(function () {
'use strict';

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var check = function (it) {
  return it && it.Math == Math && it;
};

// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
var global_1 =
  // eslint-disable-next-line es/no-global-this -- safe
  check(typeof globalThis == 'object' && globalThis) ||
  check(typeof window == 'object' && window) ||
  // eslint-disable-next-line no-restricted-globals -- safe
  check(typeof self == 'object' && self) ||
  check(typeof commonjsGlobal == 'object' && commonjsGlobal) ||
  // eslint-disable-next-line no-new-func -- fallback
  (function () { return this; })() || Function('return this')();

var isPure = false;

var fails = function (exec) {
  try {
    return !!exec();
  } catch (error) {
    return true;
  }
};

// Detect IE8's incomplete defineProperty implementation
var descriptors = !fails(function () {
  // eslint-disable-next-line es/no-object-defineproperty -- required for testing
  return Object.defineProperty({}, 1, { get: function () { return 7; } })[1] != 7;
});

var isObject = function (it) {
  return typeof it === 'object' ? it !== null : typeof it === 'function';
};

var document$1 = global_1.document;
// typeof document.createElement is 'object' in old IE
var EXISTS = isObject(document$1) && isObject(document$1.createElement);

var documentCreateElement = function (it) {
  return EXISTS ? document$1.createElement(it) : {};
};

// Thank's IE8 for his funny defineProperty
var ie8DomDefine = !descriptors && !fails(function () {
  // eslint-disable-next-line es/no-object-defineproperty -- requied for testing
  return Object.defineProperty(documentCreateElement('div'), 'a', {
    get: function () { return 7; }
  }).a != 7;
});

var anObject = function (it) {
  if (!isObject(it)) {
    throw TypeError(String(it) + ' is not an object');
  } return it;
};

// `ToPrimitive` abstract operation
// https://tc39.es/ecma262/#sec-toprimitive
// instead of the ES6 spec version, we didn't implement @@toPrimitive case
// and the second argument - flag - preferred type is a string
var toPrimitive = function (input, PREFERRED_STRING) {
  if (!isObject(input)) return input;
  var fn, val;
  if (PREFERRED_STRING && typeof (fn = input.toString) == 'function' && !isObject(val = fn.call(input))) return val;
  if (typeof (fn = input.valueOf) == 'function' && !isObject(val = fn.call(input))) return val;
  if (!PREFERRED_STRING && typeof (fn = input.toString) == 'function' && !isObject(val = fn.call(input))) return val;
  throw TypeError("Can't convert object to primitive value");
};

// eslint-disable-next-line es/no-object-defineproperty -- safe
var $defineProperty = Object.defineProperty;

// `Object.defineProperty` method
// https://tc39.es/ecma262/#sec-object.defineproperty
var f = descriptors ? $defineProperty : function defineProperty(O, P, Attributes) {
  anObject(O);
  P = toPrimitive(P, true);
  anObject(Attributes);
  if (ie8DomDefine) try {
    return $defineProperty(O, P, Attributes);
  } catch (error) { /* empty */ }
  if ('get' in Attributes || 'set' in Attributes) throw TypeError('Accessors not supported');
  if ('value' in Attributes) O[P] = Attributes.value;
  return O;
};

var objectDefineProperty = {
	f: f
};

var createPropertyDescriptor = function (bitmap, value) {
  return {
    enumerable: !(bitmap & 1),
    configurable: !(bitmap & 2),
    writable: !(bitmap & 4),
    value: value
  };
};

var createNonEnumerableProperty = descriptors ? function (object, key, value) {
  return objectDefineProperty.f(object, key, createPropertyDescriptor(1, value));
} : function (object, key, value) {
  object[key] = value;
  return object;
};

var setGlobal = function (key, value) {
  try {
    createNonEnumerableProperty(global_1, key, value);
  } catch (error) {
    global_1[key] = value;
  } return value;
};

var SHARED = '__core-js_shared__';
var store = global_1[SHARED] || setGlobal(SHARED, {});

var sharedStore = store;

var shared = createCommonjsModule(function (module) {
(module.exports = function (key, value) {
  return sharedStore[key] || (sharedStore[key] = value !== undefined ? value : {});
})('versions', []).push({
  version: '3.10.2',
  mode:  'global',
  copyright: '© 2021 Denis Pushkarev (zloirock.ru)'
});
});

var hasOwnProperty = {}.hasOwnProperty;

var has = function (it, key) {
  return hasOwnProperty.call(it, key);
};

var id = 0;
var postfix = Math.random();

var uid = function (key) {
  return 'Symbol(' + String(key === undefined ? '' : key) + ')_' + (++id + postfix).toString(36);
};

var toString$1 = {}.toString;

var classofRaw = function (it) {
  return toString$1.call(it).slice(8, -1);
};

var engineIsNode = classofRaw(global_1.process) == 'process';

var path = global_1;

var aFunction = function (variable) {
  return typeof variable == 'function' ? variable : undefined;
};

var getBuiltIn = function (namespace, method) {
  return arguments.length < 2 ? aFunction(path[namespace]) || aFunction(global_1[namespace])
    : path[namespace] && path[namespace][method] || global_1[namespace] && global_1[namespace][method];
};

var engineUserAgent = getBuiltIn('navigator', 'userAgent') || '';

var process = global_1.process;
var versions = process && process.versions;
var v8 = versions && versions.v8;
var match, version;

if (v8) {
  match = v8.split('.');
  version = match[0] + match[1];
} else if (engineUserAgent) {
  match = engineUserAgent.match(/Edge\/(\d+)/);
  if (!match || match[1] >= 74) {
    match = engineUserAgent.match(/Chrome\/(\d+)/);
    if (match) version = match[1];
  }
}

var engineV8Version = version && +version;

// eslint-disable-next-line es/no-object-getownpropertysymbols -- required for testing
var nativeSymbol = !!Object.getOwnPropertySymbols && !fails(function () {
  // eslint-disable-next-line es/no-symbol -- required for testing
  return !Symbol.sham &&
    // Chrome 38 Symbol has incorrect toString conversion
    // Chrome 38-40 symbols are not inherited from DOM collections prototypes to instances
    (engineIsNode ? engineV8Version === 38 : engineV8Version > 37 && engineV8Version < 41);
});

/* eslint-disable es/no-symbol -- required for testing */


var useSymbolAsUid = nativeSymbol
  && !Symbol.sham
  && typeof Symbol.iterator == 'symbol';

var WellKnownSymbolsStore = shared('wks');
var Symbol$1 = global_1.Symbol;
var createWellKnownSymbol = useSymbolAsUid ? Symbol$1 : Symbol$1 && Symbol$1.withoutSetter || uid;

var wellKnownSymbol = function (name) {
  if (!has(WellKnownSymbolsStore, name) || !(nativeSymbol || typeof WellKnownSymbolsStore[name] == 'string')) {
    if (nativeSymbol && has(Symbol$1, name)) {
      WellKnownSymbolsStore[name] = Symbol$1[name];
    } else {
      WellKnownSymbolsStore[name] = createWellKnownSymbol('Symbol.' + name);
    }
  } return WellKnownSymbolsStore[name];
};

var TO_STRING_TAG = wellKnownSymbol('toStringTag');
var test = {};

test[TO_STRING_TAG] = 'z';

var toStringTagSupport = String(test) === '[object z]';

var functionToString = Function.toString;

// this helper broken in `3.4.1-3.4.4`, so we can't use `shared` helper
if (typeof sharedStore.inspectSource != 'function') {
  sharedStore.inspectSource = function (it) {
    return functionToString.call(it);
  };
}

var inspectSource = sharedStore.inspectSource;

var WeakMap$1 = global_1.WeakMap;

var nativeWeakMap = typeof WeakMap$1 === 'function' && /native code/.test(inspectSource(WeakMap$1));

var keys = shared('keys');

var sharedKey = function (key) {
  return keys[key] || (keys[key] = uid(key));
};

var hiddenKeys = {};

var OBJECT_ALREADY_INITIALIZED = 'Object already initialized';
var WeakMap$2 = global_1.WeakMap;
var set, get, has$1;

var enforce = function (it) {
  return has$1(it) ? get(it) : set(it, {});
};

var getterFor = function (TYPE) {
  return function (it) {
    var state;
    if (!isObject(it) || (state = get(it)).type !== TYPE) {
      throw TypeError('Incompatible receiver, ' + TYPE + ' required');
    } return state;
  };
};

if (nativeWeakMap) {
  var store$1 = sharedStore.state || (sharedStore.state = new WeakMap$2());
  var wmget = store$1.get;
  var wmhas = store$1.has;
  var wmset = store$1.set;
  set = function (it, metadata) {
    if (wmhas.call(store$1, it)) throw new TypeError(OBJECT_ALREADY_INITIALIZED);
    metadata.facade = it;
    wmset.call(store$1, it, metadata);
    return metadata;
  };
  get = function (it) {
    return wmget.call(store$1, it) || {};
  };
  has$1 = function (it) {
    return wmhas.call(store$1, it);
  };
} else {
  var STATE = sharedKey('state');
  hiddenKeys[STATE] = true;
  set = function (it, metadata) {
    if (has(it, STATE)) throw new TypeError(OBJECT_ALREADY_INITIALIZED);
    metadata.facade = it;
    createNonEnumerableProperty(it, STATE, metadata);
    return metadata;
  };
  get = function (it) {
    return has(it, STATE) ? it[STATE] : {};
  };
  has$1 = function (it) {
    return has(it, STATE);
  };
}

var internalState = {
  set: set,
  get: get,
  has: has$1,
  enforce: enforce,
  getterFor: getterFor
};

var redefine = createCommonjsModule(function (module) {
var getInternalState = internalState.get;
var enforceInternalState = internalState.enforce;
var TEMPLATE = String(String).split('String');

(module.exports = function (O, key, value, options) {
  var unsafe = options ? !!options.unsafe : false;
  var simple = options ? !!options.enumerable : false;
  var noTargetGet = options ? !!options.noTargetGet : false;
  var state;
  if (typeof value == 'function') {
    if (typeof key == 'string' && !has(value, 'name')) {
      createNonEnumerableProperty(value, 'name', key);
    }
    state = enforceInternalState(value);
    if (!state.source) {
      state.source = TEMPLATE.join(typeof key == 'string' ? key : '');
    }
  }
  if (O === global_1) {
    if (simple) O[key] = value;
    else setGlobal(key, value);
    return;
  } else if (!unsafe) {
    delete O[key];
  } else if (!noTargetGet && O[key]) {
    simple = true;
  }
  if (simple) O[key] = value;
  else createNonEnumerableProperty(O, key, value);
// add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative
})(Function.prototype, 'toString', function toString() {
  return typeof this == 'function' && getInternalState(this).source || inspectSource(this);
});
});

var TO_STRING_TAG$1 = wellKnownSymbol('toStringTag');
// ES3 wrong here
var CORRECT_ARGUMENTS = classofRaw(function () { return arguments; }()) == 'Arguments';

// fallback for IE11 Script Access Denied error
var tryGet = function (it, key) {
  try {
    return it[key];
  } catch (error) { /* empty */ }
};

// getting tag from ES6+ `Object.prototype.toString`
var classof = toStringTagSupport ? classofRaw : function (it) {
  var O, tag, result;
  return it === undefined ? 'Undefined' : it === null ? 'Null'
    // @@toStringTag case
    : typeof (tag = tryGet(O = Object(it), TO_STRING_TAG$1)) == 'string' ? tag
    // builtinTag case
    : CORRECT_ARGUMENTS ? classofRaw(O)
    // ES3 arguments fallback
    : (result = classofRaw(O)) == 'Object' && typeof O.callee == 'function' ? 'Arguments' : result;
};

// `Object.prototype.toString` method implementation
// https://tc39.es/ecma262/#sec-object.prototype.tostring
var objectToString = toStringTagSupport ? {}.toString : function toString() {
  return '[object ' + classof(this) + ']';
};

// `Object.prototype.toString` method
// https://tc39.es/ecma262/#sec-object.prototype.tostring
if (!toStringTagSupport) {
  redefine(Object.prototype, 'toString', objectToString, { unsafe: true });
}

var $propertyIsEnumerable = {}.propertyIsEnumerable;
// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
var getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;

// Nashorn ~ JDK8 bug
var NASHORN_BUG = getOwnPropertyDescriptor && !$propertyIsEnumerable.call({ 1: 2 }, 1);

// `Object.prototype.propertyIsEnumerable` method implementation
// https://tc39.es/ecma262/#sec-object.prototype.propertyisenumerable
var f$1 = NASHORN_BUG ? function propertyIsEnumerable(V) {
  var descriptor = getOwnPropertyDescriptor(this, V);
  return !!descriptor && descriptor.enumerable;
} : $propertyIsEnumerable;

var objectPropertyIsEnumerable = {
	f: f$1
};

var split = ''.split;

// fallback for non-array-like ES3 and non-enumerable old V8 strings
var indexedObject = fails(function () {
  // throws an error in rhino, see https://github.com/mozilla/rhino/issues/346
  // eslint-disable-next-line no-prototype-builtins -- safe
  return !Object('z').propertyIsEnumerable(0);
}) ? function (it) {
  return classofRaw(it) == 'String' ? split.call(it, '') : Object(it);
} : Object;

// `RequireObjectCoercible` abstract operation
// https://tc39.es/ecma262/#sec-requireobjectcoercible
var requireObjectCoercible = function (it) {
  if (it == undefined) throw TypeError("Can't call method on " + it);
  return it;
};

// toObject with fallback for non-array-like ES3 strings



var toIndexedObject = function (it) {
  return indexedObject(requireObjectCoercible(it));
};

// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
var $getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;

// `Object.getOwnPropertyDescriptor` method
// https://tc39.es/ecma262/#sec-object.getownpropertydescriptor
var f$2 = descriptors ? $getOwnPropertyDescriptor : function getOwnPropertyDescriptor(O, P) {
  O = toIndexedObject(O);
  P = toPrimitive(P, true);
  if (ie8DomDefine) try {
    return $getOwnPropertyDescriptor(O, P);
  } catch (error) { /* empty */ }
  if (has(O, P)) return createPropertyDescriptor(!objectPropertyIsEnumerable.f.call(O, P), O[P]);
};

var objectGetOwnPropertyDescriptor = {
	f: f$2
};

var ceil = Math.ceil;
var floor = Math.floor;

// `ToInteger` abstract operation
// https://tc39.es/ecma262/#sec-tointeger
var toInteger = function (argument) {
  return isNaN(argument = +argument) ? 0 : (argument > 0 ? floor : ceil)(argument);
};

var min = Math.min;

// `ToLength` abstract operation
// https://tc39.es/ecma262/#sec-tolength
var toLength = function (argument) {
  return argument > 0 ? min(toInteger(argument), 0x1FFFFFFFFFFFFF) : 0; // 2 ** 53 - 1 == 9007199254740991
};

var max = Math.max;
var min$1 = Math.min;

// Helper for a popular repeating case of the spec:
// Let integer be ? ToInteger(index).
// If integer < 0, let result be max((length + integer), 0); else let result be min(integer, length).
var toAbsoluteIndex = function (index, length) {
  var integer = toInteger(index);
  return integer < 0 ? max(integer + length, 0) : min$1(integer, length);
};

// `Array.prototype.{ indexOf, includes }` methods implementation
var createMethod = function (IS_INCLUDES) {
  return function ($this, el, fromIndex) {
    var O = toIndexedObject($this);
    var length = toLength(O.length);
    var index = toAbsoluteIndex(fromIndex, length);
    var value;
    // Array#includes uses SameValueZero equality algorithm
    // eslint-disable-next-line no-self-compare -- NaN check
    if (IS_INCLUDES && el != el) while (length > index) {
      value = O[index++];
      // eslint-disable-next-line no-self-compare -- NaN check
      if (value != value) return true;
    // Array#indexOf ignores holes, Array#includes - not
    } else for (;length > index; index++) {
      if ((IS_INCLUDES || index in O) && O[index] === el) return IS_INCLUDES || index || 0;
    } return !IS_INCLUDES && -1;
  };
};

var arrayIncludes = {
  // `Array.prototype.includes` method
  // https://tc39.es/ecma262/#sec-array.prototype.includes
  includes: createMethod(true),
  // `Array.prototype.indexOf` method
  // https://tc39.es/ecma262/#sec-array.prototype.indexof
  indexOf: createMethod(false)
};

var indexOf = arrayIncludes.indexOf;


var objectKeysInternal = function (object, names) {
  var O = toIndexedObject(object);
  var i = 0;
  var result = [];
  var key;
  for (key in O) !has(hiddenKeys, key) && has(O, key) && result.push(key);
  // Don't enum bug & hidden keys
  while (names.length > i) if (has(O, key = names[i++])) {
    ~indexOf(result, key) || result.push(key);
  }
  return result;
};

// IE8- don't enum bug keys
var enumBugKeys = [
  'constructor',
  'hasOwnProperty',
  'isPrototypeOf',
  'propertyIsEnumerable',
  'toLocaleString',
  'toString',
  'valueOf'
];

var hiddenKeys$1 = enumBugKeys.concat('length', 'prototype');

// `Object.getOwnPropertyNames` method
// https://tc39.es/ecma262/#sec-object.getownpropertynames
// eslint-disable-next-line es/no-object-getownpropertynames -- safe
var f$3 = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
  return objectKeysInternal(O, hiddenKeys$1);
};

var objectGetOwnPropertyNames = {
	f: f$3
};

// eslint-disable-next-line es/no-object-getownpropertysymbols -- safe
var f$4 = Object.getOwnPropertySymbols;

var objectGetOwnPropertySymbols = {
	f: f$4
};

// all object keys, includes non-enumerable and symbols
var ownKeys = getBuiltIn('Reflect', 'ownKeys') || function ownKeys(it) {
  var keys = objectGetOwnPropertyNames.f(anObject(it));
  var getOwnPropertySymbols = objectGetOwnPropertySymbols.f;
  return getOwnPropertySymbols ? keys.concat(getOwnPropertySymbols(it)) : keys;
};

var copyConstructorProperties = function (target, source) {
  var keys = ownKeys(source);
  var defineProperty = objectDefineProperty.f;
  var getOwnPropertyDescriptor = objectGetOwnPropertyDescriptor.f;
  for (var i = 0; i < keys.length; i++) {
    var key = keys[i];
    if (!has(target, key)) defineProperty(target, key, getOwnPropertyDescriptor(source, key));
  }
};

var replacement = /#|\.prototype\./;

var isForced = function (feature, detection) {
  var value = data[normalize(feature)];
  return value == POLYFILL ? true
    : value == NATIVE ? false
    : typeof detection == 'function' ? fails(detection)
    : !!detection;
};

var normalize = isForced.normalize = function (string) {
  return String(string).replace(replacement, '.').toLowerCase();
};

var data = isForced.data = {};
var NATIVE = isForced.NATIVE = 'N';
var POLYFILL = isForced.POLYFILL = 'P';

var isForced_1 = isForced;

var getOwnPropertyDescriptor$1 = objectGetOwnPropertyDescriptor.f;






/*
  options.target      - name of the target object
  options.global      - target is the global object
  options.stat        - export as static methods of target
  options.proto       - export as prototype methods of target
  options.real        - real prototype method for the `pure` version
  options.forced      - export even if the native feature is available
  options.bind        - bind methods to the target, required for the `pure` version
  options.wrap        - wrap constructors to preventing global pollution, required for the `pure` version
  options.unsafe      - use the simple assignment of property instead of delete + defineProperty
  options.sham        - add a flag to not completely full polyfills
  options.enumerable  - export as enumerable property
  options.noTargetGet - prevent calling a getter on target
*/
var _export = function (options, source) {
  var TARGET = options.target;
  var GLOBAL = options.global;
  var STATIC = options.stat;
  var FORCED, target, key, targetProperty, sourceProperty, descriptor;
  if (GLOBAL) {
    target = global_1;
  } else if (STATIC) {
    target = global_1[TARGET] || setGlobal(TARGET, {});
  } else {
    target = (global_1[TARGET] || {}).prototype;
  }
  if (target) for (key in source) {
    sourceProperty = source[key];
    if (options.noTargetGet) {
      descriptor = getOwnPropertyDescriptor$1(target, key);
      targetProperty = descriptor && descriptor.value;
    } else targetProperty = target[key];
    FORCED = isForced_1(GLOBAL ? key : TARGET + (STATIC ? '.' : '#') + key, options.forced);
    // contained in target
    if (!FORCED && targetProperty !== undefined) {
      if (typeof sourceProperty === typeof targetProperty) continue;
      copyConstructorProperties(sourceProperty, targetProperty);
    }
    // add a flag to not completely full polyfills
    if (options.sham || (targetProperty && targetProperty.sham)) {
      createNonEnumerableProperty(sourceProperty, 'sham', true);
    }
    // extend global
    redefine(target, key, sourceProperty, options);
  }
};

var nativePromiseConstructor = global_1.Promise;

var redefineAll = function (target, src, options) {
  for (var key in src) redefine(target, key, src[key], options);
  return target;
};

var defineProperty = objectDefineProperty.f;



var TO_STRING_TAG$2 = wellKnownSymbol('toStringTag');

var setToStringTag = function (it, TAG, STATIC) {
  if (it && !has(it = STATIC ? it : it.prototype, TO_STRING_TAG$2)) {
    defineProperty(it, TO_STRING_TAG$2, { configurable: true, value: TAG });
  }
};

var SPECIES = wellKnownSymbol('species');

var setSpecies = function (CONSTRUCTOR_NAME) {
  var Constructor = getBuiltIn(CONSTRUCTOR_NAME);
  var defineProperty = objectDefineProperty.f;

  if (descriptors && Constructor && !Constructor[SPECIES]) {
    defineProperty(Constructor, SPECIES, {
      configurable: true,
      get: function () { return this; }
    });
  }
};

var aFunction$1 = function (it) {
  if (typeof it != 'function') {
    throw TypeError(String(it) + ' is not a function');
  } return it;
};

var anInstance = function (it, Constructor, name) {
  if (!(it instanceof Constructor)) {
    throw TypeError('Incorrect ' + (name ? name + ' ' : '') + 'invocation');
  } return it;
};

var iterators = {};

var ITERATOR = wellKnownSymbol('iterator');
var ArrayPrototype = Array.prototype;

// check on default Array iterator
var isArrayIteratorMethod = function (it) {
  return it !== undefined && (iterators.Array === it || ArrayPrototype[ITERATOR] === it);
};

// optional / simple context binding
var functionBindContext = function (fn, that, length) {
  aFunction$1(fn);
  if (that === undefined) return fn;
  switch (length) {
    case 0: return function () {
      return fn.call(that);
    };
    case 1: return function (a) {
      return fn.call(that, a);
    };
    case 2: return function (a, b) {
      return fn.call(that, a, b);
    };
    case 3: return function (a, b, c) {
      return fn.call(that, a, b, c);
    };
  }
  return function (/* ...args */) {
    return fn.apply(that, arguments);
  };
};

var ITERATOR$1 = wellKnownSymbol('iterator');

var getIteratorMethod = function (it) {
  if (it != undefined) return it[ITERATOR$1]
    || it['@@iterator']
    || iterators[classof(it)];
};

var iteratorClose = function (iterator) {
  var returnMethod = iterator['return'];
  if (returnMethod !== undefined) {
    return anObject(returnMethod.call(iterator)).value;
  }
};

var Result = function (stopped, result) {
  this.stopped = stopped;
  this.result = result;
};

var iterate = function (iterable, unboundFunction, options) {
  var that = options && options.that;
  var AS_ENTRIES = !!(options && options.AS_ENTRIES);
  var IS_ITERATOR = !!(options && options.IS_ITERATOR);
  var INTERRUPTED = !!(options && options.INTERRUPTED);
  var fn = functionBindContext(unboundFunction, that, 1 + AS_ENTRIES + INTERRUPTED);
  var iterator, iterFn, index, length, result, next, step;

  var stop = function (condition) {
    if (iterator) iteratorClose(iterator);
    return new Result(true, condition);
  };

  var callFn = function (value) {
    if (AS_ENTRIES) {
      anObject(value);
      return INTERRUPTED ? fn(value[0], value[1], stop) : fn(value[0], value[1]);
    } return INTERRUPTED ? fn(value, stop) : fn(value);
  };

  if (IS_ITERATOR) {
    iterator = iterable;
  } else {
    iterFn = getIteratorMethod(iterable);
    if (typeof iterFn != 'function') throw TypeError('Target is not iterable');
    // optimisation for array iterators
    if (isArrayIteratorMethod(iterFn)) {
      for (index = 0, length = toLength(iterable.length); length > index; index++) {
        result = callFn(iterable[index]);
        if (result && result instanceof Result) return result;
      } return new Result(false);
    }
    iterator = iterFn.call(iterable);
  }

  next = iterator.next;
  while (!(step = next.call(iterator)).done) {
    try {
      result = callFn(step.value);
    } catch (error) {
      iteratorClose(iterator);
      throw error;
    }
    if (typeof result == 'object' && result && result instanceof Result) return result;
  } return new Result(false);
};

var ITERATOR$2 = wellKnownSymbol('iterator');
var SAFE_CLOSING = false;

try {
  var called = 0;
  var iteratorWithReturn = {
    next: function () {
      return { done: !!called++ };
    },
    'return': function () {
      SAFE_CLOSING = true;
    }
  };
  iteratorWithReturn[ITERATOR$2] = function () {
    return this;
  };
  // eslint-disable-next-line es/no-array-from, no-throw-literal -- required for testing
  Array.from(iteratorWithReturn, function () { throw 2; });
} catch (error) { /* empty */ }

var checkCorrectnessOfIteration = function (exec, SKIP_CLOSING) {
  if (!SKIP_CLOSING && !SAFE_CLOSING) return false;
  var ITERATION_SUPPORT = false;
  try {
    var object = {};
    object[ITERATOR$2] = function () {
      return {
        next: function () {
          return { done: ITERATION_SUPPORT = true };
        }
      };
    };
    exec(object);
  } catch (error) { /* empty */ }
  return ITERATION_SUPPORT;
};

var SPECIES$1 = wellKnownSymbol('species');

// `SpeciesConstructor` abstract operation
// https://tc39.es/ecma262/#sec-speciesconstructor
var speciesConstructor = function (O, defaultConstructor) {
  var C = anObject(O).constructor;
  var S;
  return C === undefined || (S = anObject(C)[SPECIES$1]) == undefined ? defaultConstructor : aFunction$1(S);
};

var html = getBuiltIn('document', 'documentElement');

var engineIsIos = /(?:iphone|ipod|ipad).*applewebkit/i.test(engineUserAgent);

var location = global_1.location;
var set$1 = global_1.setImmediate;
var clear = global_1.clearImmediate;
var process$1 = global_1.process;
var MessageChannel$1 = global_1.MessageChannel;
var Dispatch = global_1.Dispatch;
var counter = 0;
var queue = {};
var ONREADYSTATECHANGE = 'onreadystatechange';
var defer, channel, port;

var run = function (id) {
  // eslint-disable-next-line no-prototype-builtins -- safe
  if (queue.hasOwnProperty(id)) {
    var fn = queue[id];
    delete queue[id];
    fn();
  }
};

var runner = function (id) {
  return function () {
    run(id);
  };
};

var listener = function (event) {
  run(event.data);
};

var post = function (id) {
  // old engines have not location.origin
  global_1.postMessage(id + '', location.protocol + '//' + location.host);
};

// Node.js 0.9+ & IE10+ has setImmediate, otherwise:
if (!set$1 || !clear) {
  set$1 = function setImmediate(fn) {
    var args = [];
    var i = 1;
    while (arguments.length > i) args.push(arguments[i++]);
    queue[++counter] = function () {
      // eslint-disable-next-line no-new-func -- spec requirement
      (typeof fn == 'function' ? fn : Function(fn)).apply(undefined, args);
    };
    defer(counter);
    return counter;
  };
  clear = function clearImmediate(id) {
    delete queue[id];
  };
  // Node.js 0.8-
  if (engineIsNode) {
    defer = function (id) {
      process$1.nextTick(runner(id));
    };
  // Sphere (JS game engine) Dispatch API
  } else if (Dispatch && Dispatch.now) {
    defer = function (id) {
      Dispatch.now(runner(id));
    };
  // Browsers with MessageChannel, includes WebWorkers
  // except iOS - https://github.com/zloirock/core-js/issues/624
  } else if (MessageChannel$1 && !engineIsIos) {
    channel = new MessageChannel$1();
    port = channel.port2;
    channel.port1.onmessage = listener;
    defer = functionBindContext(port.postMessage, port, 1);
  // Browsers with postMessage, skip WebWorkers
  // IE8 has postMessage, but it's sync & typeof its postMessage is 'object'
  } else if (
    global_1.addEventListener &&
    typeof postMessage == 'function' &&
    !global_1.importScripts &&
    location && location.protocol !== 'file:' &&
    !fails(post)
  ) {
    defer = post;
    global_1.addEventListener('message', listener, false);
  // IE8-
  } else if (ONREADYSTATECHANGE in documentCreateElement('script')) {
    defer = function (id) {
      html.appendChild(documentCreateElement('script'))[ONREADYSTATECHANGE] = function () {
        html.removeChild(this);
        run(id);
      };
    };
  // Rest old browsers
  } else {
    defer = function (id) {
      setTimeout(runner(id), 0);
    };
  }
}

var task = {
  set: set$1,
  clear: clear
};

var engineIsWebosWebkit = /web0s(?!.*chrome)/i.test(engineUserAgent);

var getOwnPropertyDescriptor$2 = objectGetOwnPropertyDescriptor.f;
var macrotask = task.set;




var MutationObserver$1 = global_1.MutationObserver || global_1.WebKitMutationObserver;
var document$2 = global_1.document;
var process$2 = global_1.process;
var Promise$1 = global_1.Promise;
// Node.js 11 shows ExperimentalWarning on getting `queueMicrotask`
var queueMicrotaskDescriptor = getOwnPropertyDescriptor$2(global_1, 'queueMicrotask');
var queueMicrotask = queueMicrotaskDescriptor && queueMicrotaskDescriptor.value;

var flush, head, last, notify, toggle, node, promise, then;

// modern engines have queueMicrotask method
if (!queueMicrotask) {
  flush = function () {
    var parent, fn;
    if (engineIsNode && (parent = process$2.domain)) parent.exit();
    while (head) {
      fn = head.fn;
      head = head.next;
      try {
        fn();
      } catch (error) {
        if (head) notify();
        else last = undefined;
        throw error;
      }
    } last = undefined;
    if (parent) parent.enter();
  };

  // browsers with MutationObserver, except iOS - https://github.com/zloirock/core-js/issues/339
  // also except WebOS Webkit https://github.com/zloirock/core-js/issues/898
  if (!engineIsIos && !engineIsNode && !engineIsWebosWebkit && MutationObserver$1 && document$2) {
    toggle = true;
    node = document$2.createTextNode('');
    new MutationObserver$1(flush).observe(node, { characterData: true });
    notify = function () {
      node.data = toggle = !toggle;
    };
  // environments with maybe non-completely correct, but existent Promise
  } else if (Promise$1 && Promise$1.resolve) {
    // Promise.resolve without an argument throws an error in LG WebOS 2
    promise = Promise$1.resolve(undefined);
    then = promise.then;
    notify = function () {
      then.call(promise, flush);
    };
  // Node.js without promises
  } else if (engineIsNode) {
    notify = function () {
      process$2.nextTick(flush);
    };
  // for other environments - macrotask based on:
  // - setImmediate
  // - MessageChannel
  // - window.postMessag
  // - onreadystatechange
  // - setTimeout
  } else {
    notify = function () {
      // strange IE + webpack dev server bug - use .call(global)
      macrotask.call(global_1, flush);
    };
  }
}

var microtask = queueMicrotask || function (fn) {
  var task = { fn: fn, next: undefined };
  if (last) last.next = task;
  if (!head) {
    head = task;
    notify();
  } last = task;
};

var PromiseCapability = function (C) {
  var resolve, reject;
  this.promise = new C(function ($$resolve, $$reject) {
    if (resolve !== undefined || reject !== undefined) throw TypeError('Bad Promise constructor');
    resolve = $$resolve;
    reject = $$reject;
  });
  this.resolve = aFunction$1(resolve);
  this.reject = aFunction$1(reject);
};

// 25.4.1.5 NewPromiseCapability(C)
var f$5 = function (C) {
  return new PromiseCapability(C);
};

var newPromiseCapability = {
	f: f$5
};

var promiseResolve = function (C, x) {
  anObject(C);
  if (isObject(x) && x.constructor === C) return x;
  var promiseCapability = newPromiseCapability.f(C);
  var resolve = promiseCapability.resolve;
  resolve(x);
  return promiseCapability.promise;
};

var hostReportErrors = function (a, b) {
  var console = global_1.console;
  if (console && console.error) {
    arguments.length === 1 ? console.error(a) : console.error(a, b);
  }
};

var perform = function (exec) {
  try {
    return { error: false, value: exec() };
  } catch (error) {
    return { error: true, value: error };
  }
};

var task$1 = task.set;











var SPECIES$2 = wellKnownSymbol('species');
var PROMISE = 'Promise';
var getInternalState = internalState.get;
var setInternalState = internalState.set;
var getInternalPromiseState = internalState.getterFor(PROMISE);
var PromiseConstructor = nativePromiseConstructor;
var TypeError$1 = global_1.TypeError;
var document$3 = global_1.document;
var process$3 = global_1.process;
var $fetch = getBuiltIn('fetch');
var newPromiseCapability$1 = newPromiseCapability.f;
var newGenericPromiseCapability = newPromiseCapability$1;
var DISPATCH_EVENT = !!(document$3 && document$3.createEvent && global_1.dispatchEvent);
var NATIVE_REJECTION_EVENT = typeof PromiseRejectionEvent == 'function';
var UNHANDLED_REJECTION = 'unhandledrejection';
var REJECTION_HANDLED = 'rejectionhandled';
var PENDING = 0;
var FULFILLED = 1;
var REJECTED = 2;
var HANDLED = 1;
var UNHANDLED = 2;
var Internal, OwnPromiseCapability, PromiseWrapper, nativeThen;

var FORCED = isForced_1(PROMISE, function () {
  var GLOBAL_CORE_JS_PROMISE = inspectSource(PromiseConstructor) !== String(PromiseConstructor);
  if (!GLOBAL_CORE_JS_PROMISE) {
    // V8 6.6 (Node 10 and Chrome 66) have a bug with resolving custom thenables
    // https://bugs.chromium.org/p/chromium/issues/detail?id=830565
    // We can't detect it synchronously, so just check versions
    if (engineV8Version === 66) return true;
    // Unhandled rejections tracking support, NodeJS Promise without it fails @@species test
    if (!engineIsNode && !NATIVE_REJECTION_EVENT) return true;
  }
  // We can't use @@species feature detection in V8 since it causes
  // deoptimization and performance degradation
  // https://github.com/zloirock/core-js/issues/679
  if (engineV8Version >= 51 && /native code/.test(PromiseConstructor)) return false;
  // Detect correctness of subclassing with @@species support
  var promise = PromiseConstructor.resolve(1);
  var FakePromise = function (exec) {
    exec(function () { /* empty */ }, function () { /* empty */ });
  };
  var constructor = promise.constructor = {};
  constructor[SPECIES$2] = FakePromise;
  return !(promise.then(function () { /* empty */ }) instanceof FakePromise);
});

var INCORRECT_ITERATION = FORCED || !checkCorrectnessOfIteration(function (iterable) {
  PromiseConstructor.all(iterable)['catch'](function () { /* empty */ });
});

// helpers
var isThenable = function (it) {
  var then;
  return isObject(it) && typeof (then = it.then) == 'function' ? then : false;
};

var notify$1 = function (state, isReject) {
  if (state.notified) return;
  state.notified = true;
  var chain = state.reactions;
  microtask(function () {
    var value = state.value;
    var ok = state.state == FULFILLED;
    var index = 0;
    // variable length - can't use forEach
    while (chain.length > index) {
      var reaction = chain[index++];
      var handler = ok ? reaction.ok : reaction.fail;
      var resolve = reaction.resolve;
      var reject = reaction.reject;
      var domain = reaction.domain;
      var result, then, exited;
      try {
        if (handler) {
          if (!ok) {
            if (state.rejection === UNHANDLED) onHandleUnhandled(state);
            state.rejection = HANDLED;
          }
          if (handler === true) result = value;
          else {
            if (domain) domain.enter();
            result = handler(value); // can throw
            if (domain) {
              domain.exit();
              exited = true;
            }
          }
          if (result === reaction.promise) {
            reject(TypeError$1('Promise-chain cycle'));
          } else if (then = isThenable(result)) {
            then.call(result, resolve, reject);
          } else resolve(result);
        } else reject(value);
      } catch (error) {
        if (domain && !exited) domain.exit();
        reject(error);
      }
    }
    state.reactions = [];
    state.notified = false;
    if (isReject && !state.rejection) onUnhandled(state);
  });
};

var dispatchEvent = function (name, promise, reason) {
  var event, handler;
  if (DISPATCH_EVENT) {
    event = document$3.createEvent('Event');
    event.promise = promise;
    event.reason = reason;
    event.initEvent(name, false, true);
    global_1.dispatchEvent(event);
  } else event = { promise: promise, reason: reason };
  if (!NATIVE_REJECTION_EVENT && (handler = global_1['on' + name])) handler(event);
  else if (name === UNHANDLED_REJECTION) hostReportErrors('Unhandled promise rejection', reason);
};

var onUnhandled = function (state) {
  task$1.call(global_1, function () {
    var promise = state.facade;
    var value = state.value;
    var IS_UNHANDLED = isUnhandled(state);
    var result;
    if (IS_UNHANDLED) {
      result = perform(function () {
        if (engineIsNode) {
          process$3.emit('unhandledRejection', value, promise);
        } else dispatchEvent(UNHANDLED_REJECTION, promise, value);
      });
      // Browsers should not trigger `rejectionHandled` event if it was handled here, NodeJS - should
      state.rejection = engineIsNode || isUnhandled(state) ? UNHANDLED : HANDLED;
      if (result.error) throw result.value;
    }
  });
};

var isUnhandled = function (state) {
  return state.rejection !== HANDLED && !state.parent;
};

var onHandleUnhandled = function (state) {
  task$1.call(global_1, function () {
    var promise = state.facade;
    if (engineIsNode) {
      process$3.emit('rejectionHandled', promise);
    } else dispatchEvent(REJECTION_HANDLED, promise, state.value);
  });
};

var bind = function (fn, state, unwrap) {
  return function (value) {
    fn(state, value, unwrap);
  };
};

var internalReject = function (state, value, unwrap) {
  if (state.done) return;
  state.done = true;
  if (unwrap) state = unwrap;
  state.value = value;
  state.state = REJECTED;
  notify$1(state, true);
};

var internalResolve = function (state, value, unwrap) {
  if (state.done) return;
  state.done = true;
  if (unwrap) state = unwrap;
  try {
    if (state.facade === value) throw TypeError$1("Promise can't be resolved itself");
    var then = isThenable(value);
    if (then) {
      microtask(function () {
        var wrapper = { done: false };
        try {
          then.call(value,
            bind(internalResolve, wrapper, state),
            bind(internalReject, wrapper, state)
          );
        } catch (error) {
          internalReject(wrapper, error, state);
        }
      });
    } else {
      state.value = value;
      state.state = FULFILLED;
      notify$1(state, false);
    }
  } catch (error) {
    internalReject({ done: false }, error, state);
  }
};

// constructor polyfill
if (FORCED) {
  // 25.4.3.1 Promise(executor)
  PromiseConstructor = function Promise(executor) {
    anInstance(this, PromiseConstructor, PROMISE);
    aFunction$1(executor);
    Internal.call(this);
    var state = getInternalState(this);
    try {
      executor(bind(internalResolve, state), bind(internalReject, state));
    } catch (error) {
      internalReject(state, error);
    }
  };
  // eslint-disable-next-line no-unused-vars -- required for `.length`
  Internal = function Promise(executor) {
    setInternalState(this, {
      type: PROMISE,
      done: false,
      notified: false,
      parent: false,
      reactions: [],
      rejection: false,
      state: PENDING,
      value: undefined
    });
  };
  Internal.prototype = redefineAll(PromiseConstructor.prototype, {
    // `Promise.prototype.then` method
    // https://tc39.es/ecma262/#sec-promise.prototype.then
    then: function then(onFulfilled, onRejected) {
      var state = getInternalPromiseState(this);
      var reaction = newPromiseCapability$1(speciesConstructor(this, PromiseConstructor));
      reaction.ok = typeof onFulfilled == 'function' ? onFulfilled : true;
      reaction.fail = typeof onRejected == 'function' && onRejected;
      reaction.domain = engineIsNode ? process$3.domain : undefined;
      state.parent = true;
      state.reactions.push(reaction);
      if (state.state != PENDING) notify$1(state, false);
      return reaction.promise;
    },
    // `Promise.prototype.catch` method
    // https://tc39.es/ecma262/#sec-promise.prototype.catch
    'catch': function (onRejected) {
      return this.then(undefined, onRejected);
    }
  });
  OwnPromiseCapability = function () {
    var promise = new Internal();
    var state = getInternalState(promise);
    this.promise = promise;
    this.resolve = bind(internalResolve, state);
    this.reject = bind(internalReject, state);
  };
  newPromiseCapability.f = newPromiseCapability$1 = function (C) {
    return C === PromiseConstructor || C === PromiseWrapper
      ? new OwnPromiseCapability(C)
      : newGenericPromiseCapability(C);
  };

  if ( typeof nativePromiseConstructor == 'function') {
    nativeThen = nativePromiseConstructor.prototype.then;

    // wrap native Promise#then for native async functions
    redefine(nativePromiseConstructor.prototype, 'then', function then(onFulfilled, onRejected) {
      var that = this;
      return new PromiseConstructor(function (resolve, reject) {
        nativeThen.call(that, resolve, reject);
      }).then(onFulfilled, onRejected);
    // https://github.com/zloirock/core-js/issues/640
    }, { unsafe: true });

    // wrap fetch result
    if (typeof $fetch == 'function') _export({ global: true, enumerable: true, forced: true }, {
      // eslint-disable-next-line no-unused-vars -- required for `.length`
      fetch: function fetch(input /* , init */) {
        return promiseResolve(PromiseConstructor, $fetch.apply(global_1, arguments));
      }
    });
  }
}

_export({ global: true, wrap: true, forced: FORCED }, {
  Promise: PromiseConstructor
});

setToStringTag(PromiseConstructor, PROMISE, false);
setSpecies(PROMISE);

PromiseWrapper = getBuiltIn(PROMISE);

// statics
_export({ target: PROMISE, stat: true, forced: FORCED }, {
  // `Promise.reject` method
  // https://tc39.es/ecma262/#sec-promise.reject
  reject: function reject(r) {
    var capability = newPromiseCapability$1(this);
    capability.reject.call(undefined, r);
    return capability.promise;
  }
});

_export({ target: PROMISE, stat: true, forced:  FORCED }, {
  // `Promise.resolve` method
  // https://tc39.es/ecma262/#sec-promise.resolve
  resolve: function resolve(x) {
    return promiseResolve( this, x);
  }
});

_export({ target: PROMISE, stat: true, forced: INCORRECT_ITERATION }, {
  // `Promise.all` method
  // https://tc39.es/ecma262/#sec-promise.all
  all: function all(iterable) {
    var C = this;
    var capability = newPromiseCapability$1(C);
    var resolve = capability.resolve;
    var reject = capability.reject;
    var result = perform(function () {
      var $promiseResolve = aFunction$1(C.resolve);
      var values = [];
      var counter = 0;
      var remaining = 1;
      iterate(iterable, function (promise) {
        var index = counter++;
        var alreadyCalled = false;
        values.push(undefined);
        remaining++;
        $promiseResolve.call(C, promise).then(function (value) {
          if (alreadyCalled) return;
          alreadyCalled = true;
          values[index] = value;
          --remaining || resolve(values);
        }, reject);
      });
      --remaining || resolve(values);
    });
    if (result.error) reject(result.value);
    return capability.promise;
  },
  // `Promise.race` method
  // https://tc39.es/ecma262/#sec-promise.race
  race: function race(iterable) {
    var C = this;
    var capability = newPromiseCapability$1(C);
    var reject = capability.reject;
    var result = perform(function () {
      var $promiseResolve = aFunction$1(C.resolve);
      iterate(iterable, function (promise) {
        $promiseResolve.call(C, promise).then(capability.resolve, reject);
      });
    });
    if (result.error) reject(result.value);
    return capability.promise;
  }
});

var defineProperty$1 = objectDefineProperty.f;

var FunctionPrototype = Function.prototype;
var FunctionPrototypeToString = FunctionPrototype.toString;
var nameRE = /^\s*function ([^ (]*)/;
var NAME = 'name';

// Function instances `.name` property
// https://tc39.es/ecma262/#sec-function-instances-name
if (descriptors && !(NAME in FunctionPrototype)) {
  defineProperty$1(FunctionPrototype, NAME, {
    configurable: true,
    get: function () {
      try {
        return FunctionPrototypeToString.call(this).match(nameRE)[1];
      } catch (error) {
        return '';
      }
    }
  });
}

// `Object.keys` method
// https://tc39.es/ecma262/#sec-object.keys
// eslint-disable-next-line es/no-object-keys -- safe
var objectKeys = Object.keys || function keys(O) {
  return objectKeysInternal(O, enumBugKeys);
};

// `Object.defineProperties` method
// https://tc39.es/ecma262/#sec-object.defineproperties
// eslint-disable-next-line es/no-object-defineproperties -- safe
var objectDefineProperties = descriptors ? Object.defineProperties : function defineProperties(O, Properties) {
  anObject(O);
  var keys = objectKeys(Properties);
  var length = keys.length;
  var index = 0;
  var key;
  while (length > index) objectDefineProperty.f(O, key = keys[index++], Properties[key]);
  return O;
};

var GT = '>';
var LT = '<';
var PROTOTYPE = 'prototype';
var SCRIPT = 'script';
var IE_PROTO = sharedKey('IE_PROTO');

var EmptyConstructor = function () { /* empty */ };

var scriptTag = function (content) {
  return LT + SCRIPT + GT + content + LT + '/' + SCRIPT + GT;
};

// Create object with fake `null` prototype: use ActiveX Object with cleared prototype
var NullProtoObjectViaActiveX = function (activeXDocument) {
  activeXDocument.write(scriptTag(''));
  activeXDocument.close();
  var temp = activeXDocument.parentWindow.Object;
  activeXDocument = null; // avoid memory leak
  return temp;
};

// Create object with fake `null` prototype: use iframe Object with cleared prototype
var NullProtoObjectViaIFrame = function () {
  // Thrash, waste and sodomy: IE GC bug
  var iframe = documentCreateElement('iframe');
  var JS = 'java' + SCRIPT + ':';
  var iframeDocument;
  iframe.style.display = 'none';
  html.appendChild(iframe);
  // https://github.com/zloirock/core-js/issues/475
  iframe.src = String(JS);
  iframeDocument = iframe.contentWindow.document;
  iframeDocument.open();
  iframeDocument.write(scriptTag('document.F=Object'));
  iframeDocument.close();
  return iframeDocument.F;
};

// Check for document.domain and active x support
// No need to use active x approach when document.domain is not set
// see https://github.com/es-shims/es5-shim/issues/150
// variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
// avoid IE GC bug
var activeXDocument;
var NullProtoObject = function () {
  try {
    /* global ActiveXObject -- old IE */
    activeXDocument = document.domain && new ActiveXObject('htmlfile');
  } catch (error) { /* ignore */ }
  NullProtoObject = activeXDocument ? NullProtoObjectViaActiveX(activeXDocument) : NullProtoObjectViaIFrame();
  var length = enumBugKeys.length;
  while (length--) delete NullProtoObject[PROTOTYPE][enumBugKeys[length]];
  return NullProtoObject();
};

hiddenKeys[IE_PROTO] = true;

// `Object.create` method
// https://tc39.es/ecma262/#sec-object.create
var objectCreate = Object.create || function create(O, Properties) {
  var result;
  if (O !== null) {
    EmptyConstructor[PROTOTYPE] = anObject(O);
    result = new EmptyConstructor();
    EmptyConstructor[PROTOTYPE] = null;
    // add "__proto__" for Object.getPrototypeOf polyfill
    result[IE_PROTO] = O;
  } else result = NullProtoObject();
  return Properties === undefined ? result : objectDefineProperties(result, Properties);
};

var UNSCOPABLES = wellKnownSymbol('unscopables');
var ArrayPrototype$1 = Array.prototype;

// Array.prototype[@@unscopables]
// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
if (ArrayPrototype$1[UNSCOPABLES] == undefined) {
  objectDefineProperty.f(ArrayPrototype$1, UNSCOPABLES, {
    configurable: true,
    value: objectCreate(null)
  });
}

// add a key to Array.prototype[@@unscopables]
var addToUnscopables = function (key) {
  ArrayPrototype$1[UNSCOPABLES][key] = true;
};

// `ToObject` abstract operation
// https://tc39.es/ecma262/#sec-toobject
var toObject = function (argument) {
  return Object(requireObjectCoercible(argument));
};

var correctPrototypeGetter = !fails(function () {
  function F() { /* empty */ }
  F.prototype.constructor = null;
  // eslint-disable-next-line es/no-object-getprototypeof -- required for testing
  return Object.getPrototypeOf(new F()) !== F.prototype;
});

var IE_PROTO$1 = sharedKey('IE_PROTO');
var ObjectPrototype = Object.prototype;

// `Object.getPrototypeOf` method
// https://tc39.es/ecma262/#sec-object.getprototypeof
// eslint-disable-next-line es/no-object-getprototypeof -- safe
var objectGetPrototypeOf = correctPrototypeGetter ? Object.getPrototypeOf : function (O) {
  O = toObject(O);
  if (has(O, IE_PROTO$1)) return O[IE_PROTO$1];
  if (typeof O.constructor == 'function' && O instanceof O.constructor) {
    return O.constructor.prototype;
  } return O instanceof Object ? ObjectPrototype : null;
};

var ITERATOR$3 = wellKnownSymbol('iterator');
var BUGGY_SAFARI_ITERATORS = false;

var returnThis = function () { return this; };

// `%IteratorPrototype%` object
// https://tc39.es/ecma262/#sec-%iteratorprototype%-object
var IteratorPrototype, PrototypeOfArrayIteratorPrototype, arrayIterator;

/* eslint-disable es/no-array-prototype-keys -- safe */
if ([].keys) {
  arrayIterator = [].keys();
  // Safari 8 has buggy iterators w/o `next`
  if (!('next' in arrayIterator)) BUGGY_SAFARI_ITERATORS = true;
  else {
    PrototypeOfArrayIteratorPrototype = objectGetPrototypeOf(objectGetPrototypeOf(arrayIterator));
    if (PrototypeOfArrayIteratorPrototype !== Object.prototype) IteratorPrototype = PrototypeOfArrayIteratorPrototype;
  }
}

var NEW_ITERATOR_PROTOTYPE = IteratorPrototype == undefined || fails(function () {
  var test = {};
  // FF44- legacy iterators case
  return IteratorPrototype[ITERATOR$3].call(test) !== test;
});

if (NEW_ITERATOR_PROTOTYPE) IteratorPrototype = {};

// 25.1.2.1.1 %IteratorPrototype%[@@iterator]()
if ( !has(IteratorPrototype, ITERATOR$3)) {
  createNonEnumerableProperty(IteratorPrototype, ITERATOR$3, returnThis);
}

var iteratorsCore = {
  IteratorPrototype: IteratorPrototype,
  BUGGY_SAFARI_ITERATORS: BUGGY_SAFARI_ITERATORS
};

var IteratorPrototype$1 = iteratorsCore.IteratorPrototype;





var returnThis$1 = function () { return this; };

var createIteratorConstructor = function (IteratorConstructor, NAME, next) {
  var TO_STRING_TAG = NAME + ' Iterator';
  IteratorConstructor.prototype = objectCreate(IteratorPrototype$1, { next: createPropertyDescriptor(1, next) });
  setToStringTag(IteratorConstructor, TO_STRING_TAG, false);
  iterators[TO_STRING_TAG] = returnThis$1;
  return IteratorConstructor;
};

var aPossiblePrototype = function (it) {
  if (!isObject(it) && it !== null) {
    throw TypeError("Can't set " + String(it) + ' as a prototype');
  } return it;
};

/* eslint-disable no-proto -- safe */



// `Object.setPrototypeOf` method
// https://tc39.es/ecma262/#sec-object.setprototypeof
// Works with __proto__ only. Old v8 can't work with null proto objects.
// eslint-disable-next-line es/no-object-setprototypeof -- safe
var objectSetPrototypeOf = Object.setPrototypeOf || ('__proto__' in {} ? function () {
  var CORRECT_SETTER = false;
  var test = {};
  var setter;
  try {
    // eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
    setter = Object.getOwnPropertyDescriptor(Object.prototype, '__proto__').set;
    setter.call(test, []);
    CORRECT_SETTER = test instanceof Array;
  } catch (error) { /* empty */ }
  return function setPrototypeOf(O, proto) {
    anObject(O);
    aPossiblePrototype(proto);
    if (CORRECT_SETTER) setter.call(O, proto);
    else O.__proto__ = proto;
    return O;
  };
}() : undefined);

var IteratorPrototype$2 = iteratorsCore.IteratorPrototype;
var BUGGY_SAFARI_ITERATORS$1 = iteratorsCore.BUGGY_SAFARI_ITERATORS;
var ITERATOR$4 = wellKnownSymbol('iterator');
var KEYS = 'keys';
var VALUES = 'values';
var ENTRIES = 'entries';

var returnThis$2 = function () { return this; };

var defineIterator = function (Iterable, NAME, IteratorConstructor, next, DEFAULT, IS_SET, FORCED) {
  createIteratorConstructor(IteratorConstructor, NAME, next);

  var getIterationMethod = function (KIND) {
    if (KIND === DEFAULT && defaultIterator) return defaultIterator;
    if (!BUGGY_SAFARI_ITERATORS$1 && KIND in IterablePrototype) return IterablePrototype[KIND];
    switch (KIND) {
      case KEYS: return function keys() { return new IteratorConstructor(this, KIND); };
      case VALUES: return function values() { return new IteratorConstructor(this, KIND); };
      case ENTRIES: return function entries() { return new IteratorConstructor(this, KIND); };
    } return function () { return new IteratorConstructor(this); };
  };

  var TO_STRING_TAG = NAME + ' Iterator';
  var INCORRECT_VALUES_NAME = false;
  var IterablePrototype = Iterable.prototype;
  var nativeIterator = IterablePrototype[ITERATOR$4]
    || IterablePrototype['@@iterator']
    || DEFAULT && IterablePrototype[DEFAULT];
  var defaultIterator = !BUGGY_SAFARI_ITERATORS$1 && nativeIterator || getIterationMethod(DEFAULT);
  var anyNativeIterator = NAME == 'Array' ? IterablePrototype.entries || nativeIterator : nativeIterator;
  var CurrentIteratorPrototype, methods, KEY;

  // fix native
  if (anyNativeIterator) {
    CurrentIteratorPrototype = objectGetPrototypeOf(anyNativeIterator.call(new Iterable()));
    if (IteratorPrototype$2 !== Object.prototype && CurrentIteratorPrototype.next) {
      if ( objectGetPrototypeOf(CurrentIteratorPrototype) !== IteratorPrototype$2) {
        if (objectSetPrototypeOf) {
          objectSetPrototypeOf(CurrentIteratorPrototype, IteratorPrototype$2);
        } else if (typeof CurrentIteratorPrototype[ITERATOR$4] != 'function') {
          createNonEnumerableProperty(CurrentIteratorPrototype, ITERATOR$4, returnThis$2);
        }
      }
      // Set @@toStringTag to native iterators
      setToStringTag(CurrentIteratorPrototype, TO_STRING_TAG, true);
    }
  }

  // fix Array#{values, @@iterator}.name in V8 / FF
  if (DEFAULT == VALUES && nativeIterator && nativeIterator.name !== VALUES) {
    INCORRECT_VALUES_NAME = true;
    defaultIterator = function values() { return nativeIterator.call(this); };
  }

  // define iterator
  if ( IterablePrototype[ITERATOR$4] !== defaultIterator) {
    createNonEnumerableProperty(IterablePrototype, ITERATOR$4, defaultIterator);
  }
  iterators[NAME] = defaultIterator;

  // export additional methods
  if (DEFAULT) {
    methods = {
      values: getIterationMethod(VALUES),
      keys: IS_SET ? defaultIterator : getIterationMethod(KEYS),
      entries: getIterationMethod(ENTRIES)
    };
    if (FORCED) for (KEY in methods) {
      if (BUGGY_SAFARI_ITERATORS$1 || INCORRECT_VALUES_NAME || !(KEY in IterablePrototype)) {
        redefine(IterablePrototype, KEY, methods[KEY]);
      }
    } else _export({ target: NAME, proto: true, forced: BUGGY_SAFARI_ITERATORS$1 || INCORRECT_VALUES_NAME }, methods);
  }

  return methods;
};

var ARRAY_ITERATOR = 'Array Iterator';
var setInternalState$1 = internalState.set;
var getInternalState$1 = internalState.getterFor(ARRAY_ITERATOR);

// `Array.prototype.entries` method
// https://tc39.es/ecma262/#sec-array.prototype.entries
// `Array.prototype.keys` method
// https://tc39.es/ecma262/#sec-array.prototype.keys
// `Array.prototype.values` method
// https://tc39.es/ecma262/#sec-array.prototype.values
// `Array.prototype[@@iterator]` method
// https://tc39.es/ecma262/#sec-array.prototype-@@iterator
// `CreateArrayIterator` internal method
// https://tc39.es/ecma262/#sec-createarrayiterator
var es_array_iterator = defineIterator(Array, 'Array', function (iterated, kind) {
  setInternalState$1(this, {
    type: ARRAY_ITERATOR,
    target: toIndexedObject(iterated), // target
    index: 0,                          // next index
    kind: kind                         // kind
  });
// `%ArrayIteratorPrototype%.next` method
// https://tc39.es/ecma262/#sec-%arrayiteratorprototype%.next
}, function () {
  var state = getInternalState$1(this);
  var target = state.target;
  var kind = state.kind;
  var index = state.index++;
  if (!target || index >= target.length) {
    state.target = undefined;
    return { value: undefined, done: true };
  }
  if (kind == 'keys') return { value: index, done: false };
  if (kind == 'values') return { value: target[index], done: false };
  return { value: [index, target[index]], done: false };
}, 'values');

// argumentsList[@@iterator] is %ArrayProto_values%
// https://tc39.es/ecma262/#sec-createunmappedargumentsobject
// https://tc39.es/ecma262/#sec-createmappedargumentsobject
iterators.Arguments = iterators.Array;

// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
addToUnscopables('keys');
addToUnscopables('values');
addToUnscopables('entries');

// `String.prototype.{ codePointAt, at }` methods implementation
var createMethod$1 = function (CONVERT_TO_STRING) {
  return function ($this, pos) {
    var S = String(requireObjectCoercible($this));
    var position = toInteger(pos);
    var size = S.length;
    var first, second;
    if (position < 0 || position >= size) return CONVERT_TO_STRING ? '' : undefined;
    first = S.charCodeAt(position);
    return first < 0xD800 || first > 0xDBFF || position + 1 === size
      || (second = S.charCodeAt(position + 1)) < 0xDC00 || second > 0xDFFF
        ? CONVERT_TO_STRING ? S.charAt(position) : first
        : CONVERT_TO_STRING ? S.slice(position, position + 2) : (first - 0xD800 << 10) + (second - 0xDC00) + 0x10000;
  };
};

var stringMultibyte = {
  // `String.prototype.codePointAt` method
  // https://tc39.es/ecma262/#sec-string.prototype.codepointat
  codeAt: createMethod$1(false),
  // `String.prototype.at` method
  // https://github.com/mathiasbynens/String.prototype.at
  charAt: createMethod$1(true)
};

var charAt = stringMultibyte.charAt;



var STRING_ITERATOR = 'String Iterator';
var setInternalState$2 = internalState.set;
var getInternalState$2 = internalState.getterFor(STRING_ITERATOR);

// `String.prototype[@@iterator]` method
// https://tc39.es/ecma262/#sec-string.prototype-@@iterator
defineIterator(String, 'String', function (iterated) {
  setInternalState$2(this, {
    type: STRING_ITERATOR,
    string: String(iterated),
    index: 0
  });
// `%StringIteratorPrototype%.next` method
// https://tc39.es/ecma262/#sec-%stringiteratorprototype%.next
}, function next() {
  var state = getInternalState$2(this);
  var string = state.string;
  var index = state.index;
  var point;
  if (index >= string.length) return { value: undefined, done: true };
  point = charAt(string, index);
  state.index += point.length;
  return { value: point, done: false };
});

// iterable DOM collections
// flag - `iterable` interface - 'entries', 'keys', 'values', 'forEach' methods
var domIterables = {
  CSSRuleList: 0,
  CSSStyleDeclaration: 0,
  CSSValueList: 0,
  ClientRectList: 0,
  DOMRectList: 0,
  DOMStringList: 0,
  DOMTokenList: 1,
  DataTransferItemList: 0,
  FileList: 0,
  HTMLAllCollection: 0,
  HTMLCollection: 0,
  HTMLFormElement: 0,
  HTMLSelectElement: 0,
  MediaList: 0,
  MimeTypeArray: 0,
  NamedNodeMap: 0,
  NodeList: 1,
  PaintRequestList: 0,
  Plugin: 0,
  PluginArray: 0,
  SVGLengthList: 0,
  SVGNumberList: 0,
  SVGPathSegList: 0,
  SVGPointList: 0,
  SVGStringList: 0,
  SVGTransformList: 0,
  SourceBufferList: 0,
  StyleSheetList: 0,
  TextTrackCueList: 0,
  TextTrackList: 0,
  TouchList: 0
};

var ITERATOR$5 = wellKnownSymbol('iterator');
var TO_STRING_TAG$3 = wellKnownSymbol('toStringTag');
var ArrayValues = es_array_iterator.values;

for (var COLLECTION_NAME in domIterables) {
  var Collection = global_1[COLLECTION_NAME];
  var CollectionPrototype = Collection && Collection.prototype;
  if (CollectionPrototype) {
    // some Chrome versions have non-configurable methods on DOMTokenList
    if (CollectionPrototype[ITERATOR$5] !== ArrayValues) try {
      createNonEnumerableProperty(CollectionPrototype, ITERATOR$5, ArrayValues);
    } catch (error) {
      CollectionPrototype[ITERATOR$5] = ArrayValues;
    }
    if (!CollectionPrototype[TO_STRING_TAG$3]) {
      createNonEnumerableProperty(CollectionPrototype, TO_STRING_TAG$3, COLLECTION_NAME);
    }
    if (domIterables[COLLECTION_NAME]) for (var METHOD_NAME in es_array_iterator) {
      // some Chrome versions have non-configurable methods on DOMTokenList
      if (CollectionPrototype[METHOD_NAME] !== es_array_iterator[METHOD_NAME]) try {
        createNonEnumerableProperty(CollectionPrototype, METHOD_NAME, es_array_iterator[METHOD_NAME]);
      } catch (error) {
        CollectionPrototype[METHOD_NAME] = es_array_iterator[METHOD_NAME];
      }
    }
  }
}

// `IsArray` abstract operation
// https://tc39.es/ecma262/#sec-isarray
// eslint-disable-next-line es/no-array-isarray -- safe
var isArray = Array.isArray || function isArray(arg) {
  return classofRaw(arg) == 'Array';
};

/* eslint-disable es/no-object-getownpropertynames -- safe */

var $getOwnPropertyNames = objectGetOwnPropertyNames.f;

var toString$2 = {}.toString;

var windowNames = typeof window == 'object' && window && Object.getOwnPropertyNames
  ? Object.getOwnPropertyNames(window) : [];

var getWindowNames = function (it) {
  try {
    return $getOwnPropertyNames(it);
  } catch (error) {
    return windowNames.slice();
  }
};

// fallback for IE11 buggy Object.getOwnPropertyNames with iframe and window
var f$6 = function getOwnPropertyNames(it) {
  return windowNames && toString$2.call(it) == '[object Window]'
    ? getWindowNames(it)
    : $getOwnPropertyNames(toIndexedObject(it));
};

var objectGetOwnPropertyNamesExternal = {
	f: f$6
};

var f$7 = wellKnownSymbol;

var wellKnownSymbolWrapped = {
	f: f$7
};

var defineProperty$2 = objectDefineProperty.f;

var defineWellKnownSymbol = function (NAME) {
  var Symbol = path.Symbol || (path.Symbol = {});
  if (!has(Symbol, NAME)) defineProperty$2(Symbol, NAME, {
    value: wellKnownSymbolWrapped.f(NAME)
  });
};

var SPECIES$3 = wellKnownSymbol('species');

// `ArraySpeciesCreate` abstract operation
// https://tc39.es/ecma262/#sec-arrayspeciescreate
var arraySpeciesCreate = function (originalArray, length) {
  var C;
  if (isArray(originalArray)) {
    C = originalArray.constructor;
    // cross-realm fallback
    if (typeof C == 'function' && (C === Array || isArray(C.prototype))) C = undefined;
    else if (isObject(C)) {
      C = C[SPECIES$3];
      if (C === null) C = undefined;
    }
  } return new (C === undefined ? Array : C)(length === 0 ? 0 : length);
};

var push = [].push;

// `Array.prototype.{ forEach, map, filter, some, every, find, findIndex, filterOut }` methods implementation
var createMethod$2 = function (TYPE) {
  var IS_MAP = TYPE == 1;
  var IS_FILTER = TYPE == 2;
  var IS_SOME = TYPE == 3;
  var IS_EVERY = TYPE == 4;
  var IS_FIND_INDEX = TYPE == 6;
  var IS_FILTER_OUT = TYPE == 7;
  var NO_HOLES = TYPE == 5 || IS_FIND_INDEX;
  return function ($this, callbackfn, that, specificCreate) {
    var O = toObject($this);
    var self = indexedObject(O);
    var boundFunction = functionBindContext(callbackfn, that, 3);
    var length = toLength(self.length);
    var index = 0;
    var create = specificCreate || arraySpeciesCreate;
    var target = IS_MAP ? create($this, length) : IS_FILTER || IS_FILTER_OUT ? create($this, 0) : undefined;
    var value, result;
    for (;length > index; index++) if (NO_HOLES || index in self) {
      value = self[index];
      result = boundFunction(value, index, O);
      if (TYPE) {
        if (IS_MAP) target[index] = result; // map
        else if (result) switch (TYPE) {
          case 3: return true;              // some
          case 5: return value;             // find
          case 6: return index;             // findIndex
          case 2: push.call(target, value); // filter
        } else switch (TYPE) {
          case 4: return false;             // every
          case 7: push.call(target, value); // filterOut
        }
      }
    }
    return IS_FIND_INDEX ? -1 : IS_SOME || IS_EVERY ? IS_EVERY : target;
  };
};

var arrayIteration = {
  // `Array.prototype.forEach` method
  // https://tc39.es/ecma262/#sec-array.prototype.foreach
  forEach: createMethod$2(0),
  // `Array.prototype.map` method
  // https://tc39.es/ecma262/#sec-array.prototype.map
  map: createMethod$2(1),
  // `Array.prototype.filter` method
  // https://tc39.es/ecma262/#sec-array.prototype.filter
  filter: createMethod$2(2),
  // `Array.prototype.some` method
  // https://tc39.es/ecma262/#sec-array.prototype.some
  some: createMethod$2(3),
  // `Array.prototype.every` method
  // https://tc39.es/ecma262/#sec-array.prototype.every
  every: createMethod$2(4),
  // `Array.prototype.find` method
  // https://tc39.es/ecma262/#sec-array.prototype.find
  find: createMethod$2(5),
  // `Array.prototype.findIndex` method
  // https://tc39.es/ecma262/#sec-array.prototype.findIndex
  findIndex: createMethod$2(6),
  // `Array.prototype.filterOut` method
  // https://github.com/tc39/proposal-array-filtering
  filterOut: createMethod$2(7)
};

var $forEach = arrayIteration.forEach;

var HIDDEN = sharedKey('hidden');
var SYMBOL = 'Symbol';
var PROTOTYPE$1 = 'prototype';
var TO_PRIMITIVE = wellKnownSymbol('toPrimitive');
var setInternalState$3 = internalState.set;
var getInternalState$3 = internalState.getterFor(SYMBOL);
var ObjectPrototype$1 = Object[PROTOTYPE$1];
var $Symbol = global_1.Symbol;
var $stringify = getBuiltIn('JSON', 'stringify');
var nativeGetOwnPropertyDescriptor = objectGetOwnPropertyDescriptor.f;
var nativeDefineProperty = objectDefineProperty.f;
var nativeGetOwnPropertyNames = objectGetOwnPropertyNamesExternal.f;
var nativePropertyIsEnumerable = objectPropertyIsEnumerable.f;
var AllSymbols = shared('symbols');
var ObjectPrototypeSymbols = shared('op-symbols');
var StringToSymbolRegistry = shared('string-to-symbol-registry');
var SymbolToStringRegistry = shared('symbol-to-string-registry');
var WellKnownSymbolsStore$1 = shared('wks');
var QObject = global_1.QObject;
// Don't use setters in Qt Script, https://github.com/zloirock/core-js/issues/173
var USE_SETTER = !QObject || !QObject[PROTOTYPE$1] || !QObject[PROTOTYPE$1].findChild;

// fallback for old Android, https://code.google.com/p/v8/issues/detail?id=687
var setSymbolDescriptor = descriptors && fails(function () {
  return objectCreate(nativeDefineProperty({}, 'a', {
    get: function () { return nativeDefineProperty(this, 'a', { value: 7 }).a; }
  })).a != 7;
}) ? function (O, P, Attributes) {
  var ObjectPrototypeDescriptor = nativeGetOwnPropertyDescriptor(ObjectPrototype$1, P);
  if (ObjectPrototypeDescriptor) delete ObjectPrototype$1[P];
  nativeDefineProperty(O, P, Attributes);
  if (ObjectPrototypeDescriptor && O !== ObjectPrototype$1) {
    nativeDefineProperty(ObjectPrototype$1, P, ObjectPrototypeDescriptor);
  }
} : nativeDefineProperty;

var wrap = function (tag, description) {
  var symbol = AllSymbols[tag] = objectCreate($Symbol[PROTOTYPE$1]);
  setInternalState$3(symbol, {
    type: SYMBOL,
    tag: tag,
    description: description
  });
  if (!descriptors) symbol.description = description;
  return symbol;
};

var isSymbol = useSymbolAsUid ? function (it) {
  return typeof it == 'symbol';
} : function (it) {
  return Object(it) instanceof $Symbol;
};

var $defineProperty$1 = function defineProperty(O, P, Attributes) {
  if (O === ObjectPrototype$1) $defineProperty$1(ObjectPrototypeSymbols, P, Attributes);
  anObject(O);
  var key = toPrimitive(P, true);
  anObject(Attributes);
  if (has(AllSymbols, key)) {
    if (!Attributes.enumerable) {
      if (!has(O, HIDDEN)) nativeDefineProperty(O, HIDDEN, createPropertyDescriptor(1, {}));
      O[HIDDEN][key] = true;
    } else {
      if (has(O, HIDDEN) && O[HIDDEN][key]) O[HIDDEN][key] = false;
      Attributes = objectCreate(Attributes, { enumerable: createPropertyDescriptor(0, false) });
    } return setSymbolDescriptor(O, key, Attributes);
  } return nativeDefineProperty(O, key, Attributes);
};

var $defineProperties = function defineProperties(O, Properties) {
  anObject(O);
  var properties = toIndexedObject(Properties);
  var keys = objectKeys(properties).concat($getOwnPropertySymbols(properties));
  $forEach(keys, function (key) {
    if (!descriptors || $propertyIsEnumerable$1.call(properties, key)) $defineProperty$1(O, key, properties[key]);
  });
  return O;
};

var $create = function create(O, Properties) {
  return Properties === undefined ? objectCreate(O) : $defineProperties(objectCreate(O), Properties);
};

var $propertyIsEnumerable$1 = function propertyIsEnumerable(V) {
  var P = toPrimitive(V, true);
  var enumerable = nativePropertyIsEnumerable.call(this, P);
  if (this === ObjectPrototype$1 && has(AllSymbols, P) && !has(ObjectPrototypeSymbols, P)) return false;
  return enumerable || !has(this, P) || !has(AllSymbols, P) || has(this, HIDDEN) && this[HIDDEN][P] ? enumerable : true;
};

var $getOwnPropertyDescriptor$1 = function getOwnPropertyDescriptor(O, P) {
  var it = toIndexedObject(O);
  var key = toPrimitive(P, true);
  if (it === ObjectPrototype$1 && has(AllSymbols, key) && !has(ObjectPrototypeSymbols, key)) return;
  var descriptor = nativeGetOwnPropertyDescriptor(it, key);
  if (descriptor && has(AllSymbols, key) && !(has(it, HIDDEN) && it[HIDDEN][key])) {
    descriptor.enumerable = true;
  }
  return descriptor;
};

var $getOwnPropertyNames$1 = function getOwnPropertyNames(O) {
  var names = nativeGetOwnPropertyNames(toIndexedObject(O));
  var result = [];
  $forEach(names, function (key) {
    if (!has(AllSymbols, key) && !has(hiddenKeys, key)) result.push(key);
  });
  return result;
};

var $getOwnPropertySymbols = function getOwnPropertySymbols(O) {
  var IS_OBJECT_PROTOTYPE = O === ObjectPrototype$1;
  var names = nativeGetOwnPropertyNames(IS_OBJECT_PROTOTYPE ? ObjectPrototypeSymbols : toIndexedObject(O));
  var result = [];
  $forEach(names, function (key) {
    if (has(AllSymbols, key) && (!IS_OBJECT_PROTOTYPE || has(ObjectPrototype$1, key))) {
      result.push(AllSymbols[key]);
    }
  });
  return result;
};

// `Symbol` constructor
// https://tc39.es/ecma262/#sec-symbol-constructor
if (!nativeSymbol) {
  $Symbol = function Symbol() {
    if (this instanceof $Symbol) throw TypeError('Symbol is not a constructor');
    var description = !arguments.length || arguments[0] === undefined ? undefined : String(arguments[0]);
    var tag = uid(description);
    var setter = function (value) {
      if (this === ObjectPrototype$1) setter.call(ObjectPrototypeSymbols, value);
      if (has(this, HIDDEN) && has(this[HIDDEN], tag)) this[HIDDEN][tag] = false;
      setSymbolDescriptor(this, tag, createPropertyDescriptor(1, value));
    };
    if (descriptors && USE_SETTER) setSymbolDescriptor(ObjectPrototype$1, tag, { configurable: true, set: setter });
    return wrap(tag, description);
  };

  redefine($Symbol[PROTOTYPE$1], 'toString', function toString() {
    return getInternalState$3(this).tag;
  });

  redefine($Symbol, 'withoutSetter', function (description) {
    return wrap(uid(description), description);
  });

  objectPropertyIsEnumerable.f = $propertyIsEnumerable$1;
  objectDefineProperty.f = $defineProperty$1;
  objectGetOwnPropertyDescriptor.f = $getOwnPropertyDescriptor$1;
  objectGetOwnPropertyNames.f = objectGetOwnPropertyNamesExternal.f = $getOwnPropertyNames$1;
  objectGetOwnPropertySymbols.f = $getOwnPropertySymbols;

  wellKnownSymbolWrapped.f = function (name) {
    return wrap(wellKnownSymbol(name), name);
  };

  if (descriptors) {
    // https://github.com/tc39/proposal-Symbol-description
    nativeDefineProperty($Symbol[PROTOTYPE$1], 'description', {
      configurable: true,
      get: function description() {
        return getInternalState$3(this).description;
      }
    });
    {
      redefine(ObjectPrototype$1, 'propertyIsEnumerable', $propertyIsEnumerable$1, { unsafe: true });
    }
  }
}

_export({ global: true, wrap: true, forced: !nativeSymbol, sham: !nativeSymbol }, {
  Symbol: $Symbol
});

$forEach(objectKeys(WellKnownSymbolsStore$1), function (name) {
  defineWellKnownSymbol(name);
});

_export({ target: SYMBOL, stat: true, forced: !nativeSymbol }, {
  // `Symbol.for` method
  // https://tc39.es/ecma262/#sec-symbol.for
  'for': function (key) {
    var string = String(key);
    if (has(StringToSymbolRegistry, string)) return StringToSymbolRegistry[string];
    var symbol = $Symbol(string);
    StringToSymbolRegistry[string] = symbol;
    SymbolToStringRegistry[symbol] = string;
    return symbol;
  },
  // `Symbol.keyFor` method
  // https://tc39.es/ecma262/#sec-symbol.keyfor
  keyFor: function keyFor(sym) {
    if (!isSymbol(sym)) throw TypeError(sym + ' is not a symbol');
    if (has(SymbolToStringRegistry, sym)) return SymbolToStringRegistry[sym];
  },
  useSetter: function () { USE_SETTER = true; },
  useSimple: function () { USE_SETTER = false; }
});

_export({ target: 'Object', stat: true, forced: !nativeSymbol, sham: !descriptors }, {
  // `Object.create` method
  // https://tc39.es/ecma262/#sec-object.create
  create: $create,
  // `Object.defineProperty` method
  // https://tc39.es/ecma262/#sec-object.defineproperty
  defineProperty: $defineProperty$1,
  // `Object.defineProperties` method
  // https://tc39.es/ecma262/#sec-object.defineproperties
  defineProperties: $defineProperties,
  // `Object.getOwnPropertyDescriptor` method
  // https://tc39.es/ecma262/#sec-object.getownpropertydescriptors
  getOwnPropertyDescriptor: $getOwnPropertyDescriptor$1
});

_export({ target: 'Object', stat: true, forced: !nativeSymbol }, {
  // `Object.getOwnPropertyNames` method
  // https://tc39.es/ecma262/#sec-object.getownpropertynames
  getOwnPropertyNames: $getOwnPropertyNames$1,
  // `Object.getOwnPropertySymbols` method
  // https://tc39.es/ecma262/#sec-object.getownpropertysymbols
  getOwnPropertySymbols: $getOwnPropertySymbols
});

// Chrome 38 and 39 `Object.getOwnPropertySymbols` fails on primitives
// https://bugs.chromium.org/p/v8/issues/detail?id=3443
_export({ target: 'Object', stat: true, forced: fails(function () { objectGetOwnPropertySymbols.f(1); }) }, {
  getOwnPropertySymbols: function getOwnPropertySymbols(it) {
    return objectGetOwnPropertySymbols.f(toObject(it));
  }
});

// `JSON.stringify` method behavior with symbols
// https://tc39.es/ecma262/#sec-json.stringify
if ($stringify) {
  var FORCED_JSON_STRINGIFY = !nativeSymbol || fails(function () {
    var symbol = $Symbol();
    // MS Edge converts symbol values to JSON as {}
    return $stringify([symbol]) != '[null]'
      // WebKit converts symbol values to JSON as null
      || $stringify({ a: symbol }) != '{}'
      // V8 throws on boxed symbols
      || $stringify(Object(symbol)) != '{}';
  });

  _export({ target: 'JSON', stat: true, forced: FORCED_JSON_STRINGIFY }, {
    // eslint-disable-next-line no-unused-vars -- required for `.length`
    stringify: function stringify(it, replacer, space) {
      var args = [it];
      var index = 1;
      var $replacer;
      while (arguments.length > index) args.push(arguments[index++]);
      $replacer = replacer;
      if (!isObject(replacer) && it === undefined || isSymbol(it)) return; // IE8 returns string on undefined
      if (!isArray(replacer)) replacer = function (key, value) {
        if (typeof $replacer == 'function') value = $replacer.call(this, key, value);
        if (!isSymbol(value)) return value;
      };
      args[1] = replacer;
      return $stringify.apply(null, args);
    }
  });
}

// `Symbol.prototype[@@toPrimitive]` method
// https://tc39.es/ecma262/#sec-symbol.prototype-@@toprimitive
if (!$Symbol[PROTOTYPE$1][TO_PRIMITIVE]) {
  createNonEnumerableProperty($Symbol[PROTOTYPE$1], TO_PRIMITIVE, $Symbol[PROTOTYPE$1].valueOf);
}
// `Symbol.prototype[@@toStringTag]` property
// https://tc39.es/ecma262/#sec-symbol.prototype-@@tostringtag
setToStringTag($Symbol, SYMBOL);

hiddenKeys[HIDDEN] = true;

var defineProperty$3 = objectDefineProperty.f;


var NativeSymbol = global_1.Symbol;

if (descriptors && typeof NativeSymbol == 'function' && (!('description' in NativeSymbol.prototype) ||
  // Safari 12 bug
  NativeSymbol().description !== undefined
)) {
  var EmptyStringDescriptionStore = {};
  // wrap Symbol constructor for correct work with undefined description
  var SymbolWrapper = function Symbol() {
    var description = arguments.length < 1 || arguments[0] === undefined ? undefined : String(arguments[0]);
    var result = this instanceof SymbolWrapper
      ? new NativeSymbol(description)
      // in Edge 13, String(Symbol(undefined)) === 'Symbol(undefined)'
      : description === undefined ? NativeSymbol() : NativeSymbol(description);
    if (description === '') EmptyStringDescriptionStore[result] = true;
    return result;
  };
  copyConstructorProperties(SymbolWrapper, NativeSymbol);
  var symbolPrototype = SymbolWrapper.prototype = NativeSymbol.prototype;
  symbolPrototype.constructor = SymbolWrapper;

  var symbolToString = symbolPrototype.toString;
  var native = String(NativeSymbol('test')) == 'Symbol(test)';
  var regexp = /^Symbol\((.*)\)[^)]+$/;
  defineProperty$3(symbolPrototype, 'description', {
    configurable: true,
    get: function description() {
      var symbol = isObject(this) ? this.valueOf() : this;
      var string = symbolToString.call(symbol);
      if (has(EmptyStringDescriptionStore, symbol)) return '';
      var desc = native ? string.slice(7, -1) : string.replace(regexp, '$1');
      return desc === '' ? undefined : desc;
    }
  });

  _export({ global: true, forced: true }, {
    Symbol: SymbolWrapper
  });
}

// `Symbol.toStringTag` well-known symbol
// https://tc39.es/ecma262/#sec-symbol.tostringtag
defineWellKnownSymbol('toStringTag');

// JSON[@@toStringTag] property
// https://tc39.es/ecma262/#sec-json-@@tostringtag
setToStringTag(global_1.JSON, 'JSON', true);

// Math[@@toStringTag] property
// https://tc39.es/ecma262/#sec-math-@@tostringtag
setToStringTag(Math, 'Math', true);

var createProperty = function (object, key, value) {
  var propertyKey = toPrimitive(key);
  if (propertyKey in object) objectDefineProperty.f(object, propertyKey, createPropertyDescriptor(0, value));
  else object[propertyKey] = value;
};

var SPECIES$4 = wellKnownSymbol('species');

var arrayMethodHasSpeciesSupport = function (METHOD_NAME) {
  // We can't use this feature detection in V8 since it causes
  // deoptimization and serious performance degradation
  // https://github.com/zloirock/core-js/issues/677
  return engineV8Version >= 51 || !fails(function () {
    var array = [];
    var constructor = array.constructor = {};
    constructor[SPECIES$4] = function () {
      return { foo: 1 };
    };
    return array[METHOD_NAME](Boolean).foo !== 1;
  });
};

var HAS_SPECIES_SUPPORT = arrayMethodHasSpeciesSupport('slice');

var SPECIES$5 = wellKnownSymbol('species');
var nativeSlice = [].slice;
var max$1 = Math.max;

// `Array.prototype.slice` method
// https://tc39.es/ecma262/#sec-array.prototype.slice
// fallback for not array-like ES3 strings and DOM objects
_export({ target: 'Array', proto: true, forced: !HAS_SPECIES_SUPPORT }, {
  slice: function slice(start, end) {
    var O = toIndexedObject(this);
    var length = toLength(O.length);
    var k = toAbsoluteIndex(start, length);
    var fin = toAbsoluteIndex(end === undefined ? length : end, length);
    // inline `ArraySpeciesCreate` for usage native `Array#slice` where it's possible
    var Constructor, result, n;
    if (isArray(O)) {
      Constructor = O.constructor;
      // cross-realm fallback
      if (typeof Constructor == 'function' && (Constructor === Array || isArray(Constructor.prototype))) {
        Constructor = undefined;
      } else if (isObject(Constructor)) {
        Constructor = Constructor[SPECIES$5];
        if (Constructor === null) Constructor = undefined;
      }
      if (Constructor === Array || Constructor === undefined) {
        return nativeSlice.call(O, k, fin);
      }
    }
    result = new (Constructor === undefined ? Array : Constructor)(max$1(fin - k, 0));
    for (n = 0; k < fin; k++, n++) if (k in O) createProperty(result, n, O[k]);
    result.length = n;
    return result;
  }
});

// `Symbol.iterator` well-known symbol
// https://tc39.es/ecma262/#sec-symbol.iterator
defineWellKnownSymbol('iterator');

// `Symbol.asyncIterator` well-known symbol
// https://tc39.es/ecma262/#sec-symbol.asynciterator
defineWellKnownSymbol('asyncIterator');

var FAILS_ON_PRIMITIVES = fails(function () { objectGetPrototypeOf(1); });

// `Object.getPrototypeOf` method
// https://tc39.es/ecma262/#sec-object.getprototypeof
_export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES, sham: !correctPrototypeGetter }, {
  getPrototypeOf: function getPrototypeOf(it) {
    return objectGetPrototypeOf(toObject(it));
  }
});

// `Object.setPrototypeOf` method
// https://tc39.es/ecma262/#sec-object.setprototypeof
_export({ target: 'Object', stat: true }, {
  setPrototypeOf: objectSetPrototypeOf
});

// `RegExp.prototype.flags` getter implementation
// https://tc39.es/ecma262/#sec-get-regexp.prototype.flags
var regexpFlags = function () {
  var that = anObject(this);
  var result = '';
  if (that.global) result += 'g';
  if (that.ignoreCase) result += 'i';
  if (that.multiline) result += 'm';
  if (that.dotAll) result += 's';
  if (that.unicode) result += 'u';
  if (that.sticky) result += 'y';
  return result;
};

var TO_STRING = 'toString';
var RegExpPrototype = RegExp.prototype;
var nativeToString = RegExpPrototype[TO_STRING];

var NOT_GENERIC = fails(function () { return nativeToString.call({ source: 'a', flags: 'b' }) != '/a/b'; });
// FF44- RegExp#toString has a wrong name
var INCORRECT_NAME = nativeToString.name != TO_STRING;

// `RegExp.prototype.toString` method
// https://tc39.es/ecma262/#sec-regexp.prototype.tostring
if (NOT_GENERIC || INCORRECT_NAME) {
  redefine(RegExp.prototype, TO_STRING, function toString() {
    var R = anObject(this);
    var p = String(R.source);
    var rf = R.flags;
    var f = String(rf === undefined && R instanceof RegExp && !('flags' in RegExpPrototype) ? regexpFlags.call(R) : rf);
    return '/' + p + '/' + f;
  }, { unsafe: true });
}

var arrayMethodIsStrict = function (METHOD_NAME, argument) {
  var method = [][METHOD_NAME];
  return !!method && fails(function () {
    // eslint-disable-next-line no-useless-call,no-throw-literal -- required for testing
    method.call(null, argument || function () { throw 1; }, 1);
  });
};

var $forEach$1 = arrayIteration.forEach;


var STRICT_METHOD = arrayMethodIsStrict('forEach');

// `Array.prototype.forEach` method implementation
// https://tc39.es/ecma262/#sec-array.prototype.foreach
var arrayForEach = !STRICT_METHOD ? function forEach(callbackfn /* , thisArg */) {
  return $forEach$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
// eslint-disable-next-line es/no-array-prototype-foreach -- safe
} : [].forEach;

for (var COLLECTION_NAME$1 in domIterables) {
  var Collection$1 = global_1[COLLECTION_NAME$1];
  var CollectionPrototype$1 = Collection$1 && Collection$1.prototype;
  // some Chrome versions have non-configurable methods on DOMTokenList
  if (CollectionPrototype$1 && CollectionPrototype$1.forEach !== arrayForEach) try {
    createNonEnumerableProperty(CollectionPrototype$1, 'forEach', arrayForEach);
  } catch (error) {
    CollectionPrototype$1.forEach = arrayForEach;
  }
}

var FAILS_ON_PRIMITIVES$1 = fails(function () { objectKeys(1); });

// `Object.keys` method
// https://tc39.es/ecma262/#sec-object.keys
_export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES$1 }, {
  keys: function keys(it) {
    return objectKeys(toObject(it));
  }
});

var $filter = arrayIteration.filter;


var HAS_SPECIES_SUPPORT$1 = arrayMethodHasSpeciesSupport('filter');

// `Array.prototype.filter` method
// https://tc39.es/ecma262/#sec-array.prototype.filter
// with adding support of @@species
_export({ target: 'Array', proto: true, forced: !HAS_SPECIES_SUPPORT$1 }, {
  filter: function filter(callbackfn /* , thisArg */) {
    return $filter(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
  }
});

var nativeGetOwnPropertyDescriptor$1 = objectGetOwnPropertyDescriptor.f;


var FAILS_ON_PRIMITIVES$2 = fails(function () { nativeGetOwnPropertyDescriptor$1(1); });
var FORCED$1 = !descriptors || FAILS_ON_PRIMITIVES$2;

// `Object.getOwnPropertyDescriptor` method
// https://tc39.es/ecma262/#sec-object.getownpropertydescriptor
_export({ target: 'Object', stat: true, forced: FORCED$1, sham: !descriptors }, {
  getOwnPropertyDescriptor: function getOwnPropertyDescriptor(it, key) {
    return nativeGetOwnPropertyDescriptor$1(toIndexedObject(it), key);
  }
});

// `Object.getOwnPropertyDescriptors` method
// https://tc39.es/ecma262/#sec-object.getownpropertydescriptors
_export({ target: 'Object', stat: true, sham: !descriptors }, {
  getOwnPropertyDescriptors: function getOwnPropertyDescriptors(object) {
    var O = toIndexedObject(object);
    var getOwnPropertyDescriptor = objectGetOwnPropertyDescriptor.f;
    var keys = ownKeys(O);
    var result = {};
    var index = 0;
    var key, descriptor;
    while (keys.length > index) {
      descriptor = getOwnPropertyDescriptor(O, key = keys[index++]);
      if (descriptor !== undefined) createProperty(result, key, descriptor);
    }
    return result;
  }
});

// babel-minify transpiles RegExp('a', 'y') -> /a/y and it causes SyntaxError,
// so we use an intermediate function.
function RE(s, f) {
  return RegExp(s, f);
}

var UNSUPPORTED_Y = fails(function () {
  // babel-minify transpiles RegExp('a', 'y') -> /a/y and it causes SyntaxError
  var re = RE('a', 'y');
  re.lastIndex = 2;
  return re.exec('abcd') != null;
});

var BROKEN_CARET = fails(function () {
  // https://bugzilla.mozilla.org/show_bug.cgi?id=773687
  var re = RE('^r', 'gy');
  re.lastIndex = 2;
  return re.exec('str') != null;
});

var regexpStickyHelpers = {
	UNSUPPORTED_Y: UNSUPPORTED_Y,
	BROKEN_CARET: BROKEN_CARET
};

var nativeExec = RegExp.prototype.exec;
var nativeReplace = shared('native-string-replace', String.prototype.replace);

var patchedExec = nativeExec;

var UPDATES_LAST_INDEX_WRONG = (function () {
  var re1 = /a/;
  var re2 = /b*/g;
  nativeExec.call(re1, 'a');
  nativeExec.call(re2, 'a');
  return re1.lastIndex !== 0 || re2.lastIndex !== 0;
})();

var UNSUPPORTED_Y$1 = regexpStickyHelpers.UNSUPPORTED_Y || regexpStickyHelpers.BROKEN_CARET;

// nonparticipating capturing group, copied from es5-shim's String#split patch.
// eslint-disable-next-line regexp/no-assertion-capturing-group, regexp/no-empty-group, regexp/no-lazy-ends -- testing
var NPCG_INCLUDED = /()??/.exec('')[1] !== undefined;

var PATCH = UPDATES_LAST_INDEX_WRONG || NPCG_INCLUDED || UNSUPPORTED_Y$1;

if (PATCH) {
  patchedExec = function exec(str) {
    var re = this;
    var lastIndex, reCopy, match, i;
    var sticky = UNSUPPORTED_Y$1 && re.sticky;
    var flags = regexpFlags.call(re);
    var source = re.source;
    var charsAdded = 0;
    var strCopy = str;

    if (sticky) {
      flags = flags.replace('y', '');
      if (flags.indexOf('g') === -1) {
        flags += 'g';
      }

      strCopy = String(str).slice(re.lastIndex);
      // Support anchored sticky behavior.
      if (re.lastIndex > 0 && (!re.multiline || re.multiline && str[re.lastIndex - 1] !== '\n')) {
        source = '(?: ' + source + ')';
        strCopy = ' ' + strCopy;
        charsAdded++;
      }
      // ^(? + rx + ) is needed, in combination with some str slicing, to
      // simulate the 'y' flag.
      reCopy = new RegExp('^(?:' + source + ')', flags);
    }

    if (NPCG_INCLUDED) {
      reCopy = new RegExp('^' + source + '$(?!\\s)', flags);
    }
    if (UPDATES_LAST_INDEX_WRONG) lastIndex = re.lastIndex;

    match = nativeExec.call(sticky ? reCopy : re, strCopy);

    if (sticky) {
      if (match) {
        match.input = match.input.slice(charsAdded);
        match[0] = match[0].slice(charsAdded);
        match.index = re.lastIndex;
        re.lastIndex += match[0].length;
      } else re.lastIndex = 0;
    } else if (UPDATES_LAST_INDEX_WRONG && match) {
      re.lastIndex = re.global ? match.index + match[0].length : lastIndex;
    }
    if (NPCG_INCLUDED && match && match.length > 1) {
      // Fix browsers whose `exec` methods don't consistently return `undefined`
      // for NPCG, like IE8. NOTE: This doesn' work for /(.?)?/
      nativeReplace.call(match[0], reCopy, function () {
        for (i = 1; i < arguments.length - 2; i++) {
          if (arguments[i] === undefined) match[i] = undefined;
        }
      });
    }

    return match;
  };
}

var regexpExec = patchedExec;

// `RegExp.prototype.exec` method
// https://tc39.es/ecma262/#sec-regexp.prototype.exec
_export({ target: 'RegExp', proto: true, forced: /./.exec !== regexpExec }, {
  exec: regexpExec
});

// TODO: Remove from `core-js@4` since it's moved to entry points






var SPECIES$6 = wellKnownSymbol('species');

var REPLACE_SUPPORTS_NAMED_GROUPS = !fails(function () {
  // #replace needs built-in support for named groups.
  // #match works fine because it just return the exec results, even if it has
  // a "grops" property.
  var re = /./;
  re.exec = function () {
    var result = [];
    result.groups = { a: '7' };
    return result;
  };
  return ''.replace(re, '$<a>') !== '7';
});

// IE <= 11 replaces $0 with the whole match, as if it was $&
// https://stackoverflow.com/questions/6024666/getting-ie-to-replace-a-regex-with-the-literal-string-0
var REPLACE_KEEPS_$0 = (function () {
  // eslint-disable-next-line regexp/prefer-escape-replacement-dollar-char -- required for testing
  return 'a'.replace(/./, '$0') === '$0';
})();

var REPLACE = wellKnownSymbol('replace');
// Safari <= 13.0.3(?) substitutes nth capture where n>m with an empty string
var REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE = (function () {
  if (/./[REPLACE]) {
    return /./[REPLACE]('a', '$0') === '';
  }
  return false;
})();

// Chrome 51 has a buggy "split" implementation when RegExp#exec !== nativeExec
// Weex JS has frozen built-in prototypes, so use try / catch wrapper
var SPLIT_WORKS_WITH_OVERWRITTEN_EXEC = !fails(function () {
  // eslint-disable-next-line regexp/no-empty-group -- required for testing
  var re = /(?:)/;
  var originalExec = re.exec;
  re.exec = function () { return originalExec.apply(this, arguments); };
  var result = 'ab'.split(re);
  return result.length !== 2 || result[0] !== 'a' || result[1] !== 'b';
});

var fixRegexpWellKnownSymbolLogic = function (KEY, length, exec, sham) {
  var SYMBOL = wellKnownSymbol(KEY);

  var DELEGATES_TO_SYMBOL = !fails(function () {
    // String methods call symbol-named RegEp methods
    var O = {};
    O[SYMBOL] = function () { return 7; };
    return ''[KEY](O) != 7;
  });

  var DELEGATES_TO_EXEC = DELEGATES_TO_SYMBOL && !fails(function () {
    // Symbol-named RegExp methods call .exec
    var execCalled = false;
    var re = /a/;

    if (KEY === 'split') {
      // We can't use real regex here since it causes deoptimization
      // and serious performance degradation in V8
      // https://github.com/zloirock/core-js/issues/306
      re = {};
      // RegExp[@@split] doesn't call the regex's exec method, but first creates
      // a new one. We need to return the patched regex when creating the new one.
      re.constructor = {};
      re.constructor[SPECIES$6] = function () { return re; };
      re.flags = '';
      re[SYMBOL] = /./[SYMBOL];
    }

    re.exec = function () { execCalled = true; return null; };

    re[SYMBOL]('');
    return !execCalled;
  });

  if (
    !DELEGATES_TO_SYMBOL ||
    !DELEGATES_TO_EXEC ||
    (KEY === 'replace' && !(
      REPLACE_SUPPORTS_NAMED_GROUPS &&
      REPLACE_KEEPS_$0 &&
      !REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE
    )) ||
    (KEY === 'split' && !SPLIT_WORKS_WITH_OVERWRITTEN_EXEC)
  ) {
    var nativeRegExpMethod = /./[SYMBOL];
    var methods = exec(SYMBOL, ''[KEY], function (nativeMethod, regexp, str, arg2, forceStringMethod) {
      if (regexp.exec === RegExp.prototype.exec) {
        if (DELEGATES_TO_SYMBOL && !forceStringMethod) {
          // The native String method already delegates to @@method (this
          // polyfilled function), leasing to infinite recursion.
          // We avoid it by directly calling the native @@method method.
          return { done: true, value: nativeRegExpMethod.call(regexp, str, arg2) };
        }
        return { done: true, value: nativeMethod.call(str, regexp, arg2) };
      }
      return { done: false };
    }, {
      REPLACE_KEEPS_$0: REPLACE_KEEPS_$0,
      REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE: REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE
    });
    var stringMethod = methods[0];
    var regexMethod = methods[1];

    redefine(String.prototype, KEY, stringMethod);
    redefine(RegExp.prototype, SYMBOL, length == 2
      // 21.2.5.8 RegExp.prototype[@@replace](string, replaceValue)
      // 21.2.5.11 RegExp.prototype[@@split](string, limit)
      ? function (string, arg) { return regexMethod.call(string, this, arg); }
      // 21.2.5.6 RegExp.prototype[@@match](string)
      // 21.2.5.9 RegExp.prototype[@@search](string)
      : function (string) { return regexMethod.call(string, this); }
    );
  }

  if (sham) createNonEnumerableProperty(RegExp.prototype[SYMBOL], 'sham', true);
};

// `SameValue` abstract operation
// https://tc39.es/ecma262/#sec-samevalue
// eslint-disable-next-line es/no-object-is -- safe
var sameValue = Object.is || function is(x, y) {
  // eslint-disable-next-line no-self-compare -- NaN check
  return x === y ? x !== 0 || 1 / x === 1 / y : x != x && y != y;
};

// `RegExpExec` abstract operation
// https://tc39.es/ecma262/#sec-regexpexec
var regexpExecAbstract = function (R, S) {
  var exec = R.exec;
  if (typeof exec === 'function') {
    var result = exec.call(R, S);
    if (typeof result !== 'object') {
      throw TypeError('RegExp exec method returned something other than an Object or null');
    }
    return result;
  }

  if (classofRaw(R) !== 'RegExp') {
    throw TypeError('RegExp#exec called on incompatible receiver');
  }

  return regexpExec.call(R, S);
};

// @@search logic
fixRegexpWellKnownSymbolLogic('search', 1, function (SEARCH, nativeSearch, maybeCallNative) {
  return [
    // `String.prototype.search` method
    // https://tc39.es/ecma262/#sec-string.prototype.search
    function search(regexp) {
      var O = requireObjectCoercible(this);
      var searcher = regexp == undefined ? undefined : regexp[SEARCH];
      return searcher !== undefined ? searcher.call(regexp, O) : new RegExp(regexp)[SEARCH](String(O));
    },
    // `RegExp.prototype[@@search]` method
    // https://tc39.es/ecma262/#sec-regexp.prototype-@@search
    function (regexp) {
      var res = maybeCallNative(nativeSearch, regexp, this);
      if (res.done) return res.value;

      var rx = anObject(regexp);
      var S = String(this);

      var previousLastIndex = rx.lastIndex;
      if (!sameValue(previousLastIndex, 0)) rx.lastIndex = 0;
      var result = regexpExecAbstract(rx, S);
      if (!sameValue(rx.lastIndex, previousLastIndex)) rx.lastIndex = previousLastIndex;
      return result === null ? -1 : result.index;
    }
  ];
});

var IS_CONCAT_SPREADABLE = wellKnownSymbol('isConcatSpreadable');
var MAX_SAFE_INTEGER = 0x1FFFFFFFFFFFFF;
var MAXIMUM_ALLOWED_INDEX_EXCEEDED = 'Maximum allowed index exceeded';

// We can't use this feature detection in V8 since it causes
// deoptimization and serious performance degradation
// https://github.com/zloirock/core-js/issues/679
var IS_CONCAT_SPREADABLE_SUPPORT = engineV8Version >= 51 || !fails(function () {
  var array = [];
  array[IS_CONCAT_SPREADABLE] = false;
  return array.concat()[0] !== array;
});

var SPECIES_SUPPORT = arrayMethodHasSpeciesSupport('concat');

var isConcatSpreadable = function (O) {
  if (!isObject(O)) return false;
  var spreadable = O[IS_CONCAT_SPREADABLE];
  return spreadable !== undefined ? !!spreadable : isArray(O);
};

var FORCED$2 = !IS_CONCAT_SPREADABLE_SUPPORT || !SPECIES_SUPPORT;

// `Array.prototype.concat` method
// https://tc39.es/ecma262/#sec-array.prototype.concat
// with adding support of @@isConcatSpreadable and @@species
_export({ target: 'Array', proto: true, forced: FORCED$2 }, {
  // eslint-disable-next-line no-unused-vars -- required for `.length`
  concat: function concat(arg) {
    var O = toObject(this);
    var A = arraySpeciesCreate(O, 0);
    var n = 0;
    var i, k, length, len, E;
    for (i = -1, length = arguments.length; i < length; i++) {
      E = i === -1 ? O : arguments[i];
      if (isConcatSpreadable(E)) {
        len = toLength(E.length);
        if (n + len > MAX_SAFE_INTEGER) throw TypeError(MAXIMUM_ALLOWED_INDEX_EXCEEDED);
        for (k = 0; k < len; k++, n++) if (k in E) createProperty(A, n, E[k]);
      } else {
        if (n >= MAX_SAFE_INTEGER) throw TypeError(MAXIMUM_ALLOWED_INDEX_EXCEEDED);
        createProperty(A, n++, E);
      }
    }
    A.length = n;
    return A;
  }
});

// makes subclassing work correct for wrapped built-ins
var inheritIfRequired = function ($this, dummy, Wrapper) {
  var NewTarget, NewTargetPrototype;
  if (
    // it can work only with native `setPrototypeOf`
    objectSetPrototypeOf &&
    // we haven't completely correct pre-ES6 way for getting `new.target`, so use this
    typeof (NewTarget = dummy.constructor) == 'function' &&
    NewTarget !== Wrapper &&
    isObject(NewTargetPrototype = NewTarget.prototype) &&
    NewTargetPrototype !== Wrapper.prototype
  ) objectSetPrototypeOf($this, NewTargetPrototype);
  return $this;
};

// a string of all valid unicode whitespaces
var whitespaces = '\u0009\u000A\u000B\u000C\u000D\u0020\u00A0\u1680\u2000\u2001\u2002' +
  '\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF';

var whitespace = '[' + whitespaces + ']';
var ltrim = RegExp('^' + whitespace + whitespace + '*');
var rtrim = RegExp(whitespace + whitespace + '*$');

// `String.prototype.{ trim, trimStart, trimEnd, trimLeft, trimRight }` methods implementation
var createMethod$3 = function (TYPE) {
  return function ($this) {
    var string = String(requireObjectCoercible($this));
    if (TYPE & 1) string = string.replace(ltrim, '');
    if (TYPE & 2) string = string.replace(rtrim, '');
    return string;
  };
};

var stringTrim = {
  // `String.prototype.{ trimLeft, trimStart }` methods
  // https://tc39.es/ecma262/#sec-string.prototype.trimstart
  start: createMethod$3(1),
  // `String.prototype.{ trimRight, trimEnd }` methods
  // https://tc39.es/ecma262/#sec-string.prototype.trimend
  end: createMethod$3(2),
  // `String.prototype.trim` method
  // https://tc39.es/ecma262/#sec-string.prototype.trim
  trim: createMethod$3(3)
};

var getOwnPropertyNames = objectGetOwnPropertyNames.f;
var getOwnPropertyDescriptor$3 = objectGetOwnPropertyDescriptor.f;
var defineProperty$4 = objectDefineProperty.f;
var trim = stringTrim.trim;

var NUMBER = 'Number';
var NativeNumber = global_1[NUMBER];
var NumberPrototype = NativeNumber.prototype;

// Opera ~12 has broken Object#toString
var BROKEN_CLASSOF = classofRaw(objectCreate(NumberPrototype)) == NUMBER;

// `ToNumber` abstract operation
// https://tc39.es/ecma262/#sec-tonumber
var toNumber = function (argument) {
  var it = toPrimitive(argument, false);
  var first, third, radix, maxCode, digits, length, index, code;
  if (typeof it == 'string' && it.length > 2) {
    it = trim(it);
    first = it.charCodeAt(0);
    if (first === 43 || first === 45) {
      third = it.charCodeAt(2);
      if (third === 88 || third === 120) return NaN; // Number('+0x1') should be NaN, old V8 fix
    } else if (first === 48) {
      switch (it.charCodeAt(1)) {
        case 66: case 98: radix = 2; maxCode = 49; break; // fast equal of /^0b[01]+$/i
        case 79: case 111: radix = 8; maxCode = 55; break; // fast equal of /^0o[0-7]+$/i
        default: return +it;
      }
      digits = it.slice(2);
      length = digits.length;
      for (index = 0; index < length; index++) {
        code = digits.charCodeAt(index);
        // parseInt parses a string to a first unavailable symbol
        // but ToNumber should return NaN if a string contains unavailable symbols
        if (code < 48 || code > maxCode) return NaN;
      } return parseInt(digits, radix);
    }
  } return +it;
};

// `Number` constructor
// https://tc39.es/ecma262/#sec-number-constructor
if (isForced_1(NUMBER, !NativeNumber(' 0o1') || !NativeNumber('0b1') || NativeNumber('+0x1'))) {
  var NumberWrapper = function Number(value) {
    var it = arguments.length < 1 ? 0 : value;
    var dummy = this;
    return dummy instanceof NumberWrapper
      // check on 1..constructor(foo) case
      && (BROKEN_CLASSOF ? fails(function () { NumberPrototype.valueOf.call(dummy); }) : classofRaw(dummy) != NUMBER)
        ? inheritIfRequired(new NativeNumber(toNumber(it)), dummy, NumberWrapper) : toNumber(it);
  };
  for (var keys$1 = descriptors ? getOwnPropertyNames(NativeNumber) : (
    // ES3:
    'MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,' +
    // ES2015 (in case, if modules with ES2015 Number statics required before):
    'EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,' +
    'MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger,' +
    // ESNext
    'fromString,range'
  ).split(','), j = 0, key; keys$1.length > j; j++) {
    if (has(NativeNumber, key = keys$1[j]) && !has(NumberWrapper, key)) {
      defineProperty$4(NumberWrapper, key, getOwnPropertyDescriptor$3(NativeNumber, key));
    }
  }
  NumberWrapper.prototype = NumberPrototype;
  NumberPrototype.constructor = NumberWrapper;
  redefine(global_1, NUMBER, NumberWrapper);
}

var $map = arrayIteration.map;


var HAS_SPECIES_SUPPORT$2 = arrayMethodHasSpeciesSupport('map');

// `Array.prototype.map` method
// https://tc39.es/ecma262/#sec-array.prototype.map
// with adding support of @@species
_export({ target: 'Array', proto: true, forced: !HAS_SPECIES_SUPPORT$2 }, {
  map: function map(callbackfn /* , thisArg */) {
    return $map(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
  }
});

/* eslint-disable es/no-array-prototype-indexof -- required for testing */

var $indexOf = arrayIncludes.indexOf;


var nativeIndexOf = [].indexOf;

var NEGATIVE_ZERO = !!nativeIndexOf && 1 / [1].indexOf(1, -0) < 0;
var STRICT_METHOD$1 = arrayMethodIsStrict('indexOf');

// `Array.prototype.indexOf` method
// https://tc39.es/ecma262/#sec-array.prototype.indexof
_export({ target: 'Array', proto: true, forced: NEGATIVE_ZERO || !STRICT_METHOD$1 }, {
  indexOf: function indexOf(searchElement /* , fromIndex = 0 */) {
    return NEGATIVE_ZERO
      // convert -0 to +0
      ? nativeIndexOf.apply(this, arguments) || 0
      : $indexOf(this, searchElement, arguments.length > 1 ? arguments[1] : undefined);
  }
});

var charAt$1 = stringMultibyte.charAt;

// `AdvanceStringIndex` abstract operation
// https://tc39.es/ecma262/#sec-advancestringindex
var advanceStringIndex = function (S, index, unicode) {
  return index + (unicode ? charAt$1(S, index).length : 1);
};

var floor$1 = Math.floor;
var replace = ''.replace;
var SUBSTITUTION_SYMBOLS = /\$([$&'`]|\d{1,2}|<[^>]*>)/g;
var SUBSTITUTION_SYMBOLS_NO_NAMED = /\$([$&'`]|\d{1,2})/g;

// https://tc39.es/ecma262/#sec-getsubstitution
var getSubstitution = function (matched, str, position, captures, namedCaptures, replacement) {
  var tailPos = position + matched.length;
  var m = captures.length;
  var symbols = SUBSTITUTION_SYMBOLS_NO_NAMED;
  if (namedCaptures !== undefined) {
    namedCaptures = toObject(namedCaptures);
    symbols = SUBSTITUTION_SYMBOLS;
  }
  return replace.call(replacement, symbols, function (match, ch) {
    var capture;
    switch (ch.charAt(0)) {
      case '$': return '$';
      case '&': return matched;
      case '`': return str.slice(0, position);
      case "'": return str.slice(tailPos);
      case '<':
        capture = namedCaptures[ch.slice(1, -1)];
        break;
      default: // \d\d?
        var n = +ch;
        if (n === 0) return match;
        if (n > m) {
          var f = floor$1(n / 10);
          if (f === 0) return match;
          if (f <= m) return captures[f - 1] === undefined ? ch.charAt(1) : captures[f - 1] + ch.charAt(1);
          return match;
        }
        capture = captures[n - 1];
    }
    return capture === undefined ? '' : capture;
  });
};

var max$2 = Math.max;
var min$2 = Math.min;

var maybeToString = function (it) {
  return it === undefined ? it : String(it);
};

// @@replace logic
fixRegexpWellKnownSymbolLogic('replace', 2, function (REPLACE, nativeReplace, maybeCallNative, reason) {
  var REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE = reason.REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE;
  var REPLACE_KEEPS_$0 = reason.REPLACE_KEEPS_$0;
  var UNSAFE_SUBSTITUTE = REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE ? '$' : '$0';

  return [
    // `String.prototype.replace` method
    // https://tc39.es/ecma262/#sec-string.prototype.replace
    function replace(searchValue, replaceValue) {
      var O = requireObjectCoercible(this);
      var replacer = searchValue == undefined ? undefined : searchValue[REPLACE];
      return replacer !== undefined
        ? replacer.call(searchValue, O, replaceValue)
        : nativeReplace.call(String(O), searchValue, replaceValue);
    },
    // `RegExp.prototype[@@replace]` method
    // https://tc39.es/ecma262/#sec-regexp.prototype-@@replace
    function (regexp, replaceValue) {
      if (
        (!REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE && REPLACE_KEEPS_$0) ||
        (typeof replaceValue === 'string' && replaceValue.indexOf(UNSAFE_SUBSTITUTE) === -1)
      ) {
        var res = maybeCallNative(nativeReplace, regexp, this, replaceValue);
        if (res.done) return res.value;
      }

      var rx = anObject(regexp);
      var S = String(this);

      var functionalReplace = typeof replaceValue === 'function';
      if (!functionalReplace) replaceValue = String(replaceValue);

      var global = rx.global;
      if (global) {
        var fullUnicode = rx.unicode;
        rx.lastIndex = 0;
      }
      var results = [];
      while (true) {
        var result = regexpExecAbstract(rx, S);
        if (result === null) break;

        results.push(result);
        if (!global) break;

        var matchStr = String(result[0]);
        if (matchStr === '') rx.lastIndex = advanceStringIndex(S, toLength(rx.lastIndex), fullUnicode);
      }

      var accumulatedResult = '';
      var nextSourcePosition = 0;
      for (var i = 0; i < results.length; i++) {
        result = results[i];

        var matched = String(result[0]);
        var position = max$2(min$2(toInteger(result.index), S.length), 0);
        var captures = [];
        // NOTE: This is equivalent to
        //   captures = result.slice(1).map(maybeToString)
        // but for some reason `nativeSlice.call(result, 1, result.length)` (called in
        // the slice polyfill when slicing native arrays) "doesn't work" in safari 9 and
        // causes a crash (https://pastebin.com/N21QzeQA) when trying to debug it.
        for (var j = 1; j < result.length; j++) captures.push(maybeToString(result[j]));
        var namedCaptures = result.groups;
        if (functionalReplace) {
          var replacerArgs = [matched].concat(captures, position, S);
          if (namedCaptures !== undefined) replacerArgs.push(namedCaptures);
          var replacement = String(replaceValue.apply(undefined, replacerArgs));
        } else {
          replacement = getSubstitution(matched, S, position, captures, namedCaptures, replaceValue);
        }
        if (position >= nextSourcePosition) {
          accumulatedResult += S.slice(nextSourcePosition, position) + replacement;
          nextSourcePosition = position + matched.length;
        }
      }
      return accumulatedResult + S.slice(nextSourcePosition);
    }
  ];
});

// `URL.prototype.toJSON` method
// https://url.spec.whatwg.org/#dom-url-tojson
_export({ target: 'URL', proto: true, enumerable: true }, {
  toJSON: function toJSON() {
    return URL.prototype.toString.call(this);
  }
});

var nativeJoin = [].join;

var ES3_STRINGS = indexedObject != Object;
var STRICT_METHOD$2 = arrayMethodIsStrict('join', ',');

// `Array.prototype.join` method
// https://tc39.es/ecma262/#sec-array.prototype.join
_export({ target: 'Array', proto: true, forced: ES3_STRINGS || !STRICT_METHOD$2 }, {
  join: function join(separator) {
    return nativeJoin.call(toIndexedObject(this), separator === undefined ? ',' : separator);
  }
});

// @@match logic
fixRegexpWellKnownSymbolLogic('match', 1, function (MATCH, nativeMatch, maybeCallNative) {
  return [
    // `String.prototype.match` method
    // https://tc39.es/ecma262/#sec-string.prototype.match
    function match(regexp) {
      var O = requireObjectCoercible(this);
      var matcher = regexp == undefined ? undefined : regexp[MATCH];
      return matcher !== undefined ? matcher.call(regexp, O) : new RegExp(regexp)[MATCH](String(O));
    },
    // `RegExp.prototype[@@match]` method
    // https://tc39.es/ecma262/#sec-regexp.prototype-@@match
    function (regexp) {
      var res = maybeCallNative(nativeMatch, regexp, this);
      if (res.done) return res.value;

      var rx = anObject(regexp);
      var S = String(this);

      if (!rx.global) return regexpExecAbstract(rx, S);

      var fullUnicode = rx.unicode;
      rx.lastIndex = 0;
      var A = [];
      var n = 0;
      var result;
      while ((result = regexpExecAbstract(rx, S)) !== null) {
        var matchStr = String(result[0]);
        A[n] = matchStr;
        if (matchStr === '') rx.lastIndex = advanceStringIndex(S, toLength(rx.lastIndex), fullUnicode);
        n++;
      }
      return n === 0 ? null : A;
    }
  ];
});

var MATCH = wellKnownSymbol('match');

// `IsRegExp` abstract operation
// https://tc39.es/ecma262/#sec-isregexp
var isRegexp = function (it) {
  var isRegExp;
  return isObject(it) && ((isRegExp = it[MATCH]) !== undefined ? !!isRegExp : classofRaw(it) == 'RegExp');
};

var defineProperty$5 = objectDefineProperty.f;
var getOwnPropertyNames$1 = objectGetOwnPropertyNames.f;





var setInternalState$4 = internalState.set;



var MATCH$1 = wellKnownSymbol('match');
var NativeRegExp = global_1.RegExp;
var RegExpPrototype$1 = NativeRegExp.prototype;
var re1 = /a/g;
var re2 = /a/g;

// "new" should create a new object, old webkit bug
var CORRECT_NEW = new NativeRegExp(re1) !== re1;

var UNSUPPORTED_Y$2 = regexpStickyHelpers.UNSUPPORTED_Y;

var FORCED$3 = descriptors && isForced_1('RegExp', (!CORRECT_NEW || UNSUPPORTED_Y$2 || fails(function () {
  re2[MATCH$1] = false;
  // RegExp constructor can alter flags and IsRegExp works correct with @@match
  return NativeRegExp(re1) != re1 || NativeRegExp(re2) == re2 || NativeRegExp(re1, 'i') != '/a/i';
})));

// `RegExp` constructor
// https://tc39.es/ecma262/#sec-regexp-constructor
if (FORCED$3) {
  var RegExpWrapper = function RegExp(pattern, flags) {
    var thisIsRegExp = this instanceof RegExpWrapper;
    var patternIsRegExp = isRegexp(pattern);
    var flagsAreUndefined = flags === undefined;
    var sticky;

    if (!thisIsRegExp && patternIsRegExp && pattern.constructor === RegExpWrapper && flagsAreUndefined) {
      return pattern;
    }

    if (CORRECT_NEW) {
      if (patternIsRegExp && !flagsAreUndefined) pattern = pattern.source;
    } else if (pattern instanceof RegExpWrapper) {
      if (flagsAreUndefined) flags = regexpFlags.call(pattern);
      pattern = pattern.source;
    }

    if (UNSUPPORTED_Y$2) {
      sticky = !!flags && flags.indexOf('y') > -1;
      if (sticky) flags = flags.replace(/y/g, '');
    }

    var result = inheritIfRequired(
      CORRECT_NEW ? new NativeRegExp(pattern, flags) : NativeRegExp(pattern, flags),
      thisIsRegExp ? this : RegExpPrototype$1,
      RegExpWrapper
    );

    if (UNSUPPORTED_Y$2 && sticky) setInternalState$4(result, { sticky: sticky });

    return result;
  };
  var proxy = function (key) {
    key in RegExpWrapper || defineProperty$5(RegExpWrapper, key, {
      configurable: true,
      get: function () { return NativeRegExp[key]; },
      set: function (it) { NativeRegExp[key] = it; }
    });
  };
  var keys$2 = getOwnPropertyNames$1(NativeRegExp);
  var index = 0;
  while (keys$2.length > index) proxy(keys$2[index++]);
  RegExpPrototype$1.constructor = RegExpWrapper;
  RegExpWrapper.prototype = RegExpPrototype$1;
  redefine(global_1, 'RegExp', RegExpWrapper);
}

// https://tc39.es/ecma262/#sec-get-regexp-@@species
setSpecies('RegExp');

var UNSUPPORTED_Y$3 = regexpStickyHelpers.UNSUPPORTED_Y;
var arrayPush = [].push;
var min$3 = Math.min;
var MAX_UINT32 = 0xFFFFFFFF;

// @@split logic
fixRegexpWellKnownSymbolLogic('split', 2, function (SPLIT, nativeSplit, maybeCallNative) {
  var internalSplit;
  if (
    'abbc'.split(/(b)*/)[1] == 'c' ||
    // eslint-disable-next-line regexp/no-empty-group -- required for testing
    'test'.split(/(?:)/, -1).length != 4 ||
    'ab'.split(/(?:ab)*/).length != 2 ||
    '.'.split(/(.?)(.?)/).length != 4 ||
    // eslint-disable-next-line regexp/no-assertion-capturing-group, regexp/no-empty-group -- required for testing
    '.'.split(/()()/).length > 1 ||
    ''.split(/.?/).length
  ) {
    // based on es5-shim implementation, need to rework it
    internalSplit = function (separator, limit) {
      var string = String(requireObjectCoercible(this));
      var lim = limit === undefined ? MAX_UINT32 : limit >>> 0;
      if (lim === 0) return [];
      if (separator === undefined) return [string];
      // If `separator` is not a regex, use native split
      if (!isRegexp(separator)) {
        return nativeSplit.call(string, separator, lim);
      }
      var output = [];
      var flags = (separator.ignoreCase ? 'i' : '') +
                  (separator.multiline ? 'm' : '') +
                  (separator.unicode ? 'u' : '') +
                  (separator.sticky ? 'y' : '');
      var lastLastIndex = 0;
      // Make `global` and avoid `lastIndex` issues by working with a copy
      var separatorCopy = new RegExp(separator.source, flags + 'g');
      var match, lastIndex, lastLength;
      while (match = regexpExec.call(separatorCopy, string)) {
        lastIndex = separatorCopy.lastIndex;
        if (lastIndex > lastLastIndex) {
          output.push(string.slice(lastLastIndex, match.index));
          if (match.length > 1 && match.index < string.length) arrayPush.apply(output, match.slice(1));
          lastLength = match[0].length;
          lastLastIndex = lastIndex;
          if (output.length >= lim) break;
        }
        if (separatorCopy.lastIndex === match.index) separatorCopy.lastIndex++; // Avoid an infinite loop
      }
      if (lastLastIndex === string.length) {
        if (lastLength || !separatorCopy.test('')) output.push('');
      } else output.push(string.slice(lastLastIndex));
      return output.length > lim ? output.slice(0, lim) : output;
    };
  // Chakra, V8
  } else if ('0'.split(undefined, 0).length) {
    internalSplit = function (separator, limit) {
      return separator === undefined && limit === 0 ? [] : nativeSplit.call(this, separator, limit);
    };
  } else internalSplit = nativeSplit;

  return [
    // `String.prototype.split` method
    // https://tc39.es/ecma262/#sec-string.prototype.split
    function split(separator, limit) {
      var O = requireObjectCoercible(this);
      var splitter = separator == undefined ? undefined : separator[SPLIT];
      return splitter !== undefined
        ? splitter.call(separator, O, limit)
        : internalSplit.call(String(O), separator, limit);
    },
    // `RegExp.prototype[@@split]` method
    // https://tc39.es/ecma262/#sec-regexp.prototype-@@split
    //
    // NOTE: This cannot be properly polyfilled in engines that don't support
    // the 'y' flag.
    function (regexp, limit) {
      var res = maybeCallNative(internalSplit, regexp, this, limit, internalSplit !== nativeSplit);
      if (res.done) return res.value;

      var rx = anObject(regexp);
      var S = String(this);
      var C = speciesConstructor(rx, RegExp);

      var unicodeMatching = rx.unicode;
      var flags = (rx.ignoreCase ? 'i' : '') +
                  (rx.multiline ? 'm' : '') +
                  (rx.unicode ? 'u' : '') +
                  (UNSUPPORTED_Y$3 ? 'g' : 'y');

      // ^(? + rx + ) is needed, in combination with some S slicing, to
      // simulate the 'y' flag.
      var splitter = new C(UNSUPPORTED_Y$3 ? '^(?:' + rx.source + ')' : rx, flags);
      var lim = limit === undefined ? MAX_UINT32 : limit >>> 0;
      if (lim === 0) return [];
      if (S.length === 0) return regexpExecAbstract(splitter, S) === null ? [S] : [];
      var p = 0;
      var q = 0;
      var A = [];
      while (q < S.length) {
        splitter.lastIndex = UNSUPPORTED_Y$3 ? 0 : q;
        var z = regexpExecAbstract(splitter, UNSUPPORTED_Y$3 ? S.slice(q) : S);
        var e;
        if (
          z === null ||
          (e = min$3(toLength(splitter.lastIndex + (UNSUPPORTED_Y$3 ? q : 0)), S.length)) === p
        ) {
          q = advanceStringIndex(S, q, unicodeMatching);
        } else {
          A.push(S.slice(p, q));
          if (A.length === lim) return A;
          for (var i = 1; i <= z.length - 1; i++) {
            A.push(z[i]);
            if (A.length === lim) return A;
          }
          q = p = e;
        }
      }
      A.push(S.slice(p));
      return A;
    }
  ];
}, UNSUPPORTED_Y$3);

var non = '\u200B\u0085\u180E';

// check that a method works with the correct list
// of whitespaces and has a correct name
var stringTrimForced = function (METHOD_NAME) {
  return fails(function () {
    return !!whitespaces[METHOD_NAME]() || non[METHOD_NAME]() != non || whitespaces[METHOD_NAME].name !== METHOD_NAME;
  });
};

var $trim = stringTrim.trim;


// `String.prototype.trim` method
// https://tc39.es/ecma262/#sec-string.prototype.trim
_export({ target: 'String', proto: true, forced: stringTrimForced('trim') }, {
  trim: function trim() {
    return $trim(this);
  }
});

// eslint-disable-next-line es/no-typed-arrays -- safe
var arrayBufferNative = typeof ArrayBuffer !== 'undefined' && typeof DataView !== 'undefined';

// `ToIndex` abstract operation
// https://tc39.es/ecma262/#sec-toindex
var toIndex = function (it) {
  if (it === undefined) return 0;
  var number = toInteger(it);
  var length = toLength(number);
  if (number !== length) throw RangeError('Wrong length or index');
  return length;
};

// IEEE754 conversions based on https://github.com/feross/ieee754
var abs = Math.abs;
var pow = Math.pow;
var floor$2 = Math.floor;
var log = Math.log;
var LN2 = Math.LN2;

var pack = function (number, mantissaLength, bytes) {
  var buffer = new Array(bytes);
  var exponentLength = bytes * 8 - mantissaLength - 1;
  var eMax = (1 << exponentLength) - 1;
  var eBias = eMax >> 1;
  var rt = mantissaLength === 23 ? pow(2, -24) - pow(2, -77) : 0;
  var sign = number < 0 || number === 0 && 1 / number < 0 ? 1 : 0;
  var index = 0;
  var exponent, mantissa, c;
  number = abs(number);
  // eslint-disable-next-line no-self-compare -- NaN check
  if (number != number || number === Infinity) {
    // eslint-disable-next-line no-self-compare -- NaN check
    mantissa = number != number ? 1 : 0;
    exponent = eMax;
  } else {
    exponent = floor$2(log(number) / LN2);
    if (number * (c = pow(2, -exponent)) < 1) {
      exponent--;
      c *= 2;
    }
    if (exponent + eBias >= 1) {
      number += rt / c;
    } else {
      number += rt * pow(2, 1 - eBias);
    }
    if (number * c >= 2) {
      exponent++;
      c /= 2;
    }
    if (exponent + eBias >= eMax) {
      mantissa = 0;
      exponent = eMax;
    } else if (exponent + eBias >= 1) {
      mantissa = (number * c - 1) * pow(2, mantissaLength);
      exponent = exponent + eBias;
    } else {
      mantissa = number * pow(2, eBias - 1) * pow(2, mantissaLength);
      exponent = 0;
    }
  }
  for (; mantissaLength >= 8; buffer[index++] = mantissa & 255, mantissa /= 256, mantissaLength -= 8);
  exponent = exponent << mantissaLength | mantissa;
  exponentLength += mantissaLength;
  for (; exponentLength > 0; buffer[index++] = exponent & 255, exponent /= 256, exponentLength -= 8);
  buffer[--index] |= sign * 128;
  return buffer;
};

var unpack = function (buffer, mantissaLength) {
  var bytes = buffer.length;
  var exponentLength = bytes * 8 - mantissaLength - 1;
  var eMax = (1 << exponentLength) - 1;
  var eBias = eMax >> 1;
  var nBits = exponentLength - 7;
  var index = bytes - 1;
  var sign = buffer[index--];
  var exponent = sign & 127;
  var mantissa;
  sign >>= 7;
  for (; nBits > 0; exponent = exponent * 256 + buffer[index], index--, nBits -= 8);
  mantissa = exponent & (1 << -nBits) - 1;
  exponent >>= -nBits;
  nBits += mantissaLength;
  for (; nBits > 0; mantissa = mantissa * 256 + buffer[index], index--, nBits -= 8);
  if (exponent === 0) {
    exponent = 1 - eBias;
  } else if (exponent === eMax) {
    return mantissa ? NaN : sign ? -Infinity : Infinity;
  } else {
    mantissa = mantissa + pow(2, mantissaLength);
    exponent = exponent - eBias;
  } return (sign ? -1 : 1) * mantissa * pow(2, exponent - mantissaLength);
};

var ieee754 = {
  pack: pack,
  unpack: unpack
};

// `Array.prototype.fill` method implementation
// https://tc39.es/ecma262/#sec-array.prototype.fill
var arrayFill = function fill(value /* , start = 0, end = @length */) {
  var O = toObject(this);
  var length = toLength(O.length);
  var argumentsLength = arguments.length;
  var index = toAbsoluteIndex(argumentsLength > 1 ? arguments[1] : undefined, length);
  var end = argumentsLength > 2 ? arguments[2] : undefined;
  var endPos = end === undefined ? length : toAbsoluteIndex(end, length);
  while (endPos > index) O[index++] = value;
  return O;
};

var getOwnPropertyNames$2 = objectGetOwnPropertyNames.f;
var defineProperty$6 = objectDefineProperty.f;




var getInternalState$4 = internalState.get;
var setInternalState$5 = internalState.set;
var ARRAY_BUFFER = 'ArrayBuffer';
var DATA_VIEW = 'DataView';
var PROTOTYPE$2 = 'prototype';
var WRONG_LENGTH = 'Wrong length';
var WRONG_INDEX = 'Wrong index';
var NativeArrayBuffer = global_1[ARRAY_BUFFER];
var $ArrayBuffer = NativeArrayBuffer;
var $DataView = global_1[DATA_VIEW];
var $DataViewPrototype = $DataView && $DataView[PROTOTYPE$2];
var ObjectPrototype$2 = Object.prototype;
var RangeError$1 = global_1.RangeError;

var packIEEE754 = ieee754.pack;
var unpackIEEE754 = ieee754.unpack;

var packInt8 = function (number) {
  return [number & 0xFF];
};

var packInt16 = function (number) {
  return [number & 0xFF, number >> 8 & 0xFF];
};

var packInt32 = function (number) {
  return [number & 0xFF, number >> 8 & 0xFF, number >> 16 & 0xFF, number >> 24 & 0xFF];
};

var unpackInt32 = function (buffer) {
  return buffer[3] << 24 | buffer[2] << 16 | buffer[1] << 8 | buffer[0];
};

var packFloat32 = function (number) {
  return packIEEE754(number, 23, 4);
};

var packFloat64 = function (number) {
  return packIEEE754(number, 52, 8);
};

var addGetter = function (Constructor, key) {
  defineProperty$6(Constructor[PROTOTYPE$2], key, { get: function () { return getInternalState$4(this)[key]; } });
};

var get$1 = function (view, count, index, isLittleEndian) {
  var intIndex = toIndex(index);
  var store = getInternalState$4(view);
  if (intIndex + count > store.byteLength) throw RangeError$1(WRONG_INDEX);
  var bytes = getInternalState$4(store.buffer).bytes;
  var start = intIndex + store.byteOffset;
  var pack = bytes.slice(start, start + count);
  return isLittleEndian ? pack : pack.reverse();
};

var set$2 = function (view, count, index, conversion, value, isLittleEndian) {
  var intIndex = toIndex(index);
  var store = getInternalState$4(view);
  if (intIndex + count > store.byteLength) throw RangeError$1(WRONG_INDEX);
  var bytes = getInternalState$4(store.buffer).bytes;
  var start = intIndex + store.byteOffset;
  var pack = conversion(+value);
  for (var i = 0; i < count; i++) bytes[start + i] = pack[isLittleEndian ? i : count - i - 1];
};

if (!arrayBufferNative) {
  $ArrayBuffer = function ArrayBuffer(length) {
    anInstance(this, $ArrayBuffer, ARRAY_BUFFER);
    var byteLength = toIndex(length);
    setInternalState$5(this, {
      bytes: arrayFill.call(new Array(byteLength), 0),
      byteLength: byteLength
    });
    if (!descriptors) this.byteLength = byteLength;
  };

  $DataView = function DataView(buffer, byteOffset, byteLength) {
    anInstance(this, $DataView, DATA_VIEW);
    anInstance(buffer, $ArrayBuffer, DATA_VIEW);
    var bufferLength = getInternalState$4(buffer).byteLength;
    var offset = toInteger(byteOffset);
    if (offset < 0 || offset > bufferLength) throw RangeError$1('Wrong offset');
    byteLength = byteLength === undefined ? bufferLength - offset : toLength(byteLength);
    if (offset + byteLength > bufferLength) throw RangeError$1(WRONG_LENGTH);
    setInternalState$5(this, {
      buffer: buffer,
      byteLength: byteLength,
      byteOffset: offset
    });
    if (!descriptors) {
      this.buffer = buffer;
      this.byteLength = byteLength;
      this.byteOffset = offset;
    }
  };

  if (descriptors) {
    addGetter($ArrayBuffer, 'byteLength');
    addGetter($DataView, 'buffer');
    addGetter($DataView, 'byteLength');
    addGetter($DataView, 'byteOffset');
  }

  redefineAll($DataView[PROTOTYPE$2], {
    getInt8: function getInt8(byteOffset) {
      return get$1(this, 1, byteOffset)[0] << 24 >> 24;
    },
    getUint8: function getUint8(byteOffset) {
      return get$1(this, 1, byteOffset)[0];
    },
    getInt16: function getInt16(byteOffset /* , littleEndian */) {
      var bytes = get$1(this, 2, byteOffset, arguments.length > 1 ? arguments[1] : undefined);
      return (bytes[1] << 8 | bytes[0]) << 16 >> 16;
    },
    getUint16: function getUint16(byteOffset /* , littleEndian */) {
      var bytes = get$1(this, 2, byteOffset, arguments.length > 1 ? arguments[1] : undefined);
      return bytes[1] << 8 | bytes[0];
    },
    getInt32: function getInt32(byteOffset /* , littleEndian */) {
      return unpackInt32(get$1(this, 4, byteOffset, arguments.length > 1 ? arguments[1] : undefined));
    },
    getUint32: function getUint32(byteOffset /* , littleEndian */) {
      return unpackInt32(get$1(this, 4, byteOffset, arguments.length > 1 ? arguments[1] : undefined)) >>> 0;
    },
    getFloat32: function getFloat32(byteOffset /* , littleEndian */) {
      return unpackIEEE754(get$1(this, 4, byteOffset, arguments.length > 1 ? arguments[1] : undefined), 23);
    },
    getFloat64: function getFloat64(byteOffset /* , littleEndian */) {
      return unpackIEEE754(get$1(this, 8, byteOffset, arguments.length > 1 ? arguments[1] : undefined), 52);
    },
    setInt8: function setInt8(byteOffset, value) {
      set$2(this, 1, byteOffset, packInt8, value);
    },
    setUint8: function setUint8(byteOffset, value) {
      set$2(this, 1, byteOffset, packInt8, value);
    },
    setInt16: function setInt16(byteOffset, value /* , littleEndian */) {
      set$2(this, 2, byteOffset, packInt16, value, arguments.length > 2 ? arguments[2] : undefined);
    },
    setUint16: function setUint16(byteOffset, value /* , littleEndian */) {
      set$2(this, 2, byteOffset, packInt16, value, arguments.length > 2 ? arguments[2] : undefined);
    },
    setInt32: function setInt32(byteOffset, value /* , littleEndian */) {
      set$2(this, 4, byteOffset, packInt32, value, arguments.length > 2 ? arguments[2] : undefined);
    },
    setUint32: function setUint32(byteOffset, value /* , littleEndian */) {
      set$2(this, 4, byteOffset, packInt32, value, arguments.length > 2 ? arguments[2] : undefined);
    },
    setFloat32: function setFloat32(byteOffset, value /* , littleEndian */) {
      set$2(this, 4, byteOffset, packFloat32, value, arguments.length > 2 ? arguments[2] : undefined);
    },
    setFloat64: function setFloat64(byteOffset, value /* , littleEndian */) {
      set$2(this, 8, byteOffset, packFloat64, value, arguments.length > 2 ? arguments[2] : undefined);
    }
  });
} else {
  /* eslint-disable no-new -- required for testing */
  if (!fails(function () {
    NativeArrayBuffer(1);
  }) || !fails(function () {
    new NativeArrayBuffer(-1);
  }) || fails(function () {
    new NativeArrayBuffer();
    new NativeArrayBuffer(1.5);
    new NativeArrayBuffer(NaN);
    return NativeArrayBuffer.name != ARRAY_BUFFER;
  })) {
  /* eslint-enable no-new -- required for testing */
    $ArrayBuffer = function ArrayBuffer(length) {
      anInstance(this, $ArrayBuffer);
      return new NativeArrayBuffer(toIndex(length));
    };
    var ArrayBufferPrototype = $ArrayBuffer[PROTOTYPE$2] = NativeArrayBuffer[PROTOTYPE$2];
    for (var keys$3 = getOwnPropertyNames$2(NativeArrayBuffer), j$1 = 0, key$1; keys$3.length > j$1;) {
      if (!((key$1 = keys$3[j$1++]) in $ArrayBuffer)) {
        createNonEnumerableProperty($ArrayBuffer, key$1, NativeArrayBuffer[key$1]);
      }
    }
    ArrayBufferPrototype.constructor = $ArrayBuffer;
  }

  // WebKit bug - the same parent prototype for typed arrays and data view
  if (objectSetPrototypeOf && objectGetPrototypeOf($DataViewPrototype) !== ObjectPrototype$2) {
    objectSetPrototypeOf($DataViewPrototype, ObjectPrototype$2);
  }

  // iOS Safari 7.x bug
  var testView = new $DataView(new $ArrayBuffer(2));
  var $setInt8 = $DataViewPrototype.setInt8;
  testView.setInt8(0, 2147483648);
  testView.setInt8(1, 2147483649);
  if (testView.getInt8(0) || !testView.getInt8(1)) redefineAll($DataViewPrototype, {
    setInt8: function setInt8(byteOffset, value) {
      $setInt8.call(this, byteOffset, value << 24 >> 24);
    },
    setUint8: function setUint8(byteOffset, value) {
      $setInt8.call(this, byteOffset, value << 24 >> 24);
    }
  }, { unsafe: true });
}

setToStringTag($ArrayBuffer, ARRAY_BUFFER);
setToStringTag($DataView, DATA_VIEW);

var arrayBuffer = {
  ArrayBuffer: $ArrayBuffer,
  DataView: $DataView
};

var ARRAY_BUFFER$1 = 'ArrayBuffer';
var ArrayBuffer$1 = arrayBuffer[ARRAY_BUFFER$1];
var NativeArrayBuffer$1 = global_1[ARRAY_BUFFER$1];

// `ArrayBuffer` constructor
// https://tc39.es/ecma262/#sec-arraybuffer-constructor
_export({ global: true, forced: NativeArrayBuffer$1 !== ArrayBuffer$1 }, {
  ArrayBuffer: ArrayBuffer$1
});

setSpecies(ARRAY_BUFFER$1);

var ArrayBuffer$2 = arrayBuffer.ArrayBuffer;
var DataView$1 = arrayBuffer.DataView;
var nativeArrayBufferSlice = ArrayBuffer$2.prototype.slice;

var INCORRECT_SLICE = fails(function () {
  return !new ArrayBuffer$2(2).slice(1, undefined).byteLength;
});

// `ArrayBuffer.prototype.slice` method
// https://tc39.es/ecma262/#sec-arraybuffer.prototype.slice
_export({ target: 'ArrayBuffer', proto: true, unsafe: true, forced: INCORRECT_SLICE }, {
  slice: function slice(start, end) {
    if (nativeArrayBufferSlice !== undefined && end === undefined) {
      return nativeArrayBufferSlice.call(anObject(this), start); // FF fix
    }
    var length = anObject(this).byteLength;
    var first = toAbsoluteIndex(start, length);
    var fin = toAbsoluteIndex(end === undefined ? length : end, length);
    var result = new (speciesConstructor(this, ArrayBuffer$2))(toLength(fin - first));
    var viewSource = new DataView$1(this);
    var viewTarget = new DataView$1(result);
    var index = 0;
    while (first < fin) {
      viewTarget.setUint8(index++, viewSource.getUint8(first++));
    } return result;
  }
});

var defineProperty$7 = objectDefineProperty.f;





var Int8Array = global_1.Int8Array;
var Int8ArrayPrototype = Int8Array && Int8Array.prototype;
var Uint8ClampedArray = global_1.Uint8ClampedArray;
var Uint8ClampedArrayPrototype = Uint8ClampedArray && Uint8ClampedArray.prototype;
var TypedArray = Int8Array && objectGetPrototypeOf(Int8Array);
var TypedArrayPrototype = Int8ArrayPrototype && objectGetPrototypeOf(Int8ArrayPrototype);
var ObjectPrototype$3 = Object.prototype;
var isPrototypeOf = ObjectPrototype$3.isPrototypeOf;

var TO_STRING_TAG$4 = wellKnownSymbol('toStringTag');
var TYPED_ARRAY_TAG = uid('TYPED_ARRAY_TAG');
// Fixing native typed arrays in Opera Presto crashes the browser, see #595
var NATIVE_ARRAY_BUFFER_VIEWS = arrayBufferNative && !!objectSetPrototypeOf && classof(global_1.opera) !== 'Opera';
var TYPED_ARRAY_TAG_REQIRED = false;
var NAME$1;

var TypedArrayConstructorsList = {
  Int8Array: 1,
  Uint8Array: 1,
  Uint8ClampedArray: 1,
  Int16Array: 2,
  Uint16Array: 2,
  Int32Array: 4,
  Uint32Array: 4,
  Float32Array: 4,
  Float64Array: 8
};

var BigIntArrayConstructorsList = {
  BigInt64Array: 8,
  BigUint64Array: 8
};

var isView = function isView(it) {
  if (!isObject(it)) return false;
  var klass = classof(it);
  return klass === 'DataView'
    || has(TypedArrayConstructorsList, klass)
    || has(BigIntArrayConstructorsList, klass);
};

var isTypedArray = function (it) {
  if (!isObject(it)) return false;
  var klass = classof(it);
  return has(TypedArrayConstructorsList, klass)
    || has(BigIntArrayConstructorsList, klass);
};

var aTypedArray = function (it) {
  if (isTypedArray(it)) return it;
  throw TypeError('Target is not a typed array');
};

var aTypedArrayConstructor = function (C) {
  if (objectSetPrototypeOf) {
    if (isPrototypeOf.call(TypedArray, C)) return C;
  } else for (var ARRAY in TypedArrayConstructorsList) if (has(TypedArrayConstructorsList, NAME$1)) {
    var TypedArrayConstructor = global_1[ARRAY];
    if (TypedArrayConstructor && (C === TypedArrayConstructor || isPrototypeOf.call(TypedArrayConstructor, C))) {
      return C;
    }
  } throw TypeError('Target is not a typed array constructor');
};

var exportTypedArrayMethod = function (KEY, property, forced) {
  if (!descriptors) return;
  if (forced) for (var ARRAY in TypedArrayConstructorsList) {
    var TypedArrayConstructor = global_1[ARRAY];
    if (TypedArrayConstructor && has(TypedArrayConstructor.prototype, KEY)) {
      delete TypedArrayConstructor.prototype[KEY];
    }
  }
  if (!TypedArrayPrototype[KEY] || forced) {
    redefine(TypedArrayPrototype, KEY, forced ? property
      : NATIVE_ARRAY_BUFFER_VIEWS && Int8ArrayPrototype[KEY] || property);
  }
};

var exportTypedArrayStaticMethod = function (KEY, property, forced) {
  var ARRAY, TypedArrayConstructor;
  if (!descriptors) return;
  if (objectSetPrototypeOf) {
    if (forced) for (ARRAY in TypedArrayConstructorsList) {
      TypedArrayConstructor = global_1[ARRAY];
      if (TypedArrayConstructor && has(TypedArrayConstructor, KEY)) {
        delete TypedArrayConstructor[KEY];
      }
    }
    if (!TypedArray[KEY] || forced) {
      // V8 ~ Chrome 49-50 `%TypedArray%` methods are non-writable non-configurable
      try {
        return redefine(TypedArray, KEY, forced ? property : NATIVE_ARRAY_BUFFER_VIEWS && Int8Array[KEY] || property);
      } catch (error) { /* empty */ }
    } else return;
  }
  for (ARRAY in TypedArrayConstructorsList) {
    TypedArrayConstructor = global_1[ARRAY];
    if (TypedArrayConstructor && (!TypedArrayConstructor[KEY] || forced)) {
      redefine(TypedArrayConstructor, KEY, property);
    }
  }
};

for (NAME$1 in TypedArrayConstructorsList) {
  if (!global_1[NAME$1]) NATIVE_ARRAY_BUFFER_VIEWS = false;
}

// WebKit bug - typed arrays constructors prototype is Object.prototype
if (!NATIVE_ARRAY_BUFFER_VIEWS || typeof TypedArray != 'function' || TypedArray === Function.prototype) {
  // eslint-disable-next-line no-shadow -- safe
  TypedArray = function TypedArray() {
    throw TypeError('Incorrect invocation');
  };
  if (NATIVE_ARRAY_BUFFER_VIEWS) for (NAME$1 in TypedArrayConstructorsList) {
    if (global_1[NAME$1]) objectSetPrototypeOf(global_1[NAME$1], TypedArray);
  }
}

if (!NATIVE_ARRAY_BUFFER_VIEWS || !TypedArrayPrototype || TypedArrayPrototype === ObjectPrototype$3) {
  TypedArrayPrototype = TypedArray.prototype;
  if (NATIVE_ARRAY_BUFFER_VIEWS) for (NAME$1 in TypedArrayConstructorsList) {
    if (global_1[NAME$1]) objectSetPrototypeOf(global_1[NAME$1].prototype, TypedArrayPrototype);
  }
}

// WebKit bug - one more object in Uint8ClampedArray prototype chain
if (NATIVE_ARRAY_BUFFER_VIEWS && objectGetPrototypeOf(Uint8ClampedArrayPrototype) !== TypedArrayPrototype) {
  objectSetPrototypeOf(Uint8ClampedArrayPrototype, TypedArrayPrototype);
}

if (descriptors && !has(TypedArrayPrototype, TO_STRING_TAG$4)) {
  TYPED_ARRAY_TAG_REQIRED = true;
  defineProperty$7(TypedArrayPrototype, TO_STRING_TAG$4, { get: function () {
    return isObject(this) ? this[TYPED_ARRAY_TAG] : undefined;
  } });
  for (NAME$1 in TypedArrayConstructorsList) if (global_1[NAME$1]) {
    createNonEnumerableProperty(global_1[NAME$1], TYPED_ARRAY_TAG, NAME$1);
  }
}

var arrayBufferViewCore = {
  NATIVE_ARRAY_BUFFER_VIEWS: NATIVE_ARRAY_BUFFER_VIEWS,
  TYPED_ARRAY_TAG: TYPED_ARRAY_TAG_REQIRED && TYPED_ARRAY_TAG,
  aTypedArray: aTypedArray,
  aTypedArrayConstructor: aTypedArrayConstructor,
  exportTypedArrayMethod: exportTypedArrayMethod,
  exportTypedArrayStaticMethod: exportTypedArrayStaticMethod,
  isView: isView,
  isTypedArray: isTypedArray,
  TypedArray: TypedArray,
  TypedArrayPrototype: TypedArrayPrototype
};

var NATIVE_ARRAY_BUFFER_VIEWS$1 = arrayBufferViewCore.NATIVE_ARRAY_BUFFER_VIEWS;

// `ArrayBuffer.isView` method
// https://tc39.es/ecma262/#sec-arraybuffer.isview
_export({ target: 'ArrayBuffer', stat: true, forced: !NATIVE_ARRAY_BUFFER_VIEWS$1 }, {
  isView: arrayBufferViewCore.isView
});

var ITERATOR$6 = wellKnownSymbol('iterator');

var nativeUrl = !fails(function () {
  var url = new URL('b?a=1&b=2&c=3', 'http://a');
  var searchParams = url.searchParams;
  var result = '';
  url.pathname = 'c%20d';
  searchParams.forEach(function (value, key) {
    searchParams['delete']('b');
    result += key + value;
  });
  return (isPure && !url.toJSON)
    || !searchParams.sort
    || url.href !== 'http://a/c%20d?a=1&c=3'
    || searchParams.get('c') !== '3'
    || String(new URLSearchParams('?a=1')) !== 'a=1'
    || !searchParams[ITERATOR$6]
    // throws in Edge
    || new URL('https://a@b').username !== 'a'
    || new URLSearchParams(new URLSearchParams('a=b')).get('a') !== 'b'
    // not punycoded in Edge
    || new URL('http://тест').host !== 'xn--e1aybc'
    // not escaped in Chrome 62-
    || new URL('http://a#б').hash !== '#%D0%B1'
    // fails in Chrome 66-
    || result !== 'a1c3'
    // throws in Safari
    || new URL('http://x', undefined).host !== 'x';
});

// eslint-disable-next-line es/no-object-assign -- safe
var $assign = Object.assign;
// eslint-disable-next-line es/no-object-defineproperty -- required for testing
var defineProperty$8 = Object.defineProperty;

// `Object.assign` method
// https://tc39.es/ecma262/#sec-object.assign
var objectAssign = !$assign || fails(function () {
  // should have correct order of operations (Edge bug)
  if (descriptors && $assign({ b: 1 }, $assign(defineProperty$8({}, 'a', {
    enumerable: true,
    get: function () {
      defineProperty$8(this, 'b', {
        value: 3,
        enumerable: false
      });
    }
  }), { b: 2 })).b !== 1) return true;
  // should work with symbols and should have deterministic property order (V8 bug)
  var A = {};
  var B = {};
  // eslint-disable-next-line es/no-symbol -- safe
  var symbol = Symbol();
  var alphabet = 'abcdefghijklmnopqrst';
  A[symbol] = 7;
  alphabet.split('').forEach(function (chr) { B[chr] = chr; });
  return $assign({}, A)[symbol] != 7 || objectKeys($assign({}, B)).join('') != alphabet;
}) ? function assign(target, source) { // eslint-disable-line no-unused-vars -- required for `.length`
  var T = toObject(target);
  var argumentsLength = arguments.length;
  var index = 1;
  var getOwnPropertySymbols = objectGetOwnPropertySymbols.f;
  var propertyIsEnumerable = objectPropertyIsEnumerable.f;
  while (argumentsLength > index) {
    var S = indexedObject(arguments[index++]);
    var keys = getOwnPropertySymbols ? objectKeys(S).concat(getOwnPropertySymbols(S)) : objectKeys(S);
    var length = keys.length;
    var j = 0;
    var key;
    while (length > j) {
      key = keys[j++];
      if (!descriptors || propertyIsEnumerable.call(S, key)) T[key] = S[key];
    }
  } return T;
} : $assign;

// call something on iterator step with safe closing on error
var callWithSafeIterationClosing = function (iterator, fn, value, ENTRIES) {
  try {
    return ENTRIES ? fn(anObject(value)[0], value[1]) : fn(value);
  // 7.4.6 IteratorClose(iterator, completion)
  } catch (error) {
    iteratorClose(iterator);
    throw error;
  }
};

// `Array.from` method implementation
// https://tc39.es/ecma262/#sec-array.from
var arrayFrom = function from(arrayLike /* , mapfn = undefined, thisArg = undefined */) {
  var O = toObject(arrayLike);
  var C = typeof this == 'function' ? this : Array;
  var argumentsLength = arguments.length;
  var mapfn = argumentsLength > 1 ? arguments[1] : undefined;
  var mapping = mapfn !== undefined;
  var iteratorMethod = getIteratorMethod(O);
  var index = 0;
  var length, result, step, iterator, next, value;
  if (mapping) mapfn = functionBindContext(mapfn, argumentsLength > 2 ? arguments[2] : undefined, 2);
  // if the target is not iterable or it's an array with the default iterator - use a simple case
  if (iteratorMethod != undefined && !(C == Array && isArrayIteratorMethod(iteratorMethod))) {
    iterator = iteratorMethod.call(O);
    next = iterator.next;
    result = new C();
    for (;!(step = next.call(iterator)).done; index++) {
      value = mapping ? callWithSafeIterationClosing(iterator, mapfn, [step.value, index], true) : step.value;
      createProperty(result, index, value);
    }
  } else {
    length = toLength(O.length);
    result = new C(length);
    for (;length > index; index++) {
      value = mapping ? mapfn(O[index], index) : O[index];
      createProperty(result, index, value);
    }
  }
  result.length = index;
  return result;
};

// based on https://github.com/bestiejs/punycode.js/blob/master/punycode.js
var maxInt = 2147483647; // aka. 0x7FFFFFFF or 2^31-1
var base = 36;
var tMin = 1;
var tMax = 26;
var skew = 38;
var damp = 700;
var initialBias = 72;
var initialN = 128; // 0x80
var delimiter = '-'; // '\x2D'
var regexNonASCII = /[^\0-\u007E]/; // non-ASCII chars
var regexSeparators = /[.\u3002\uFF0E\uFF61]/g; // RFC 3490 separators
var OVERFLOW_ERROR = 'Overflow: input needs wider integers to process';
var baseMinusTMin = base - tMin;
var floor$3 = Math.floor;
var stringFromCharCode = String.fromCharCode;

/**
 * Creates an array containing the numeric code points of each Unicode
 * character in the string. While JavaScript uses UCS-2 internally,
 * this function will convert a pair of surrogate halves (each of which
 * UCS-2 exposes as separate characters) into a single code point,
 * matching UTF-16.
 */
var ucs2decode = function (string) {
  var output = [];
  var counter = 0;
  var length = string.length;
  while (counter < length) {
    var value = string.charCodeAt(counter++);
    if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
      // It's a high surrogate, and there is a next character.
      var extra = string.charCodeAt(counter++);
      if ((extra & 0xFC00) == 0xDC00) { // Low surrogate.
        output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
      } else {
        // It's an unmatched surrogate; only append this code unit, in case the
        // next code unit is the high surrogate of a surrogate pair.
        output.push(value);
        counter--;
      }
    } else {
      output.push(value);
    }
  }
  return output;
};

/**
 * Converts a digit/integer into a basic code point.
 */
var digitToBasic = function (digit) {
  //  0..25 map to ASCII a..z or A..Z
  // 26..35 map to ASCII 0..9
  return digit + 22 + 75 * (digit < 26);
};

/**
 * Bias adaptation function as per section 3.4 of RFC 3492.
 * https://tools.ietf.org/html/rfc3492#section-3.4
 */
var adapt = function (delta, numPoints, firstTime) {
  var k = 0;
  delta = firstTime ? floor$3(delta / damp) : delta >> 1;
  delta += floor$3(delta / numPoints);
  for (; delta > baseMinusTMin * tMax >> 1; k += base) {
    delta = floor$3(delta / baseMinusTMin);
  }
  return floor$3(k + (baseMinusTMin + 1) * delta / (delta + skew));
};

/**
 * Converts a string of Unicode symbols (e.g. a domain name label) to a
 * Punycode string of ASCII-only symbols.
 */
// eslint-disable-next-line max-statements -- TODO
var encode = function (input) {
  var output = [];

  // Convert the input in UCS-2 to an array of Unicode code points.
  input = ucs2decode(input);

  // Cache the length.
  var inputLength = input.length;

  // Initialize the state.
  var n = initialN;
  var delta = 0;
  var bias = initialBias;
  var i, currentValue;

  // Handle the basic code points.
  for (i = 0; i < input.length; i++) {
    currentValue = input[i];
    if (currentValue < 0x80) {
      output.push(stringFromCharCode(currentValue));
    }
  }

  var basicLength = output.length; // number of basic code points.
  var handledCPCount = basicLength; // number of code points that have been handled;

  // Finish the basic string with a delimiter unless it's empty.
  if (basicLength) {
    output.push(delimiter);
  }

  // Main encoding loop:
  while (handledCPCount < inputLength) {
    // All non-basic code points < n have been handled already. Find the next larger one:
    var m = maxInt;
    for (i = 0; i < input.length; i++) {
      currentValue = input[i];
      if (currentValue >= n && currentValue < m) {
        m = currentValue;
      }
    }

    // Increase `delta` enough to advance the decoder's <n,i> state to <m,0>, but guard against overflow.
    var handledCPCountPlusOne = handledCPCount + 1;
    if (m - n > floor$3((maxInt - delta) / handledCPCountPlusOne)) {
      throw RangeError(OVERFLOW_ERROR);
    }

    delta += (m - n) * handledCPCountPlusOne;
    n = m;

    for (i = 0; i < input.length; i++) {
      currentValue = input[i];
      if (currentValue < n && ++delta > maxInt) {
        throw RangeError(OVERFLOW_ERROR);
      }
      if (currentValue == n) {
        // Represent delta as a generalized variable-length integer.
        var q = delta;
        for (var k = base; /* no condition */; k += base) {
          var t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);
          if (q < t) break;
          var qMinusT = q - t;
          var baseMinusT = base - t;
          output.push(stringFromCharCode(digitToBasic(t + qMinusT % baseMinusT)));
          q = floor$3(qMinusT / baseMinusT);
        }

        output.push(stringFromCharCode(digitToBasic(q)));
        bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
        delta = 0;
        ++handledCPCount;
      }
    }

    ++delta;
    ++n;
  }
  return output.join('');
};

var stringPunycodeToAscii = function (input) {
  var encoded = [];
  var labels = input.toLowerCase().replace(regexSeparators, '\u002E').split('.');
  var i, label;
  for (i = 0; i < labels.length; i++) {
    label = labels[i];
    encoded.push(regexNonASCII.test(label) ? 'xn--' + encode(label) : label);
  }
  return encoded.join('.');
};

var getIterator = function (it) {
  var iteratorMethod = getIteratorMethod(it);
  if (typeof iteratorMethod != 'function') {
    throw TypeError(String(it) + ' is not iterable');
  } return anObject(iteratorMethod.call(it));
};

// TODO: in core-js@4, move /modules/ dependencies to public entries for better optimization by tools like `preset-env`





















var $fetch$1 = getBuiltIn('fetch');
var Headers = getBuiltIn('Headers');
var ITERATOR$7 = wellKnownSymbol('iterator');
var URL_SEARCH_PARAMS = 'URLSearchParams';
var URL_SEARCH_PARAMS_ITERATOR = URL_SEARCH_PARAMS + 'Iterator';
var setInternalState$6 = internalState.set;
var getInternalParamsState = internalState.getterFor(URL_SEARCH_PARAMS);
var getInternalIteratorState = internalState.getterFor(URL_SEARCH_PARAMS_ITERATOR);

var plus = /\+/g;
var sequences = Array(4);

var percentSequence = function (bytes) {
  return sequences[bytes - 1] || (sequences[bytes - 1] = RegExp('((?:%[\\da-f]{2}){' + bytes + '})', 'gi'));
};

var percentDecode = function (sequence) {
  try {
    return decodeURIComponent(sequence);
  } catch (error) {
    return sequence;
  }
};

var deserialize = function (it) {
  var result = it.replace(plus, ' ');
  var bytes = 4;
  try {
    return decodeURIComponent(result);
  } catch (error) {
    while (bytes) {
      result = result.replace(percentSequence(bytes--), percentDecode);
    }
    return result;
  }
};

var find = /[!'()~]|%20/g;

var replace$1 = {
  '!': '%21',
  "'": '%27',
  '(': '%28',
  ')': '%29',
  '~': '%7E',
  '%20': '+'
};

var replacer = function (match) {
  return replace$1[match];
};

var serialize = function (it) {
  return encodeURIComponent(it).replace(find, replacer);
};

var parseSearchParams = function (result, query) {
  if (query) {
    var attributes = query.split('&');
    var index = 0;
    var attribute, entry;
    while (index < attributes.length) {
      attribute = attributes[index++];
      if (attribute.length) {
        entry = attribute.split('=');
        result.push({
          key: deserialize(entry.shift()),
          value: deserialize(entry.join('='))
        });
      }
    }
  }
};

var updateSearchParams = function (query) {
  this.entries.length = 0;
  parseSearchParams(this.entries, query);
};

var validateArgumentsLength = function (passed, required) {
  if (passed < required) throw TypeError('Not enough arguments');
};

var URLSearchParamsIterator = createIteratorConstructor(function Iterator(params, kind) {
  setInternalState$6(this, {
    type: URL_SEARCH_PARAMS_ITERATOR,
    iterator: getIterator(getInternalParamsState(params).entries),
    kind: kind
  });
}, 'Iterator', function next() {
  var state = getInternalIteratorState(this);
  var kind = state.kind;
  var step = state.iterator.next();
  var entry = step.value;
  if (!step.done) {
    step.value = kind === 'keys' ? entry.key : kind === 'values' ? entry.value : [entry.key, entry.value];
  } return step;
});

// `URLSearchParams` constructor
// https://url.spec.whatwg.org/#interface-urlsearchparams
var URLSearchParamsConstructor = function URLSearchParams(/* init */) {
  anInstance(this, URLSearchParamsConstructor, URL_SEARCH_PARAMS);
  var init = arguments.length > 0 ? arguments[0] : undefined;
  var that = this;
  var entries = [];
  var iteratorMethod, iterator, next, step, entryIterator, entryNext, first, second, key;

  setInternalState$6(that, {
    type: URL_SEARCH_PARAMS,
    entries: entries,
    updateURL: function () { /* empty */ },
    updateSearchParams: updateSearchParams
  });

  if (init !== undefined) {
    if (isObject(init)) {
      iteratorMethod = getIteratorMethod(init);
      if (typeof iteratorMethod === 'function') {
        iterator = iteratorMethod.call(init);
        next = iterator.next;
        while (!(step = next.call(iterator)).done) {
          entryIterator = getIterator(anObject(step.value));
          entryNext = entryIterator.next;
          if (
            (first = entryNext.call(entryIterator)).done ||
            (second = entryNext.call(entryIterator)).done ||
            !entryNext.call(entryIterator).done
          ) throw TypeError('Expected sequence with length 2');
          entries.push({ key: first.value + '', value: second.value + '' });
        }
      } else for (key in init) if (has(init, key)) entries.push({ key: key, value: init[key] + '' });
    } else {
      parseSearchParams(entries, typeof init === 'string' ? init.charAt(0) === '?' ? init.slice(1) : init : init + '');
    }
  }
};

var URLSearchParamsPrototype = URLSearchParamsConstructor.prototype;

redefineAll(URLSearchParamsPrototype, {
  // `URLSearchParams.prototype.append` method
  // https://url.spec.whatwg.org/#dom-urlsearchparams-append
  append: function append(name, value) {
    validateArgumentsLength(arguments.length, 2);
    var state = getInternalParamsState(this);
    state.entries.push({ key: name + '', value: value + '' });
    state.updateURL();
  },
  // `URLSearchParams.prototype.delete` method
  // https://url.spec.whatwg.org/#dom-urlsearchparams-delete
  'delete': function (name) {
    validateArgumentsLength(arguments.length, 1);
    var state = getInternalParamsState(this);
    var entries = state.entries;
    var key = name + '';
    var index = 0;
    while (index < entries.length) {
      if (entries[index].key === key) entries.splice(index, 1);
      else index++;
    }
    state.updateURL();
  },
  // `URLSearchParams.prototype.get` method
  // https://url.spec.whatwg.org/#dom-urlsearchparams-get
  get: function get(name) {
    validateArgumentsLength(arguments.length, 1);
    var entries = getInternalParamsState(this).entries;
    var key = name + '';
    var index = 0;
    for (; index < entries.length; index++) {
      if (entries[index].key === key) return entries[index].value;
    }
    return null;
  },
  // `URLSearchParams.prototype.getAll` method
  // https://url.spec.whatwg.org/#dom-urlsearchparams-getall
  getAll: function getAll(name) {
    validateArgumentsLength(arguments.length, 1);
    var entries = getInternalParamsState(this).entries;
    var key = name + '';
    var result = [];
    var index = 0;
    for (; index < entries.length; index++) {
      if (entries[index].key === key) result.push(entries[index].value);
    }
    return result;
  },
  // `URLSearchParams.prototype.has` method
  // https://url.spec.whatwg.org/#dom-urlsearchparams-has
  has: function has(name) {
    validateArgumentsLength(arguments.length, 1);
    var entries = getInternalParamsState(this).entries;
    var key = name + '';
    var index = 0;
    while (index < entries.length) {
      if (entries[index++].key === key) return true;
    }
    return false;
  },
  // `URLSearchParams.prototype.set` method
  // https://url.spec.whatwg.org/#dom-urlsearchparams-set
  set: function set(name, value) {
    validateArgumentsLength(arguments.length, 1);
    var state = getInternalParamsState(this);
    var entries = state.entries;
    var found = false;
    var key = name + '';
    var val = value + '';
    var index = 0;
    var entry;
    for (; index < entries.length; index++) {
      entry = entries[index];
      if (entry.key === key) {
        if (found) entries.splice(index--, 1);
        else {
          found = true;
          entry.value = val;
        }
      }
    }
    if (!found) entries.push({ key: key, value: val });
    state.updateURL();
  },
  // `URLSearchParams.prototype.sort` method
  // https://url.spec.whatwg.org/#dom-urlsearchparams-sort
  sort: function sort() {
    var state = getInternalParamsState(this);
    var entries = state.entries;
    // Array#sort is not stable in some engines
    var slice = entries.slice();
    var entry, entriesIndex, sliceIndex;
    entries.length = 0;
    for (sliceIndex = 0; sliceIndex < slice.length; sliceIndex++) {
      entry = slice[sliceIndex];
      for (entriesIndex = 0; entriesIndex < sliceIndex; entriesIndex++) {
        if (entries[entriesIndex].key > entry.key) {
          entries.splice(entriesIndex, 0, entry);
          break;
        }
      }
      if (entriesIndex === sliceIndex) entries.push(entry);
    }
    state.updateURL();
  },
  // `URLSearchParams.prototype.forEach` method
  forEach: function forEach(callback /* , thisArg */) {
    var entries = getInternalParamsState(this).entries;
    var boundFunction = functionBindContext(callback, arguments.length > 1 ? arguments[1] : undefined, 3);
    var index = 0;
    var entry;
    while (index < entries.length) {
      entry = entries[index++];
      boundFunction(entry.value, entry.key, this);
    }
  },
  // `URLSearchParams.prototype.keys` method
  keys: function keys() {
    return new URLSearchParamsIterator(this, 'keys');
  },
  // `URLSearchParams.prototype.values` method
  values: function values() {
    return new URLSearchParamsIterator(this, 'values');
  },
  // `URLSearchParams.prototype.entries` method
  entries: function entries() {
    return new URLSearchParamsIterator(this, 'entries');
  }
}, { enumerable: true });

// `URLSearchParams.prototype[@@iterator]` method
redefine(URLSearchParamsPrototype, ITERATOR$7, URLSearchParamsPrototype.entries);

// `URLSearchParams.prototype.toString` method
// https://url.spec.whatwg.org/#urlsearchparams-stringification-behavior
redefine(URLSearchParamsPrototype, 'toString', function toString() {
  var entries = getInternalParamsState(this).entries;
  var result = [];
  var index = 0;
  var entry;
  while (index < entries.length) {
    entry = entries[index++];
    result.push(serialize(entry.key) + '=' + serialize(entry.value));
  } return result.join('&');
}, { enumerable: true });

setToStringTag(URLSearchParamsConstructor, URL_SEARCH_PARAMS);

_export({ global: true, forced: !nativeUrl }, {
  URLSearchParams: URLSearchParamsConstructor
});

// Wrap `fetch` for correct work with polyfilled `URLSearchParams`
// https://github.com/zloirock/core-js/issues/674
if (!nativeUrl && typeof $fetch$1 == 'function' && typeof Headers == 'function') {
  _export({ global: true, enumerable: true, forced: true }, {
    fetch: function fetch(input /* , init */) {
      var args = [input];
      var init, body, headers;
      if (arguments.length > 1) {
        init = arguments[1];
        if (isObject(init)) {
          body = init.body;
          if (classof(body) === URL_SEARCH_PARAMS) {
            headers = init.headers ? new Headers(init.headers) : new Headers();
            if (!headers.has('content-type')) {
              headers.set('content-type', 'application/x-www-form-urlencoded;charset=UTF-8');
            }
            init = objectCreate(init, {
              body: createPropertyDescriptor(0, String(body)),
              headers: createPropertyDescriptor(0, headers)
            });
          }
        }
        args.push(init);
      } return $fetch$1.apply(this, args);
    }
  });
}

var web_urlSearchParams = {
  URLSearchParams: URLSearchParamsConstructor,
  getState: getInternalParamsState
};

// TODO: in core-js@4, move /modules/ dependencies to public entries for better optimization by tools like `preset-env`











var codeAt = stringMultibyte.codeAt;





var NativeURL = global_1.URL;
var URLSearchParams$1 = web_urlSearchParams.URLSearchParams;
var getInternalSearchParamsState = web_urlSearchParams.getState;
var setInternalState$7 = internalState.set;
var getInternalURLState = internalState.getterFor('URL');
var floor$4 = Math.floor;
var pow$1 = Math.pow;

var INVALID_AUTHORITY = 'Invalid authority';
var INVALID_SCHEME = 'Invalid scheme';
var INVALID_HOST = 'Invalid host';
var INVALID_PORT = 'Invalid port';

var ALPHA = /[A-Za-z]/;
var ALPHANUMERIC = /[\d+-.A-Za-z]/;
var DIGIT = /\d/;
var HEX_START = /^(0x|0X)/;
var OCT = /^[0-7]+$/;
var DEC = /^\d+$/;
var HEX = /^[\dA-Fa-f]+$/;
/* eslint-disable no-control-regex -- safe */
var FORBIDDEN_HOST_CODE_POINT = /[\u0000\t\u000A\u000D #%/:?@[\\]]/;
var FORBIDDEN_HOST_CODE_POINT_EXCLUDING_PERCENT = /[\u0000\t\u000A\u000D #/:?@[\\]]/;
var LEADING_AND_TRAILING_C0_CONTROL_OR_SPACE = /^[\u0000-\u001F ]+|[\u0000-\u001F ]+$/g;
var TAB_AND_NEW_LINE = /[\t\u000A\u000D]/g;
/* eslint-enable no-control-regex -- safe */
var EOF;

var parseHost = function (url, input) {
  var result, codePoints, index;
  if (input.charAt(0) == '[') {
    if (input.charAt(input.length - 1) != ']') return INVALID_HOST;
    result = parseIPv6(input.slice(1, -1));
    if (!result) return INVALID_HOST;
    url.host = result;
  // opaque host
  } else if (!isSpecial(url)) {
    if (FORBIDDEN_HOST_CODE_POINT_EXCLUDING_PERCENT.test(input)) return INVALID_HOST;
    result = '';
    codePoints = arrayFrom(input);
    for (index = 0; index < codePoints.length; index++) {
      result += percentEncode(codePoints[index], C0ControlPercentEncodeSet);
    }
    url.host = result;
  } else {
    input = stringPunycodeToAscii(input);
    if (FORBIDDEN_HOST_CODE_POINT.test(input)) return INVALID_HOST;
    result = parseIPv4(input);
    if (result === null) return INVALID_HOST;
    url.host = result;
  }
};

var parseIPv4 = function (input) {
  var parts = input.split('.');
  var partsLength, numbers, index, part, radix, number, ipv4;
  if (parts.length && parts[parts.length - 1] == '') {
    parts.pop();
  }
  partsLength = parts.length;
  if (partsLength > 4) return input;
  numbers = [];
  for (index = 0; index < partsLength; index++) {
    part = parts[index];
    if (part == '') return input;
    radix = 10;
    if (part.length > 1 && part.charAt(0) == '0') {
      radix = HEX_START.test(part) ? 16 : 8;
      part = part.slice(radix == 8 ? 1 : 2);
    }
    if (part === '') {
      number = 0;
    } else {
      if (!(radix == 10 ? DEC : radix == 8 ? OCT : HEX).test(part)) return input;
      number = parseInt(part, radix);
    }
    numbers.push(number);
  }
  for (index = 0; index < partsLength; index++) {
    number = numbers[index];
    if (index == partsLength - 1) {
      if (number >= pow$1(256, 5 - partsLength)) return null;
    } else if (number > 255) return null;
  }
  ipv4 = numbers.pop();
  for (index = 0; index < numbers.length; index++) {
    ipv4 += numbers[index] * pow$1(256, 3 - index);
  }
  return ipv4;
};

// eslint-disable-next-line max-statements -- TODO
var parseIPv6 = function (input) {
  var address = [0, 0, 0, 0, 0, 0, 0, 0];
  var pieceIndex = 0;
  var compress = null;
  var pointer = 0;
  var value, length, numbersSeen, ipv4Piece, number, swaps, swap;

  var char = function () {
    return input.charAt(pointer);
  };

  if (char() == ':') {
    if (input.charAt(1) != ':') return;
    pointer += 2;
    pieceIndex++;
    compress = pieceIndex;
  }
  while (char()) {
    if (pieceIndex == 8) return;
    if (char() == ':') {
      if (compress !== null) return;
      pointer++;
      pieceIndex++;
      compress = pieceIndex;
      continue;
    }
    value = length = 0;
    while (length < 4 && HEX.test(char())) {
      value = value * 16 + parseInt(char(), 16);
      pointer++;
      length++;
    }
    if (char() == '.') {
      if (length == 0) return;
      pointer -= length;
      if (pieceIndex > 6) return;
      numbersSeen = 0;
      while (char()) {
        ipv4Piece = null;
        if (numbersSeen > 0) {
          if (char() == '.' && numbersSeen < 4) pointer++;
          else return;
        }
        if (!DIGIT.test(char())) return;
        while (DIGIT.test(char())) {
          number = parseInt(char(), 10);
          if (ipv4Piece === null) ipv4Piece = number;
          else if (ipv4Piece == 0) return;
          else ipv4Piece = ipv4Piece * 10 + number;
          if (ipv4Piece > 255) return;
          pointer++;
        }
        address[pieceIndex] = address[pieceIndex] * 256 + ipv4Piece;
        numbersSeen++;
        if (numbersSeen == 2 || numbersSeen == 4) pieceIndex++;
      }
      if (numbersSeen != 4) return;
      break;
    } else if (char() == ':') {
      pointer++;
      if (!char()) return;
    } else if (char()) return;
    address[pieceIndex++] = value;
  }
  if (compress !== null) {
    swaps = pieceIndex - compress;
    pieceIndex = 7;
    while (pieceIndex != 0 && swaps > 0) {
      swap = address[pieceIndex];
      address[pieceIndex--] = address[compress + swaps - 1];
      address[compress + --swaps] = swap;
    }
  } else if (pieceIndex != 8) return;
  return address;
};

var findLongestZeroSequence = function (ipv6) {
  var maxIndex = null;
  var maxLength = 1;
  var currStart = null;
  var currLength = 0;
  var index = 0;
  for (; index < 8; index++) {
    if (ipv6[index] !== 0) {
      if (currLength > maxLength) {
        maxIndex = currStart;
        maxLength = currLength;
      }
      currStart = null;
      currLength = 0;
    } else {
      if (currStart === null) currStart = index;
      ++currLength;
    }
  }
  if (currLength > maxLength) {
    maxIndex = currStart;
    maxLength = currLength;
  }
  return maxIndex;
};

var serializeHost = function (host) {
  var result, index, compress, ignore0;
  // ipv4
  if (typeof host == 'number') {
    result = [];
    for (index = 0; index < 4; index++) {
      result.unshift(host % 256);
      host = floor$4(host / 256);
    } return result.join('.');
  // ipv6
  } else if (typeof host == 'object') {
    result = '';
    compress = findLongestZeroSequence(host);
    for (index = 0; index < 8; index++) {
      if (ignore0 && host[index] === 0) continue;
      if (ignore0) ignore0 = false;
      if (compress === index) {
        result += index ? ':' : '::';
        ignore0 = true;
      } else {
        result += host[index].toString(16);
        if (index < 7) result += ':';
      }
    }
    return '[' + result + ']';
  } return host;
};

var C0ControlPercentEncodeSet = {};
var fragmentPercentEncodeSet = objectAssign({}, C0ControlPercentEncodeSet, {
  ' ': 1, '"': 1, '<': 1, '>': 1, '`': 1
});
var pathPercentEncodeSet = objectAssign({}, fragmentPercentEncodeSet, {
  '#': 1, '?': 1, '{': 1, '}': 1
});
var userinfoPercentEncodeSet = objectAssign({}, pathPercentEncodeSet, {
  '/': 1, ':': 1, ';': 1, '=': 1, '@': 1, '[': 1, '\\': 1, ']': 1, '^': 1, '|': 1
});

var percentEncode = function (char, set) {
  var code = codeAt(char, 0);
  return code > 0x20 && code < 0x7F && !has(set, char) ? char : encodeURIComponent(char);
};

var specialSchemes = {
  ftp: 21,
  file: null,
  http: 80,
  https: 443,
  ws: 80,
  wss: 443
};

var isSpecial = function (url) {
  return has(specialSchemes, url.scheme);
};

var includesCredentials = function (url) {
  return url.username != '' || url.password != '';
};

var cannotHaveUsernamePasswordPort = function (url) {
  return !url.host || url.cannotBeABaseURL || url.scheme == 'file';
};

var isWindowsDriveLetter = function (string, normalized) {
  var second;
  return string.length == 2 && ALPHA.test(string.charAt(0))
    && ((second = string.charAt(1)) == ':' || (!normalized && second == '|'));
};

var startsWithWindowsDriveLetter = function (string) {
  var third;
  return string.length > 1 && isWindowsDriveLetter(string.slice(0, 2)) && (
    string.length == 2 ||
    ((third = string.charAt(2)) === '/' || third === '\\' || third === '?' || third === '#')
  );
};

var shortenURLsPath = function (url) {
  var path = url.path;
  var pathSize = path.length;
  if (pathSize && (url.scheme != 'file' || pathSize != 1 || !isWindowsDriveLetter(path[0], true))) {
    path.pop();
  }
};

var isSingleDot = function (segment) {
  return segment === '.' || segment.toLowerCase() === '%2e';
};

var isDoubleDot = function (segment) {
  segment = segment.toLowerCase();
  return segment === '..' || segment === '%2e.' || segment === '.%2e' || segment === '%2e%2e';
};

// States:
var SCHEME_START = {};
var SCHEME = {};
var NO_SCHEME = {};
var SPECIAL_RELATIVE_OR_AUTHORITY = {};
var PATH_OR_AUTHORITY = {};
var RELATIVE = {};
var RELATIVE_SLASH = {};
var SPECIAL_AUTHORITY_SLASHES = {};
var SPECIAL_AUTHORITY_IGNORE_SLASHES = {};
var AUTHORITY = {};
var HOST = {};
var HOSTNAME = {};
var PORT = {};
var FILE = {};
var FILE_SLASH = {};
var FILE_HOST = {};
var PATH_START = {};
var PATH = {};
var CANNOT_BE_A_BASE_URL_PATH = {};
var QUERY = {};
var FRAGMENT = {};

// eslint-disable-next-line max-statements -- TODO
var parseURL = function (url, input, stateOverride, base) {
  var state = stateOverride || SCHEME_START;
  var pointer = 0;
  var buffer = '';
  var seenAt = false;
  var seenBracket = false;
  var seenPasswordToken = false;
  var codePoints, char, bufferCodePoints, failure;

  if (!stateOverride) {
    url.scheme = '';
    url.username = '';
    url.password = '';
    url.host = null;
    url.port = null;
    url.path = [];
    url.query = null;
    url.fragment = null;
    url.cannotBeABaseURL = false;
    input = input.replace(LEADING_AND_TRAILING_C0_CONTROL_OR_SPACE, '');
  }

  input = input.replace(TAB_AND_NEW_LINE, '');

  codePoints = arrayFrom(input);

  while (pointer <= codePoints.length) {
    char = codePoints[pointer];
    switch (state) {
      case SCHEME_START:
        if (char && ALPHA.test(char)) {
          buffer += char.toLowerCase();
          state = SCHEME;
        } else if (!stateOverride) {
          state = NO_SCHEME;
          continue;
        } else return INVALID_SCHEME;
        break;

      case SCHEME:
        if (char && (ALPHANUMERIC.test(char) || char == '+' || char == '-' || char == '.')) {
          buffer += char.toLowerCase();
        } else if (char == ':') {
          if (stateOverride && (
            (isSpecial(url) != has(specialSchemes, buffer)) ||
            (buffer == 'file' && (includesCredentials(url) || url.port !== null)) ||
            (url.scheme == 'file' && !url.host)
          )) return;
          url.scheme = buffer;
          if (stateOverride) {
            if (isSpecial(url) && specialSchemes[url.scheme] == url.port) url.port = null;
            return;
          }
          buffer = '';
          if (url.scheme == 'file') {
            state = FILE;
          } else if (isSpecial(url) && base && base.scheme == url.scheme) {
            state = SPECIAL_RELATIVE_OR_AUTHORITY;
          } else if (isSpecial(url)) {
            state = SPECIAL_AUTHORITY_SLASHES;
          } else if (codePoints[pointer + 1] == '/') {
            state = PATH_OR_AUTHORITY;
            pointer++;
          } else {
            url.cannotBeABaseURL = true;
            url.path.push('');
            state = CANNOT_BE_A_BASE_URL_PATH;
          }
        } else if (!stateOverride) {
          buffer = '';
          state = NO_SCHEME;
          pointer = 0;
          continue;
        } else return INVALID_SCHEME;
        break;

      case NO_SCHEME:
        if (!base || (base.cannotBeABaseURL && char != '#')) return INVALID_SCHEME;
        if (base.cannotBeABaseURL && char == '#') {
          url.scheme = base.scheme;
          url.path = base.path.slice();
          url.query = base.query;
          url.fragment = '';
          url.cannotBeABaseURL = true;
          state = FRAGMENT;
          break;
        }
        state = base.scheme == 'file' ? FILE : RELATIVE;
        continue;

      case SPECIAL_RELATIVE_OR_AUTHORITY:
        if (char == '/' && codePoints[pointer + 1] == '/') {
          state = SPECIAL_AUTHORITY_IGNORE_SLASHES;
          pointer++;
        } else {
          state = RELATIVE;
          continue;
        } break;

      case PATH_OR_AUTHORITY:
        if (char == '/') {
          state = AUTHORITY;
          break;
        } else {
          state = PATH;
          continue;
        }

      case RELATIVE:
        url.scheme = base.scheme;
        if (char == EOF) {
          url.username = base.username;
          url.password = base.password;
          url.host = base.host;
          url.port = base.port;
          url.path = base.path.slice();
          url.query = base.query;
        } else if (char == '/' || (char == '\\' && isSpecial(url))) {
          state = RELATIVE_SLASH;
        } else if (char == '?') {
          url.username = base.username;
          url.password = base.password;
          url.host = base.host;
          url.port = base.port;
          url.path = base.path.slice();
          url.query = '';
          state = QUERY;
        } else if (char == '#') {
          url.username = base.username;
          url.password = base.password;
          url.host = base.host;
          url.port = base.port;
          url.path = base.path.slice();
          url.query = base.query;
          url.fragment = '';
          state = FRAGMENT;
        } else {
          url.username = base.username;
          url.password = base.password;
          url.host = base.host;
          url.port = base.port;
          url.path = base.path.slice();
          url.path.pop();
          state = PATH;
          continue;
        } break;

      case RELATIVE_SLASH:
        if (isSpecial(url) && (char == '/' || char == '\\')) {
          state = SPECIAL_AUTHORITY_IGNORE_SLASHES;
        } else if (char == '/') {
          state = AUTHORITY;
        } else {
          url.username = base.username;
          url.password = base.password;
          url.host = base.host;
          url.port = base.port;
          state = PATH;
          continue;
        } break;

      case SPECIAL_AUTHORITY_SLASHES:
        state = SPECIAL_AUTHORITY_IGNORE_SLASHES;
        if (char != '/' || buffer.charAt(pointer + 1) != '/') continue;
        pointer++;
        break;

      case SPECIAL_AUTHORITY_IGNORE_SLASHES:
        if (char != '/' && char != '\\') {
          state = AUTHORITY;
          continue;
        } break;

      case AUTHORITY:
        if (char == '@') {
          if (seenAt) buffer = '%40' + buffer;
          seenAt = true;
          bufferCodePoints = arrayFrom(buffer);
          for (var i = 0; i < bufferCodePoints.length; i++) {
            var codePoint = bufferCodePoints[i];
            if (codePoint == ':' && !seenPasswordToken) {
              seenPasswordToken = true;
              continue;
            }
            var encodedCodePoints = percentEncode(codePoint, userinfoPercentEncodeSet);
            if (seenPasswordToken) url.password += encodedCodePoints;
            else url.username += encodedCodePoints;
          }
          buffer = '';
        } else if (
          char == EOF || char == '/' || char == '?' || char == '#' ||
          (char == '\\' && isSpecial(url))
        ) {
          if (seenAt && buffer == '') return INVALID_AUTHORITY;
          pointer -= arrayFrom(buffer).length + 1;
          buffer = '';
          state = HOST;
        } else buffer += char;
        break;

      case HOST:
      case HOSTNAME:
        if (stateOverride && url.scheme == 'file') {
          state = FILE_HOST;
          continue;
        } else if (char == ':' && !seenBracket) {
          if (buffer == '') return INVALID_HOST;
          failure = parseHost(url, buffer);
          if (failure) return failure;
          buffer = '';
          state = PORT;
          if (stateOverride == HOSTNAME) return;
        } else if (
          char == EOF || char == '/' || char == '?' || char == '#' ||
          (char == '\\' && isSpecial(url))
        ) {
          if (isSpecial(url) && buffer == '') return INVALID_HOST;
          if (stateOverride && buffer == '' && (includesCredentials(url) || url.port !== null)) return;
          failure = parseHost(url, buffer);
          if (failure) return failure;
          buffer = '';
          state = PATH_START;
          if (stateOverride) return;
          continue;
        } else {
          if (char == '[') seenBracket = true;
          else if (char == ']') seenBracket = false;
          buffer += char;
        } break;

      case PORT:
        if (DIGIT.test(char)) {
          buffer += char;
        } else if (
          char == EOF || char == '/' || char == '?' || char == '#' ||
          (char == '\\' && isSpecial(url)) ||
          stateOverride
        ) {
          if (buffer != '') {
            var port = parseInt(buffer, 10);
            if (port > 0xFFFF) return INVALID_PORT;
            url.port = (isSpecial(url) && port === specialSchemes[url.scheme]) ? null : port;
            buffer = '';
          }
          if (stateOverride) return;
          state = PATH_START;
          continue;
        } else return INVALID_PORT;
        break;

      case FILE:
        url.scheme = 'file';
        if (char == '/' || char == '\\') state = FILE_SLASH;
        else if (base && base.scheme == 'file') {
          if (char == EOF) {
            url.host = base.host;
            url.path = base.path.slice();
            url.query = base.query;
          } else if (char == '?') {
            url.host = base.host;
            url.path = base.path.slice();
            url.query = '';
            state = QUERY;
          } else if (char == '#') {
            url.host = base.host;
            url.path = base.path.slice();
            url.query = base.query;
            url.fragment = '';
            state = FRAGMENT;
          } else {
            if (!startsWithWindowsDriveLetter(codePoints.slice(pointer).join(''))) {
              url.host = base.host;
              url.path = base.path.slice();
              shortenURLsPath(url);
            }
            state = PATH;
            continue;
          }
        } else {
          state = PATH;
          continue;
        } break;

      case FILE_SLASH:
        if (char == '/' || char == '\\') {
          state = FILE_HOST;
          break;
        }
        if (base && base.scheme == 'file' && !startsWithWindowsDriveLetter(codePoints.slice(pointer).join(''))) {
          if (isWindowsDriveLetter(base.path[0], true)) url.path.push(base.path[0]);
          else url.host = base.host;
        }
        state = PATH;
        continue;

      case FILE_HOST:
        if (char == EOF || char == '/' || char == '\\' || char == '?' || char == '#') {
          if (!stateOverride && isWindowsDriveLetter(buffer)) {
            state = PATH;
          } else if (buffer == '') {
            url.host = '';
            if (stateOverride) return;
            state = PATH_START;
          } else {
            failure = parseHost(url, buffer);
            if (failure) return failure;
            if (url.host == 'localhost') url.host = '';
            if (stateOverride) return;
            buffer = '';
            state = PATH_START;
          } continue;
        } else buffer += char;
        break;

      case PATH_START:
        if (isSpecial(url)) {
          state = PATH;
          if (char != '/' && char != '\\') continue;
        } else if (!stateOverride && char == '?') {
          url.query = '';
          state = QUERY;
        } else if (!stateOverride && char == '#') {
          url.fragment = '';
          state = FRAGMENT;
        } else if (char != EOF) {
          state = PATH;
          if (char != '/') continue;
        } break;

      case PATH:
        if (
          char == EOF || char == '/' ||
          (char == '\\' && isSpecial(url)) ||
          (!stateOverride && (char == '?' || char == '#'))
        ) {
          if (isDoubleDot(buffer)) {
            shortenURLsPath(url);
            if (char != '/' && !(char == '\\' && isSpecial(url))) {
              url.path.push('');
            }
          } else if (isSingleDot(buffer)) {
            if (char != '/' && !(char == '\\' && isSpecial(url))) {
              url.path.push('');
            }
          } else {
            if (url.scheme == 'file' && !url.path.length && isWindowsDriveLetter(buffer)) {
              if (url.host) url.host = '';
              buffer = buffer.charAt(0) + ':'; // normalize windows drive letter
            }
            url.path.push(buffer);
          }
          buffer = '';
          if (url.scheme == 'file' && (char == EOF || char == '?' || char == '#')) {
            while (url.path.length > 1 && url.path[0] === '') {
              url.path.shift();
            }
          }
          if (char == '?') {
            url.query = '';
            state = QUERY;
          } else if (char == '#') {
            url.fragment = '';
            state = FRAGMENT;
          }
        } else {
          buffer += percentEncode(char, pathPercentEncodeSet);
        } break;

      case CANNOT_BE_A_BASE_URL_PATH:
        if (char == '?') {
          url.query = '';
          state = QUERY;
        } else if (char == '#') {
          url.fragment = '';
          state = FRAGMENT;
        } else if (char != EOF) {
          url.path[0] += percentEncode(char, C0ControlPercentEncodeSet);
        } break;

      case QUERY:
        if (!stateOverride && char == '#') {
          url.fragment = '';
          state = FRAGMENT;
        } else if (char != EOF) {
          if (char == "'" && isSpecial(url)) url.query += '%27';
          else if (char == '#') url.query += '%23';
          else url.query += percentEncode(char, C0ControlPercentEncodeSet);
        } break;

      case FRAGMENT:
        if (char != EOF) url.fragment += percentEncode(char, fragmentPercentEncodeSet);
        break;
    }

    pointer++;
  }
};

// `URL` constructor
// https://url.spec.whatwg.org/#url-class
var URLConstructor = function URL(url /* , base */) {
  var that = anInstance(this, URLConstructor, 'URL');
  var base = arguments.length > 1 ? arguments[1] : undefined;
  var urlString = String(url);
  var state = setInternalState$7(that, { type: 'URL' });
  var baseState, failure;
  if (base !== undefined) {
    if (base instanceof URLConstructor) baseState = getInternalURLState(base);
    else {
      failure = parseURL(baseState = {}, String(base));
      if (failure) throw TypeError(failure);
    }
  }
  failure = parseURL(state, urlString, null, baseState);
  if (failure) throw TypeError(failure);
  var searchParams = state.searchParams = new URLSearchParams$1();
  var searchParamsState = getInternalSearchParamsState(searchParams);
  searchParamsState.updateSearchParams(state.query);
  searchParamsState.updateURL = function () {
    state.query = String(searchParams) || null;
  };
  if (!descriptors) {
    that.href = serializeURL.call(that);
    that.origin = getOrigin.call(that);
    that.protocol = getProtocol.call(that);
    that.username = getUsername.call(that);
    that.password = getPassword.call(that);
    that.host = getHost.call(that);
    that.hostname = getHostname.call(that);
    that.port = getPort.call(that);
    that.pathname = getPathname.call(that);
    that.search = getSearch.call(that);
    that.searchParams = getSearchParams.call(that);
    that.hash = getHash.call(that);
  }
};

var URLPrototype = URLConstructor.prototype;

var serializeURL = function () {
  var url = getInternalURLState(this);
  var scheme = url.scheme;
  var username = url.username;
  var password = url.password;
  var host = url.host;
  var port = url.port;
  var path = url.path;
  var query = url.query;
  var fragment = url.fragment;
  var output = scheme + ':';
  if (host !== null) {
    output += '//';
    if (includesCredentials(url)) {
      output += username + (password ? ':' + password : '') + '@';
    }
    output += serializeHost(host);
    if (port !== null) output += ':' + port;
  } else if (scheme == 'file') output += '//';
  output += url.cannotBeABaseURL ? path[0] : path.length ? '/' + path.join('/') : '';
  if (query !== null) output += '?' + query;
  if (fragment !== null) output += '#' + fragment;
  return output;
};

var getOrigin = function () {
  var url = getInternalURLState(this);
  var scheme = url.scheme;
  var port = url.port;
  if (scheme == 'blob') try {
    return new URLConstructor(scheme.path[0]).origin;
  } catch (error) {
    return 'null';
  }
  if (scheme == 'file' || !isSpecial(url)) return 'null';
  return scheme + '://' + serializeHost(url.host) + (port !== null ? ':' + port : '');
};

var getProtocol = function () {
  return getInternalURLState(this).scheme + ':';
};

var getUsername = function () {
  return getInternalURLState(this).username;
};

var getPassword = function () {
  return getInternalURLState(this).password;
};

var getHost = function () {
  var url = getInternalURLState(this);
  var host = url.host;
  var port = url.port;
  return host === null ? ''
    : port === null ? serializeHost(host)
    : serializeHost(host) + ':' + port;
};

var getHostname = function () {
  var host = getInternalURLState(this).host;
  return host === null ? '' : serializeHost(host);
};

var getPort = function () {
  var port = getInternalURLState(this).port;
  return port === null ? '' : String(port);
};

var getPathname = function () {
  var url = getInternalURLState(this);
  var path = url.path;
  return url.cannotBeABaseURL ? path[0] : path.length ? '/' + path.join('/') : '';
};

var getSearch = function () {
  var query = getInternalURLState(this).query;
  return query ? '?' + query : '';
};

var getSearchParams = function () {
  return getInternalURLState(this).searchParams;
};

var getHash = function () {
  var fragment = getInternalURLState(this).fragment;
  return fragment ? '#' + fragment : '';
};

var accessorDescriptor = function (getter, setter) {
  return { get: getter, set: setter, configurable: true, enumerable: true };
};

if (descriptors) {
  objectDefineProperties(URLPrototype, {
    // `URL.prototype.href` accessors pair
    // https://url.spec.whatwg.org/#dom-url-href
    href: accessorDescriptor(serializeURL, function (href) {
      var url = getInternalURLState(this);
      var urlString = String(href);
      var failure = parseURL(url, urlString);
      if (failure) throw TypeError(failure);
      getInternalSearchParamsState(url.searchParams).updateSearchParams(url.query);
    }),
    // `URL.prototype.origin` getter
    // https://url.spec.whatwg.org/#dom-url-origin
    origin: accessorDescriptor(getOrigin),
    // `URL.prototype.protocol` accessors pair
    // https://url.spec.whatwg.org/#dom-url-protocol
    protocol: accessorDescriptor(getProtocol, function (protocol) {
      var url = getInternalURLState(this);
      parseURL(url, String(protocol) + ':', SCHEME_START);
    }),
    // `URL.prototype.username` accessors pair
    // https://url.spec.whatwg.org/#dom-url-username
    username: accessorDescriptor(getUsername, function (username) {
      var url = getInternalURLState(this);
      var codePoints = arrayFrom(String(username));
      if (cannotHaveUsernamePasswordPort(url)) return;
      url.username = '';
      for (var i = 0; i < codePoints.length; i++) {
        url.username += percentEncode(codePoints[i], userinfoPercentEncodeSet);
      }
    }),
    // `URL.prototype.password` accessors pair
    // https://url.spec.whatwg.org/#dom-url-password
    password: accessorDescriptor(getPassword, function (password) {
      var url = getInternalURLState(this);
      var codePoints = arrayFrom(String(password));
      if (cannotHaveUsernamePasswordPort(url)) return;
      url.password = '';
      for (var i = 0; i < codePoints.length; i++) {
        url.password += percentEncode(codePoints[i], userinfoPercentEncodeSet);
      }
    }),
    // `URL.prototype.host` accessors pair
    // https://url.spec.whatwg.org/#dom-url-host
    host: accessorDescriptor(getHost, function (host) {
      var url = getInternalURLState(this);
      if (url.cannotBeABaseURL) return;
      parseURL(url, String(host), HOST);
    }),
    // `URL.prototype.hostname` accessors pair
    // https://url.spec.whatwg.org/#dom-url-hostname
    hostname: accessorDescriptor(getHostname, function (hostname) {
      var url = getInternalURLState(this);
      if (url.cannotBeABaseURL) return;
      parseURL(url, String(hostname), HOSTNAME);
    }),
    // `URL.prototype.port` accessors pair
    // https://url.spec.whatwg.org/#dom-url-port
    port: accessorDescriptor(getPort, function (port) {
      var url = getInternalURLState(this);
      if (cannotHaveUsernamePasswordPort(url)) return;
      port = String(port);
      if (port == '') url.port = null;
      else parseURL(url, port, PORT);
    }),
    // `URL.prototype.pathname` accessors pair
    // https://url.spec.whatwg.org/#dom-url-pathname
    pathname: accessorDescriptor(getPathname, function (pathname) {
      var url = getInternalURLState(this);
      if (url.cannotBeABaseURL) return;
      url.path = [];
      parseURL(url, pathname + '', PATH_START);
    }),
    // `URL.prototype.search` accessors pair
    // https://url.spec.whatwg.org/#dom-url-search
    search: accessorDescriptor(getSearch, function (search) {
      var url = getInternalURLState(this);
      search = String(search);
      if (search == '') {
        url.query = null;
      } else {
        if ('?' == search.charAt(0)) search = search.slice(1);
        url.query = '';
        parseURL(url, search, QUERY);
      }
      getInternalSearchParamsState(url.searchParams).updateSearchParams(url.query);
    }),
    // `URL.prototype.searchParams` getter
    // https://url.spec.whatwg.org/#dom-url-searchparams
    searchParams: accessorDescriptor(getSearchParams),
    // `URL.prototype.hash` accessors pair
    // https://url.spec.whatwg.org/#dom-url-hash
    hash: accessorDescriptor(getHash, function (hash) {
      var url = getInternalURLState(this);
      hash = String(hash);
      if (hash == '') {
        url.fragment = null;
        return;
      }
      if ('#' == hash.charAt(0)) hash = hash.slice(1);
      url.fragment = '';
      parseURL(url, hash, FRAGMENT);
    })
  });
}

// `URL.prototype.toJSON` method
// https://url.spec.whatwg.org/#dom-url-tojson
redefine(URLPrototype, 'toJSON', function toJSON() {
  return serializeURL.call(this);
}, { enumerable: true });

// `URL.prototype.toString` method
// https://url.spec.whatwg.org/#URL-stringification-behavior
redefine(URLPrototype, 'toString', function toString() {
  return serializeURL.call(this);
}, { enumerable: true });

if (NativeURL) {
  var nativeCreateObjectURL = NativeURL.createObjectURL;
  var nativeRevokeObjectURL = NativeURL.revokeObjectURL;
  // `URL.createObjectURL` method
  // https://developer.mozilla.org/en-US/docs/Web/API/URL/createObjectURL
  // eslint-disable-next-line no-unused-vars -- required for `.length`
  if (nativeCreateObjectURL) redefine(URLConstructor, 'createObjectURL', function createObjectURL(blob) {
    return nativeCreateObjectURL.apply(NativeURL, arguments);
  });
  // `URL.revokeObjectURL` method
  // https://developer.mozilla.org/en-US/docs/Web/API/URL/revokeObjectURL
  // eslint-disable-next-line no-unused-vars -- required for `.length`
  if (nativeRevokeObjectURL) redefine(URLConstructor, 'revokeObjectURL', function revokeObjectURL(url) {
    return nativeRevokeObjectURL.apply(NativeURL, arguments);
  });
}

setToStringTag(URLConstructor, 'URL');

_export({ global: true, forced: !nativeUrl, sham: !descriptors }, {
  URL: URLConstructor
});

var slice = [].slice;
var factories = {};

var construct = function (C, argsLength, args) {
  if (!(argsLength in factories)) {
    for (var list = [], i = 0; i < argsLength; i++) list[i] = 'a[' + i + ']';
    // eslint-disable-next-line no-new-func -- we have no proper alternatives, IE8- only
    factories[argsLength] = Function('C,a', 'return new C(' + list.join(',') + ')');
  } return factories[argsLength](C, args);
};

// `Function.prototype.bind` method implementation
// https://tc39.es/ecma262/#sec-function.prototype.bind
var functionBind = Function.bind || function bind(that /* , ...args */) {
  var fn = aFunction$1(this);
  var partArgs = slice.call(arguments, 1);
  var boundFunction = function bound(/* args... */) {
    var args = partArgs.concat(slice.call(arguments));
    return this instanceof boundFunction ? construct(fn, args.length, args) : fn.apply(that, args);
  };
  if (isObject(fn.prototype)) boundFunction.prototype = fn.prototype;
  return boundFunction;
};

var nativeConstruct = getBuiltIn('Reflect', 'construct');

// `Reflect.construct` method
// https://tc39.es/ecma262/#sec-reflect.construct
// MS Edge supports only 2 arguments and argumentsList argument is optional
// FF Nightly sets third argument as `new.target`, but does not create `this` from it
var NEW_TARGET_BUG = fails(function () {
  function F() { /* empty */ }
  return !(nativeConstruct(function () { /* empty */ }, [], F) instanceof F);
});
var ARGS_BUG = !fails(function () {
  nativeConstruct(function () { /* empty */ });
});
var FORCED$4 = NEW_TARGET_BUG || ARGS_BUG;

_export({ target: 'Reflect', stat: true, forced: FORCED$4, sham: FORCED$4 }, {
  construct: function construct(Target, args /* , newTarget */) {
    aFunction$1(Target);
    anObject(args);
    var newTarget = arguments.length < 3 ? Target : aFunction$1(arguments[2]);
    if (ARGS_BUG && !NEW_TARGET_BUG) return nativeConstruct(Target, args, newTarget);
    if (Target == newTarget) {
      // w/o altered newTarget, optimization for 0-4 arguments
      switch (args.length) {
        case 0: return new Target();
        case 1: return new Target(args[0]);
        case 2: return new Target(args[0], args[1]);
        case 3: return new Target(args[0], args[1], args[2]);
        case 4: return new Target(args[0], args[1], args[2], args[3]);
      }
      // w/o altered newTarget, lot of arguments case
      var $args = [null];
      $args.push.apply($args, args);
      return new (functionBind.apply(Target, $args))();
    }
    // with altered newTarget, not support built-in constructors
    var proto = newTarget.prototype;
    var instance = objectCreate(isObject(proto) ? proto : Object.prototype);
    var result = Function.apply.call(Target, instance, args);
    return isObject(result) ? result : instance;
  }
});

var freezing = !fails(function () {
  // eslint-disable-next-line es/no-object-isextensible, es/no-object-preventextensions -- required for testing
  return Object.isExtensible(Object.preventExtensions({}));
});

var internalMetadata = createCommonjsModule(function (module) {
var defineProperty = objectDefineProperty.f;



var METADATA = uid('meta');
var id = 0;

// eslint-disable-next-line es/no-object-isextensible -- safe
var isExtensible = Object.isExtensible || function () {
  return true;
};

var setMetadata = function (it) {
  defineProperty(it, METADATA, { value: {
    objectID: 'O' + ++id, // object ID
    weakData: {}          // weak collections IDs
  } });
};

var fastKey = function (it, create) {
  // return a primitive with prefix
  if (!isObject(it)) return typeof it == 'symbol' ? it : (typeof it == 'string' ? 'S' : 'P') + it;
  if (!has(it, METADATA)) {
    // can't set metadata to uncaught frozen object
    if (!isExtensible(it)) return 'F';
    // not necessary to add metadata
    if (!create) return 'E';
    // add missing metadata
    setMetadata(it);
  // return object ID
  } return it[METADATA].objectID;
};

var getWeakData = function (it, create) {
  if (!has(it, METADATA)) {
    // can't set metadata to uncaught frozen object
    if (!isExtensible(it)) return true;
    // not necessary to add metadata
    if (!create) return false;
    // add missing metadata
    setMetadata(it);
  // return the store of weak collections IDs
  } return it[METADATA].weakData;
};

// add metadata on freeze-family methods calling
var onFreeze = function (it) {
  if (freezing && meta.REQUIRED && isExtensible(it) && !has(it, METADATA)) setMetadata(it);
  return it;
};

var meta = module.exports = {
  REQUIRED: false,
  fastKey: fastKey,
  getWeakData: getWeakData,
  onFreeze: onFreeze
};

hiddenKeys[METADATA] = true;
});
var internalMetadata_1 = internalMetadata.REQUIRED;
var internalMetadata_2 = internalMetadata.fastKey;
var internalMetadata_3 = internalMetadata.getWeakData;
var internalMetadata_4 = internalMetadata.onFreeze;

var collection = function (CONSTRUCTOR_NAME, wrapper, common) {
  var IS_MAP = CONSTRUCTOR_NAME.indexOf('Map') !== -1;
  var IS_WEAK = CONSTRUCTOR_NAME.indexOf('Weak') !== -1;
  var ADDER = IS_MAP ? 'set' : 'add';
  var NativeConstructor = global_1[CONSTRUCTOR_NAME];
  var NativePrototype = NativeConstructor && NativeConstructor.prototype;
  var Constructor = NativeConstructor;
  var exported = {};

  var fixMethod = function (KEY) {
    var nativeMethod = NativePrototype[KEY];
    redefine(NativePrototype, KEY,
      KEY == 'add' ? function add(value) {
        nativeMethod.call(this, value === 0 ? 0 : value);
        return this;
      } : KEY == 'delete' ? function (key) {
        return IS_WEAK && !isObject(key) ? false : nativeMethod.call(this, key === 0 ? 0 : key);
      } : KEY == 'get' ? function get(key) {
        return IS_WEAK && !isObject(key) ? undefined : nativeMethod.call(this, key === 0 ? 0 : key);
      } : KEY == 'has' ? function has(key) {
        return IS_WEAK && !isObject(key) ? false : nativeMethod.call(this, key === 0 ? 0 : key);
      } : function set(key, value) {
        nativeMethod.call(this, key === 0 ? 0 : key, value);
        return this;
      }
    );
  };

  var REPLACE = isForced_1(
    CONSTRUCTOR_NAME,
    typeof NativeConstructor != 'function' || !(IS_WEAK || NativePrototype.forEach && !fails(function () {
      new NativeConstructor().entries().next();
    }))
  );

  if (REPLACE) {
    // create collection constructor
    Constructor = common.getConstructor(wrapper, CONSTRUCTOR_NAME, IS_MAP, ADDER);
    internalMetadata.REQUIRED = true;
  } else if (isForced_1(CONSTRUCTOR_NAME, true)) {
    var instance = new Constructor();
    // early implementations not supports chaining
    var HASNT_CHAINING = instance[ADDER](IS_WEAK ? {} : -0, 1) != instance;
    // V8 ~ Chromium 40- weak-collections throws on primitives, but should return false
    var THROWS_ON_PRIMITIVES = fails(function () { instance.has(1); });
    // most early implementations doesn't supports iterables, most modern - not close it correctly
    // eslint-disable-next-line no-new -- required for testing
    var ACCEPT_ITERABLES = checkCorrectnessOfIteration(function (iterable) { new NativeConstructor(iterable); });
    // for early implementations -0 and +0 not the same
    var BUGGY_ZERO = !IS_WEAK && fails(function () {
      // V8 ~ Chromium 42- fails only with 5+ elements
      var $instance = new NativeConstructor();
      var index = 5;
      while (index--) $instance[ADDER](index, index);
      return !$instance.has(-0);
    });

    if (!ACCEPT_ITERABLES) {
      Constructor = wrapper(function (dummy, iterable) {
        anInstance(dummy, Constructor, CONSTRUCTOR_NAME);
        var that = inheritIfRequired(new NativeConstructor(), dummy, Constructor);
        if (iterable != undefined) iterate(iterable, that[ADDER], { that: that, AS_ENTRIES: IS_MAP });
        return that;
      });
      Constructor.prototype = NativePrototype;
      NativePrototype.constructor = Constructor;
    }

    if (THROWS_ON_PRIMITIVES || BUGGY_ZERO) {
      fixMethod('delete');
      fixMethod('has');
      IS_MAP && fixMethod('get');
    }

    if (BUGGY_ZERO || HASNT_CHAINING) fixMethod(ADDER);

    // weak collections should not contains .clear method
    if (IS_WEAK && NativePrototype.clear) delete NativePrototype.clear;
  }

  exported[CONSTRUCTOR_NAME] = Constructor;
  _export({ global: true, forced: Constructor != NativeConstructor }, exported);

  setToStringTag(Constructor, CONSTRUCTOR_NAME);

  if (!IS_WEAK) common.setStrong(Constructor, CONSTRUCTOR_NAME, IS_MAP);

  return Constructor;
};

var defineProperty$9 = objectDefineProperty.f;








var fastKey = internalMetadata.fastKey;


var setInternalState$8 = internalState.set;
var internalStateGetterFor = internalState.getterFor;

var collectionStrong = {
  getConstructor: function (wrapper, CONSTRUCTOR_NAME, IS_MAP, ADDER) {
    var C = wrapper(function (that, iterable) {
      anInstance(that, C, CONSTRUCTOR_NAME);
      setInternalState$8(that, {
        type: CONSTRUCTOR_NAME,
        index: objectCreate(null),
        first: undefined,
        last: undefined,
        size: 0
      });
      if (!descriptors) that.size = 0;
      if (iterable != undefined) iterate(iterable, that[ADDER], { that: that, AS_ENTRIES: IS_MAP });
    });

    var getInternalState = internalStateGetterFor(CONSTRUCTOR_NAME);

    var define = function (that, key, value) {
      var state = getInternalState(that);
      var entry = getEntry(that, key);
      var previous, index;
      // change existing entry
      if (entry) {
        entry.value = value;
      // create new entry
      } else {
        state.last = entry = {
          index: index = fastKey(key, true),
          key: key,
          value: value,
          previous: previous = state.last,
          next: undefined,
          removed: false
        };
        if (!state.first) state.first = entry;
        if (previous) previous.next = entry;
        if (descriptors) state.size++;
        else that.size++;
        // add to index
        if (index !== 'F') state.index[index] = entry;
      } return that;
    };

    var getEntry = function (that, key) {
      var state = getInternalState(that);
      // fast case
      var index = fastKey(key);
      var entry;
      if (index !== 'F') return state.index[index];
      // frozen object case
      for (entry = state.first; entry; entry = entry.next) {
        if (entry.key == key) return entry;
      }
    };

    redefineAll(C.prototype, {
      // 23.1.3.1 Map.prototype.clear()
      // 23.2.3.2 Set.prototype.clear()
      clear: function clear() {
        var that = this;
        var state = getInternalState(that);
        var data = state.index;
        var entry = state.first;
        while (entry) {
          entry.removed = true;
          if (entry.previous) entry.previous = entry.previous.next = undefined;
          delete data[entry.index];
          entry = entry.next;
        }
        state.first = state.last = undefined;
        if (descriptors) state.size = 0;
        else that.size = 0;
      },
      // 23.1.3.3 Map.prototype.delete(key)
      // 23.2.3.4 Set.prototype.delete(value)
      'delete': function (key) {
        var that = this;
        var state = getInternalState(that);
        var entry = getEntry(that, key);
        if (entry) {
          var next = entry.next;
          var prev = entry.previous;
          delete state.index[entry.index];
          entry.removed = true;
          if (prev) prev.next = next;
          if (next) next.previous = prev;
          if (state.first == entry) state.first = next;
          if (state.last == entry) state.last = prev;
          if (descriptors) state.size--;
          else that.size--;
        } return !!entry;
      },
      // 23.2.3.6 Set.prototype.forEach(callbackfn, thisArg = undefined)
      // 23.1.3.5 Map.prototype.forEach(callbackfn, thisArg = undefined)
      forEach: function forEach(callbackfn /* , that = undefined */) {
        var state = getInternalState(this);
        var boundFunction = functionBindContext(callbackfn, arguments.length > 1 ? arguments[1] : undefined, 3);
        var entry;
        while (entry = entry ? entry.next : state.first) {
          boundFunction(entry.value, entry.key, this);
          // revert to the last existing entry
          while (entry && entry.removed) entry = entry.previous;
        }
      },
      // 23.1.3.7 Map.prototype.has(key)
      // 23.2.3.7 Set.prototype.has(value)
      has: function has(key) {
        return !!getEntry(this, key);
      }
    });

    redefineAll(C.prototype, IS_MAP ? {
      // 23.1.3.6 Map.prototype.get(key)
      get: function get(key) {
        var entry = getEntry(this, key);
        return entry && entry.value;
      },
      // 23.1.3.9 Map.prototype.set(key, value)
      set: function set(key, value) {
        return define(this, key === 0 ? 0 : key, value);
      }
    } : {
      // 23.2.3.1 Set.prototype.add(value)
      add: function add(value) {
        return define(this, value = value === 0 ? 0 : value, value);
      }
    });
    if (descriptors) defineProperty$9(C.prototype, 'size', {
      get: function () {
        return getInternalState(this).size;
      }
    });
    return C;
  },
  setStrong: function (C, CONSTRUCTOR_NAME, IS_MAP) {
    var ITERATOR_NAME = CONSTRUCTOR_NAME + ' Iterator';
    var getInternalCollectionState = internalStateGetterFor(CONSTRUCTOR_NAME);
    var getInternalIteratorState = internalStateGetterFor(ITERATOR_NAME);
    // add .keys, .values, .entries, [@@iterator]
    // 23.1.3.4, 23.1.3.8, 23.1.3.11, 23.1.3.12, 23.2.3.5, 23.2.3.8, 23.2.3.10, 23.2.3.11
    defineIterator(C, CONSTRUCTOR_NAME, function (iterated, kind) {
      setInternalState$8(this, {
        type: ITERATOR_NAME,
        target: iterated,
        state: getInternalCollectionState(iterated),
        kind: kind,
        last: undefined
      });
    }, function () {
      var state = getInternalIteratorState(this);
      var kind = state.kind;
      var entry = state.last;
      // revert to the last existing entry
      while (entry && entry.removed) entry = entry.previous;
      // get next entry
      if (!state.target || !(state.last = entry = entry ? entry.next : state.state.first)) {
        // or finish the iteration
        state.target = undefined;
        return { value: undefined, done: true };
      }
      // return step by kind
      if (kind == 'keys') return { value: entry.key, done: false };
      if (kind == 'values') return { value: entry.value, done: false };
      return { value: [entry.key, entry.value], done: false };
    }, IS_MAP ? 'entries' : 'values', !IS_MAP, true);

    // add [@@species], 23.1.2.2, 23.2.2.2
    setSpecies(CONSTRUCTOR_NAME);
  }
};

// `Map` constructor
// https://tc39.es/ecma262/#sec-map-objects
var es_map = collection('Map', function (init) {
  return function Map() { return init(this, arguments.length ? arguments[0] : undefined); };
}, collectionStrong);

// `Reflect.get` method
// https://tc39.es/ecma262/#sec-reflect.get
function get$2(target, propertyKey /* , receiver */) {
  var receiver = arguments.length < 3 ? target : arguments[2];
  var descriptor, prototype;
  if (anObject(target) === receiver) return target[propertyKey];
  if (descriptor = objectGetOwnPropertyDescriptor.f(target, propertyKey)) return has(descriptor, 'value')
    ? descriptor.value
    : descriptor.get === undefined
      ? undefined
      : descriptor.get.call(receiver);
  if (isObject(prototype = objectGetPrototypeOf(target))) return get$2(prototype, propertyKey, receiver);
}

_export({ target: 'Reflect', stat: true }, {
  get: get$2
});

var INCORRECT_ITERATION$1 = !checkCorrectnessOfIteration(function (iterable) {
  // eslint-disable-next-line es/no-array-from -- required for testing
  Array.from(iterable);
});

// `Array.from` method
// https://tc39.es/ecma262/#sec-array.from
_export({ target: 'Array', stat: true, forced: INCORRECT_ITERATION$1 }, {
  from: arrayFrom
});

// `Object.assign` method
// https://tc39.es/ecma262/#sec-object.assign
// eslint-disable-next-line es/no-object-assign -- required for testing
_export({ target: 'Object', stat: true, forced: Object.assign !== objectAssign }, {
  assign: objectAssign
});

var getOwnPropertyNames$3 = objectGetOwnPropertyNamesExternal.f;

// eslint-disable-next-line es/no-object-getownpropertynames -- required for testing
var FAILS_ON_PRIMITIVES$3 = fails(function () { return !Object.getOwnPropertyNames(1); });

// `Object.getOwnPropertyNames` method
// https://tc39.es/ecma262/#sec-object.getownpropertynames
_export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES$3 }, {
  getOwnPropertyNames: getOwnPropertyNames$3
});

// `Array.prototype.{ reduce, reduceRight }` methods implementation
var createMethod$4 = function (IS_RIGHT) {
  return function (that, callbackfn, argumentsLength, memo) {
    aFunction$1(callbackfn);
    var O = toObject(that);
    var self = indexedObject(O);
    var length = toLength(O.length);
    var index = IS_RIGHT ? length - 1 : 0;
    var i = IS_RIGHT ? -1 : 1;
    if (argumentsLength < 2) while (true) {
      if (index in self) {
        memo = self[index];
        index += i;
        break;
      }
      index += i;
      if (IS_RIGHT ? index < 0 : length <= index) {
        throw TypeError('Reduce of empty array with no initial value');
      }
    }
    for (;IS_RIGHT ? index >= 0 : length > index; index += i) if (index in self) {
      memo = callbackfn(memo, self[index], index, O);
    }
    return memo;
  };
};

var arrayReduce = {
  // `Array.prototype.reduce` method
  // https://tc39.es/ecma262/#sec-array.prototype.reduce
  left: createMethod$4(false),
  // `Array.prototype.reduceRight` method
  // https://tc39.es/ecma262/#sec-array.prototype.reduceright
  right: createMethod$4(true)
};

var $reduce = arrayReduce.left;




var STRICT_METHOD$3 = arrayMethodIsStrict('reduce');
// Chrome 80-82 has a critical bug
// https://bugs.chromium.org/p/chromium/issues/detail?id=1049982
var CHROME_BUG = !engineIsNode && engineV8Version > 79 && engineV8Version < 83;

// `Array.prototype.reduce` method
// https://tc39.es/ecma262/#sec-array.prototype.reduce
_export({ target: 'Array', proto: true, forced: !STRICT_METHOD$3 || CHROME_BUG }, {
  reduce: function reduce(callbackfn /* , initialValue */) {
    return $reduce(this, callbackfn, arguments.length, arguments.length > 1 ? arguments[1] : undefined);
  }
});

var test$1 = [];
var nativeSort = test$1.sort;

// IE8-
var FAILS_ON_UNDEFINED = fails(function () {
  test$1.sort(undefined);
});
// V8 bug
var FAILS_ON_NULL = fails(function () {
  test$1.sort(null);
});
// Old WebKit
var STRICT_METHOD$4 = arrayMethodIsStrict('sort');

var FORCED$5 = FAILS_ON_UNDEFINED || !FAILS_ON_NULL || !STRICT_METHOD$4;

// `Array.prototype.sort` method
// https://tc39.es/ecma262/#sec-array.prototype.sort
_export({ target: 'Array', proto: true, forced: FORCED$5 }, {
  sort: function sort(comparefn) {
    return comparefn === undefined
      ? nativeSort.call(toObject(this))
      : nativeSort.call(toObject(this), aFunction$1(comparefn));
  }
});

// `thisNumberValue` abstract operation
// https://tc39.es/ecma262/#sec-thisnumbervalue
var thisNumberValue = function (value) {
  if (typeof value != 'number' && classofRaw(value) != 'Number') {
    throw TypeError('Incorrect invocation');
  }
  return +value;
};

// `String.prototype.repeat` method implementation
// https://tc39.es/ecma262/#sec-string.prototype.repeat
var stringRepeat = function repeat(count) {
  var str = String(requireObjectCoercible(this));
  var result = '';
  var n = toInteger(count);
  if (n < 0 || n == Infinity) throw RangeError('Wrong number of repetitions');
  for (;n > 0; (n >>>= 1) && (str += str)) if (n & 1) result += str;
  return result;
};

var nativeToFixed = 1.0.toFixed;
var floor$5 = Math.floor;

var pow$2 = function (x, n, acc) {
  return n === 0 ? acc : n % 2 === 1 ? pow$2(x, n - 1, acc * x) : pow$2(x * x, n / 2, acc);
};

var log$1 = function (x) {
  var n = 0;
  var x2 = x;
  while (x2 >= 4096) {
    n += 12;
    x2 /= 4096;
  }
  while (x2 >= 2) {
    n += 1;
    x2 /= 2;
  } return n;
};

var multiply = function (data, n, c) {
  var index = -1;
  var c2 = c;
  while (++index < 6) {
    c2 += n * data[index];
    data[index] = c2 % 1e7;
    c2 = floor$5(c2 / 1e7);
  }
};

var divide = function (data, n) {
  var index = 6;
  var c = 0;
  while (--index >= 0) {
    c += data[index];
    data[index] = floor$5(c / n);
    c = (c % n) * 1e7;
  }
};

var dataToString = function (data) {
  var index = 6;
  var s = '';
  while (--index >= 0) {
    if (s !== '' || index === 0 || data[index] !== 0) {
      var t = String(data[index]);
      s = s === '' ? t : s + stringRepeat.call('0', 7 - t.length) + t;
    }
  } return s;
};

var FORCED$6 = nativeToFixed && (
  0.00008.toFixed(3) !== '0.000' ||
  0.9.toFixed(0) !== '1' ||
  1.255.toFixed(2) !== '1.25' ||
  1000000000000000128.0.toFixed(0) !== '1000000000000000128'
) || !fails(function () {
  // V8 ~ Android 4.3-
  nativeToFixed.call({});
});

// `Number.prototype.toFixed` method
// https://tc39.es/ecma262/#sec-number.prototype.tofixed
_export({ target: 'Number', proto: true, forced: FORCED$6 }, {
  toFixed: function toFixed(fractionDigits) {
    var number = thisNumberValue(this);
    var fractDigits = toInteger(fractionDigits);
    var data = [0, 0, 0, 0, 0, 0];
    var sign = '';
    var result = '0';
    var e, z, j, k;

    if (fractDigits < 0 || fractDigits > 20) throw RangeError('Incorrect fraction digits');
    // eslint-disable-next-line no-self-compare -- NaN check
    if (number != number) return 'NaN';
    if (number <= -1e21 || number >= 1e21) return String(number);
    if (number < 0) {
      sign = '-';
      number = -number;
    }
    if (number > 1e-21) {
      e = log$1(number * pow$2(2, 69, 1)) - 69;
      z = e < 0 ? number * pow$2(2, -e, 1) : number / pow$2(2, e, 1);
      z *= 0x10000000000000;
      e = 52 - e;
      if (e > 0) {
        multiply(data, 0, z);
        j = fractDigits;
        while (j >= 7) {
          multiply(data, 1e7, 0);
          j -= 7;
        }
        multiply(data, pow$2(10, j, 1), 0);
        j = e - 1;
        while (j >= 23) {
          divide(data, 1 << 23);
          j -= 23;
        }
        divide(data, 1 << j);
        multiply(data, 1, 1);
        divide(data, 2);
        result = dataToString(data);
      } else {
        multiply(data, 0, z);
        multiply(data, 1 << -e, 0);
        result = dataToString(data) + stringRepeat.call('0', fractDigits);
      }
    }
    if (fractDigits > 0) {
      k = result.length;
      result = sign + (k <= fractDigits
        ? '0.' + stringRepeat.call('0', fractDigits - k) + result
        : result.slice(0, k - fractDigits) + '.' + result.slice(k - fractDigits));
    } else {
      result = sign + result;
    } return result;
  }
});

var $find = arrayIteration.find;


var FIND = 'find';
var SKIPS_HOLES = true;

// Shouldn't skip holes
if (FIND in []) Array(1)[FIND](function () { SKIPS_HOLES = false; });

// `Array.prototype.find` method
// https://tc39.es/ecma262/#sec-array.prototype.find
_export({ target: 'Array', proto: true, forced: SKIPS_HOLES }, {
  find: function find(callbackfn /* , that = undefined */) {
    return $find(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
  }
});

// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
addToUnscopables(FIND);

var HAS_SPECIES_SUPPORT$3 = arrayMethodHasSpeciesSupport('splice');

var max$3 = Math.max;
var min$4 = Math.min;
var MAX_SAFE_INTEGER$1 = 0x1FFFFFFFFFFFFF;
var MAXIMUM_ALLOWED_LENGTH_EXCEEDED = 'Maximum allowed length exceeded';

// `Array.prototype.splice` method
// https://tc39.es/ecma262/#sec-array.prototype.splice
// with adding support of @@species
_export({ target: 'Array', proto: true, forced: !HAS_SPECIES_SUPPORT$3 }, {
  splice: function splice(start, deleteCount /* , ...items */) {
    var O = toObject(this);
    var len = toLength(O.length);
    var actualStart = toAbsoluteIndex(start, len);
    var argumentsLength = arguments.length;
    var insertCount, actualDeleteCount, A, k, from, to;
    if (argumentsLength === 0) {
      insertCount = actualDeleteCount = 0;
    } else if (argumentsLength === 1) {
      insertCount = 0;
      actualDeleteCount = len - actualStart;
    } else {
      insertCount = argumentsLength - 2;
      actualDeleteCount = min$4(max$3(toInteger(deleteCount), 0), len - actualStart);
    }
    if (len + insertCount - actualDeleteCount > MAX_SAFE_INTEGER$1) {
      throw TypeError(MAXIMUM_ALLOWED_LENGTH_EXCEEDED);
    }
    A = arraySpeciesCreate(O, actualDeleteCount);
    for (k = 0; k < actualDeleteCount; k++) {
      from = actualStart + k;
      if (from in O) createProperty(A, k, O[from]);
    }
    A.length = actualDeleteCount;
    if (insertCount < actualDeleteCount) {
      for (k = actualStart; k < len - actualDeleteCount; k++) {
        from = k + actualDeleteCount;
        to = k + insertCount;
        if (from in O) O[to] = O[from];
        else delete O[to];
      }
      for (k = len; k > len - actualDeleteCount + insertCount; k--) delete O[k - 1];
    } else if (insertCount > actualDeleteCount) {
      for (k = len - actualDeleteCount; k > actualStart; k--) {
        from = k + actualDeleteCount - 1;
        to = k + insertCount - 1;
        if (from in O) O[to] = O[from];
        else delete O[to];
      }
    }
    for (k = 0; k < insertCount; k++) {
      O[k + actualStart] = arguments[k + 2];
    }
    O.length = len - actualDeleteCount + insertCount;
    return A;
  }
});

// `Array.prototype.fill` method
// https://tc39.es/ecma262/#sec-array.prototype.fill
_export({ target: 'Array', proto: true }, {
  fill: arrayFill
});

// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
addToUnscopables('fill');

var quot = /"/g;

// B.2.3.2.1 CreateHTML(string, tag, attribute, value)
// https://tc39.es/ecma262/#sec-createhtml
var createHtml = function (string, tag, attribute, value) {
  var S = String(requireObjectCoercible(string));
  var p1 = '<' + tag;
  if (attribute !== '') p1 += ' ' + attribute + '="' + String(value).replace(quot, '&quot;') + '"';
  return p1 + '>' + S + '</' + tag + '>';
};

// check the existence of a method, lowercase
// of a tag and escaping quotes in arguments
var stringHtmlForced = function (METHOD_NAME) {
  return fails(function () {
    var test = ''[METHOD_NAME]('"');
    return test !== test.toLowerCase() || test.split('"').length > 3;
  });
};

// `String.prototype.small` method
// https://tc39.es/ecma262/#sec-string.prototype.small
_export({ target: 'String', proto: true, forced: stringHtmlForced('small') }, {
  small: function small() {
    return createHtml(this, 'small', '', '');
  }
});

// `String.prototype.fixed` method
// https://tc39.es/ecma262/#sec-string.prototype.fixed
_export({ target: 'String', proto: true, forced: stringHtmlForced('fixed') }, {
  fixed: function fixed() {
    return createHtml(this, 'tt', '', '');
  }
});

// `String.prototype.link` method
// https://tc39.es/ecma262/#sec-string.prototype.link
_export({ target: 'String', proto: true, forced: stringHtmlForced('link') }, {
  link: function link(url) {
    return createHtml(this, 'a', 'href', url);
  }
});

var $findIndex = arrayIteration.findIndex;


var FIND_INDEX = 'findIndex';
var SKIPS_HOLES$1 = true;

// Shouldn't skip holes
if (FIND_INDEX in []) Array(1)[FIND_INDEX](function () { SKIPS_HOLES$1 = false; });

// `Array.prototype.findIndex` method
// https://tc39.es/ecma262/#sec-array.prototype.findindex
_export({ target: 'Array', proto: true, forced: SKIPS_HOLES$1 }, {
  findIndex: function findIndex(callbackfn /* , that = undefined */) {
    return $findIndex(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
  }
});

// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
addToUnscopables(FIND_INDEX);

var onFreeze = internalMetadata.onFreeze;

// eslint-disable-next-line es/no-object-freeze -- safe
var $freeze = Object.freeze;
var FAILS_ON_PRIMITIVES$4 = fails(function () { $freeze(1); });

// `Object.freeze` method
// https://tc39.es/ecma262/#sec-object.freeze
_export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES$4, sham: !freezing }, {
  freeze: function freeze(it) {
    return $freeze && isObject(it) ? $freeze(onFreeze(it)) : it;
  }
});

var FORCED$7 = !global_1.setImmediate || !global_1.clearImmediate;

// http://w3c.github.io/setImmediate/
_export({ global: true, bind: true, enumerable: true, forced: FORCED$7 }, {
  // `setImmediate` method
  // http://w3c.github.io/setImmediate/#si-setImmediate
  setImmediate: task.set,
  // `clearImmediate` method
  // http://w3c.github.io/setImmediate/#si-clearImmediate
  clearImmediate: task.clear
});

var getWeakData = internalMetadata.getWeakData;








var setInternalState$9 = internalState.set;
var internalStateGetterFor$1 = internalState.getterFor;
var find$1 = arrayIteration.find;
var findIndex = arrayIteration.findIndex;
var id$1 = 0;

// fallback for uncaught frozen keys
var uncaughtFrozenStore = function (store) {
  return store.frozen || (store.frozen = new UncaughtFrozenStore());
};

var UncaughtFrozenStore = function () {
  this.entries = [];
};

var findUncaughtFrozen = function (store, key) {
  return find$1(store.entries, function (it) {
    return it[0] === key;
  });
};

UncaughtFrozenStore.prototype = {
  get: function (key) {
    var entry = findUncaughtFrozen(this, key);
    if (entry) return entry[1];
  },
  has: function (key) {
    return !!findUncaughtFrozen(this, key);
  },
  set: function (key, value) {
    var entry = findUncaughtFrozen(this, key);
    if (entry) entry[1] = value;
    else this.entries.push([key, value]);
  },
  'delete': function (key) {
    var index = findIndex(this.entries, function (it) {
      return it[0] === key;
    });
    if (~index) this.entries.splice(index, 1);
    return !!~index;
  }
};

var collectionWeak = {
  getConstructor: function (wrapper, CONSTRUCTOR_NAME, IS_MAP, ADDER) {
    var C = wrapper(function (that, iterable) {
      anInstance(that, C, CONSTRUCTOR_NAME);
      setInternalState$9(that, {
        type: CONSTRUCTOR_NAME,
        id: id$1++,
        frozen: undefined
      });
      if (iterable != undefined) iterate(iterable, that[ADDER], { that: that, AS_ENTRIES: IS_MAP });
    });

    var getInternalState = internalStateGetterFor$1(CONSTRUCTOR_NAME);

    var define = function (that, key, value) {
      var state = getInternalState(that);
      var data = getWeakData(anObject(key), true);
      if (data === true) uncaughtFrozenStore(state).set(key, value);
      else data[state.id] = value;
      return that;
    };

    redefineAll(C.prototype, {
      // 23.3.3.2 WeakMap.prototype.delete(key)
      // 23.4.3.3 WeakSet.prototype.delete(value)
      'delete': function (key) {
        var state = getInternalState(this);
        if (!isObject(key)) return false;
        var data = getWeakData(key);
        if (data === true) return uncaughtFrozenStore(state)['delete'](key);
        return data && has(data, state.id) && delete data[state.id];
      },
      // 23.3.3.4 WeakMap.prototype.has(key)
      // 23.4.3.4 WeakSet.prototype.has(value)
      has: function has$1(key) {
        var state = getInternalState(this);
        if (!isObject(key)) return false;
        var data = getWeakData(key);
        if (data === true) return uncaughtFrozenStore(state).has(key);
        return data && has(data, state.id);
      }
    });

    redefineAll(C.prototype, IS_MAP ? {
      // 23.3.3.3 WeakMap.prototype.get(key)
      get: function get(key) {
        var state = getInternalState(this);
        if (isObject(key)) {
          var data = getWeakData(key);
          if (data === true) return uncaughtFrozenStore(state).get(key);
          return data ? data[state.id] : undefined;
        }
      },
      // 23.3.3.5 WeakMap.prototype.set(key, value)
      set: function set(key, value) {
        return define(this, key, value);
      }
    } : {
      // 23.4.3.1 WeakSet.prototype.add(value)
      add: function add(value) {
        return define(this, value, true);
      }
    });

    return C;
  }
};

var es_weakMap = createCommonjsModule(function (module) {






var enforceIternalState = internalState.enforce;


var IS_IE11 = !global_1.ActiveXObject && 'ActiveXObject' in global_1;
// eslint-disable-next-line es/no-object-isextensible -- safe
var isExtensible = Object.isExtensible;
var InternalWeakMap;

var wrapper = function (init) {
  return function WeakMap() {
    return init(this, arguments.length ? arguments[0] : undefined);
  };
};

// `WeakMap` constructor
// https://tc39.es/ecma262/#sec-weakmap-constructor
var $WeakMap = module.exports = collection('WeakMap', wrapper, collectionWeak);

// IE11 WeakMap frozen keys fix
// We can't use feature detection because it crash some old IE builds
// https://github.com/zloirock/core-js/issues/485
if (nativeWeakMap && IS_IE11) {
  InternalWeakMap = collectionWeak.getConstructor(wrapper, 'WeakMap', true);
  internalMetadata.REQUIRED = true;
  var WeakMapPrototype = $WeakMap.prototype;
  var nativeDelete = WeakMapPrototype['delete'];
  var nativeHas = WeakMapPrototype.has;
  var nativeGet = WeakMapPrototype.get;
  var nativeSet = WeakMapPrototype.set;
  redefineAll(WeakMapPrototype, {
    'delete': function (key) {
      if (isObject(key) && !isExtensible(key)) {
        var state = enforceIternalState(this);
        if (!state.frozen) state.frozen = new InternalWeakMap();
        return nativeDelete.call(this, key) || state.frozen['delete'](key);
      } return nativeDelete.call(this, key);
    },
    has: function has(key) {
      if (isObject(key) && !isExtensible(key)) {
        var state = enforceIternalState(this);
        if (!state.frozen) state.frozen = new InternalWeakMap();
        return nativeHas.call(this, key) || state.frozen.has(key);
      } return nativeHas.call(this, key);
    },
    get: function get(key) {
      if (isObject(key) && !isExtensible(key)) {
        var state = enforceIternalState(this);
        if (!state.frozen) state.frozen = new InternalWeakMap();
        return nativeHas.call(this, key) ? nativeGet.call(this, key) : state.frozen.get(key);
      } return nativeGet.call(this, key);
    },
    set: function set(key, value) {
      if (isObject(key) && !isExtensible(key)) {
        var state = enforceIternalState(this);
        if (!state.frozen) state.frozen = new InternalWeakMap();
        nativeHas.call(this, key) ? nativeSet.call(this, key, value) : state.frozen.set(key, value);
      } else nativeSet.call(this, key, value);
      return this;
    }
  });
}
});

// Safari bug https://bugs.webkit.org/show_bug.cgi?id=200829
var NON_GENERIC = !!nativePromiseConstructor && fails(function () {
  nativePromiseConstructor.prototype['finally'].call({ then: function () { /* empty */ } }, function () { /* empty */ });
});

// `Promise.prototype.finally` method
// https://tc39.es/ecma262/#sec-promise.prototype.finally
_export({ target: 'Promise', proto: true, real: true, forced: NON_GENERIC }, {
  'finally': function (onFinally) {
    var C = speciesConstructor(this, getBuiltIn('Promise'));
    var isFunction = typeof onFinally == 'function';
    return this.then(
      isFunction ? function (x) {
        return promiseResolve(C, onFinally()).then(function () { return x; });
      } : onFinally,
      isFunction ? function (e) {
        return promiseResolve(C, onFinally()).then(function () { throw e; });
      } : onFinally
    );
  }
});

// patch native Promise.prototype for native async functions
if ( typeof nativePromiseConstructor == 'function' && !nativePromiseConstructor.prototype['finally']) {
  redefine(nativePromiseConstructor.prototype, 'finally', getBuiltIn('Promise').prototype['finally']);
}

var UNSUPPORTED_Y$4 = regexpStickyHelpers.UNSUPPORTED_Y;

// `RegExp.prototype.flags` getter
// https://tc39.es/ecma262/#sec-get-regexp.prototype.flags
// eslint-disable-next-line es/no-regexp-prototype-flags -- required for testing
if (descriptors && (/./g.flags != 'g' || UNSUPPORTED_Y$4)) {
  objectDefineProperty.f(RegExp.prototype, 'flags', {
    configurable: true,
    get: regexpFlags
  });
}

var propertyIsEnumerable = objectPropertyIsEnumerable.f;

// `Object.{ entries, values }` methods implementation
var createMethod$5 = function (TO_ENTRIES) {
  return function (it) {
    var O = toIndexedObject(it);
    var keys = objectKeys(O);
    var length = keys.length;
    var i = 0;
    var result = [];
    var key;
    while (length > i) {
      key = keys[i++];
      if (!descriptors || propertyIsEnumerable.call(O, key)) {
        result.push(TO_ENTRIES ? [key, O[key]] : O[key]);
      }
    }
    return result;
  };
};

var objectToArray = {
  // `Object.entries` method
  // https://tc39.es/ecma262/#sec-object.entries
  entries: createMethod$5(true),
  // `Object.values` method
  // https://tc39.es/ecma262/#sec-object.values
  values: createMethod$5(false)
};

var $values = objectToArray.values;

// `Object.values` method
// https://tc39.es/ecma262/#sec-object.values
_export({ target: 'Object', stat: true }, {
  values: function values(O) {
    return $values(O);
  }
});

var floor$6 = Math.floor;

// `Number.isInteger` method implementation
// https://tc39.es/ecma262/#sec-number.isinteger
var isInteger = function isInteger(it) {
  return !isObject(it) && isFinite(it) && floor$6(it) === it;
};

// `Number.isInteger` method
// https://tc39.es/ecma262/#sec-number.isinteger
_export({ target: 'Number', stat: true }, {
  isInteger: isInteger
});

// `Number.isNaN` method
// https://tc39.es/ecma262/#sec-number.isnan
_export({ target: 'Number', stat: true }, {
  isNaN: function isNaN(number) {
    // eslint-disable-next-line no-self-compare -- NaN check
    return number != number;
  }
});

// `Set` constructor
// https://tc39.es/ecma262/#sec-set-objects
var es_set = collection('Set', function (init) {
  return function Set() { return init(this, arguments.length ? arguments[0] : undefined); };
}, collectionStrong);

var $includes = arrayIncludes.includes;


// `Array.prototype.includes` method
// https://tc39.es/ecma262/#sec-array.prototype.includes
_export({ target: 'Array', proto: true }, {
  includes: function includes(el /* , fromIndex = 0 */) {
    return $includes(this, el, arguments.length > 1 ? arguments[1] : undefined);
  }
});

// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
addToUnscopables('includes');

var notARegexp = function (it) {
  if (isRegexp(it)) {
    throw TypeError("The method doesn't accept regular expressions");
  } return it;
};

var MATCH$2 = wellKnownSymbol('match');

var correctIsRegexpLogic = function (METHOD_NAME) {
  var regexp = /./;
  try {
    '/./'[METHOD_NAME](regexp);
  } catch (error1) {
    try {
      regexp[MATCH$2] = false;
      return '/./'[METHOD_NAME](regexp);
    } catch (error2) { /* empty */ }
  } return false;
};

// `String.prototype.includes` method
// https://tc39.es/ecma262/#sec-string.prototype.includes
_export({ target: 'String', proto: true, forced: !correctIsRegexpLogic('includes') }, {
  includes: function includes(searchString /* , position = 0 */) {
    return !!~String(requireObjectCoercible(this))
      .indexOf(notARegexp(searchString), arguments.length > 1 ? arguments[1] : undefined);
  }
});

// eslint-disable-next-line es/no-object-isextensible -- safe
var $isExtensible = Object.isExtensible;
var FAILS_ON_PRIMITIVES$5 = fails(function () { $isExtensible(1); });

// `Object.isExtensible` method
// https://tc39.es/ecma262/#sec-object.isextensible
_export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES$5 }, {
  isExtensible: function isExtensible(it) {
    return isObject(it) ? $isExtensible ? $isExtensible(it) : true : false;
  }
});

var onFreeze$1 = internalMetadata.onFreeze;



// eslint-disable-next-line es/no-object-preventextensions -- safe
var $preventExtensions = Object.preventExtensions;
var FAILS_ON_PRIMITIVES$6 = fails(function () { $preventExtensions(1); });

// `Object.preventExtensions` method
// https://tc39.es/ecma262/#sec-object.preventextensions
_export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES$6, sham: !freezing }, {
  preventExtensions: function preventExtensions(it) {
    return $preventExtensions && isObject(it) ? $preventExtensions(onFreeze$1(it)) : it;
  }
});

// `String.prototype.repeat` method
// https://tc39.es/ecma262/#sec-string.prototype.repeat
_export({ target: 'String', proto: true }, {
  repeat: stringRepeat
});

// `Reflect.ownKeys` method
// https://tc39.es/ecma262/#sec-reflect.ownkeys
_export({ target: 'Reflect', stat: true }, {
  ownKeys: ownKeys
});

// eslint-disable-next-line es/no-object-isfrozen -- safe
var $isFrozen = Object.isFrozen;
var FAILS_ON_PRIMITIVES$7 = fails(function () { $isFrozen(1); });

// `Object.isFrozen` method
// https://tc39.es/ecma262/#sec-object.isfrozen
_export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES$7 }, {
  isFrozen: function isFrozen(it) {
    return isObject(it) ? $isFrozen ? $isFrozen(it) : false : true;
  }
});

/* eslint-disable es/no-array-prototype-lastindexof -- safe */





var min$5 = Math.min;
var $lastIndexOf = [].lastIndexOf;
var NEGATIVE_ZERO$1 = !!$lastIndexOf && 1 / [1].lastIndexOf(1, -0) < 0;
var STRICT_METHOD$5 = arrayMethodIsStrict('lastIndexOf');
var FORCED$8 = NEGATIVE_ZERO$1 || !STRICT_METHOD$5;

// `Array.prototype.lastIndexOf` method implementation
// https://tc39.es/ecma262/#sec-array.prototype.lastindexof
var arrayLastIndexOf = FORCED$8 ? function lastIndexOf(searchElement /* , fromIndex = @[*-1] */) {
  // convert -0 to +0
  if (NEGATIVE_ZERO$1) return $lastIndexOf.apply(this, arguments) || 0;
  var O = toIndexedObject(this);
  var length = toLength(O.length);
  var index = length - 1;
  if (arguments.length > 1) index = min$5(index, toInteger(arguments[1]));
  if (index < 0) index = length + index;
  for (;index >= 0; index--) if (index in O && O[index] === searchElement) return index || 0;
  return -1;
} : $lastIndexOf;

// `Array.prototype.lastIndexOf` method
// https://tc39.es/ecma262/#sec-array.prototype.lastindexof
// eslint-disable-next-line es/no-array-prototype-lastindexof -- required for testing
_export({ target: 'Array', proto: true, forced: arrayLastIndexOf !== [].lastIndexOf }, {
  lastIndexOf: arrayLastIndexOf
});

/******/(function(modules){// webpackBootstrap
/******/ // install a JSONP callback for chunk loading
/******/function webpackJsonpCallback(data){
/******/var chunkIds=data[0];
/******/var moreModules=data[1];
/******/
/******/
/******/ // add "moreModules" to the modules object,
/******/ // then flag all "chunkIds" as loaded and fire callback
/******/var moduleId,chunkId,i=0,resolves=[];
/******/for(;i<chunkIds.length;i++){
/******/chunkId=chunkIds[i];
/******/if(Object.prototype.hasOwnProperty.call(installedChunks,chunkId)&&installedChunks[chunkId]){
/******/resolves.push(installedChunks[chunkId][0]);
/******/}
/******/installedChunks[chunkId]=0;
/******/}
/******/for(moduleId in moreModules){
/******/if(Object.prototype.hasOwnProperty.call(moreModules,moduleId)){
/******/modules[moduleId]=moreModules[moduleId];
/******/}
/******/}
/******/if(parentJsonpFunction)parentJsonpFunction(data);
/******/
/******/while(resolves.length){
/******/resolves.shift()();
/******/}
/******/
/******/}/******/
/******/
/******/ // The module cache
/******/var installedModules={};
/******/
/******/ // object to store loaded and loading chunks
/******/ // undefined = chunk not loaded, null = chunk preloaded/prefetched
/******/ // Promise = chunk loading, 0 = chunk loaded
/******/var installedChunks={
/******/"/main":0
/******/};
/******/
/******/
/******/
/******/ // script path function
/******/function jsonpScriptSrc(chunkId){
/******/return __webpack_require__.p+"js/bundle/"+({"Customers":"Customers","Suppliers":"Suppliers","Users":"Users","index_adjustment":"index_adjustment","index_expense":"index_expense","index_products":"index_products","index_purchase_return":"index_purchase_return","index_purchases":"index_purchases","index_sale_return":"index_sale_return","index_transfer":"index_transfer","payments_purchases":"payments_purchases","payments_purchases_returns":"payments_purchases_returns","payments_sales":"payments_sales","payments_sales_returns":"payments_sales_returns","purchase_report":"purchase_report","sales_report":"sales_report","vendors~barcode~detail_product~index_sales~pos":"vendors~barcode~detail_product~index_sales~pos","vendors~index_sales~pos":"vendors~index_sales~pos","index_sales":"index_sales","Backup":"Backup","Brands":"Brands","Categories":"Categories","Currencies":"Currencies","NotFound":"NotFound","People":"People","System_settings":"System_settings","Warehouses":"Warehouses","adjustments":"adjustments","change_to_sale":"change_to_sale","customers_report":"customers_report","customizer":"customizer","detail_customer_report":"detail_customer_report","detail_purchase":"detail_purchase","detail_purchase_return":"detail_purchase_return","detail_quotation":"detail_quotation","detail_sale":"detail_sale","detail_sale_return":"detail_sale_return","detail_supplier_report":"detail_supplier_report","edit_adjustment":"edit_adjustment","edit_expense":"edit_expense","edit_permission":"edit_permission","edit_purchase":"edit_purchase","edit_purchase_return":"edit_purchase_return","edit_quotation":"edit_quotation","edit_sale":"edit_sale","edit_sale_return":"edit_sale_return","edit_transfer":"edit_transfer","expense_category":"expense_category","expenses":"expenses","groupPermission":"groupPermission","not_authorize":"not_authorize","permissions":"permissions","products":"products","profile":"profile","profit_and_loss":"profit_and_loss","providers_report":"providers_report","purchase_return":"purchase_return","purchases":"purchases","quantity_alerts":"quantity_alerts","quotations":"quotations","sale_return":"sale_return","sales":"sales","settings":"settings","store_adjustment":"store_adjustment","store_expense":"store_expense","store_permission":"store_permission","store_purchase":"store_purchase","store_purchase_return":"store_purchase_return","store_quotation":"store_quotation","store_sale":"store_sale","store_sale_return":"store_sale_return","store_transfer":"store_transfer","transfers":"transfers","units":"units","barcode":"barcode","detail_product":"detail_product","vendors~largeSidebar~pos":"vendors~largeSidebar~pos","pos":"pos","vendors~dashboard~warehouse_report":"vendors~dashboard~warehouse_report","dashboard":"dashboard","warehouse_report":"warehouse_report","vendors~edit_product~store_product":"vendors~edit_product~store_product","edit_product":"edit_product","store_product":"store_product","vendors~largeSidebar":"vendors~largeSidebar","largeSidebar":"largeSidebar","vendors~vue-perfect-scrollbar":"vendors~vue-perfect-scrollbar"}[chunkId]||chunkId)+".js";
/******/}
/******/
/******/ // The require function
/******/function __webpack_require__(moduleId){
/******/
/******/ // Check if module is in cache
/******/if(installedModules[moduleId]){
/******/return installedModules[moduleId].exports;
/******/}
/******/ // Create a new module (and put it into the cache)
/******/var module=installedModules[moduleId]={
/******/i:moduleId,
/******/l:false,
/******/exports:{}
/******/};
/******/
/******/ // Execute the module function
/******/modules[moduleId].call(module.exports,module,module.exports,__webpack_require__);
/******/
/******/ // Flag the module as loaded
/******/module.l=true;
/******/
/******/ // Return the exports of the module
/******/return module.exports;
/******/}
/******/
/******/ // This file contains only the entry chunk.
/******/ // The chunk loading function for additional chunks
/******/__webpack_require__.e=function requireEnsure(chunkId){
/******/var promises=[];
/******/
/******/
/******/ // JSONP chunk loading for javascript
/******/
/******/var installedChunkData=installedChunks[chunkId];
/******/if(installedChunkData!==0){// 0 means "already installed".
/******/
/******/ // a Promise means "currently loading".
/******/if(installedChunkData){
/******/promises.push(installedChunkData[2]);
/******/}else {
/******/ // setup Promise in chunk cache
/******/var promise=new Promise(function(resolve,reject){
/******/installedChunkData=installedChunks[chunkId]=[resolve,reject];
/******/});
/******/promises.push(installedChunkData[2]=promise);
/******/
/******/ // start chunk loading
/******/var script=document.createElement('script');
/******/var onScriptComplete;
/******/
/******/script.charset='utf-8';
/******/script.timeout=120;
/******/if(__webpack_require__.nc){
/******/script.setAttribute("nonce",__webpack_require__.nc);
/******/}
/******/script.src=jsonpScriptSrc(chunkId);
/******/
/******/ // create error before stack unwound to get useful stacktrace later
/******/var error=new Error();
/******/onScriptComplete=function onScriptComplete(event){
/******/ // avoid mem leaks in IE.
/******/script.onerror=script.onload=null;
/******/clearTimeout(timeout);
/******/var chunk=installedChunks[chunkId];
/******/if(chunk!==0){
/******/if(chunk){
/******/var errorType=event&&(event.type==='load'?'missing':event.type);
/******/var realSrc=event&&event.target&&event.target.src;
/******/error.message='Loading chunk '+chunkId+' failed.\n('+errorType+': '+realSrc+')';
/******/error.name='ChunkLoadError';
/******/error.type=errorType;
/******/error.request=realSrc;
/******/chunk[1](error);
/******/}
/******/installedChunks[chunkId]=undefined;
/******/}
/******/};
/******/var timeout=setTimeout(function(){
/******/onScriptComplete({type:'timeout',target:script});
/******/},120000);
/******/script.onerror=script.onload=onScriptComplete;
/******/document.head.appendChild(script);
/******/}
/******/}
/******/return Promise.all(promises);
/******/};
/******/
/******/ // expose the modules object (__webpack_modules__)
/******/__webpack_require__.m=modules;
/******/
/******/ // expose the module cache
/******/__webpack_require__.c=installedModules;
/******/
/******/ // define getter function for harmony exports
/******/__webpack_require__.d=function(exports,name,getter){
/******/if(!__webpack_require__.o(exports,name)){
/******/Object.defineProperty(exports,name,{enumerable:true,get:getter});
/******/}
/******/};
/******/
/******/ // define __esModule on exports
/******/__webpack_require__.r=function(exports){
/******/if(typeof Symbol!=='undefined'&&Symbol.toStringTag){
/******/Object.defineProperty(exports,Symbol.toStringTag,{value:'Module'});
/******/}
/******/Object.defineProperty(exports,'__esModule',{value:true});
/******/};
/******/
/******/ // create a fake namespace object
/******/ // mode & 1: value is a module id, require it
/******/ // mode & 2: merge all properties of value into the ns
/******/ // mode & 4: return value when already ns object
/******/ // mode & 8|1: behave like require
/******/__webpack_require__.t=function(value,mode){
/******/if(mode&1)value=__webpack_require__(value);
/******/if(mode&8)return value;
/******/if(mode&4&&typeof value==='object'&&value&&value.__esModule)return value;
/******/var ns=Object.create(null);
/******/__webpack_require__.r(ns);
/******/Object.defineProperty(ns,'default',{enumerable:true,value:value});
/******/if(mode&2&&typeof value!='string')for(var key in value){__webpack_require__.d(ns,key,function(key){return value[key];}.bind(null,key));}
/******/return ns;
/******/};
/******/
/******/ // getDefaultExport function for compatibility with non-harmony modules
/******/__webpack_require__.n=function(module){
/******/var getter=module&&module.__esModule?
/******/function getDefault(){return module['default'];}:
/******/function getModuleExports(){return module;};
/******/__webpack_require__.d(getter,'a',getter);
/******/return getter;
/******/};
/******/
/******/ // Object.prototype.hasOwnProperty.call
/******/__webpack_require__.o=function(object,property){return Object.prototype.hasOwnProperty.call(object,property);};
/******/
/******/ // __webpack_public_path__
/******/__webpack_require__.p="/";
/******/
/******/ // on error function for async loading
/******/__webpack_require__.oe=function(err){console.error(err);throw err;};
/******/
/******/var jsonpArray=window["webpackJsonp"]=window["webpackJsonp"]||[];
/******/var oldJsonpFunction=jsonpArray.push.bind(jsonpArray);
/******/jsonpArray.push=webpackJsonpCallback;
/******/jsonpArray=jsonpArray.slice();
/******/for(var i=0;i<jsonpArray.length;i++){webpackJsonpCallback(jsonpArray[i]);}
/******/var parentJsonpFunction=oldJsonpFunction;
/******/
/******/
/******/ // Load entry module and return exports
/******/return __webpack_require__(__webpack_require__.s=0);
/******/})(
/************************************************************************/
/******/{

/***/"./node_modules/@babel/runtime/node_modules/regenerator-runtime/runtime.js":
/*!*********************************************************************************!*\
  !*** ./node_modules/@babel/runtime/node_modules/regenerator-runtime/runtime.js ***!
  \*********************************************************************************/
/*! no static exports found */
/***/function node_modulesBabelRuntimeNode_modulesRegeneratorRuntimeRuntimeJs(module,exports,__webpack_require__){

/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var runtime=function(exports){

var Op=Object.prototype;
var hasOwn=Op.hasOwnProperty;
var undefined$1;// More compressible than void 0.
var $Symbol=typeof Symbol==="function"?Symbol:{};
var iteratorSymbol=$Symbol.iterator||"@@iterator";
var asyncIteratorSymbol=$Symbol.asyncIterator||"@@asyncIterator";
var toStringTagSymbol=$Symbol.toStringTag||"@@toStringTag";

function define(obj,key,value){
Object.defineProperty(obj,key,{
value:value,
enumerable:true,
configurable:true,
writable:true});

return obj[key];
}
try{
// IE 8 has a broken Object.defineProperty that only works on DOM objects.
define({},"");
}catch(err){
define=function define(obj,key,value){
return obj[key]=value;
};
}

function wrap(innerFn,outerFn,self,tryLocsList){
// If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
var protoGenerator=outerFn&&outerFn.prototype instanceof Generator?outerFn:Generator;
var generator=Object.create(protoGenerator.prototype);
var context=new Context(tryLocsList||[]);

// The ._invoke method unifies the implementations of the .next,
// .throw, and .return methods.
generator._invoke=makeInvokeMethod(innerFn,self,context);

return generator;
}
exports.wrap=wrap;

// Try/catch helper to minimize deoptimizations. Returns a completion
// record like context.tryEntries[i].completion. This interface could
// have been (and was previously) designed to take a closure to be
// invoked without arguments, but in all the cases we care about we
// already have an existing method we want to call, so there's no need
// to create a new function object. We can even get away with assuming
// the method takes exactly one argument, since that happens to be true
// in every case, so we don't have to touch the arguments object. The
// only additional allocation required is the completion record, which
// has a stable shape and so hopefully should be cheap to allocate.
function tryCatch(fn,obj,arg){
try{
return {type:"normal",arg:fn.call(obj,arg)};
}catch(err){
return {type:"throw",arg:err};
}
}

var GenStateSuspendedStart="suspendedStart";
var GenStateSuspendedYield="suspendedYield";
var GenStateExecuting="executing";
var GenStateCompleted="completed";

// Returning this object from the innerFn has the same effect as
// breaking out of the dispatch switch statement.
var ContinueSentinel={};

// Dummy constructor functions that we use as the .constructor and
// .constructor.prototype properties for functions that return Generator
// objects. For full spec compliance, you may wish to configure your
// minifier not to mangle the names of these two functions.
function Generator(){}
function GeneratorFunction(){}
function GeneratorFunctionPrototype(){}

// This is a polyfill for %IteratorPrototype% for environments that
// don't natively support it.
var IteratorPrototype={};
IteratorPrototype[iteratorSymbol]=function(){
return this;
};

var getProto=Object.getPrototypeOf;
var NativeIteratorPrototype=getProto&&getProto(getProto(values([])));
if(NativeIteratorPrototype&&
NativeIteratorPrototype!==Op&&
hasOwn.call(NativeIteratorPrototype,iteratorSymbol)){
// This environment has a native %IteratorPrototype%; use it instead
// of the polyfill.
IteratorPrototype=NativeIteratorPrototype;
}

var Gp=GeneratorFunctionPrototype.prototype=
Generator.prototype=Object.create(IteratorPrototype);
GeneratorFunction.prototype=Gp.constructor=GeneratorFunctionPrototype;
GeneratorFunctionPrototype.constructor=GeneratorFunction;
GeneratorFunction.displayName=define(
GeneratorFunctionPrototype,
toStringTagSymbol,
"GeneratorFunction");


// Helper for defining the .next, .throw, and .return methods of the
// Iterator interface in terms of a single ._invoke method.
function defineIteratorMethods(prototype){
["next","throw","return"].forEach(function(method){
define(prototype,method,function(arg){
return this._invoke(method,arg);
});
});
}

exports.isGeneratorFunction=function(genFun){
var ctor=typeof genFun==="function"&&genFun.constructor;
return ctor?
ctor===GeneratorFunction||
// For the native GeneratorFunction constructor, the best we can
// do is to check its .name property.
(ctor.displayName||ctor.name)==="GeneratorFunction":
false;
};

exports.mark=function(genFun){
if(Object.setPrototypeOf){
Object.setPrototypeOf(genFun,GeneratorFunctionPrototype);
}else {
genFun.__proto__=GeneratorFunctionPrototype;
define(genFun,toStringTagSymbol,"GeneratorFunction");
}
genFun.prototype=Object.create(Gp);
return genFun;
};

// Within the body of any async function, `await x` is transformed to
// `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
// `hasOwn.call(value, "__await")` to determine if the yielded value is
// meant to be awaited.
exports.awrap=function(arg){
return {__await:arg};
};

function AsyncIterator(generator,PromiseImpl){
function invoke(method,arg,resolve,reject){
var record=tryCatch(generator[method],generator,arg);
if(record.type==="throw"){
reject(record.arg);
}else {
var result=record.arg;
var value=result.value;
if(value&&
typeof value==="object"&&
hasOwn.call(value,"__await")){
return PromiseImpl.resolve(value.__await).then(function(value){
invoke("next",value,resolve,reject);
},function(err){
invoke("throw",err,resolve,reject);
});
}

return PromiseImpl.resolve(value).then(function(unwrapped){
// When a yielded Promise is resolved, its final value becomes
// the .value of the Promise<{value,done}> result for the
// current iteration.
result.value=unwrapped;
resolve(result);
},function(error){
// If a rejected Promise was yielded, throw the rejection back
// into the async generator function so it can be handled there.
return invoke("throw",error,resolve,reject);
});
}
}

var previousPromise;

function enqueue(method,arg){
function callInvokeWithMethodAndArg(){
return new PromiseImpl(function(resolve,reject){
invoke(method,arg,resolve,reject);
});
}

return previousPromise=
// If enqueue has been called before, then we want to wait until
// all previous Promises have been resolved before calling invoke,
// so that results are always delivered in the correct order. If
// enqueue has not been called before, then it is important to
// call invoke immediately, without waiting on a callback to fire,
// so that the async generator function has the opportunity to do
// any necessary setup in a predictable way. This predictability
// is why the Promise constructor synchronously invokes its
// executor callback, and why async functions synchronously
// execute code before the first await. Since we implement simple
// async functions in terms of async generators, it is especially
// important to get this right, even though it requires care.
previousPromise?previousPromise.then(
callInvokeWithMethodAndArg,
// Avoid propagating failures to Promises returned by later
// invocations of the iterator.
callInvokeWithMethodAndArg):
callInvokeWithMethodAndArg();
}

// Define the unified helper method that is used to implement .next,
// .throw, and .return (see defineIteratorMethods).
this._invoke=enqueue;
}

defineIteratorMethods(AsyncIterator.prototype);
AsyncIterator.prototype[asyncIteratorSymbol]=function(){
return this;
};
exports.AsyncIterator=AsyncIterator;

// Note that simple async functions are implemented on top of
// AsyncIterator objects; they just return a Promise for the value of
// the final result produced by the iterator.
exports.async=function(innerFn,outerFn,self,tryLocsList,PromiseImpl){
if(PromiseImpl===void 0)PromiseImpl=Promise;

var iter=new AsyncIterator(
wrap(innerFn,outerFn,self,tryLocsList),
PromiseImpl);


return exports.isGeneratorFunction(outerFn)?
iter// If outerFn is a generator, return the full iterator.
:iter.next().then(function(result){
return result.done?result.value:iter.next();
});
};

function makeInvokeMethod(innerFn,self,context){
var state=GenStateSuspendedStart;

return function invoke(method,arg){
if(state===GenStateExecuting){
throw new Error("Generator is already running");
}

if(state===GenStateCompleted){
if(method==="throw"){
throw arg;
}

// Be forgiving, per 25.3.3.3.3 of the spec:
// https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
return doneResult();
}

context.method=method;
context.arg=arg;

while(true){
var delegate=context.delegate;
if(delegate){
var delegateResult=maybeInvokeDelegate(delegate,context);
if(delegateResult){
if(delegateResult===ContinueSentinel)continue;
return delegateResult;
}
}

if(context.method==="next"){
// Setting context._sent for legacy support of Babel's
// function.sent implementation.
context.sent=context._sent=context.arg;

}else if(context.method==="throw"){
if(state===GenStateSuspendedStart){
state=GenStateCompleted;
throw context.arg;
}

context.dispatchException(context.arg);

}else if(context.method==="return"){
context.abrupt("return",context.arg);
}

state=GenStateExecuting;

var record=tryCatch(innerFn,self,context);
if(record.type==="normal"){
// If an exception is thrown from innerFn, we leave state ===
// GenStateExecuting and loop back for another invocation.
state=context.done?
GenStateCompleted:
GenStateSuspendedYield;

if(record.arg===ContinueSentinel){
continue;
}

return {
value:record.arg,
done:context.done};


}else if(record.type==="throw"){
state=GenStateCompleted;
// Dispatch the exception by looping back around to the
// context.dispatchException(context.arg) call above.
context.method="throw";
context.arg=record.arg;
}
}
};
}

// Call delegate.iterator[context.method](context.arg) and handle the
// result, either by returning a { value, done } result from the
// delegate iterator, or by modifying context.method and context.arg,
// setting context.delegate to null, and returning the ContinueSentinel.
function maybeInvokeDelegate(delegate,context){
var method=delegate.iterator[context.method];
if(method===undefined$1){
// A .throw or .return when the delegate iterator has no .throw
// method always terminates the yield* loop.
context.delegate=null;

if(context.method==="throw"){
// Note: ["return"] must be used for ES3 parsing compatibility.
if(delegate.iterator["return"]){
// If the delegate iterator has a return method, give it a
// chance to clean up.
context.method="return";
context.arg=undefined$1;
maybeInvokeDelegate(delegate,context);

if(context.method==="throw"){
// If maybeInvokeDelegate(context) changed context.method from
// "return" to "throw", let that override the TypeError below.
return ContinueSentinel;
}
}

context.method="throw";
context.arg=new TypeError(
"The iterator does not provide a 'throw' method");
}

return ContinueSentinel;
}

var record=tryCatch(method,delegate.iterator,context.arg);

if(record.type==="throw"){
context.method="throw";
context.arg=record.arg;
context.delegate=null;
return ContinueSentinel;
}

var info=record.arg;

if(!info){
context.method="throw";
context.arg=new TypeError("iterator result is not an object");
context.delegate=null;
return ContinueSentinel;
}

if(info.done){
// Assign the result of the finished delegate to the temporary
// variable specified by delegate.resultName (see delegateYield).
context[delegate.resultName]=info.value;

// Resume execution at the desired location (see delegateYield).
context.next=delegate.nextLoc;

// If context.method was "throw" but the delegate handled the
// exception, let the outer generator proceed normally. If
// context.method was "next", forget context.arg since it has been
// "consumed" by the delegate iterator. If context.method was
// "return", allow the original .return call to continue in the
// outer generator.
if(context.method!=="return"){
context.method="next";
context.arg=undefined$1;
}

}else {
// Re-yield the result returned by the delegate method.
return info;
}

// The delegate iterator is finished, so forget it and continue with
// the outer generator.
context.delegate=null;
return ContinueSentinel;
}

// Define Generator.prototype.{next,throw,return} in terms of the
// unified ._invoke helper method.
defineIteratorMethods(Gp);

define(Gp,toStringTagSymbol,"Generator");

// A Generator should always return itself as the iterator object when the
// @@iterator function is called on it. Some browsers' implementations of the
// iterator prototype chain incorrectly implement this, causing the Generator
// object to not be returned from this call. This ensures that doesn't happen.
// See https://github.com/facebook/regenerator/issues/274 for more details.
Gp[iteratorSymbol]=function(){
return this;
};

Gp.toString=function(){
return "[object Generator]";
};

function pushTryEntry(locs){
var entry={tryLoc:locs[0]};

if(1 in locs){
entry.catchLoc=locs[1];
}

if(2 in locs){
entry.finallyLoc=locs[2];
entry.afterLoc=locs[3];
}

this.tryEntries.push(entry);
}

function resetTryEntry(entry){
var record=entry.completion||{};
record.type="normal";
delete record.arg;
entry.completion=record;
}

function Context(tryLocsList){
// The root entry object (effectively a try statement without a catch
// or a finally block) gives us a place to store values thrown from
// locations where there is no enclosing try statement.
this.tryEntries=[{tryLoc:"root"}];
tryLocsList.forEach(pushTryEntry,this);
this.reset(true);
}

exports.keys=function(object){
var keys=[];
for(var key in object){
keys.push(key);
}
keys.reverse();

// Rather than returning an object with a next method, we keep
// things simple and return the next function itself.
return function next(){
while(keys.length){
var key=keys.pop();
if(key in object){
next.value=key;
next.done=false;
return next;
}
}

// To avoid creating an additional object, we just hang the .value
// and .done properties off the next function object itself. This
// also ensures that the minifier will not anonymize the function.
next.done=true;
return next;
};
};

function values(iterable){
if(iterable){
var iteratorMethod=iterable[iteratorSymbol];
if(iteratorMethod){
return iteratorMethod.call(iterable);
}

if(typeof iterable.next==="function"){
return iterable;
}

if(!isNaN(iterable.length)){
var i=-1,next=function next(){
while(++i<iterable.length){
if(hasOwn.call(iterable,i)){
next.value=iterable[i];
next.done=false;
return next;
}
}

next.value=undefined$1;
next.done=true;

return next;
};

return next.next=next;
}
}

// Return an iterator with no values.
return {next:doneResult};
}
exports.values=values;

function doneResult(){
return {value:undefined$1,done:true};
}

Context.prototype={
constructor:Context,

reset:function reset(skipTempReset){
this.prev=0;
this.next=0;
// Resetting context._sent for legacy support of Babel's
// function.sent implementation.
this.sent=this._sent=undefined$1;
this.done=false;
this.delegate=null;

this.method="next";
this.arg=undefined$1;

this.tryEntries.forEach(resetTryEntry);

if(!skipTempReset){
for(var name in this){
// Not sure about the optimal order of these conditions:
if(name.charAt(0)==="t"&&
hasOwn.call(this,name)&&
!isNaN(+name.slice(1))){
this[name]=undefined$1;
}
}
}
},

stop:function stop(){
this.done=true;

var rootEntry=this.tryEntries[0];
var rootRecord=rootEntry.completion;
if(rootRecord.type==="throw"){
throw rootRecord.arg;
}

return this.rval;
},

dispatchException:function dispatchException(exception){
if(this.done){
throw exception;
}

var context=this;
function handle(loc,caught){
record.type="throw";
record.arg=exception;
context.next=loc;

if(caught){
// If the dispatched exception was caught by a catch block,
// then let that catch block handle the exception normally.
context.method="next";
context.arg=undefined$1;
}

return !!caught;
}

for(var i=this.tryEntries.length-1;i>=0;--i){
var entry=this.tryEntries[i];
var record=entry.completion;

if(entry.tryLoc==="root"){
// Exception thrown outside of any try block that could handle
// it, so set the completion value of the entire function to
// throw the exception.
return handle("end");
}

if(entry.tryLoc<=this.prev){
var hasCatch=hasOwn.call(entry,"catchLoc");
var hasFinally=hasOwn.call(entry,"finallyLoc");

if(hasCatch&&hasFinally){
if(this.prev<entry.catchLoc){
return handle(entry.catchLoc,true);
}else if(this.prev<entry.finallyLoc){
return handle(entry.finallyLoc);
}

}else if(hasCatch){
if(this.prev<entry.catchLoc){
return handle(entry.catchLoc,true);
}

}else if(hasFinally){
if(this.prev<entry.finallyLoc){
return handle(entry.finallyLoc);
}

}else {
throw new Error("try statement without catch or finally");
}
}
}
},

abrupt:function abrupt(type,arg){
for(var i=this.tryEntries.length-1;i>=0;--i){
var entry=this.tryEntries[i];
if(entry.tryLoc<=this.prev&&
hasOwn.call(entry,"finallyLoc")&&
this.prev<entry.finallyLoc){
var finallyEntry=entry;
break;
}
}

if(finallyEntry&&(
type==="break"||
type==="continue")&&
finallyEntry.tryLoc<=arg&&
arg<=finallyEntry.finallyLoc){
// Ignore the finally entry if control is not jumping to a
// location outside the try/catch block.
finallyEntry=null;
}

var record=finallyEntry?finallyEntry.completion:{};
record.type=type;
record.arg=arg;

if(finallyEntry){
this.method="next";
this.next=finallyEntry.finallyLoc;
return ContinueSentinel;
}

return this.complete(record);
},

complete:function complete(record,afterLoc){
if(record.type==="throw"){
throw record.arg;
}

if(record.type==="break"||
record.type==="continue"){
this.next=record.arg;
}else if(record.type==="return"){
this.rval=this.arg=record.arg;
this.method="return";
this.next="end";
}else if(record.type==="normal"&&afterLoc){
this.next=afterLoc;
}

return ContinueSentinel;
},

finish:function finish(finallyLoc){
for(var i=this.tryEntries.length-1;i>=0;--i){
var entry=this.tryEntries[i];
if(entry.finallyLoc===finallyLoc){
this.complete(entry.completion,entry.afterLoc);
resetTryEntry(entry);
return ContinueSentinel;
}
}
},

"catch":function _catch(tryLoc){
for(var i=this.tryEntries.length-1;i>=0;--i){
var entry=this.tryEntries[i];
if(entry.tryLoc===tryLoc){
var record=entry.completion;
if(record.type==="throw"){
var thrown=record.arg;
resetTryEntry(entry);
}
return thrown;
}
}

// The context.catch method must only be called with a location
// argument that corresponds to a known catch block.
throw new Error("illegal catch attempt");
},

delegateYield:function delegateYield(iterable,resultName,nextLoc){
this.delegate={
iterator:values(iterable),
resultName:resultName,
nextLoc:nextLoc};


if(this.method==="next"){
// Deliberately forget the last sent value so that we don't
// accidentally pass it on to the delegate.
this.arg=undefined$1;
}

return ContinueSentinel;
}};


// Regardless of whether this script is executing as a CommonJS module
// or not, return the runtime object so that we can declare the variable
// regeneratorRuntime in the outer scope, which allows this module to be
// injected easily by `bin/regenerator --include-runtime script.js`.
return exports;

}(
// If this script is executing as a CommonJS module, use module.exports
// as the regeneratorRuntime namespace. Otherwise create a new empty
// object. Either way, the resulting object will be used to initialize
// the regeneratorRuntime variable at the top of this file.
module.exports);


try{
regeneratorRuntime=runtime;
}catch(accidentalStrictMode){
// This module should not be running in strict mode, so the above
// assignment should always work unless something is misconfigured. Just
// in case runtime.js accidentally runs in strict mode, we can escape
// strict mode using a global Function call. This could conceivably fail
// if a Content Security Policy forbids using Function, but in that case
// the proper solution is to fix the accidental strict mode problem. If
// you've misconfigured your bundler to force strict mode and applied a
// CSP to forbid Function, and you're not willing to fix either of those
// problems, please detail your unique predicament in a GitHub issue.
Function("r","regeneratorRuntime = r")(runtime);
}


/***/},

/***/"./node_modules/@babel/runtime/regenerator/index.js":
/*!**********************************************************!*\
  !*** ./node_modules/@babel/runtime/regenerator/index.js ***!
  \**********************************************************/
/*! no static exports found */
/***/function node_modulesBabelRuntimeRegeneratorIndexJs(module,exports,__webpack_require__){

module.exports=__webpack_require__(/*! regenerator-runtime */"./node_modules/@babel/runtime/node_modules/regenerator-runtime/runtime.js");


/***/},

/***/"./node_modules/@trevoreyre/autocomplete-vue/dist/autocomplete.esm.js":
/*!****************************************************************************!*\
  !*** ./node_modules/@trevoreyre/autocomplete-vue/dist/autocomplete.esm.js ***!
  \****************************************************************************/
/*! exports provided: default */
/***/function node_modulesTrevoreyreAutocompleteVueDistAutocompleteEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* WEBPACK VAR INJECTION */(function(global){function _classCallCheck(instance,Constructor){
if(!(instance instanceof Constructor)){
throw new TypeError("Cannot call a class as a function");
}
}

function _defineProperty(obj,key,value){
if(key in obj){
Object.defineProperty(obj,key,{
value:value,
enumerable:true,
configurable:true,
writable:true});

}else {
obj[key]=value;
}

return obj;
}

function ownKeys(object,enumerableOnly){
var keys=Object.keys(object);

if(Object.getOwnPropertySymbols){
var symbols=Object.getOwnPropertySymbols(object);
if(enumerableOnly)symbols=symbols.filter(function(sym){
return Object.getOwnPropertyDescriptor(object,sym).enumerable;
});
keys.push.apply(keys,symbols);
}

return keys;
}

function _objectSpread2(target){
for(var i=1;i<arguments.length;i++){
var source=arguments[i]!=null?arguments[i]:{};

if(i%2){
ownKeys(Object(source),true).forEach(function(key){
_defineProperty(target,key,source[key]);
});
}else if(Object.getOwnPropertyDescriptors){
Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));
}else {
ownKeys(Object(source)).forEach(function(key){
Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));
});
}
}

return target;
}

// Polyfill for element.matches, to support Internet Explorer. It's a relatively
// simple polyfill, so we'll just include it rather than require the user to
// include the polyfill themselves. Adapted from
// https://developer.mozilla.org/en-US/docs/Web/API/Element/matches#Polyfill
var matches=function matches(element,selector){
return element.matches?element.matches(selector):element.msMatchesSelector?element.msMatchesSelector(selector):element.webkitMatchesSelector?element.webkitMatchesSelector(selector):null;
};

// Polyfill for element.closest, to support Internet Explorer. It's a relatively

var closestPolyfill=function closestPolyfill(el,selector){
var element=el;

while(element&&element.nodeType===1){
if(matches(element,selector)){
return element;
}

element=element.parentNode;
}

return null;
};

var closest=function closest(element,selector){
return element.closest?element.closest(selector):closestPolyfill(element,selector);
};

// Returns true if the value has a "then" function. Adapted from
// https://github.com/graphql/graphql-js/blob/499a75939f70c4863d44149371d6a99d57ff7c35/src/jsutils/isPromise.js
var isPromise=function isPromise(value){
return Boolean(value&&typeof value.then==='function');
};

var AutocompleteCore=function AutocompleteCore(){
var _this=this;

var _ref=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{},
search=_ref.search,
_ref$autoSelect=_ref.autoSelect,
autoSelect=_ref$autoSelect===void 0?false:_ref$autoSelect,
_ref$setValue=_ref.setValue,
setValue=_ref$setValue===void 0?function(){}:_ref$setValue,
_ref$setAttribute=_ref.setAttribute,
setAttribute=_ref$setAttribute===void 0?function(){}:_ref$setAttribute,
_ref$onUpdate=_ref.onUpdate,
onUpdate=_ref$onUpdate===void 0?function(){}:_ref$onUpdate,
_ref$onSubmit=_ref.onSubmit,
onSubmit=_ref$onSubmit===void 0?function(){}:_ref$onSubmit,
_ref$onShow=_ref.onShow,
onShow=_ref$onShow===void 0?function(){}:_ref$onShow,
_ref$onHide=_ref.onHide,
onHide=_ref$onHide===void 0?function(){}:_ref$onHide,
_ref$onLoading=_ref.onLoading,
onLoading=_ref$onLoading===void 0?function(){}:_ref$onLoading,
_ref$onLoaded=_ref.onLoaded,
onLoaded=_ref$onLoaded===void 0?function(){}:_ref$onLoaded;

_classCallCheck(this,AutocompleteCore);

_defineProperty(this,"value",'');

_defineProperty(this,"searchCounter",0);

_defineProperty(this,"results",[]);

_defineProperty(this,"selectedIndex",-1);

_defineProperty(this,"handleInput",function(event){
var value=event.target.value;

_this.updateResults(value);

_this.value=value;
});

_defineProperty(this,"handleKeyDown",function(event){
var key=event.key;

switch(key){
case'Up':// IE/Edge

case'Down':// IE/Edge

case'ArrowUp':
case'ArrowDown':
{
var selectedIndex=key==='ArrowUp'||key==='Up'?_this.selectedIndex-1:_this.selectedIndex+1;
event.preventDefault();

_this.handleArrows(selectedIndex);

break;
}

case'Tab':
{
_this.selectResult();

break;
}

case'Enter':
{
var selectedResult=_this.results[_this.selectedIndex];

_this.selectResult();

_this.onSubmit(selectedResult);

break;
}

case'Esc':// IE/Edge

case'Escape':
{
_this.hideResults();

_this.setValue();

break;
}

default:
return;}

});

_defineProperty(this,"handleFocus",function(event){
var value=event.target.value;

_this.updateResults(value);

_this.value=value;
});

_defineProperty(this,"handleBlur",function(){
_this.hideResults();
});

_defineProperty(this,"handleResultMouseDown",function(event){
event.preventDefault();
});

_defineProperty(this,"handleResultClick",function(event){
var target=event.target;
var result=closest(target,'[data-result-index]');

if(result){
_this.selectedIndex=parseInt(result.dataset.resultIndex,10);
var selectedResult=_this.results[_this.selectedIndex];

_this.selectResult();

_this.onSubmit(selectedResult);
}
});

_defineProperty(this,"handleArrows",function(selectedIndex){
// Loop selectedIndex back to first or last result if out of bounds
var resultsCount=_this.results.length;
_this.selectedIndex=(selectedIndex%resultsCount+resultsCount)%resultsCount;// Update results and aria attributes

_this.onUpdate(_this.results,_this.selectedIndex);
});

_defineProperty(this,"selectResult",function(){
var selectedResult=_this.results[_this.selectedIndex];

if(selectedResult){
_this.setValue(selectedResult);
}

_this.hideResults();
});

_defineProperty(this,"updateResults",function(value){
var currentSearch=++_this.searchCounter;

_this.onLoading();

_this.search(value).then(function(results){
if(currentSearch!==_this.searchCounter){
return;
}

_this.results=results;

_this.onLoaded();

if(_this.results.length===0){
_this.hideResults();

return;
}

_this.selectedIndex=_this.autoSelect?0:-1;

_this.onUpdate(_this.results,_this.selectedIndex);

_this.showResults();
});
});

_defineProperty(this,"showResults",function(){
_this.setAttribute('aria-expanded',true);

_this.onShow();
});

_defineProperty(this,"hideResults",function(){
_this.selectedIndex=-1;
_this.results=[];

_this.setAttribute('aria-expanded',false);

_this.setAttribute('aria-activedescendant','');

_this.onUpdate(_this.results,_this.selectedIndex);

_this.onHide();
});

_defineProperty(this,"checkSelectedResultVisible",function(resultsElement){
var selectedResultElement=resultsElement.querySelector("[data-result-index=\"".concat(_this.selectedIndex,"\"]"));

if(!selectedResultElement){
return;
}

var resultsPosition=resultsElement.getBoundingClientRect();
var selectedPosition=selectedResultElement.getBoundingClientRect();

if(selectedPosition.top<resultsPosition.top){
// Element is above viewable area
resultsElement.scrollTop-=resultsPosition.top-selectedPosition.top;
}else if(selectedPosition.bottom>resultsPosition.bottom){
// Element is below viewable area
resultsElement.scrollTop+=selectedPosition.bottom-resultsPosition.bottom;
}
});

this.search=isPromise(search)?search:function(value){
return Promise.resolve(search(value));
};
this.autoSelect=autoSelect;
this.setValue=setValue;
this.setAttribute=setAttribute;
this.onUpdate=onUpdate;
this.onSubmit=onSubmit;
this.onShow=onShow;
this.onHide=onHide;
this.onLoading=onLoading;
this.onLoaded=onLoaded;
};

// Generates a unique ID, with optional prefix. Adapted from
// https://github.com/lodash/lodash/blob/61acdd0c295e4447c9c10da04e287b1ebffe452c/uniqueId.js
var idCounter=0;

var uniqueId=function uniqueId(){
var prefix=arguments.length>0&&arguments[0]!==undefined?arguments[0]:'';
return "".concat(prefix).concat(++idCounter);
};

// Calculates whether element2 should be above or below element1. Always
// places element2 below unless all of the following:
// 1. There isn't enough visible viewport below to fit element2
// 2. There is more room above element1 than there is below
// 3. Placing elemen2 above 1 won't overflow window
var getRelativePosition=function getRelativePosition(element1,element2){
var position1=element1.getBoundingClientRect();
var position2=element2.getBoundingClientRect();
var positionAbove=
/* 1 */
position1.bottom+position2.height>window.innerHeight&&
/* 2 */
window.innerHeight-position1.bottom<position1.top&&
/* 3 */
window.pageYOffset+position1.top-position2.height>0;
return positionAbove?'above':'below';
};

// Credit David Walsh (https://davidwalsh.name/javascript-debounce-function)
// Returns a function, that, as long as it continues to be invoked, will not
// be triggered. The function will be called after it stops being called for
// N milliseconds. If `immediate` is passed, trigger the function on the
// leading edge, instead of the trailing.
var debounce=function debounce(func,wait,immediate){
var timeout;
return function executedFunction(){
var context=this;
var args=arguments;

var later=function later(){
timeout=null;
if(!immediate)func.apply(context,args);
};

var callNow=immediate&&!timeout;
clearTimeout(timeout);
timeout=setTimeout(later,wait);
if(callNow)func.apply(context,args);
};
};

var script={
name:'Autocomplete',
inheritAttrs:false,
props:{
search:{
type:Function,
required:true},

baseClass:{
type:String,
"default":'autocomplete'},

autoSelect:{
type:Boolean,
"default":false},

getResultValue:{
type:Function,
"default":function _default(result){
return result;
}},

defaultValue:{
type:String,
"default":''},

debounceTime:{
type:Number,
"default":0}},


data:function data(){
var core=new AutocompleteCore({
search:this.search,
autoSelect:this.autoSelect,
setValue:this.setValue,
onUpdate:this.handleUpdate,
onSubmit:this.handleSubmit,
onShow:this.handleShow,
onHide:this.handleHide,
onLoading:this.handleLoading,
onLoaded:this.handleLoaded});


if(this.debounceTime>0){
core.handleInput=debounce(core.handleInput,this.debounceTime);
}

return {
core:core,
value:this.defaultValue,
resultListId:uniqueId("".concat(this.baseClass,"-result-list-")),
results:[],
selectedIndex:-1,
expanded:false,
loading:false,
position:'below',
resetPosition:true};

},
computed:{
rootProps:function rootProps(){
return {
"class":this.baseClass,
style:{
position:'relative'},

'data-expanded':this.expanded,
'data-loading':this.loading,
'data-position':this.position};

},
inputProps:function inputProps(){
return _objectSpread2({
"class":"".concat(this.baseClass,"-input"),
value:this.value,
role:'combobox',
autocomplete:'off',
autocapitalize:'off',
autocorrect:'off',
spellcheck:'false',
'aria-autocomplete':'list',
'aria-haspopup':'listbox',
'aria-owns':this.resultListId,
'aria-expanded':this.expanded?'true':'false',
'aria-activedescendant':this.selectedIndex>-1?this.resultProps[this.selectedIndex].id:''},
this.$attrs);
},
inputListeners:function inputListeners(){
return {
input:this.handleInput,
keydown:this.core.handleKeyDown,
focus:this.core.handleFocus,
blur:this.core.handleBlur};

},
resultListProps:function resultListProps(){
var yPosition=this.position==='below'?'top':'bottom';
return {
id:this.resultListId,
"class":"".concat(this.baseClass,"-result-list"),
role:'listbox',
style:_defineProperty({
position:'absolute',
zIndex:1,
width:'100%',
visibility:this.expanded?'visible':'hidden',
pointerEvents:this.expanded?'auto':'none'},
yPosition,'100%')};

},
resultListListeners:function resultListListeners(){
return {
mousedown:this.core.handleResultMouseDown,
click:this.core.handleResultClick};

},
resultProps:function resultProps(){
var _this=this;

return this.results.map(function(result,index){
return _objectSpread2({
id:"".concat(_this.baseClass,"-result-").concat(index),
"class":"".concat(_this.baseClass,"-result"),
'data-result-index':index,
role:'option'},
_this.selectedIndex===index?{
'aria-selected':'true'}:
{});
});
}},

mounted:function mounted(){
document.body.addEventListener('click',this.handleDocumentClick);
},
beforeDestroy:function beforeDestroy(){
document.body.removeEventListener('click',this.handleDocumentClick);
},
updated:function updated(){
if(!this.$refs.input||!this.$refs.resultList){
return;
}

if(this.resetPosition&&this.results.length>0){
this.resetPosition=false;
this.position=getRelativePosition(this.$refs.input,this.$refs.resultList);
}

this.core.checkSelectedResultVisible(this.$refs.resultList);
},
methods:{
setValue:function setValue(result){
this.value=result?this.getResultValue(result):'';
},
handleUpdate:function handleUpdate(results,selectedIndex){
this.results=results;
this.selectedIndex=selectedIndex;
this.$emit('update',results,selectedIndex);
},
handleShow:function handleShow(){
this.expanded=true;
},
handleHide:function handleHide(){
this.expanded=false;
this.resetPosition=true;
},
handleLoading:function handleLoading(){
this.loading=true;
},
handleLoaded:function handleLoaded(){
this.loading=false;
},
handleInput:function handleInput(event){
this.value=event.target.value;
this.core.handleInput(event);
},
handleSubmit:function handleSubmit(selectedResult){
this.$emit('submit',selectedResult);
},
handleDocumentClick:function handleDocumentClick(event){
if(this.$refs.root.contains(event.target)){
return;
}

this.core.hideResults();
}}};



function normalizeComponent(template,style,script,scopeId,isFunctionalTemplate,moduleIdentifier/* server only */,shadowMode,createInjector,createInjectorSSR,createInjectorShadow){
if(typeof shadowMode!=='boolean'){
createInjectorSSR=createInjector;
createInjector=shadowMode;
shadowMode=false;
}
// Vue.extend constructor export interop.
var options=typeof script==='function'?script.options:script;
// render functions
if(template&&template.render){
options.render=template.render;
options.staticRenderFns=template.staticRenderFns;
options._compiled=true;
// functional template
if(isFunctionalTemplate){
options.functional=true;
}
}
// scopedId
if(scopeId){
options._scopeId=scopeId;
}
var hook;
if(moduleIdentifier){
// server build
hook=function hook(context){
// 2.3 injection
context=
context||// cached call
this.$vnode&&this.$vnode.ssrContext||// stateful
this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext;// functional
// 2.2 with runInNewContext: true
if(!context&&typeof __VUE_SSR_CONTEXT__!=='undefined'){
context=__VUE_SSR_CONTEXT__;
}
// inject component styles
if(style){
style.call(this,createInjectorSSR(context));
}
// register component module identifier for async chunk inference
if(context&&context._registeredComponents){
context._registeredComponents.add(moduleIdentifier);
}
};
// used by ssr in case component is cached and beforeCreate
// never gets called
options._ssrRegister=hook;
}else
if(style){
hook=shadowMode?
function(context){
style.call(this,createInjectorShadow(context,this.$root.$options.shadowRoot));
}:
function(context){
style.call(this,createInjector(context));
};
}
if(hook){
if(options.functional){
// register for functional component in vue file
var originalRender=options.render;
options.render=function renderWithStyleInjection(h,context){
hook.call(context);
return originalRender(h,context);
};
}else
{
// inject component registration as beforeCreate hook
var existing=options.beforeCreate;
options.beforeCreate=existing?[].concat(existing,hook):[hook];
}
}
return script;
}

/* script */
var __vue_script__=script;

/* template */
var __vue_render__=function __vue_render__(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{ref:"root"},[_vm._t("default",[_c('div',_vm._b({},'div',_vm.rootProps,false),[_c('input',_vm._g(_vm._b({ref:"input",on:{"input":_vm.handleInput,"keydown":_vm.core.handleKeyDown,"focus":_vm.core.handleFocus,"blur":_vm.core.handleBlur}},'input',_vm.inputProps,false),_vm.$listeners)),_vm._v(" "),_c('ul',_vm._g(_vm._b({ref:"resultList"},'ul',_vm.resultListProps,false),_vm.resultListListeners),[_vm._l(_vm.results,function(result,index){return [_vm._t("result",[_c('li',_vm._b({key:_vm.resultProps[index].id},'li',_vm.resultProps[index],false),[_vm._v("\n              "+_vm._s(_vm.getResultValue(result))+"\n            ")])],{"result":result,"props":_vm.resultProps[index]})];})],2)])],{"rootProps":_vm.rootProps,"inputProps":_vm.inputProps,"inputListeners":_vm.inputListeners,"resultListProps":_vm.resultListProps,"resultListListeners":_vm.resultListListeners,"results":_vm.results,"resultProps":_vm.resultProps})],2);};
var __vue_staticRenderFns__=[];

/* style */
var __vue_inject_styles__=undefined;
/* scoped */
var __vue_scope_id__=undefined;
/* module identifier */
var __vue_module_identifier__=undefined;
/* functional template */
var __vue_is_functional_template__=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */



var __vue_component__=normalizeComponent(
{render:__vue_render__,staticRenderFns:__vue_staticRenderFns__},
__vue_inject_styles__,
__vue_script__,
__vue_scope_id__,
__vue_is_functional_template__,
__vue_module_identifier__,
false,
undefined,
undefined,
undefined);


function install(Vue){
if(install.installed){
return;
}

install.installed=true;
Vue.component('Autocomplete',__vue_component__);
}

var plugin={
install:install};
// Auto install if Vue is found

var GlobalVue;

if(typeof window!=='undefined'){
GlobalVue=window.Vue;
}else if(typeof global!=='undefined'){
GlobalVue=global.Vue;
}

if(GlobalVue){
GlobalVue.use(plugin);
}// Inject install function into component. Allows component to be registered via
// Vue.use() as well as Vue.component()


__vue_component__.install=install;

/* harmony default export */__webpack_exports__["default"]=__vue_component__;

/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"));

/***/},

/***/"./node_modules/@trevoreyre/autocomplete-vue/dist/style.css":
/*!******************************************************************!*\
  !*** ./node_modules/@trevoreyre/autocomplete-vue/dist/style.css ***!
  \******************************************************************/
/*! no static exports found */
/***/function node_modulesTrevoreyreAutocompleteVueDistStyleCss(module,exports,__webpack_require__){


var content=__webpack_require__(/*! !../../../css-loader??ref--6-1!../../../postcss-loader/src??ref--6-2!./style.css */"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/@trevoreyre/autocomplete-vue/dist/style.css");

if(typeof content==='string')content=[[module.i,content,'']];

var transform;



var options={"hmr":true};

options.transform=transform;
options.insertInto=undefined;

var update=__webpack_require__(/*! ../../../style-loader/lib/addStyles.js */"./node_modules/style-loader/lib/addStyles.js")(content,options);

if(content.locals)module.exports=content.locals;

/***/},

/***/"./node_modules/axios/index.js":
/*!*************************************!*\
  !*** ./node_modules/axios/index.js ***!
  \*************************************/
/*! no static exports found */
/***/function node_modulesAxiosIndexJs(module,exports,__webpack_require__){

module.exports=__webpack_require__(/*! ./lib/axios */"./node_modules/axios/lib/axios.js");

/***/},

/***/"./node_modules/axios/lib/adapters/xhr.js":
/*!************************************************!*\
  !*** ./node_modules/axios/lib/adapters/xhr.js ***!
  \************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibAdaptersXhrJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");
var settle=__webpack_require__(/*! ./../core/settle */"./node_modules/axios/lib/core/settle.js");
var buildURL=__webpack_require__(/*! ./../helpers/buildURL */"./node_modules/axios/lib/helpers/buildURL.js");
var buildFullPath=__webpack_require__(/*! ../core/buildFullPath */"./node_modules/axios/lib/core/buildFullPath.js");
var parseHeaders=__webpack_require__(/*! ./../helpers/parseHeaders */"./node_modules/axios/lib/helpers/parseHeaders.js");
var isURLSameOrigin=__webpack_require__(/*! ./../helpers/isURLSameOrigin */"./node_modules/axios/lib/helpers/isURLSameOrigin.js");
var createError=__webpack_require__(/*! ../core/createError */"./node_modules/axios/lib/core/createError.js");

module.exports=function xhrAdapter(config){
return new Promise(function dispatchXhrRequest(resolve,reject){
var requestData=config.data;
var requestHeaders=config.headers;

if(utils.isFormData(requestData)){
delete requestHeaders['Content-Type'];// Let the browser set it
}

var request=new XMLHttpRequest();

// HTTP basic authentication
if(config.auth){
var username=config.auth.username||'';
var password=config.auth.password||'';
requestHeaders.Authorization='Basic '+btoa(username+':'+password);
}

var fullPath=buildFullPath(config.baseURL,config.url);
request.open(config.method.toUpperCase(),buildURL(fullPath,config.params,config.paramsSerializer),true);

// Set the request timeout in MS
request.timeout=config.timeout;

// Listen for ready state
request.onreadystatechange=function handleLoad(){
if(!request||request.readyState!==4){
return;
}

// The request errored out and we didn't get a response, this will be
// handled by onerror instead
// With one exception: request that using file: protocol, most browsers
// will return status as 0 even though it's a successful request
if(request.status===0&&!(request.responseURL&&request.responseURL.indexOf('file:')===0)){
return;
}

// Prepare the response
var responseHeaders='getAllResponseHeaders'in request?parseHeaders(request.getAllResponseHeaders()):null;
var responseData=!config.responseType||config.responseType==='text'?request.responseText:request.response;
var response={
data:responseData,
status:request.status,
statusText:request.statusText,
headers:responseHeaders,
config:config,
request:request};


settle(resolve,reject,response);

// Clean up request
request=null;
};

// Handle browser request cancellation (as opposed to a manual cancellation)
request.onabort=function handleAbort(){
if(!request){
return;
}

reject(createError('Request aborted',config,'ECONNABORTED',request));

// Clean up request
request=null;
};

// Handle low level network errors
request.onerror=function handleError(){
// Real errors are hidden from us by the browser
// onerror should only fire if it's a network error
reject(createError('Network Error',config,null,request));

// Clean up request
request=null;
};

// Handle timeout
request.ontimeout=function handleTimeout(){
var timeoutErrorMessage='timeout of '+config.timeout+'ms exceeded';
if(config.timeoutErrorMessage){
timeoutErrorMessage=config.timeoutErrorMessage;
}
reject(createError(timeoutErrorMessage,config,'ECONNABORTED',
request));

// Clean up request
request=null;
};

// Add xsrf header
// This is only done if running in a standard browser environment.
// Specifically not if we're in a web worker, or react-native.
if(utils.isStandardBrowserEnv()){
var cookies=__webpack_require__(/*! ./../helpers/cookies */"./node_modules/axios/lib/helpers/cookies.js");

// Add xsrf header
var xsrfValue=(config.withCredentials||isURLSameOrigin(fullPath))&&config.xsrfCookieName?
cookies.read(config.xsrfCookieName):
undefined;

if(xsrfValue){
requestHeaders[config.xsrfHeaderName]=xsrfValue;
}
}

// Add headers to the request
if('setRequestHeader'in request){
utils.forEach(requestHeaders,function setRequestHeader(val,key){
if(typeof requestData==='undefined'&&key.toLowerCase()==='content-type'){
// Remove Content-Type if data is undefined
delete requestHeaders[key];
}else {
// Otherwise add header to the request
request.setRequestHeader(key,val);
}
});
}

// Add withCredentials to request if needed
if(!utils.isUndefined(config.withCredentials)){
request.withCredentials=!!config.withCredentials;
}

// Add responseType to request if needed
if(config.responseType){
try{
request.responseType=config.responseType;
}catch(e){
// Expected DOMException thrown by browsers not compatible XMLHttpRequest Level 2.
// But, this can be suppressed for 'json' type as it can be parsed by default 'transformResponse' function.
if(config.responseType!=='json'){
throw e;
}
}
}

// Handle progress if needed
if(typeof config.onDownloadProgress==='function'){
request.addEventListener('progress',config.onDownloadProgress);
}

// Not all browsers support upload events
if(typeof config.onUploadProgress==='function'&&request.upload){
request.upload.addEventListener('progress',config.onUploadProgress);
}

if(config.cancelToken){
// Handle cancellation
config.cancelToken.promise.then(function onCanceled(cancel){
if(!request){
return;
}

request.abort();
reject(cancel);
// Clean up request
request=null;
});
}

if(requestData===undefined){
requestData=null;
}

// Send the request
request.send(requestData);
});
};


/***/},

/***/"./node_modules/axios/lib/axios.js":
/*!*****************************************!*\
  !*** ./node_modules/axios/lib/axios.js ***!
  \*****************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibAxiosJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./utils */"./node_modules/axios/lib/utils.js");
var bind=__webpack_require__(/*! ./helpers/bind */"./node_modules/axios/lib/helpers/bind.js");
var Axios=__webpack_require__(/*! ./core/Axios */"./node_modules/axios/lib/core/Axios.js");
var mergeConfig=__webpack_require__(/*! ./core/mergeConfig */"./node_modules/axios/lib/core/mergeConfig.js");
var defaults=__webpack_require__(/*! ./defaults */"./node_modules/axios/lib/defaults.js");

/**
 * Create an instance of Axios
 *
 * @param {Object} defaultConfig The default config for the instance
 * @return {Axios} A new instance of Axios
 */
function createInstance(defaultConfig){
var context=new Axios(defaultConfig);
var instance=bind(Axios.prototype.request,context);

// Copy axios.prototype to instance
utils.extend(instance,Axios.prototype,context);

// Copy context to instance
utils.extend(instance,context);

return instance;
}

// Create the default instance to be exported
var axios=createInstance(defaults);

// Expose Axios class to allow class inheritance
axios.Axios=Axios;

// Factory for creating new instances
axios.create=function create(instanceConfig){
return createInstance(mergeConfig(axios.defaults,instanceConfig));
};

// Expose Cancel & CancelToken
axios.Cancel=__webpack_require__(/*! ./cancel/Cancel */"./node_modules/axios/lib/cancel/Cancel.js");
axios.CancelToken=__webpack_require__(/*! ./cancel/CancelToken */"./node_modules/axios/lib/cancel/CancelToken.js");
axios.isCancel=__webpack_require__(/*! ./cancel/isCancel */"./node_modules/axios/lib/cancel/isCancel.js");

// Expose all/spread
axios.all=function all(promises){
return Promise.all(promises);
};
axios.spread=__webpack_require__(/*! ./helpers/spread */"./node_modules/axios/lib/helpers/spread.js");

module.exports=axios;

// Allow use of default import syntax in TypeScript
module.exports.default=axios;


/***/},

/***/"./node_modules/axios/lib/cancel/Cancel.js":
/*!*************************************************!*\
  !*** ./node_modules/axios/lib/cancel/Cancel.js ***!
  \*************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCancelCancelJs(module,exports,__webpack_require__){


/**
 * A `Cancel` is an object that is thrown when an operation is canceled.
 *
 * @class
 * @param {string=} message The message.
 */
function Cancel(message){
this.message=message;
}

Cancel.prototype.toString=function toString(){
return 'Cancel'+(this.message?': '+this.message:'');
};

Cancel.prototype.__CANCEL__=true;

module.exports=Cancel;


/***/},

/***/"./node_modules/axios/lib/cancel/CancelToken.js":
/*!******************************************************!*\
  !*** ./node_modules/axios/lib/cancel/CancelToken.js ***!
  \******************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCancelCancelTokenJs(module,exports,__webpack_require__){


var Cancel=__webpack_require__(/*! ./Cancel */"./node_modules/axios/lib/cancel/Cancel.js");

/**
 * A `CancelToken` is an object that can be used to request cancellation of an operation.
 *
 * @class
 * @param {Function} executor The executor function.
 */
function CancelToken(executor){
if(typeof executor!=='function'){
throw new TypeError('executor must be a function.');
}

var resolvePromise;
this.promise=new Promise(function promiseExecutor(resolve){
resolvePromise=resolve;
});

var token=this;
executor(function cancel(message){
if(token.reason){
// Cancellation has already been requested
return;
}

token.reason=new Cancel(message);
resolvePromise(token.reason);
});
}

/**
 * Throws a `Cancel` if cancellation has been requested.
 */
CancelToken.prototype.throwIfRequested=function throwIfRequested(){
if(this.reason){
throw this.reason;
}
};

/**
 * Returns an object that contains a new `CancelToken` and a function that, when called,
 * cancels the `CancelToken`.
 */
CancelToken.source=function source(){
var cancel;
var token=new CancelToken(function executor(c){
cancel=c;
});
return {
token:token,
cancel:cancel};

};

module.exports=CancelToken;


/***/},

/***/"./node_modules/axios/lib/cancel/isCancel.js":
/*!***************************************************!*\
  !*** ./node_modules/axios/lib/cancel/isCancel.js ***!
  \***************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCancelIsCancelJs(module,exports,__webpack_require__){


module.exports=function isCancel(value){
return !!(value&&value.__CANCEL__);
};


/***/},

/***/"./node_modules/axios/lib/core/Axios.js":
/*!**********************************************!*\
  !*** ./node_modules/axios/lib/core/Axios.js ***!
  \**********************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreAxiosJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");
var buildURL=__webpack_require__(/*! ../helpers/buildURL */"./node_modules/axios/lib/helpers/buildURL.js");
var InterceptorManager=__webpack_require__(/*! ./InterceptorManager */"./node_modules/axios/lib/core/InterceptorManager.js");
var dispatchRequest=__webpack_require__(/*! ./dispatchRequest */"./node_modules/axios/lib/core/dispatchRequest.js");
var mergeConfig=__webpack_require__(/*! ./mergeConfig */"./node_modules/axios/lib/core/mergeConfig.js");

/**
 * Create a new instance of Axios
 *
 * @param {Object} instanceConfig The default config for the instance
 */
function Axios(instanceConfig){
this.defaults=instanceConfig;
this.interceptors={
request:new InterceptorManager(),
response:new InterceptorManager()};

}

/**
 * Dispatch a request
 *
 * @param {Object} config The config specific for this request (merged with this.defaults)
 */
Axios.prototype.request=function request(config){
/*eslint no-param-reassign:0*/
// Allow for axios('example/url'[, config]) a la fetch API
if(typeof config==='string'){
config=arguments[1]||{};
config.url=arguments[0];
}else {
config=config||{};
}

config=mergeConfig(this.defaults,config);

// Set config.method
if(config.method){
config.method=config.method.toLowerCase();
}else if(this.defaults.method){
config.method=this.defaults.method.toLowerCase();
}else {
config.method='get';
}

// Hook up interceptors middleware
var chain=[dispatchRequest,undefined];
var promise=Promise.resolve(config);

this.interceptors.request.forEach(function unshiftRequestInterceptors(interceptor){
chain.unshift(interceptor.fulfilled,interceptor.rejected);
});

this.interceptors.response.forEach(function pushResponseInterceptors(interceptor){
chain.push(interceptor.fulfilled,interceptor.rejected);
});

while(chain.length){
promise=promise.then(chain.shift(),chain.shift());
}

return promise;
};

Axios.prototype.getUri=function getUri(config){
config=mergeConfig(this.defaults,config);
return buildURL(config.url,config.params,config.paramsSerializer).replace(/^\?/,'');
};

// Provide aliases for supported request methods
utils.forEach(['delete','get','head','options'],function forEachMethodNoData(method){
/*eslint func-names:0*/
Axios.prototype[method]=function(url,config){
return this.request(utils.merge(config||{},{
method:method,
url:url}));

};
});

utils.forEach(['post','put','patch'],function forEachMethodWithData(method){
/*eslint func-names:0*/
Axios.prototype[method]=function(url,data,config){
return this.request(utils.merge(config||{},{
method:method,
url:url,
data:data}));

};
});

module.exports=Axios;


/***/},

/***/"./node_modules/axios/lib/core/InterceptorManager.js":
/*!***********************************************************!*\
  !*** ./node_modules/axios/lib/core/InterceptorManager.js ***!
  \***********************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreInterceptorManagerJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");

function InterceptorManager(){
this.handlers=[];
}

/**
 * Add a new interceptor to the stack
 *
 * @param {Function} fulfilled The function to handle `then` for a `Promise`
 * @param {Function} rejected The function to handle `reject` for a `Promise`
 *
 * @return {Number} An ID used to remove interceptor later
 */
InterceptorManager.prototype.use=function use(fulfilled,rejected){
this.handlers.push({
fulfilled:fulfilled,
rejected:rejected});

return this.handlers.length-1;
};

/**
 * Remove an interceptor from the stack
 *
 * @param {Number} id The ID that was returned by `use`
 */
InterceptorManager.prototype.eject=function eject(id){
if(this.handlers[id]){
this.handlers[id]=null;
}
};

/**
 * Iterate over all the registered interceptors
 *
 * This method is particularly useful for skipping over any
 * interceptors that may have become `null` calling `eject`.
 *
 * @param {Function} fn The function to call for each interceptor
 */
InterceptorManager.prototype.forEach=function forEach(fn){
utils.forEach(this.handlers,function forEachHandler(h){
if(h!==null){
fn(h);
}
});
};

module.exports=InterceptorManager;


/***/},

/***/"./node_modules/axios/lib/core/buildFullPath.js":
/*!******************************************************!*\
  !*** ./node_modules/axios/lib/core/buildFullPath.js ***!
  \******************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreBuildFullPathJs(module,exports,__webpack_require__){


var isAbsoluteURL=__webpack_require__(/*! ../helpers/isAbsoluteURL */"./node_modules/axios/lib/helpers/isAbsoluteURL.js");
var combineURLs=__webpack_require__(/*! ../helpers/combineURLs */"./node_modules/axios/lib/helpers/combineURLs.js");

/**
 * Creates a new URL by combining the baseURL with the requestedURL,
 * only when the requestedURL is not already an absolute URL.
 * If the requestURL is absolute, this function returns the requestedURL untouched.
 *
 * @param {string} baseURL The base URL
 * @param {string} requestedURL Absolute or relative URL to combine
 * @returns {string} The combined full path
 */
module.exports=function buildFullPath(baseURL,requestedURL){
if(baseURL&&!isAbsoluteURL(requestedURL)){
return combineURLs(baseURL,requestedURL);
}
return requestedURL;
};


/***/},

/***/"./node_modules/axios/lib/core/createError.js":
/*!****************************************************!*\
  !*** ./node_modules/axios/lib/core/createError.js ***!
  \****************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreCreateErrorJs(module,exports,__webpack_require__){


var enhanceError=__webpack_require__(/*! ./enhanceError */"./node_modules/axios/lib/core/enhanceError.js");

/**
 * Create an Error with the specified message, config, error code, request and response.
 *
 * @param {string} message The error message.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The created error.
 */
module.exports=function createError(message,config,code,request,response){
var error=new Error(message);
return enhanceError(error,config,code,request,response);
};


/***/},

/***/"./node_modules/axios/lib/core/dispatchRequest.js":
/*!********************************************************!*\
  !*** ./node_modules/axios/lib/core/dispatchRequest.js ***!
  \********************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreDispatchRequestJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");
var transformData=__webpack_require__(/*! ./transformData */"./node_modules/axios/lib/core/transformData.js");
var isCancel=__webpack_require__(/*! ../cancel/isCancel */"./node_modules/axios/lib/cancel/isCancel.js");
var defaults=__webpack_require__(/*! ../defaults */"./node_modules/axios/lib/defaults.js");

/**
 * Throws a `Cancel` if cancellation has been requested.
 */
function throwIfCancellationRequested(config){
if(config.cancelToken){
config.cancelToken.throwIfRequested();
}
}

/**
 * Dispatch a request to the server using the configured adapter.
 *
 * @param {object} config The config that is to be used for the request
 * @returns {Promise} The Promise to be fulfilled
 */
module.exports=function dispatchRequest(config){
throwIfCancellationRequested(config);

// Ensure headers exist
config.headers=config.headers||{};

// Transform request data
config.data=transformData(
config.data,
config.headers,
config.transformRequest);


// Flatten headers
config.headers=utils.merge(
config.headers.common||{},
config.headers[config.method]||{},
config.headers);


utils.forEach(
['delete','get','head','post','put','patch','common'],
function cleanHeaderConfig(method){
delete config.headers[method];
});


var adapter=config.adapter||defaults.adapter;

return adapter(config).then(function onAdapterResolution(response){
throwIfCancellationRequested(config);

// Transform response data
response.data=transformData(
response.data,
response.headers,
config.transformResponse);


return response;
},function onAdapterRejection(reason){
if(!isCancel(reason)){
throwIfCancellationRequested(config);

// Transform response data
if(reason&&reason.response){
reason.response.data=transformData(
reason.response.data,
reason.response.headers,
config.transformResponse);

}
}

return Promise.reject(reason);
});
};


/***/},

/***/"./node_modules/axios/lib/core/enhanceError.js":
/*!*****************************************************!*\
  !*** ./node_modules/axios/lib/core/enhanceError.js ***!
  \*****************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreEnhanceErrorJs(module,exports,__webpack_require__){


/**
 * Update an Error with the specified config, error code, and response.
 *
 * @param {Error} error The error to update.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The error.
 */
module.exports=function enhanceError(error,config,code,request,response){
error.config=config;
if(code){
error.code=code;
}

error.request=request;
error.response=response;
error.isAxiosError=true;

error.toJSON=function(){
return {
// Standard
message:this.message,
name:this.name,
// Microsoft
description:this.description,
number:this.number,
// Mozilla
fileName:this.fileName,
lineNumber:this.lineNumber,
columnNumber:this.columnNumber,
stack:this.stack,
// Axios
config:this.config,
code:this.code};

};
return error;
};


/***/},

/***/"./node_modules/axios/lib/core/mergeConfig.js":
/*!****************************************************!*\
  !*** ./node_modules/axios/lib/core/mergeConfig.js ***!
  \****************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreMergeConfigJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ../utils */"./node_modules/axios/lib/utils.js");

/**
 * Config-specific merge-function which creates a new config-object
 * by merging two configuration objects together.
 *
 * @param {Object} config1
 * @param {Object} config2
 * @returns {Object} New object resulting from merging config2 to config1
 */
module.exports=function mergeConfig(config1,config2){
// eslint-disable-next-line no-param-reassign
config2=config2||{};
var config={};

var valueFromConfig2Keys=['url','method','params','data'];
var mergeDeepPropertiesKeys=['headers','auth','proxy'];
var defaultToConfig2Keys=[
'baseURL','url','transformRequest','transformResponse','paramsSerializer',
'timeout','withCredentials','adapter','responseType','xsrfCookieName',
'xsrfHeaderName','onUploadProgress','onDownloadProgress',
'maxContentLength','validateStatus','maxRedirects','httpAgent',
'httpsAgent','cancelToken','socketPath'];


utils.forEach(valueFromConfig2Keys,function valueFromConfig2(prop){
if(typeof config2[prop]!=='undefined'){
config[prop]=config2[prop];
}
});

utils.forEach(mergeDeepPropertiesKeys,function mergeDeepProperties(prop){
if(utils.isObject(config2[prop])){
config[prop]=utils.deepMerge(config1[prop],config2[prop]);
}else if(typeof config2[prop]!=='undefined'){
config[prop]=config2[prop];
}else if(utils.isObject(config1[prop])){
config[prop]=utils.deepMerge(config1[prop]);
}else if(typeof config1[prop]!=='undefined'){
config[prop]=config1[prop];
}
});

utils.forEach(defaultToConfig2Keys,function defaultToConfig2(prop){
if(typeof config2[prop]!=='undefined'){
config[prop]=config2[prop];
}else if(typeof config1[prop]!=='undefined'){
config[prop]=config1[prop];
}
});

var axiosKeys=valueFromConfig2Keys.
concat(mergeDeepPropertiesKeys).
concat(defaultToConfig2Keys);

var otherKeys=Object.
keys(config2).
filter(function filterAxiosKeys(key){
return axiosKeys.indexOf(key)===-1;
});

utils.forEach(otherKeys,function otherKeysDefaultToConfig2(prop){
if(typeof config2[prop]!=='undefined'){
config[prop]=config2[prop];
}else if(typeof config1[prop]!=='undefined'){
config[prop]=config1[prop];
}
});

return config;
};


/***/},

/***/"./node_modules/axios/lib/core/settle.js":
/*!***********************************************!*\
  !*** ./node_modules/axios/lib/core/settle.js ***!
  \***********************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreSettleJs(module,exports,__webpack_require__){


var createError=__webpack_require__(/*! ./createError */"./node_modules/axios/lib/core/createError.js");

/**
 * Resolve or reject a Promise based on response status.
 *
 * @param {Function} resolve A function that resolves the promise.
 * @param {Function} reject A function that rejects the promise.
 * @param {object} response The response.
 */
module.exports=function settle(resolve,reject,response){
var validateStatus=response.config.validateStatus;
if(!validateStatus||validateStatus(response.status)){
resolve(response);
}else {
reject(createError(
'Request failed with status code '+response.status,
response.config,
null,
response.request,
response));

}
};


/***/},

/***/"./node_modules/axios/lib/core/transformData.js":
/*!******************************************************!*\
  !*** ./node_modules/axios/lib/core/transformData.js ***!
  \******************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibCoreTransformDataJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");

/**
 * Transform the data for a request or a response
 *
 * @param {Object|String} data The data to be transformed
 * @param {Array} headers The headers for the request or response
 * @param {Array|Function} fns A single function or Array of functions
 * @returns {*} The resulting transformed data
 */
module.exports=function transformData(data,headers,fns){
/*eslint no-param-reassign:0*/
utils.forEach(fns,function transform(fn){
data=fn(data,headers);
});

return data;
};


/***/},

/***/"./node_modules/axios/lib/defaults.js":
/*!********************************************!*\
  !*** ./node_modules/axios/lib/defaults.js ***!
  \********************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibDefaultsJs(module,exports,__webpack_require__){
/* WEBPACK VAR INJECTION */(function(process){

var utils=__webpack_require__(/*! ./utils */"./node_modules/axios/lib/utils.js");
var normalizeHeaderName=__webpack_require__(/*! ./helpers/normalizeHeaderName */"./node_modules/axios/lib/helpers/normalizeHeaderName.js");

var DEFAULT_CONTENT_TYPE={
'Content-Type':'application/x-www-form-urlencoded'};


function setContentTypeIfUnset(headers,value){
if(!utils.isUndefined(headers)&&utils.isUndefined(headers['Content-Type'])){
headers['Content-Type']=value;
}
}

function getDefaultAdapter(){
var adapter;
if(typeof XMLHttpRequest!=='undefined'){
// For browsers use XHR adapter
adapter=__webpack_require__(/*! ./adapters/xhr */"./node_modules/axios/lib/adapters/xhr.js");
}else if(typeof process!=='undefined'&&Object.prototype.toString.call(process)==='[object process]'){
// For node use HTTP adapter
adapter=__webpack_require__(/*! ./adapters/http */"./node_modules/axios/lib/adapters/xhr.js");
}
return adapter;
}

var defaults={
adapter:getDefaultAdapter(),

transformRequest:[function transformRequest(data,headers){
normalizeHeaderName(headers,'Accept');
normalizeHeaderName(headers,'Content-Type');
if(utils.isFormData(data)||
utils.isArrayBuffer(data)||
utils.isBuffer(data)||
utils.isStream(data)||
utils.isFile(data)||
utils.isBlob(data))
{
return data;
}
if(utils.isArrayBufferView(data)){
return data.buffer;
}
if(utils.isURLSearchParams(data)){
setContentTypeIfUnset(headers,'application/x-www-form-urlencoded;charset=utf-8');
return data.toString();
}
if(utils.isObject(data)){
setContentTypeIfUnset(headers,'application/json;charset=utf-8');
return JSON.stringify(data);
}
return data;
}],

transformResponse:[function transformResponse(data){
/*eslint no-param-reassign:0*/
if(typeof data==='string'){
try{
data=JSON.parse(data);
}catch(e){/* Ignore */}
}
return data;
}],

/**
   * A timeout in milliseconds to abort a request. If set to 0 (default) a
   * timeout is not created.
   */
timeout:0,

xsrfCookieName:'XSRF-TOKEN',
xsrfHeaderName:'X-XSRF-TOKEN',

maxContentLength:-1,

validateStatus:function validateStatus(status){
return status>=200&&status<300;
}};


defaults.headers={
common:{
'Accept':'application/json, text/plain, */*'}};



utils.forEach(['delete','get','head'],function forEachMethodNoData(method){
defaults.headers[method]={};
});

utils.forEach(['post','put','patch'],function forEachMethodWithData(method){
defaults.headers[method]=utils.merge(DEFAULT_CONTENT_TYPE);
});

module.exports=defaults;

/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../process/browser.js */"./node_modules/process/browser.js"));

/***/},

/***/"./node_modules/axios/lib/helpers/bind.js":
/*!************************************************!*\
  !*** ./node_modules/axios/lib/helpers/bind.js ***!
  \************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersBindJs(module,exports,__webpack_require__){


module.exports=function bind(fn,thisArg){
return function wrap(){
var args=new Array(arguments.length);
for(var i=0;i<args.length;i++){
args[i]=arguments[i];
}
return fn.apply(thisArg,args);
};
};


/***/},

/***/"./node_modules/axios/lib/helpers/buildURL.js":
/*!****************************************************!*\
  !*** ./node_modules/axios/lib/helpers/buildURL.js ***!
  \****************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersBuildURLJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");

function encode(val){
return encodeURIComponent(val).
replace(/%40/gi,'@').
replace(/%3A/gi,':').
replace(/%24/g,'$').
replace(/%2C/gi,',').
replace(/%20/g,'+').
replace(/%5B/gi,'[').
replace(/%5D/gi,']');
}

/**
 * Build a URL by appending params to the end
 *
 * @param {string} url The base of the url (e.g., http://www.google.com)
 * @param {object} [params] The params to be appended
 * @returns {string} The formatted url
 */
module.exports=function buildURL(url,params,paramsSerializer){
/*eslint no-param-reassign:0*/
if(!params){
return url;
}

var serializedParams;
if(paramsSerializer){
serializedParams=paramsSerializer(params);
}else if(utils.isURLSearchParams(params)){
serializedParams=params.toString();
}else {
var parts=[];

utils.forEach(params,function serialize(val,key){
if(val===null||typeof val==='undefined'){
return;
}

if(utils.isArray(val)){
key=key+'[]';
}else {
val=[val];
}

utils.forEach(val,function parseValue(v){
if(utils.isDate(v)){
v=v.toISOString();
}else if(utils.isObject(v)){
v=JSON.stringify(v);
}
parts.push(encode(key)+'='+encode(v));
});
});

serializedParams=parts.join('&');
}

if(serializedParams){
var hashmarkIndex=url.indexOf('#');
if(hashmarkIndex!==-1){
url=url.slice(0,hashmarkIndex);
}

url+=(url.indexOf('?')===-1?'?':'&')+serializedParams;
}

return url;
};


/***/},

/***/"./node_modules/axios/lib/helpers/combineURLs.js":
/*!*******************************************************!*\
  !*** ./node_modules/axios/lib/helpers/combineURLs.js ***!
  \*******************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersCombineURLsJs(module,exports,__webpack_require__){


/**
 * Creates a new URL by combining the specified URLs
 *
 * @param {string} baseURL The base URL
 * @param {string} relativeURL The relative URL
 * @returns {string} The combined URL
 */
module.exports=function combineURLs(baseURL,relativeURL){
return relativeURL?
baseURL.replace(/\/+$/,'')+'/'+relativeURL.replace(/^\/+/,''):
baseURL;
};


/***/},

/***/"./node_modules/axios/lib/helpers/cookies.js":
/*!***************************************************!*\
  !*** ./node_modules/axios/lib/helpers/cookies.js ***!
  \***************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersCookiesJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");

module.exports=
utils.isStandardBrowserEnv()?

// Standard browser envs support document.cookie
function standardBrowserEnv(){
return {
write:function write(name,value,expires,path,domain,secure){
var cookie=[];
cookie.push(name+'='+encodeURIComponent(value));

if(utils.isNumber(expires)){
cookie.push('expires='+new Date(expires).toGMTString());
}

if(utils.isString(path)){
cookie.push('path='+path);
}

if(utils.isString(domain)){
cookie.push('domain='+domain);
}

if(secure===true){
cookie.push('secure');
}

document.cookie=cookie.join('; ');
},

read:function read(name){
var match=document.cookie.match(new RegExp('(^|;\\s*)('+name+')=([^;]*)'));
return match?decodeURIComponent(match[3]):null;
},

remove:function remove(name){
this.write(name,'',Date.now()-86400000);
}};

}():

// Non standard browser env (web workers, react-native) lack needed support.
function nonStandardBrowserEnv(){
return {
write:function write(){},
read:function read(){return null;},
remove:function remove(){}};

}();



/***/},

/***/"./node_modules/axios/lib/helpers/isAbsoluteURL.js":
/*!*********************************************************!*\
  !*** ./node_modules/axios/lib/helpers/isAbsoluteURL.js ***!
  \*********************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersIsAbsoluteURLJs(module,exports,__webpack_require__){


/**
 * Determines whether the specified URL is absolute
 *
 * @param {string} url The URL to test
 * @returns {boolean} True if the specified URL is absolute, otherwise false
 */
module.exports=function isAbsoluteURL(url){
// A URL is considered absolute if it begins with "<scheme>://" or "//" (protocol-relative URL).
// RFC 3986 defines scheme name as a sequence of characters beginning with a letter and followed
// by any combination of letters, digits, plus, period, or hyphen.
return /^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(url);
};


/***/},

/***/"./node_modules/axios/lib/helpers/isURLSameOrigin.js":
/*!***********************************************************!*\
  !*** ./node_modules/axios/lib/helpers/isURLSameOrigin.js ***!
  \***********************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersIsURLSameOriginJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");

module.exports=
utils.isStandardBrowserEnv()?

// Standard browser envs have full support of the APIs needed to test
// whether the request URL is of the same origin as current location.
function standardBrowserEnv(){
var msie=/(msie|trident)/i.test(navigator.userAgent);
var urlParsingNode=document.createElement('a');
var originURL;

/**
    * Parse a URL to discover it's components
    *
    * @param {String} url The URL to be parsed
    * @returns {Object}
    */
function resolveURL(url){
var href=url;

if(msie){
// IE needs attribute set twice to normalize properties
urlParsingNode.setAttribute('href',href);
href=urlParsingNode.href;
}

urlParsingNode.setAttribute('href',href);

// urlParsingNode provides the UrlUtils interface - http://url.spec.whatwg.org/#urlutils
return {
href:urlParsingNode.href,
protocol:urlParsingNode.protocol?urlParsingNode.protocol.replace(/:$/,''):'',
host:urlParsingNode.host,
search:urlParsingNode.search?urlParsingNode.search.replace(/^\?/,''):'',
hash:urlParsingNode.hash?urlParsingNode.hash.replace(/^#/,''):'',
hostname:urlParsingNode.hostname,
port:urlParsingNode.port,
pathname:urlParsingNode.pathname.charAt(0)==='/'?
urlParsingNode.pathname:
'/'+urlParsingNode.pathname};

}

originURL=resolveURL(window.location.href);

/**
    * Determine if a URL shares the same origin as the current location
    *
    * @param {String} requestURL The URL to test
    * @returns {boolean} True if URL shares the same origin, otherwise false
    */
return function isURLSameOrigin(requestURL){
var parsed=utils.isString(requestURL)?resolveURL(requestURL):requestURL;
return parsed.protocol===originURL.protocol&&
parsed.host===originURL.host;
};
}():

// Non standard browser envs (web workers, react-native) lack needed support.
function nonStandardBrowserEnv(){
return function isURLSameOrigin(){
return true;
};
}();



/***/},

/***/"./node_modules/axios/lib/helpers/normalizeHeaderName.js":
/*!***************************************************************!*\
  !*** ./node_modules/axios/lib/helpers/normalizeHeaderName.js ***!
  \***************************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersNormalizeHeaderNameJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ../utils */"./node_modules/axios/lib/utils.js");

module.exports=function normalizeHeaderName(headers,normalizedName){
utils.forEach(headers,function processHeader(value,name){
if(name!==normalizedName&&name.toUpperCase()===normalizedName.toUpperCase()){
headers[normalizedName]=value;
delete headers[name];
}
});
};


/***/},

/***/"./node_modules/axios/lib/helpers/parseHeaders.js":
/*!********************************************************!*\
  !*** ./node_modules/axios/lib/helpers/parseHeaders.js ***!
  \********************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersParseHeadersJs(module,exports,__webpack_require__){


var utils=__webpack_require__(/*! ./../utils */"./node_modules/axios/lib/utils.js");

// Headers whose duplicates are ignored by node
// c.f. https://nodejs.org/api/http.html#http_message_headers
var ignoreDuplicateOf=[
'age','authorization','content-length','content-type','etag',
'expires','from','host','if-modified-since','if-unmodified-since',
'last-modified','location','max-forwards','proxy-authorization',
'referer','retry-after','user-agent'];


/**
 * Parse headers into an object
 *
 * ```
 * Date: Wed, 27 Aug 2014 08:58:49 GMT
 * Content-Type: application/json
 * Connection: keep-alive
 * Transfer-Encoding: chunked
 * ```
 *
 * @param {String} headers Headers needing to be parsed
 * @returns {Object} Headers parsed into an object
 */
module.exports=function parseHeaders(headers){
var parsed={};
var key;
var val;
var i;

if(!headers){return parsed;}

utils.forEach(headers.split('\n'),function parser(line){
i=line.indexOf(':');
key=utils.trim(line.substr(0,i)).toLowerCase();
val=utils.trim(line.substr(i+1));

if(key){
if(parsed[key]&&ignoreDuplicateOf.indexOf(key)>=0){
return;
}
if(key==='set-cookie'){
parsed[key]=(parsed[key]?parsed[key]:[]).concat([val]);
}else {
parsed[key]=parsed[key]?parsed[key]+', '+val:val;
}
}
});

return parsed;
};


/***/},

/***/"./node_modules/axios/lib/helpers/spread.js":
/*!**************************************************!*\
  !*** ./node_modules/axios/lib/helpers/spread.js ***!
  \**************************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibHelpersSpreadJs(module,exports,__webpack_require__){


/**
 * Syntactic sugar for invoking a function and expanding an array for arguments.
 *
 * Common use case would be to use `Function.prototype.apply`.
 *
 *  ```js
 *  function f(x, y, z) {}
 *  var args = [1, 2, 3];
 *  f.apply(null, args);
 *  ```
 *
 * With `spread` this example can be re-written.
 *
 *  ```js
 *  spread(function(x, y, z) {})([1, 2, 3]);
 *  ```
 *
 * @param {Function} callback
 * @returns {Function}
 */
module.exports=function spread(callback){
return function wrap(arr){
return callback.apply(null,arr);
};
};


/***/},

/***/"./node_modules/axios/lib/utils.js":
/*!*****************************************!*\
  !*** ./node_modules/axios/lib/utils.js ***!
  \*****************************************/
/*! no static exports found */
/***/function node_modulesAxiosLibUtilsJs(module,exports,__webpack_require__){


var bind=__webpack_require__(/*! ./helpers/bind */"./node_modules/axios/lib/helpers/bind.js");

/*global toString:true*/

// utils is a library of generic helper functions non-specific to axios

var toString=Object.prototype.toString;

/**
 * Determine if a value is an Array
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Array, otherwise false
 */
function isArray(val){
return toString.call(val)==='[object Array]';
}

/**
 * Determine if a value is undefined
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if the value is undefined, otherwise false
 */
function isUndefined(val){
return typeof val==='undefined';
}

/**
 * Determine if a value is a Buffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Buffer, otherwise false
 */
function isBuffer(val){
return val!==null&&!isUndefined(val)&&val.constructor!==null&&!isUndefined(val.constructor)&&
typeof val.constructor.isBuffer==='function'&&val.constructor.isBuffer(val);
}

/**
 * Determine if a value is an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an ArrayBuffer, otherwise false
 */
function isArrayBuffer(val){
return toString.call(val)==='[object ArrayBuffer]';
}

/**
 * Determine if a value is a FormData
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an FormData, otherwise false
 */
function isFormData(val){
return typeof FormData!=='undefined'&&val instanceof FormData;
}

/**
 * Determine if a value is a view on an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a view on an ArrayBuffer, otherwise false
 */
function isArrayBufferView(val){
var result;
if(typeof ArrayBuffer!=='undefined'&&ArrayBuffer.isView){
result=ArrayBuffer.isView(val);
}else {
result=val&&val.buffer&&val.buffer instanceof ArrayBuffer;
}
return result;
}

/**
 * Determine if a value is a String
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a String, otherwise false
 */
function isString(val){
return typeof val==='string';
}

/**
 * Determine if a value is a Number
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Number, otherwise false
 */
function isNumber(val){
return typeof val==='number';
}

/**
 * Determine if a value is an Object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Object, otherwise false
 */
function isObject(val){
return val!==null&&typeof val==='object';
}

/**
 * Determine if a value is a Date
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Date, otherwise false
 */
function isDate(val){
return toString.call(val)==='[object Date]';
}

/**
 * Determine if a value is a File
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a File, otherwise false
 */
function isFile(val){
return toString.call(val)==='[object File]';
}

/**
 * Determine if a value is a Blob
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Blob, otherwise false
 */
function isBlob(val){
return toString.call(val)==='[object Blob]';
}

/**
 * Determine if a value is a Function
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Function, otherwise false
 */
function isFunction(val){
return toString.call(val)==='[object Function]';
}

/**
 * Determine if a value is a Stream
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Stream, otherwise false
 */
function isStream(val){
return isObject(val)&&isFunction(val.pipe);
}

/**
 * Determine if a value is a URLSearchParams object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a URLSearchParams object, otherwise false
 */
function isURLSearchParams(val){
return typeof URLSearchParams!=='undefined'&&val instanceof URLSearchParams;
}

/**
 * Trim excess whitespace off the beginning and end of a string
 *
 * @param {String} str The String to trim
 * @returns {String} The String freed of excess whitespace
 */
function trim(str){
return str.replace(/^\s*/,'').replace(/\s*$/,'');
}

/**
 * Determine if we're running in a standard browser environment
 *
 * This allows axios to run in a web worker, and react-native.
 * Both environments support XMLHttpRequest, but not fully standard globals.
 *
 * web workers:
 *  typeof window -> undefined
 *  typeof document -> undefined
 *
 * react-native:
 *  navigator.product -> 'ReactNative'
 * nativescript
 *  navigator.product -> 'NativeScript' or 'NS'
 */
function isStandardBrowserEnv(){
if(typeof navigator!=='undefined'&&(navigator.product==='ReactNative'||
navigator.product==='NativeScript'||
navigator.product==='NS')){
return false;
}
return(
typeof window!=='undefined'&&
typeof document!=='undefined');

}

/**
 * Iterate over an Array or an Object invoking a function for each item.
 *
 * If `obj` is an Array callback will be called passing
 * the value, index, and complete array for each item.
 *
 * If 'obj' is an Object callback will be called passing
 * the value, key, and complete object for each property.
 *
 * @param {Object|Array} obj The object to iterate
 * @param {Function} fn The callback to invoke for each item
 */
function forEach(obj,fn){
// Don't bother if no value provided
if(obj===null||typeof obj==='undefined'){
return;
}

// Force an array if not already something iterable
if(typeof obj!=='object'){
/*eslint no-param-reassign:0*/
obj=[obj];
}

if(isArray(obj)){
// Iterate over array values
for(var i=0,l=obj.length;i<l;i++){
fn.call(null,obj[i],i,obj);
}
}else {
// Iterate over object keys
for(var key in obj){
if(Object.prototype.hasOwnProperty.call(obj,key)){
fn.call(null,obj[key],key,obj);
}
}
}
}

/**
 * Accepts varargs expecting each argument to be an object, then
 * immutably merges the properties of each object and returns result.
 *
 * When multiple objects contain the same key the later object in
 * the arguments list will take precedence.
 *
 * Example:
 *
 * ```js
 * var result = merge({foo: 123}, {foo: 456});
 * console.log(result.foo); // outputs 456
 * ```
 *
 * @param {Object} obj1 Object to merge
 * @returns {Object} Result of all merge properties
 */
function merge()/* obj1, obj2, obj3, ... */{
var result={};
function assignValue(val,key){
if(typeof result[key]==='object'&&typeof val==='object'){
result[key]=merge(result[key],val);
}else {
result[key]=val;
}
}

for(var i=0,l=arguments.length;i<l;i++){
forEach(arguments[i],assignValue);
}
return result;
}

/**
 * Function equal to merge with the difference being that no reference
 * to original objects is kept.
 *
 * @see merge
 * @param {Object} obj1 Object to merge
 * @returns {Object} Result of all merge properties
 */
function deepMerge()/* obj1, obj2, obj3, ... */{
var result={};
function assignValue(val,key){
if(typeof result[key]==='object'&&typeof val==='object'){
result[key]=deepMerge(result[key],val);
}else if(typeof val==='object'){
result[key]=deepMerge({},val);
}else {
result[key]=val;
}
}

for(var i=0,l=arguments.length;i<l;i++){
forEach(arguments[i],assignValue);
}
return result;
}

/**
 * Extends object a by mutably adding to it the properties of object b.
 *
 * @param {Object} a The object to be extended
 * @param {Object} b The object to copy properties from
 * @param {Object} thisArg The object to bind function to
 * @return {Object} The resulting value of object a
 */
function extend(a,b,thisArg){
forEach(b,function assignValue(val,key){
if(thisArg&&typeof val==='function'){
a[key]=bind(val,thisArg);
}else {
a[key]=val;
}
});
return a;
}

module.exports={
isArray:isArray,
isArrayBuffer:isArrayBuffer,
isBuffer:isBuffer,
isFormData:isFormData,
isArrayBufferView:isArrayBufferView,
isString:isString,
isNumber:isNumber,
isObject:isObject,
isUndefined:isUndefined,
isDate:isDate,
isFile:isFile,
isBlob:isBlob,
isFunction:isFunction,
isStream:isStream,
isURLSearchParams:isURLSearchParams,
isStandardBrowserEnv:isStandardBrowserEnv,
forEach:forEach,
merge:merge,
deepMerge:deepMerge,
extend:extend,
trim:trim};



/***/},

/***/"./node_modules/babel-loader/lib/index.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/App.vue?vue&type=script&lang=js&":
/*!****************************************************************************************************************************************************!*\
  !*** ./node_modules/babel-loader/lib??ref--4-0!./node_modules/vue-loader/lib??vue-loader-options!./resources/src/App.vue?vue&type=script&lang=js& ***!
  \****************************************************************************************************************************************************/
/*! exports provided: default */
/***/function node_modulesBabelLoaderLibIndexJsNode_modulesVueLoaderLibIndexJsResourcesSrcAppVueVueTypeScriptLangJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var vuex__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vuex */"./node_modules/vuex/dist/vuex.esm.js");
function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);if(enumerableOnly)symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable;});keys.push.apply(keys,symbols);}return keys;}

function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=arguments[i]!=null?arguments[i]:{};if(i%2){ownKeys(Object(source),true).forEach(function(key){_defineProperty(target,key,source[key]);});}else if(Object.getOwnPropertyDescriptors){Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));}else {ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));});}}return target;}

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//
//
//
//
//
//
//
//
//

/* harmony default export */__webpack_exports__["default"]={
data:function data(){
return {
Loading:false};

},
computed:_objectSpread(_objectSpread({},Object(vuex__WEBPACK_IMPORTED_MODULE_0__["mapGetters"])(["getThemeMode","isAuthenticated"])),{},{
themeName:function themeName(){
return this.getThemeMode.dark?"dark-theme":" ";
},
rtl:function rtl(){
return this.getThemeMode.rtl?"rtl":" ";
}}),

metaInfo:function metaInfo(){
return {
// if no subcomponents specify a metaInfo.title, this title will be used
title:"Stocky",
// all titles will be injected into this template
titleTemplate:"%s | Ultimate Inventory With POS",
bodyAttrs:{
"class":[this.themeName,"text-left"]},

htmlAttrs:{
dir:this.rtl}};


},
methods:_objectSpread({},Object(vuex__WEBPACK_IMPORTED_MODULE_0__["mapActions"])(["refreshUserPermissions"])),
beforeMount:function beforeMount(){
var _this=this;

// if(this.isAuthenticated){
this.refreshUserPermissions();
setTimeout(function(){
return _this.Loading=true;
},300);// }
// else{
//   setTimeout(() => this.Loading= true, 300);
// }
}};


/***/},

/***/"./node_modules/babel-loader/lib/index.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/components/breadcumb.vue?vue&type=script&lang=js&":
/*!*********************************************************************************************************************************************************************!*\
  !*** ./node_modules/babel-loader/lib??ref--4-0!./node_modules/vue-loader/lib??vue-loader-options!./resources/src/components/breadcumb.vue?vue&type=script&lang=js& ***!
  \*********************************************************************************************************************************************************************/
/*! exports provided: default */
/***/function node_modulesBabelLoaderLibIndexJsNode_modulesVueLoaderLibIndexJsResourcesSrcComponentsBreadcumbVueVueTypeScriptLangJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
//
//
//
//
//
//
//
//
//
//
//
//
//
//
/* harmony default export */__webpack_exports__["default"]={
props:['page','folder']};


/***/},

/***/"./node_modules/bootstrap-vue/dist/bootstrap-vue.esm.js":
/*!**************************************************************!*\
  !*** ./node_modules/bootstrap-vue/dist/bootstrap-vue.esm.js ***!
  \**************************************************************/
/*! exports provided: default, AlertPlugin, AspectPlugin, AvatarPlugin, BAlert, BAspect, BAvatar, BAvatarGroup, BBadge, BBreadcrumb, BBreadcrumbItem, BButton, BButtonClose, BButtonGroup, BButtonToolbar, BCalendar, BCard, BCardBody, BCardFooter, BCardGroup, BCardHeader, BCardImg, BCardImgLazy, BCardSubTitle, BCardText, BCardTitle, BCarousel, BCarouselSlide, BCol, BCollapse, BContainer, BDropdown, BDropdownDivider, BDropdownForm, BDropdownGroup, BDropdownHeader, BDropdownItem, BDropdownItemButton, BDropdownText, BEmbed, BForm, BFormCheckbox, BFormCheckboxGroup, BFormDatalist, BFormDatepicker, BFormFile, BFormGroup, BFormInput, BFormInvalidFeedback, BFormRadio, BFormRadioGroup, BFormRating, BFormRow, BFormSelect, BFormSelectOption, BFormSelectOptionGroup, BFormSpinbutton, BFormTag, BFormTags, BFormText, BFormTextarea, BFormTimepicker, BFormValidFeedback, BIcon, BIconAlarm, BIconAlarmFill, BIconAlignBottom, BIconAlignCenter, BIconAlignEnd, BIconAlignMiddle, BIconAlignStart, BIconAlignTop, BIconAlt, BIconApp, BIconAppIndicator, BIconArchive, BIconArchiveFill, BIconArrow90degDown, BIconArrow90degLeft, BIconArrow90degRight, BIconArrow90degUp, BIconArrowBarDown, BIconArrowBarLeft, BIconArrowBarRight, BIconArrowBarUp, BIconArrowClockwise, BIconArrowCounterclockwise, BIconArrowDown, BIconArrowDownCircle, BIconArrowDownCircleFill, BIconArrowDownLeft, BIconArrowDownLeftCircle, BIconArrowDownLeftCircleFill, BIconArrowDownLeftSquare, BIconArrowDownLeftSquareFill, BIconArrowDownRight, BIconArrowDownRightCircle, BIconArrowDownRightCircleFill, BIconArrowDownRightSquare, BIconArrowDownRightSquareFill, BIconArrowDownShort, BIconArrowDownSquare, BIconArrowDownSquareFill, BIconArrowDownUp, BIconArrowLeft, BIconArrowLeftCircle, BIconArrowLeftCircleFill, BIconArrowLeftRight, BIconArrowLeftShort, BIconArrowLeftSquare, BIconArrowLeftSquareFill, BIconArrowRepeat, BIconArrowReturnLeft, BIconArrowReturnRight, BIconArrowRight, BIconArrowRightCircle, BIconArrowRightCircleFill, BIconArrowRightShort, BIconArrowRightSquare, BIconArrowRightSquareFill, BIconArrowUp, BIconArrowUpCircle, BIconArrowUpCircleFill, BIconArrowUpLeft, BIconArrowUpLeftCircle, BIconArrowUpLeftCircleFill, BIconArrowUpLeftSquare, BIconArrowUpLeftSquareFill, BIconArrowUpRight, BIconArrowUpRightCircle, BIconArrowUpRightCircleFill, BIconArrowUpRightSquare, BIconArrowUpRightSquareFill, BIconArrowUpShort, BIconArrowUpSquare, BIconArrowUpSquareFill, BIconArrowsAngleContract, BIconArrowsAngleExpand, BIconArrowsCollapse, BIconArrowsExpand, BIconArrowsFullscreen, BIconArrowsMove, BIconAspectRatio, BIconAspectRatioFill, BIconAsterisk, BIconAt, BIconAward, BIconAwardFill, BIconBack, BIconBackspace, BIconBackspaceFill, BIconBackspaceReverse, BIconBackspaceReverseFill, BIconBadge4k, BIconBadge4kFill, BIconBadge8k, BIconBadge8kFill, BIconBadgeAd, BIconBadgeAdFill, BIconBadgeCc, BIconBadgeCcFill, BIconBadgeHd, BIconBadgeHdFill, BIconBadgeTm, BIconBadgeTmFill, BIconBadgeVo, BIconBadgeVoFill, BIconBag, BIconBagCheck, BIconBagCheckFill, BIconBagDash, BIconBagDashFill, BIconBagFill, BIconBagPlus, BIconBagPlusFill, BIconBagX, BIconBagXFill, BIconBarChart, BIconBarChartFill, BIconBarChartLine, BIconBarChartLineFill, BIconBarChartSteps, BIconBasket, BIconBasket2, BIconBasket2Fill, BIconBasket3, BIconBasket3Fill, BIconBasketFill, BIconBattery, BIconBatteryCharging, BIconBatteryFull, BIconBatteryHalf, BIconBell, BIconBellFill, BIconBezier, BIconBezier2, BIconBicycle, BIconBinoculars, BIconBinocularsFill, BIconBlank, BIconBlockquoteLeft, BIconBlockquoteRight, BIconBook, BIconBookFill, BIconBookHalf, BIconBookmark, BIconBookmarkCheck, BIconBookmarkCheckFill, BIconBookmarkDash, BIconBookmarkDashFill, BIconBookmarkFill, BIconBookmarkHeart, BIconBookmarkHeartFill, BIconBookmarkPlus, BIconBookmarkPlusFill, BIconBookmarkStar, BIconBookmarkStarFill, BIconBookmarkX, BIconBookmarkXFill, BIconBookmarks, BIconBookmarksFill, BIconBookshelf, BIconBootstrap, BIconBootstrapFill, BIconBootstrapReboot, BIconBorderStyle, BIconBorderWidth, BIconBoundingBox, BIconBoundingBoxCircles, BIconBox, BIconBoxArrowDown, BIconBoxArrowDownLeft, BIconBoxArrowDownRight, BIconBoxArrowInDown, BIconBoxArrowInDownLeft, BIconBoxArrowInDownRight, BIconBoxArrowInLeft, BIconBoxArrowInRight, BIconBoxArrowInUp, BIconBoxArrowInUpLeft, BIconBoxArrowInUpRight, BIconBoxArrowLeft, BIconBoxArrowRight, BIconBoxArrowUp, BIconBoxArrowUpLeft, BIconBoxArrowUpRight, BIconBoxSeam, BIconBraces, BIconBricks, BIconBriefcase, BIconBriefcaseFill, BIconBrightnessAltHigh, BIconBrightnessAltHighFill, BIconBrightnessAltLow, BIconBrightnessAltLowFill, BIconBrightnessHigh, BIconBrightnessHighFill, BIconBrightnessLow, BIconBrightnessLowFill, BIconBroadcast, BIconBroadcastPin, BIconBrush, BIconBrushFill, BIconBucket, BIconBucketFill, BIconBug, BIconBugFill, BIconBuilding, BIconBullseye, BIconCalculator, BIconCalculatorFill, BIconCalendar, BIconCalendar2, BIconCalendar2Check, BIconCalendar2CheckFill, BIconCalendar2Date, BIconCalendar2DateFill, BIconCalendar2Day, BIconCalendar2DayFill, BIconCalendar2Event, BIconCalendar2EventFill, BIconCalendar2Fill, BIconCalendar2Minus, BIconCalendar2MinusFill, BIconCalendar2Month, BIconCalendar2MonthFill, BIconCalendar2Plus, BIconCalendar2PlusFill, BIconCalendar2Range, BIconCalendar2RangeFill, BIconCalendar2Week, BIconCalendar2WeekFill, BIconCalendar2X, BIconCalendar2XFill, BIconCalendar3, BIconCalendar3Event, BIconCalendar3EventFill, BIconCalendar3Fill, BIconCalendar3Range, BIconCalendar3RangeFill, BIconCalendar3Week, BIconCalendar3WeekFill, BIconCalendar4, BIconCalendar4Event, BIconCalendar4Range, BIconCalendar4Week, BIconCalendarCheck, BIconCalendarCheckFill, BIconCalendarDate, BIconCalendarDateFill, BIconCalendarDay, BIconCalendarDayFill, BIconCalendarEvent, BIconCalendarEventFill, BIconCalendarFill, BIconCalendarMinus, BIconCalendarMinusFill, BIconCalendarMonth, BIconCalendarMonthFill, BIconCalendarPlus, BIconCalendarPlusFill, BIconCalendarRange, BIconCalendarRangeFill, BIconCalendarWeek, BIconCalendarWeekFill, BIconCalendarX, BIconCalendarXFill, BIconCamera, BIconCamera2, BIconCameraFill, BIconCameraReels, BIconCameraReelsFill, BIconCameraVideo, BIconCameraVideoFill, BIconCameraVideoOff, BIconCameraVideoOffFill, BIconCapslock, BIconCapslockFill, BIconCardChecklist, BIconCardHeading, BIconCardImage, BIconCardList, BIconCardText, BIconCaretDown, BIconCaretDownFill, BIconCaretDownSquare, BIconCaretDownSquareFill, BIconCaretLeft, BIconCaretLeftFill, BIconCaretLeftSquare, BIconCaretLeftSquareFill, BIconCaretRight, BIconCaretRightFill, BIconCaretRightSquare, BIconCaretRightSquareFill, BIconCaretUp, BIconCaretUpFill, BIconCaretUpSquare, BIconCaretUpSquareFill, BIconCart, BIconCart2, BIconCart3, BIconCart4, BIconCartCheck, BIconCartCheckFill, BIconCartDash, BIconCartDashFill, BIconCartFill, BIconCartPlus, BIconCartPlusFill, BIconCartX, BIconCartXFill, BIconCash, BIconCashStack, BIconCast, BIconChat, BIconChatDots, BIconChatDotsFill, BIconChatFill, BIconChatLeft, BIconChatLeftDots, BIconChatLeftDotsFill, BIconChatLeftFill, BIconChatLeftQuote, BIconChatLeftQuoteFill, BIconChatLeftText, BIconChatLeftTextFill, BIconChatQuote, BIconChatQuoteFill, BIconChatRight, BIconChatRightDots, BIconChatRightDotsFill, BIconChatRightFill, BIconChatRightQuote, BIconChatRightQuoteFill, BIconChatRightText, BIconChatRightTextFill, BIconChatSquare, BIconChatSquareDots, BIconChatSquareDotsFill, BIconChatSquareFill, BIconChatSquareQuote, BIconChatSquareQuoteFill, BIconChatSquareText, BIconChatSquareTextFill, BIconChatText, BIconChatTextFill, BIconCheck, BIconCheck2, BIconCheck2All, BIconCheck2Circle, BIconCheck2Square, BIconCheckAll, BIconCheckCircle, BIconCheckCircleFill, BIconCheckSquare, BIconCheckSquareFill, BIconChevronBarContract, BIconChevronBarDown, BIconChevronBarExpand, BIconChevronBarLeft, BIconChevronBarRight, BIconChevronBarUp, BIconChevronCompactDown, BIconChevronCompactLeft, BIconChevronCompactRight, BIconChevronCompactUp, BIconChevronContract, BIconChevronDoubleDown, BIconChevronDoubleLeft, BIconChevronDoubleRight, BIconChevronDoubleUp, BIconChevronDown, BIconChevronExpand, BIconChevronLeft, BIconChevronRight, BIconChevronUp, BIconCircle, BIconCircleFill, BIconCircleHalf, BIconCircleSquare, BIconClipboard, BIconClipboardCheck, BIconClipboardData, BIconClipboardMinus, BIconClipboardPlus, BIconClipboardX, BIconClock, BIconClockFill, BIconClockHistory, BIconCloud, BIconCloudArrowDown, BIconCloudArrowDownFill, BIconCloudArrowUp, BIconCloudArrowUpFill, BIconCloudCheck, BIconCloudCheckFill, BIconCloudDownload, BIconCloudDownloadFill, BIconCloudFill, BIconCloudMinus, BIconCloudMinusFill, BIconCloudPlus, BIconCloudPlusFill, BIconCloudSlash, BIconCloudSlashFill, BIconCloudUpload, BIconCloudUploadFill, BIconCode, BIconCodeSlash, BIconCodeSquare, BIconCollection, BIconCollectionFill, BIconCollectionPlay, BIconCollectionPlayFill, BIconColumns, BIconColumnsGap, BIconCommand, BIconCompass, BIconCompassFill, BIconCone, BIconConeStriped, BIconController, BIconCpu, BIconCpuFill, BIconCreditCard, BIconCreditCard2Back, BIconCreditCard2BackFill, BIconCreditCard2Front, BIconCreditCard2FrontFill, BIconCreditCardFill, BIconCrop, BIconCup, BIconCupFill, BIconCupStraw, BIconCursor, BIconCursorFill, BIconCursorText, BIconDash, BIconDashCircle, BIconDashCircleFill, BIconDashSquare, BIconDashSquareFill, BIconDiagram2, BIconDiagram2Fill, BIconDiagram3, BIconDiagram3Fill, BIconDiamond, BIconDiamondFill, BIconDiamondHalf, BIconDice1, BIconDice1Fill, BIconDice2, BIconDice2Fill, BIconDice3, BIconDice3Fill, BIconDice4, BIconDice4Fill, BIconDice5, BIconDice5Fill, BIconDice6, BIconDice6Fill, BIconDisc, BIconDiscFill, BIconDiscord, BIconDisplay, BIconDisplayFill, BIconDistributeHorizontal, BIconDistributeVertical, BIconDoorClosed, BIconDoorClosedFill, BIconDoorOpen, BIconDoorOpenFill, BIconDot, BIconDownload, BIconDroplet, BIconDropletFill, BIconDropletHalf, BIconEarbuds, BIconEasel, BIconEaselFill, BIconEgg, BIconEggFill, BIconEggFried, BIconEject, BIconEjectFill, BIconEmojiAngry, BIconEmojiAngryFill, BIconEmojiDizzy, BIconEmojiDizzyFill, BIconEmojiExpressionless, BIconEmojiExpressionlessFill, BIconEmojiFrown, BIconEmojiFrownFill, BIconEmojiHeartEyes, BIconEmojiHeartEyesFill, BIconEmojiLaughing, BIconEmojiLaughingFill, BIconEmojiNeutral, BIconEmojiNeutralFill, BIconEmojiSmile, BIconEmojiSmileFill, BIconEmojiSmileUpsideDown, BIconEmojiSmileUpsideDownFill, BIconEmojiSunglasses, BIconEmojiSunglassesFill, BIconEmojiWink, BIconEmojiWinkFill, BIconEnvelope, BIconEnvelopeFill, BIconEnvelopeOpen, BIconEnvelopeOpenFill, BIconExclamation, BIconExclamationCircle, BIconExclamationCircleFill, BIconExclamationDiamond, BIconExclamationDiamondFill, BIconExclamationOctagon, BIconExclamationOctagonFill, BIconExclamationSquare, BIconExclamationSquareFill, BIconExclamationTriangle, BIconExclamationTriangleFill, BIconExclude, BIconEye, BIconEyeFill, BIconEyeSlash, BIconEyeSlashFill, BIconEyeglasses, BIconFacebook, BIconFile, BIconFileArrowDown, BIconFileArrowDownFill, BIconFileArrowUp, BIconFileArrowUpFill, BIconFileBarGraph, BIconFileBarGraphFill, BIconFileBinary, BIconFileBinaryFill, BIconFileBreak, BIconFileBreakFill, BIconFileCheck, BIconFileCheckFill, BIconFileCode, BIconFileCodeFill, BIconFileDiff, BIconFileDiffFill, BIconFileEarmark, BIconFileEarmarkArrowDown, BIconFileEarmarkArrowDownFill, BIconFileEarmarkArrowUp, BIconFileEarmarkArrowUpFill, BIconFileEarmarkBarGraph, BIconFileEarmarkBarGraphFill, BIconFileEarmarkBinary, BIconFileEarmarkBinaryFill, BIconFileEarmarkBreak, BIconFileEarmarkBreakFill, BIconFileEarmarkCheck, BIconFileEarmarkCheckFill, BIconFileEarmarkCode, BIconFileEarmarkCodeFill, BIconFileEarmarkDiff, BIconFileEarmarkDiffFill, BIconFileEarmarkEasel, BIconFileEarmarkEaselFill, BIconFileEarmarkExcel, BIconFileEarmarkExcelFill, BIconFileEarmarkFill, BIconFileEarmarkFont, BIconFileEarmarkFontFill, BIconFileEarmarkImage, BIconFileEarmarkImageFill, BIconFileEarmarkLock, BIconFileEarmarkLock2, BIconFileEarmarkLock2Fill, BIconFileEarmarkLockFill, BIconFileEarmarkMedical, BIconFileEarmarkMedicalFill, BIconFileEarmarkMinus, BIconFileEarmarkMinusFill, BIconFileEarmarkMusic, BIconFileEarmarkMusicFill, BIconFileEarmarkPerson, BIconFileEarmarkPersonFill, BIconFileEarmarkPlay, BIconFileEarmarkPlayFill, BIconFileEarmarkPlus, BIconFileEarmarkPlusFill, BIconFileEarmarkPost, BIconFileEarmarkPostFill, BIconFileEarmarkPpt, BIconFileEarmarkPptFill, BIconFileEarmarkRichtext, BIconFileEarmarkRichtextFill, BIconFileEarmarkRuled, BIconFileEarmarkRuledFill, BIconFileEarmarkSlides, BIconFileEarmarkSlidesFill, BIconFileEarmarkSpreadsheet, BIconFileEarmarkSpreadsheetFill, BIconFileEarmarkText, BIconFileEarmarkTextFill, BIconFileEarmarkWord, BIconFileEarmarkWordFill, BIconFileEarmarkX, BIconFileEarmarkXFill, BIconFileEarmarkZip, BIconFileEarmarkZipFill, BIconFileEasel, BIconFileEaselFill, BIconFileExcel, BIconFileExcelFill, BIconFileFill, BIconFileFont, BIconFileFontFill, BIconFileImage, BIconFileImageFill, BIconFileLock, BIconFileLock2, BIconFileLock2Fill, BIconFileLockFill, BIconFileMedical, BIconFileMedicalFill, BIconFileMinus, BIconFileMinusFill, BIconFileMusic, BIconFileMusicFill, BIconFilePerson, BIconFilePersonFill, BIconFilePlay, BIconFilePlayFill, BIconFilePlus, BIconFilePlusFill, BIconFilePost, BIconFilePostFill, BIconFilePpt, BIconFilePptFill, BIconFileRichtext, BIconFileRichtextFill, BIconFileRuled, BIconFileRuledFill, BIconFileSlides, BIconFileSlidesFill, BIconFileSpreadsheet, BIconFileSpreadsheetFill, BIconFileText, BIconFileTextFill, BIconFileWord, BIconFileWordFill, BIconFileX, BIconFileXFill, BIconFileZip, BIconFileZipFill, BIconFiles, BIconFilesAlt, BIconFilm, BIconFilter, BIconFilterCircle, BIconFilterCircleFill, BIconFilterLeft, BIconFilterRight, BIconFilterSquare, BIconFilterSquareFill, BIconFlag, BIconFlagFill, BIconFlower1, BIconFlower2, BIconFlower3, BIconFolder, BIconFolder2, BIconFolder2Open, BIconFolderCheck, BIconFolderFill, BIconFolderMinus, BIconFolderPlus, BIconFolderSymlink, BIconFolderSymlinkFill, BIconFolderX, BIconFonts, BIconForward, BIconForwardFill, BIconFront, BIconFullscreen, BIconFullscreenExit, BIconFunnel, BIconFunnelFill, BIconGear, BIconGearFill, BIconGearWide, BIconGearWideConnected, BIconGem, BIconGeo, BIconGeoAlt, BIconGeoAltFill, BIconGeoFill, BIconGift, BIconGiftFill, BIconGithub, BIconGlobe, BIconGlobe2, BIconGoogle, BIconGraphDown, BIconGraphUp, BIconGrid, BIconGrid1x2, BIconGrid1x2Fill, BIconGrid3x2, BIconGrid3x2Gap, BIconGrid3x2GapFill, BIconGrid3x3, BIconGrid3x3Gap, BIconGrid3x3GapFill, BIconGridFill, BIconGripHorizontal, BIconGripVertical, BIconHammer, BIconHandIndex, BIconHandIndexThumb, BIconHandThumbsDown, BIconHandThumbsUp, BIconHandbag, BIconHandbagFill, BIconHash, BIconHdd, BIconHddFill, BIconHddNetwork, BIconHddNetworkFill, BIconHddRack, BIconHddRackFill, BIconHddStack, BIconHddStackFill, BIconHeadphones, BIconHeadset, BIconHeart, BIconHeartFill, BIconHeartHalf, BIconHeptagon, BIconHeptagonFill, BIconHeptagonHalf, BIconHexagon, BIconHexagonFill, BIconHexagonHalf, BIconHourglass, BIconHourglassBottom, BIconHourglassSplit, BIconHourglassTop, BIconHouse, BIconHouseDoor, BIconHouseDoorFill, BIconHouseFill, BIconHr, BIconImage, BIconImageAlt, BIconImageFill, BIconImages, BIconInbox, BIconInboxFill, BIconInboxes, BIconInboxesFill, BIconInfo, BIconInfoCircle, BIconInfoCircleFill, BIconInfoSquare, BIconInfoSquareFill, BIconInputCursor, BIconInputCursorText, BIconInstagram, BIconIntersect, BIconJournal, BIconJournalAlbum, BIconJournalArrowDown, BIconJournalArrowUp, BIconJournalBookmark, BIconJournalBookmarkFill, BIconJournalCheck, BIconJournalCode, BIconJournalMedical, BIconJournalMinus, BIconJournalPlus, BIconJournalRichtext, BIconJournalText, BIconJournalX, BIconJournals, BIconJoystick, BIconJustify, BIconJustifyLeft, BIconJustifyRight, BIconKanban, BIconKanbanFill, BIconKey, BIconKeyFill, BIconKeyboard, BIconKeyboardFill, BIconLadder, BIconLamp, BIconLampFill, BIconLaptop, BIconLaptopFill, BIconLayers, BIconLayersFill, BIconLayersHalf, BIconLayoutSidebar, BIconLayoutSidebarInset, BIconLayoutSidebarInsetReverse, BIconLayoutSidebarReverse, BIconLayoutSplit, BIconLayoutTextSidebar, BIconLayoutTextSidebarReverse, BIconLayoutTextWindow, BIconLayoutTextWindowReverse, BIconLayoutThreeColumns, BIconLayoutWtf, BIconLifePreserver, BIconLightning, BIconLightningFill, BIconLink, BIconLink45deg, BIconLinkedin, BIconList, BIconListCheck, BIconListNested, BIconListOl, BIconListStars, BIconListTask, BIconListUl, BIconLock, BIconLockFill, BIconMailbox, BIconMailbox2, BIconMap, BIconMapFill, BIconMarkdown, BIconMarkdownFill, BIconMenuApp, BIconMenuAppFill, BIconMenuButton, BIconMenuButtonFill, BIconMenuButtonWide, BIconMenuButtonWideFill, BIconMenuDown, BIconMenuUp, BIconMic, BIconMicFill, BIconMicMute, BIconMicMuteFill, BIconMinecart, BIconMinecartLoaded, BIconMoon, BIconMouse, BIconMouse2, BIconMouse3, BIconMusicNote, BIconMusicNoteBeamed, BIconMusicNoteList, BIconMusicPlayer, BIconMusicPlayerFill, BIconNewspaper, BIconNodeMinus, BIconNodeMinusFill, BIconNodePlus, BIconNodePlusFill, BIconNut, BIconNutFill, BIconOctagon, BIconOctagonFill, BIconOctagonHalf, BIconOption, BIconOutlet, BIconPaperclip, BIconParagraph, BIconPatchCheck, BIconPatchCheckFill, BIconPatchExclamation, BIconPatchExclamationFill, BIconPatchMinus, BIconPatchMinusFill, BIconPatchPlus, BIconPatchPlusFill, BIconPatchQuestion, BIconPatchQuestionFill, BIconPause, BIconPauseBtn, BIconPauseBtnFill, BIconPauseCircle, BIconPauseCircleFill, BIconPauseFill, BIconPeace, BIconPeaceFill, BIconPen, BIconPenFill, BIconPencil, BIconPencilFill, BIconPencilSquare, BIconPentagon, BIconPentagonFill, BIconPentagonHalf, BIconPeople, BIconPeopleFill, BIconPercent, BIconPerson, BIconPersonBadge, BIconPersonBadgeFill, BIconPersonBoundingBox, BIconPersonCheck, BIconPersonCheckFill, BIconPersonCircle, BIconPersonDash, BIconPersonDashFill, BIconPersonFill, BIconPersonLinesFill, BIconPersonPlus, BIconPersonPlusFill, BIconPersonSquare, BIconPersonX, BIconPersonXFill, BIconPhone, BIconPhoneFill, BIconPhoneLandscape, BIconPhoneLandscapeFill, BIconPhoneVibrate, BIconPieChart, BIconPieChartFill, BIconPip, BIconPipFill, BIconPlay, BIconPlayBtn, BIconPlayBtnFill, BIconPlayCircle, BIconPlayCircleFill, BIconPlayFill, BIconPlug, BIconPlugFill, BIconPlus, BIconPlusCircle, BIconPlusCircleFill, BIconPlusSquare, BIconPlusSquareFill, BIconPower, BIconPrinter, BIconPrinterFill, BIconPuzzle, BIconPuzzleFill, BIconQuestion, BIconQuestionCircle, BIconQuestionCircleFill, BIconQuestionDiamond, BIconQuestionDiamondFill, BIconQuestionOctagon, BIconQuestionOctagonFill, BIconQuestionSquare, BIconQuestionSquareFill, BIconReceipt, BIconReceiptCutoff, BIconReception0, BIconReception1, BIconReception2, BIconReception3, BIconReception4, BIconRecord, BIconRecord2, BIconRecord2Fill, BIconRecordBtn, BIconRecordBtnFill, BIconRecordCircle, BIconRecordCircleFill, BIconRecordFill, BIconReply, BIconReplyAll, BIconReplyAllFill, BIconReplyFill, BIconRss, BIconRssFill, BIconScissors, BIconScrewdriver, BIconSearch, BIconSegmentedNav, BIconServer, BIconShare, BIconShareFill, BIconShield, BIconShieldCheck, BIconShieldExclamation, BIconShieldFill, BIconShieldFillCheck, BIconShieldFillExclamation, BIconShieldFillMinus, BIconShieldFillPlus, BIconShieldFillX, BIconShieldLock, BIconShieldLockFill, BIconShieldMinus, BIconShieldPlus, BIconShieldShaded, BIconShieldSlash, BIconShieldSlashFill, BIconShieldX, BIconShift, BIconShiftFill, BIconShop, BIconShopWindow, BIconShuffle, BIconSignpost, BIconSignpost2, BIconSignpost2Fill, BIconSignpostFill, BIconSignpostSplit, BIconSignpostSplitFill, BIconSim, BIconSimFill, BIconSkipBackward, BIconSkipBackwardBtn, BIconSkipBackwardBtnFill, BIconSkipBackwardCircle, BIconSkipBackwardCircleFill, BIconSkipBackwardFill, BIconSkipEnd, BIconSkipEndBtn, BIconSkipEndBtnFill, BIconSkipEndCircle, BIconSkipEndCircleFill, BIconSkipEndFill, BIconSkipForward, BIconSkipForwardBtn, BIconSkipForwardBtnFill, BIconSkipForwardCircle, BIconSkipForwardCircleFill, BIconSkipForwardFill, BIconSkipStart, BIconSkipStartBtn, BIconSkipStartBtnFill, BIconSkipStartCircle, BIconSkipStartCircleFill, BIconSkipStartFill, BIconSlack, BIconSlash, BIconSlashCircle, BIconSlashCircleFill, BIconSlashSquare, BIconSlashSquareFill, BIconSliders, BIconSmartwatch, BIconSortAlphaDown, BIconSortAlphaDownAlt, BIconSortAlphaUp, BIconSortAlphaUpAlt, BIconSortDown, BIconSortDownAlt, BIconSortNumericDown, BIconSortNumericDownAlt, BIconSortNumericUp, BIconSortNumericUpAlt, BIconSortUp, BIconSortUpAlt, BIconSoundwave, BIconSpeaker, BIconSpeakerFill, BIconSpellcheck, BIconSquare, BIconSquareFill, BIconSquareHalf, BIconStar, BIconStarFill, BIconStarHalf, BIconStickies, BIconStickiesFill, BIconSticky, BIconStickyFill, BIconStop, BIconStopBtn, BIconStopBtnFill, BIconStopCircle, BIconStopCircleFill, BIconStopFill, BIconStoplights, BIconStoplightsFill, BIconStopwatch, BIconStopwatchFill, BIconSubtract, BIconSuitClub, BIconSuitClubFill, BIconSuitDiamond, BIconSuitDiamondFill, BIconSuitHeart, BIconSuitHeartFill, BIconSuitSpade, BIconSuitSpadeFill, BIconSun, BIconSunglasses, BIconTable, BIconTablet, BIconTabletFill, BIconTabletLandscape, BIconTabletLandscapeFill, BIconTag, BIconTagFill, BIconTags, BIconTagsFill, BIconTelephone, BIconTelephoneFill, BIconTelephoneForward, BIconTelephoneForwardFill, BIconTelephoneInbound, BIconTelephoneInboundFill, BIconTelephoneMinus, BIconTelephoneMinusFill, BIconTelephoneOutbound, BIconTelephoneOutboundFill, BIconTelephonePlus, BIconTelephonePlusFill, BIconTelephoneX, BIconTelephoneXFill, BIconTerminal, BIconTerminalFill, BIconTextCenter, BIconTextIndentLeft, BIconTextIndentRight, BIconTextLeft, BIconTextParagraph, BIconTextRight, BIconTextarea, BIconTextareaResize, BIconTextareaT, BIconThermometer, BIconThermometerHalf, BIconThreeDots, BIconThreeDotsVertical, BIconToggle2Off, BIconToggle2On, BIconToggleOff, BIconToggleOn, BIconToggles, BIconToggles2, BIconTools, BIconTrash, BIconTrash2, BIconTrash2Fill, BIconTrashFill, BIconTree, BIconTreeFill, BIconTriangle, BIconTriangleFill, BIconTriangleHalf, BIconTrophy, BIconTrophyFill, BIconTruck, BIconTruckFlatbed, BIconTv, BIconTvFill, BIconTwitch, BIconTwitter, BIconType, BIconTypeBold, BIconTypeH1, BIconTypeH2, BIconTypeH3, BIconTypeItalic, BIconTypeStrikethrough, BIconTypeUnderline, BIconUiChecks, BIconUiChecksGrid, BIconUiRadios, BIconUiRadiosGrid, BIconUnion, BIconUnlock, BIconUnlockFill, BIconUpc, BIconUpcScan, BIconUpload, BIconVectorPen, BIconViewList, BIconViewStacked, BIconVinyl, BIconVinylFill, BIconVoicemail, BIconVolumeDown, BIconVolumeDownFill, BIconVolumeMute, BIconVolumeMuteFill, BIconVolumeOff, BIconVolumeOffFill, BIconVolumeUp, BIconVolumeUpFill, BIconVr, BIconWallet, BIconWallet2, BIconWalletFill, BIconWatch, BIconWifi, BIconWifi1, BIconWifi2, BIconWifiOff, BIconWindow, BIconWrench, BIconX, BIconXCircle, BIconXCircleFill, BIconXDiamond, BIconXDiamondFill, BIconXOctagon, BIconXOctagonFill, BIconXSquare, BIconXSquareFill, BIconYoutube, BIconZoomIn, BIconZoomOut, BIconstack, BImg, BImgLazy, BInputGroup, BInputGroupAddon, BInputGroupAppend, BInputGroupPrepend, BInputGroupText, BJumbotron, BLink, BListGroup, BListGroupItem, BMedia, BMediaAside, BMediaBody, BModal, BNav, BNavForm, BNavItem, BNavItemDropdown, BNavText, BNavbar, BNavbarBrand, BNavbarNav, BNavbarToggle, BOverlay, BPagination, BPaginationNav, BPopover, BProgress, BProgressBar, BRow, BSidebar, BSkeleton, BSkeletonIcon, BSkeletonImg, BSkeletonTable, BSkeletonWrapper, BSpinner, BTab, BTable, BTableLite, BTableSimple, BTabs, BTbody, BTd, BTfoot, BTh, BThead, BTime, BToast, BToaster, BTooltip, BTr, BVConfig, BVConfigPlugin, BVModalPlugin, BVToastPlugin, BadgePlugin, BootstrapVue, BootstrapVueIcons, BreadcrumbPlugin, ButtonGroupPlugin, ButtonPlugin, ButtonToolbarPlugin, CalendarPlugin, CardPlugin, CarouselPlugin, CollapsePlugin, DropdownPlugin, EmbedPlugin, FormCheckboxPlugin, FormDatepickerPlugin, FormFilePlugin, FormGroupPlugin, FormInputPlugin, FormPlugin, FormRadioPlugin, FormRatingPlugin, FormSelectPlugin, FormSpinbuttonPlugin, FormTagsPlugin, FormTextareaPlugin, FormTimepickerPlugin, IconsPlugin, ImagePlugin, InputGroupPlugin, JumbotronPlugin, LayoutPlugin, LinkPlugin, ListGroupPlugin, MediaPlugin, ModalPlugin, NAME, NavPlugin, NavbarPlugin, OverlayPlugin, PaginationNavPlugin, PaginationPlugin, PopoverPlugin, ProgressPlugin, SidebarPlugin, SkeletonPlugin, SpinnerPlugin, TableLitePlugin, TablePlugin, TableSimplePlugin, TabsPlugin, TimePlugin, ToastPlugin, TooltipPlugin, VBHover, VBHoverPlugin, VBModal, VBModalPlugin, VBPopover, VBPopoverPlugin, VBScrollspy, VBScrollspyPlugin, VBToggle, VBTogglePlugin, VBTooltip, VBTooltipPlugin, VBVisible, VBVisiblePlugin, install */
/***/function node_modulesBootstrapVueDistBootstrapVueEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* WEBPACK VAR INJECTION */(function(process){/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"AlertPlugin",function(){return AlertPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"AspectPlugin",function(){return AspectPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"AvatarPlugin",function(){return AvatarPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BAlert",function(){return BAlert;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BAspect",function(){return BAspect;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BAvatar",function(){return BAvatar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BAvatarGroup",function(){return BAvatarGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BBadge",function(){return BBadge;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BBreadcrumb",function(){return BBreadcrumb;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BBreadcrumbItem",function(){return BBreadcrumbItem;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BButton",function(){return BButton;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BButtonClose",function(){return BButtonClose;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BButtonGroup",function(){return BButtonGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BButtonToolbar",function(){return BButtonToolbar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCalendar",function(){return BCalendar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCard",function(){return BCard;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardBody",function(){return BCardBody;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardFooter",function(){return BCardFooter;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardGroup",function(){return BCardGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardHeader",function(){return BCardHeader;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardImg",function(){return BCardImg;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardImgLazy",function(){return BCardImgLazy;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardSubTitle",function(){return BCardSubTitle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardText",function(){return BCardText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCardTitle",function(){return BCardTitle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCarousel",function(){return BCarousel;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCarouselSlide",function(){return BCarouselSlide;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCol",function(){return BCol;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BCollapse",function(){return BCollapse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BContainer",function(){return BContainer;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdown",function(){return BDropdown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdownDivider",function(){return BDropdownDivider;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdownForm",function(){return BDropdownForm;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdownGroup",function(){return BDropdownGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdownHeader",function(){return BDropdownHeader;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdownItem",function(){return BDropdownItem;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdownItemButton",function(){return BDropdownItemButton;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BDropdownText",function(){return BDropdownText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BEmbed",function(){return BEmbed;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BForm",function(){return BForm;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormCheckbox",function(){return BFormCheckbox;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormCheckboxGroup",function(){return BFormCheckboxGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormDatalist",function(){return BFormDatalist;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormDatepicker",function(){return BFormDatepicker;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormFile",function(){return BFormFile;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormGroup",function(){return BFormGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormInput",function(){return BFormInput;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormInvalidFeedback",function(){return BFormInvalidFeedback;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormRadio",function(){return BFormRadio;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormRadioGroup",function(){return BFormRadioGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormRating",function(){return BFormRating;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormRow",function(){return BFormRow;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormSelect",function(){return BFormSelect;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormSelectOption",function(){return BFormSelectOption;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormSelectOptionGroup",function(){return BFormSelectOptionGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormSpinbutton",function(){return BFormSpinbutton;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormTag",function(){return BFormTag;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormTags",function(){return BFormTags;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormText",function(){return BFormText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormTextarea",function(){return BFormTextarea;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormTimepicker",function(){return BFormTimepicker;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BFormValidFeedback",function(){return BFormValidFeedback;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIcon",function(){return BIcon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlarm",function(){return BIconAlarm;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlarmFill",function(){return BIconAlarmFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlignBottom",function(){return BIconAlignBottom;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlignCenter",function(){return BIconAlignCenter;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlignEnd",function(){return BIconAlignEnd;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlignMiddle",function(){return BIconAlignMiddle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlignStart",function(){return BIconAlignStart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlignTop",function(){return BIconAlignTop;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAlt",function(){return BIconAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconApp",function(){return BIconApp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAppIndicator",function(){return BIconAppIndicator;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArchive",function(){return BIconArchive;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArchiveFill",function(){return BIconArchiveFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrow90degDown",function(){return BIconArrow90degDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrow90degLeft",function(){return BIconArrow90degLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrow90degRight",function(){return BIconArrow90degRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrow90degUp",function(){return BIconArrow90degUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowBarDown",function(){return BIconArrowBarDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowBarLeft",function(){return BIconArrowBarLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowBarRight",function(){return BIconArrowBarRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowBarUp",function(){return BIconArrowBarUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowClockwise",function(){return BIconArrowClockwise;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowCounterclockwise",function(){return BIconArrowCounterclockwise;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDown",function(){return BIconArrowDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownCircle",function(){return BIconArrowDownCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownCircleFill",function(){return BIconArrowDownCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownLeft",function(){return BIconArrowDownLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownLeftCircle",function(){return BIconArrowDownLeftCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownLeftCircleFill",function(){return BIconArrowDownLeftCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownLeftSquare",function(){return BIconArrowDownLeftSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownLeftSquareFill",function(){return BIconArrowDownLeftSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownRight",function(){return BIconArrowDownRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownRightCircle",function(){return BIconArrowDownRightCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownRightCircleFill",function(){return BIconArrowDownRightCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownRightSquare",function(){return BIconArrowDownRightSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownRightSquareFill",function(){return BIconArrowDownRightSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownShort",function(){return BIconArrowDownShort;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownSquare",function(){return BIconArrowDownSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownSquareFill",function(){return BIconArrowDownSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowDownUp",function(){return BIconArrowDownUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowLeft",function(){return BIconArrowLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowLeftCircle",function(){return BIconArrowLeftCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowLeftCircleFill",function(){return BIconArrowLeftCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowLeftRight",function(){return BIconArrowLeftRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowLeftShort",function(){return BIconArrowLeftShort;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowLeftSquare",function(){return BIconArrowLeftSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowLeftSquareFill",function(){return BIconArrowLeftSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowRepeat",function(){return BIconArrowRepeat;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowReturnLeft",function(){return BIconArrowReturnLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowReturnRight",function(){return BIconArrowReturnRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowRight",function(){return BIconArrowRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowRightCircle",function(){return BIconArrowRightCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowRightCircleFill",function(){return BIconArrowRightCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowRightShort",function(){return BIconArrowRightShort;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowRightSquare",function(){return BIconArrowRightSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowRightSquareFill",function(){return BIconArrowRightSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUp",function(){return BIconArrowUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpCircle",function(){return BIconArrowUpCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpCircleFill",function(){return BIconArrowUpCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpLeft",function(){return BIconArrowUpLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpLeftCircle",function(){return BIconArrowUpLeftCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpLeftCircleFill",function(){return BIconArrowUpLeftCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpLeftSquare",function(){return BIconArrowUpLeftSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpLeftSquareFill",function(){return BIconArrowUpLeftSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpRight",function(){return BIconArrowUpRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpRightCircle",function(){return BIconArrowUpRightCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpRightCircleFill",function(){return BIconArrowUpRightCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpRightSquare",function(){return BIconArrowUpRightSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpRightSquareFill",function(){return BIconArrowUpRightSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpShort",function(){return BIconArrowUpShort;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpSquare",function(){return BIconArrowUpSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowUpSquareFill",function(){return BIconArrowUpSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowsAngleContract",function(){return BIconArrowsAngleContract;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowsAngleExpand",function(){return BIconArrowsAngleExpand;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowsCollapse",function(){return BIconArrowsCollapse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowsExpand",function(){return BIconArrowsExpand;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowsFullscreen",function(){return BIconArrowsFullscreen;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconArrowsMove",function(){return BIconArrowsMove;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAspectRatio",function(){return BIconAspectRatio;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAspectRatioFill",function(){return BIconAspectRatioFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAsterisk",function(){return BIconAsterisk;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAt",function(){return BIconAt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAward",function(){return BIconAward;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconAwardFill",function(){return BIconAwardFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBack",function(){return BIconBack;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBackspace",function(){return BIconBackspace;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBackspaceFill",function(){return BIconBackspaceFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBackspaceReverse",function(){return BIconBackspaceReverse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBackspaceReverseFill",function(){return BIconBackspaceReverseFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadge4k",function(){return BIconBadge4k;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadge4kFill",function(){return BIconBadge4kFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadge8k",function(){return BIconBadge8k;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadge8kFill",function(){return BIconBadge8kFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeAd",function(){return BIconBadgeAd;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeAdFill",function(){return BIconBadgeAdFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeCc",function(){return BIconBadgeCc;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeCcFill",function(){return BIconBadgeCcFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeHd",function(){return BIconBadgeHd;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeHdFill",function(){return BIconBadgeHdFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeTm",function(){return BIconBadgeTm;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeTmFill",function(){return BIconBadgeTmFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeVo",function(){return BIconBadgeVo;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBadgeVoFill",function(){return BIconBadgeVoFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBag",function(){return BIconBag;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagCheck",function(){return BIconBagCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagCheckFill",function(){return BIconBagCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagDash",function(){return BIconBagDash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagDashFill",function(){return BIconBagDashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagFill",function(){return BIconBagFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagPlus",function(){return BIconBagPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagPlusFill",function(){return BIconBagPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagX",function(){return BIconBagX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBagXFill",function(){return BIconBagXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBarChart",function(){return BIconBarChart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBarChartFill",function(){return BIconBarChartFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBarChartLine",function(){return BIconBarChartLine;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBarChartLineFill",function(){return BIconBarChartLineFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBarChartSteps",function(){return BIconBarChartSteps;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBasket",function(){return BIconBasket;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBasket2",function(){return BIconBasket2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBasket2Fill",function(){return BIconBasket2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBasket3",function(){return BIconBasket3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBasket3Fill",function(){return BIconBasket3Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBasketFill",function(){return BIconBasketFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBattery",function(){return BIconBattery;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBatteryCharging",function(){return BIconBatteryCharging;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBatteryFull",function(){return BIconBatteryFull;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBatteryHalf",function(){return BIconBatteryHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBell",function(){return BIconBell;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBellFill",function(){return BIconBellFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBezier",function(){return BIconBezier;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBezier2",function(){return BIconBezier2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBicycle",function(){return BIconBicycle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBinoculars",function(){return BIconBinoculars;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBinocularsFill",function(){return BIconBinocularsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBlank",function(){return BIconBlank;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBlockquoteLeft",function(){return BIconBlockquoteLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBlockquoteRight",function(){return BIconBlockquoteRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBook",function(){return BIconBook;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookFill",function(){return BIconBookFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookHalf",function(){return BIconBookHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmark",function(){return BIconBookmark;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkCheck",function(){return BIconBookmarkCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkCheckFill",function(){return BIconBookmarkCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkDash",function(){return BIconBookmarkDash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkDashFill",function(){return BIconBookmarkDashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkFill",function(){return BIconBookmarkFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkHeart",function(){return BIconBookmarkHeart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkHeartFill",function(){return BIconBookmarkHeartFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkPlus",function(){return BIconBookmarkPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkPlusFill",function(){return BIconBookmarkPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkStar",function(){return BIconBookmarkStar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkStarFill",function(){return BIconBookmarkStarFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkX",function(){return BIconBookmarkX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarkXFill",function(){return BIconBookmarkXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarks",function(){return BIconBookmarks;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookmarksFill",function(){return BIconBookmarksFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBookshelf",function(){return BIconBookshelf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBootstrap",function(){return BIconBootstrap;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBootstrapFill",function(){return BIconBootstrapFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBootstrapReboot",function(){return BIconBootstrapReboot;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBorderStyle",function(){return BIconBorderStyle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBorderWidth",function(){return BIconBorderWidth;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoundingBox",function(){return BIconBoundingBox;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoundingBoxCircles",function(){return BIconBoundingBoxCircles;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBox",function(){return BIconBox;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowDown",function(){return BIconBoxArrowDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowDownLeft",function(){return BIconBoxArrowDownLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowDownRight",function(){return BIconBoxArrowDownRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInDown",function(){return BIconBoxArrowInDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInDownLeft",function(){return BIconBoxArrowInDownLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInDownRight",function(){return BIconBoxArrowInDownRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInLeft",function(){return BIconBoxArrowInLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInRight",function(){return BIconBoxArrowInRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInUp",function(){return BIconBoxArrowInUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInUpLeft",function(){return BIconBoxArrowInUpLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowInUpRight",function(){return BIconBoxArrowInUpRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowLeft",function(){return BIconBoxArrowLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowRight",function(){return BIconBoxArrowRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowUp",function(){return BIconBoxArrowUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowUpLeft",function(){return BIconBoxArrowUpLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxArrowUpRight",function(){return BIconBoxArrowUpRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBoxSeam",function(){return BIconBoxSeam;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBraces",function(){return BIconBraces;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBricks",function(){return BIconBricks;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBriefcase",function(){return BIconBriefcase;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBriefcaseFill",function(){return BIconBriefcaseFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessAltHigh",function(){return BIconBrightnessAltHigh;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessAltHighFill",function(){return BIconBrightnessAltHighFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessAltLow",function(){return BIconBrightnessAltLow;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessAltLowFill",function(){return BIconBrightnessAltLowFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessHigh",function(){return BIconBrightnessHigh;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessHighFill",function(){return BIconBrightnessHighFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessLow",function(){return BIconBrightnessLow;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrightnessLowFill",function(){return BIconBrightnessLowFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBroadcast",function(){return BIconBroadcast;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBroadcastPin",function(){return BIconBroadcastPin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrush",function(){return BIconBrush;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBrushFill",function(){return BIconBrushFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBucket",function(){return BIconBucket;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBucketFill",function(){return BIconBucketFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBug",function(){return BIconBug;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBugFill",function(){return BIconBugFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBuilding",function(){return BIconBuilding;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconBullseye",function(){return BIconBullseye;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalculator",function(){return BIconCalculator;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalculatorFill",function(){return BIconCalculatorFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar",function(){return BIconCalendar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2",function(){return BIconCalendar2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Check",function(){return BIconCalendar2Check;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2CheckFill",function(){return BIconCalendar2CheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Date",function(){return BIconCalendar2Date;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2DateFill",function(){return BIconCalendar2DateFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Day",function(){return BIconCalendar2Day;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2DayFill",function(){return BIconCalendar2DayFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Event",function(){return BIconCalendar2Event;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2EventFill",function(){return BIconCalendar2EventFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Fill",function(){return BIconCalendar2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Minus",function(){return BIconCalendar2Minus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2MinusFill",function(){return BIconCalendar2MinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Month",function(){return BIconCalendar2Month;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2MonthFill",function(){return BIconCalendar2MonthFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Plus",function(){return BIconCalendar2Plus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2PlusFill",function(){return BIconCalendar2PlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Range",function(){return BIconCalendar2Range;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2RangeFill",function(){return BIconCalendar2RangeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2Week",function(){return BIconCalendar2Week;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2WeekFill",function(){return BIconCalendar2WeekFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2X",function(){return BIconCalendar2X;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar2XFill",function(){return BIconCalendar2XFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3",function(){return BIconCalendar3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3Event",function(){return BIconCalendar3Event;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3EventFill",function(){return BIconCalendar3EventFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3Fill",function(){return BIconCalendar3Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3Range",function(){return BIconCalendar3Range;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3RangeFill",function(){return BIconCalendar3RangeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3Week",function(){return BIconCalendar3Week;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar3WeekFill",function(){return BIconCalendar3WeekFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar4",function(){return BIconCalendar4;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar4Event",function(){return BIconCalendar4Event;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar4Range",function(){return BIconCalendar4Range;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendar4Week",function(){return BIconCalendar4Week;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarCheck",function(){return BIconCalendarCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarCheckFill",function(){return BIconCalendarCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarDate",function(){return BIconCalendarDate;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarDateFill",function(){return BIconCalendarDateFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarDay",function(){return BIconCalendarDay;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarDayFill",function(){return BIconCalendarDayFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarEvent",function(){return BIconCalendarEvent;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarEventFill",function(){return BIconCalendarEventFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarFill",function(){return BIconCalendarFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarMinus",function(){return BIconCalendarMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarMinusFill",function(){return BIconCalendarMinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarMonth",function(){return BIconCalendarMonth;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarMonthFill",function(){return BIconCalendarMonthFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarPlus",function(){return BIconCalendarPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarPlusFill",function(){return BIconCalendarPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarRange",function(){return BIconCalendarRange;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarRangeFill",function(){return BIconCalendarRangeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarWeek",function(){return BIconCalendarWeek;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarWeekFill",function(){return BIconCalendarWeekFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarX",function(){return BIconCalendarX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCalendarXFill",function(){return BIconCalendarXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCamera",function(){return BIconCamera;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCamera2",function(){return BIconCamera2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCameraFill",function(){return BIconCameraFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCameraReels",function(){return BIconCameraReels;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCameraReelsFill",function(){return BIconCameraReelsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCameraVideo",function(){return BIconCameraVideo;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCameraVideoFill",function(){return BIconCameraVideoFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCameraVideoOff",function(){return BIconCameraVideoOff;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCameraVideoOffFill",function(){return BIconCameraVideoOffFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCapslock",function(){return BIconCapslock;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCapslockFill",function(){return BIconCapslockFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCardChecklist",function(){return BIconCardChecklist;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCardHeading",function(){return BIconCardHeading;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCardImage",function(){return BIconCardImage;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCardList",function(){return BIconCardList;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCardText",function(){return BIconCardText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretDown",function(){return BIconCaretDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretDownFill",function(){return BIconCaretDownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretDownSquare",function(){return BIconCaretDownSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretDownSquareFill",function(){return BIconCaretDownSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretLeft",function(){return BIconCaretLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretLeftFill",function(){return BIconCaretLeftFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretLeftSquare",function(){return BIconCaretLeftSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretLeftSquareFill",function(){return BIconCaretLeftSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretRight",function(){return BIconCaretRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretRightFill",function(){return BIconCaretRightFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretRightSquare",function(){return BIconCaretRightSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretRightSquareFill",function(){return BIconCaretRightSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretUp",function(){return BIconCaretUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretUpFill",function(){return BIconCaretUpFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretUpSquare",function(){return BIconCaretUpSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCaretUpSquareFill",function(){return BIconCaretUpSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCart",function(){return BIconCart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCart2",function(){return BIconCart2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCart3",function(){return BIconCart3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCart4",function(){return BIconCart4;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartCheck",function(){return BIconCartCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartCheckFill",function(){return BIconCartCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartDash",function(){return BIconCartDash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartDashFill",function(){return BIconCartDashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartFill",function(){return BIconCartFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartPlus",function(){return BIconCartPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartPlusFill",function(){return BIconCartPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartX",function(){return BIconCartX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCartXFill",function(){return BIconCartXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCash",function(){return BIconCash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCashStack",function(){return BIconCashStack;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCast",function(){return BIconCast;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChat",function(){return BIconChat;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatDots",function(){return BIconChatDots;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatDotsFill",function(){return BIconChatDotsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatFill",function(){return BIconChatFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeft",function(){return BIconChatLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeftDots",function(){return BIconChatLeftDots;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeftDotsFill",function(){return BIconChatLeftDotsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeftFill",function(){return BIconChatLeftFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeftQuote",function(){return BIconChatLeftQuote;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeftQuoteFill",function(){return BIconChatLeftQuoteFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeftText",function(){return BIconChatLeftText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatLeftTextFill",function(){return BIconChatLeftTextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatQuote",function(){return BIconChatQuote;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatQuoteFill",function(){return BIconChatQuoteFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRight",function(){return BIconChatRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRightDots",function(){return BIconChatRightDots;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRightDotsFill",function(){return BIconChatRightDotsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRightFill",function(){return BIconChatRightFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRightQuote",function(){return BIconChatRightQuote;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRightQuoteFill",function(){return BIconChatRightQuoteFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRightText",function(){return BIconChatRightText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatRightTextFill",function(){return BIconChatRightTextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquare",function(){return BIconChatSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquareDots",function(){return BIconChatSquareDots;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquareDotsFill",function(){return BIconChatSquareDotsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquareFill",function(){return BIconChatSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquareQuote",function(){return BIconChatSquareQuote;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquareQuoteFill",function(){return BIconChatSquareQuoteFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquareText",function(){return BIconChatSquareText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatSquareTextFill",function(){return BIconChatSquareTextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatText",function(){return BIconChatText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChatTextFill",function(){return BIconChatTextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheck",function(){return BIconCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheck2",function(){return BIconCheck2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheck2All",function(){return BIconCheck2All;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheck2Circle",function(){return BIconCheck2Circle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheck2Square",function(){return BIconCheck2Square;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheckAll",function(){return BIconCheckAll;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheckCircle",function(){return BIconCheckCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheckCircleFill",function(){return BIconCheckCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheckSquare",function(){return BIconCheckSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCheckSquareFill",function(){return BIconCheckSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronBarContract",function(){return BIconChevronBarContract;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronBarDown",function(){return BIconChevronBarDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronBarExpand",function(){return BIconChevronBarExpand;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronBarLeft",function(){return BIconChevronBarLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronBarRight",function(){return BIconChevronBarRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronBarUp",function(){return BIconChevronBarUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronCompactDown",function(){return BIconChevronCompactDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronCompactLeft",function(){return BIconChevronCompactLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronCompactRight",function(){return BIconChevronCompactRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronCompactUp",function(){return BIconChevronCompactUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronContract",function(){return BIconChevronContract;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronDoubleDown",function(){return BIconChevronDoubleDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronDoubleLeft",function(){return BIconChevronDoubleLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronDoubleRight",function(){return BIconChevronDoubleRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronDoubleUp",function(){return BIconChevronDoubleUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronDown",function(){return BIconChevronDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronExpand",function(){return BIconChevronExpand;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronLeft",function(){return BIconChevronLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronRight",function(){return BIconChevronRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconChevronUp",function(){return BIconChevronUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCircle",function(){return BIconCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCircleFill",function(){return BIconCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCircleHalf",function(){return BIconCircleHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCircleSquare",function(){return BIconCircleSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClipboard",function(){return BIconClipboard;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClipboardCheck",function(){return BIconClipboardCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClipboardData",function(){return BIconClipboardData;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClipboardMinus",function(){return BIconClipboardMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClipboardPlus",function(){return BIconClipboardPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClipboardX",function(){return BIconClipboardX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClock",function(){return BIconClock;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClockFill",function(){return BIconClockFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconClockHistory",function(){return BIconClockHistory;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloud",function(){return BIconCloud;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudArrowDown",function(){return BIconCloudArrowDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudArrowDownFill",function(){return BIconCloudArrowDownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudArrowUp",function(){return BIconCloudArrowUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudArrowUpFill",function(){return BIconCloudArrowUpFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudCheck",function(){return BIconCloudCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudCheckFill",function(){return BIconCloudCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudDownload",function(){return BIconCloudDownload;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudDownloadFill",function(){return BIconCloudDownloadFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudFill",function(){return BIconCloudFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudMinus",function(){return BIconCloudMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudMinusFill",function(){return BIconCloudMinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudPlus",function(){return BIconCloudPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudPlusFill",function(){return BIconCloudPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudSlash",function(){return BIconCloudSlash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudSlashFill",function(){return BIconCloudSlashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudUpload",function(){return BIconCloudUpload;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCloudUploadFill",function(){return BIconCloudUploadFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCode",function(){return BIconCode;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCodeSlash",function(){return BIconCodeSlash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCodeSquare",function(){return BIconCodeSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCollection",function(){return BIconCollection;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCollectionFill",function(){return BIconCollectionFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCollectionPlay",function(){return BIconCollectionPlay;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCollectionPlayFill",function(){return BIconCollectionPlayFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconColumns",function(){return BIconColumns;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconColumnsGap",function(){return BIconColumnsGap;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCommand",function(){return BIconCommand;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCompass",function(){return BIconCompass;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCompassFill",function(){return BIconCompassFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCone",function(){return BIconCone;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconConeStriped",function(){return BIconConeStriped;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconController",function(){return BIconController;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCpu",function(){return BIconCpu;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCpuFill",function(){return BIconCpuFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCreditCard",function(){return BIconCreditCard;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCreditCard2Back",function(){return BIconCreditCard2Back;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCreditCard2BackFill",function(){return BIconCreditCard2BackFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCreditCard2Front",function(){return BIconCreditCard2Front;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCreditCard2FrontFill",function(){return BIconCreditCard2FrontFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCreditCardFill",function(){return BIconCreditCardFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCrop",function(){return BIconCrop;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCup",function(){return BIconCup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCupFill",function(){return BIconCupFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCupStraw",function(){return BIconCupStraw;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCursor",function(){return BIconCursor;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCursorFill",function(){return BIconCursorFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconCursorText",function(){return BIconCursorText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDash",function(){return BIconDash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDashCircle",function(){return BIconDashCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDashCircleFill",function(){return BIconDashCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDashSquare",function(){return BIconDashSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDashSquareFill",function(){return BIconDashSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiagram2",function(){return BIconDiagram2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiagram2Fill",function(){return BIconDiagram2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiagram3",function(){return BIconDiagram3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiagram3Fill",function(){return BIconDiagram3Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiamond",function(){return BIconDiamond;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiamondFill",function(){return BIconDiamondFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiamondHalf",function(){return BIconDiamondHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice1",function(){return BIconDice1;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice1Fill",function(){return BIconDice1Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice2",function(){return BIconDice2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice2Fill",function(){return BIconDice2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice3",function(){return BIconDice3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice3Fill",function(){return BIconDice3Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice4",function(){return BIconDice4;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice4Fill",function(){return BIconDice4Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice5",function(){return BIconDice5;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice5Fill",function(){return BIconDice5Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice6",function(){return BIconDice6;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDice6Fill",function(){return BIconDice6Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDisc",function(){return BIconDisc;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiscFill",function(){return BIconDiscFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDiscord",function(){return BIconDiscord;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDisplay",function(){return BIconDisplay;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDisplayFill",function(){return BIconDisplayFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDistributeHorizontal",function(){return BIconDistributeHorizontal;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDistributeVertical",function(){return BIconDistributeVertical;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDoorClosed",function(){return BIconDoorClosed;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDoorClosedFill",function(){return BIconDoorClosedFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDoorOpen",function(){return BIconDoorOpen;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDoorOpenFill",function(){return BIconDoorOpenFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDot",function(){return BIconDot;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDownload",function(){return BIconDownload;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDroplet",function(){return BIconDroplet;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDropletFill",function(){return BIconDropletFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconDropletHalf",function(){return BIconDropletHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEarbuds",function(){return BIconEarbuds;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEasel",function(){return BIconEasel;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEaselFill",function(){return BIconEaselFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEgg",function(){return BIconEgg;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEggFill",function(){return BIconEggFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEggFried",function(){return BIconEggFried;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEject",function(){return BIconEject;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEjectFill",function(){return BIconEjectFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiAngry",function(){return BIconEmojiAngry;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiAngryFill",function(){return BIconEmojiAngryFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiDizzy",function(){return BIconEmojiDizzy;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiDizzyFill",function(){return BIconEmojiDizzyFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiExpressionless",function(){return BIconEmojiExpressionless;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiExpressionlessFill",function(){return BIconEmojiExpressionlessFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiFrown",function(){return BIconEmojiFrown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiFrownFill",function(){return BIconEmojiFrownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiHeartEyes",function(){return BIconEmojiHeartEyes;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiHeartEyesFill",function(){return BIconEmojiHeartEyesFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiLaughing",function(){return BIconEmojiLaughing;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiLaughingFill",function(){return BIconEmojiLaughingFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiNeutral",function(){return BIconEmojiNeutral;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiNeutralFill",function(){return BIconEmojiNeutralFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiSmile",function(){return BIconEmojiSmile;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiSmileFill",function(){return BIconEmojiSmileFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiSmileUpsideDown",function(){return BIconEmojiSmileUpsideDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiSmileUpsideDownFill",function(){return BIconEmojiSmileUpsideDownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiSunglasses",function(){return BIconEmojiSunglasses;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiSunglassesFill",function(){return BIconEmojiSunglassesFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiWink",function(){return BIconEmojiWink;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEmojiWinkFill",function(){return BIconEmojiWinkFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEnvelope",function(){return BIconEnvelope;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEnvelopeFill",function(){return BIconEnvelopeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEnvelopeOpen",function(){return BIconEnvelopeOpen;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEnvelopeOpenFill",function(){return BIconEnvelopeOpenFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamation",function(){return BIconExclamation;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationCircle",function(){return BIconExclamationCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationCircleFill",function(){return BIconExclamationCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationDiamond",function(){return BIconExclamationDiamond;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationDiamondFill",function(){return BIconExclamationDiamondFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationOctagon",function(){return BIconExclamationOctagon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationOctagonFill",function(){return BIconExclamationOctagonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationSquare",function(){return BIconExclamationSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationSquareFill",function(){return BIconExclamationSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationTriangle",function(){return BIconExclamationTriangle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclamationTriangleFill",function(){return BIconExclamationTriangleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconExclude",function(){return BIconExclude;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEye",function(){return BIconEye;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEyeFill",function(){return BIconEyeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEyeSlash",function(){return BIconEyeSlash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEyeSlashFill",function(){return BIconEyeSlashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconEyeglasses",function(){return BIconEyeglasses;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFacebook",function(){return BIconFacebook;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFile",function(){return BIconFile;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileArrowDown",function(){return BIconFileArrowDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileArrowDownFill",function(){return BIconFileArrowDownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileArrowUp",function(){return BIconFileArrowUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileArrowUpFill",function(){return BIconFileArrowUpFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileBarGraph",function(){return BIconFileBarGraph;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileBarGraphFill",function(){return BIconFileBarGraphFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileBinary",function(){return BIconFileBinary;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileBinaryFill",function(){return BIconFileBinaryFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileBreak",function(){return BIconFileBreak;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileBreakFill",function(){return BIconFileBreakFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileCheck",function(){return BIconFileCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileCheckFill",function(){return BIconFileCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileCode",function(){return BIconFileCode;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileCodeFill",function(){return BIconFileCodeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileDiff",function(){return BIconFileDiff;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileDiffFill",function(){return BIconFileDiffFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmark",function(){return BIconFileEarmark;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkArrowDown",function(){return BIconFileEarmarkArrowDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkArrowDownFill",function(){return BIconFileEarmarkArrowDownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkArrowUp",function(){return BIconFileEarmarkArrowUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkArrowUpFill",function(){return BIconFileEarmarkArrowUpFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkBarGraph",function(){return BIconFileEarmarkBarGraph;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkBarGraphFill",function(){return BIconFileEarmarkBarGraphFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkBinary",function(){return BIconFileEarmarkBinary;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkBinaryFill",function(){return BIconFileEarmarkBinaryFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkBreak",function(){return BIconFileEarmarkBreak;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkBreakFill",function(){return BIconFileEarmarkBreakFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkCheck",function(){return BIconFileEarmarkCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkCheckFill",function(){return BIconFileEarmarkCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkCode",function(){return BIconFileEarmarkCode;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkCodeFill",function(){return BIconFileEarmarkCodeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkDiff",function(){return BIconFileEarmarkDiff;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkDiffFill",function(){return BIconFileEarmarkDiffFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkEasel",function(){return BIconFileEarmarkEasel;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkEaselFill",function(){return BIconFileEarmarkEaselFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkExcel",function(){return BIconFileEarmarkExcel;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkExcelFill",function(){return BIconFileEarmarkExcelFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkFill",function(){return BIconFileEarmarkFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkFont",function(){return BIconFileEarmarkFont;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkFontFill",function(){return BIconFileEarmarkFontFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkImage",function(){return BIconFileEarmarkImage;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkImageFill",function(){return BIconFileEarmarkImageFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkLock",function(){return BIconFileEarmarkLock;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkLock2",function(){return BIconFileEarmarkLock2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkLock2Fill",function(){return BIconFileEarmarkLock2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkLockFill",function(){return BIconFileEarmarkLockFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkMedical",function(){return BIconFileEarmarkMedical;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkMedicalFill",function(){return BIconFileEarmarkMedicalFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkMinus",function(){return BIconFileEarmarkMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkMinusFill",function(){return BIconFileEarmarkMinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkMusic",function(){return BIconFileEarmarkMusic;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkMusicFill",function(){return BIconFileEarmarkMusicFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPerson",function(){return BIconFileEarmarkPerson;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPersonFill",function(){return BIconFileEarmarkPersonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPlay",function(){return BIconFileEarmarkPlay;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPlayFill",function(){return BIconFileEarmarkPlayFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPlus",function(){return BIconFileEarmarkPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPlusFill",function(){return BIconFileEarmarkPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPost",function(){return BIconFileEarmarkPost;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPostFill",function(){return BIconFileEarmarkPostFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPpt",function(){return BIconFileEarmarkPpt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkPptFill",function(){return BIconFileEarmarkPptFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkRichtext",function(){return BIconFileEarmarkRichtext;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkRichtextFill",function(){return BIconFileEarmarkRichtextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkRuled",function(){return BIconFileEarmarkRuled;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkRuledFill",function(){return BIconFileEarmarkRuledFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkSlides",function(){return BIconFileEarmarkSlides;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkSlidesFill",function(){return BIconFileEarmarkSlidesFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkSpreadsheet",function(){return BIconFileEarmarkSpreadsheet;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkSpreadsheetFill",function(){return BIconFileEarmarkSpreadsheetFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkText",function(){return BIconFileEarmarkText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkTextFill",function(){return BIconFileEarmarkTextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkWord",function(){return BIconFileEarmarkWord;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkWordFill",function(){return BIconFileEarmarkWordFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkX",function(){return BIconFileEarmarkX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkXFill",function(){return BIconFileEarmarkXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkZip",function(){return BIconFileEarmarkZip;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEarmarkZipFill",function(){return BIconFileEarmarkZipFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEasel",function(){return BIconFileEasel;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileEaselFill",function(){return BIconFileEaselFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileExcel",function(){return BIconFileExcel;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileExcelFill",function(){return BIconFileExcelFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileFill",function(){return BIconFileFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileFont",function(){return BIconFileFont;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileFontFill",function(){return BIconFileFontFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileImage",function(){return BIconFileImage;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileImageFill",function(){return BIconFileImageFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileLock",function(){return BIconFileLock;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileLock2",function(){return BIconFileLock2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileLock2Fill",function(){return BIconFileLock2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileLockFill",function(){return BIconFileLockFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileMedical",function(){return BIconFileMedical;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileMedicalFill",function(){return BIconFileMedicalFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileMinus",function(){return BIconFileMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileMinusFill",function(){return BIconFileMinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileMusic",function(){return BIconFileMusic;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileMusicFill",function(){return BIconFileMusicFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePerson",function(){return BIconFilePerson;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePersonFill",function(){return BIconFilePersonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePlay",function(){return BIconFilePlay;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePlayFill",function(){return BIconFilePlayFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePlus",function(){return BIconFilePlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePlusFill",function(){return BIconFilePlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePost",function(){return BIconFilePost;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePostFill",function(){return BIconFilePostFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePpt",function(){return BIconFilePpt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilePptFill",function(){return BIconFilePptFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileRichtext",function(){return BIconFileRichtext;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileRichtextFill",function(){return BIconFileRichtextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileRuled",function(){return BIconFileRuled;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileRuledFill",function(){return BIconFileRuledFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileSlides",function(){return BIconFileSlides;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileSlidesFill",function(){return BIconFileSlidesFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileSpreadsheet",function(){return BIconFileSpreadsheet;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileSpreadsheetFill",function(){return BIconFileSpreadsheetFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileText",function(){return BIconFileText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileTextFill",function(){return BIconFileTextFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileWord",function(){return BIconFileWord;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileWordFill",function(){return BIconFileWordFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileX",function(){return BIconFileX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileXFill",function(){return BIconFileXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileZip",function(){return BIconFileZip;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFileZipFill",function(){return BIconFileZipFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFiles",function(){return BIconFiles;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilesAlt",function(){return BIconFilesAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilm",function(){return BIconFilm;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilter",function(){return BIconFilter;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilterCircle",function(){return BIconFilterCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilterCircleFill",function(){return BIconFilterCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilterLeft",function(){return BIconFilterLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilterRight",function(){return BIconFilterRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilterSquare",function(){return BIconFilterSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFilterSquareFill",function(){return BIconFilterSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFlag",function(){return BIconFlag;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFlagFill",function(){return BIconFlagFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFlower1",function(){return BIconFlower1;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFlower2",function(){return BIconFlower2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFlower3",function(){return BIconFlower3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolder",function(){return BIconFolder;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolder2",function(){return BIconFolder2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolder2Open",function(){return BIconFolder2Open;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolderCheck",function(){return BIconFolderCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolderFill",function(){return BIconFolderFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolderMinus",function(){return BIconFolderMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolderPlus",function(){return BIconFolderPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolderSymlink",function(){return BIconFolderSymlink;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolderSymlinkFill",function(){return BIconFolderSymlinkFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFolderX",function(){return BIconFolderX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFonts",function(){return BIconFonts;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconForward",function(){return BIconForward;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconForwardFill",function(){return BIconForwardFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFront",function(){return BIconFront;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFullscreen",function(){return BIconFullscreen;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFullscreenExit",function(){return BIconFullscreenExit;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFunnel",function(){return BIconFunnel;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconFunnelFill",function(){return BIconFunnelFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGear",function(){return BIconGear;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGearFill",function(){return BIconGearFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGearWide",function(){return BIconGearWide;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGearWideConnected",function(){return BIconGearWideConnected;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGem",function(){return BIconGem;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGeo",function(){return BIconGeo;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGeoAlt",function(){return BIconGeoAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGeoAltFill",function(){return BIconGeoAltFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGeoFill",function(){return BIconGeoFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGift",function(){return BIconGift;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGiftFill",function(){return BIconGiftFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGithub",function(){return BIconGithub;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGlobe",function(){return BIconGlobe;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGlobe2",function(){return BIconGlobe2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGoogle",function(){return BIconGoogle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGraphDown",function(){return BIconGraphDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGraphUp",function(){return BIconGraphUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid",function(){return BIconGrid;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid1x2",function(){return BIconGrid1x2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid1x2Fill",function(){return BIconGrid1x2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid3x2",function(){return BIconGrid3x2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid3x2Gap",function(){return BIconGrid3x2Gap;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid3x2GapFill",function(){return BIconGrid3x2GapFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid3x3",function(){return BIconGrid3x3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid3x3Gap",function(){return BIconGrid3x3Gap;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGrid3x3GapFill",function(){return BIconGrid3x3GapFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGridFill",function(){return BIconGridFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGripHorizontal",function(){return BIconGripHorizontal;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconGripVertical",function(){return BIconGripVertical;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHammer",function(){return BIconHammer;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHandIndex",function(){return BIconHandIndex;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHandIndexThumb",function(){return BIconHandIndexThumb;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHandThumbsDown",function(){return BIconHandThumbsDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHandThumbsUp",function(){return BIconHandThumbsUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHandbag",function(){return BIconHandbag;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHandbagFill",function(){return BIconHandbagFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHash",function(){return BIconHash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHdd",function(){return BIconHdd;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHddFill",function(){return BIconHddFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHddNetwork",function(){return BIconHddNetwork;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHddNetworkFill",function(){return BIconHddNetworkFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHddRack",function(){return BIconHddRack;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHddRackFill",function(){return BIconHddRackFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHddStack",function(){return BIconHddStack;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHddStackFill",function(){return BIconHddStackFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeadphones",function(){return BIconHeadphones;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeadset",function(){return BIconHeadset;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeart",function(){return BIconHeart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeartFill",function(){return BIconHeartFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeartHalf",function(){return BIconHeartHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeptagon",function(){return BIconHeptagon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeptagonFill",function(){return BIconHeptagonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHeptagonHalf",function(){return BIconHeptagonHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHexagon",function(){return BIconHexagon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHexagonFill",function(){return BIconHexagonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHexagonHalf",function(){return BIconHexagonHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHourglass",function(){return BIconHourglass;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHourglassBottom",function(){return BIconHourglassBottom;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHourglassSplit",function(){return BIconHourglassSplit;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHourglassTop",function(){return BIconHourglassTop;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHouse",function(){return BIconHouse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHouseDoor",function(){return BIconHouseDoor;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHouseDoorFill",function(){return BIconHouseDoorFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHouseFill",function(){return BIconHouseFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconHr",function(){return BIconHr;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconImage",function(){return BIconImage;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconImageAlt",function(){return BIconImageAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconImageFill",function(){return BIconImageFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconImages",function(){return BIconImages;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInbox",function(){return BIconInbox;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInboxFill",function(){return BIconInboxFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInboxes",function(){return BIconInboxes;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInboxesFill",function(){return BIconInboxesFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInfo",function(){return BIconInfo;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInfoCircle",function(){return BIconInfoCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInfoCircleFill",function(){return BIconInfoCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInfoSquare",function(){return BIconInfoSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInfoSquareFill",function(){return BIconInfoSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInputCursor",function(){return BIconInputCursor;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInputCursorText",function(){return BIconInputCursorText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconInstagram",function(){return BIconInstagram;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconIntersect",function(){return BIconIntersect;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournal",function(){return BIconJournal;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalAlbum",function(){return BIconJournalAlbum;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalArrowDown",function(){return BIconJournalArrowDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalArrowUp",function(){return BIconJournalArrowUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalBookmark",function(){return BIconJournalBookmark;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalBookmarkFill",function(){return BIconJournalBookmarkFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalCheck",function(){return BIconJournalCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalCode",function(){return BIconJournalCode;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalMedical",function(){return BIconJournalMedical;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalMinus",function(){return BIconJournalMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalPlus",function(){return BIconJournalPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalRichtext",function(){return BIconJournalRichtext;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalText",function(){return BIconJournalText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournalX",function(){return BIconJournalX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJournals",function(){return BIconJournals;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJoystick",function(){return BIconJoystick;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJustify",function(){return BIconJustify;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJustifyLeft",function(){return BIconJustifyLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconJustifyRight",function(){return BIconJustifyRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconKanban",function(){return BIconKanban;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconKanbanFill",function(){return BIconKanbanFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconKey",function(){return BIconKey;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconKeyFill",function(){return BIconKeyFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconKeyboard",function(){return BIconKeyboard;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconKeyboardFill",function(){return BIconKeyboardFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLadder",function(){return BIconLadder;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLamp",function(){return BIconLamp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLampFill",function(){return BIconLampFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLaptop",function(){return BIconLaptop;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLaptopFill",function(){return BIconLaptopFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayers",function(){return BIconLayers;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayersFill",function(){return BIconLayersFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayersHalf",function(){return BIconLayersHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutSidebar",function(){return BIconLayoutSidebar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutSidebarInset",function(){return BIconLayoutSidebarInset;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutSidebarInsetReverse",function(){return BIconLayoutSidebarInsetReverse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutSidebarReverse",function(){return BIconLayoutSidebarReverse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutSplit",function(){return BIconLayoutSplit;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutTextSidebar",function(){return BIconLayoutTextSidebar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutTextSidebarReverse",function(){return BIconLayoutTextSidebarReverse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutTextWindow",function(){return BIconLayoutTextWindow;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutTextWindowReverse",function(){return BIconLayoutTextWindowReverse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutThreeColumns",function(){return BIconLayoutThreeColumns;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLayoutWtf",function(){return BIconLayoutWtf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLifePreserver",function(){return BIconLifePreserver;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLightning",function(){return BIconLightning;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLightningFill",function(){return BIconLightningFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLink",function(){return BIconLink;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLink45deg",function(){return BIconLink45deg;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLinkedin",function(){return BIconLinkedin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconList",function(){return BIconList;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconListCheck",function(){return BIconListCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconListNested",function(){return BIconListNested;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconListOl",function(){return BIconListOl;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconListStars",function(){return BIconListStars;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconListTask",function(){return BIconListTask;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconListUl",function(){return BIconListUl;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLock",function(){return BIconLock;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconLockFill",function(){return BIconLockFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMailbox",function(){return BIconMailbox;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMailbox2",function(){return BIconMailbox2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMap",function(){return BIconMap;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMapFill",function(){return BIconMapFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMarkdown",function(){return BIconMarkdown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMarkdownFill",function(){return BIconMarkdownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuApp",function(){return BIconMenuApp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuAppFill",function(){return BIconMenuAppFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuButton",function(){return BIconMenuButton;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuButtonFill",function(){return BIconMenuButtonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuButtonWide",function(){return BIconMenuButtonWide;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuButtonWideFill",function(){return BIconMenuButtonWideFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuDown",function(){return BIconMenuDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMenuUp",function(){return BIconMenuUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMic",function(){return BIconMic;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMicFill",function(){return BIconMicFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMicMute",function(){return BIconMicMute;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMicMuteFill",function(){return BIconMicMuteFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMinecart",function(){return BIconMinecart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMinecartLoaded",function(){return BIconMinecartLoaded;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMoon",function(){return BIconMoon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMouse",function(){return BIconMouse;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMouse2",function(){return BIconMouse2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMouse3",function(){return BIconMouse3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMusicNote",function(){return BIconMusicNote;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMusicNoteBeamed",function(){return BIconMusicNoteBeamed;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMusicNoteList",function(){return BIconMusicNoteList;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMusicPlayer",function(){return BIconMusicPlayer;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconMusicPlayerFill",function(){return BIconMusicPlayerFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconNewspaper",function(){return BIconNewspaper;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconNodeMinus",function(){return BIconNodeMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconNodeMinusFill",function(){return BIconNodeMinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconNodePlus",function(){return BIconNodePlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconNodePlusFill",function(){return BIconNodePlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconNut",function(){return BIconNut;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconNutFill",function(){return BIconNutFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconOctagon",function(){return BIconOctagon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconOctagonFill",function(){return BIconOctagonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconOctagonHalf",function(){return BIconOctagonHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconOption",function(){return BIconOption;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconOutlet",function(){return BIconOutlet;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPaperclip",function(){return BIconPaperclip;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconParagraph",function(){return BIconParagraph;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchCheck",function(){return BIconPatchCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchCheckFill",function(){return BIconPatchCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchExclamation",function(){return BIconPatchExclamation;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchExclamationFill",function(){return BIconPatchExclamationFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchMinus",function(){return BIconPatchMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchMinusFill",function(){return BIconPatchMinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchPlus",function(){return BIconPatchPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchPlusFill",function(){return BIconPatchPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchQuestion",function(){return BIconPatchQuestion;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPatchQuestionFill",function(){return BIconPatchQuestionFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPause",function(){return BIconPause;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPauseBtn",function(){return BIconPauseBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPauseBtnFill",function(){return BIconPauseBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPauseCircle",function(){return BIconPauseCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPauseCircleFill",function(){return BIconPauseCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPauseFill",function(){return BIconPauseFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPeace",function(){return BIconPeace;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPeaceFill",function(){return BIconPeaceFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPen",function(){return BIconPen;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPenFill",function(){return BIconPenFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPencil",function(){return BIconPencil;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPencilFill",function(){return BIconPencilFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPencilSquare",function(){return BIconPencilSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPentagon",function(){return BIconPentagon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPentagonFill",function(){return BIconPentagonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPentagonHalf",function(){return BIconPentagonHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPeople",function(){return BIconPeople;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPeopleFill",function(){return BIconPeopleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPercent",function(){return BIconPercent;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPerson",function(){return BIconPerson;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonBadge",function(){return BIconPersonBadge;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonBadgeFill",function(){return BIconPersonBadgeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonBoundingBox",function(){return BIconPersonBoundingBox;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonCheck",function(){return BIconPersonCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonCheckFill",function(){return BIconPersonCheckFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonCircle",function(){return BIconPersonCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonDash",function(){return BIconPersonDash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonDashFill",function(){return BIconPersonDashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonFill",function(){return BIconPersonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonLinesFill",function(){return BIconPersonLinesFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonPlus",function(){return BIconPersonPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonPlusFill",function(){return BIconPersonPlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonSquare",function(){return BIconPersonSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonX",function(){return BIconPersonX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPersonXFill",function(){return BIconPersonXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPhone",function(){return BIconPhone;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPhoneFill",function(){return BIconPhoneFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPhoneLandscape",function(){return BIconPhoneLandscape;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPhoneLandscapeFill",function(){return BIconPhoneLandscapeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPhoneVibrate",function(){return BIconPhoneVibrate;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPieChart",function(){return BIconPieChart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPieChartFill",function(){return BIconPieChartFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPip",function(){return BIconPip;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPipFill",function(){return BIconPipFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlay",function(){return BIconPlay;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlayBtn",function(){return BIconPlayBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlayBtnFill",function(){return BIconPlayBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlayCircle",function(){return BIconPlayCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlayCircleFill",function(){return BIconPlayCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlayFill",function(){return BIconPlayFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlug",function(){return BIconPlug;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlugFill",function(){return BIconPlugFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlus",function(){return BIconPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlusCircle",function(){return BIconPlusCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlusCircleFill",function(){return BIconPlusCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlusSquare",function(){return BIconPlusSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPlusSquareFill",function(){return BIconPlusSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPower",function(){return BIconPower;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPrinter",function(){return BIconPrinter;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPrinterFill",function(){return BIconPrinterFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPuzzle",function(){return BIconPuzzle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconPuzzleFill",function(){return BIconPuzzleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestion",function(){return BIconQuestion;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionCircle",function(){return BIconQuestionCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionCircleFill",function(){return BIconQuestionCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionDiamond",function(){return BIconQuestionDiamond;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionDiamondFill",function(){return BIconQuestionDiamondFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionOctagon",function(){return BIconQuestionOctagon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionOctagonFill",function(){return BIconQuestionOctagonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionSquare",function(){return BIconQuestionSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconQuestionSquareFill",function(){return BIconQuestionSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReceipt",function(){return BIconReceipt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReceiptCutoff",function(){return BIconReceiptCutoff;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReception0",function(){return BIconReception0;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReception1",function(){return BIconReception1;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReception2",function(){return BIconReception2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReception3",function(){return BIconReception3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReception4",function(){return BIconReception4;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecord",function(){return BIconRecord;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecord2",function(){return BIconRecord2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecord2Fill",function(){return BIconRecord2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecordBtn",function(){return BIconRecordBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecordBtnFill",function(){return BIconRecordBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecordCircle",function(){return BIconRecordCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecordCircleFill",function(){return BIconRecordCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRecordFill",function(){return BIconRecordFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReply",function(){return BIconReply;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReplyAll",function(){return BIconReplyAll;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReplyAllFill",function(){return BIconReplyAllFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconReplyFill",function(){return BIconReplyFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRss",function(){return BIconRss;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconRssFill",function(){return BIconRssFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconScissors",function(){return BIconScissors;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconScrewdriver",function(){return BIconScrewdriver;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSearch",function(){return BIconSearch;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSegmentedNav",function(){return BIconSegmentedNav;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconServer",function(){return BIconServer;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShare",function(){return BIconShare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShareFill",function(){return BIconShareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShield",function(){return BIconShield;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldCheck",function(){return BIconShieldCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldExclamation",function(){return BIconShieldExclamation;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldFill",function(){return BIconShieldFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldFillCheck",function(){return BIconShieldFillCheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldFillExclamation",function(){return BIconShieldFillExclamation;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldFillMinus",function(){return BIconShieldFillMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldFillPlus",function(){return BIconShieldFillPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldFillX",function(){return BIconShieldFillX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldLock",function(){return BIconShieldLock;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldLockFill",function(){return BIconShieldLockFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldMinus",function(){return BIconShieldMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldPlus",function(){return BIconShieldPlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldShaded",function(){return BIconShieldShaded;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldSlash",function(){return BIconShieldSlash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldSlashFill",function(){return BIconShieldSlashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShieldX",function(){return BIconShieldX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShift",function(){return BIconShift;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShiftFill",function(){return BIconShiftFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShop",function(){return BIconShop;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShopWindow",function(){return BIconShopWindow;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconShuffle",function(){return BIconShuffle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSignpost",function(){return BIconSignpost;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSignpost2",function(){return BIconSignpost2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSignpost2Fill",function(){return BIconSignpost2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSignpostFill",function(){return BIconSignpostFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSignpostSplit",function(){return BIconSignpostSplit;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSignpostSplitFill",function(){return BIconSignpostSplitFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSim",function(){return BIconSim;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSimFill",function(){return BIconSimFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipBackward",function(){return BIconSkipBackward;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipBackwardBtn",function(){return BIconSkipBackwardBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipBackwardBtnFill",function(){return BIconSkipBackwardBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipBackwardCircle",function(){return BIconSkipBackwardCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipBackwardCircleFill",function(){return BIconSkipBackwardCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipBackwardFill",function(){return BIconSkipBackwardFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipEnd",function(){return BIconSkipEnd;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipEndBtn",function(){return BIconSkipEndBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipEndBtnFill",function(){return BIconSkipEndBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipEndCircle",function(){return BIconSkipEndCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipEndCircleFill",function(){return BIconSkipEndCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipEndFill",function(){return BIconSkipEndFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipForward",function(){return BIconSkipForward;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipForwardBtn",function(){return BIconSkipForwardBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipForwardBtnFill",function(){return BIconSkipForwardBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipForwardCircle",function(){return BIconSkipForwardCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipForwardCircleFill",function(){return BIconSkipForwardCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipForwardFill",function(){return BIconSkipForwardFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipStart",function(){return BIconSkipStart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipStartBtn",function(){return BIconSkipStartBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipStartBtnFill",function(){return BIconSkipStartBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipStartCircle",function(){return BIconSkipStartCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipStartCircleFill",function(){return BIconSkipStartCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSkipStartFill",function(){return BIconSkipStartFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSlack",function(){return BIconSlack;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSlash",function(){return BIconSlash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSlashCircle",function(){return BIconSlashCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSlashCircleFill",function(){return BIconSlashCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSlashSquare",function(){return BIconSlashSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSlashSquareFill",function(){return BIconSlashSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSliders",function(){return BIconSliders;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSmartwatch",function(){return BIconSmartwatch;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortAlphaDown",function(){return BIconSortAlphaDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortAlphaDownAlt",function(){return BIconSortAlphaDownAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortAlphaUp",function(){return BIconSortAlphaUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortAlphaUpAlt",function(){return BIconSortAlphaUpAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortDown",function(){return BIconSortDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortDownAlt",function(){return BIconSortDownAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortNumericDown",function(){return BIconSortNumericDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortNumericDownAlt",function(){return BIconSortNumericDownAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortNumericUp",function(){return BIconSortNumericUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortNumericUpAlt",function(){return BIconSortNumericUpAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortUp",function(){return BIconSortUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSortUpAlt",function(){return BIconSortUpAlt;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSoundwave",function(){return BIconSoundwave;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSpeaker",function(){return BIconSpeaker;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSpeakerFill",function(){return BIconSpeakerFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSpellcheck",function(){return BIconSpellcheck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSquare",function(){return BIconSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSquareFill",function(){return BIconSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSquareHalf",function(){return BIconSquareHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStar",function(){return BIconStar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStarFill",function(){return BIconStarFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStarHalf",function(){return BIconStarHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStickies",function(){return BIconStickies;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStickiesFill",function(){return BIconStickiesFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSticky",function(){return BIconSticky;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStickyFill",function(){return BIconStickyFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStop",function(){return BIconStop;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStopBtn",function(){return BIconStopBtn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStopBtnFill",function(){return BIconStopBtnFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStopCircle",function(){return BIconStopCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStopCircleFill",function(){return BIconStopCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStopFill",function(){return BIconStopFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStoplights",function(){return BIconStoplights;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStoplightsFill",function(){return BIconStoplightsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStopwatch",function(){return BIconStopwatch;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconStopwatchFill",function(){return BIconStopwatchFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSubtract",function(){return BIconSubtract;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitClub",function(){return BIconSuitClub;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitClubFill",function(){return BIconSuitClubFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitDiamond",function(){return BIconSuitDiamond;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitDiamondFill",function(){return BIconSuitDiamondFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitHeart",function(){return BIconSuitHeart;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitHeartFill",function(){return BIconSuitHeartFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitSpade",function(){return BIconSuitSpade;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSuitSpadeFill",function(){return BIconSuitSpadeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSun",function(){return BIconSun;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconSunglasses",function(){return BIconSunglasses;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTable",function(){return BIconTable;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTablet",function(){return BIconTablet;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTabletFill",function(){return BIconTabletFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTabletLandscape",function(){return BIconTabletLandscape;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTabletLandscapeFill",function(){return BIconTabletLandscapeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTag",function(){return BIconTag;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTagFill",function(){return BIconTagFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTags",function(){return BIconTags;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTagsFill",function(){return BIconTagsFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephone",function(){return BIconTelephone;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneFill",function(){return BIconTelephoneFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneForward",function(){return BIconTelephoneForward;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneForwardFill",function(){return BIconTelephoneForwardFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneInbound",function(){return BIconTelephoneInbound;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneInboundFill",function(){return BIconTelephoneInboundFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneMinus",function(){return BIconTelephoneMinus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneMinusFill",function(){return BIconTelephoneMinusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneOutbound",function(){return BIconTelephoneOutbound;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneOutboundFill",function(){return BIconTelephoneOutboundFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephonePlus",function(){return BIconTelephonePlus;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephonePlusFill",function(){return BIconTelephonePlusFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneX",function(){return BIconTelephoneX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTelephoneXFill",function(){return BIconTelephoneXFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTerminal",function(){return BIconTerminal;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTerminalFill",function(){return BIconTerminalFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextCenter",function(){return BIconTextCenter;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextIndentLeft",function(){return BIconTextIndentLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextIndentRight",function(){return BIconTextIndentRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextLeft",function(){return BIconTextLeft;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextParagraph",function(){return BIconTextParagraph;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextRight",function(){return BIconTextRight;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextarea",function(){return BIconTextarea;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextareaResize",function(){return BIconTextareaResize;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTextareaT",function(){return BIconTextareaT;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconThermometer",function(){return BIconThermometer;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconThermometerHalf",function(){return BIconThermometerHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconThreeDots",function(){return BIconThreeDots;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconThreeDotsVertical",function(){return BIconThreeDotsVertical;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconToggle2Off",function(){return BIconToggle2Off;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconToggle2On",function(){return BIconToggle2On;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconToggleOff",function(){return BIconToggleOff;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconToggleOn",function(){return BIconToggleOn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconToggles",function(){return BIconToggles;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconToggles2",function(){return BIconToggles2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTools",function(){return BIconTools;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTrash",function(){return BIconTrash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTrash2",function(){return BIconTrash2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTrash2Fill",function(){return BIconTrash2Fill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTrashFill",function(){return BIconTrashFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTree",function(){return BIconTree;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTreeFill",function(){return BIconTreeFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTriangle",function(){return BIconTriangle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTriangleFill",function(){return BIconTriangleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTriangleHalf",function(){return BIconTriangleHalf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTrophy",function(){return BIconTrophy;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTrophyFill",function(){return BIconTrophyFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTruck",function(){return BIconTruck;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTruckFlatbed",function(){return BIconTruckFlatbed;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTv",function(){return BIconTv;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTvFill",function(){return BIconTvFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTwitch",function(){return BIconTwitch;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTwitter",function(){return BIconTwitter;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconType",function(){return BIconType;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTypeBold",function(){return BIconTypeBold;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTypeH1",function(){return BIconTypeH1;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTypeH2",function(){return BIconTypeH2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTypeH3",function(){return BIconTypeH3;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTypeItalic",function(){return BIconTypeItalic;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTypeStrikethrough",function(){return BIconTypeStrikethrough;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconTypeUnderline",function(){return BIconTypeUnderline;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUiChecks",function(){return BIconUiChecks;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUiChecksGrid",function(){return BIconUiChecksGrid;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUiRadios",function(){return BIconUiRadios;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUiRadiosGrid",function(){return BIconUiRadiosGrid;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUnion",function(){return BIconUnion;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUnlock",function(){return BIconUnlock;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUnlockFill",function(){return BIconUnlockFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUpc",function(){return BIconUpc;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUpcScan",function(){return BIconUpcScan;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconUpload",function(){return BIconUpload;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVectorPen",function(){return BIconVectorPen;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconViewList",function(){return BIconViewList;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconViewStacked",function(){return BIconViewStacked;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVinyl",function(){return BIconVinyl;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVinylFill",function(){return BIconVinylFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVoicemail",function(){return BIconVoicemail;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeDown",function(){return BIconVolumeDown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeDownFill",function(){return BIconVolumeDownFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeMute",function(){return BIconVolumeMute;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeMuteFill",function(){return BIconVolumeMuteFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeOff",function(){return BIconVolumeOff;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeOffFill",function(){return BIconVolumeOffFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeUp",function(){return BIconVolumeUp;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVolumeUpFill",function(){return BIconVolumeUpFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconVr",function(){return BIconVr;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWallet",function(){return BIconWallet;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWallet2",function(){return BIconWallet2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWalletFill",function(){return BIconWalletFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWatch",function(){return BIconWatch;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWifi",function(){return BIconWifi;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWifi1",function(){return BIconWifi1;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWifi2",function(){return BIconWifi2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWifiOff",function(){return BIconWifiOff;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWindow",function(){return BIconWindow;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconWrench",function(){return BIconWrench;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconX",function(){return BIconX;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXCircle",function(){return BIconXCircle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXCircleFill",function(){return BIconXCircleFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXDiamond",function(){return BIconXDiamond;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXDiamondFill",function(){return BIconXDiamondFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXOctagon",function(){return BIconXOctagon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXOctagonFill",function(){return BIconXOctagonFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXSquare",function(){return BIconXSquare;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconXSquareFill",function(){return BIconXSquareFill;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconYoutube",function(){return BIconYoutube;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconZoomIn",function(){return BIconZoomIn;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconZoomOut",function(){return BIconZoomOut;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BIconstack",function(){return BIconstack;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BImg",function(){return BImg;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BImgLazy",function(){return BImgLazy;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BInputGroup",function(){return BInputGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BInputGroupAddon",function(){return BInputGroupAddon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BInputGroupAppend",function(){return BInputGroupAppend;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BInputGroupPrepend",function(){return BInputGroupPrepend;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BInputGroupText",function(){return BInputGroupText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BJumbotron",function(){return BJumbotron;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BLink",function(){return BLink;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BListGroup",function(){return BListGroup;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BListGroupItem",function(){return BListGroupItem;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BMedia",function(){return BMedia;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BMediaAside",function(){return BMediaAside;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BMediaBody",function(){return BMediaBody;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BModal",function(){return BModal;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNav",function(){return BNav;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavForm",function(){return BNavForm;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavItem",function(){return BNavItem;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavItemDropdown",function(){return BNavItemDropdown;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavText",function(){return BNavText;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavbar",function(){return BNavbar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavbarBrand",function(){return BNavbarBrand;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavbarNav",function(){return BNavbarNav;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BNavbarToggle",function(){return BNavbarToggle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BOverlay",function(){return BOverlay;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BPagination",function(){return BPagination;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BPaginationNav",function(){return BPaginationNav;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BPopover",function(){return BPopover;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BProgress",function(){return BProgress;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BProgressBar",function(){return BProgressBar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BRow",function(){return BRow;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BSidebar",function(){return BSidebar;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BSkeleton",function(){return BSkeleton;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BSkeletonIcon",function(){return BSkeletonIcon;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BSkeletonImg",function(){return BSkeletonImg;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BSkeletonTable",function(){return BSkeletonTable;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BSkeletonWrapper",function(){return BSkeletonWrapper;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BSpinner",function(){return BSpinner;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTab",function(){return BTab;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTable",function(){return BTable;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTableLite",function(){return BTableLite;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTableSimple",function(){return BTableSimple;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTabs",function(){return BTabs;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTbody",function(){return BTbody;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTd",function(){return BTd;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTfoot",function(){return BTfoot;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTh",function(){return BTh;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BThead",function(){return BThead;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTime",function(){return BTime;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BToast",function(){return BToast;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BToaster",function(){return BToaster;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTooltip",function(){return BTooltip;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BTr",function(){return BTr;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BVConfig",function(){return BVConfigPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BVConfigPlugin",function(){return BVConfigPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BVModalPlugin",function(){return BVModalPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BVToastPlugin",function(){return BVToastPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BadgePlugin",function(){return BadgePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BootstrapVue",function(){return BootstrapVue;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BootstrapVueIcons",function(){return BootstrapVueIcons;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"BreadcrumbPlugin",function(){return BreadcrumbPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ButtonGroupPlugin",function(){return ButtonGroupPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ButtonPlugin",function(){return ButtonPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ButtonToolbarPlugin",function(){return ButtonToolbarPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"CalendarPlugin",function(){return CalendarPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"CardPlugin",function(){return CardPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"CarouselPlugin",function(){return CarouselPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"CollapsePlugin",function(){return CollapsePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"DropdownPlugin",function(){return DropdownPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"EmbedPlugin",function(){return EmbedPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormCheckboxPlugin",function(){return FormCheckboxPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormDatepickerPlugin",function(){return FormDatepickerPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormFilePlugin",function(){return FormFilePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormGroupPlugin",function(){return FormGroupPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormInputPlugin",function(){return FormInputPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormPlugin",function(){return FormPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormRadioPlugin",function(){return FormRadioPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormRatingPlugin",function(){return FormRatingPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormSelectPlugin",function(){return FormSelectPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormSpinbuttonPlugin",function(){return FormSpinbuttonPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormTagsPlugin",function(){return FormTagsPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormTextareaPlugin",function(){return FormTextareaPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"FormTimepickerPlugin",function(){return FormTimepickerPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"IconsPlugin",function(){return IconsPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ImagePlugin",function(){return ImagePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"InputGroupPlugin",function(){return InputGroupPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"JumbotronPlugin",function(){return JumbotronPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"LayoutPlugin",function(){return LayoutPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"LinkPlugin",function(){return LinkPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ListGroupPlugin",function(){return ListGroupPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"MediaPlugin",function(){return MediaPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ModalPlugin",function(){return ModalPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"NAME",function(){return NAME$2;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"NavPlugin",function(){return NavPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"NavbarPlugin",function(){return NavbarPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"OverlayPlugin",function(){return OverlayPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"PaginationNavPlugin",function(){return PaginationNavPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"PaginationPlugin",function(){return PaginationPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"PopoverPlugin",function(){return PopoverPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ProgressPlugin",function(){return ProgressPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"SidebarPlugin",function(){return SidebarPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"SkeletonPlugin",function(){return SkeletonPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"SpinnerPlugin",function(){return SpinnerPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"TableLitePlugin",function(){return TableLitePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"TablePlugin",function(){return TablePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"TableSimplePlugin",function(){return TableSimplePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"TabsPlugin",function(){return TabsPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"TimePlugin",function(){return TimePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ToastPlugin",function(){return ToastPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"TooltipPlugin",function(){return TooltipPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBHover",function(){return VBHover;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBHoverPlugin",function(){return VBHoverPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBModal",function(){return VBModal;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBModalPlugin",function(){return VBModalPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBPopover",function(){return VBPopover;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBPopoverPlugin",function(){return VBPopoverPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBScrollspy",function(){return VBScrollspy;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBScrollspyPlugin",function(){return VBScrollspyPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBToggle",function(){return VBToggle;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBTogglePlugin",function(){return VBTogglePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBTooltip",function(){return VBTooltip;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBTooltipPlugin",function(){return VBTooltipPlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBVisible",function(){return VBVisible;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VBVisiblePlugin",function(){return VBVisiblePlugin;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"install",function(){return install;});
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue-functional-data-merge */"./node_modules/vue-functional-data-merge/dist/lib.esm.js");
/* harmony import */var popper_js__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! popper.js */"./node_modules/popper.js/dist/esm/popper.js");
/* harmony import */var portal_vue__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(/*! portal-vue */"./node_modules/portal-vue/dist/portal-vue.common.js");
/*!
 * BootstrapVue 2.21.2
 *
 * @link https://bootstrap-vue.org
 * @source https://github.com/bootstrap-vue/bootstrap-vue
 * @copyright (c) 2016-2021 BootstrapVue
 * @license MIT
 * https://github.com/bootstrap-vue/bootstrap-vue/blob/master/LICENSE
 */






function _typeof(obj){
"@babel/helpers - typeof";

if(typeof Symbol==="function"&&typeof Symbol.iterator==="symbol"){
_typeof=function _typeof(obj){
return typeof obj;
};
}else {
_typeof=function _typeof(obj){
return obj&&typeof Symbol==="function"&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj;
};
}

return _typeof(obj);
}

function _classCallCheck(instance,Constructor){
if(!(instance instanceof Constructor)){
throw new TypeError("Cannot call a class as a function");
}
}

function _defineProperties(target,props){
for(var i=0;i<props.length;i++){
var descriptor=props[i];
descriptor.enumerable=descriptor.enumerable||false;
descriptor.configurable=true;
if("value"in descriptor)descriptor.writable=true;
Object.defineProperty(target,descriptor.key,descriptor);
}
}

function _createClass(Constructor,protoProps,staticProps){
if(protoProps)_defineProperties(Constructor.prototype,protoProps);
if(staticProps)_defineProperties(Constructor,staticProps);
return Constructor;
}

function _defineProperty(obj,key,value){
if(key in obj){
Object.defineProperty(obj,key,{
value:value,
enumerable:true,
configurable:true,
writable:true});

}else {
obj[key]=value;
}

return obj;
}

function ownKeys(object,enumerableOnly){
var keys=Object.keys(object);

if(Object.getOwnPropertySymbols){
var symbols=Object.getOwnPropertySymbols(object);
if(enumerableOnly)symbols=symbols.filter(function(sym){
return Object.getOwnPropertyDescriptor(object,sym).enumerable;
});
keys.push.apply(keys,symbols);
}

return keys;
}

function _objectSpread2(target){
for(var i=1;i<arguments.length;i++){
var source=arguments[i]!=null?arguments[i]:{};

if(i%2){
ownKeys(Object(source),true).forEach(function(key){
_defineProperty(target,key,source[key]);
});
}else if(Object.getOwnPropertyDescriptors){
Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));
}else {
ownKeys(Object(source)).forEach(function(key){
Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));
});
}
}

return target;
}

function _inherits(subClass,superClass){
if(typeof superClass!=="function"&&superClass!==null){
throw new TypeError("Super expression must either be null or a function");
}

subClass.prototype=Object.create(superClass&&superClass.prototype,{
constructor:{
value:subClass,
writable:true,
configurable:true}});


if(superClass)_setPrototypeOf(subClass,superClass);
}

function _getPrototypeOf(o){
_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function _getPrototypeOf(o){
return o.__proto__||Object.getPrototypeOf(o);
};
return _getPrototypeOf(o);
}

function _setPrototypeOf(o,p){
_setPrototypeOf=Object.setPrototypeOf||function _setPrototypeOf(o,p){
o.__proto__=p;
return o;
};

return _setPrototypeOf(o,p);
}

function _isNativeReflectConstruct(){
if(typeof Reflect==="undefined"||!Reflect.construct)return false;
if(Reflect.construct.sham)return false;
if(typeof Proxy==="function")return true;

try{
Date.prototype.toString.call(Reflect.construct(Date,[],function(){}));
return true;
}catch(e){
return false;
}
}

function _construct(Parent,args,Class){
if(_isNativeReflectConstruct()){
_construct=Reflect.construct;
}else {
_construct=function _construct(Parent,args,Class){
var a=[null];
a.push.apply(a,args);
var Constructor=Function.bind.apply(Parent,a);
var instance=new Constructor();
if(Class)_setPrototypeOf(instance,Class.prototype);
return instance;
};
}

return _construct.apply(null,arguments);
}

function _isNativeFunction(fn){
return Function.toString.call(fn).indexOf("[native code]")!==-1;
}

function _wrapNativeSuper(Class){
var _cache=typeof Map==="function"?new Map():undefined;

_wrapNativeSuper=function _wrapNativeSuper(Class){
if(Class===null||!_isNativeFunction(Class))return Class;

if(typeof Class!=="function"){
throw new TypeError("Super expression must either be null or a function");
}

if(typeof _cache!=="undefined"){
if(_cache.has(Class))return _cache.get(Class);

_cache.set(Class,Wrapper);
}

function Wrapper(){
return _construct(Class,arguments,_getPrototypeOf(this).constructor);
}

Wrapper.prototype=Object.create(Class.prototype,{
constructor:{
value:Wrapper,
enumerable:false,
writable:true,
configurable:true}});


return _setPrototypeOf(Wrapper,Class);
};

return _wrapNativeSuper(Class);
}

function _assertThisInitialized(self){
if(self===void 0){
throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
}

return self;
}

function _possibleConstructorReturn(self,call){
if(call&&(typeof call==="object"||typeof call==="function")){
return call;
}

return _assertThisInitialized(self);
}

function _createSuper(Derived){
var hasNativeReflectConstruct=_isNativeReflectConstruct();

return function _createSuperInternal(){
var Super=_getPrototypeOf(Derived),
result;

if(hasNativeReflectConstruct){
var NewTarget=_getPrototypeOf(this).constructor;

result=Reflect.construct(Super,arguments,NewTarget);
}else {
result=Super.apply(this,arguments);
}

return _possibleConstructorReturn(this,result);
};
}

function _superPropBase(object,property){
while(!Object.prototype.hasOwnProperty.call(object,property)){
object=_getPrototypeOf(object);
if(object===null)break;
}

return object;
}

function _get(target,property,receiver){
if(typeof Reflect!=="undefined"&&Reflect.get){
_get=Reflect.get;
}else {
_get=function _get(target,property,receiver){
var base=_superPropBase(target,property);

if(!base)return;
var desc=Object.getOwnPropertyDescriptor(base,property);

if(desc.get){
return desc.get.call(receiver);
}

return desc.value;
};
}

return _get(target,property,receiver||target);
}

function _slicedToArray(arr,i){
return _arrayWithHoles(arr)||_iterableToArrayLimit(arr,i)||_unsupportedIterableToArray(arr,i)||_nonIterableRest();
}

function _toConsumableArray(arr){
return _arrayWithoutHoles(arr)||_iterableToArray(arr)||_unsupportedIterableToArray(arr)||_nonIterableSpread();
}

function _arrayWithoutHoles(arr){
if(Array.isArray(arr))return _arrayLikeToArray(arr);
}

function _arrayWithHoles(arr){
if(Array.isArray(arr))return arr;
}

function _iterableToArray(iter){
if(typeof Symbol!=="undefined"&&Symbol.iterator in Object(iter))return Array.from(iter);
}

function _iterableToArrayLimit(arr,i){
if(typeof Symbol==="undefined"||!(Symbol.iterator in Object(arr)))return;
var _arr=[];
var _n=true;
var _d=false;
var _e=undefined;

try{
for(var _i=arr[Symbol.iterator](),_s;!(_n=(_s=_i.next()).done);_n=true){
_arr.push(_s.value);

if(i&&_arr.length===i)break;
}
}catch(err){
_d=true;
_e=err;
}finally{
try{
if(!_n&&_i["return"]!=null)_i["return"]();
}finally{
if(_d)throw _e;
}
}

return _arr;
}

function _unsupportedIterableToArray(o,minLen){
if(!o)return;
if(typeof o==="string")return _arrayLikeToArray(o,minLen);
var n=Object.prototype.toString.call(o).slice(8,-1);
if(n==="Object"&&o.constructor)n=o.constructor.name;
if(n==="Map"||n==="Set")return Array.from(o);
if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return _arrayLikeToArray(o,minLen);
}

function _arrayLikeToArray(arr,len){
if(len==null||len>arr.length)len=arr.length;

for(var i=0,arr2=new Array(len);i<len;i++){arr2[i]=arr[i];}

return arr2;
}

function _nonIterableSpread(){
throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _nonIterableRest(){
throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var COMPONENT_UID_KEY='_uid';

var HAS_WINDOW_SUPPORT=typeof window!=='undefined';
var HAS_DOCUMENT_SUPPORT=typeof document!=='undefined';
var HAS_NAVIGATOR_SUPPORT=typeof navigator!=='undefined';
var HAS_PROMISE_SUPPORT=typeof Promise!=='undefined';
/* istanbul ignore next: JSDOM always returns false */

var HAS_MUTATION_OBSERVER_SUPPORT=typeof MutationObserver!=='undefined'||typeof WebKitMutationObserver!=='undefined'||typeof MozMutationObserver!=='undefined';
var IS_BROWSER=HAS_WINDOW_SUPPORT&&HAS_DOCUMENT_SUPPORT&&HAS_NAVIGATOR_SUPPORT;
var WINDOW=HAS_WINDOW_SUPPORT?window:{};
var DOCUMENT=HAS_DOCUMENT_SUPPORT?document:{};
var NAVIGATOR=HAS_NAVIGATOR_SUPPORT?navigator:{};
var USER_AGENT=(NAVIGATOR.userAgent||'').toLowerCase();
var IS_JSDOM=USER_AGENT.indexOf('jsdom')>0;
var IS_IE=/msie|trident/.test(USER_AGENT);// Determine if the browser supports the option passive for events

var HAS_PASSIVE_EVENT_SUPPORT=function(){
var passiveEventSupported=false;

if(IS_BROWSER){
try{
var options={
// This function will be called when the browser
// attempts to access the passive property
get passive(){
/* istanbul ignore next: will never be called in JSDOM */
passiveEventSupported=true;
}};


WINDOW.addEventListener('test',options,options);
WINDOW.removeEventListener('test',options,options);
}catch(_unused){
/* istanbul ignore next: will never be called in JSDOM */
passiveEventSupported=false;
}
}

return passiveEventSupported;
}();
var HAS_TOUCH_SUPPORT=IS_BROWSER&&('ontouchstart'in DOCUMENT.documentElement||NAVIGATOR.maxTouchPoints>0);
var HAS_POINTER_EVENT_SUPPORT=IS_BROWSER&&Boolean(WINDOW.PointerEvent||WINDOW.MSPointerEvent);
/* istanbul ignore next: JSDOM only checks for 'IntersectionObserver' */

var HAS_INTERACTION_OBSERVER_SUPPORT=IS_BROWSER&&'IntersectionObserver'in WINDOW&&'IntersectionObserverEntry'in WINDOW&&// Edge 15 and UC Browser lack support for `isIntersecting`
// but we an use `intersectionRatio > 0` instead
// 'isIntersecting' in window.IntersectionObserverEntry.prototype &&
'intersectionRatio'in WINDOW.IntersectionObserverEntry.prototype;

var NAME='BvConfig';
var PROP_NAME='$bvConfig';
var DEFAULT_BREAKPOINT=['xs','sm','md','lg','xl'];

// --- General ---
var RX_ARRAY_NOTATION=/\[(\d+)]/g;
var RX_BV_PREFIX=/^(BV?)/;
var RX_DIGITS=/^\d+$/;
var RX_EXTENSION=/^\..+/;
var RX_HASH=/^#/;
var RX_HASH_ID=/^#[A-Za-z]+[\w\-:.]*$/;
var RX_HTML_TAGS=/(<([^>]+)>)/gi;
var RX_HYPHENATE=/\B([A-Z])/g;
var RX_LOWER_UPPER=/([a-z])([A-Z])/g;
var RX_NUMBER=/^[0-9]*\.?[0-9]+$/;
var RX_PLUS=/\+/g;
var RX_REGEXP_REPLACE=/[-/\\^$*+?.()|[\]{}]/g;
var RX_SPACES=/[\s\uFEFF\xA0]+/g;
var RX_SPACE_SPLIT=/\s+/;
var RX_STAR=/\/\*$/;
var RX_START_SPACE_WORD=/(\s|^)(\w)/g;
var RX_TRIM_LEFT=/^\s+/;
var RX_UNDERSCORE=/_/g;
var RX_UN_KEBAB=/-(\w)/g;// --- Date ---
// Loose YYYY-MM-DD matching, ignores any appended time inforation
// Matches '1999-12-20', '1999-1-1', '1999-01-20T22:51:49.118Z', '1999-01-02 13:00:00'

var RX_DATE=/^\d+-\d\d?-\d\d?(?:\s|T|$)/;// Used to split off the date parts of the YYYY-MM-DD string

var RX_DATE_SPLIT=/-|\s|T/;// Time string RegEx (optional seconds)

var RX_TIME=/^([0-1]?[0-9]|2[0-3]):[0-5]?[0-9](:[0-5]?[0-9])?$/;// --- URL ---
// HREFs must end with a hash followed by at least one non-hash character

var RX_HREF=/^.*(#[^#]+)$/;
var RX_ENCODED_COMMA=/%2C/g;
var RX_ENCODE_REVERSE=/[!'()*]/g;
var RX_QUERY_START=/^(\?|#|&)/;// --- Aspect ---

var RX_ASPECT=/^\d+(\.\d*)?[/:]\d+(\.\d*)?$/;
var RX_ASPECT_SEPARATOR=/[/:]/;// --- Grid ---

var RX_COL_CLASS=/^col-/;// --- Icon ---

var RX_ICON_PREFIX=/^BIcon/;// --- Locale ---

var RX_STRIP_LOCALE_MODS=/-u-.+/;

/* istanbul ignore next */

var Element=HAS_WINDOW_SUPPORT?WINDOW.Element:/*#__PURE__*/function(_Object){
_inherits(Element,_Object);

var _super=_createSuper(Element);

function Element(){
_classCallCheck(this,Element);

return _super.apply(this,arguments);
}

return Element;
}(/*#__PURE__*/_wrapNativeSuper(Object));
/* istanbul ignore next */

var HTMLElement=HAS_WINDOW_SUPPORT?WINDOW.HTMLElement:/*#__PURE__*/function(_Element){
_inherits(HTMLElement,_Element);

var _super2=_createSuper(HTMLElement);

function HTMLElement(){
_classCallCheck(this,HTMLElement);

return _super2.apply(this,arguments);
}

return HTMLElement;
}(Element);
/* istanbul ignore next */

var SVGElement=HAS_WINDOW_SUPPORT?WINDOW.SVGElement:/*#__PURE__*/function(_Element2){
_inherits(SVGElement,_Element2);

var _super3=_createSuper(SVGElement);

function SVGElement(){
_classCallCheck(this,SVGElement);

return _super3.apply(this,arguments);
}

return SVGElement;
}(Element);
/* istanbul ignore next */

var File=HAS_WINDOW_SUPPORT?WINDOW.File:/*#__PURE__*/function(_Object2){
_inherits(File,_Object2);

var _super4=_createSuper(File);

function File(){
_classCallCheck(this,File);

return _super4.apply(this,arguments);
}

return File;
}(/*#__PURE__*/_wrapNativeSuper(Object));

var toType=function toType(value){
return _typeof(value);
};
var toRawType=function toRawType(value){
return Object.prototype.toString.call(value).slice(8,-1);
};
var isUndefined=function isUndefined(value){
return value===undefined;
};
var isNull=function isNull(value){
return value===null;
};
var isUndefinedOrNull=function isUndefinedOrNull(value){
return isUndefined(value)||isNull(value);
};
var isFunction=function isFunction(value){
return toType(value)==='function';
};
var isBoolean=function isBoolean(value){
return toType(value)==='boolean';
};
var isString=function isString(value){
return toType(value)==='string';
};
var isNumber=function isNumber(value){
return toType(value)==='number';
};
var isNumeric=function isNumeric(value){
return RX_NUMBER.test(String(value));
};
var isArray=function isArray(value){
return Array.isArray(value);
};// Quick object check
// This is primarily used to tell Objects from primitive values
// when we know the value is a JSON-compliant type
// Note object could be a complex type like array, Date, etc.

var isObject=function isObject(obj){
return obj!==null&&_typeof(obj)==='object';
};// Strict object type check
// Only returns true for plain JavaScript objects

var isPlainObject=function isPlainObject(obj){
return Object.prototype.toString.call(obj)==='[object Object]';
};
var isDate=function isDate(value){
return value instanceof Date;
};
var isEvent=function isEvent(value){
return value instanceof Event;
};
var isFile=function isFile(value){
return value instanceof File;
};
var isRegExp=function isRegExp(value){
return toRawType(value)==='RegExp';
};
var isPromise=function isPromise(value){
return !isUndefinedOrNull(value)&&isFunction(value.then)&&isFunction(value.catch);
};

var assign=function assign(){
return Object.assign.apply(Object,arguments);
};
var create=function create(proto,optionalProps){
return Object.create(proto,optionalProps);
};
var defineProperties=function defineProperties(obj,props){
return Object.defineProperties(obj,props);
};
var defineProperty=function defineProperty(obj,prop,descriptor){
return Object.defineProperty(obj,prop,descriptor);
};
var getOwnPropertyNames=function getOwnPropertyNames(obj){
return Object.getOwnPropertyNames(obj);
};
var keys=function keys(obj){
return Object.keys(obj);
};// --- "Instance" ---

var hasOwnProperty=function hasOwnProperty(obj,prop){
return Object.prototype.hasOwnProperty.call(obj,prop);
};
var toString=function toString(obj){
return Object.prototype.toString.call(obj);
};// --- Utilities ---
// Shallow copy an object

var clone=function clone(obj){
return _objectSpread2({},obj);
};// Return a shallow copy of object with the specified properties only
// See: https://gist.github.com/bisubus/2da8af7e801ffd813fab7ac221aa7afc

var pick=function pick(obj,props){
return keys(obj).filter(function(key){
return props.indexOf(key)!==-1;
}).reduce(function(result,key){
return _objectSpread2(_objectSpread2({},result),{},_defineProperty({},key,obj[key]));
},{});
};// Return a shallow copy of object with the specified properties omitted
// See: https://gist.github.com/bisubus/2da8af7e801ffd813fab7ac221aa7afc

var omit=function omit(obj,props){
return keys(obj).filter(function(key){
return props.indexOf(key)===-1;
}).reduce(function(result,key){
return _objectSpread2(_objectSpread2({},result),{},_defineProperty({},key,obj[key]));
},{});
};// Merges two object deeply together
// See: https://gist.github.com/Salakar/1d7137de9cb8b704e48a

var mergeDeep=function mergeDeep(target,source){
if(isObject(target)&&isObject(source)){
keys(source).forEach(function(key){
if(isObject(source[key])){
if(!target[key]||!isObject(target[key])){
target[key]=source[key];
}

mergeDeep(target[key],source[key]);
}else {
assign(target,_defineProperty({},key,source[key]));
}
});
}

return target;
};// Returns a shallow copy of the object with keys in sorted order

var sortKeys=function sortKeys(obj){
return keys(obj).sort().reduce(function(result,key){
return _objectSpread2(_objectSpread2({},result),{},_defineProperty({},key,obj[key]));
},{});
};// Convenience method to create a read-only descriptor

var readonlyDescriptor=function readonlyDescriptor(){
return {
enumerable:true,
configurable:false,
writable:false};

};

var cloneDeep=function cloneDeep(obj){
var defaultValue=arguments.length>1&&arguments[1]!==undefined?arguments[1]:obj;

if(isArray(obj)){
return obj.reduce(function(result,val){
return [].concat(_toConsumableArray(result),[cloneDeep(val,val)]);
},[]);
}

if(isPlainObject(obj)){
return keys(obj).reduce(function(result,key){
return _objectSpread2(_objectSpread2({},result),{},_defineProperty({},key,cloneDeep(obj[key],obj[key])));
},{});
}

return defaultValue;
};

var identity=function identity(x){
return x;
};

/**
 * Get property defined by dot/array notation in string, returns undefined if not found
 *
 * @link https://gist.github.com/jeneg/9767afdcca45601ea44930ea03e0febf#gistcomment-1935901
 *
 * @param {Object} obj
 * @param {string|Array} path
 * @return {*}
 */

var getRaw=function getRaw(obj,path){
var defaultValue=arguments.length>2&&arguments[2]!==undefined?arguments[2]:undefined;
// Handle array of path values
path=isArray(path)?path.join('.'):path;// If no path or no object passed

if(!path||!isObject(obj)){
return defaultValue;
}// Handle edge case where user has dot(s) in top-level item field key
// See https://github.com/bootstrap-vue/bootstrap-vue/issues/2762
// Switched to `in` operator vs `hasOwnProperty` to handle obj.prototype getters
// https://github.com/bootstrap-vue/bootstrap-vue/issues/3463


if(path in obj){
return obj[path];
}// Handle string array notation (numeric indices only)


path=String(path).replace(RX_ARRAY_NOTATION,'.$1');
var steps=path.split('.').filter(identity);// Handle case where someone passes a string of only dots

if(steps.length===0){
return defaultValue;
}// Traverse path in object to find result
// Switched to `in` operator vs `hasOwnProperty` to handle obj.prototype getters
// https://github.com/bootstrap-vue/bootstrap-vue/issues/3463


return steps.every(function(step){
return isObject(obj)&&step in obj&&!isUndefinedOrNull(obj=obj[step]);
})?obj:isNull(obj)?null:defaultValue;
};
/**
 * Get property defined by dot/array notation in string.
 *
 * @link https://gist.github.com/jeneg/9767afdcca45601ea44930ea03e0febf#gistcomment-1935901
 *
 * @param {Object} obj
 * @param {string|Array} path
 * @param {*} defaultValue (optional)
 * @return {*}
 */

var get=function get(obj,path){
var defaultValue=arguments.length>2&&arguments[2]!==undefined?arguments[2]:null;
var value=getRaw(obj,path);
return isUndefinedOrNull(value)?defaultValue:value;
};

/**
 * Utilities to get information about the current environment
 */
var getEnv=function getEnv(key){
var fallback=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;
var env=typeof process!=='undefined'&&process?process.env||{}:{};

if(!key){
/* istanbul ignore next */
return env;
}

return env[key]||fallback;
};
var getNoWarn=function getNoWarn(){
return getEnv('BOOTSTRAP_VUE_NO_WARN')||getEnv('NODE_ENV')==='production';
};

/**
 * Log a warning message to the console with BootstrapVue formatting
 * @param {string} message
 */

var warn=function warn(message)
/* istanbul ignore next */
{
var source=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;

if(!getNoWarn()){
console.warn("[BootstrapVue warn]: ".concat(source?"".concat(source," - "):'').concat(message));
}
};
/**
 * Warn when no Promise support is given
 * @param {string} source
 * @returns {boolean} warned
 */

var warnNotClient=function warnNotClient(source){
/* istanbul ignore else */
if(IS_BROWSER){
return false;
}else {
warn("".concat(source,": Can not be called during SSR."));
return true;
}
};
/**
 * Warn when no Promise support is given
 * @param {string} source
 * @returns {boolean} warned
 */

var warnNoPromiseSupport=function warnNoPromiseSupport(source){
/* istanbul ignore else */
if(HAS_PROMISE_SUPPORT){
return false;
}else {
warn("".concat(source,": Requires Promise support."));
return true;
}
};
/**
 * Warn when no MutationObserver support is given
 * @param {string} source
 * @returns {boolean} warned
 */

var warnNoMutationObserverSupport=function warnNoMutationObserverSupport(source){
/* istanbul ignore else */
if(HAS_MUTATION_OBSERVER_SUPPORT){
return false;
}else {
warn("".concat(source,": Requires MutationObserver support."));
return true;
}
};

var BvConfig=/*#__PURE__*/function(){
function BvConfig(){
_classCallCheck(this,BvConfig);

this.$_config={};
}// Method to merge in user config parameters


_createClass(BvConfig,[{
key:"setConfig",
value:function setConfig(){
var _this=this;

var config=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{};

/* istanbul ignore next */
if(!isPlainObject(config)){
return;
}

var configKeys=getOwnPropertyNames(config);
configKeys.forEach(function(key){
/* istanbul ignore next */
var subConfig=config[key];

if(key==='breakpoints'){
/* istanbul ignore if */
if(!isArray(subConfig)||subConfig.length<2||subConfig.some(function(b){
return !isString(b)||b.length===0;
})){
warn('"breakpoints" must be an array of at least 2 breakpoint names',NAME);
}else {
_this.$_config[key]=cloneDeep(subConfig);
}
}else if(isPlainObject(subConfig)){
// Component prop defaults
_this.$_config[key]=getOwnPropertyNames(subConfig).reduce(function(config,prop){
if(!isUndefined(subConfig[prop])){
config[prop]=cloneDeep(subConfig[prop]);
}

return config;
},_this.$_config[key]||{});
}
});
}// Clear the config
},
{
key:"resetConfig",
value:function resetConfig(){
this.$_config={};
}// Returns a deep copy of the user config
},
{
key:"getConfig",
value:function getConfig(){
return cloneDeep(this.$_config);
}// Returns a deep copy of the config value
},
{
key:"getConfigValue",
value:function getConfigValue(key){
var defaultValue=arguments.length>1&&arguments[1]!==undefined?arguments[1]:undefined;
return cloneDeep(getRaw(this.$_config,key,defaultValue));
}}]);


return BvConfig;
}();// Method for applying a global config


var setConfig=function setConfig(){
var config=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{};
var Vue$1=arguments.length>1&&arguments[1]!==undefined?arguments[1]:vue__WEBPACK_IMPORTED_MODULE_0___default.a;
// Ensure we have a `$bvConfig` Object on the Vue prototype
// We set on Vue and OurVue just in case consumer has not set an alias of `vue`
Vue$1.prototype[PROP_NAME]=vue__WEBPACK_IMPORTED_MODULE_0___default.a.prototype[PROP_NAME]=Vue$1.prototype[PROP_NAME]||vue__WEBPACK_IMPORTED_MODULE_0___default.a.prototype[PROP_NAME]||new BvConfig();// Apply the config values

Vue$1.prototype[PROP_NAME].setConfig(config);
};// Method for resetting the user config

/**
 * Checks if there are multiple instances of Vue, and warns (once) about possible issues.
 * @param {object} Vue
 */

var checkMultipleVue=function(){
var checkMultipleVueWarned=false;
var MULTIPLE_VUE_WARNING=['Multiple instances of Vue detected!','You may need to set up an alias for Vue in your bundler config.','See: https://bootstrap-vue.org/docs#using-module-bundlers'].join('\n');
return function(Vue$1){
/* istanbul ignore next */
if(!checkMultipleVueWarned&&vue__WEBPACK_IMPORTED_MODULE_0___default.a!==Vue$1&&!IS_JSDOM){
warn(MULTIPLE_VUE_WARNING);
}

checkMultipleVueWarned=true;
};
}();
/**
 * Plugin install factory function.
 * @param {object} { components, directives }
 * @returns {function} plugin install function
 */

var installFactory=function installFactory(){
var _ref=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{},
components=_ref.components,
directives=_ref.directives,
plugins=_ref.plugins;

var install=function install(Vue){
var config=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

if(install.installed){
/* istanbul ignore next */
return;
}

install.installed=true;
checkMultipleVue(Vue);
setConfig(config,Vue);
registerComponents(Vue,components);
registerDirectives(Vue,directives);
registerPlugins(Vue,plugins);
};

install.installed=false;
return install;
};
/**
 * Plugin install factory function (no plugin config option).
 * @param {object} { components, directives }
 * @returns {function} plugin install function
 */

var installFactoryNoConfig=function installFactoryNoConfig(){
var _ref2=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{},
components=_ref2.components,
directives=_ref2.directives,
plugins=_ref2.plugins;

var install=function install(Vue){
if(install.installed){
/* istanbul ignore next */
return;
}

install.installed=true;
checkMultipleVue(Vue);
registerComponents(Vue,components);
registerDirectives(Vue,directives);
registerPlugins(Vue,plugins);
};

install.installed=false;
return install;
};
/**
 * Plugin object factory function.
 * @param {object} { components, directives, plugins }
 * @returns {object} plugin install object
 */

var pluginFactory=function pluginFactory(){
var options=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{};
var extend=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
return _objectSpread2(_objectSpread2({},extend),{},{
install:installFactory(options)});

};
/**
 * Plugin object factory function (no config option).
 * @param {object} { components, directives, plugins }
 * @returns {object} plugin install object
 */

var pluginFactoryNoConfig=function pluginFactoryNoConfig(){
var options=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{};
var extend=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
return _objectSpread2(_objectSpread2({},extend),{},{
install:installFactoryNoConfig(options)});

};
/**
 * Load a group of plugins.
 * @param {object} Vue
 * @param {object} Plugin definitions
 */

var registerPlugins=function registerPlugins(Vue){
var plugins=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

for(var plugin in plugins){
if(plugin&&plugins[plugin]){
Vue.use(plugins[plugin]);
}
}
};
/**
 * Load a component.
 * @param {object} Vue
 * @param {string} Component name
 * @param {object} Component definition
 */

var registerComponent=function registerComponent(Vue,name,def){
if(Vue&&name&&def){
Vue.component(name,def);
}
};
/**
 * Load a group of components.
 * @param {object} Vue
 * @param {object} Object of component definitions
 */

var registerComponents=function registerComponents(Vue){
var components=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

for(var component in components){
registerComponent(Vue,component,components[component]);
}
};
/**
 * Load a directive.
 * @param {object} Vue
 * @param {string} Directive name
 * @param {object} Directive definition
 */

var registerDirective=function registerDirective(Vue,name,def){
if(Vue&&name&&def){
// Ensure that any leading V is removed from the
// name, as Vue adds it automatically
Vue.directive(name.replace(/^VB/,'B'),def);
}
};
/**
 * Load a group of directives.
 * @param {object} Vue
 * @param {object} Object of directive definitions
 */

var registerDirectives=function registerDirectives(Vue){
var directives=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

for(var directive in directives){
registerDirective(Vue,directive,directives[directive]);
}
};

// Component names
var NAME_ALERT='BAlert';
var NAME_ASPECT='BAspect';
var NAME_AVATAR='BAvatar';
var NAME_AVATAR_GROUP='BAvatarGroup';
var NAME_BADGE='BBadge';
var NAME_BREADCRUMB='BBreadcrumb';
var NAME_BREADCRUMB_ITEM='BBreadcrumbItem';
var NAME_BREADCRUMB_LINK='BBreadcrumbLink';
var NAME_BUTTON='BButton';
var NAME_BUTTON_CLOSE='BButtonClose';
var NAME_BUTTON_GROUP='BButtonGroup';
var NAME_BUTTON_TOOLBAR='BButtonToolbar';
var NAME_CALENDAR='BCalendar';
var NAME_CARD='BCard';
var NAME_CARD_BODY='BCardBody';
var NAME_CARD_FOOTER='BCardFooter';
var NAME_CARD_GROUP='BCardGroup';
var NAME_CARD_HEADER='BCardHeader';
var NAME_CARD_IMG='BCardImg';
var NAME_CARD_IMG_LAZY='BCardImgLazy';
var NAME_CARD_SUB_TITLE='BCardSubTitle';
var NAME_CARD_TEXT='BCardText';
var NAME_CARD_TITLE='BCardTitle';
var NAME_CAROUSEL='BCarousel';
var NAME_CAROUSEL_SLIDE='BCarouselSlide';
var NAME_COL='BCol';
var NAME_COLLAPSE='BCollapse';
var NAME_CONTAINER='BContainer';
var NAME_DROPDOWN='BDropdown';
var NAME_DROPDOWN_DIVIDER='BDropdownDivider';
var NAME_DROPDOWN_FORM='BDropdownForm';
var NAME_DROPDOWN_GROUP='BDropdownGroup';
var NAME_DROPDOWN_HEADER='BDropdownHeader';
var NAME_DROPDOWN_ITEM='BDropdownItem';
var NAME_DROPDOWN_ITEM_BUTTON='BDropdownItemButton';
var NAME_DROPDOWN_TEXT='BDropdownText';
var NAME_EMBED='BEmbed';
var NAME_FORM='BForm';
var NAME_FORM_CHECKBOX='BFormCheckbox';
var NAME_FORM_CHECKBOX_GROUP='BFormCheckboxGroup';
var NAME_FORM_DATALIST='BFormDatalist';
var NAME_FORM_DATEPICKER='BFormDatepicker';
var NAME_FORM_FILE='BFormFile';
var NAME_FORM_GROUP='BFormGroup';
var NAME_FORM_INPUT='BFormInput';
var NAME_FORM_INVALID_FEEDBACK='BFormInvalidFeedback';
var NAME_FORM_RADIO='BFormRadio';
var NAME_FORM_RADIO_GROUP='BFormRadioGroup';
var NAME_FORM_RATING='BFormRating';
var NAME_FORM_ROW='BFormRow';
var NAME_FORM_SELECT='BFormSelect';
var NAME_FORM_SELECT_OPTION='BFormSelectOption';
var NAME_FORM_SELECT_OPTION_GROUP='BFormSelectOptionGroup';
var NAME_FORM_SPINBUTTON='BFormSpinbutton';
var NAME_FORM_TAG='BFormTag';
var NAME_FORM_TAGS='BFormTags';
var NAME_FORM_TEXT='BFormText';
var NAME_FORM_TEXTAREA='BFormTextarea';
var NAME_FORM_TIMEPICKER='BFormTimepicker';
var NAME_FORM_VALID_FEEDBACK='BFormValidFeedback';
var NAME_ICON='BIcon';
var NAME_ICONSTACK='BIconstack';
var NAME_ICON_BASE='BIconBase';
var NAME_IMG='BImg';
var NAME_IMG_LAZY='BImgLazy';
var NAME_INPUT_GROUP='BInputGroup';
var NAME_INPUT_GROUP_ADDON='BInputGroupAddon';
var NAME_INPUT_GROUP_APPEND='BInputGroupAppend';
var NAME_INPUT_GROUP_PREPEND='BInputGroupPrepend';
var NAME_INPUT_GROUP_TEXT='BInputGroupText';
var NAME_JUMBOTRON='BJumbotron';
var NAME_LINK='BLink';
var NAME_LIST_GROUP='BListGroup';
var NAME_LIST_GROUP_ITEM='BListGroupItem';
var NAME_MEDIA='BMedia';
var NAME_MEDIA_ASIDE='BMediaAside';
var NAME_MEDIA_BODY='BMediaBody';
var NAME_MODAL='BModal';
var NAME_MSG_BOX='BMsgBox';
var NAME_NAV='BNav';
var NAME_NAVBAR='BNavbar';
var NAME_NAVBAR_BRAND='BNavbarBrand';
var NAME_NAVBAR_NAV='BNavbarNav';
var NAME_NAVBAR_TOGGLE='BNavbarToggle';
var NAME_NAV_FORM='BNavForm';
var NAME_NAV_ITEM='BNavItem';
var NAME_NAV_ITEM_DROPDOWN='BNavItemDropdown';
var NAME_NAV_TEXT='BNavText';
var NAME_OVERLAY='BOverlay';
var NAME_PAGINATION='BPagination';
var NAME_PAGINATION_NAV='BPaginationNav';
var NAME_POPOVER='BPopover';
var NAME_PROGRESS='BProgress';
var NAME_PROGRESS_BAR='BProgressBar';
var NAME_ROW='BRow';
var NAME_SIDEBAR='BSidebar';
var NAME_SKELETON='BSkeleton';
var NAME_SKELETON_ICON='BSkeletonIcon';
var NAME_SKELETON_IMG='BSkeletonImg';
var NAME_SKELETON_TABLE='BSkeletonTable';
var NAME_SKELETON_WRAPPER='BSkeletonWrapper';
var NAME_SPINNER='BSpinner';
var NAME_TAB='BTab';
var NAME_TABLE='BTable';
var NAME_TABLE_CELL='BTableCell';
var NAME_TABLE_LITE='BTableLite';
var NAME_TABLE_SIMPLE='BTableSimple';
var NAME_TABS='BTabs';
var NAME_TBODY='BTbody';
var NAME_TFOOT='BTfoot';
var NAME_TH='BTh';
var NAME_THEAD='BThead';
var NAME_TIME='BTime';
var NAME_TOAST='BToast';
var NAME_TOASTER='BToaster';
var NAME_TOOLTIP='BTooltip';
var NAME_TR='BTr';// Helper component names

var NAME_COLLAPSE_HELPER='BVCollapse';
var NAME_FORM_BUTTON_LABEL_CONTROL='BVFormBtnLabelControl';
var NAME_FORM_RATING_STAR='BVFormRatingStar';
var NAME_POPOVER_HELPER='BVPopover';
var NAME_POPOVER_TEMPLATE='BVPopoverTemplate';
var NAME_POPPER='BVPopper';
var NAME_TAB_BUTTON_HELPER='BVTabButton';
var NAME_TOAST_POP='BVToastPop';
var NAME_TOOLTIP_HELPER='BVTooltip';
var NAME_TOOLTIP_TEMPLATE='BVTooltipTemplate';
var NAME_TRANSITION='BVTransition';
var NAME_TRANSPORTER='BVTransporter';
var NAME_TRANSPORTER_TARGET='BVTransporterTarget';

var EVENT_NAME_ACTIVATE_TAB='activate-tab';
var EVENT_NAME_BLUR='blur';
var EVENT_NAME_CANCEL='cancel';
var EVENT_NAME_CHANGE='change';
var EVENT_NAME_CHANGED='changed';
var EVENT_NAME_CLICK='click';
var EVENT_NAME_CLOSE='close';
var EVENT_NAME_CONTEXT='context';
var EVENT_NAME_CONTEXT_CHANGED='context-changed';
var EVENT_NAME_DESTROYED='destroyed';
var EVENT_NAME_DISABLE='disable';
var EVENT_NAME_DISABLED='disabled';
var EVENT_NAME_DISMISSED='dismissed';
var EVENT_NAME_DISMISS_COUNT_DOWN='dismiss-count-down';
var EVENT_NAME_ENABLE='enable';
var EVENT_NAME_ENABLED='enabled';
var EVENT_NAME_FILTERED='filtered';
var EVENT_NAME_FIRST='first';
var EVENT_NAME_FOCUSIN='focusin';
var EVENT_NAME_FOCUSOUT='focusout';
var EVENT_NAME_HEAD_CLICKED='head-clicked';
var EVENT_NAME_HIDDEN='hidden';
var EVENT_NAME_HIDE='hide';
var EVENT_NAME_IMG_ERROR='img-error';
var EVENT_NAME_INPUT='input';
var EVENT_NAME_LAST='last';
var EVENT_NAME_MOUSEENTER='mouseenter';
var EVENT_NAME_MOUSELEAVE='mouseleave';
var EVENT_NAME_NEXT='next';
var EVENT_NAME_OK='ok';
var EVENT_NAME_OPEN='open';
var EVENT_NAME_PAGE_CLICK='page-click';
var EVENT_NAME_PAUSED='paused';
var EVENT_NAME_PREV='prev';
var EVENT_NAME_REFRESH='refresh';
var EVENT_NAME_REFRESHED='refreshed';
var EVENT_NAME_REMOVE='remove';
var EVENT_NAME_ROW_CLICKED='row-clicked';
var EVENT_NAME_ROW_CONTEXTMENU='row-contextmenu';
var EVENT_NAME_ROW_DBLCLICKED='row-dblclicked';
var EVENT_NAME_ROW_HOVERED='row-hovered';
var EVENT_NAME_ROW_MIDDLE_CLICKED='row-middle-clicked';
var EVENT_NAME_ROW_SELECTED='row-selected';
var EVENT_NAME_ROW_UNHOVERED='row-unhovered';
var EVENT_NAME_SELECTED='selected';
var EVENT_NAME_SHOW='show';
var EVENT_NAME_SHOWN='shown';
var EVENT_NAME_SLIDING_END='sliding-end';
var EVENT_NAME_SLIDING_START='sliding-start';
var EVENT_NAME_SORT_CHANGED='sort-changed';
var EVENT_NAME_TAG_STATE='tag-state';
var EVENT_NAME_TOGGLE='toggle';
var EVENT_NAME_UNPAUSED='unpaused';
var EVENT_NAME_UPDATE='update';
var HOOK_EVENT_NAME_BEFORE_DESTROY='hook:beforeDestroy';
var HOOK_EVENT_NAME_DESTROYED='hook:destroyed';
var MODEL_EVENT_NAME_PREFIX='update:';
var ROOT_EVENT_NAME_PREFIX='bv';
var ROOT_EVENT_NAME_SEPARATOR='::';
var EVENT_OPTIONS_PASSIVE={
passive:true};

var EVENT_OPTIONS_NO_CAPTURE={
passive:true,
capture:false};


// General types
var PROP_TYPE_ANY=undefined;
var PROP_TYPE_ARRAY=Array;
var PROP_TYPE_BOOLEAN=Boolean;
var PROP_TYPE_DATE=Date;
var PROP_TYPE_FUNCTION=Function;
var PROP_TYPE_NUMBER=Number;
var PROP_TYPE_OBJECT=Object;
var PROP_TYPE_REG_EXP=RegExp;
var PROP_TYPE_STRING=String;// Multiple types

var PROP_TYPE_ARRAY_FUNCTION=[PROP_TYPE_ARRAY,PROP_TYPE_FUNCTION];
var PROP_TYPE_ARRAY_OBJECT=[PROP_TYPE_ARRAY,PROP_TYPE_OBJECT];
var PROP_TYPE_ARRAY_OBJECT_STRING=[PROP_TYPE_ARRAY,PROP_TYPE_OBJECT,PROP_TYPE_STRING];
var PROP_TYPE_ARRAY_STRING=[PROP_TYPE_ARRAY,PROP_TYPE_STRING];
var PROP_TYPE_BOOLEAN_NUMBER=[PROP_TYPE_BOOLEAN,PROP_TYPE_NUMBER];
var PROP_TYPE_BOOLEAN_NUMBER_STRING=[PROP_TYPE_BOOLEAN,PROP_TYPE_NUMBER,PROP_TYPE_STRING];
var PROP_TYPE_BOOLEAN_STRING=[PROP_TYPE_BOOLEAN,PROP_TYPE_STRING];
var PROP_TYPE_DATE_STRING=[PROP_TYPE_DATE,PROP_TYPE_STRING];
var PROP_TYPE_FUNCTION_STRING=[PROP_TYPE_FUNCTION,PROP_TYPE_STRING];
var PROP_TYPE_NUMBER_STRING=[PROP_TYPE_NUMBER,PROP_TYPE_STRING];
var PROP_TYPE_NUMBER_OBJECT_STRING=[PROP_TYPE_NUMBER,PROP_TYPE_OBJECT,PROP_TYPE_STRING];
var PROP_TYPE_OBJECT_FUNCTION=[PROP_TYPE_OBJECT,PROP_TYPE_FUNCTION];
var PROP_TYPE_OBJECT_STRING=[PROP_TYPE_OBJECT,PROP_TYPE_STRING];

var SLOT_NAME_ADD_BUTTON_TEXT='add-button-text';
var SLOT_NAME_APPEND='append';
var SLOT_NAME_ASIDE='aside';
var SLOT_NAME_BADGE='badge';
var SLOT_NAME_BOTTOM_ROW='bottom-row';
var SLOT_NAME_BUTTON_CONTENT='button-content';
var SLOT_NAME_CUSTOM_FOOT='custom-foot';
var SLOT_NAME_DECREMENT='decrement';
var SLOT_NAME_DEFAULT='default';
var SLOT_NAME_DESCRIPTION='description';
var SLOT_NAME_DISMISS='dismiss';
var SLOT_NAME_DROP_PLACEHOLDER='drop-placeholder';
var SLOT_NAME_ELLIPSIS_TEXT='ellipsis-text';
var SLOT_NAME_EMPTY='empty';
var SLOT_NAME_EMPTYFILTERED='emptyfiltered';
var SLOT_NAME_FILE_NAME='file-name';
var SLOT_NAME_FIRST='first';
var SLOT_NAME_FIRST_TEXT='first-text';
var SLOT_NAME_FOOTER='footer';
var SLOT_NAME_HEADER='header';
var SLOT_NAME_HEADER_CLOSE='header-close';
var SLOT_NAME_ICON_CLEAR='icon-clear';
var SLOT_NAME_ICON_EMPTY='icon-empty';
var SLOT_NAME_ICON_FULL='icon-full';
var SLOT_NAME_ICON_HALF='icon-half';
var SLOT_NAME_IMG='img';
var SLOT_NAME_INCREMENT='increment';
var SLOT_NAME_INVALID_FEEDBACK='invalid-feedback';
var SLOT_NAME_LABEL='label';
var SLOT_NAME_LAST_TEXT='last-text';
var SLOT_NAME_LEAD='lead';
var SLOT_NAME_LOADING='loading';
var SLOT_NAME_MODAL_BACKDROP='modal-backdrop';
var SLOT_NAME_MODAL_CANCEL='modal-cancel';
var SLOT_NAME_MODAL_FOOTER='modal-footer';
var SLOT_NAME_MODAL_HEADER='modal-header';
var SLOT_NAME_MODAL_HEADER_CLOSE='modal-header-close';
var SLOT_NAME_MODAL_OK='modal-ok';
var SLOT_NAME_MODAL_TITLE='modal-title';
var SLOT_NAME_NAV_NEXT_DECADE='nav-next-decade';
var SLOT_NAME_NAV_NEXT_MONTH='nav-next-month';
var SLOT_NAME_NAV_NEXT_YEAR='nav-next-year';
var SLOT_NAME_NAV_PEV_DECADE='nav-prev-decade';
var SLOT_NAME_NAV_PEV_MONTH='nav-prev-month';
var SLOT_NAME_NAV_PEV_YEAR='nav-prev-year';
var SLOT_NAME_NAV_THIS_MONTH='nav-this-month';
var SLOT_NAME_NEXT_TEXT='next-text';
var SLOT_NAME_OVERLAY='overlay';
var SLOT_NAME_PAGE='page';
var SLOT_NAME_PLACEHOLDER='placeholder';
var SLOT_NAME_PREPEND='prepend';
var SLOT_NAME_PREV_TEXT='prev-text';
var SLOT_NAME_ROW_DETAILS='row-details';
var SLOT_NAME_TABLE_BUSY='table-busy';
var SLOT_NAME_TABLE_CAPTION='table-caption';
var SLOT_NAME_TABLE_COLGROUP='table-colgroup';
var SLOT_NAME_TABS_END='tabs-end';
var SLOT_NAME_TABS_START='tabs-start';
var SLOT_NAME_TEXT='text';
var SLOT_NAME_THEAD_TOP='thead-top';
var SLOT_NAME_TITLE='title';
var SLOT_NAME_TOAST_TITLE='toast-title';
var SLOT_NAME_TOP_ROW='top-row';
var SLOT_NAME_VALID_FEEDBACK='valid-feedback';

var from=function from(){
return Array.from.apply(Array,arguments);
};// --- Instance ---

var arrayIncludes=function arrayIncludes(array,value){
return array.indexOf(value)!==-1;
};
var concat=function concat(){
for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){
args[_key]=arguments[_key];
}

return Array.prototype.concat.apply([],args);
};// --- Utilities ---

var createArray=function createArray(length,fillFn){
var mapFn=isFunction(fillFn)?fillFn:function(){
return fillFn;
};
return Array.apply(null,{
length:length}).
map(mapFn);
};
var flatten=function flatten(array){
return array.reduce(function(result,item){
return concat(result,item);
},[]);
};
var flattenDeep=function flattenDeep(array){
return array.reduce(function(result,item){
return concat(result,Array.isArray(item)?flattenDeep(item):item);
},[]);
};

// Number utilities
// Converts a value (string, number, etc.) to an integer number
// Assumes radix base 10
var toInteger=function toInteger(value){
var defaultValue=arguments.length>1&&arguments[1]!==undefined?arguments[1]:NaN;
var integer=parseInt(value,10);
return isNaN(integer)?defaultValue:integer;
};// Converts a value (string, number, etc.) to a number

var toFloat=function toFloat(value){
var defaultValue=arguments.length>1&&arguments[1]!==undefined?arguments[1]:NaN;
var float=parseFloat(value);
return isNaN(float)?defaultValue:float;
};// Converts a value (string, number, etc.) to a string
// representation with `precision` digits after the decimal
// Returns the string 'NaN' if the value cannot be converted

var toFixed=function toFixed(val,precision){
return toFloat(val).toFixed(toInteger(precision,0));
};

// String utilities
// Converts PascalCase or camelCase to kebab-case

var kebabCase=function kebabCase(str){
return str.replace(RX_HYPHENATE,'-$1').toLowerCase();
};// Converts a kebab-case or camelCase string to PascalCase

var pascalCase=function pascalCase(str){
str=kebabCase(str).replace(RX_UN_KEBAB,function(_,c){
return c?c.toUpperCase():'';
});
return str.charAt(0).toUpperCase()+str.slice(1);
};// Converts a string, including strings in camelCase or snake_case, into Start Case
// It keeps original single quote and hyphen in the word
// https://github.com/UrbanCompass/to-start-case

var startCase=function startCase(str){
return str.replace(RX_UNDERSCORE,' ').replace(RX_LOWER_UPPER,function(str,$1,$2){
return $1+' '+$2;
}).replace(RX_START_SPACE_WORD,function(str,$1,$2){
return $1+$2.toUpperCase();
});
};// Lowercases the first letter of a string and returns a new string

var lowerFirst=function lowerFirst(str){
str=isString(str)?str.trim():String(str);
return str.charAt(0).toLowerCase()+str.slice(1);
};// Uppercases the first letter of a string and returns a new string

var upperFirst=function upperFirst(str){
str=isString(str)?str.trim():String(str);
return str.charAt(0).toUpperCase()+str.slice(1);
};// Escape characters to be used in building a regular expression

var escapeRegExp=function escapeRegExp(str){
return str.replace(RX_REGEXP_REPLACE,'\\$&');
};// Convert a value to a string that can be rendered
// `undefined`/`null` will be converted to `''`
// Plain objects and arrays will be JSON stringified

var toString$1=function toString(val){
var spaces=arguments.length>1&&arguments[1]!==undefined?arguments[1]:2;
return isUndefinedOrNull(val)?'':isArray(val)||isPlainObject(val)&&val.toString===Object.prototype.toString?JSON.stringify(val,null,spaces):String(val);
};// Remove leading white space from a string

var trimLeft=function trimLeft(str){
return toString$1(str).replace(RX_TRIM_LEFT,'');
};// Remove Trailing white space from a string

var trim=function trim(str){
return toString$1(str).trim();
};// Lower case a string

var lowerCase=function lowerCase(str){
return toString$1(str).toLowerCase();
};// Upper case a string

var ELEMENT_PROTO=Element.prototype;
var TABABLE_SELECTOR=['button','[href]:not(.disabled)','input','select','textarea','[tabindex]','[contenteditable]'].map(function(s){
return "".concat(s,":not(:disabled):not([disabled])");
}).join(', ');// --- Normalization utils ---
// See: https://developer.mozilla.org/en-US/docs/Web/API/Element/matches#Polyfill

/* istanbul ignore next */

var matchesEl=ELEMENT_PROTO.matches||ELEMENT_PROTO.msMatchesSelector||ELEMENT_PROTO.webkitMatchesSelector;// See: https://developer.mozilla.org/en-US/docs/Web/API/Element/closest

/* istanbul ignore next */

var closestEl=ELEMENT_PROTO.closest||function(sel){
var el=this;

do{
// Use our "patched" matches function
if(matches(el,sel)){
return el;
}

el=el.parentElement||el.parentNode;
}while(!isNull(el)&&el.nodeType===Node.ELEMENT_NODE);

return null;
};// `requestAnimationFrame()` convenience method

/* istanbul ignore next: JSDOM always returns the first option */

var requestAF=WINDOW.requestAnimationFrame||WINDOW.webkitRequestAnimationFrame||WINDOW.mozRequestAnimationFrame||WINDOW.msRequestAnimationFrame||WINDOW.oRequestAnimationFrame||// Fallback, but not a true polyfill
// Only needed for Opera Mini

/* istanbul ignore next */
function(cb){
return setTimeout(cb,16);
};
var MutationObs=WINDOW.MutationObserver||WINDOW.WebKitMutationObserver||WINDOW.MozMutationObserver||null;// --- Utils ---
// Remove a node from DOM

var removeNode=function removeNode(el){
return el&&el.parentNode&&el.parentNode.removeChild(el);
};// Determine if an element is an HTML element

var isElement=function isElement(el){
return !!(el&&el.nodeType===Node.ELEMENT_NODE);
};// Get the currently active HTML element

var getActiveElement=function getActiveElement(){
var excludes=arguments.length>0&&arguments[0]!==undefined?arguments[0]:[];
var activeElement=DOCUMENT.activeElement;
return activeElement&&!excludes.some(function(el){
return el===activeElement;
})?activeElement:null;
};// Returns `true` if a tag's name equals `name`

var isTag=function isTag(tag,name){
return toString$1(tag).toLowerCase()===toString$1(name).toLowerCase();
};// Determine if an HTML element is the currently active element

var isActiveElement=function isActiveElement(el){
return isElement(el)&&el===getActiveElement();
};// Determine if an HTML element is visible - Faster than CSS check

var isVisible=function isVisible(el){
if(!isElement(el)||!el.parentNode||!contains(DOCUMENT.body,el)){
// Note this can fail for shadow dom elements since they
// are not a direct descendant of document.body
return false;
}

if(getStyle(el,'display')==='none'){
// We do this check to help with vue-test-utils when using v-show

/* istanbul ignore next */
return false;
}// All browsers support getBoundingClientRect(), except JSDOM as it returns all 0's for values :(
// So any tests that need isVisible will fail in JSDOM
// Except when we override the getBCR prototype in some tests


var bcr=getBCR(el);
return !!(bcr&&bcr.height>0&&bcr.width>0);
};// Determine if an element is disabled

var isDisabled=function isDisabled(el){
return !isElement(el)||el.disabled||hasAttr(el,'disabled')||hasClass(el,'disabled');
};// Cause/wait-for an element to reflow its content (adjusting its height/width)

var reflow=function reflow(el){
// Requesting an elements offsetHight will trigger a reflow of the element content

/* istanbul ignore next: reflow doesn't happen in JSDOM */
return isElement(el)&&el.offsetHeight;
};// Select all elements matching selector. Returns `[]` if none found

var selectAll=function selectAll(selector,root){
return from((isElement(root)?root:DOCUMENT).querySelectorAll(selector));
};// Select a single element, returns `null` if not found

var select=function select(selector,root){
return (isElement(root)?root:DOCUMENT).querySelector(selector)||null;
};// Determine if an element matches a selector

var matches=function matches(el,selector){
return isElement(el)?matchesEl.call(el,selector):false;
};// Finds closest element matching selector. Returns `null` if not found

var closest=function closest(selector,root){
var includeRoot=arguments.length>2&&arguments[2]!==undefined?arguments[2]:false;

if(!isElement(root)){
return null;
}

var el=closestEl.call(root,selector);// Native closest behaviour when `includeRoot` is truthy,
// else emulate jQuery closest and return `null` if match is
// the passed in root element when `includeRoot` is falsey

return includeRoot?el:el===root?null:el;
};// Returns true if the parent element contains the child element

var contains=function contains(parent,child){
return parent&&isFunction(parent.contains)?parent.contains(child):false;
};// Get an element given an ID

var getById=function getById(id){
return DOCUMENT.getElementById(/^#/.test(id)?id.slice(1):id)||null;
};// Add a class to an element

var addClass=function addClass(el,className){
// We are checking for `el.classList` existence here since IE 11
// returns `undefined` for some elements (e.g. SVG elements)
// See https://github.com/bootstrap-vue/bootstrap-vue/issues/2713
if(className&&isElement(el)&&el.classList){
el.classList.add(className);
}
};// Remove a class from an element

var removeClass=function removeClass(el,className){
// We are checking for `el.classList` existence here since IE 11
// returns `undefined` for some elements (e.g. SVG elements)
// See https://github.com/bootstrap-vue/bootstrap-vue/issues/2713
if(className&&isElement(el)&&el.classList){
el.classList.remove(className);
}
};// Test if an element has a class

var hasClass=function hasClass(el,className){
// We are checking for `el.classList` existence here since IE 11
// returns `undefined` for some elements (e.g. SVG elements)
// See https://github.com/bootstrap-vue/bootstrap-vue/issues/2713
if(className&&isElement(el)&&el.classList){
return el.classList.contains(className);
}

return false;
};// Set an attribute on an element

var setAttr=function setAttr(el,attr,value){
if(attr&&isElement(el)){
el.setAttribute(attr,value);
}
};// Remove an attribute from an element

var removeAttr=function removeAttr(el,attr){
if(attr&&isElement(el)){
el.removeAttribute(attr);
}
};// Get an attribute value from an element
// Returns `null` if not found

var getAttr=function getAttr(el,attr){
return attr&&isElement(el)?el.getAttribute(attr):null;
};// Determine if an attribute exists on an element
// Returns `true` or `false`, or `null` if element not found

var hasAttr=function hasAttr(el,attr){
return attr&&isElement(el)?el.hasAttribute(attr):null;
};// Set an style property on an element

var setStyle=function setStyle(el,prop,value){
if(prop&&isElement(el)){
el.style[prop]=value;
}
};// Remove an style property from an element

var removeStyle=function removeStyle(el,prop){
if(prop&&isElement(el)){
el.style[prop]='';
}
};// Get an style property value from an element
// Returns `null` if not found

var getStyle=function getStyle(el,prop){
return prop&&isElement(el)?el.style[prop]||null:null;
};// Return the Bounding Client Rect of an element
// Returns `null` if not an element

/* istanbul ignore next: getBoundingClientRect() doesn't work in JSDOM */

var getBCR=function getBCR(el){
return isElement(el)?el.getBoundingClientRect():null;
};// Get computed style object for an element

/* istanbul ignore next: getComputedStyle() doesn't work in JSDOM */

var getCS=function getCS(el){
var getComputedStyle=WINDOW.getComputedStyle;
return getComputedStyle&&isElement(el)?getComputedStyle(el):{};
};// Returns a `Selection` object representing the range of text selected
// Returns `null` if no window support is given

/* istanbul ignore next: getSelection() doesn't work in JSDOM */

var getSel=function getSel(){
var getSelection=WINDOW.getSelection;
return getSelection?WINDOW.getSelection():null;
};// Return an element's offset with respect to document element
// https://j11y.io/jquery/#v=git&fn=jQuery.fn.offset

var offset=function offset(el)
/* istanbul ignore next: getBoundingClientRect(), getClientRects() doesn't work in JSDOM */
{
var _offset={
top:0,
left:0};


if(!isElement(el)||el.getClientRects().length===0){
return _offset;
}

var bcr=getBCR(el);

if(bcr){
var win=el.ownerDocument.defaultView;
_offset.top=bcr.top+win.pageYOffset;
_offset.left=bcr.left+win.pageXOffset;
}

return _offset;
};// Return an element's offset with respect to to its offsetParent
// https://j11y.io/jquery/#v=git&fn=jQuery.fn.position

var position=function position(el)
/* istanbul ignore next: getBoundingClientRect() doesn't work in JSDOM */
{
var _offset={
top:0,
left:0};


if(!isElement(el)){
return _offset;
}

var parentOffset={
top:0,
left:0};

var elStyles=getCS(el);

if(elStyles.position==='fixed'){
_offset=getBCR(el)||_offset;
}else {
_offset=offset(el);
var doc=el.ownerDocument;
var offsetParent=el.offsetParent||doc.documentElement;

while(offsetParent&&(offsetParent===doc.body||offsetParent===doc.documentElement)&&getCS(offsetParent).position==='static'){
offsetParent=offsetParent.parentNode;
}

if(offsetParent&&offsetParent!==el&&offsetParent.nodeType===Node.ELEMENT_NODE){
parentOffset=offset(offsetParent);
var offsetParentStyles=getCS(offsetParent);
parentOffset.top+=toFloat(offsetParentStyles.borderTopWidth,0);
parentOffset.left+=toFloat(offsetParentStyles.borderLeftWidth,0);
}
}

return {
top:_offset.top-parentOffset.top-toFloat(elStyles.marginTop,0),
left:_offset.left-parentOffset.left-toFloat(elStyles.marginLeft,0)};

};// Find all tabable elements in the given element
// Assumes users have not used `tabindex` > `0` on elements

var getTabables=function getTabables(){
var rootEl=arguments.length>0&&arguments[0]!==undefined?arguments[0]:document;
return selectAll(TABABLE_SELECTOR,rootEl).filter(isVisible).filter(function(el){
return el.tabIndex>-1&&!el.disabled;
});
};// Attempt to focus an element, and return `true` if successful

var attemptFocus=function attemptFocus(el){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

try{
el.focus(options);
}catch(_unused){}

return isActiveElement(el);
};// Attempt to blur an element, and return `true` if successful

var attemptBlur=function attemptBlur(el){
try{
el.blur();
}catch(_unused2){}

return !isActiveElement(el);
};

var memoize=function memoize(fn){
var cache=create(null);
return function(){
for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){
args[_key]=arguments[_key];
}

var argsKey=JSON.stringify(args);
return cache[argsKey]=cache[argsKey]||fn.apply(null,args);
};
};

var VueProto=vue__WEBPACK_IMPORTED_MODULE_0___default.a.prototype;// --- Getter methods ---

var getConfigValue=function getConfigValue(key){
var defaultValue=arguments.length>1&&arguments[1]!==undefined?arguments[1]:undefined;
var bvConfig=VueProto[PROP_NAME];
return bvConfig?bvConfig.getConfigValue(key,defaultValue):cloneDeep(defaultValue);
};// Method to grab a config value for a particular component

var getComponentConfig=function getComponentConfig(key){
var propKey=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;
var defaultValue=arguments.length>2&&arguments[2]!==undefined?arguments[2]:undefined;
// Return the particular config value for key if specified,
// otherwise we return the full config (or an empty object if not found)
return propKey?getConfigValue("".concat(key,".").concat(propKey),defaultValue):getConfigValue(key,{});
};// Get all breakpoint names

var getBreakpoints=function getBreakpoints(){
return getConfigValue('breakpoints',DEFAULT_BREAKPOINT);
};// Private method for caching breakpoint names

var _getBreakpointsCached=memoize(function(){
return getBreakpoints();
});// Get all breakpoint names (cached)


var getBreakpointsCached=function getBreakpointsCached(){
return cloneDeep(_getBreakpointsCached());
};// Get breakpoints with the smallest breakpoint set as ''
// Useful for components that create breakpoint specific props

var getBreakpointsUpCached=memoize(function(){
var breakpoints=getBreakpointsCached();
breakpoints[0]='';
return breakpoints;
});// Get breakpoints with the largest breakpoint set as ''

var prefixPropName=function prefixPropName(prefix,value){
return prefix+upperFirst(value);
};// Remove a prefix from a property

var unprefixPropName=function unprefixPropName(prefix,value){
return lowerFirst(value.replace(prefix,''));
};// Suffix can be a falsey value so nothing is appended to string
// (helps when looping over props & some shouldn't change)
// Use data last parameters to allow for currying

var suffixPropName=function suffixPropName(suffix,value){
return value+(suffix?upperFirst(suffix):'');
};// Generates a prop object

var makeProp=function makeProp(){
var type=arguments.length>0&&arguments[0]!==undefined?arguments[0]:PROP_TYPE_ANY;
var value=arguments.length>1&&arguments[1]!==undefined?arguments[1]:undefined;
var requiredOrValidator=arguments.length>2&&arguments[2]!==undefined?arguments[2]:undefined;
var validator=arguments.length>3&&arguments[3]!==undefined?arguments[3]:undefined;
var required=requiredOrValidator===true;
validator=required?validator:requiredOrValidator;
return _objectSpread2(_objectSpread2(_objectSpread2({},type?{
type:type}:
{}),required?{
required:required}:
isUndefined(value)?{}:{
default:isObject(value)?function(){
return value;
}:value}),
isUndefined(validator)?{}:{
validator:validator});

};// Copies props from one array/object to a new array/object
// Prop values are also cloned as new references to prevent possible
// mutation of original prop object values
// Optionally accepts a function to transform the prop name

var copyProps=function copyProps(props){
var transformFn=arguments.length>1&&arguments[1]!==undefined?arguments[1]:identity;

if(isArray(props)){
return props.map(transformFn);
}

var copied={};

for(var prop in props){
/* istanbul ignore else */
if(hasOwnProperty(props,prop)){
// If the prop value is an object, do a shallow clone
// to prevent potential mutations to the original object
copied[transformFn(prop)]=isObject(props[prop])?clone(props[prop]):props[prop];
}
}

return copied;
};// Given an array of properties or an object of property keys,
// plucks all the values off the target object, returning a new object
// that has props that reference the original prop values

var pluckProps=function pluckProps(keysToPluck,objToPluck){
var transformFn=arguments.length>2&&arguments[2]!==undefined?arguments[2]:identity;
return (isArray(keysToPluck)?keysToPluck.slice():keys(keysToPluck)).reduce(function(memo,prop){
memo[transformFn(prop)]=objToPluck[prop];
return memo;
},{});
};// Make a prop object configurable by global configuration
// Replaces the current `default` key of each prop with a `getComponentConfig()`
// call that falls back to the current default value of the prop

var makePropConfigurable=function makePropConfigurable(prop,key,componentKey){
return _objectSpread2(_objectSpread2({},cloneDeep(prop)),{},{
default:function bvConfigurablePropDefault(){
var value=getComponentConfig(componentKey,key,prop.default);
return isFunction(value)?value():value;
}});

};// Make a props object configurable by global configuration
// Replaces the current `default` key of each prop with a `getComponentConfig()`
// call that falls back to the current default value of the prop

var makePropsConfigurable=function makePropsConfigurable(props,componentKey){
return keys(props).reduce(function(result,key){
return _objectSpread2(_objectSpread2({},result),{},_defineProperty({},key,makePropConfigurable(props[key],key,componentKey)));
},{});
};// Get function name we use in `makePropConfigurable()`
// for the prop default value override to compare
// against in `hasPropFunction()`

var configurablePropDefaultFnName=makePropConfigurable({},'','').default.name;// Detect wether the given value is currently a function
// and isn't the props default function

var hasPropFunction=function hasPropFunction(fn){
return isFunction(fn)&&fn.name!==configurablePropDefaultFnName;
};

var makeModelMixin=function makeModelMixin(prop){
var _ref=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{},
_ref$type=_ref.type,
type=_ref$type===void 0?PROP_TYPE_ANY:_ref$type,
_ref$defaultValue=_ref.defaultValue,
defaultValue=_ref$defaultValue===void 0?undefined:_ref$defaultValue,
_ref$validator=_ref.validator,
validator=_ref$validator===void 0?undefined:_ref$validator,
_ref$event=_ref.event,
event=_ref$event===void 0?EVENT_NAME_INPUT:_ref$event;

var props=_defineProperty({},prop,makeProp(type,defaultValue,validator));// @vue/component


var mixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
model:{
prop:prop,
event:event},

props:props});

return {
mixin:mixin,
props:props,
prop:prop,
event:event};

};

// In functional components, `slots` is a function so it must be called
// first before passing to the below methods. `scopedSlots` is always an
// object and may be undefined (for Vue < 2.6.x)

/**
 * Returns true if either scoped or unscoped named slot exists
 *
 * @param {String, Array} name or name[]
 * @param {Object} scopedSlots
 * @param {Object} slots
 * @returns {Array|undefined} VNodes
 */

var hasNormalizedSlot=function hasNormalizedSlot(names){
var $scopedSlots=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
var $slots=arguments.length>2&&arguments[2]!==undefined?arguments[2]:{};
// Ensure names is an array
names=concat(names).filter(identity);// Returns true if the either a $scopedSlot or $slot exists with the specified name

return names.some(function(name){
return $scopedSlots[name]||$slots[name];
});
};
/**
 * Returns VNodes for named slot either scoped or unscoped
 *
 * @param {String, Array} name or name[]
 * @param {String} scope
 * @param {Object} scopedSlots
 * @param {Object} slots
 * @returns {Array|undefined} VNodes
 */

var normalizeSlot=function normalizeSlot(names){
var scope=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
var $scopedSlots=arguments.length>2&&arguments[2]!==undefined?arguments[2]:{};
var $slots=arguments.length>3&&arguments[3]!==undefined?arguments[3]:{};
// Ensure names is an array
names=concat(names).filter(identity);
var slot;

for(var i=0;i<names.length&&!slot;i++){
var name=names[i];
slot=$scopedSlots[name]||$slots[name];
}// Note: in Vue 2.6.x, all named slots are also scoped slots


return isFunction(slot)?slot(scope):slot;
};

var normalizeSlotMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
methods:{
// Returns `true` if the either a `$scopedSlot` or `$slot` exists with the specified name
// `name` can be a string name or an array of names
hasNormalizedSlot:function hasNormalizedSlot$1(){
var name=arguments.length>0&&arguments[0]!==undefined?arguments[0]:SLOT_NAME_DEFAULT;
var scopedSlots=arguments.length>1&&arguments[1]!==undefined?arguments[1]:this.$scopedSlots;
var slots=arguments.length>2&&arguments[2]!==undefined?arguments[2]:this.$slots;
return hasNormalizedSlot(name,scopedSlots,slots);
},
// Returns an array of rendered VNodes if slot found, otherwise `undefined`
// `name` can be a string name or an array of names
normalizeSlot:function normalizeSlot$1(){
var name=arguments.length>0&&arguments[0]!==undefined?arguments[0]:SLOT_NAME_DEFAULT;
var scope=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
var scopedSlots=arguments.length>2&&arguments[2]!==undefined?arguments[2]:this.$scopedSlots;
var slots=arguments.length>3&&arguments[3]!==undefined?arguments[3]:this.$slots;

var vNodes=normalizeSlot(name,scope,scopedSlots,slots);

return vNodes?concat(vNodes):vNodes;
}}});



// Normalize event options based on support of passive option
// Exported only for testing purposes

var parseEventOptions=function parseEventOptions(options){
/* istanbul ignore else: can't test in JSDOM, as it supports passive */
if(HAS_PASSIVE_EVENT_SUPPORT){
return isObject(options)?options:{
capture:!!options||false};

}else {
// Need to translate to actual Boolean value
return !!(isObject(options)?options.capture:options);
}
};// Attach an event listener to an element

var eventOn=function eventOn(el,eventName,handler,options){
if(el&&el.addEventListener){
el.addEventListener(eventName,handler,parseEventOptions(options));
}
};// Remove an event listener from an element

var eventOff=function eventOff(el,eventName,handler,options){
if(el&&el.removeEventListener){
el.removeEventListener(eventName,handler,parseEventOptions(options));
}
};// Utility method to add/remove a event listener based on first argument (boolean)
// It passes all other arguments to the `eventOn()` or `eventOff` method

var eventOnOff=function eventOnOff(on){
var method=on?eventOn:eventOff;

for(var _len=arguments.length,args=new Array(_len>1?_len-1:0),_key=1;_key<_len;_key++){
args[_key-1]=arguments[_key];
}

method.apply(void 0,args);
};// Utility method to prevent the default event handling and propagation

var stopEvent=function stopEvent(event){
var _ref=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{},
_ref$preventDefault=_ref.preventDefault,
preventDefault=_ref$preventDefault===void 0?true:_ref$preventDefault,
_ref$propagation=_ref.propagation,
propagation=_ref$propagation===void 0?true:_ref$propagation,
_ref$immediatePropaga=_ref.immediatePropagation,
immediatePropagation=_ref$immediatePropaga===void 0?false:_ref$immediatePropaga;

if(preventDefault){
event.preventDefault();
}

if(propagation){
event.stopPropagation();
}

if(immediatePropagation){
event.stopImmediatePropagation();
}
};// Helper method to convert a component/directive name to a base event name
// `getBaseEventName('BNavigationItem')` => 'navigation-item'
// `getBaseEventName('BVToggle')` => 'toggle'

var getBaseEventName=function getBaseEventName(value){
return kebabCase(value.replace(RX_BV_PREFIX,''));
};// Get a root event name by component/directive and event name
// `getBaseEventName('BModal', 'show')` => 'bv::modal::show'


var getRootEventName=function getRootEventName(name,eventName){
return [ROOT_EVENT_NAME_PREFIX,getBaseEventName(name),eventName].join(ROOT_EVENT_NAME_SEPARATOR);
};// Get a root action event name by component/directive and action name
// `getRootActionEventName('BModal', 'show')` => 'bv::show::modal'

var getRootActionEventName=function getRootActionEventName(name,actionName){
return [ROOT_EVENT_NAME_PREFIX,actionName,getBaseEventName(name)].join(ROOT_EVENT_NAME_SEPARATOR);
};

var props=makePropsConfigurable({
ariaLabel:makeProp(PROP_TYPE_STRING,'Close'),
content:makeProp(PROP_TYPE_STRING,'&times;'),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
textVariant:makeProp(PROP_TYPE_STRING)},
NAME_BUTTON_CLOSE);// --- Main component ---
// @vue/component

var BButtonClose=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BUTTON_CLOSE,
functional:true,
props:props,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots;
var $slots=slots();
var $scopedSlots=scopedSlots||{};
var componentData={
staticClass:'close',
class:_defineProperty({},"text-".concat(props.textVariant),props.textVariant),
attrs:{
type:'button',
disabled:props.disabled,
'aria-label':props.ariaLabel?String(props.ariaLabel):null},

on:{
click:function click(event){
// Ensure click on button HTML content is also disabled

/* istanbul ignore if: bug in JSDOM still emits click on inner element */
if(props.disabled&&isEvent(event)){
stopEvent(event);
}
}}};

// Careful not to override the default slot with innerHTML

if(!hasNormalizedSlot(SLOT_NAME_DEFAULT,$scopedSlots,$slots)){
componentData.domProps={
innerHTML:props.content};

}

return h('button',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,componentData),normalizeSlot(SLOT_NAME_DEFAULT,{},$scopedSlots,$slots));
}});


var NO_FADE_PROPS={
name:'',
enterClass:'',
enterActiveClass:'',
enterToClass:'show',
leaveClass:'show',
leaveActiveClass:'',
leaveToClass:''};


var FADE_PROPS=_objectSpread2(_objectSpread2({},NO_FADE_PROPS),{},{
enterActiveClass:'fade',
leaveActiveClass:'fade'});
// --- Props ---


var props$1={
// Has no effect if `trans-props` provided
appear:makeProp(PROP_TYPE_BOOLEAN,false),
// Can be overridden by user supplied `trans-props`
mode:makeProp(PROP_TYPE_STRING),
// Only applicable to the built in transition
// Has no effect if `trans-props` provided
noFade:makeProp(PROP_TYPE_BOOLEAN,false),
// For user supplied transitions (if needed)
transProps:makeProp(PROP_TYPE_OBJECT)};
// --- Main component ---
// @vue/component

var BVTransition=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TRANSITION,
functional:true,
props:props$1,
render:function render(h,_ref){
var children=_ref.children,
data=_ref.data,
props=_ref.props;
var transProps=props.transProps;

if(!isPlainObject(transProps)){
transProps=props.noFade?NO_FADE_PROPS:FADE_PROPS;

if(props.appear){
// Default the appear classes to equal the enter classes
transProps=_objectSpread2(_objectSpread2({},transProps),{},{
appear:true,
appearClass:transProps.enterClass,
appearActiveClass:transProps.enterActiveClass,
appearToClass:transProps.enterToClass});

}
}

transProps=_objectSpread2(_objectSpread2({
mode:props.mode},
transProps),{},{
// We always need `css` true
css:true});

return h('transition',// Any transition event listeners will get merged here
Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
props:transProps}),
children);
}});


var _watch;

var _makeModelMixin=makeModelMixin('show',{
type:PROP_TYPE_BOOLEAN_NUMBER_STRING,
defaultValue:false}),

modelMixin=_makeModelMixin.mixin,
modelProps=_makeModelMixin.props,
MODEL_PROP_NAME=_makeModelMixin.prop,
MODEL_EVENT_NAME=_makeModelMixin.event;// --- Helper methods ---
// Convert `show` value to a number


var parseCountDown=function parseCountDown(show){
if(show===''||isBoolean(show)){
return 0;
}

show=toInteger(show,0);
return show>0?show:0;
};// Convert `show` value to a boolean


var parseShow=function parseShow(show){
if(show===''||show===true){
return true;
}

if(toInteger(show,0)<1){
// Boolean will always return false for the above comparison
return false;
}

return !!show;
};// --- Props ---


var props$2=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},modelProps),{},{
dismissLabel:makeProp(PROP_TYPE_STRING,'Close'),
dismissible:makeProp(PROP_TYPE_BOOLEAN,false),
fade:makeProp(PROP_TYPE_BOOLEAN,false),
variant:makeProp(PROP_TYPE_STRING,'info')})),
NAME_ALERT);// --- Main component ---
// @vue/component

var BAlert=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_ALERT,
mixins:[modelMixin,normalizeSlotMixin],
props:props$2,
data:function data(){
return {
countDown:0,
// If initially shown, we need to set these for SSR
localShow:parseShow(this[MODEL_PROP_NAME])};

},
watch:(_watch={},_defineProperty(_watch,MODEL_PROP_NAME,function(newValue){
this.countDown=parseCountDown(newValue);
this.localShow=parseShow(newValue);
}),_defineProperty(_watch,"countDown",function countDown(newValue){
var _this=this;

this.clearCountDownInterval();
var show=this[MODEL_PROP_NAME];// Ignore if `show` transitions to a boolean value

if(isNumeric(show)){
this.$emit(EVENT_NAME_DISMISS_COUNT_DOWN,newValue);// Update the v-model if needed

if(show!==newValue){
this.$emit(MODEL_EVENT_NAME,newValue);
}

if(newValue>0){
this.localShow=true;
this.$_countDownTimeout=setTimeout(function(){
_this.countDown--;
},1000);
}else {
// Slightly delay the hide to allow any UI updates
this.$nextTick(function(){
requestAF(function(){
_this.localShow=false;
});
});
}
}
}),_defineProperty(_watch,"localShow",function localShow(newValue){
var show=this[MODEL_PROP_NAME];// Only emit dismissed events for dismissible or auto-dismissing alerts

if(!newValue&&(this.dismissible||isNumeric(show))){
this.$emit(EVENT_NAME_DISMISSED);
}// Only emit booleans if we weren't passed a number via v-model


if(!isNumeric(show)&&show!==newValue){
this.$emit(MODEL_EVENT_NAME,newValue);
}
}),_watch),
created:function created(){
// Create private non-reactive props
this.$_filterTimer=null;
var show=this[MODEL_PROP_NAME];
this.countDown=parseCountDown(show);
this.localShow=parseShow(show);
},
beforeDestroy:function beforeDestroy(){
this.clearCountDownInterval();
},
methods:{
dismiss:function dismiss(){
this.clearCountDownInterval();
this.countDown=0;
this.localShow=false;
},
clearCountDownInterval:function clearCountDownInterval(){
clearTimeout(this.$_countDownTimeout);
this.$_countDownTimeout=null;
}},

render:function render(h){
var $alert=h();

if(this.localShow){
var dismissible=this.dismissible,
variant=this.variant;
var $dismissButton=h();

if(dismissible){
// Add dismiss button
$dismissButton=h(BButtonClose,{
attrs:{
'aria-label':this.dismissLabel},

on:{
click:this.dismiss}},

[this.normalizeSlot(SLOT_NAME_DISMISS)]);
}

$alert=h('div',{
staticClass:'alert',
class:_defineProperty({
'alert-dismissible':dismissible},
"alert-".concat(variant),variant),
attrs:{
role:'alert',
'aria-live':'polite',
'aria-atomic':true},

key:this[COMPONENT_UID_KEY]},
[$dismissButton,this.normalizeSlot()]);
}

return h(BVTransition,{
props:{
noFade:!this.fade}},

[$alert]);
}});


var AlertPlugin=/*#__PURE__*/pluginFactory({
components:{
BAlert:BAlert}});



// Math utilty functions
var mathMin=Math.min;
var mathMax=Math.max;
var mathAbs=Math.abs;
var mathCeil=Math.ceil;
var mathFloor=Math.floor;
var mathPow=Math.pow;
var mathRound=Math.round;

var CLASS_NAME='b-aspect';// --- Props ---

var props$3=makePropsConfigurable({
// Accepts a number (i.e. `16 / 9`, `1`, `4 / 3`)
// Or a string (i.e. '16/9', '16:9', '4:3' '1:1')
aspect:makeProp(PROP_TYPE_NUMBER_STRING,'1:1'),
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_ASPECT);// --- Main component ---
// @vue/component

var BAspect=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_ASPECT,
mixins:[normalizeSlotMixin],
props:props$3,
computed:{
padding:function padding(){
var aspect=this.aspect;
var ratio=1;

if(RX_ASPECT.test(aspect)){
// Width and/or Height can be a decimal value below `1`, so
// we only fallback to `1` if the value is `0` or `NaN`
var _aspect$split$map=aspect.split(RX_ASPECT_SEPARATOR).map(function(v){
return toFloat(v)||1;
}),
_aspect$split$map2=_slicedToArray(_aspect$split$map,2),
width=_aspect$split$map2[0],
height=_aspect$split$map2[1];

ratio=width/height;
}else {
ratio=toFloat(aspect)||1;
}

return "".concat(100/mathAbs(ratio),"%");
}},

render:function render(h){
var $sizer=h('div',{
staticClass:"".concat(CLASS_NAME,"-sizer flex-grow-1"),
style:{
paddingBottom:this.padding,
height:0}});


var $content=h('div',{
staticClass:"".concat(CLASS_NAME,"-content flex-grow-1 w-100 mw-100"),
style:{
marginLeft:'-100%'}},

this.normalizeSlot());
return h(this.tag,{
staticClass:"".concat(CLASS_NAME," d-flex")},
[$sizer,$content]);
}});


var AspectPlugin=/*#__PURE__*/pluginFactory({
components:{
BAspect:BAspect}});



var ANCHOR_TAG='a';// Method to replace reserved chars

var encodeReserveReplacer=function encodeReserveReplacer(c){
return '%'+c.charCodeAt(0).toString(16);
};// Fixed encodeURIComponent which is more conformant to RFC3986:
// - escapes [!'()*]
// - preserve commas


var encode=function encode(str){
return encodeURIComponent(toString$1(str)).replace(RX_ENCODE_REVERSE,encodeReserveReplacer).replace(RX_ENCODED_COMMA,',');
};

var decode=decodeURIComponent;// Stringifies an object of query parameters
// See: https://github.com/vuejs/vue-router/blob/dev/src/util/query.js

var stringifyQueryObj=function stringifyQueryObj(obj){
if(!isPlainObject(obj)){
return '';
}

var query=keys(obj).map(function(key){
var value=obj[key];

if(isUndefined(value)){
return '';
}else if(isNull(value)){
return encode(key);
}else if(isArray(value)){
return value.reduce(function(results,value2){
if(isNull(value2)){
results.push(encode(key));
}else if(!isUndefined(value2)){
// Faster than string interpolation
results.push(encode(key)+'='+encode(value2));
}

return results;
},[]).join('&');
}// Faster than string interpolation


return encode(key)+'='+encode(value);
})
/* must check for length, as we only want to filter empty strings, not things that look falsey! */.
filter(function(x){
return x.length>0;
}).join('&');
return query?"?".concat(query):'';
};
var parseQuery=function parseQuery(query){
var parsed={};
query=toString$1(query).trim().replace(RX_QUERY_START,'');

if(!query){
return parsed;
}

query.split('&').forEach(function(param){
var parts=param.replace(RX_PLUS,' ').split('=');
var key=decode(parts.shift());
var value=parts.length>0?decode(parts.join('=')):null;

if(isUndefined(parsed[key])){
parsed[key]=value;
}else if(isArray(parsed[key])){
parsed[key].push(value);
}else {
parsed[key]=[parsed[key],value];
}
});
return parsed;
};
var isLink=function isLink(props){
return !!(props.href||props.to);
};
var isRouterLink=function isRouterLink(tag){
return !!(tag&&!isTag(tag,'a'));
};
var computeTag=function computeTag(_ref,thisOrParent){
var to=_ref.to,
disabled=_ref.disabled,
routerComponentName=_ref.routerComponentName;
var hasRouter=!!thisOrParent.$router;

if(!hasRouter||hasRouter&&(disabled||!to)){
return ANCHOR_TAG;
}// TODO:
//   Check registered components for existence of user supplied router link component name
//   We would need to check PascalCase, kebab-case, and camelCase versions of name:
//   const name = routerComponentName
//   const names = [name, PascalCase(name), KebabCase(name), CamelCase(name)]
//   exists = names.some(name => !!thisOrParent.$options.components[name])
//   And may want to cache the result for performance or we just let the render fail
//   if the component is not registered


return routerComponentName||(thisOrParent.$nuxt?'nuxt-link':'router-link');
};
var computeRel=function computeRel(){
var _ref2=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{},
target=_ref2.target,
rel=_ref2.rel;

return target==='_blank'&&isNull(rel)?'noopener':rel||null;
};
var computeHref=function computeHref(){
var _ref3=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{},
href=_ref3.href,
to=_ref3.to;

var tag=arguments.length>1&&arguments[1]!==undefined?arguments[1]:ANCHOR_TAG;
var fallback=arguments.length>2&&arguments[2]!==undefined?arguments[2]:'#';
var toFallback=arguments.length>3&&arguments[3]!==undefined?arguments[3]:'/';

// Return `href` when explicitly provided
if(href){
return href;
}// We've checked for `$router` in `computeTag()`, so `isRouterLink()` indicates a live router
// When deferring to Vue Router's `<router-link>`, don't use the `href` attribute at all
// We return `null`, and then remove `href` from the attributes passed to `<router-link>`


if(isRouterLink(tag)){
return null;
}// Fallback to `to` prop (if `to` is a string)


if(isString(to)){
return to||toFallback;
}// Fallback to `to.path' + `to.query` + `to.hash` prop (if `to` is an object)


if(isPlainObject(to)&&(to.path||to.query||to.hash)){
var path=toString$1(to.path);
var query=stringifyQueryObj(to.query);
var hash=toString$1(to.hash);
hash=!hash||hash.charAt(0)==='#'?hash:"#".concat(hash);
return "".concat(path).concat(query).concat(hash)||toFallback;
}// If nothing is provided return the fallback


return fallback;
};

// Base attributes needed on all icons

var BASE_ATTRS={
viewBox:'0 0 16 16',
width:'1em',
height:'1em',
focusable:'false',
role:'img',
'aria-label':'icon'};
// Attributes that are nulled out when stacked

var STACKED_ATTRS={
width:null,
height:null,
focusable:null,
role:null,
'aria-label':null};
// --- Props ---

var props$4={
animation:makeProp(PROP_TYPE_STRING),
content:makeProp(PROP_TYPE_STRING),
flipH:makeProp(PROP_TYPE_BOOLEAN,false),
flipV:makeProp(PROP_TYPE_BOOLEAN,false),
fontScale:makeProp(PROP_TYPE_NUMBER_STRING,1),
rotate:makeProp(PROP_TYPE_NUMBER_STRING,0),
scale:makeProp(PROP_TYPE_NUMBER_STRING,1),
shiftH:makeProp(PROP_TYPE_NUMBER_STRING,0),
shiftV:makeProp(PROP_TYPE_NUMBER_STRING,0),
stacked:makeProp(PROP_TYPE_BOOLEAN,false),
title:makeProp(PROP_TYPE_STRING),
variant:makeProp(PROP_TYPE_STRING)};
// --- Main component ---
// Shared private base component to reduce bundle/runtime size
// @vue/component

var BVIconBase=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_ICON_BASE,
functional:true,
props:props$4,
render:function render(h,_ref){
var _class;

var data=_ref.data,
props=_ref.props,
children=_ref.children;
var animation=props.animation,
content=props.content,
flipH=props.flipH,
flipV=props.flipV,
stacked=props.stacked,
title=props.title,
variant=props.variant;
var fontScale=mathMax(toFloat(props.fontScale,1),0)||1;
var scale=mathMax(toFloat(props.scale,1),0)||1;
var rotate=toFloat(props.rotate,0);
var shiftH=toFloat(props.shiftH,0);
var shiftV=toFloat(props.shiftV,0);// Compute the transforms
// Note that order is important as SVG transforms are applied in order from
// left to right and we want flipping/scale to occur before rotation
// Note shifting is applied separately
// Assumes that the viewbox is `0 0 16 16` (`8 8` is the center)

var hasScale=flipH||flipV||scale!==1;
var hasTransforms=hasScale||rotate;
var hasShift=shiftH||shiftV;
var hasContent=!isUndefinedOrNull(content);
var transforms=[hasTransforms?'translate(8 8)':null,hasScale?"scale(".concat((flipH?-1:1)*scale," ").concat((flipV?-1:1)*scale,")"):null,rotate?"rotate(".concat(rotate,")"):null,hasTransforms?'translate(-8 -8)':null].filter(identity);// We wrap the content in a `<g>` for handling the transforms (except shift)

var $inner=h('g',{
attrs:{
transform:transforms.join(' ')||null},

domProps:hasContent?{
innerHTML:content||''}:
{}},
children);// If needed, we wrap in an additional `<g>` in order to handle the shifting

if(hasShift){
$inner=h('g',{
attrs:{
transform:"translate(".concat(16*shiftH/16," ").concat(-16*shiftV/16,")")}},

[$inner]);
}// Wrap in an additional `<g>` for proper animation handling if stacked


if(stacked){
$inner=h('g',[$inner]);
}

var $title=title?h('title',title):null;
var $content=[$title,$inner].filter(identity);
return h('svg',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])({
staticClass:'b-icon bi',
class:(_class={},_defineProperty(_class,"text-".concat(variant),variant),_defineProperty(_class,"b-icon-animation-".concat(animation),animation),_class),
attrs:BASE_ATTRS,
style:stacked?{}:{
fontSize:fontScale===1?null:"".concat(fontScale*100,"%")}},

// Merge in user supplied data
data,// If icon is stacked, null-out some attrs
stacked?{
attrs:STACKED_ATTRS}:
{},// These cannot be overridden by users
{
attrs:{
xmlns:stacked?null:'http://www.w3.org/2000/svg',
fill:'currentColor'}}),

$content);
}});


/**
 * Icon component generator function
 *
 * @param {string} icon name (minus the leading `BIcon`)
 * @param {string} raw `innerHTML` for SVG
 * @return {VueComponent}
 */

var makeIcon=function makeIcon(name,content){
// For performance reason we pre-compute some values, so that
// they are not computed on each render of the icon component
var kebabName=kebabCase(name);
var iconName="BIcon".concat(pascalCase(name));
var iconNameClass="bi-".concat(kebabName);
var iconTitle=kebabName.replace(/-/g,' ');
var svgContent=trim(content||'');
return/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:iconName,
functional:true,
props:omit(props$4,['content']),
render:function render(h,_ref){
var data=_ref.data,
props=_ref.props;
return h(BVIconBase,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(// Defaults
{
props:{
title:iconTitle},

attrs:{
'aria-label':iconTitle}},

// User data
data,// Required data
{
staticClass:iconNameClass,
props:_objectSpread2(_objectSpread2({},props),{},{
content:svgContent})}));


}});

};

// --- BEGIN AUTO-GENERATED FILE ---
var BIconBlank=/*#__PURE__*/makeIcon('Blank','');// --- Bootstrap Icons ---
// eslint-disable-next-line
var BIconAlarm=/*#__PURE__*/makeIcon('Alarm','<path d="M8.5 5.5a.5.5 0 0 0-1 0v3.362l-1.429 2.38a.5.5 0 1 0 .858.515l1.5-2.5A.5.5 0 0 0 8.5 9V5.5z"/><path d="M6.5 0a.5.5 0 0 0 0 1H7v1.07a7.001 7.001 0 0 0-3.273 12.474l-.602.602a.5.5 0 0 0 .707.708l.746-.746A6.97 6.97 0 0 0 8 16a6.97 6.97 0 0 0 3.422-.892l.746.746a.5.5 0 0 0 .707-.708l-.601-.602A7.001 7.001 0 0 0 9 2.07V1h.5a.5.5 0 0 0 0-1h-3zm1.038 3.018a6.093 6.093 0 0 1 .924 0 6 6 0 1 1-.924 0zM0 3.5c0 .753.333 1.429.86 1.887A8.035 8.035 0 0 1 4.387 1.86 2.5 2.5 0 0 0 0 3.5zM13.5 1c-.753 0-1.429.333-1.887.86a8.035 8.035 0 0 1 3.527 3.527A2.5 2.5 0 0 0 13.5 1z"/>');// eslint-disable-next-line
var BIconAlarmFill=/*#__PURE__*/makeIcon('AlarmFill','<path d="M6 .5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1H9v1.07a7.001 7.001 0 0 1 3.274 12.474l.601.602a.5.5 0 0 1-.707.708l-.746-.746A6.97 6.97 0 0 1 8 16a6.97 6.97 0 0 1-3.422-.892l-.746.746a.5.5 0 0 1-.707-.708l.602-.602A7.001 7.001 0 0 1 7 2.07V1h-.5A.5.5 0 0 1 6 .5zm2.5 5a.5.5 0 0 0-1 0v3.362l-1.429 2.38a.5.5 0 1 0 .858.515l1.5-2.5A.5.5 0 0 0 8.5 9V5.5zM.86 5.387A2.5 2.5 0 1 1 4.387 1.86 8.035 8.035 0 0 0 .86 5.387zM11.613 1.86a2.5 2.5 0 1 1 3.527 3.527 8.035 8.035 0 0 0-3.527-3.527z"/>');// eslint-disable-next-line
var BIconAlignBottom=/*#__PURE__*/makeIcon('AlignBottom','<rect width="4" height="12" x="6" y="1" rx="1"/><path d="M1.5 14a.5.5 0 0 0 0 1v-1zm13 1a.5.5 0 0 0 0-1v1zm-13 0h13v-1h-13v1z"/>');// eslint-disable-next-line
var BIconAlignCenter=/*#__PURE__*/makeIcon('AlignCenter','<path d="M8 1a.5.5 0 0 1 .5.5V6h-1V1.5A.5.5 0 0 1 8 1zm0 14a.5.5 0 0 1-.5-.5V10h1v4.5a.5.5 0 0 1-.5.5zM2 7a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V7z"/>');// eslint-disable-next-line
var BIconAlignEnd=/*#__PURE__*/makeIcon('AlignEnd','<path fill-rule="evenodd" d="M14.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5z"/><path d="M13 7a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V7z"/>');// eslint-disable-next-line
var BIconAlignMiddle=/*#__PURE__*/makeIcon('AlignMiddle','<path d="M6 13a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v10zM1 8a.5.5 0 0 0 .5.5H6v-1H1.5A.5.5 0 0 0 1 8zm14 0a.5.5 0 0 1-.5.5H10v-1h4.5a.5.5 0 0 1 .5.5z"/>');// eslint-disable-next-line
var BIconAlignStart=/*#__PURE__*/makeIcon('AlignStart','<path fill-rule="evenodd" d="M1.5 1a.5.5 0 0 1 .5.5v13a.5.5 0 0 1-1 0v-13a.5.5 0 0 1 .5-.5z"/><path d="M3 7a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V7z"/>');// eslint-disable-next-line
var BIconAlignTop=/*#__PURE__*/makeIcon('AlignTop','<rect width="4" height="12" rx="1" transform="matrix(1 0 0 -1 6 15)"/><path d="M1.5 2a.5.5 0 0 1 0-1v1zm13-1a.5.5 0 0 1 0 1V1zm-13 0h13v1h-13V1z"/>');// eslint-disable-next-line
var BIconAlt=/*#__PURE__*/makeIcon('Alt','<path d="M1 13.5a.5.5 0 0 0 .5.5h3.797a.5.5 0 0 0 .439-.26L11 3h3.5a.5.5 0 0 0 0-1h-3.797a.5.5 0 0 0-.439.26L5 13H1.5a.5.5 0 0 0-.5.5zm10 0a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 0-1h-3a.5.5 0 0 0-.5.5z"/>');// eslint-disable-next-line
var BIconApp=/*#__PURE__*/makeIcon('App','<path d="M11 2a3 3 0 0 1 3 3v6a3 3 0 0 1-3 3H5a3 3 0 0 1-3-3V5a3 3 0 0 1 3-3h6zM5 1a4 4 0 0 0-4 4v6a4 4 0 0 0 4 4h6a4 4 0 0 0 4-4V5a4 4 0 0 0-4-4H5z"/>');// eslint-disable-next-line
var BIconAppIndicator=/*#__PURE__*/makeIcon('AppIndicator','<path d="M5.5 2A3.5 3.5 0 0 0 2 5.5v5A3.5 3.5 0 0 0 5.5 14h5a3.5 3.5 0 0 0 3.5-3.5V8a.5.5 0 0 1 1 0v2.5a4.5 4.5 0 0 1-4.5 4.5h-5A4.5 4.5 0 0 1 1 10.5v-5A4.5 4.5 0 0 1 5.5 1H8a.5.5 0 0 1 0 1H5.5z"/><path d="M16 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/>');// eslint-disable-next-line
var BIconArchive=/*#__PURE__*/makeIcon('Archive','<path d="M0 2a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v7.5a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5V5a1 1 0 0 1-1-1V2zm2 3v7.5A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5V5H2zm13-3H1v2h14V2zM5 7.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconArchiveFill=/*#__PURE__*/makeIcon('ArchiveFill','<path d="M12.643 15C13.979 15 15 13.845 15 12.5V5H1v7.5C1 13.845 2.021 15 3.357 15h9.286zM5.5 7h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zM.8 1a.8.8 0 0 0-.8.8V3a.8.8 0 0 0 .8.8h14.4A.8.8 0 0 0 16 3V1.8a.8.8 0 0 0-.8-.8H.8z"/>');// eslint-disable-next-line
var BIconArrow90degDown=/*#__PURE__*/makeIcon('Arrow90degDown','<path fill-rule="evenodd" d="M4.854 14.854a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 .708-.708L4 13.293V3.5A2.5 2.5 0 0 1 6.5 1h8a.5.5 0 0 1 0 1h-8A1.5 1.5 0 0 0 5 3.5v9.793l3.146-3.147a.5.5 0 0 1 .708.708l-4 4z"/>');// eslint-disable-next-line
var BIconArrow90degLeft=/*#__PURE__*/makeIcon('Arrow90degLeft','<path fill-rule="evenodd" d="M1.146 4.854a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 4H12.5A2.5 2.5 0 0 1 15 6.5v8a.5.5 0 0 1-1 0v-8A1.5 1.5 0 0 0 12.5 5H2.707l3.147 3.146a.5.5 0 1 1-.708.708l-4-4z"/>');// eslint-disable-next-line
var BIconArrow90degRight=/*#__PURE__*/makeIcon('Arrow90degRight','<path fill-rule="evenodd" d="M14.854 4.854a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 4H3.5A2.5 2.5 0 0 0 1 6.5v8a.5.5 0 0 0 1 0v-8A1.5 1.5 0 0 1 3.5 5h9.793l-3.147 3.146a.5.5 0 0 0 .708.708l4-4z"/>');// eslint-disable-next-line
var BIconArrow90degUp=/*#__PURE__*/makeIcon('Arrow90degUp','<path fill-rule="evenodd" d="M4.854 1.146a.5.5 0 0 0-.708 0l-4 4a.5.5 0 1 0 .708.708L4 2.707V12.5A2.5 2.5 0 0 0 6.5 15h8a.5.5 0 0 0 0-1h-8A1.5 1.5 0 0 1 5 12.5V2.707l3.146 3.147a.5.5 0 1 0 .708-.708l-4-4z"/>');// eslint-disable-next-line
var BIconArrowBarDown=/*#__PURE__*/makeIcon('ArrowBarDown','<path fill-rule="evenodd" d="M1 3.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13a.5.5 0 0 1-.5-.5zM8 6a.5.5 0 0 1 .5.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-3-3a.5.5 0 0 1 .708-.708L7.5 12.293V6.5A.5.5 0 0 1 8 6z"/>');// eslint-disable-next-line
var BIconArrowBarLeft=/*#__PURE__*/makeIcon('ArrowBarLeft','<path fill-rule="evenodd" d="M12.5 15a.5.5 0 0 1-.5-.5v-13a.5.5 0 0 1 1 0v13a.5.5 0 0 1-.5.5zM10 8a.5.5 0 0 1-.5.5H3.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L3.707 7.5H9.5a.5.5 0 0 1 .5.5z"/>');// eslint-disable-next-line
var BIconArrowBarRight=/*#__PURE__*/makeIcon('ArrowBarRight','<path fill-rule="evenodd" d="M6 8a.5.5 0 0 0 .5.5h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 0 0-.708.708L12.293 7.5H6.5A.5.5 0 0 0 6 8zm-2.5 7a.5.5 0 0 1-.5-.5v-13a.5.5 0 0 1 1 0v13a.5.5 0 0 1-.5.5z"/>');// eslint-disable-next-line
var BIconArrowBarUp=/*#__PURE__*/makeIcon('ArrowBarUp','<path fill-rule="evenodd" d="M8 10a.5.5 0 0 0 .5-.5V3.707l2.146 2.147a.5.5 0 0 0 .708-.708l-3-3a.5.5 0 0 0-.708 0l-3 3a.5.5 0 1 0 .708.708L7.5 3.707V9.5a.5.5 0 0 0 .5.5zm-7 2.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconArrowClockwise=/*#__PURE__*/makeIcon('ArrowClockwise','<path fill-rule="evenodd" d="M8 3a5 5 0 1 0 4.546 2.914.5.5 0 0 1 .908-.417A6 6 0 1 1 8 2v1z"/><path d="M8 4.466V.534a.25.25 0 0 1 .41-.192l2.36 1.966c.12.1.12.284 0 .384L8.41 4.658A.25.25 0 0 1 8 4.466z"/>');// eslint-disable-next-line
var BIconArrowCounterclockwise=/*#__PURE__*/makeIcon('ArrowCounterclockwise','<path fill-rule="evenodd" d="M8 3a5 5 0 1 1-4.546 2.914.5.5 0 0 0-.908-.417A6 6 0 1 0 8 2v1z"/><path d="M8 4.466V.534a.25.25 0 0 0-.41-.192L5.23 2.308a.25.25 0 0 0 0 .384l2.36 1.966A.25.25 0 0 0 8 4.466z"/>');// eslint-disable-next-line
var BIconArrowDown=/*#__PURE__*/makeIcon('ArrowDown','<path fill-rule="evenodd" d="M8 1a.5.5 0 0 1 .5.5v11.793l3.146-3.147a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 .708-.708L7.5 13.293V1.5A.5.5 0 0 1 8 1z"/>');// eslint-disable-next-line
var BIconArrowDownCircle=/*#__PURE__*/makeIcon('ArrowDownCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v5.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V4.5z"/>');// eslint-disable-next-line
var BIconArrowDownCircleFill=/*#__PURE__*/makeIcon('ArrowDownCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v5.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V4.5z"/>');// eslint-disable-next-line
var BIconArrowDownLeft=/*#__PURE__*/makeIcon('ArrowDownLeft','<path fill-rule="evenodd" d="M2 13.5a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 0-1H3.707L13.854 2.854a.5.5 0 0 0-.708-.708L3 12.293V7.5a.5.5 0 0 0-1 0v6z"/>');// eslint-disable-next-line
var BIconArrowDownLeftCircle=/*#__PURE__*/makeIcon('ArrowDownLeftCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904-2.854a.5.5 0 1 1 .707.708L6.707 9.95h2.768a.5.5 0 1 1 0 1H5.5a.5.5 0 0 1-.5-.5V6.475a.5.5 0 1 1 1 0v2.768l4.096-4.097z"/>');// eslint-disable-next-line
var BIconArrowDownLeftCircleFill=/*#__PURE__*/makeIcon('ArrowDownLeftCircleFill','<path d="M16 8A8 8 0 1 0 0 8a8 8 0 0 0 16 0zm-5.904-2.803a.5.5 0 1 1 .707.707L6.707 10h2.768a.5.5 0 0 1 0 1H5.5a.5.5 0 0 1-.5-.5V6.525a.5.5 0 0 1 1 0v2.768l4.096-4.096z"/>');// eslint-disable-next-line
var BIconArrowDownLeftSquare=/*#__PURE__*/makeIcon('ArrowDownLeftSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904-2.854a.5.5 0 1 1 .707.708L6.707 9.95h2.768a.5.5 0 1 1 0 1H5.5a.5.5 0 0 1-.5-.5V6.475a.5.5 0 1 1 1 0v2.768l4.096-4.097z"/>');// eslint-disable-next-line
var BIconArrowDownLeftSquareFill=/*#__PURE__*/makeIcon('ArrowDownLeftSquareFill','<path d="M2 16a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2zm8.096-10.803L6 9.293V6.525a.5.5 0 0 0-1 0V10.5a.5.5 0 0 0 .5.5h3.975a.5.5 0 0 0 0-1H6.707l4.096-4.096a.5.5 0 1 0-.707-.707z"/>');// eslint-disable-next-line
var BIconArrowDownRight=/*#__PURE__*/makeIcon('ArrowDownRight','<path fill-rule="evenodd" d="M14 13.5a.5.5 0 0 1-.5.5h-6a.5.5 0 0 1 0-1h4.793L2.146 2.854a.5.5 0 1 1 .708-.708L13 12.293V7.5a.5.5 0 0 1 1 0v6z"/>');// eslint-disable-next-line
var BIconArrowDownRightCircle=/*#__PURE__*/makeIcon('ArrowDownRightCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 5.146a.5.5 0 1 0-.708.708L9.243 9.95H6.475a.5.5 0 1 0 0 1h3.975a.5.5 0 0 0 .5-.5V6.475a.5.5 0 1 0-1 0v2.768L5.854 5.146z"/>');// eslint-disable-next-line
var BIconArrowDownRightCircleFill=/*#__PURE__*/makeIcon('ArrowDownRightCircleFill','<path d="M0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8zm5.904-2.803a.5.5 0 1 0-.707.707L9.293 10H6.525a.5.5 0 0 0 0 1H10.5a.5.5 0 0 0 .5-.5V6.525a.5.5 0 0 0-1 0v2.768L5.904 5.197z"/>');// eslint-disable-next-line
var BIconArrowDownRightSquare=/*#__PURE__*/makeIcon('ArrowDownRightSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 5.146a.5.5 0 1 0-.708.708L9.243 9.95H6.475a.5.5 0 1 0 0 1h3.975a.5.5 0 0 0 .5-.5V6.475a.5.5 0 1 0-1 0v2.768L5.854 5.146z"/>');// eslint-disable-next-line
var BIconArrowDownRightSquareFill=/*#__PURE__*/makeIcon('ArrowDownRightSquareFill','<path d="M14 16a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12zM5.904 5.197L10 9.293V6.525a.5.5 0 0 1 1 0V10.5a.5.5 0 0 1-.5.5H6.525a.5.5 0 0 1 0-1h2.768L5.197 5.904a.5.5 0 0 1 .707-.707z"/>');// eslint-disable-next-line
var BIconArrowDownShort=/*#__PURE__*/makeIcon('ArrowDownShort','<path fill-rule="evenodd" d="M8 4a.5.5 0 0 1 .5.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-3-3a.5.5 0 1 1 .708-.708L7.5 10.293V4.5A.5.5 0 0 1 8 4z"/>');// eslint-disable-next-line
var BIconArrowDownSquare=/*#__PURE__*/makeIcon('ArrowDownSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v5.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V4.5z"/>');// eslint-disable-next-line
var BIconArrowDownSquareFill=/*#__PURE__*/makeIcon('ArrowDownSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm6.5 4.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-3-3a.5.5 0 1 1 .708-.708L7.5 10.293V4.5a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconArrowDownUp=/*#__PURE__*/makeIcon('ArrowDownUp','<path fill-rule="evenodd" d="M11.5 15a.5.5 0 0 0 .5-.5V2.707l3.146 3.147a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 1 0 .708.708L11 2.707V14.5a.5.5 0 0 0 .5.5zm-7-14a.5.5 0 0 1 .5.5v11.793l3.146-3.147a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 .708-.708L4 13.293V1.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconArrowLeft=/*#__PURE__*/makeIcon('ArrowLeft','<path fill-rule="evenodd" d="M15 8a.5.5 0 0 0-.5-.5H2.707l3.147-3.146a.5.5 0 1 0-.708-.708l-4 4a.5.5 0 0 0 0 .708l4 4a.5.5 0 0 0 .708-.708L2.707 8.5H14.5A.5.5 0 0 0 15 8z"/>');// eslint-disable-next-line
var BIconArrowLeftCircle=/*#__PURE__*/makeIcon('ArrowLeftCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.5-.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5z"/>');// eslint-disable-next-line
var BIconArrowLeftCircleFill=/*#__PURE__*/makeIcon('ArrowLeftCircleFill','<path d="M8 0a8 8 0 1 0 0 16A8 8 0 0 0 8 0zm3.5 7.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5z"/>');// eslint-disable-next-line
var BIconArrowLeftRight=/*#__PURE__*/makeIcon('ArrowLeftRight','<path fill-rule="evenodd" d="M1 11.5a.5.5 0 0 0 .5.5h11.793l-3.147 3.146a.5.5 0 0 0 .708.708l4-4a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 11H1.5a.5.5 0 0 0-.5.5zm14-7a.5.5 0 0 1-.5.5H2.707l3.147 3.146a.5.5 0 1 1-.708.708l-4-4a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 4H14.5a.5.5 0 0 1 .5.5z"/>');// eslint-disable-next-line
var BIconArrowLeftShort=/*#__PURE__*/makeIcon('ArrowLeftShort','<path fill-rule="evenodd" d="M12 8a.5.5 0 0 1-.5.5H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5a.5.5 0 0 1 .5.5z"/>');// eslint-disable-next-line
var BIconArrowLeftSquare=/*#__PURE__*/makeIcon('ArrowLeftSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.5-.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5z"/>');// eslint-disable-next-line
var BIconArrowLeftSquareFill=/*#__PURE__*/makeIcon('ArrowLeftSquareFill','<path d="M16 14a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12zm-4.5-6.5H5.707l2.147-2.146a.5.5 0 1 0-.708-.708l-3 3a.5.5 0 0 0 0 .708l3 3a.5.5 0 0 0 .708-.708L5.707 8.5H11.5a.5.5 0 0 0 0-1z"/>');// eslint-disable-next-line
var BIconArrowRepeat=/*#__PURE__*/makeIcon('ArrowRepeat','<path d="M11.534 7h3.932a.25.25 0 0 1 .192.41l-1.966 2.36a.25.25 0 0 1-.384 0l-1.966-2.36a.25.25 0 0 1 .192-.41zm-11 2h3.932a.25.25 0 0 0 .192-.41L2.692 6.23a.25.25 0 0 0-.384 0L.342 8.59A.25.25 0 0 0 .534 9z"/><path fill-rule="evenodd" d="M8 3c-1.552 0-2.94.707-3.857 1.818a.5.5 0 1 1-.771-.636A6.002 6.002 0 0 1 13.917 7H12.9A5.002 5.002 0 0 0 8 3zM3.1 9a5.002 5.002 0 0 0 8.757 2.182.5.5 0 1 1 .771.636A6.002 6.002 0 0 1 2.083 9H3.1z"/>');// eslint-disable-next-line
var BIconArrowReturnLeft=/*#__PURE__*/makeIcon('ArrowReturnLeft','<path fill-rule="evenodd" d="M14.5 1.5a.5.5 0 0 1 .5.5v4.8a2.5 2.5 0 0 1-2.5 2.5H2.707l3.347 3.346a.5.5 0 0 1-.708.708l-4.2-4.2a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 8.3H12.5A1.5 1.5 0 0 0 14 6.8V2a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconArrowReturnRight=/*#__PURE__*/makeIcon('ArrowReturnRight','<path fill-rule="evenodd" d="M1.5 1.5A.5.5 0 0 0 1 2v4.8a2.5 2.5 0 0 0 2.5 2.5h9.793l-3.347 3.346a.5.5 0 0 0 .708.708l4.2-4.2a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 8.3H3.5A1.5 1.5 0 0 1 2 6.8V2a.5.5 0 0 0-.5-.5z"/>');// eslint-disable-next-line
var BIconArrowRight=/*#__PURE__*/makeIcon('ArrowRight','<path fill-rule="evenodd" d="M1 8a.5.5 0 0 1 .5-.5h11.793l-3.147-3.146a.5.5 0 0 1 .708-.708l4 4a.5.5 0 0 1 0 .708l-4 4a.5.5 0 0 1-.708-.708L13.293 8.5H1.5A.5.5 0 0 1 1 8z"/>');// eslint-disable-next-line
var BIconArrowRightCircle=/*#__PURE__*/makeIcon('ArrowRightCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.5 7.5a.5.5 0 0 0 0 1h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H4.5z"/>');// eslint-disable-next-line
var BIconArrowRightCircleFill=/*#__PURE__*/makeIcon('ArrowRightCircleFill','<path d="M8 0a8 8 0 1 1 0 16A8 8 0 0 1 8 0zM4.5 7.5a.5.5 0 0 0 0 1h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H4.5z"/>');// eslint-disable-next-line
var BIconArrowRightShort=/*#__PURE__*/makeIcon('ArrowRightShort','<path fill-rule="evenodd" d="M4 8a.5.5 0 0 1 .5-.5h5.793L8.146 5.354a.5.5 0 1 1 .708-.708l3 3a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708-.708L10.293 8.5H4.5A.5.5 0 0 1 4 8z"/>');// eslint-disable-next-line
var BIconArrowRightSquare=/*#__PURE__*/makeIcon('ArrowRightSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.5 7.5a.5.5 0 0 0 0 1h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H4.5z"/>');// eslint-disable-next-line
var BIconArrowRightSquareFill=/*#__PURE__*/makeIcon('ArrowRightSquareFill','<path d="M0 14a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12zm4.5-6.5h5.793L8.146 5.354a.5.5 0 1 1 .708-.708l3 3a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708-.708L10.293 8.5H4.5a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconArrowUp=/*#__PURE__*/makeIcon('ArrowUp','<path fill-rule="evenodd" d="M8 15a.5.5 0 0 0 .5-.5V2.707l3.146 3.147a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 1 0 .708.708L7.5 2.707V14.5a.5.5 0 0 0 .5.5z"/>');// eslint-disable-next-line
var BIconArrowUpCircle=/*#__PURE__*/makeIcon('ArrowUpCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-7.5 3.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11.5z"/>');// eslint-disable-next-line
var BIconArrowUpCircleFill=/*#__PURE__*/makeIcon('ArrowUpCircleFill','<path d="M16 8A8 8 0 1 0 0 8a8 8 0 0 0 16 0zm-7.5 3.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11.5z"/>');// eslint-disable-next-line
var BIconArrowUpLeft=/*#__PURE__*/makeIcon('ArrowUpLeft','<path fill-rule="evenodd" d="M2 2.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1H3.707l10.147 10.146a.5.5 0 0 1-.708.708L3 3.707V8.5a.5.5 0 0 1-1 0v-6z"/>');// eslint-disable-next-line
var BIconArrowUpLeftCircle=/*#__PURE__*/makeIcon('ArrowUpLeftCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904 2.803a.5.5 0 1 0 .707-.707L6.707 6h2.768a.5.5 0 1 0 0-1H5.5a.5.5 0 0 0-.5.5v3.975a.5.5 0 0 0 1 0V6.707l4.096 4.096z"/>');// eslint-disable-next-line
var BIconArrowUpLeftCircleFill=/*#__PURE__*/makeIcon('ArrowUpLeftCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904 2.803a.5.5 0 1 0 .707-.707L6.707 6h2.768a.5.5 0 1 0 0-1H5.5a.5.5 0 0 0-.5.5v3.975a.5.5 0 0 0 1 0V6.707l4.096 4.096z"/>');// eslint-disable-next-line
var BIconArrowUpLeftSquare=/*#__PURE__*/makeIcon('ArrowUpLeftSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904 2.803a.5.5 0 1 0 .707-.707L6.707 6h2.768a.5.5 0 1 0 0-1H5.5a.5.5 0 0 0-.5.5v3.975a.5.5 0 0 0 1 0V6.707l4.096 4.096z"/>');// eslint-disable-next-line
var BIconArrowUpLeftSquareFill=/*#__PURE__*/makeIcon('ArrowUpLeftSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm8.096 10.803L6 6.707v2.768a.5.5 0 0 1-1 0V5.5a.5.5 0 0 1 .5-.5h3.975a.5.5 0 1 1 0 1H6.707l4.096 4.096a.5.5 0 1 1-.707.707z"/>');// eslint-disable-next-line
var BIconArrowUpRight=/*#__PURE__*/makeIcon('ArrowUpRight','<path fill-rule="evenodd" d="M14 2.5a.5.5 0 0 0-.5-.5h-6a.5.5 0 0 0 0 1h4.793L2.146 13.146a.5.5 0 0 0 .708.708L13 3.707V8.5a.5.5 0 0 0 1 0v-6z"/>');// eslint-disable-next-line
var BIconArrowUpRightCircle=/*#__PURE__*/makeIcon('ArrowUpRightCircle','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 10.803a.5.5 0 1 1-.708-.707L9.243 6H6.475a.5.5 0 1 1 0-1h3.975a.5.5 0 0 1 .5.5v3.975a.5.5 0 1 1-1 0V6.707l-4.096 4.096z"/>');// eslint-disable-next-line
var BIconArrowUpRightCircleFill=/*#__PURE__*/makeIcon('ArrowUpRightCircleFill','<path d="M0 8a8 8 0 1 0 16 0A8 8 0 0 0 0 8zm5.904 2.803a.5.5 0 1 1-.707-.707L9.293 6H6.525a.5.5 0 1 1 0-1H10.5a.5.5 0 0 1 .5.5v3.975a.5.5 0 0 1-1 0V6.707l-4.096 4.096z"/>');// eslint-disable-next-line
var BIconArrowUpRightSquare=/*#__PURE__*/makeIcon('ArrowUpRightSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 10.803a.5.5 0 1 1-.708-.707L9.243 6H6.475a.5.5 0 1 1 0-1h3.975a.5.5 0 0 1 .5.5v3.975a.5.5 0 1 1-1 0V6.707l-4.096 4.096z"/>');// eslint-disable-next-line
var BIconArrowUpRightSquareFill=/*#__PURE__*/makeIcon('ArrowUpRightSquareFill','<path d="M14 0a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12zM5.904 10.803L10 6.707v2.768a.5.5 0 0 0 1 0V5.5a.5.5 0 0 0-.5-.5H6.525a.5.5 0 1 0 0 1h2.768l-4.096 4.096a.5.5 0 0 0 .707.707z"/>');// eslint-disable-next-line
var BIconArrowUpShort=/*#__PURE__*/makeIcon('ArrowUpShort','<path fill-rule="evenodd" d="M8 12a.5.5 0 0 0 .5-.5V5.707l2.146 2.147a.5.5 0 0 0 .708-.708l-3-3a.5.5 0 0 0-.708 0l-3 3a.5.5 0 1 0 .708.708L7.5 5.707V11.5a.5.5 0 0 0 .5.5z"/>');// eslint-disable-next-line
var BIconArrowUpSquare=/*#__PURE__*/makeIcon('ArrowUpSquare','<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-7.5 3.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11.5z"/>');// eslint-disable-next-line
var BIconArrowUpSquareFill=/*#__PURE__*/makeIcon('ArrowUpSquareFill','<path d="M2 16a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2zm6.5-4.5V5.707l2.146 2.147a.5.5 0 0 0 .708-.708l-3-3a.5.5 0 0 0-.708 0l-3 3a.5.5 0 1 0 .708.708L7.5 5.707V11.5a.5.5 0 0 0 1 0z"/>');// eslint-disable-next-line
var BIconArrowsAngleContract=/*#__PURE__*/makeIcon('ArrowsAngleContract','<path fill-rule="evenodd" d="M.172 15.828a.5.5 0 0 0 .707 0l4.096-4.096V14.5a.5.5 0 1 0 1 0v-3.975a.5.5 0 0 0-.5-.5H1.5a.5.5 0 0 0 0 1h2.768L.172 15.121a.5.5 0 0 0 0 .707zM15.828.172a.5.5 0 0 0-.707 0l-4.096 4.096V1.5a.5.5 0 1 0-1 0v3.975a.5.5 0 0 0 .5.5H14.5a.5.5 0 0 0 0-1h-2.768L15.828.879a.5.5 0 0 0 0-.707z"/>');// eslint-disable-next-line
var BIconArrowsAngleExpand=/*#__PURE__*/makeIcon('ArrowsAngleExpand','<path fill-rule="evenodd" d="M5.828 10.172a.5.5 0 0 0-.707 0l-4.096 4.096V11.5a.5.5 0 0 0-1 0v3.975a.5.5 0 0 0 .5.5H4.5a.5.5 0 0 0 0-1H1.732l4.096-4.096a.5.5 0 0 0 0-.707zm4.344-4.344a.5.5 0 0 0 .707 0l4.096-4.096V4.5a.5.5 0 1 0 1 0V.525a.5.5 0 0 0-.5-.5H11.5a.5.5 0 0 0 0 1h2.768l-4.096 4.096a.5.5 0 0 0 0 .707z"/>');// eslint-disable-next-line
var BIconArrowsCollapse=/*#__PURE__*/makeIcon('ArrowsCollapse','<path fill-rule="evenodd" d="M1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8zm7-8a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 4.293V.5A.5.5 0 0 1 8 0zm-.5 11.707l-1.146 1.147a.5.5 0 0 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 11.707V15.5a.5.5 0 0 1-1 0v-3.793z"/>');// eslint-disable-next-line
var BIconArrowsExpand=/*#__PURE__*/makeIcon('ArrowsExpand','<path fill-rule="evenodd" d="M1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8zM7.646.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 1.707V5.5a.5.5 0 0 1-1 0V1.707L6.354 2.854a.5.5 0 1 1-.708-.708l2-2zM8 10a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 .708-.708L7.5 14.293V10.5A.5.5 0 0 1 8 10z"/>');// eslint-disable-next-line
var BIconArrowsFullscreen=/*#__PURE__*/makeIcon('ArrowsFullscreen','<path fill-rule="evenodd" d="M5.828 10.172a.5.5 0 0 0-.707 0l-4.096 4.096V11.5a.5.5 0 0 0-1 0v3.975a.5.5 0 0 0 .5.5H4.5a.5.5 0 0 0 0-1H1.732l4.096-4.096a.5.5 0 0 0 0-.707zm4.344 0a.5.5 0 0 1 .707 0l4.096 4.096V11.5a.5.5 0 1 1 1 0v3.975a.5.5 0 0 1-.5.5H11.5a.5.5 0 0 1 0-1h2.768l-4.096-4.096a.5.5 0 0 1 0-.707zm0-4.344a.5.5 0 0 0 .707 0l4.096-4.096V4.5a.5.5 0 1 0 1 0V.525a.5.5 0 0 0-.5-.5H11.5a.5.5 0 0 0 0 1h2.768l-4.096 4.096a.5.5 0 0 0 0 .707zm-4.344 0a.5.5 0 0 1-.707 0L1.025 1.732V4.5a.5.5 0 0 1-1 0V.525a.5.5 0 0 1 .5-.5H4.5a.5.5 0 0 1 0 1H1.732l4.096 4.096a.5.5 0 0 1 0 .707z"/>');// eslint-disable-next-line
var BIconArrowsMove=/*#__PURE__*/makeIcon('ArrowsMove','<path fill-rule="evenodd" d="M7.646.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 1.707V5.5a.5.5 0 0 1-1 0V1.707L6.354 2.854a.5.5 0 1 1-.708-.708l2-2zM8 10a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 .708-.708L7.5 14.293V10.5A.5.5 0 0 1 8 10zM.146 8.354a.5.5 0 0 1 0-.708l2-2a.5.5 0 1 1 .708.708L1.707 7.5H5.5a.5.5 0 0 1 0 1H1.707l1.147 1.146a.5.5 0 0 1-.708.708l-2-2zM10 8a.5.5 0 0 1 .5-.5h3.793l-1.147-1.146a.5.5 0 0 1 .708-.708l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L14.293 8.5H10.5A.5.5 0 0 1 10 8z"/>');// eslint-disable-next-line
var BIconAspectRatio=/*#__PURE__*/makeIcon('AspectRatio','<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5v-9zM1.5 3a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-13z"/><path d="M2 4.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1H3v2.5a.5.5 0 0 1-1 0v-3zm12 7a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1 0-1H13V8.5a.5.5 0 0 1 1 0v3z"/>');// eslint-disable-next-line
var BIconAspectRatioFill=/*#__PURE__*/makeIcon('AspectRatioFill','<path d="M0 12.5v-9A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5zM2.5 4a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 1 0V5h2.5a.5.5 0 0 0 0-1h-3zm11 8a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-1 0V11h-2.5a.5.5 0 0 0 0 1h3z"/>');// eslint-disable-next-line
var BIconAsterisk=/*#__PURE__*/makeIcon('Asterisk','<path d="M8 0a1 1 0 0 1 1 1v5.268l4.562-2.634a1 1 0 1 1 1 1.732L10 8l4.562 2.634a1 1 0 1 1-1 1.732L9 9.732V15a1 1 0 1 1-2 0V9.732l-4.562 2.634a1 1 0 1 1-1-1.732L6 8 1.438 5.366a1 1 0 0 1 1-1.732L7 6.268V1a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconAt=/*#__PURE__*/makeIcon('At','<path d="M13.106 7.222c0-2.967-2.249-5.032-5.482-5.032-3.35 0-5.646 2.318-5.646 5.702 0 3.493 2.235 5.708 5.762 5.708.862 0 1.689-.123 2.304-.335v-.862c-.43.199-1.354.328-2.29.328-2.926 0-4.813-1.88-4.813-4.798 0-2.844 1.921-4.881 4.594-4.881 2.735 0 4.608 1.688 4.608 4.156 0 1.682-.554 2.769-1.416 2.769-.492 0-.772-.28-.772-.76V5.206H8.923v.834h-.11c-.266-.595-.881-.964-1.6-.964-1.4 0-2.378 1.162-2.378 2.823 0 1.737.957 2.906 2.379 2.906.8 0 1.415-.39 1.709-1.087h.11c.081.67.703 1.148 1.503 1.148 1.572 0 2.57-1.415 2.57-3.643zm-7.177.704c0-1.197.54-1.907 1.456-1.907.93 0 1.524.738 1.524 1.907S8.308 9.84 7.371 9.84c-.895 0-1.442-.725-1.442-1.914z"/>');// eslint-disable-next-line
var BIconAward=/*#__PURE__*/makeIcon('Award','<path d="M9.669.864L8 0 6.331.864l-1.858.282-.842 1.68-1.337 1.32L2.6 6l-.306 1.854 1.337 1.32.842 1.68 1.858.282L8 12l1.669-.864 1.858-.282.842-1.68 1.337-1.32L13.4 6l.306-1.854-1.337-1.32-.842-1.68L9.669.864zm1.196 1.193l.684 1.365 1.086 1.072L12.387 6l.248 1.506-1.086 1.072-.684 1.365-1.51.229L8 10.874l-1.355-.702-1.51-.229-.684-1.365-1.086-1.072L3.614 6l-.25-1.506 1.087-1.072.684-1.365 1.51-.229L8 1.126l1.356.702 1.509.229z"/><path d="M4 11.794V16l4-1 4 1v-4.206l-2.018.306L8 13.126 6.018 12.1 4 11.794z"/>');// eslint-disable-next-line
var BIconAwardFill=/*#__PURE__*/makeIcon('AwardFill','<path d="M8 0l1.669.864 1.858.282.842 1.68 1.337 1.32L13.4 6l.306 1.854-1.337 1.32-.842 1.68-1.858.282L8 12l-1.669-.864-1.858-.282-.842-1.68-1.337-1.32L2.6 6l-.306-1.854 1.337-1.32.842-1.68L6.331.864 8 0z"/><path d="M4 11.794V16l4-1 4 1v-4.206l-2.018.306L8 13.126 6.018 12.1 4 11.794z"/>');// eslint-disable-next-line
var BIconBack=/*#__PURE__*/makeIcon('Back','<path fill-rule="evenodd" d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H2z"/>');// eslint-disable-next-line
var BIconBackspace=/*#__PURE__*/makeIcon('Backspace','<path d="M5.83 5.146a.5.5 0 0 0 0 .708L7.975 8l-2.147 2.146a.5.5 0 0 0 .707.708l2.147-2.147 2.146 2.147a.5.5 0 0 0 .707-.708L9.39 8l2.146-2.146a.5.5 0 0 0-.707-.708L8.683 7.293 6.536 5.146a.5.5 0 0 0-.707 0z"/><path d="M13.683 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-7.08a2 2 0 0 1-1.519-.698L.241 8.65a1 1 0 0 1 0-1.302L5.084 1.7A2 2 0 0 1 6.603 1h7.08zm-7.08 1a1 1 0 0 0-.76.35L1 8l4.844 5.65a1 1 0 0 0 .759.35h7.08a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1h-7.08z"/>');// eslint-disable-next-line
var BIconBackspaceFill=/*#__PURE__*/makeIcon('BackspaceFill','<path d="M15.683 3a2 2 0 0 0-2-2h-7.08a2 2 0 0 0-1.519.698L.241 7.35a1 1 0 0 0 0 1.302l4.843 5.65A2 2 0 0 0 6.603 15h7.08a2 2 0 0 0 2-2V3zM5.829 5.854a.5.5 0 1 1 .707-.708l2.147 2.147 2.146-2.147a.5.5 0 1 1 .707.708L9.39 8l2.146 2.146a.5.5 0 0 1-.707.708L8.683 8.707l-2.147 2.147a.5.5 0 0 1-.707-.708L7.976 8 5.829 5.854z"/>');// eslint-disable-next-line
var BIconBackspaceReverse=/*#__PURE__*/makeIcon('BackspaceReverse','<path d="M9.854 5.146a.5.5 0 0 1 0 .708L7.707 8l2.147 2.146a.5.5 0 0 1-.708.708L7 8.707l-2.146 2.147a.5.5 0 0 1-.708-.708L6.293 8 4.146 5.854a.5.5 0 1 1 .708-.708L7 7.293l2.146-2.147a.5.5 0 0 1 .708 0z"/><path d="M2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h7.08a2 2 0 0 0 1.519-.698l4.843-5.651a1 1 0 0 0 0-1.302L10.6 1.7A2 2 0 0 0 9.08 1H2zm7.08 1a1 1 0 0 1 .76.35L14.682 8l-4.844 5.65a1 1 0 0 1-.759.35H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h7.08z"/>');// eslint-disable-next-line
var BIconBackspaceReverseFill=/*#__PURE__*/makeIcon('BackspaceReverseFill','<path d="M0 3a2 2 0 0 1 2-2h7.08a2 2 0 0 1 1.519.698l4.843 5.651a1 1 0 0 1 0 1.302L10.6 14.3a2 2 0 0 1-1.52.7H2a2 2 0 0 1-2-2V3zm9.854 2.854a.5.5 0 0 0-.708-.708L7 7.293 4.854 5.146a.5.5 0 1 0-.708.708L6.293 8l-2.147 2.146a.5.5 0 0 0 .708.708L7 8.707l2.146 2.147a.5.5 0 0 0 .708-.708L7.707 8l2.147-2.146z"/>');// eslint-disable-next-line
var BIconBadge4k=/*#__PURE__*/makeIcon('Badge4k','<path d="M4.807 5.001C4.021 6.298 3.203 7.6 2.5 8.917v.971h2.905V11h1.112V9.888h.733V8.93h-.733V5.001h-1.71zm-1.23 3.93v-.032a46.781 46.781 0 0 1 1.766-3.001h.062V8.93H3.577zm9.831-3.93h-1.306L9.835 7.687h-.057V5H8.59v6h1.187V9.075l.615-.699L12.072 11H13.5l-2.232-3.415 2.14-2.584z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconBadge4kFill=/*#__PURE__*/makeIcon('Badge4kFill','<path d="M3.577 8.9v.03h1.828V5.898h-.062a46.781 46.781 0 0 0-1.766 3.001z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm2.372 3.715l.435-.714h1.71v3.93h.733v.957h-.733V11H5.405V9.888H2.5v-.971c.574-1.077 1.225-2.142 1.872-3.202zm7.73-.714h1.306l-2.14 2.584L13.5 11h-1.428l-1.679-2.624-.615.7V11H8.59V5.001h1.187v2.686h.057L12.102 5z"/>');// eslint-disable-next-line
var BIconBadge8k=/*#__PURE__*/makeIcon('Badge8k','<path d="M4.837 11.114c1.406 0 2.333-.725 2.333-1.766 0-.945-.712-1.38-1.256-1.49v-.053c.496-.15 1.02-.55 1.02-1.331 0-.914-.831-1.587-2.084-1.587-1.257 0-2.087.673-2.087 1.587 0 .773.51 1.177 1.02 1.331v.053c-.546.11-1.258.54-1.258 1.494 0 1.042.906 1.762 2.312 1.762zm.013-3.643c-.545 0-.95-.356-.95-.866s.405-.852.95-.852c.545 0 .945.343.945.852 0 .51-.4.866-.945.866zm0 2.786c-.65 0-1.142-.395-1.142-.984S4.2 8.28 4.85 8.28c.646 0 1.143.404 1.143.993s-.497.984-1.143.984zM13.408 5h-1.306L9.835 7.685h-.057V5H8.59v5.998h1.187V9.075l.615-.699 1.679 2.623H13.5l-2.232-3.414L13.408 5z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconBadge8kFill=/*#__PURE__*/makeIcon('Badge8kFill','<path d="M3.9 6.605c0 .51.405.866.95.866.545 0 .945-.356.945-.866s-.4-.852-.945-.852c-.545 0-.95.343-.95.852zm-.192 2.668c0 .589.492.984 1.142.984.646 0 1.143-.395 1.143-.984S5.496 8.28 4.85 8.28c-.65 0-1.142.404-1.142.993z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm5.17 7.348c0 1.041-.927 1.766-2.333 1.766-1.406 0-2.312-.72-2.312-1.762 0-.954.712-1.384 1.257-1.494v-.053c-.51-.154-1.02-.558-1.02-1.331 0-.914.831-1.587 2.088-1.587 1.253 0 2.083.673 2.083 1.587 0 .782-.523 1.182-1.02 1.331v.053c.545.11 1.257.545 1.257 1.49zM12.102 5h1.306l-2.14 2.584 2.232 3.415h-1.428l-1.679-2.624-.615.699v1.925H8.59V5h1.187v2.685h.057L12.102 5z"/>');// eslint-disable-next-line
var BIconBadgeAd=/*#__PURE__*/makeIcon('BadgeAd','<path d="M3.7 11l.47-1.542h2.004L6.644 11h1.261L5.901 5.001H4.513L2.5 11h1.2zm1.503-4.852l.734 2.426H4.416l.734-2.426h.053zm4.759.128c-1.059 0-1.753.765-1.753 2.043v.695c0 1.279.685 2.043 1.74 2.043.677 0 1.222-.33 1.367-.804h.057V11h1.138V4.685h-1.16v2.36h-.053c-.18-.475-.68-.77-1.336-.77zm.387.923c.58 0 1.002.44 1.002 1.138v.602c0 .76-.396 1.2-.984 1.2-.598 0-.972-.449-.972-1.248v-.453c0-.795.37-1.24.954-1.24z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconBadgeAdFill=/*#__PURE__*/makeIcon('BadgeAdFill','<path d="M11.35 8.337c0-.699-.42-1.138-1.001-1.138-.584 0-.954.444-.954 1.239v.453c0 .8.374 1.248.972 1.248.588 0 .984-.44.984-1.2v-.602zm-5.413.237l-.734-2.426H5.15l-.734 2.426h1.52z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm6.209 6.32c0-1.28.694-2.044 1.753-2.044.655 0 1.156.294 1.336.769h.053v-2.36h1.16V11h-1.138v-.747h-.057c-.145.474-.69.804-1.367.804-1.055 0-1.74-.764-1.74-2.043v-.695zm-4.04 1.138L3.7 11H2.5l2.013-5.999H5.9L7.905 11H6.644l-.47-1.542H4.17z"/>');// eslint-disable-next-line
var BIconBadgeCc=/*#__PURE__*/makeIcon('BadgeCc','<path d="M3.708 7.755c0-1.111.488-1.753 1.319-1.753.681 0 1.138.47 1.186 1.107H7.36V7c-.052-1.186-1.024-2-2.342-2C3.414 5 2.5 6.05 2.5 7.751v.747c0 1.7.905 2.73 2.518 2.73 1.314 0 2.285-.792 2.342-1.939v-.114H6.213c-.048.615-.496 1.05-1.186 1.05-.84 0-1.319-.62-1.319-1.727v-.743zm6.14 0c0-1.111.488-1.753 1.318-1.753.682 0 1.139.47 1.187 1.107H13.5V7c-.053-1.186-1.024-2-2.342-2C9.554 5 8.64 6.05 8.64 7.751v.747c0 1.7.905 2.73 2.518 2.73 1.314 0 2.285-.792 2.342-1.939v-.114h-1.147c-.048.615-.497 1.05-1.187 1.05-.839 0-1.318-.62-1.318-1.727v-.743z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconBadgeCcFill=/*#__PURE__*/makeIcon('BadgeCcFill','<path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm3.027 4.002c-.83 0-1.319.642-1.319 1.753v.743c0 1.107.48 1.727 1.319 1.727.69 0 1.138-.435 1.186-1.05H7.36v.114c-.057 1.147-1.028 1.938-2.342 1.938-1.613 0-2.518-1.028-2.518-2.729v-.747C2.5 6.051 3.414 5 5.018 5c1.318 0 2.29.813 2.342 2v.11H6.213c-.048-.638-.505-1.108-1.186-1.108zm6.14 0c-.831 0-1.319.642-1.319 1.753v.743c0 1.107.48 1.727 1.318 1.727.69 0 1.139-.435 1.187-1.05H13.5v.114c-.057 1.147-1.028 1.938-2.342 1.938-1.613 0-2.518-1.028-2.518-2.729v-.747c0-1.7.914-2.751 2.518-2.751 1.318 0 2.29.813 2.342 2v.11h-1.147c-.048-.638-.505-1.108-1.187-1.108z"/>');// eslint-disable-next-line
var BIconBadgeHd=/*#__PURE__*/makeIcon('BadgeHd','<path d="M7.396 11V5.001H6.209v2.44H3.687V5H2.5v6h1.187V8.43h2.522V11h1.187zM8.5 5.001V11h2.188c1.811 0 2.685-1.107 2.685-3.015 0-1.894-.86-2.984-2.684-2.984H8.5zm1.187.967h.843c1.112 0 1.622.686 1.622 2.04 0 1.353-.505 2.02-1.622 2.02h-.843v-4.06z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconBadgeHdFill=/*#__PURE__*/makeIcon('BadgeHdFill','<path d="M10.53 5.968h-.843v4.06h.843c1.117 0 1.622-.667 1.622-2.02 0-1.354-.51-2.04-1.622-2.04z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm5.396 3.001V11H6.209V8.43H3.687V11H2.5V5.001h1.187v2.44h2.522V5h1.187zM8.5 11V5.001h2.188c1.824 0 2.685 1.09 2.685 2.984C13.373 9.893 12.5 11 10.69 11H8.5z"/>');// eslint-disable-next-line
var BIconBadgeTm=/*#__PURE__*/makeIcon('BadgeTm','<path d="M5.295 11V5.995H7V5H2.403v.994h1.701V11h1.19zm3.397 0V7.01h.058l1.428 3.239h.773l1.42-3.24h.057V11H13.5V5.001h-1.2l-1.71 3.894h-.039l-1.71-3.894H7.634V11h1.06z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconBadgeTmFill=/*#__PURE__*/makeIcon('BadgeTmFill','<path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm3.295 3.995V11H4.104V5.995h-1.7V5H7v.994H5.295zM8.692 7.01V11H7.633V5.001h1.209l1.71 3.894h.039l1.71-3.894H13.5V11h-1.072V7.01h-.057l-1.42 3.239h-.773L8.75 7.008h-.058z"/>');// eslint-disable-next-line
var BIconBadgeVo=/*#__PURE__*/makeIcon('BadgeVo','<path d="M4.508 11h1.429l1.99-5.999H6.61L5.277 9.708H5.22L3.875 5.001H2.5L4.508 11zM13.5 8.39v-.77c0-1.696-.962-2.733-2.566-2.733-1.604 0-2.571 1.029-2.571 2.734v.769c0 1.691.967 2.724 2.57 2.724 1.605 0 2.567-1.033 2.567-2.724zm-1.204-.778v.782c0 1.156-.571 1.732-1.362 1.732-.796 0-1.363-.576-1.363-1.732v-.782c0-1.156.567-1.736 1.363-1.736.79 0 1.362.58 1.362 1.736z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconBadgeVoFill=/*#__PURE__*/makeIcon('BadgeVoFill','<path d="M12.296 8.394v-.782c0-1.156-.571-1.736-1.362-1.736-.796 0-1.363.58-1.363 1.736v.782c0 1.156.567 1.732 1.363 1.732.79 0 1.362-.576 1.362-1.732z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm11.5 5.62v.77c0 1.691-.962 2.724-2.566 2.724-1.604 0-2.571-1.033-2.571-2.724v-.77c0-1.704.967-2.733 2.57-2.733 1.605 0 2.567 1.037 2.567 2.734zM5.937 11H4.508L2.5 5.001h1.375L5.22 9.708h.057L6.61 5.001h1.318L5.937 11z"/>');// eslint-disable-next-line
var BIconBag=/*#__PURE__*/makeIcon('Bag','<path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>');// eslint-disable-next-line
var BIconBagCheck=/*#__PURE__*/makeIcon('BagCheck','<path fill-rule="evenodd" d="M10.854 8.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L7.5 10.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>');// eslint-disable-next-line
var BIconBagCheckFill=/*#__PURE__*/makeIcon('BagCheckFill','<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zm-.646 5.354a.5.5 0 0 0-.708-.708L7.5 10.793 6.354 9.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/>');// eslint-disable-next-line
var BIconBagDash=/*#__PURE__*/makeIcon('BagDash','<path fill-rule="evenodd" d="M5.5 10a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>');// eslint-disable-next-line
var BIconBagDashFill=/*#__PURE__*/makeIcon('BagDashFill','<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zM6 9.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H6z"/>');// eslint-disable-next-line
var BIconBagFill=/*#__PURE__*/makeIcon('BagFill','<path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5z"/>');// eslint-disable-next-line
var BIconBagPlus=/*#__PURE__*/makeIcon('BagPlus','<path fill-rule="evenodd" d="M8 7.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V12a.5.5 0 0 1-1 0v-1.5H6a.5.5 0 0 1 0-1h1.5V8a.5.5 0 0 1 .5-.5z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>');// eslint-disable-next-line
var BIconBagPlusFill=/*#__PURE__*/makeIcon('BagPlusFill','<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zM8.5 8a.5.5 0 0 0-1 0v1.5H6a.5.5 0 0 0 0 1h1.5V12a.5.5 0 0 0 1 0v-1.5H10a.5.5 0 0 0 0-1H8.5V8z"/>');// eslint-disable-next-line
var BIconBagX=/*#__PURE__*/makeIcon('BagX','<path fill-rule="evenodd" d="M6.146 8.146a.5.5 0 0 1 .708 0L8 9.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 10l1.147 1.146a.5.5 0 0 1-.708.708L8 10.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 10 6.146 8.854a.5.5 0 0 1 0-.708z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>');// eslint-disable-next-line
var BIconBagXFill=/*#__PURE__*/makeIcon('BagXFill','<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zM6.854 8.146a.5.5 0 1 0-.708.708L7.293 10l-1.147 1.146a.5.5 0 0 0 .708.708L8 10.707l1.146 1.147a.5.5 0 0 0 .708-.708L8.707 10l1.147-1.146a.5.5 0 0 0-.708-.708L8 9.293 6.854 8.146z"/>');// eslint-disable-next-line
var BIconBarChart=/*#__PURE__*/makeIcon('BarChart','<path d="M4 11H2v3h2v-3zm5-4H7v7h2V7zm5-5v12h-2V2h2zm-2-1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2zM6 7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V7zm-5 4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-3z"/>');// eslint-disable-next-line
var BIconBarChartFill=/*#__PURE__*/makeIcon('BarChartFill','<path d="M1 11a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-3zm5-4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V7zm5-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V2z"/>');// eslint-disable-next-line
var BIconBarChartLine=/*#__PURE__*/makeIcon('BarChartLine','<path d="M11 2a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1v-3a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3h1V7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7h1V2zm1 12h2V2h-2v12zm-3 0V7H7v7h2zm-5 0v-3H2v3h2z"/>');// eslint-disable-next-line
var BIconBarChartLineFill=/*#__PURE__*/makeIcon('BarChartLineFill','<path d="M11 2a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1v-3a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3h1V7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7h1V2z"/>');// eslint-disable-next-line
var BIconBarChartSteps=/*#__PURE__*/makeIcon('BarChartSteps','<path d="M.5 0a.5.5 0 0 1 .5.5v15a.5.5 0 0 1-1 0V.5A.5.5 0 0 1 .5 0zM2 1.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-4a.5.5 0 0 1-.5-.5v-1zm2 4a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zm2 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-6a.5.5 0 0 1-.5-.5v-1zm2 4a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1z"/>');// eslint-disable-next-line
var BIconBasket=/*#__PURE__*/makeIcon('Basket','<path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1v4.5a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 13.5V9a1 1 0 0 1-1-1V7a1 1 0 0 1 1-1h1.217L5.07 1.243a.5.5 0 0 1 .686-.172zM2 9v4.5A1.5 1.5 0 0 0 3.5 15h9a1.5 1.5 0 0 0 1.5-1.5V9H2zM1 7v1h14V7H1zm3 3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3A.5.5 0 0 1 4 10zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3A.5.5 0 0 1 6 10zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3A.5.5 0 0 1 8 10zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 1 .5-.5zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconBasket2=/*#__PURE__*/makeIcon('Basket2','<path d="M4 10a1 1 0 0 1 2 0v2a1 1 0 0 1-2 0v-2zm3 0a1 1 0 0 1 2 0v2a1 1 0 0 1-2 0v-2zm3 0a1 1 0 1 1 2 0v2a1 1 0 0 1-2 0v-2z"/><path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-.623l-1.844 6.456a.75.75 0 0 1-.722.544H3.69a.75.75 0 0 1-.722-.544L1.123 8H.5a.5.5 0 0 1-.5-.5v-1A.5.5 0 0 1 .5 6h1.717L5.07 1.243a.5.5 0 0 1 .686-.172zM2.163 8l1.714 6h8.246l1.714-6H2.163z"/>');// eslint-disable-next-line
var BIconBasket2Fill=/*#__PURE__*/makeIcon('Basket2Fill','<path d="M5.929 1.757a.5.5 0 1 0-.858-.514L2.217 6H.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h.623l1.844 6.456A.75.75 0 0 0 3.69 15h8.622a.75.75 0 0 0 .722-.544L14.877 8h.623a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1.717L10.93 1.243a.5.5 0 1 0-.858.514L12.617 6H3.383L5.93 1.757zM4 10a1 1 0 0 1 2 0v2a1 1 0 1 1-2 0v-2zm3 0a1 1 0 0 1 2 0v2a1 1 0 1 1-2 0v-2zm4-1a1 1 0 0 1 1 1v2a1 1 0 1 1-2 0v-2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconBasket3=/*#__PURE__*/makeIcon('Basket3','<path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-1A.5.5 0 0 1 .5 6h1.717L5.07 1.243a.5.5 0 0 1 .686-.172zM3.394 15l-1.48-6h-.97l1.525 6.426a.75.75 0 0 0 .729.574h9.606a.75.75 0 0 0 .73-.574L15.056 9h-.972l-1.479 6h-9.21z"/>');// eslint-disable-next-line
var BIconBasket3Fill=/*#__PURE__*/makeIcon('Basket3Fill','<path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-1A.5.5 0 0 1 .5 6h1.717L5.07 1.243a.5.5 0 0 1 .686-.172zM2.468 15.426L.943 9h14.114l-1.525 6.426a.75.75 0 0 1-.729.574H3.197a.75.75 0 0 1-.73-.574z"/>');// eslint-disable-next-line
var BIconBasketFill=/*#__PURE__*/makeIcon('BasketFill','<path d="M5.071 1.243a.5.5 0 0 1 .858.514L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5H15v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V9H.5a.5.5 0 0 1-.5-.5v-2A.5.5 0 0 1 .5 6h1.717L5.07 1.243zM3.5 10.5a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3z"/>');// eslint-disable-next-line
var BIconBattery=/*#__PURE__*/makeIcon('Battery','<path d="M0 6a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V6zm2-1a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1H2zm14 3a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>');// eslint-disable-next-line
var BIconBatteryCharging=/*#__PURE__*/makeIcon('BatteryCharging','<path d="M9.585 2.568a.5.5 0 0 1 .226.58L8.677 6.832h1.99a.5.5 0 0 1 .364.843l-5.334 5.667a.5.5 0 0 1-.842-.49L5.99 9.167H4a.5.5 0 0 1-.364-.843l5.333-5.667a.5.5 0 0 1 .616-.09z"/><path d="M2 4h4.332l-.94 1H2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h2.38l-.308 1H2a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2z"/><path d="M2 6h2.45L2.908 7.639A1.5 1.5 0 0 0 3.313 10H2V6zm8.595-2l-.308 1H12a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H9.276l-.942 1H12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-1.405z"/><path d="M12 10h-1.783l1.542-1.639c.097-.103.178-.218.241-.34V10zm0-3.354V6h-.646a1.5 1.5 0 0 1 .646.646zM16 8a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>');// eslint-disable-next-line
var BIconBatteryFull=/*#__PURE__*/makeIcon('BatteryFull','<path d="M2 6h10v4H2V6z"/><path d="M2 4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H2zm10 1a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h10zm4 3a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>');// eslint-disable-next-line
var BIconBatteryHalf=/*#__PURE__*/makeIcon('BatteryHalf','<path d="M2 6h5v4H2V6z"/><path d="M2 4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H2zm10 1a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h10zm4 3a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>');// eslint-disable-next-line
var BIconBell=/*#__PURE__*/makeIcon('Bell','<path d="M8 16a2 2 0 0 0 2-2H6a2 2 0 0 0 2 2zM8 1.918l-.797.161A4.002 4.002 0 0 0 4 6c0 .628-.134 2.197-.459 3.742-.16.767-.376 1.566-.663 2.258h10.244c-.287-.692-.502-1.49-.663-2.258C12.134 8.197 12 6.628 12 6a4.002 4.002 0 0 0-3.203-3.92L8 1.917zM14.22 12c.223.447.481.801.78 1H1c.299-.199.557-.553.78-1C2.68 10.2 3 6.88 3 6c0-2.42 1.72-4.44 4.005-4.901a1 1 0 1 1 1.99 0A5.002 5.002 0 0 1 13 6c0 .88.32 4.2 1.22 6z"/>');// eslint-disable-next-line
var BIconBellFill=/*#__PURE__*/makeIcon('BellFill','<path d="M8 16a2 2 0 0 0 2-2H6a2 2 0 0 0 2 2zm.995-14.901a1 1 0 1 0-1.99 0A5.002 5.002 0 0 0 3 6c0 1.098-.5 6-2 7h14c-1.5-1-2-5.902-2-7 0-2.42-1.72-4.44-4.005-4.901z"/>');// eslint-disable-next-line
var BIconBezier=/*#__PURE__*/makeIcon('Bezier','<path fill-rule="evenodd" d="M0 10.5A1.5 1.5 0 0 1 1.5 9h1A1.5 1.5 0 0 1 4 10.5v1A1.5 1.5 0 0 1 2.5 13h-1A1.5 1.5 0 0 1 0 11.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm10.5.5A1.5 1.5 0 0 1 13.5 9h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM6 4.5A1.5 1.5 0 0 1 7.5 3h1A1.5 1.5 0 0 1 10 4.5v1A1.5 1.5 0 0 1 8.5 7h-1A1.5 1.5 0 0 1 6 5.5v-1zM7.5 4a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/><path d="M6 4.5H1.866a1 1 0 1 0 0 1h2.668A6.517 6.517 0 0 0 1.814 9H2.5c.123 0 .244.015.358.043a5.517 5.517 0 0 1 3.185-3.185A1.503 1.503 0 0 1 6 5.5v-1zm3.957 1.358A1.5 1.5 0 0 0 10 5.5v-1h4.134a1 1 0 1 1 0 1h-2.668a6.517 6.517 0 0 1 2.72 3.5H13.5c-.123 0-.243.015-.358.043a5.517 5.517 0 0 0-3.185-3.185z"/>');// eslint-disable-next-line
var BIconBezier2=/*#__PURE__*/makeIcon('Bezier2','<path fill-rule="evenodd" d="M1 2.5A1.5 1.5 0 0 1 2.5 1h1A1.5 1.5 0 0 1 5 2.5h4.134a1 1 0 1 1 0 1h-2.01c.18.18.34.381.484.605.638.992.892 2.354.892 3.895 0 1.993.257 3.092.713 3.7.356.476.895.721 1.787.784A1.5 1.5 0 0 1 12.5 11h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5H6.866a1 1 0 1 1 0-1h1.711a2.839 2.839 0 0 1-.165-.2C7.743 11.407 7.5 10.007 7.5 8c0-1.46-.246-2.597-.733-3.355-.39-.605-.952-1-1.767-1.112A1.5 1.5 0 0 1 3.5 5h-1A1.5 1.5 0 0 1 1 3.5v-1zM2.5 2a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm10 10a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>');// eslint-disable-next-line
var BIconBicycle=/*#__PURE__*/makeIcon('Bicycle','<path d="M4 4.5a.5.5 0 0 1 .5-.5H6a.5.5 0 0 1 0 1v.5h4.14l.386-1.158A.5.5 0 0 1 11 4h1a.5.5 0 0 1 0 1h-.64l-.311.935.807 1.29a3 3 0 1 1-.848.53l-.508-.812-2.076 3.322A.5.5 0 0 1 8 10.5H5.959a3 3 0 1 1-1.815-3.274L5 5.856V5h-.5a.5.5 0 0 1-.5-.5zm1.5 2.443l-.508.814c.5.444.85 1.054.967 1.743h1.139L5.5 6.943zM8 9.057L9.598 6.5H6.402L8 9.057zM4.937 9.5a1.997 1.997 0 0 0-.487-.877l-.548.877h1.035zM3.603 8.092A2 2 0 1 0 4.937 10.5H3a.5.5 0 0 1-.424-.765l1.027-1.643zm7.947.53a2 2 0 1 0 .848-.53l1.026 1.643a.5.5 0 1 1-.848.53L11.55 8.623z"/>');// eslint-disable-next-line
var BIconBinoculars=/*#__PURE__*/makeIcon('Binoculars','<path d="M3 2.5A1.5 1.5 0 0 1 4.5 1h1A1.5 1.5 0 0 1 7 2.5V5h2V2.5A1.5 1.5 0 0 1 10.5 1h1A1.5 1.5 0 0 1 13 2.5v2.382a.5.5 0 0 0 .276.447l.895.447A1.5 1.5 0 0 1 15 7.118V14.5a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 14.5v-3a.5.5 0 0 1 .146-.354l.854-.853V9.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v.793l.854.853A.5.5 0 0 1 7 11.5v3A1.5 1.5 0 0 1 5.5 16h-3A1.5 1.5 0 0 1 1 14.5V7.118a1.5 1.5 0 0 1 .83-1.342l.894-.447A.5.5 0 0 0 3 4.882V2.5zM4.5 2a.5.5 0 0 0-.5.5V3h2v-.5a.5.5 0 0 0-.5-.5h-1zM6 4H4v.882a1.5 1.5 0 0 1-.83 1.342l-.894.447A.5.5 0 0 0 2 7.118V13h4v-1.293l-.854-.853A.5.5 0 0 1 5 10.5v-1A1.5 1.5 0 0 1 6.5 8h3A1.5 1.5 0 0 1 11 9.5v1a.5.5 0 0 1-.146.354l-.854.853V13h4V7.118a.5.5 0 0 0-.276-.447l-.895-.447A1.5 1.5 0 0 1 12 4.882V4h-2v1.5a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5V4zm4-1h2v-.5a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5V3zm4 11h-4v.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5V14zm-8 0H2v.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5V14z"/>');// eslint-disable-next-line
var BIconBinocularsFill=/*#__PURE__*/makeIcon('BinocularsFill','<path d="M4.5 1A1.5 1.5 0 0 0 3 2.5V3h4v-.5A1.5 1.5 0 0 0 5.5 1h-1zM7 4v1h2V4h4v.882a.5.5 0 0 0 .276.447l.895.447A1.5 1.5 0 0 1 15 7.118V13H9v-1.5a.5.5 0 0 1 .146-.354l.854-.853V9.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v.793l.854.853A.5.5 0 0 1 7 11.5V13H1V7.118a1.5 1.5 0 0 1 .83-1.342l.894-.447A.5.5 0 0 0 3 4.882V4h4zM1 14v.5A1.5 1.5 0 0 0 2.5 16h3A1.5 1.5 0 0 0 7 14.5V14H1zm8 0v.5a1.5 1.5 0 0 0 1.5 1.5h3a1.5 1.5 0 0 0 1.5-1.5V14H9zm4-11H9v-.5A1.5 1.5 0 0 1 10.5 1h1A1.5 1.5 0 0 1 13 2.5V3z"/>');// eslint-disable-next-line
var BIconBlockquoteLeft=/*#__PURE__*/makeIcon('BlockquoteLeft','<path d="M2.5 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm5 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm0 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm-5 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm.79-5.373c.112-.078.26-.17.444-.275L3.524 6c-.122.074-.272.17-.452.287-.18.117-.35.26-.51.428a2.425 2.425 0 0 0-.398.562c-.11.207-.164.438-.164.692 0 .36.072.65.217.873.144.219.385.328.72.328.215 0 .383-.07.504-.211a.697.697 0 0 0 .188-.463c0-.23-.07-.404-.211-.521-.137-.121-.326-.182-.568-.182h-.282c.024-.203.065-.37.123-.498a1.38 1.38 0 0 1 .252-.37 1.94 1.94 0 0 1 .346-.298zm2.167 0c.113-.078.262-.17.445-.275L5.692 6c-.122.074-.272.17-.452.287-.18.117-.35.26-.51.428a2.425 2.425 0 0 0-.398.562c-.11.207-.164.438-.164.692 0 .36.072.65.217.873.144.219.385.328.72.328.215 0 .383-.07.504-.211a.697.697 0 0 0 .188-.463c0-.23-.07-.404-.211-.521-.137-.121-.326-.182-.568-.182h-.282a1.75 1.75 0 0 1 .118-.492c.058-.13.144-.254.257-.375a1.94 1.94 0 0 1 .346-.3z"/>');// eslint-disable-next-line
var BIconBlockquoteRight=/*#__PURE__*/makeIcon('BlockquoteRight','<path d="M2.5 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm0 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm0 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm0 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm10.113-5.373a6.59 6.59 0 0 0-.445-.275l.21-.352c.122.074.272.17.452.287.18.117.35.26.51.428.156.164.289.351.398.562.11.207.164.438.164.692 0 .36-.072.65-.216.873-.145.219-.385.328-.721.328-.215 0-.383-.07-.504-.211a.697.697 0 0 1-.188-.463c0-.23.07-.404.211-.521.137-.121.326-.182.569-.182h.281a1.686 1.686 0 0 0-.123-.498 1.379 1.379 0 0 0-.252-.37 1.94 1.94 0 0 0-.346-.298zm-2.168 0A6.59 6.59 0 0 0 10 6.352L10.21 6c.122.074.272.17.452.287.18.117.35.26.51.428.156.164.289.351.398.562.11.207.164.438.164.692 0 .36-.072.65-.216.873-.145.219-.385.328-.721.328-.215 0-.383-.07-.504-.211a.697.697 0 0 1-.188-.463c0-.23.07-.404.211-.521.137-.121.327-.182.569-.182h.281a1.749 1.749 0 0 0-.117-.492 1.402 1.402 0 0 0-.258-.375 1.94 1.94 0 0 0-.346-.3z"/>');// eslint-disable-next-line
var BIconBook=/*#__PURE__*/makeIcon('Book','<path d="M1 2.828c.885-.37 2.154-.769 3.388-.893 1.33-.134 2.458.063 3.112.752v9.746c-.935-.53-2.12-.603-3.213-.493-1.18.12-2.37.461-3.287.811V2.828zm7.5-.141c.654-.689 1.782-.886 3.112-.752 1.234.124 2.503.523 3.388.893v9.923c-.918-.35-2.107-.692-3.287-.81-1.094-.111-2.278-.039-3.213.492V2.687zM8 1.783C7.015.936 5.587.81 4.287.94c-1.514.153-3.042.672-3.994 1.105A.5.5 0 0 0 0 2.5v11a.5.5 0 0 0 .707.455c.882-.4 2.303-.881 3.68-1.02 1.409-.142 2.59.087 3.223.877a.5.5 0 0 0 .78 0c.633-.79 1.814-1.019 3.222-.877 1.378.139 2.8.62 3.681 1.02A.5.5 0 0 0 16 13.5v-11a.5.5 0 0 0-.293-.455c-.952-.433-2.48-.952-3.994-1.105C10.413.809 8.985.936 8 1.783z"/>');// eslint-disable-next-line
var BIconBookFill=/*#__PURE__*/makeIcon('BookFill','<path d="M8 1.783C7.015.936 5.587.81 4.287.94c-1.514.153-3.042.672-3.994 1.105A.5.5 0 0 0 0 2.5v11a.5.5 0 0 0 .707.455c.882-.4 2.303-.881 3.68-1.02 1.409-.142 2.59.087 3.223.877a.5.5 0 0 0 .78 0c.633-.79 1.814-1.019 3.222-.877 1.378.139 2.8.62 3.681 1.02A.5.5 0 0 0 16 13.5v-11a.5.5 0 0 0-.293-.455c-.952-.433-2.48-.952-3.994-1.105C10.413.809 8.985.936 8 1.783z"/>');// eslint-disable-next-line
var BIconBookHalf=/*#__PURE__*/makeIcon('BookHalf','<path d="M8.5 2.687c.654-.689 1.782-.886 3.112-.752 1.234.124 2.503.523 3.388.893v9.923c-.918-.35-2.107-.692-3.287-.81-1.094-.111-2.278-.039-3.213.492V2.687zM8 1.783C7.015.936 5.587.81 4.287.94c-1.514.153-3.042.672-3.994 1.105A.5.5 0 0 0 0 2.5v11a.5.5 0 0 0 .707.455c.882-.4 2.303-.881 3.68-1.02 1.409-.142 2.59.087 3.223.877a.5.5 0 0 0 .78 0c.633-.79 1.814-1.019 3.222-.877 1.378.139 2.8.62 3.681 1.02A.5.5 0 0 0 16 13.5v-11a.5.5 0 0 0-.293-.455c-.952-.433-2.48-.952-3.994-1.105C10.413.809 8.985.936 8 1.783z"/>');// eslint-disable-next-line
var BIconBookmark=/*#__PURE__*/makeIcon('Bookmark','<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconBookmarkCheck=/*#__PURE__*/makeIcon('BookmarkCheck','<path fill-rule="evenodd" d="M10.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconBookmarkCheckFill=/*#__PURE__*/makeIcon('BookmarkCheckFill','<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zm8.854-9.646a.5.5 0 0 0-.708-.708L7.5 7.793 6.354 6.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/>');// eslint-disable-next-line
var BIconBookmarkDash=/*#__PURE__*/makeIcon('BookmarkDash','<path fill-rule="evenodd" d="M5.5 6.5A.5.5 0 0 1 6 6h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconBookmarkDashFill=/*#__PURE__*/makeIcon('BookmarkDashFill','<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zM6 6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H6z"/>');// eslint-disable-next-line
var BIconBookmarkFill=/*#__PURE__*/makeIcon('BookmarkFill','<path d="M2 2v13.5a.5.5 0 0 0 .74.439L8 13.069l5.26 2.87A.5.5 0 0 0 14 15.5V2a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2z"/>');// eslint-disable-next-line
var BIconBookmarkHeart=/*#__PURE__*/makeIcon('BookmarkHeart','<path fill-rule="evenodd" d="M8 4.41c1.387-1.425 4.854 1.07 0 4.277C3.146 5.48 6.613 2.986 8 4.412z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconBookmarkHeartFill=/*#__PURE__*/makeIcon('BookmarkHeartFill','<path d="M2 15.5a.5.5 0 0 0 .74.439L8 13.069l5.26 2.87A.5.5 0 0 0 14 15.5V2a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v13.5zM8 4.41c1.387-1.425 4.854 1.07 0 4.277C3.146 5.48 6.613 2.986 8 4.412z"/>');// eslint-disable-next-line
var BIconBookmarkPlus=/*#__PURE__*/makeIcon('BookmarkPlus','<path fill-rule="evenodd" d="M8 4a.5.5 0 0 1 .5.5V6H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V7H6a.5.5 0 0 1 0-1h1.5V4.5A.5.5 0 0 1 8 4z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconBookmarkPlusFill=/*#__PURE__*/makeIcon('BookmarkPlusFill','<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zm6.5-11a.5.5 0 0 0-1 0V6H6a.5.5 0 0 0 0 1h1.5v1.5a.5.5 0 0 0 1 0V7H10a.5.5 0 0 0 0-1H8.5V4.5z"/>');// eslint-disable-next-line
var BIconBookmarkStar=/*#__PURE__*/makeIcon('BookmarkStar','<path d="M7.84 4.1a.178.178 0 0 1 .32 0l.634 1.285a.178.178 0 0 0 .134.098l1.42.206c.145.021.204.2.098.303L9.42 6.993a.178.178 0 0 0-.051.158l.242 1.414a.178.178 0 0 1-.258.187l-1.27-.668a.178.178 0 0 0-.165 0l-1.27.668a.178.178 0 0 1-.257-.187l.242-1.414a.178.178 0 0 0-.05-.158l-1.03-1.001a.178.178 0 0 1 .098-.303l1.42-.206a.178.178 0 0 0 .134-.098L7.84 4.1z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconBookmarkStarFill=/*#__PURE__*/makeIcon('BookmarkStarFill','<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zM8.16 4.1a.178.178 0 0 0-.32 0l-.634 1.285a.178.178 0 0 1-.134.098l-1.42.206a.178.178 0 0 0-.098.303L6.58 6.993c.042.041.061.1.051.158L6.39 8.565a.178.178 0 0 0 .258.187l1.27-.668a.178.178 0 0 1 .165 0l1.27.668a.178.178 0 0 0 .257-.187L9.368 7.15a.178.178 0 0 1 .05-.158l1.028-1.001a.178.178 0 0 0-.098-.303l-1.42-.206a.178.178 0 0 1-.134-.098L8.16 4.1z"/>');// eslint-disable-next-line
var BIconBookmarkX=/*#__PURE__*/makeIcon('BookmarkX','<path fill-rule="evenodd" d="M6.146 5.146a.5.5 0 0 1 .708 0L8 6.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 7l1.147 1.146a.5.5 0 0 1-.708.708L8 7.707 6.854 8.854a.5.5 0 1 1-.708-.708L7.293 7 6.146 5.854a.5.5 0 0 1 0-.708z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconBookmarkXFill=/*#__PURE__*/makeIcon('BookmarkXFill','<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zM6.854 5.146a.5.5 0 1 0-.708.708L7.293 7 6.146 8.146a.5.5 0 1 0 .708.708L8 7.707l1.146 1.147a.5.5 0 1 0 .708-.708L8.707 7l1.147-1.146a.5.5 0 0 0-.708-.708L8 6.293 6.854 5.146z"/>');// eslint-disable-next-line
var BIconBookmarks=/*#__PURE__*/makeIcon('Bookmarks','<path d="M2 4a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v11.5a.5.5 0 0 1-.777.416L7 13.101l-4.223 2.815A.5.5 0 0 1 2 15.5V4zm2-1a1 1 0 0 0-1 1v10.566l3.723-2.482a.5.5 0 0 1 .554 0L11 14.566V4a1 1 0 0 0-1-1H4z"/><path d="M4.268 1H12a1 1 0 0 1 1 1v11.768l.223.148A.5.5 0 0 0 14 13.5V2a2 2 0 0 0-2-2H6a2 2 0 0 0-1.732 1z"/>');// eslint-disable-next-line
var BIconBookmarksFill=/*#__PURE__*/makeIcon('BookmarksFill','<path d="M2 4a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v11.5a.5.5 0 0 1-.777.416L7 13.101l-4.223 2.815A.5.5 0 0 1 2 15.5V4z"/><path d="M4.268 1A2 2 0 0 1 6 0h6a2 2 0 0 1 2 2v11.5a.5.5 0 0 1-.777.416L13 13.768V2a1 1 0 0 0-1-1H4.268z"/>');// eslint-disable-next-line
var BIconBookshelf=/*#__PURE__*/makeIcon('Bookshelf','<path d="M2.5 0a.5.5 0 0 1 .5.5V2h10V.5a.5.5 0 0 1 1 0v15a.5.5 0 0 1-1 0V15H3v.5a.5.5 0 0 1-1 0V.5a.5.5 0 0 1 .5-.5zM3 14h10v-3H3v3zm0-4h10V7H3v3zm0-4h10V3H3v3z"/>');// eslint-disable-next-line
var BIconBootstrap=/*#__PURE__*/makeIcon('Bootstrap','<path d="M5.062 12h3.475c1.804 0 2.888-.908 2.888-2.396 0-1.102-.761-1.916-1.904-2.034v-.1c.832-.14 1.482-.93 1.482-1.816 0-1.3-.955-2.11-2.542-2.11H5.062V12zm1.313-4.875V4.658h1.78c.973 0 1.542.457 1.542 1.237 0 .802-.604 1.23-1.764 1.23H6.375zm0 3.762V8.162h1.822c1.236 0 1.887.463 1.887 1.348 0 .896-.627 1.377-1.811 1.377H6.375z"/><path d="M0 4a4 4 0 0 1 4-4h8a4 4 0 0 1 4 4v8a4 4 0 0 1-4 4H4a4 4 0 0 1-4-4V4zm4-3a3 3 0 0 0-3 3v8a3 3 0 0 0 3 3h8a3 3 0 0 0 3-3V4a3 3 0 0 0-3-3H4z"/>');// eslint-disable-next-line
var BIconBootstrapFill=/*#__PURE__*/makeIcon('BootstrapFill','<path d="M6.375 7.125V4.658h1.78c.973 0 1.542.457 1.542 1.237 0 .802-.604 1.23-1.764 1.23H6.375zm0 3.762h1.898c1.184 0 1.81-.48 1.81-1.377 0-.885-.65-1.348-1.886-1.348H6.375v2.725z"/><path d="M4.002 0a4 4 0 0 0-4 4v8a4 4 0 0 0 4 4h8a4 4 0 0 0 4-4V4a4 4 0 0 0-4-4h-8zm1.06 12V3.545h3.399c1.587 0 2.543.809 2.543 2.11 0 .884-.65 1.675-1.483 1.816v.1c1.143.117 1.904.931 1.904 2.033 0 1.488-1.084 2.396-2.888 2.396H5.062z"/>');// eslint-disable-next-line
var BIconBootstrapReboot=/*#__PURE__*/makeIcon('BootstrapReboot','<path d="M1.161 8a6.84 6.84 0 1 0 6.842-6.84.58.58 0 0 1 0-1.16 8 8 0 1 1-6.556 3.412l-.663-.577a.58.58 0 0 1 .227-.997l2.52-.69a.58.58 0 0 1 .728.633l-.332 2.592a.58.58 0 0 1-.956.364l-.643-.56A6.812 6.812 0 0 0 1.16 8z"/><path d="M6.641 11.671V8.843h1.57l1.498 2.828h1.314L9.377 8.665c.897-.3 1.427-1.106 1.427-2.1 0-1.37-.943-2.246-2.456-2.246H5.5v7.352h1.141zm0-3.75V5.277h1.57c.881 0 1.416.499 1.416 1.32 0 .84-.504 1.324-1.386 1.324h-1.6z"/>');// eslint-disable-next-line
var BIconBorderStyle=/*#__PURE__*/makeIcon('BorderStyle','<path d="M1 3.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-1zm0 4a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-1zm0 4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm8 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-4 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm8 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-4-4a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-1z"/>');// eslint-disable-next-line
var BIconBorderWidth=/*#__PURE__*/makeIcon('BorderWidth','<path d="M0 3.5A.5.5 0 0 1 .5 3h15a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-2zm0 5A.5.5 0 0 1 .5 8h15a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-1zm0 4a.5.5 0 0 1 .5-.5h15a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconBoundingBox=/*#__PURE__*/makeIcon('BoundingBox','<path d="M5 2V0H0v5h2v6H0v5h5v-2h6v2h5v-5h-2V5h2V0h-5v2H5zm6 1v2h2v6h-2v2H5v-2H3V5h2V3h6zm1-2h3v3h-3V1zm3 11v3h-3v-3h3zM4 15H1v-3h3v3zM1 4V1h3v3H1z"/>');// eslint-disable-next-line
var BIconBoundingBoxCircles=/*#__PURE__*/makeIcon('BoundingBoxCircles','<path d="M2 1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zM0 2a2 2 0 0 1 3.937-.5h8.126A2 2 0 1 1 14.5 3.937v8.126a2 2 0 1 1-2.437 2.437H3.937A2 2 0 1 1 1.5 12.063V3.937A2 2 0 0 1 0 2zm2.5 1.937v8.126c.703.18 1.256.734 1.437 1.437h8.126a2.004 2.004 0 0 1 1.437-1.437V3.937A2.004 2.004 0 0 1 12.063 2.5H3.937A2.004 2.004 0 0 1 2.5 3.937zM14 1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zM2 13a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm12 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>');// eslint-disable-next-line
var BIconBox=/*#__PURE__*/makeIcon('Box','<path d="M8.186 1.113a.5.5 0 0 0-.372 0L1.846 3.5 8 5.961 14.154 3.5 8.186 1.113zM15 4.239l-6.5 2.6v7.922l6.5-2.6V4.24zM7.5 14.762V6.838L1 4.239v7.923l6.5 2.6zM7.443.184a1.5 1.5 0 0 1 1.114 0l7.129 2.852A.5.5 0 0 1 16 3.5v8.662a1 1 0 0 1-.629.928l-7.185 2.874a.5.5 0 0 1-.372 0L.63 13.09a1 1 0 0 1-.63-.928V3.5a.5.5 0 0 1 .314-.464L7.443.184z"/>');// eslint-disable-next-line
var BIconBoxArrowDown=/*#__PURE__*/makeIcon('BoxArrowDown','<path fill-rule="evenodd" d="M3.5 10a.5.5 0 0 1-.5-.5v-8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 0 0 1h2A1.5 1.5 0 0 0 14 9.5v-8A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v8A1.5 1.5 0 0 0 3.5 11h2a.5.5 0 0 0 0-1h-2z"/><path fill-rule="evenodd" d="M7.646 15.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 14.293V5.5a.5.5 0 0 0-1 0v8.793l-2.146-2.147a.5.5 0 0 0-.708.708l3 3z"/>');// eslint-disable-next-line
var BIconBoxArrowDownLeft=/*#__PURE__*/makeIcon('BoxArrowDownLeft','<path fill-rule="evenodd" d="M7.364 12.5a.5.5 0 0 0 .5.5H14.5a1.5 1.5 0 0 0 1.5-1.5v-10A1.5 1.5 0 0 0 14.5 0h-10A1.5 1.5 0 0 0 3 1.5v6.636a.5.5 0 1 0 1 0V1.5a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v10a.5.5 0 0 1-.5.5H7.864a.5.5 0 0 0-.5.5z"/><path fill-rule="evenodd" d="M0 15.5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 0-1H1.707l8.147-8.146a.5.5 0 0 0-.708-.708L1 14.293V10.5a.5.5 0 0 0-1 0v5z"/>');// eslint-disable-next-line
var BIconBoxArrowDownRight=/*#__PURE__*/makeIcon('BoxArrowDownRight','<path fill-rule="evenodd" d="M8.636 12.5a.5.5 0 0 1-.5.5H1.5A1.5 1.5 0 0 1 0 11.5v-10A1.5 1.5 0 0 1 1.5 0h10A1.5 1.5 0 0 1 13 1.5v6.636a.5.5 0 0 1-1 0V1.5a.5.5 0 0 0-.5-.5h-10a.5.5 0 0 0-.5.5v10a.5.5 0 0 0 .5.5h6.636a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M16 15.5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1 0-1h3.793L6.146 6.854a.5.5 0 1 1 .708-.708L15 14.293V10.5a.5.5 0 0 1 1 0v5z"/>');// eslint-disable-next-line
var BIconBoxArrowInDown=/*#__PURE__*/makeIcon('BoxArrowInDown','<path fill-rule="evenodd" d="M3.5 6a.5.5 0 0 0-.5.5v8a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5v-8a.5.5 0 0 0-.5-.5h-2a.5.5 0 0 1 0-1h2A1.5 1.5 0 0 1 14 6.5v8a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 14.5v-8A1.5 1.5 0 0 1 3.5 5h2a.5.5 0 0 1 0 1h-2z"/><path fill-rule="evenodd" d="M7.646 11.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V1.5a.5.5 0 0 0-1 0v8.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3z"/>');// eslint-disable-next-line
var BIconBoxArrowInDownLeft=/*#__PURE__*/makeIcon('BoxArrowInDownLeft','<path fill-rule="evenodd" d="M9.636 2.5a.5.5 0 0 0-.5-.5H2.5A1.5 1.5 0 0 0 1 3.5v10A1.5 1.5 0 0 0 2.5 15h10a1.5 1.5 0 0 0 1.5-1.5V6.864a.5.5 0 0 0-1 0V13.5a.5.5 0 0 1-.5.5h-10a.5.5 0 0 1-.5-.5v-10a.5.5 0 0 1 .5-.5h6.636a.5.5 0 0 0 .5-.5z"/><path fill-rule="evenodd" d="M5 10.5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 0-1H6.707l8.147-8.146a.5.5 0 0 0-.708-.708L6 9.293V5.5a.5.5 0 0 0-1 0v5z"/>');// eslint-disable-next-line
var BIconBoxArrowInDownRight=/*#__PURE__*/makeIcon('BoxArrowInDownRight','<path fill-rule="evenodd" d="M6.364 2.5a.5.5 0 0 1 .5-.5H13.5A1.5 1.5 0 0 1 15 3.5v10a1.5 1.5 0 0 1-1.5 1.5h-10A1.5 1.5 0 0 1 2 13.5V6.864a.5.5 0 1 1 1 0V13.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5v-10a.5.5 0 0 0-.5-.5H6.864a.5.5 0 0 1-.5-.5z"/><path fill-rule="evenodd" d="M11 10.5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1 0-1h3.793L1.146 1.854a.5.5 0 1 1 .708-.708L10 9.293V5.5a.5.5 0 0 1 1 0v5z"/>');// eslint-disable-next-line
var BIconBoxArrowInLeft=/*#__PURE__*/makeIcon('BoxArrowInLeft','<path fill-rule="evenodd" d="M10 3.5a.5.5 0 0 0-.5-.5h-8a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 1 1 0v2A1.5 1.5 0 0 1 9.5 14h-8A1.5 1.5 0 0 1 0 12.5v-9A1.5 1.5 0 0 1 1.5 2h8A1.5 1.5 0 0 1 11 3.5v2a.5.5 0 0 1-1 0v-2z"/><path fill-rule="evenodd" d="M4.146 8.354a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H14.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3z"/>');// eslint-disable-next-line
var BIconBoxArrowInRight=/*#__PURE__*/makeIcon('BoxArrowInRight','<path fill-rule="evenodd" d="M6 3.5a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-8a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 0-1 0v2A1.5 1.5 0 0 0 6.5 14h8a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-8A1.5 1.5 0 0 0 5 3.5v2a.5.5 0 0 0 1 0v-2z"/><path fill-rule="evenodd" d="M11.854 8.354a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H1.5a.5.5 0 0 0 0 1h8.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3z"/>');// eslint-disable-next-line
var BIconBoxArrowInUp=/*#__PURE__*/makeIcon('BoxArrowInUp','<path fill-rule="evenodd" d="M3.5 10a.5.5 0 0 1-.5-.5v-8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 0 0 1h2A1.5 1.5 0 0 0 14 9.5v-8A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v8A1.5 1.5 0 0 0 3.5 11h2a.5.5 0 0 0 0-1h-2z"/><path fill-rule="evenodd" d="M7.646 4.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V14.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3z"/>');// eslint-disable-next-line
var BIconBoxArrowInUpLeft=/*#__PURE__*/makeIcon('BoxArrowInUpLeft','<path fill-rule="evenodd" d="M9.636 13.5a.5.5 0 0 1-.5.5H2.5A1.5 1.5 0 0 1 1 12.5v-10A1.5 1.5 0 0 1 2.5 1h10A1.5 1.5 0 0 1 14 2.5v6.636a.5.5 0 0 1-1 0V2.5a.5.5 0 0 0-.5-.5h-10a.5.5 0 0 0-.5.5v10a.5.5 0 0 0 .5.5h6.636a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M5 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1H6.707l8.147 8.146a.5.5 0 0 1-.708.708L6 6.707V10.5a.5.5 0 0 1-1 0v-5z"/>');// eslint-disable-next-line
var BIconBoxArrowInUpRight=/*#__PURE__*/makeIcon('BoxArrowInUpRight','<path fill-rule="evenodd" d="M6.364 13.5a.5.5 0 0 0 .5.5H13.5a1.5 1.5 0 0 0 1.5-1.5v-10A1.5 1.5 0 0 0 13.5 1h-10A1.5 1.5 0 0 0 2 2.5v6.636a.5.5 0 1 0 1 0V2.5a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v10a.5.5 0 0 1-.5.5H6.864a.5.5 0 0 0-.5.5z"/><path fill-rule="evenodd" d="M11 5.5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h3.793l-8.147 8.146a.5.5 0 0 0 .708.708L10 6.707V10.5a.5.5 0 0 0 1 0v-5z"/>');// eslint-disable-next-line
var BIconBoxArrowLeft=/*#__PURE__*/makeIcon('BoxArrowLeft','<path fill-rule="evenodd" d="M6 12.5a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-8a.5.5 0 0 0-.5.5v2a.5.5 0 0 1-1 0v-2A1.5 1.5 0 0 1 6.5 2h8A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-8A1.5 1.5 0 0 1 5 12.5v-2a.5.5 0 0 1 1 0v2z"/><path fill-rule="evenodd" d="M.146 8.354a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L1.707 7.5H10.5a.5.5 0 0 1 0 1H1.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3z"/>');// eslint-disable-next-line
var BIconBoxArrowRight=/*#__PURE__*/makeIcon('BoxArrowRight','<path fill-rule="evenodd" d="M10 12.5a.5.5 0 0 1-.5.5h-8a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 .5.5v2a.5.5 0 0 0 1 0v-2A1.5 1.5 0 0 0 9.5 2h-8A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h8a1.5 1.5 0 0 0 1.5-1.5v-2a.5.5 0 0 0-1 0v2z"/><path fill-rule="evenodd" d="M15.854 8.354a.5.5 0 0 0 0-.708l-3-3a.5.5 0 0 0-.708.708L14.293 7.5H5.5a.5.5 0 0 0 0 1h8.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3z"/>');// eslint-disable-next-line
var BIconBoxArrowUp=/*#__PURE__*/makeIcon('BoxArrowUp','<path fill-rule="evenodd" d="M3.5 6a.5.5 0 0 0-.5.5v8a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5v-8a.5.5 0 0 0-.5-.5h-2a.5.5 0 0 1 0-1h2A1.5 1.5 0 0 1 14 6.5v8a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 14.5v-8A1.5 1.5 0 0 1 3.5 5h2a.5.5 0 0 1 0 1h-2z"/><path fill-rule="evenodd" d="M7.646.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 1.707V10.5a.5.5 0 0 1-1 0V1.707L5.354 3.854a.5.5 0 1 1-.708-.708l3-3z"/>');// eslint-disable-next-line
var BIconBoxArrowUpLeft=/*#__PURE__*/makeIcon('BoxArrowUpLeft','<path fill-rule="evenodd" d="M7.364 3.5a.5.5 0 0 1 .5-.5H14.5A1.5 1.5 0 0 1 16 4.5v10a1.5 1.5 0 0 1-1.5 1.5h-10A1.5 1.5 0 0 1 3 14.5V7.864a.5.5 0 1 1 1 0V14.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5v-10a.5.5 0 0 0-.5-.5H7.864a.5.5 0 0 1-.5-.5z"/><path fill-rule="evenodd" d="M0 .5A.5.5 0 0 1 .5 0h5a.5.5 0 0 1 0 1H1.707l8.147 8.146a.5.5 0 0 1-.708.708L1 1.707V5.5a.5.5 0 0 1-1 0v-5z"/>');// eslint-disable-next-line
var BIconBoxArrowUpRight=/*#__PURE__*/makeIcon('BoxArrowUpRight','<path fill-rule="evenodd" d="M8.636 3.5a.5.5 0 0 0-.5-.5H1.5A1.5 1.5 0 0 0 0 4.5v10A1.5 1.5 0 0 0 1.5 16h10a1.5 1.5 0 0 0 1.5-1.5V7.864a.5.5 0 0 0-1 0V14.5a.5.5 0 0 1-.5.5h-10a.5.5 0 0 1-.5-.5v-10a.5.5 0 0 1 .5-.5h6.636a.5.5 0 0 0 .5-.5z"/><path fill-rule="evenodd" d="M16 .5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h3.793L6.146 9.146a.5.5 0 1 0 .708.708L15 1.707V5.5a.5.5 0 0 0 1 0v-5z"/>');// eslint-disable-next-line
var BIconBoxSeam=/*#__PURE__*/makeIcon('BoxSeam','<path d="M8.186 1.113a.5.5 0 0 0-.372 0L1.846 3.5l2.404.961L10.404 2l-2.218-.887zm3.564 1.426L5.596 5 8 5.961 14.154 3.5l-2.404-.961zm3.25 1.7l-6.5 2.6v7.922l6.5-2.6V4.24zM7.5 14.762V6.838L1 4.239v7.923l6.5 2.6zM7.443.184a1.5 1.5 0 0 1 1.114 0l7.129 2.852A.5.5 0 0 1 16 3.5v8.662a1 1 0 0 1-.629.928l-7.185 2.874a.5.5 0 0 1-.372 0L.63 13.09a1 1 0 0 1-.63-.928V3.5a.5.5 0 0 1 .314-.464L7.443.184z"/>');// eslint-disable-next-line
var BIconBraces=/*#__PURE__*/makeIcon('Braces','<path d="M2.114 8.063V7.9c1.005-.102 1.497-.615 1.497-1.6V4.503c0-1.094.39-1.538 1.354-1.538h.273V2h-.376C3.25 2 2.49 2.759 2.49 4.352v1.524c0 1.094-.376 1.456-1.49 1.456v1.299c1.114 0 1.49.362 1.49 1.456v1.524c0 1.593.759 2.352 2.372 2.352h.376v-.964h-.273c-.964 0-1.354-.444-1.354-1.538V9.663c0-.984-.492-1.497-1.497-1.6zM13.886 7.9v.163c-1.005.103-1.497.616-1.497 1.6v1.798c0 1.094-.39 1.538-1.354 1.538h-.273v.964h.376c1.613 0 2.372-.759 2.372-2.352v-1.524c0-1.094.376-1.456 1.49-1.456V7.332c-1.114 0-1.49-.362-1.49-1.456V4.352C13.51 2.759 12.75 2 11.138 2h-.376v.964h.273c.964 0 1.354.444 1.354 1.538V6.3c0 .984.492 1.497 1.497 1.6z"/>');// eslint-disable-next-line
var BIconBricks=/*#__PURE__*/makeIcon('Bricks','<path d="M0 .5A.5.5 0 0 1 .5 0h15a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5H14v2h1.5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5H14v2h1.5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-3a.5.5 0 0 1 .5-.5H2v-2H.5a.5.5 0 0 1-.5-.5v-3A.5.5 0 0 1 .5 6H2V4H.5a.5.5 0 0 1-.5-.5v-3zM3 4v2h4.5V4H3zm5.5 0v2H13V4H8.5zM3 10v2h4.5v-2H3zm5.5 0v2H13v-2H8.5zM1 1v2h3.5V1H1zm4.5 0v2h5V1h-5zm6 0v2H15V1h-3.5zM1 7v2h3.5V7H1zm4.5 0v2h5V7h-5zm6 0v2H15V7h-3.5zM1 13v2h3.5v-2H1zm4.5 0v2h5v-2h-5zm6 0v2H15v-2h-3.5z"/>');// eslint-disable-next-line
var BIconBriefcase=/*#__PURE__*/makeIcon('Briefcase','<path d="M6.5 1A1.5 1.5 0 0 0 5 2.5V3H1.5A1.5 1.5 0 0 0 0 4.5v8A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-8A1.5 1.5 0 0 0 14.5 3H11v-.5A1.5 1.5 0 0 0 9.5 1h-3zm0 1h3a.5.5 0 0 1 .5.5V3H6v-.5a.5.5 0 0 1 .5-.5zm1.886 6.914L15 7.151V12.5a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5V7.15l6.614 1.764a1.5 1.5 0 0 0 .772 0zM1.5 4h13a.5.5 0 0 1 .5.5v1.616L8.129 7.948a.5.5 0 0 1-.258 0L1 6.116V4.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconBriefcaseFill=/*#__PURE__*/makeIcon('BriefcaseFill','<path d="M6.5 1A1.5 1.5 0 0 0 5 2.5V3H1.5A1.5 1.5 0 0 0 0 4.5v1.384l7.614 2.03a1.5 1.5 0 0 0 .772 0L16 5.884V4.5A1.5 1.5 0 0 0 14.5 3H11v-.5A1.5 1.5 0 0 0 9.5 1h-3zm0 1h3a.5.5 0 0 1 .5.5V3H6v-.5a.5.5 0 0 1 .5-.5z"/><path d="M0 12.5A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5V6.85L8.129 8.947a.5.5 0 0 1-.258 0L0 6.85v5.65z"/>');// eslint-disable-next-line
var BIconBrightnessAltHigh=/*#__PURE__*/makeIcon('BrightnessAltHigh','<path d="M8 3a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 3zm8 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zm-13.5.5a.5.5 0 0 0 0-1h-2a.5.5 0 0 0 0 1h2zm11.157-6.157a.5.5 0 0 1 0 .707l-1.414 1.414a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm-9.9 2.121a.5.5 0 0 0 .707-.707L3.05 5.343a.5.5 0 1 0-.707.707l1.414 1.414zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4zm0 1a3 3 0 0 1 2.959 2.5H5.04A3 3 0 0 1 8 8z"/>');// eslint-disable-next-line
var BIconBrightnessAltHighFill=/*#__PURE__*/makeIcon('BrightnessAltHighFill','<path d="M8 3a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 3zm8 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zm-13.5.5a.5.5 0 0 0 0-1h-2a.5.5 0 0 0 0 1h2zm11.157-6.157a.5.5 0 0 1 0 .707l-1.414 1.414a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm-9.9 2.121a.5.5 0 0 0 .707-.707L3.05 5.343a.5.5 0 1 0-.707.707l1.414 1.414zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4z"/>');// eslint-disable-next-line
var BIconBrightnessAltLow=/*#__PURE__*/makeIcon('BrightnessAltLow','<path d="M8.5 5.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5 6a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM2 11a.5.5 0 1 0 1 0 .5.5 0 0 0-1 0zm10.243-3.536a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-8.486-.707a.5.5 0 1 0 .707.707.5.5 0 0 0-.707-.707zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4zm0 1a3 3 0 0 1 2.959 2.5H5.04A3 3 0 0 1 8 8z"/>');// eslint-disable-next-line
var BIconBrightnessAltLowFill=/*#__PURE__*/makeIcon('BrightnessAltLowFill','<path d="M8.5 5.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5 6a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM2 11a.5.5 0 1 0 1 0 .5.5 0 0 0-1 0zm10.243-3.536a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-8.486-.707a.5.5 0 1 0 .707.707.5.5 0 0 0-.707-.707zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4z"/>');// eslint-disable-next-line
var BIconBrightnessHigh=/*#__PURE__*/makeIcon('BrightnessHigh','<path d="M8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6zm0 1a4 4 0 1 0 0-8 4 4 0 0 0 0 8zM8 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 0zm0 13a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 13zm8-5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zM3 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2A.5.5 0 0 1 3 8zm10.657-5.657a.5.5 0 0 1 0 .707l-1.414 1.415a.5.5 0 1 1-.707-.708l1.414-1.414a.5.5 0 0 1 .707 0zm-9.193 9.193a.5.5 0 0 1 0 .707L3.05 13.657a.5.5 0 0 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm9.193 2.121a.5.5 0 0 1-.707 0l-1.414-1.414a.5.5 0 0 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .707zM4.464 4.465a.5.5 0 0 1-.707 0L2.343 3.05a.5.5 0 1 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .708z"/>');// eslint-disable-next-line
var BIconBrightnessHighFill=/*#__PURE__*/makeIcon('BrightnessHighFill','<path d="M12 8a4 4 0 1 1-8 0 4 4 0 0 1 8 0zM8 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 0zm0 13a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 13zm8-5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zM3 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2A.5.5 0 0 1 3 8zm10.657-5.657a.5.5 0 0 1 0 .707l-1.414 1.415a.5.5 0 1 1-.707-.708l1.414-1.414a.5.5 0 0 1 .707 0zm-9.193 9.193a.5.5 0 0 1 0 .707L3.05 13.657a.5.5 0 0 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm9.193 2.121a.5.5 0 0 1-.707 0l-1.414-1.414a.5.5 0 0 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .707zM4.464 4.465a.5.5 0 0 1-.707 0L2.343 3.05a.5.5 0 1 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .708z"/>');// eslint-disable-next-line
var BIconBrightnessLow=/*#__PURE__*/makeIcon('BrightnessLow','<path d="M8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6zm0 1a4 4 0 1 0 0-8 4 4 0 0 0 0 8zm.5-9.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm0 11a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5-5a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm-11 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm9.743-4.036a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-7.779 7.779a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm7.072 0a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707zM3.757 4.464a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707z"/>');// eslint-disable-next-line
var BIconBrightnessLowFill=/*#__PURE__*/makeIcon('BrightnessLowFill','<path d="M12 8a4 4 0 1 1-8 0 4 4 0 0 1 8 0zM8.5 2.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm0 11a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5-5a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm-11 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm9.743-4.036a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-7.779 7.779a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm7.072 0a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707zM3.757 4.464a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707z"/>');// eslint-disable-next-line
var BIconBroadcast=/*#__PURE__*/makeIcon('Broadcast','<path d="M3.05 3.05a7 7 0 0 0 0 9.9.5.5 0 0 1-.707.707 8 8 0 0 1 0-11.314.5.5 0 0 1 .707.707zm2.122 2.122a4 4 0 0 0 0 5.656.5.5 0 0 1-.708.708 5 5 0 0 1 0-7.072.5.5 0 0 1 .708.708zm5.656-.708a.5.5 0 0 1 .708 0 5 5 0 0 1 0 7.072.5.5 0 1 1-.708-.708 4 4 0 0 0 0-5.656.5.5 0 0 1 0-.708zm2.122-2.12a.5.5 0 0 1 .707 0 8 8 0 0 1 0 11.313.5.5 0 0 1-.707-.707 7 7 0 0 0 0-9.9.5.5 0 0 1 0-.707zM10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>');// eslint-disable-next-line
var BIconBroadcastPin=/*#__PURE__*/makeIcon('BroadcastPin','<path d="M3.05 3.05a7 7 0 0 0 0 9.9.5.5 0 0 1-.707.707 8 8 0 0 1 0-11.314.5.5 0 0 1 .707.707zm2.122 2.122a4 4 0 0 0 0 5.656.5.5 0 0 1-.708.708 5 5 0 0 1 0-7.072.5.5 0 0 1 .708.708zm5.656-.708a.5.5 0 0 1 .708 0 5 5 0 0 1 0 7.072.5.5 0 1 1-.708-.708 4 4 0 0 0 0-5.656.5.5 0 0 1 0-.708zm2.122-2.12a.5.5 0 0 1 .707 0 8 8 0 0 1 0 11.313.5.5 0 0 1-.707-.707 7 7 0 0 0 0-9.9.5.5 0 0 1 0-.707zM6 8a2 2 0 1 1 2.5 1.937V15.5a.5.5 0 0 1-1 0V9.937A2 2 0 0 1 6 8z"/>');// eslint-disable-next-line
var BIconBrush=/*#__PURE__*/makeIcon('Brush','<path d="M15.825.12a.5.5 0 0 1 .132.584c-1.53 3.43-4.743 8.17-7.095 10.64a6.067 6.067 0 0 1-2.373 1.534c-.018.227-.06.538-.16.868-.201.659-.667 1.479-1.708 1.74a8.117 8.117 0 0 1-3.078.132 3.658 3.658 0 0 1-.563-.135 1.382 1.382 0 0 1-.465-.247.714.714 0 0 1-.204-.288.622.622 0 0 1 .004-.443c.095-.245.316-.38.461-.452.393-.197.625-.453.867-.826.094-.144.184-.297.287-.472l.117-.198c.151-.255.326-.54.546-.848.528-.739 1.2-.925 1.746-.896.126.007.243.025.348.048.062-.172.142-.38.238-.608.261-.619.658-1.419 1.187-2.069 2.175-2.67 6.18-6.206 9.117-8.104a.5.5 0 0 1 .596.04zM4.705 11.912a1.23 1.23 0 0 0-.419-.1c-.247-.013-.574.05-.88.479a11.01 11.01 0 0 0-.5.777l-.104.177c-.107.181-.213.362-.32.528-.206.317-.438.61-.76.861a7.127 7.127 0 0 0 2.657-.12c.559-.139.843-.569.993-1.06a3.121 3.121 0 0 0 .126-.75l-.793-.792zm1.44.026c.12-.04.277-.1.458-.183a5.068 5.068 0 0 0 1.535-1.1c1.9-1.996 4.412-5.57 6.052-8.631-2.591 1.927-5.566 4.66-7.302 6.792-.442.543-.796 1.243-1.042 1.826a11.507 11.507 0 0 0-.276.721l.575.575zm-4.973 3.04l.007-.005a.031.031 0 0 1-.007.004zm3.582-3.043l.002.001h-.002z"/>');// eslint-disable-next-line
var BIconBrushFill=/*#__PURE__*/makeIcon('BrushFill','<path d="M15.825.12a.5.5 0 0 1 .132.584c-1.53 3.43-4.743 8.17-7.095 10.64a6.067 6.067 0 0 1-2.373 1.534c-.018.227-.06.538-.16.868-.201.659-.667 1.479-1.708 1.74a8.117 8.117 0 0 1-3.078.132 3.658 3.658 0 0 1-.563-.135 1.382 1.382 0 0 1-.465-.247.714.714 0 0 1-.204-.288.622.622 0 0 1 .004-.443c.095-.245.316-.38.461-.452.393-.197.625-.453.867-.826.094-.144.184-.297.287-.472l.117-.198c.151-.255.326-.54.546-.848.528-.739 1.2-.925 1.746-.896.126.007.243.025.348.048.062-.172.142-.38.238-.608.261-.619.658-1.419 1.187-2.069 2.175-2.67 6.18-6.206 9.117-8.104a.5.5 0 0 1 .596.04z"/>');// eslint-disable-next-line
var BIconBucket=/*#__PURE__*/makeIcon('Bucket','<path d="M2.522 5H2a.5.5 0 0 0-.494.574l1.372 9.149A1.5 1.5 0 0 0 4.36 16h7.278a1.5 1.5 0 0 0 1.483-1.277l1.373-9.149A.5.5 0 0 0 14 5h-.522A5.5 5.5 0 0 0 2.522 5zm1.005 0a4.5 4.5 0 0 1 8.945 0H3.527zm9.892 1l-1.286 8.574a.5.5 0 0 1-.494.426H4.36a.5.5 0 0 1-.494-.426L2.58 6h10.838z"/>');// eslint-disable-next-line
var BIconBucketFill=/*#__PURE__*/makeIcon('BucketFill','<path d="M2.522 5H2a.5.5 0 0 0-.494.574l1.372 9.149A1.5 1.5 0 0 0 4.36 16h7.278a1.5 1.5 0 0 0 1.483-1.277l1.373-9.149A.5.5 0 0 0 14 5h-.522A5.5 5.5 0 0 0 2.522 5zm1.005 0a4.5 4.5 0 0 1 8.945 0H3.527z"/>');// eslint-disable-next-line
var BIconBug=/*#__PURE__*/makeIcon('Bug','<path d="M4.355.522a.5.5 0 0 1 .623.333l.291.956A4.979 4.979 0 0 1 8 1c1.007 0 1.946.298 2.731.811l.29-.956a.5.5 0 1 1 .957.29l-.41 1.352A4.985 4.985 0 0 1 13 6h.5a.5.5 0 0 0 .5-.5V5a.5.5 0 0 1 1 0v.5A1.5 1.5 0 0 1 13.5 7H13v1h1.5a.5.5 0 0 1 0 1H13v1h.5a1.5 1.5 0 0 1 1.5 1.5v.5a.5.5 0 1 1-1 0v-.5a.5.5 0 0 0-.5-.5H13a5 5 0 0 1-10 0h-.5a.5.5 0 0 0-.5.5v.5a.5.5 0 1 1-1 0v-.5A1.5 1.5 0 0 1 2.5 10H3V9H1.5a.5.5 0 0 1 0-1H3V7h-.5A1.5 1.5 0 0 1 1 5.5V5a.5.5 0 0 1 1 0v.5a.5.5 0 0 0 .5.5H3c0-1.364.547-2.601 1.432-3.503l-.41-1.352a.5.5 0 0 1 .333-.623zM4 7v4a4 4 0 0 0 3.5 3.97V7H4zm4.5 0v7.97A4 4 0 0 0 12 11V7H8.5zM12 6a3.989 3.989 0 0 0-1.334-2.982A3.983 3.983 0 0 0 8 2a3.983 3.983 0 0 0-2.667 1.018A3.989 3.989 0 0 0 4 6h8z"/>');// eslint-disable-next-line
var BIconBugFill=/*#__PURE__*/makeIcon('BugFill','<path d="M4.978.855a.5.5 0 1 0-.956.29l.41 1.352A4.985 4.985 0 0 0 3 6h10a4.985 4.985 0 0 0-1.432-3.503l.41-1.352a.5.5 0 1 0-.956-.29l-.291.956A4.978 4.978 0 0 0 8 1a4.979 4.979 0 0 0-2.731.811l-.29-.956z"/><path d="M13 6v1H8.5v8.975A5 5 0 0 0 13 11h.5a.5.5 0 0 1 .5.5v.5a.5.5 0 1 0 1 0v-.5a1.5 1.5 0 0 0-1.5-1.5H13V9h1.5a.5.5 0 0 0 0-1H13V7h.5A1.5 1.5 0 0 0 15 5.5V5a.5.5 0 0 0-1 0v.5a.5.5 0 0 1-.5.5H13zm-5.5 9.975V7H3V6h-.5a.5.5 0 0 1-.5-.5V5a.5.5 0 0 0-1 0v.5A1.5 1.5 0 0 0 2.5 7H3v1H1.5a.5.5 0 0 0 0 1H3v1h-.5A1.5 1.5 0 0 0 1 11.5v.5a.5.5 0 1 0 1 0v-.5a.5.5 0 0 1 .5-.5H3a5 5 0 0 0 4.5 4.975z"/>');// eslint-disable-next-line
var BIconBuilding=/*#__PURE__*/makeIcon('Building','<path fill-rule="evenodd" d="M14.763.075A.5.5 0 0 1 15 .5v15a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5V14h-1v1.5a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5V10a.5.5 0 0 1 .342-.474L6 7.64V4.5a.5.5 0 0 1 .276-.447l8-4a.5.5 0 0 1 .487.022zM6 8.694L1 10.36V15h5V8.694zM7 15h2v-1.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5V15h2V1.309l-7 3.5V15z"/><path d="M2 11h1v1H2v-1zm2 0h1v1H4v-1zm-2 2h1v1H2v-1zm2 0h1v1H4v-1zm4-4h1v1H8V9zm2 0h1v1h-1V9zm-2 2h1v1H8v-1zm2 0h1v1h-1v-1zm2-2h1v1h-1V9zm0 2h1v1h-1v-1zM8 7h1v1H8V7zm2 0h1v1h-1V7zm2 0h1v1h-1V7zM8 5h1v1H8V5zm2 0h1v1h-1V5zm2 0h1v1h-1V5zm0-2h1v1h-1V3z"/>');// eslint-disable-next-line
var BIconBullseye=/*#__PURE__*/makeIcon('Bullseye','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8 13A5 5 0 1 1 8 3a5 5 0 0 1 0 10zm0 1A6 6 0 1 0 8 2a6 6 0 0 0 0 12z"/><path d="M8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6zm0 1a4 4 0 1 0 0-8 4 4 0 0 0 0 8z"/><path d="M9.5 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconCalculator=/*#__PURE__*/makeIcon('Calculator','<path d="M12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M4 2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-2zm0 4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-4z"/>');// eslint-disable-next-line
var BIconCalculatorFill=/*#__PURE__*/makeIcon('CalculatorFill','<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2 .5v2a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-7a.5.5 0 0 0-.5.5zm0 4v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zM4.5 9a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM4 12.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zM7.5 6a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM7 9.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zm.5 2.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM10 6.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zm.5 2.5a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5h-1z"/>');// eslint-disable-next-line
var BIconCalendar=/*#__PURE__*/makeIcon('Calendar','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendar2=/*#__PURE__*/makeIcon('Calendar2','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2Check=/*#__PURE__*/makeIcon('Calendar2Check','<path d="M10.854 8.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L7.5 10.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2CheckFill=/*#__PURE__*/makeIcon('Calendar2CheckFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-2.6 5.854a.5.5 0 0 0-.708-.708L7.5 10.793 6.354 9.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/>');// eslint-disable-next-line
var BIconCalendar2Date=/*#__PURE__*/makeIcon('Calendar2Date','<path d="M6.445 12.688V7.354h-.633A12.6 12.6 0 0 0 4.5 8.16v.695c.375-.257.969-.62 1.258-.777h.012v4.61h.675zm1.188-1.305c.047.64.594 1.406 1.703 1.406 1.258 0 2-1.066 2-2.871 0-1.934-.781-2.668-1.953-2.668-.926 0-1.797.672-1.797 1.809 0 1.16.824 1.77 1.676 1.77.746 0 1.23-.376 1.383-.79h.027c-.004 1.316-.461 2.164-1.305 2.164-.664 0-1.008-.45-1.05-.82h-.684zm2.953-2.317c0 .696-.559 1.18-1.184 1.18-.601 0-1.144-.383-1.144-1.2 0-.823.582-1.21 1.168-1.21.633 0 1.16.398 1.16 1.23z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2DateFill=/*#__PURE__*/makeIcon('Calendar2DateFill','<path d="M9.402 10.246c.625 0 1.184-.484 1.184-1.18 0-.832-.527-1.23-1.16-1.23-.586 0-1.168.387-1.168 1.21 0 .817.543 1.2 1.144 1.2z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-4.118 9.79c1.258 0 2-1.067 2-2.872 0-1.934-.781-2.668-1.953-2.668-.926 0-1.797.672-1.797 1.809 0 1.16.824 1.77 1.676 1.77.746 0 1.23-.376 1.383-.79h.027c-.004 1.316-.461 2.164-1.305 2.164-.664 0-1.008-.45-1.05-.82h-.684c.047.64.594 1.406 1.703 1.406zm-2.89-5.435h-.633A12.6 12.6 0 0 0 4.5 8.16v.695c.375-.257.969-.62 1.258-.777h.012v4.61h.675V7.354z"/>');// eslint-disable-next-line
var BIconCalendar2Day=/*#__PURE__*/makeIcon('Calendar2Day','<path d="M4.684 12.523v-2.3h2.261v-.61H4.684V7.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V9.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105zm2.805-5.093c0 .238.192.425.43.425a.428.428 0 1 0 0-.855.426.426 0 0 0-.43.43zm.094 5.093h.672V8.418h-.672v4.105z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2DayFill=/*#__PURE__*/makeIcon('Calendar2DayFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-2.24 4.855a.428.428 0 1 0 0-.855.426.426 0 0 0-.429.43c0 .238.192.425.43.425zm.337.563h-.672v4.105h.672V8.418zm-6.867 4.105v-2.3h2.261v-.61H4.684V7.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V9.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105z"/>');// eslint-disable-next-line
var BIconCalendar2Event=/*#__PURE__*/makeIcon('Calendar2Event','<path d="M11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2EventFill=/*#__PURE__*/makeIcon('Calendar2EventFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM11.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>');// eslint-disable-next-line
var BIconCalendar2Fill=/*#__PURE__*/makeIcon('Calendar2Fill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM2.545 3h10.91c.3 0 .545.224.545.5v1c0 .276-.244.5-.546.5H2.545C2.245 5 2 4.776 2 4.5v-1c0-.276.244-.5.545-.5z"/>');// eslint-disable-next-line
var BIconCalendar2Minus=/*#__PURE__*/makeIcon('Calendar2Minus','<path d="M5.5 10.5A.5.5 0 0 1 6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2MinusFill=/*#__PURE__*/makeIcon('Calendar2MinusFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM6 10a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H6z"/>');// eslint-disable-next-line
var BIconCalendar2Month=/*#__PURE__*/makeIcon('Calendar2Month','<path d="M2.56 12.332l.54-1.602h1.984l.54 1.602h.718L4.444 7h-.696L1.85 12.332h.71zm1.544-4.527L4.9 10.18H3.284l.8-2.375h.02zm5.746.422h-.676v2.543c0 .652-.414 1.023-1.004 1.023-.539 0-.98-.246-.98-1.012V8.227h-.676v2.746c0 .941.606 1.425 1.453 1.425.656 0 1.043-.28 1.188-.605h.027v.539h.668V8.227zm2.258 5.046c-.563 0-.91-.304-.985-.636h-.687c.094.683.625 1.199 1.668 1.199.93 0 1.746-.527 1.746-1.578V8.227h-.649v.578h-.019c-.191-.348-.637-.64-1.195-.64-.965 0-1.64.679-1.64 1.886v.34c0 1.23.683 1.902 1.64 1.902.558 0 1.008-.293 1.172-.648h.02v.605c0 .645-.423 1.023-1.071 1.023zm.008-4.53c.648 0 1.062.527 1.062 1.359v.253c0 .848-.39 1.364-1.062 1.364-.692 0-1.098-.512-1.098-1.364v-.253c0-.868.406-1.36 1.098-1.36z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2MonthFill=/*#__PURE__*/makeIcon('Calendar2MonthFill','<path d="M4.104 7.805L4.9 10.18H3.284l.8-2.375h.02zm9.074 2.297c0-.832-.414-1.36-1.062-1.36-.692 0-1.098.492-1.098 1.36v.253c0 .852.406 1.364 1.098 1.364.671 0 1.062-.516 1.062-1.364v-.253z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM2.561 12.332L3.1 10.73h1.984l.54 1.602h.718L4.444 7h-.696L1.85 12.332h.71zM9.85 8.227h-.676v2.543c0 .652-.414 1.023-1.004 1.023-.539 0-.98-.246-.98-1.012V8.227h-.676v2.746c0 .941.606 1.425 1.453 1.425.656 0 1.043-.28 1.188-.605h.027v.539h.668V8.227zm1.273 4.41h-.687c.094.683.625 1.199 1.668 1.199.93 0 1.746-.527 1.746-1.578V8.227h-.649v.578h-.019c-.191-.348-.637-.64-1.195-.64-.965 0-1.64.679-1.64 1.886v.34c0 1.23.683 1.902 1.64 1.902.558 0 1.008-.293 1.172-.648h.02v.605c0 .645-.423 1.023-1.071 1.023-.563 0-.91-.304-.985-.636z"/>');// eslint-disable-next-line
var BIconCalendar2Plus=/*#__PURE__*/makeIcon('Calendar2Plus','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4zM8 8a.5.5 0 0 1 .5.5V10H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V11H6a.5.5 0 0 1 0-1h1.5V8.5A.5.5 0 0 1 8 8z"/>');// eslint-disable-next-line
var BIconCalendar2PlusFill=/*#__PURE__*/makeIcon('Calendar2PlusFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 3.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5H2.545c-.3 0-.545.224-.545.5zm6.5 5a.5.5 0 0 0-1 0V10H6a.5.5 0 0 0 0 1h1.5v1.5a.5.5 0 0 0 1 0V11H10a.5.5 0 0 0 0-1H8.5V8.5z"/>');// eslint-disable-next-line
var BIconCalendar2Range=/*#__PURE__*/makeIcon('Calendar2Range','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4zM9 8a1 1 0 0 1 1-1h5v2h-5a1 1 0 0 1-1-1zm-8 2h4a1 1 0 1 1 0 2H1v-2z"/>');// eslint-disable-next-line
var BIconCalendar2RangeFill=/*#__PURE__*/makeIcon('Calendar2RangeFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM10 7a1 1 0 0 0 0 2h5V7h-5zm-4 4a1 1 0 0 0-1-1H1v2h4a1 1 0 0 0 1-1z"/>');// eslint-disable-next-line
var BIconCalendar2Week=/*#__PURE__*/makeIcon('Calendar2Week','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4zM11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-5 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/>');// eslint-disable-next-line
var BIconCalendar2WeekFill=/*#__PURE__*/makeIcon('Calendar2WeekFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM8.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm3 0a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM3 10.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zm3.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>');// eslint-disable-next-line
var BIconCalendar2X=/*#__PURE__*/makeIcon('Calendar2X','<path d="M6.146 8.146a.5.5 0 0 1 .708 0L8 9.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 10l1.147 1.146a.5.5 0 0 1-.708.708L8 10.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 10 6.146 8.854a.5.5 0 0 1 0-.708z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>');// eslint-disable-next-line
var BIconCalendar2XFill=/*#__PURE__*/makeIcon('Calendar2XFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-6.6 5.146a.5.5 0 1 0-.708.708L7.293 10l-1.147 1.146a.5.5 0 0 0 .708.708L8 10.707l1.146 1.147a.5.5 0 0 0 .708-.708L8.707 10l1.147-1.146a.5.5 0 0 0-.708-.708L8 9.293 6.854 8.146z"/>');// eslint-disable-next-line
var BIconCalendar3=/*#__PURE__*/makeIcon('Calendar3','<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M6.5 7a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-9 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-9 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconCalendar3Event=/*#__PURE__*/makeIcon('Calendar3Event','<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M12 7a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconCalendar3EventFill=/*#__PURE__*/makeIcon('Calendar3EventFill','<path fill-rule="evenodd" d="M2 0a2 2 0 0 0-2 2h16a2 2 0 0 0-2-2H2zM0 14V3h16v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm12-8a1 1 0 1 0 2 0 1 1 0 0 0-2 0z"/>');// eslint-disable-next-line
var BIconCalendar3Fill=/*#__PURE__*/makeIcon('Calendar3Fill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2H0zm0 1v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3H0z"/>');// eslint-disable-next-line
var BIconCalendar3Range=/*#__PURE__*/makeIcon('Calendar3Range','<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M7 10a1 1 0 0 0 0-2H1v2h6zm2-3h6V5H9a1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconCalendar3RangeFill=/*#__PURE__*/makeIcon('Calendar3RangeFill','<path fill-rule="evenodd" d="M2 0a2 2 0 0 0-2 2h16a2 2 0 0 0-2-2H2zM0 8V3h16v2h-6a1 1 0 1 0 0 2h6v7a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-4h6a1 1 0 1 0 0-2H0z"/>');// eslint-disable-next-line
var BIconCalendar3Week=/*#__PURE__*/makeIcon('Calendar3Week','<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M12 7a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-5 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm2-3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-5 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconCalendar3WeekFill=/*#__PURE__*/makeIcon('Calendar3WeekFill','<path fill-rule="evenodd" d="M2 0a2 2 0 0 0-2 2h16a2 2 0 0 0-2-2H2zM0 14V3h16v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm12-8a1 1 0 1 0 2 0 1 1 0 0 0-2 0zM5 9a1 1 0 1 0 2 0 1 1 0 0 0-2 0zm5-2a1 1 0 1 1 0-2 1 1 0 0 1 0 2zM2 9a1 1 0 1 0 2 0 1 1 0 0 0-2 0z"/>');// eslint-disable-next-line
var BIconCalendar4=/*#__PURE__*/makeIcon('Calendar4','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/>');// eslint-disable-next-line
var BIconCalendar4Event=/*#__PURE__*/makeIcon('Calendar4Event','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/><path d="M11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/>');// eslint-disable-next-line
var BIconCalendar4Range=/*#__PURE__*/makeIcon('Calendar4Range','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/><path d="M9 7.5a.5.5 0 0 1 .5-.5H15v2H9.5a.5.5 0 0 1-.5-.5v-1zm-2 3v1a.5.5 0 0 1-.5.5H1v-2h5.5a.5.5 0 0 1 .5.5z"/>');// eslint-disable-next-line
var BIconCalendar4Week=/*#__PURE__*/makeIcon('Calendar4Week','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/><path d="M11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-2 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/>');// eslint-disable-next-line
var BIconCalendarCheck=/*#__PURE__*/makeIcon('CalendarCheck','<path d="M10.854 7.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 9.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarCheckFill=/*#__PURE__*/makeIcon('CalendarCheckFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zm-5.146-5.146l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L7.5 10.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconCalendarDate=/*#__PURE__*/makeIcon('CalendarDate','<path d="M6.445 11.688V6.354h-.633A12.6 12.6 0 0 0 4.5 7.16v.695c.375-.257.969-.62 1.258-.777h.012v4.61h.675zm1.188-1.305c.047.64.594 1.406 1.703 1.406 1.258 0 2-1.066 2-2.871 0-1.934-.781-2.668-1.953-2.668-.926 0-1.797.672-1.797 1.809 0 1.16.824 1.77 1.676 1.77.746 0 1.23-.376 1.383-.79h.027c-.004 1.316-.461 2.164-1.305 2.164-.664 0-1.008-.45-1.05-.82h-.684zm2.953-2.317c0 .696-.559 1.18-1.184 1.18-.601 0-1.144-.383-1.144-1.2 0-.823.582-1.21 1.168-1.21.633 0 1.16.398 1.16 1.23z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarDateFill=/*#__PURE__*/makeIcon('CalendarDateFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zm5.402 9.746c.625 0 1.184-.484 1.184-1.18 0-.832-.527-1.23-1.16-1.23-.586 0-1.168.387-1.168 1.21 0 .817.543 1.2 1.144 1.2z"/><path d="M16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zm-6.664-1.21c-1.11 0-1.656-.767-1.703-1.407h.683c.043.37.387.82 1.051.82.844 0 1.301-.848 1.305-2.164h-.027c-.153.414-.637.79-1.383.79-.852 0-1.676-.61-1.676-1.77 0-1.137.871-1.809 1.797-1.809 1.172 0 1.953.734 1.953 2.668 0 1.805-.742 2.871-2 2.871zm-2.89-5.435v5.332H5.77V8.079h-.012c-.29.156-.883.52-1.258.777V8.16a12.6 12.6 0 0 1 1.313-.805h.632z"/>');// eslint-disable-next-line
var BIconCalendarDay=/*#__PURE__*/makeIcon('CalendarDay','<path d="M4.684 11.523v-2.3h2.261v-.61H4.684V6.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V8.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105zm2.805-5.093c0 .238.192.425.43.425a.428.428 0 1 0 0-.855.426.426 0 0 0-.43.43zm.094 5.093h.672V7.418h-.672v4.105z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarDayFill=/*#__PURE__*/makeIcon('CalendarDayFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V5h16v9zm-4.785-6.145a.428.428 0 1 0 0-.855.426.426 0 0 0-.43.43c0 .238.192.425.43.425zm.336.563h-.672v4.105h.672V8.418zm-6.867 4.105v-2.3h2.261v-.61H4.684V7.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V9.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105z"/>');// eslint-disable-next-line
var BIconCalendarEvent=/*#__PURE__*/makeIcon('CalendarEvent','<path d="M11 6.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarEventFill=/*#__PURE__*/makeIcon('CalendarEventFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zm-3.5-7h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconCalendarFill=/*#__PURE__*/makeIcon('CalendarFill','<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V5h16V4H0V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconCalendarMinus=/*#__PURE__*/makeIcon('CalendarMinus','<path d="M5.5 9.5A.5.5 0 0 1 6 9h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarMinusFill=/*#__PURE__*/makeIcon('CalendarMinusFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconCalendarMonth=/*#__PURE__*/makeIcon('CalendarMonth','<path d="M2.56 11.332L3.1 9.73h1.984l.54 1.602h.718L4.444 6h-.696L1.85 11.332h.71zm1.544-4.527L4.9 9.18H3.284l.8-2.375h.02zm5.746.422h-.676V9.77c0 .652-.414 1.023-1.004 1.023-.539 0-.98-.246-.98-1.012V7.227h-.676v2.746c0 .941.606 1.425 1.453 1.425.656 0 1.043-.28 1.188-.605h.027v.539h.668V7.227zm2.258 5.046c-.563 0-.91-.304-.985-.636h-.687c.094.683.625 1.199 1.668 1.199.93 0 1.746-.527 1.746-1.578V7.227h-.649v.578h-.019c-.191-.348-.637-.64-1.195-.64-.965 0-1.64.679-1.64 1.886v.34c0 1.23.683 1.902 1.64 1.902.558 0 1.008-.293 1.172-.648h.02v.605c0 .645-.423 1.023-1.071 1.023zm.008-4.53c.648 0 1.062.527 1.062 1.359v.253c0 .848-.39 1.364-1.062 1.364-.692 0-1.098-.512-1.098-1.364v-.253c0-.868.406-1.36 1.098-1.36z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarMonthFill=/*#__PURE__*/makeIcon('CalendarMonthFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zm.104 7.305L4.9 10.18H3.284l.8-2.375h.02zm9.074 2.297c0-.832-.414-1.36-1.062-1.36-.692 0-1.098.492-1.098 1.36v.253c0 .852.406 1.364 1.098 1.364.671 0 1.062-.516 1.062-1.364v-.253z"/><path d="M16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM2.56 12.332h-.71L3.748 7h.696l1.898 5.332h-.719l-.539-1.602H3.1l-.54 1.602zm7.29-4.105v4.105h-.668v-.539h-.027c-.145.324-.532.605-1.188.605-.847 0-1.453-.484-1.453-1.425V8.227h.676v2.554c0 .766.441 1.012.98 1.012.59 0 1.004-.371 1.004-1.023V8.227h.676zm1.273 4.41c.075.332.422.636.985.636.648 0 1.07-.378 1.07-1.023v-.605h-.02c-.163.355-.613.648-1.171.648-.957 0-1.64-.672-1.64-1.902v-.34c0-1.207.675-1.887 1.64-1.887.558 0 1.004.293 1.195.64h.02v-.577h.648v4.03c0 1.052-.816 1.579-1.746 1.579-1.043 0-1.574-.516-1.668-1.2h.687z"/>');// eslint-disable-next-line
var BIconCalendarPlus=/*#__PURE__*/makeIcon('CalendarPlus','<path d="M8 7a.5.5 0 0 1 .5.5V9H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V10H6a.5.5 0 0 1 0-1h1.5V7.5A.5.5 0 0 1 8 7z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarPlusFill=/*#__PURE__*/makeIcon('CalendarPlusFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM8.5 8.5V10H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V11H6a.5.5 0 0 1 0-1h1.5V8.5a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconCalendarRange=/*#__PURE__*/makeIcon('CalendarRange','<path d="M9 7a1 1 0 0 1 1-1h5v2h-5a1 1 0 0 1-1-1zM1 9h4a1 1 0 0 1 0 2H1V9z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarRangeFill=/*#__PURE__*/makeIcon('CalendarRangeFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 7V5H0v5h5a1 1 0 1 1 0 2H0v2a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9h-6a1 1 0 1 1 0-2h6z"/>');// eslint-disable-next-line
var BIconCalendarWeek=/*#__PURE__*/makeIcon('CalendarWeek','<path d="M11 6.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-5 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarWeekFill=/*#__PURE__*/makeIcon('CalendarWeekFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM9.5 7h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5zm3 0h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5zM2 10.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3.5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconCalendarX=/*#__PURE__*/makeIcon('CalendarX','<path d="M6.146 7.146a.5.5 0 0 1 .708 0L8 8.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 9l1.147 1.146a.5.5 0 0 1-.708.708L8 9.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 9 6.146 7.854a.5.5 0 0 1 0-.708z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>');// eslint-disable-next-line
var BIconCalendarXFill=/*#__PURE__*/makeIcon('CalendarXFill','<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM6.854 8.146L8 9.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 10l1.147 1.146a.5.5 0 0 1-.708.708L8 10.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 10 6.146 8.854a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconCamera=/*#__PURE__*/makeIcon('Camera','<path d="M15 12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h1.172a3 3 0 0 0 2.12-.879l.83-.828A1 1 0 0 1 6.827 3h2.344a1 1 0 0 1 .707.293l.828.828A3 3 0 0 0 12.828 5H14a1 1 0 0 1 1 1v6zM2 4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-1.172a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 9.172 2H6.828a2 2 0 0 0-1.414.586l-.828.828A2 2 0 0 1 3.172 4H2z"/><path d="M8 11a2.5 2.5 0 1 1 0-5 2.5 2.5 0 0 1 0 5zm0 1a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7zM3 6.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconCamera2=/*#__PURE__*/makeIcon('Camera2','<path d="M5 8c0-1.657 2.343-3 4-3V4a4 4 0 0 0-4 4z"/><path d="M12.318 3h2.015C15.253 3 16 3.746 16 4.667v6.666c0 .92-.746 1.667-1.667 1.667h-2.015A5.97 5.97 0 0 1 9 14a5.972 5.972 0 0 1-3.318-1H1.667C.747 13 0 12.254 0 11.333V4.667C0 3.747.746 3 1.667 3H2a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1h.682A5.97 5.97 0 0 1 9 2c1.227 0 2.367.368 3.318 1zM2 4.5a.5.5 0 1 0-1 0 .5.5 0 0 0 1 0zM14 8A5 5 0 1 0 4 8a5 5 0 0 0 10 0z"/>');// eslint-disable-next-line
var BIconCameraFill=/*#__PURE__*/makeIcon('CameraFill','<path d="M10.5 8.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0z"/><path d="M2 4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-1.172a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 9.172 2H6.828a2 2 0 0 0-1.414.586l-.828.828A2 2 0 0 1 3.172 4H2zm.5 2a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm9 2.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0z"/>');// eslint-disable-next-line
var BIconCameraReels=/*#__PURE__*/makeIcon('CameraReels','<path d="M6 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0zM1 3a2 2 0 1 0 4 0 2 2 0 0 0-4 0z"/><path d="M9 6h.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 7.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 16H2a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h7zm6 8.73V7.27l-3.5 1.555v4.35l3.5 1.556zM1 8v6a1 1 0 0 0 1 1h7.5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1z"/><path d="M9 6a3 3 0 1 0 0-6 3 3 0 0 0 0 6zM7 3a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/>');// eslint-disable-next-line
var BIconCameraReelsFill=/*#__PURE__*/makeIcon('CameraReelsFill','<path d="M6 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M9 6a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/><path d="M9 6h.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 7.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 16H2a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h7z"/>');// eslint-disable-next-line
var BIconCameraVideo=/*#__PURE__*/makeIcon('CameraVideo','<path fill-rule="evenodd" d="M0 5a2 2 0 0 1 2-2h7.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 4.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 13H2a2 2 0 0 1-2-2V5zm11.5 5.175l3.5 1.556V4.269l-3.5 1.556v4.35zM2 4a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h7.5a1 1 0 0 0 1-1V5a1 1 0 0 0-1-1H2z"/>');// eslint-disable-next-line
var BIconCameraVideoFill=/*#__PURE__*/makeIcon('CameraVideoFill','<path fill-rule="evenodd" d="M0 5a2 2 0 0 1 2-2h7.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 4.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 13H2a2 2 0 0 1-2-2V5z"/>');// eslint-disable-next-line
var BIconCameraVideoOff=/*#__PURE__*/makeIcon('CameraVideoOff','<path fill-rule="evenodd" d="M10.961 12.365a1.99 1.99 0 0 0 .522-1.103l3.11 1.382A1 1 0 0 0 16 11.731V4.269a1 1 0 0 0-1.406-.913l-3.111 1.382A2 2 0 0 0 9.5 3H4.272l.714 1H9.5a1 1 0 0 1 1 1v6a1 1 0 0 1-.144.518l.605.847zM1.428 4.18A.999.999 0 0 0 1 5v6a1 1 0 0 0 1 1h5.014l.714 1H2a2 2 0 0 1-2-2V5c0-.675.334-1.272.847-1.634l.58.814zM15 11.73l-3.5-1.555v-4.35L15 4.269v7.462zm-4.407 3.56l-10-14 .814-.58 10 14-.814.58z"/>');// eslint-disable-next-line
var BIconCameraVideoOffFill=/*#__PURE__*/makeIcon('CameraVideoOffFill','<path fill-rule="evenodd" d="M10.961 12.365a1.99 1.99 0 0 0 .522-1.103l3.11 1.382A1 1 0 0 0 16 11.731V4.269a1 1 0 0 0-1.406-.913l-3.111 1.382A2 2 0 0 0 9.5 3H4.272l6.69 9.365zm-10.114-9A2.001 2.001 0 0 0 0 5v6a2 2 0 0 0 2 2h5.728L.847 3.366zm9.746 11.925l-10-14 .814-.58 10 14-.814.58z"/>');// eslint-disable-next-line
var BIconCapslock=/*#__PURE__*/makeIcon('Capslock','<path fill-rule="evenodd" d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1H1.654C.78 9.5.326 8.455.924 7.816L7.27 1.047zM14.346 8.5L8 1.731 1.654 8.5H4.5a1 1 0 0 1 1 1v1h5v-1a1 1 0 0 1 1-1h2.846zm-9.846 5a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1zm6 0h-5v1h5v-1z"/>');// eslint-disable-next-line
var BIconCapslockFill=/*#__PURE__*/makeIcon('CapslockFill','<path d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1H1.654C.78 9.5.326 8.455.924 7.816L7.27 1.047zM4.5 13.5a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1z"/>');// eslint-disable-next-line
var BIconCardChecklist=/*#__PURE__*/makeIcon('CardChecklist','<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M7 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm-1.496-.854a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 1 1 .708-.708l.146.147 1.146-1.147a.5.5 0 0 1 .708 0zM7 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm-1.496-.854a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 0 1 .708-.708l.146.147 1.146-1.147a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconCardHeading=/*#__PURE__*/makeIcon('CardHeading','<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M3 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0-5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5v-1z"/>');// eslint-disable-next-line
var BIconCardImage=/*#__PURE__*/makeIcon('CardImage','<path d="M6.002 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M1.5 2A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13zm13 1a.5.5 0 0 1 .5.5v6l-3.775-1.947a.5.5 0 0 0-.577.093l-3.71 3.71-2.66-1.772a.5.5 0 0 0-.63.062L1.002 12v.54A.505.505 0 0 1 1 12.5v-9a.5.5 0 0 1 .5-.5h13z"/>');// eslint-disable-next-line
var BIconCardList=/*#__PURE__*/makeIcon('CardList','<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M5 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 5 8zm0-2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0 5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-1-5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zM4 8a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm0 2.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconCardText=/*#__PURE__*/makeIcon('CardText','<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M3 5.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 8zm0 2.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconCaretDown=/*#__PURE__*/makeIcon('CaretDown','<path d="M3.204 5h9.592L8 10.481 3.204 5zm-.753.659l4.796 5.48a1 1 0 0 0 1.506 0l4.796-5.48c.566-.647.106-1.659-.753-1.659H3.204a1 1 0 0 0-.753 1.659z"/>');// eslint-disable-next-line
var BIconCaretDownFill=/*#__PURE__*/makeIcon('CaretDownFill','<path d="M7.247 11.14L2.451 5.658C1.885 5.013 2.345 4 3.204 4h9.592a1 1 0 0 1 .753 1.659l-4.796 5.48a1 1 0 0 1-1.506 0z"/>');// eslint-disable-next-line
var BIconCaretDownSquare=/*#__PURE__*/makeIcon('CaretDownSquare','<path d="M3.626 6.832A.5.5 0 0 1 4 6h8a.5.5 0 0 1 .374.832l-4 4.5a.5.5 0 0 1-.748 0l-4-4.5z"/><path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V2z"/>');// eslint-disable-next-line
var BIconCaretDownSquareFill=/*#__PURE__*/makeIcon('CaretDownSquareFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm4 4a.5.5 0 0 0-.374.832l4 4.5a.5.5 0 0 0 .748 0l4-4.5A.5.5 0 0 0 12 6H4z"/>');// eslint-disable-next-line
var BIconCaretLeft=/*#__PURE__*/makeIcon('CaretLeft','<path d="M10 12.796V3.204L4.519 8 10 12.796zm-.659.753l-5.48-4.796a1 1 0 0 1 0-1.506l5.48-4.796A1 1 0 0 1 11 3.204v9.592a1 1 0 0 1-1.659.753z"/>');// eslint-disable-next-line
var BIconCaretLeftFill=/*#__PURE__*/makeIcon('CaretLeftFill','<path d="M3.86 8.753l5.482 4.796c.646.566 1.658.106 1.658-.753V3.204a1 1 0 0 0-1.659-.753l-5.48 4.796a1 1 0 0 0 0 1.506z"/>');// eslint-disable-next-line
var BIconCaretLeftSquare=/*#__PURE__*/makeIcon('CaretLeftSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M10.205 12.456A.5.5 0 0 0 10.5 12V4a.5.5 0 0 0-.832-.374l-4.5 4a.5.5 0 0 0 0 .748l4.5 4a.5.5 0 0 0 .537.082z"/>');// eslint-disable-next-line
var BIconCaretLeftSquareFill=/*#__PURE__*/makeIcon('CaretLeftSquareFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm10.5 10V4a.5.5 0 0 0-.832-.374l-4.5 4a.5.5 0 0 0 0 .748l4.5 4A.5.5 0 0 0 10.5 12z"/>');// eslint-disable-next-line
var BIconCaretRight=/*#__PURE__*/makeIcon('CaretRight','<path d="M6 12.796V3.204L11.481 8 6 12.796zm.659.753l5.48-4.796a1 1 0 0 0 0-1.506L6.66 2.451C6.011 1.885 5 2.345 5 3.204v9.592a1 1 0 0 0 1.659.753z"/>');// eslint-disable-next-line
var BIconCaretRightFill=/*#__PURE__*/makeIcon('CaretRightFill','<path d="M12.14 8.753l-5.482 4.796c-.646.566-1.658.106-1.658-.753V3.204a1 1 0 0 1 1.659-.753l5.48 4.796a1 1 0 0 1 0 1.506z"/>');// eslint-disable-next-line
var BIconCaretRightSquare=/*#__PURE__*/makeIcon('CaretRightSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5.795 12.456A.5.5 0 0 1 5.5 12V4a.5.5 0 0 1 .832-.374l4.5 4a.5.5 0 0 1 0 .748l-4.5 4a.5.5 0 0 1-.537.082z"/>');// eslint-disable-next-line
var BIconCaretRightSquareFill=/*#__PURE__*/makeIcon('CaretRightSquareFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm5.5 10a.5.5 0 0 0 .832.374l4.5-4a.5.5 0 0 0 0-.748l-4.5-4A.5.5 0 0 0 5.5 4v8z"/>');// eslint-disable-next-line
var BIconCaretUp=/*#__PURE__*/makeIcon('CaretUp','<path d="M3.204 11h9.592L8 5.519 3.204 11zm-.753-.659l4.796-5.48a1 1 0 0 1 1.506 0l4.796 5.48c.566.647.106 1.659-.753 1.659H3.204a1 1 0 0 1-.753-1.659z"/>');// eslint-disable-next-line
var BIconCaretUpFill=/*#__PURE__*/makeIcon('CaretUpFill','<path d="M7.247 4.86l-4.796 5.481c-.566.647-.106 1.659.753 1.659h9.592a1 1 0 0 0 .753-1.659l-4.796-5.48a1 1 0 0 0-1.506 0z"/>');// eslint-disable-next-line
var BIconCaretUpSquare=/*#__PURE__*/makeIcon('CaretUpSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M3.544 10.705A.5.5 0 0 0 4 11h8a.5.5 0 0 0 .374-.832l-4-4.5a.5.5 0 0 0-.748 0l-4 4.5a.5.5 0 0 0-.082.537z"/>');// eslint-disable-next-line
var BIconCaretUpSquareFill=/*#__PURE__*/makeIcon('CaretUpSquareFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm4 9h8a.5.5 0 0 0 .374-.832l-4-4.5a.5.5 0 0 0-.748 0l-4 4.5A.5.5 0 0 0 4 11z"/>');// eslint-disable-next-line
var BIconCart=/*#__PURE__*/makeIcon('Cart','<path d="M0 1.5A.5.5 0 0 1 .5 1H2a.5.5 0 0 1 .485.379L2.89 3H14.5a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 13 12H4a.5.5 0 0 1-.491-.408L2.01 3.607 1.61 2H.5a.5.5 0 0 1-.5-.5zM3.102 4l1.313 7h8.17l1.313-7H3.102zM5 12a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm7 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm-7 1a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm7 0a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconCart2=/*#__PURE__*/makeIcon('Cart2','<path d="M0 2.5A.5.5 0 0 1 .5 2H2a.5.5 0 0 1 .485.379L2.89 4H14.5a.5.5 0 0 1 .485.621l-1.5 6A.5.5 0 0 1 13 11H4a.5.5 0 0 1-.485-.379L1.61 3H.5a.5.5 0 0 1-.5-.5zM3.14 5l1.25 5h8.22l1.25-5H3.14zM5 13a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0zm9-1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/>');// eslint-disable-next-line
var BIconCart3=/*#__PURE__*/makeIcon('Cart3','<path d="M0 1.5A.5.5 0 0 1 .5 1H2a.5.5 0 0 1 .485.379L2.89 3H14.5a.5.5 0 0 1 .49.598l-1 5a.5.5 0 0 1-.465.401l-9.397.472L4.415 11H13a.5.5 0 0 1 0 1H4a.5.5 0 0 1-.491-.408L2.01 3.607 1.61 2H.5a.5.5 0 0 1-.5-.5zM3.102 4l.84 4.479 9.144-.459L13.89 4H3.102zM5 12a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm7 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm-7 1a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm7 0a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconCart4=/*#__PURE__*/makeIcon('Cart4','<path d="M0 2.5A.5.5 0 0 1 .5 2H2a.5.5 0 0 1 .485.379L2.89 4H14.5a.5.5 0 0 1 .485.621l-1.5 6A.5.5 0 0 1 13 11H4a.5.5 0 0 1-.485-.379L1.61 3H.5a.5.5 0 0 1-.5-.5zM3.14 5l.5 2H5V5H3.14zM6 5v2h2V5H6zm3 0v2h2V5H9zm3 0v2h1.36l.5-2H12zm1.11 3H12v2h.61l.5-2zM11 8H9v2h2V8zM8 8H6v2h2V8zM5 8H3.89l.5 2H5V8zm0 5a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0zm9-1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/>');// eslint-disable-next-line
var BIconCartCheck=/*#__PURE__*/makeIcon('CartCheck','<path d="M11.354 6.354a.5.5 0 0 0-.708-.708L8 8.293 6.854 7.146a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconCartCheckFill=/*#__PURE__*/makeIcon('CartCheckFill','<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-1.646-7.646l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L8 8.293l2.646-2.647a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconCartDash=/*#__PURE__*/makeIcon('CartDash','<path d="M6.5 7a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1h-4z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconCartDashFill=/*#__PURE__*/makeIcon('CartDashFill','<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM6.5 7h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconCartFill=/*#__PURE__*/makeIcon('CartFill','<path d="M0 1.5A.5.5 0 0 1 .5 1H2a.5.5 0 0 1 .485.379L2.89 3H14.5a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 13 12H4a.5.5 0 0 1-.491-.408L2.01 3.607 1.61 2H.5a.5.5 0 0 1-.5-.5zM5 12a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm7 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm-7 1a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm7 0a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconCartPlus=/*#__PURE__*/makeIcon('CartPlus','<path d="M9 5.5a.5.5 0 0 0-1 0V7H6.5a.5.5 0 0 0 0 1H8v1.5a.5.5 0 0 0 1 0V8h1.5a.5.5 0 0 0 0-1H9V5.5z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconCartPlusFill=/*#__PURE__*/makeIcon('CartPlusFill','<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM9 5.5V7h1.5a.5.5 0 0 1 0 1H9v1.5a.5.5 0 0 1-1 0V8H6.5a.5.5 0 0 1 0-1H8V5.5a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconCartX=/*#__PURE__*/makeIcon('CartX','<path d="M7.354 5.646a.5.5 0 1 0-.708.708L7.793 7.5 6.646 8.646a.5.5 0 1 0 .708.708L8.5 8.207l1.146 1.147a.5.5 0 0 0 .708-.708L9.207 7.5l1.147-1.146a.5.5 0 0 0-.708-.708L8.5 6.793 7.354 5.646z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconCartXFill=/*#__PURE__*/makeIcon('CartXFill','<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM7.354 5.646L8.5 6.793l1.146-1.147a.5.5 0 0 1 .708.708L9.207 7.5l1.147 1.146a.5.5 0 0 1-.708.708L8.5 8.207 7.354 9.354a.5.5 0 1 1-.708-.708L7.793 7.5 6.646 6.354a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconCash=/*#__PURE__*/makeIcon('Cash','<path d="M8 10a2 2 0 1 0 0-4 2 2 0 0 0 0 4z"/><path d="M0 4a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V4zm3 0a2 2 0 0 1-2 2v4a2 2 0 0 1 2 2h10a2 2 0 0 1 2-2V6a2 2 0 0 1-2-2H3z"/>');// eslint-disable-next-line
var BIconCashStack=/*#__PURE__*/makeIcon('CashStack','<path d="M1 3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1H1zm7 8a2 2 0 1 0 0-4 2 2 0 0 0 0 4z"/><path d="M0 5a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V5zm3 0a2 2 0 0 1-2 2v4a2 2 0 0 1 2 2h10a2 2 0 0 1 2-2V7a2 2 0 0 1-2-2H3z"/>');// eslint-disable-next-line
var BIconCast=/*#__PURE__*/makeIcon('Cast','<path d="M7.646 9.354l-3.792 3.792a.5.5 0 0 0 .353.854h7.586a.5.5 0 0 0 .354-.854L8.354 9.354a.5.5 0 0 0-.708 0z"/><path d="M11.414 11H14.5a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-13a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h3.086l-1 1H1.5A1.5 1.5 0 0 1 0 10.5v-7A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v7a1.5 1.5 0 0 1-1.5 1.5h-2.086l-1-1z"/>');// eslint-disable-next-line
var BIconChat=/*#__PURE__*/makeIcon('Chat','<path d="M2.678 11.894a1 1 0 0 1 .287.801 10.97 10.97 0 0 1-.398 2c1.395-.323 2.247-.697 2.634-.893a1 1 0 0 1 .71-.074A8.06 8.06 0 0 0 8 14c3.996 0 7-2.807 7-6 0-3.192-3.004-6-7-6S1 4.808 1 8c0 1.468.617 2.83 1.678 3.894zm-.493 3.905a21.682 21.682 0 0 1-.713.129c-.2.032-.352-.176-.273-.362a9.68 9.68 0 0 0 .244-.637l.003-.01c.248-.72.45-1.548.524-2.319C.743 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.52.263-1.639.742-3.468 1.105z"/>');// eslint-disable-next-line
var BIconChatDots=/*#__PURE__*/makeIcon('ChatDots','<path d="M5 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/><path d="M2.165 15.803l.02-.004c1.83-.363 2.948-.842 3.468-1.105A9.06 9.06 0 0 0 8 15c4.418 0 8-3.134 8-7s-3.582-7-8-7-8 3.134-8 7c0 1.76.743 3.37 1.97 4.6a10.437 10.437 0 0 1-.524 2.318l-.003.011a10.722 10.722 0 0 1-.244.637c-.079.186.074.394.273.362a21.673 21.673 0 0 0 .693-.125zm.8-3.108a1 1 0 0 0-.287-.801C1.618 10.83 1 9.468 1 8c0-3.192 3.004-6 7-6s7 2.808 7 6c0 3.193-3.004 6-7 6a8.06 8.06 0 0 1-2.088-.272 1 1 0 0 0-.711.074c-.387.196-1.24.57-2.634.893a10.97 10.97 0 0 0 .398-2z"/>');// eslint-disable-next-line
var BIconChatDotsFill=/*#__PURE__*/makeIcon('ChatDotsFill','<path d="M16 8c0 3.866-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.584.296-1.925.864-4.181 1.234-.2.032-.352-.176-.273-.362.354-.836.674-1.95.77-2.966C.744 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7zM5 8a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm4 0a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconChatFill=/*#__PURE__*/makeIcon('ChatFill','<path d="M8 15c4.418 0 8-3.134 8-7s-3.582-7-8-7-8 3.134-8 7c0 1.76.743 3.37 1.97 4.6-.097 1.016-.417 2.13-.771 2.966-.079.186.074.394.273.362 2.256-.37 3.597-.938 4.18-1.234A9.06 9.06 0 0 0 8 15z"/>');// eslint-disable-next-line
var BIconChatLeft=/*#__PURE__*/makeIcon('ChatLeft','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconChatLeftDots=/*#__PURE__*/makeIcon('ChatLeftDots','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconChatLeftDotsFill=/*#__PURE__*/makeIcon('ChatLeftDotsFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H4.414a1 1 0 0 0-.707.293L.854 15.146A.5.5 0 0 1 0 14.793V2zm5 4a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm4 0a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconChatLeftFill=/*#__PURE__*/makeIcon('ChatLeftFill','<path d="M2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconChatLeftQuote=/*#__PURE__*/makeIcon('ChatLeftQuote','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M7.066 4.76A1.665 1.665 0 0 0 4 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>');// eslint-disable-next-line
var BIconChatLeftQuoteFill=/*#__PURE__*/makeIcon('ChatLeftQuoteFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H4.414a1 1 0 0 0-.707.293L.854 15.146A.5.5 0 0 1 0 14.793V2zm7.194 2.766a1.688 1.688 0 0 0-.227-.272 1.467 1.467 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 5.734 4C4.776 4 4 4.746 4 5.667c0 .92.776 1.666 1.734 1.666.343 0 .662-.095.931-.26-.137.389-.39.804-.81 1.22a.405.405 0 0 0 .011.59c.173.16.447.155.614-.01 1.334-1.329 1.37-2.758.941-3.706a2.461 2.461 0 0 0-.227-.4zM11 7.073c-.136.389-.39.804-.81 1.22a.405.405 0 0 0 .012.59c.172.16.446.155.613-.01 1.334-1.329 1.37-2.758.942-3.706a2.466 2.466 0 0 0-.228-.4 1.686 1.686 0 0 0-.227-.273 1.466 1.466 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 10.07 4c-.957 0-1.734.746-1.734 1.667 0 .92.777 1.666 1.734 1.666.343 0 .662-.095.931-.26z"/>');// eslint-disable-next-line
var BIconChatLeftText=/*#__PURE__*/makeIcon('ChatLeftText','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M3 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 6a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 6zm0 2.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconChatLeftTextFill=/*#__PURE__*/makeIcon('ChatLeftTextFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H4.414a1 1 0 0 0-.707.293L.854 15.146A.5.5 0 0 1 0 14.793V2zm3.5 1a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/>');// eslint-disable-next-line
var BIconChatQuote=/*#__PURE__*/makeIcon('ChatQuote','<path d="M2.678 11.894a1 1 0 0 1 .287.801 10.97 10.97 0 0 1-.398 2c1.395-.323 2.247-.697 2.634-.893a1 1 0 0 1 .71-.074A8.06 8.06 0 0 0 8 14c3.996 0 7-2.807 7-6 0-3.192-3.004-6-7-6S1 4.808 1 8c0 1.468.617 2.83 1.678 3.894zm-.493 3.905a21.682 21.682 0 0 1-.713.129c-.2.032-.352-.176-.273-.362a9.68 9.68 0 0 0 .244-.637l.003-.01c.248-.72.45-1.548.524-2.319C.743 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.52.263-1.639.742-3.468 1.105z"/><path d="M7.066 6.76A1.665 1.665 0 0 0 4 7.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 0 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 7.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 0 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>');// eslint-disable-next-line
var BIconChatQuoteFill=/*#__PURE__*/makeIcon('ChatQuoteFill','<path d="M16 8c0 3.866-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.584.296-1.925.864-4.181 1.234-.2.032-.352-.176-.273-.362.354-.836.674-1.95.77-2.966C.744 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7zM7.194 6.766a1.688 1.688 0 0 0-.227-.272 1.467 1.467 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 5.734 6C4.776 6 4 6.746 4 7.667c0 .92.776 1.666 1.734 1.666.343 0 .662-.095.931-.26-.137.389-.39.804-.81 1.22a.405.405 0 0 0 .011.59c.173.16.447.155.614-.01 1.334-1.329 1.37-2.758.941-3.706a2.461 2.461 0 0 0-.227-.4zM11 9.073c-.136.389-.39.804-.81 1.22a.405.405 0 0 0 .012.59c.172.16.446.155.613-.01 1.334-1.329 1.37-2.758.942-3.706a2.466 2.466 0 0 0-.228-.4 1.686 1.686 0 0 0-.227-.273 1.466 1.466 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 10.07 6c-.957 0-1.734.746-1.734 1.667 0 .92.777 1.666 1.734 1.666.343 0 .662-.095.931-.26z"/>');// eslint-disable-next-line
var BIconChatRight=/*#__PURE__*/makeIcon('ChatRight','<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/>');// eslint-disable-next-line
var BIconChatRightDots=/*#__PURE__*/makeIcon('ChatRightDots','<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/><path d="M5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconChatRightDotsFill=/*#__PURE__*/makeIcon('ChatRightDotsFill','<path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h9.586a1 1 0 0 1 .707.293l2.853 2.853a.5.5 0 0 0 .854-.353V2zM5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 1a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>');// eslint-disable-next-line
var BIconChatRightFill=/*#__PURE__*/makeIcon('ChatRightFill','<path d="M14 0a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/>');// eslint-disable-next-line
var BIconChatRightQuote=/*#__PURE__*/makeIcon('ChatRightQuote','<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/><path d="M7.066 4.76A1.665 1.665 0 0 0 4 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>');// eslint-disable-next-line
var BIconChatRightQuoteFill=/*#__PURE__*/makeIcon('ChatRightQuoteFill','<path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h9.586a1 1 0 0 1 .707.293l2.853 2.853a.5.5 0 0 0 .854-.353V2zM7.194 4.766c.087.124.163.26.227.401.428.948.393 2.377-.942 3.706a.446.446 0 0 1-.612.01.405.405 0 0 1-.011-.59c.419-.416.672-.831.809-1.22-.269.165-.588.26-.93.26C4.775 7.333 4 6.587 4 5.667 4 4.747 4.776 4 5.734 4c.271 0 .528.06.756.166l.008.004c.169.07.327.182.469.324.085.083.161.174.227.272zM11 7.073c-.269.165-.588.26-.93.26-.958 0-1.735-.746-1.735-1.666 0-.92.777-1.667 1.734-1.667.271 0 .528.06.756.166l.008.004c.17.07.327.182.469.324.085.083.161.174.227.272.087.124.164.26.228.401.428.948.392 2.377-.942 3.706a.446.446 0 0 1-.613.01.405.405 0 0 1-.011-.59c.42-.416.672-.831.81-1.22z"/>');// eslint-disable-next-line
var BIconChatRightText=/*#__PURE__*/makeIcon('ChatRightText','<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/><path d="M3 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 6a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 6zm0 2.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconChatRightTextFill=/*#__PURE__*/makeIcon('ChatRightTextFill','<path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h9.586a1 1 0 0 1 .707.293l2.853 2.853a.5.5 0 0 0 .854-.353V2zM3.5 3h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1 0-1zm0 2.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1 0-1zm0 2.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconChatSquare=/*#__PURE__*/makeIcon('ChatSquare','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconChatSquareDots=/*#__PURE__*/makeIcon('ChatSquareDots','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconChatSquareDotsFill=/*#__PURE__*/makeIcon('ChatSquareDotsFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.5a1 1 0 0 0-.8.4l-1.9 2.533a1 1 0 0 1-1.6 0L5.3 12.4a1 1 0 0 0-.8-.4H2a2 2 0 0 1-2-2V2zm5 4a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm4 0a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconChatSquareFill=/*#__PURE__*/makeIcon('ChatSquareFill','<path d="M2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconChatSquareQuote=/*#__PURE__*/makeIcon('ChatSquareQuote','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M7.066 4.76A1.665 1.665 0 0 0 4 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>');// eslint-disable-next-line
var BIconChatSquareQuoteFill=/*#__PURE__*/makeIcon('ChatSquareQuoteFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.5a1 1 0 0 0-.8.4l-1.9 2.533a1 1 0 0 1-1.6 0L5.3 12.4a1 1 0 0 0-.8-.4H2a2 2 0 0 1-2-2V2zm7.194 2.766a1.688 1.688 0 0 0-.227-.272 1.467 1.467 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 5.734 4C4.776 4 4 4.746 4 5.667c0 .92.776 1.666 1.734 1.666.343 0 .662-.095.931-.26-.137.389-.39.804-.81 1.22a.405.405 0 0 0 .011.59c.173.16.447.155.614-.01 1.334-1.329 1.37-2.758.941-3.706a2.461 2.461 0 0 0-.227-.4zM11 7.073c-.136.389-.39.804-.81 1.22a.405.405 0 0 0 .012.59c.172.16.446.155.613-.01 1.334-1.329 1.37-2.758.942-3.706a2.466 2.466 0 0 0-.228-.4 1.686 1.686 0 0 0-.227-.273 1.466 1.466 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 10.07 4c-.957 0-1.734.746-1.734 1.667 0 .92.777 1.666 1.734 1.666.343 0 .662-.095.931-.26z"/>');// eslint-disable-next-line
var BIconChatSquareText=/*#__PURE__*/makeIcon('ChatSquareText','<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M3 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 6a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 6zm0 2.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconChatSquareTextFill=/*#__PURE__*/makeIcon('ChatSquareTextFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.5a1 1 0 0 0-.8.4l-1.9 2.533a1 1 0 0 1-1.6 0L5.3 12.4a1 1 0 0 0-.8-.4H2a2 2 0 0 1-2-2V2zm3.5 1a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/>');// eslint-disable-next-line
var BIconChatText=/*#__PURE__*/makeIcon('ChatText','<path d="M2.678 11.894a1 1 0 0 1 .287.801 10.97 10.97 0 0 1-.398 2c1.395-.323 2.247-.697 2.634-.893a1 1 0 0 1 .71-.074A8.06 8.06 0 0 0 8 14c3.996 0 7-2.807 7-6 0-3.192-3.004-6-7-6S1 4.808 1 8c0 1.468.617 2.83 1.678 3.894zm-.493 3.905a21.682 21.682 0 0 1-.713.129c-.2.032-.352-.176-.273-.362a9.68 9.68 0 0 0 .244-.637l.003-.01c.248-.72.45-1.548.524-2.319C.743 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.52.263-1.639.742-3.468 1.105z"/><path d="M4 5.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8zm0 2.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconChatTextFill=/*#__PURE__*/makeIcon('ChatTextFill','<path d="M16 8c0 3.866-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.584.296-1.925.864-4.181 1.234-.2.032-.352-.176-.273-.362.354-.836.674-1.95.77-2.966C.744 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7zM4.5 5a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-7zm0 2.5a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-7zm0 2.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1h-4z"/>');// eslint-disable-next-line
var BIconCheck=/*#__PURE__*/makeIcon('Check','<path d="M10.97 4.97a.75.75 0 0 1 1.07 1.05l-3.99 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.267.267 0 0 1 .02-.022z"/>');// eslint-disable-next-line
var BIconCheck2=/*#__PURE__*/makeIcon('Check2','<path d="M13.854 3.646a.5.5 0 0 1 0 .708l-7 7a.5.5 0 0 1-.708 0l-3.5-3.5a.5.5 0 1 1 .708-.708L6.5 10.293l6.646-6.647a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconCheck2All=/*#__PURE__*/makeIcon('Check2All','<path d="M12.354 4.354a.5.5 0 0 0-.708-.708L5 10.293 1.854 7.146a.5.5 0 1 0-.708.708l3.5 3.5a.5.5 0 0 0 .708 0l7-7zm-4.208 7l-.896-.897.707-.707.543.543 6.646-6.647a.5.5 0 0 1 .708.708l-7 7a.5.5 0 0 1-.708 0z"/><path d="M5.354 7.146l.896.897-.707.707-.897-.896a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconCheck2Circle=/*#__PURE__*/makeIcon('Check2Circle','<path d="M2.5 8a5.5 5.5 0 0 1 8.25-4.764.5.5 0 0 0 .5-.866A6.5 6.5 0 1 0 14.5 8a.5.5 0 0 0-1 0 5.5 5.5 0 1 1-11 0z"/><path d="M15.354 3.354a.5.5 0 0 0-.708-.708L8 9.293 5.354 6.646a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l7-7z"/>');// eslint-disable-next-line
var BIconCheck2Square=/*#__PURE__*/makeIcon('Check2Square','<path d="M3 14.5A1.5 1.5 0 0 1 1.5 13V3A1.5 1.5 0 0 1 3 1.5h8a.5.5 0 0 1 0 1H3a.5.5 0 0 0-.5.5v10a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5V8a.5.5 0 0 1 1 0v5a1.5 1.5 0 0 1-1.5 1.5H3z"/><path d="M8.354 10.354l7-7a.5.5 0 0 0-.708-.708L8 9.293 5.354 6.646a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0z"/>');// eslint-disable-next-line
var BIconCheckAll=/*#__PURE__*/makeIcon('CheckAll','<path d="M8.97 4.97a.75.75 0 0 1 1.071 1.05l-3.992 4.99a.75.75 0 0 1-1.08.02L2.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093L8.95 4.992a.252.252 0 0 1 .02-.022zm-.92 5.14l.92.92a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 1 0-1.091-1.028L9.477 9.417l-.485-.486-.943 1.179z"/>');// eslint-disable-next-line
var BIconCheckCircle=/*#__PURE__*/makeIcon('CheckCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M10.97 4.97a.235.235 0 0 0-.02.022L7.477 9.417 5.384 7.323a.75.75 0 0 0-1.06 1.06L6.97 11.03a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 0 0-1.071-1.05z"/>');// eslint-disable-next-line
var BIconCheckCircleFill=/*#__PURE__*/makeIcon('CheckCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-3.97-3.03a.75.75 0 0 0-1.08.022L7.477 9.417 5.384 7.323a.75.75 0 0 0-1.06 1.06L6.97 11.03a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 0 0-.01-1.05z"/>');// eslint-disable-next-line
var BIconCheckSquare=/*#__PURE__*/makeIcon('CheckSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M10.97 4.97a.75.75 0 0 1 1.071 1.05l-3.992 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.235.235 0 0 1 .02-.022z"/>');// eslint-disable-next-line
var BIconCheckSquareFill=/*#__PURE__*/makeIcon('CheckSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm10.03 4.97a.75.75 0 0 1 .011 1.05l-3.992 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.75.75 0 0 1 1.08-.022z"/>');// eslint-disable-next-line
var BIconChevronBarContract=/*#__PURE__*/makeIcon('ChevronBarContract','<path fill-rule="evenodd" d="M3.646 14.854a.5.5 0 0 0 .708 0L8 11.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zm0-13.708a.5.5 0 0 1 .708 0L8 4.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zM1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8z"/>');// eslint-disable-next-line
var BIconChevronBarDown=/*#__PURE__*/makeIcon('ChevronBarDown','<path fill-rule="evenodd" d="M3.646 4.146a.5.5 0 0 1 .708 0L8 7.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zM1 11.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconChevronBarExpand=/*#__PURE__*/makeIcon('ChevronBarExpand','<path fill-rule="evenodd" d="M3.646 10.146a.5.5 0 0 1 .708 0L8 13.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zm0-4.292a.5.5 0 0 0 .708 0L8 2.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zM1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8z"/>');// eslint-disable-next-line
var BIconChevronBarLeft=/*#__PURE__*/makeIcon('ChevronBarLeft','<path fill-rule="evenodd" d="M11.854 3.646a.5.5 0 0 1 0 .708L8.207 8l3.647 3.646a.5.5 0 0 1-.708.708l-4-4a.5.5 0 0 1 0-.708l4-4a.5.5 0 0 1 .708 0zM4.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5z"/>');// eslint-disable-next-line
var BIconChevronBarRight=/*#__PURE__*/makeIcon('ChevronBarRight','<path fill-rule="evenodd" d="M4.146 3.646a.5.5 0 0 0 0 .708L7.793 8l-3.647 3.646a.5.5 0 0 0 .708.708l4-4a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708 0zM11.5 1a.5.5 0 0 1 .5.5v13a.5.5 0 0 1-1 0v-13a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconChevronBarUp=/*#__PURE__*/makeIcon('ChevronBarUp','<path fill-rule="evenodd" d="M3.646 11.854a.5.5 0 0 0 .708 0L8 8.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zM2.4 5.2c0 .22.18.4.4.4h10.4a.4.4 0 0 0 0-.8H2.8a.4.4 0 0 0-.4.4z"/>');// eslint-disable-next-line
var BIconChevronCompactDown=/*#__PURE__*/makeIcon('ChevronCompactDown','<path fill-rule="evenodd" d="M1.553 6.776a.5.5 0 0 1 .67-.223L8 9.44l5.776-2.888a.5.5 0 1 1 .448.894l-6 3a.5.5 0 0 1-.448 0l-6-3a.5.5 0 0 1-.223-.67z"/>');// eslint-disable-next-line
var BIconChevronCompactLeft=/*#__PURE__*/makeIcon('ChevronCompactLeft','<path fill-rule="evenodd" d="M9.224 1.553a.5.5 0 0 1 .223.67L6.56 8l2.888 5.776a.5.5 0 1 1-.894.448l-3-6a.5.5 0 0 1 0-.448l3-6a.5.5 0 0 1 .67-.223z"/>');// eslint-disable-next-line
var BIconChevronCompactRight=/*#__PURE__*/makeIcon('ChevronCompactRight','<path fill-rule="evenodd" d="M6.776 1.553a.5.5 0 0 1 .671.223l3 6a.5.5 0 0 1 0 .448l-3 6a.5.5 0 1 1-.894-.448L9.44 8 6.553 2.224a.5.5 0 0 1 .223-.671z"/>');// eslint-disable-next-line
var BIconChevronCompactUp=/*#__PURE__*/makeIcon('ChevronCompactUp','<path fill-rule="evenodd" d="M7.776 5.553a.5.5 0 0 1 .448 0l6 3a.5.5 0 1 1-.448.894L8 6.56 2.224 9.447a.5.5 0 1 1-.448-.894l6-3z"/>');// eslint-disable-next-line
var BIconChevronContract=/*#__PURE__*/makeIcon('ChevronContract','<path fill-rule="evenodd" d="M3.646 13.854a.5.5 0 0 0 .708 0L8 10.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zm0-11.708a.5.5 0 0 1 .708 0L8 5.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconChevronDoubleDown=/*#__PURE__*/makeIcon('ChevronDoubleDown','<path fill-rule="evenodd" d="M1.646 6.646a.5.5 0 0 1 .708 0L8 12.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/><path fill-rule="evenodd" d="M1.646 2.646a.5.5 0 0 1 .708 0L8 8.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconChevronDoubleLeft=/*#__PURE__*/makeIcon('ChevronDoubleLeft','<path fill-rule="evenodd" d="M8.354 1.646a.5.5 0 0 1 0 .708L2.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/><path fill-rule="evenodd" d="M12.354 1.646a.5.5 0 0 1 0 .708L6.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconChevronDoubleRight=/*#__PURE__*/makeIcon('ChevronDoubleRight','<path fill-rule="evenodd" d="M3.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L9.293 8 3.646 2.354a.5.5 0 0 1 0-.708z"/><path fill-rule="evenodd" d="M7.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L13.293 8 7.646 2.354a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconChevronDoubleUp=/*#__PURE__*/makeIcon('ChevronDoubleUp','<path fill-rule="evenodd" d="M7.646 2.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1-.708.708L8 3.707 2.354 9.354a.5.5 0 1 1-.708-.708l6-6z"/><path fill-rule="evenodd" d="M7.646 6.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1-.708.708L8 7.707l-5.646 5.647a.5.5 0 0 1-.708-.708l6-6z"/>');// eslint-disable-next-line
var BIconChevronDown=/*#__PURE__*/makeIcon('ChevronDown','<path fill-rule="evenodd" d="M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconChevronExpand=/*#__PURE__*/makeIcon('ChevronExpand','<path fill-rule="evenodd" d="M3.646 9.146a.5.5 0 0 1 .708 0L8 12.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zm0-2.292a.5.5 0 0 0 .708 0L8 3.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708z"/>');// eslint-disable-next-line
var BIconChevronLeft=/*#__PURE__*/makeIcon('ChevronLeft','<path fill-rule="evenodd" d="M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconChevronRight=/*#__PURE__*/makeIcon('ChevronRight','<path fill-rule="evenodd" d="M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconChevronUp=/*#__PURE__*/makeIcon('ChevronUp','<path fill-rule="evenodd" d="M7.646 4.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1-.708.708L8 5.707l-5.646 5.647a.5.5 0 0 1-.708-.708l6-6z"/>');// eslint-disable-next-line
var BIconCircle=/*#__PURE__*/makeIcon('Circle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/>');// eslint-disable-next-line
var BIconCircleFill=/*#__PURE__*/makeIcon('CircleFill','<circle cx="8" cy="8" r="8"/>');// eslint-disable-next-line
var BIconCircleHalf=/*#__PURE__*/makeIcon('CircleHalf','<path d="M8 15A7 7 0 1 0 8 1v14zm0 1A8 8 0 1 1 8 0a8 8 0 0 1 0 16z"/>');// eslint-disable-next-line
var BIconCircleSquare=/*#__PURE__*/makeIcon('CircleSquare','<path d="M0 6a6 6 0 1 1 12 0A6 6 0 0 1 0 6z"/><path d="M12.93 5h1.57a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5v-1.57a6.953 6.953 0 0 1-1-.22v1.79A1.5 1.5 0 0 0 5.5 16h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 4h-1.79c.097.324.17.658.22 1z"/>');// eslint-disable-next-line
var BIconClipboard=/*#__PURE__*/makeIcon('Clipboard','<path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>');// eslint-disable-next-line
var BIconClipboardCheck=/*#__PURE__*/makeIcon('ClipboardCheck','<path fill-rule="evenodd" d="M10.854 7.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 9.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>');// eslint-disable-next-line
var BIconClipboardData=/*#__PURE__*/makeIcon('ClipboardData','<path d="M4 11a1 1 0 1 1 2 0v1a1 1 0 1 1-2 0v-1zm6-4a1 1 0 1 1 2 0v5a1 1 0 1 1-2 0V7zM7 9a1 1 0 0 1 2 0v3a1 1 0 1 1-2 0V9z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>');// eslint-disable-next-line
var BIconClipboardMinus=/*#__PURE__*/makeIcon('ClipboardMinus','<path fill-rule="evenodd" d="M5.5 9.5A.5.5 0 0 1 6 9h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>');// eslint-disable-next-line
var BIconClipboardPlus=/*#__PURE__*/makeIcon('ClipboardPlus','<path fill-rule="evenodd" d="M8 7a.5.5 0 0 1 .5.5V9H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V10H6a.5.5 0 0 1 0-1h1.5V7.5A.5.5 0 0 1 8 7z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>');// eslint-disable-next-line
var BIconClipboardX=/*#__PURE__*/makeIcon('ClipboardX','<path fill-rule="evenodd" d="M6.146 7.146a.5.5 0 0 1 .708 0L8 8.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 9l1.147 1.146a.5.5 0 0 1-.708.708L8 9.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 9 6.146 7.854a.5.5 0 0 1 0-.708z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>');// eslint-disable-next-line
var BIconClock=/*#__PURE__*/makeIcon('Clock','<path d="M8 3.5a.5.5 0 0 0-1 0V9a.5.5 0 0 0 .252.434l3.5 2a.5.5 0 0 0 .496-.868L8 8.71V3.5z"/><path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm7-8A7 7 0 1 1 1 8a7 7 0 0 1 14 0z"/>');// eslint-disable-next-line
var BIconClockFill=/*#__PURE__*/makeIcon('ClockFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8 3.5a.5.5 0 0 0-1 0V9a.5.5 0 0 0 .252.434l3.5 2a.5.5 0 0 0 .496-.868L8 8.71V3.5z"/>');// eslint-disable-next-line
var BIconClockHistory=/*#__PURE__*/makeIcon('ClockHistory','<path d="M8.515 1.019A7 7 0 0 0 8 1V0a8 8 0 0 1 .589.022l-.074.997zm2.004.45a7.003 7.003 0 0 0-.985-.299l.219-.976c.383.086.76.2 1.126.342l-.36.933zm1.37.71a7.01 7.01 0 0 0-.439-.27l.493-.87a8.025 8.025 0 0 1 .979.654l-.615.789a6.996 6.996 0 0 0-.418-.302zm1.834 1.79a6.99 6.99 0 0 0-.653-.796l.724-.69c.27.285.52.59.747.91l-.818.576zm.744 1.352a7.08 7.08 0 0 0-.214-.468l.893-.45a7.976 7.976 0 0 1 .45 1.088l-.95.313a7.023 7.023 0 0 0-.179-.483zm.53 2.507a6.991 6.991 0 0 0-.1-1.025l.985-.17c.067.386.106.778.116 1.17l-1 .025zm-.131 1.538c.033-.17.06-.339.081-.51l.993.123a7.957 7.957 0 0 1-.23 1.155l-.964-.267c.046-.165.086-.332.12-.501zm-.952 2.379c.184-.29.346-.594.486-.908l.914.405c-.16.36-.345.706-.555 1.038l-.845-.535zm-.964 1.205c.122-.122.239-.248.35-.378l.758.653a8.073 8.073 0 0 1-.401.432l-.707-.707z"/><path d="M8 1a7 7 0 1 0 4.95 11.95l.707.707A8.001 8.001 0 1 1 8 0v1z"/><path d="M7.5 3a.5.5 0 0 1 .5.5v5.21l3.248 1.856a.5.5 0 0 1-.496.868l-3.5-2A.5.5 0 0 1 7 9V3.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconCloud=/*#__PURE__*/makeIcon('Cloud','<path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>');// eslint-disable-next-line
var BIconCloudArrowDown=/*#__PURE__*/makeIcon('CloudArrowDown','<path fill-rule="evenodd" d="M7.646 10.854a.5.5 0 0 0 .708 0l2-2a.5.5 0 0 0-.708-.708L8.5 9.293V5.5a.5.5 0 0 0-1 0v3.793L6.354 8.146a.5.5 0 1 0-.708.708l2 2z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>');// eslint-disable-next-line
var BIconCloudArrowDownFill=/*#__PURE__*/makeIcon('CloudArrowDownFill','<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm2.354 6.854l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5a.5.5 0 0 1 1 0v3.793l1.146-1.147a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconCloudArrowUp=/*#__PURE__*/makeIcon('CloudArrowUp','<path fill-rule="evenodd" d="M7.646 5.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 6.707V10.5a.5.5 0 0 1-1 0V6.707L6.354 7.854a.5.5 0 1 1-.708-.708l2-2z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>');// eslint-disable-next-line
var BIconCloudArrowUpFill=/*#__PURE__*/makeIcon('CloudArrowUpFill','<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm2.354 5.146a.5.5 0 0 1-.708.708L8.5 6.707V10.5a.5.5 0 0 1-1 0V6.707L6.354 7.854a.5.5 0 1 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2z"/>');// eslint-disable-next-line
var BIconCloudCheck=/*#__PURE__*/makeIcon('CloudCheck','<path fill-rule="evenodd" d="M10.354 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>');// eslint-disable-next-line
var BIconCloudCheckFill=/*#__PURE__*/makeIcon('CloudCheckFill','<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm2.354 4.854l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconCloudDownload=/*#__PURE__*/makeIcon('CloudDownload','<path d="M4.406 1.342A5.53 5.53 0 0 1 8 0c2.69 0 4.923 2 5.166 4.579C14.758 4.804 16 6.137 16 7.773 16 9.569 14.502 11 12.687 11H10a.5.5 0 0 1 0-1h2.688C13.979 10 15 8.988 15 7.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 2.825 10.328 1 8 1a4.53 4.53 0 0 0-2.941 1.1c-.757.652-1.153 1.438-1.153 2.055v.448l-.445.049C2.064 4.805 1 5.952 1 7.318 1 8.785 2.23 10 3.781 10H6a.5.5 0 0 1 0 1H3.781C1.708 11 0 9.366 0 7.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383z"/><path d="M7.646 15.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 14.293V5.5a.5.5 0 0 0-1 0v8.793l-2.146-2.147a.5.5 0 0 0-.708.708l3 3z"/>');// eslint-disable-next-line
var BIconCloudDownloadFill=/*#__PURE__*/makeIcon('CloudDownloadFill','<path fill-rule="evenodd" d="M8 0a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 4.095 0 5.555 0 7.318 0 9.366 1.708 11 3.781 11H7.5V5.5a.5.5 0 0 1 1 0V11h4.188C14.502 11 16 9.57 16 7.773c0-1.636-1.242-2.969-2.834-3.194C12.923 1.999 10.69 0 8 0zm-.354 15.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 14.293V11h-1v3.293l-2.146-2.147a.5.5 0 0 0-.708.708l3 3z"/>');// eslint-disable-next-line
var BIconCloudFill=/*#__PURE__*/makeIcon('CloudFill','<path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383z"/>');// eslint-disable-next-line
var BIconCloudMinus=/*#__PURE__*/makeIcon('CloudMinus','<path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>');// eslint-disable-next-line
var BIconCloudMinusFill=/*#__PURE__*/makeIcon('CloudMinusFill','<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zM6 7.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconCloudPlus=/*#__PURE__*/makeIcon('CloudPlus','<path fill-rule="evenodd" d="M8 5.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 .5-.5z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>');// eslint-disable-next-line
var BIconCloudPlusFill=/*#__PURE__*/makeIcon('CloudPlusFill','<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm.5 4v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconCloudSlash=/*#__PURE__*/makeIcon('CloudSlash','<path fill-rule="evenodd" d="M3.112 5.112a3.125 3.125 0 0 0-.17.613C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13H11l-1-1H3.781C2.231 12 1 10.785 1 9.318c0-1.365 1.064-2.513 2.46-2.666l.446-.05v-.447c0-.075.006-.152.018-.231l-.812-.812zm2.55-1.45l-.725-.725A5.512 5.512 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773a3.2 3.2 0 0 1-1.516 2.711l-.733-.733C14.498 11.378 15 10.626 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3c-.875 0-1.678.26-2.339.661z"/><path d="M13.646 14.354l-12-12 .708-.708 12 12-.707.707z"/>');// eslint-disable-next-line
var BIconCloudSlashFill=/*#__PURE__*/makeIcon('CloudSlashFill','<path fill-rule="evenodd" d="M3.112 5.112a3.125 3.125 0 0 0-.17.613C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13H11L3.112 5.112zm11.372 7.372L4.937 2.937A5.512 5.512 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773a3.2 3.2 0 0 1-1.516 2.711zm-.838 1.87l-12-12 .708-.708 12 12-.707.707z"/>');// eslint-disable-next-line
var BIconCloudUpload=/*#__PURE__*/makeIcon('CloudUpload','<path fill-rule="evenodd" d="M4.406 1.342A5.53 5.53 0 0 1 8 0c2.69 0 4.923 2 5.166 4.579C14.758 4.804 16 6.137 16 7.773 16 9.569 14.502 11 12.687 11H10a.5.5 0 0 1 0-1h2.688C13.979 10 15 8.988 15 7.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 2.825 10.328 1 8 1a4.53 4.53 0 0 0-2.941 1.1c-.757.652-1.153 1.438-1.153 2.055v.448l-.445.049C2.064 4.805 1 5.952 1 7.318 1 8.785 2.23 10 3.781 10H6a.5.5 0 0 1 0 1H3.781C1.708 11 0 9.366 0 7.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383z"/><path fill-rule="evenodd" d="M7.646 4.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V14.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3z"/>');// eslint-disable-next-line
var BIconCloudUploadFill=/*#__PURE__*/makeIcon('CloudUploadFill','<path fill-rule="evenodd" d="M8 0a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 4.095 0 5.555 0 7.318 0 9.366 1.708 11 3.781 11H7.5V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11h4.188C14.502 11 16 9.57 16 7.773c0-1.636-1.242-2.969-2.834-3.194C12.923 1.999 10.69 0 8 0zm-.5 14.5V11h1v3.5a.5.5 0 0 1-1 0z"/>');// eslint-disable-next-line
var BIconCode=/*#__PURE__*/makeIcon('Code','<path d="M5.854 4.854a.5.5 0 1 0-.708-.708l-3.5 3.5a.5.5 0 0 0 0 .708l3.5 3.5a.5.5 0 0 0 .708-.708L2.707 8l3.147-3.146zm4.292 0a.5.5 0 0 1 .708-.708l3.5 3.5a.5.5 0 0 1 0 .708l-3.5 3.5a.5.5 0 0 1-.708-.708L13.293 8l-3.147-3.146z"/>');// eslint-disable-next-line
var BIconCodeSlash=/*#__PURE__*/makeIcon('CodeSlash','<path d="M10.478 1.647a.5.5 0 1 0-.956-.294l-4 13a.5.5 0 0 0 .956.294l4-13zM4.854 4.146a.5.5 0 0 1 0 .708L1.707 8l3.147 3.146a.5.5 0 0 1-.708.708l-3.5-3.5a.5.5 0 0 1 0-.708l3.5-3.5a.5.5 0 0 1 .708 0zm6.292 0a.5.5 0 0 0 0 .708L14.293 8l-3.147 3.146a.5.5 0 0 0 .708.708l3.5-3.5a.5.5 0 0 0 0-.708l-3.5-3.5a.5.5 0 0 0-.708 0z"/>');// eslint-disable-next-line
var BIconCodeSquare=/*#__PURE__*/makeIcon('CodeSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M6.854 4.646a.5.5 0 0 1 0 .708L4.207 8l2.647 2.646a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 0 1 .708 0zm2.292 0a.5.5 0 0 0 0 .708L11.793 8l-2.647 2.646a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 0 0-.708 0z"/>');// eslint-disable-next-line
var BIconCollection=/*#__PURE__*/makeIcon('Collection','<path d="M2.5 3.5a.5.5 0 0 1 0-1h11a.5.5 0 0 1 0 1h-11zm2-2a.5.5 0 0 1 0-1h7a.5.5 0 0 1 0 1h-7zM0 13a1.5 1.5 0 0 0 1.5 1.5h13A1.5 1.5 0 0 0 16 13V6a1.5 1.5 0 0 0-1.5-1.5h-13A1.5 1.5 0 0 0 0 6v7zm1.5.5A.5.5 0 0 1 1 13V6a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-13z"/>');// eslint-disable-next-line
var BIconCollectionFill=/*#__PURE__*/makeIcon('CollectionFill','<path d="M0 13a1.5 1.5 0 0 0 1.5 1.5h13A1.5 1.5 0 0 0 16 13V6a1.5 1.5 0 0 0-1.5-1.5h-13A1.5 1.5 0 0 0 0 6v7zM2 3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 0-1h-11A.5.5 0 0 0 2 3zm2-2a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7A.5.5 0 0 0 4 1z"/>');// eslint-disable-next-line
var BIconCollectionPlay=/*#__PURE__*/makeIcon('CollectionPlay','<path d="M2 3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 0-1h-11A.5.5 0 0 0 2 3zm2-2a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7A.5.5 0 0 0 4 1zm2.765 5.576A.5.5 0 0 0 6 7v5a.5.5 0 0 0 .765.424l4-2.5a.5.5 0 0 0 0-.848l-4-2.5z"/><path d="M1.5 14.5A1.5 1.5 0 0 1 0 13V6a1.5 1.5 0 0 1 1.5-1.5h13A1.5 1.5 0 0 1 16 6v7a1.5 1.5 0 0 1-1.5 1.5h-13zm13-1a.5.5 0 0 0 .5-.5V6a.5.5 0 0 0-.5-.5h-13A.5.5 0 0 0 1 6v7a.5.5 0 0 0 .5.5h13z"/>');// eslint-disable-next-line
var BIconCollectionPlayFill=/*#__PURE__*/makeIcon('CollectionPlayFill','<path d="M2.5 3.5a.5.5 0 0 1 0-1h11a.5.5 0 0 1 0 1h-11zm2-2a.5.5 0 0 1 0-1h7a.5.5 0 0 1 0 1h-7zM0 13a1.5 1.5 0 0 0 1.5 1.5h13A1.5 1.5 0 0 0 16 13V6a1.5 1.5 0 0 0-1.5-1.5h-13A1.5 1.5 0 0 0 0 6v7zm6.258-6.437a.5.5 0 0 1 .507.013l4 2.5a.5.5 0 0 1 0 .848l-4 2.5A.5.5 0 0 1 6 12V7a.5.5 0 0 1 .258-.437z"/>');// eslint-disable-next-line
var BIconColumns=/*#__PURE__*/makeIcon('Columns','<path d="M0 2a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V2zm8.5 0v8H15V2H8.5zm0 9v3H15v-3H8.5zm-1-9H1v3h6.5V2zM1 14h6.5V6H1v8z"/>');// eslint-disable-next-line
var BIconColumnsGap=/*#__PURE__*/makeIcon('ColumnsGap','<path d="M6 1v3H1V1h5zM1 0a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1H1zm14 12v3h-5v-3h5zm-5-1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1h-5zM6 8v7H1V8h5zM1 7a1 1 0 0 0-1 1v7a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H1zm14-6v7h-5V1h5zm-5-1a1 1 0 0 0-1 1v7a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1h-5z"/>');// eslint-disable-next-line
var BIconCommand=/*#__PURE__*/makeIcon('Command','<path d="M3.5 2A1.5 1.5 0 0 1 5 3.5V5H3.5a1.5 1.5 0 1 1 0-3zM6 5V3.5A2.5 2.5 0 1 0 3.5 6H5v4H3.5A2.5 2.5 0 1 0 6 12.5V11h4v1.5a2.5 2.5 0 1 0 2.5-2.5H11V6h1.5A2.5 2.5 0 1 0 10 3.5V5H6zm4 1v4H6V6h4zm1-1V3.5A1.5 1.5 0 1 1 12.5 5H11zm0 6h1.5a1.5 1.5 0 1 1-1.5 1.5V11zm-6 0v1.5A1.5 1.5 0 1 1 3.5 11H5z"/>');// eslint-disable-next-line
var BIconCompass=/*#__PURE__*/makeIcon('Compass','<path d="M8 16.016a7.5 7.5 0 0 0 1.962-14.74A1 1 0 0 0 9 0H7a1 1 0 0 0-.962 1.276A7.5 7.5 0 0 0 8 16.016zm6.5-7.5a6.5 6.5 0 1 1-13 0 6.5 6.5 0 0 1 13 0z"/><path d="M6.94 7.44l4.95-2.83-2.83 4.95-4.949 2.83 2.828-4.95z"/>');// eslint-disable-next-line
var BIconCompassFill=/*#__PURE__*/makeIcon('CompassFill','<path d="M15.5 8.516a7.5 7.5 0 1 1-9.462-7.24A1 1 0 0 1 7 0h2a1 1 0 0 1 .962 1.276 7.503 7.503 0 0 1 5.538 7.24zm-3.61-3.905L6.94 7.439 4.11 12.39l4.95-2.828 2.828-4.95z"/>');// eslint-disable-next-line
var BIconCone=/*#__PURE__*/makeIcon('Cone','<path d="M7.03 1.88c.252-1.01 1.688-1.01 1.94 0l2.905 11.62H14a.5.5 0 0 1 0 1H2a.5.5 0 0 1 0-1h2.125L7.03 1.88z"/>');// eslint-disable-next-line
var BIconConeStriped=/*#__PURE__*/makeIcon('ConeStriped','<path d="M9.97 4.88l.953 3.811C10.158 8.878 9.14 9 8 9c-1.14 0-2.159-.122-2.923-.309L6.03 4.88C6.635 4.957 7.3 5 8 5s1.365-.043 1.97-.12zm-.245-.978L8.97.88C8.718-.13 7.282-.13 7.03.88L6.274 3.9C6.8 3.965 7.382 4 8 4c.618 0 1.2-.036 1.725-.098zm4.396 8.613a.5.5 0 0 1 .037.96l-6 2a.5.5 0 0 1-.316 0l-6-2a.5.5 0 0 1 .037-.96l2.391-.598.565-2.257c.862.212 1.964.339 3.165.339s2.303-.127 3.165-.339l.565 2.257 2.391.598z"/>');// eslint-disable-next-line
var BIconController=/*#__PURE__*/makeIcon('Controller','<path d="M11.5 6.027a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-1.5 1.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm2.5-.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-1.5 1.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm-6.5-3h1v1h1v1h-1v1h-1v-1h-1v-1h1v-1z"/><path d="M3.051 3.26a.5.5 0 0 1 .354-.613l1.932-.518a.5.5 0 0 1 .62.39c.655-.079 1.35-.117 2.043-.117.72 0 1.443.041 2.12.126a.5.5 0 0 1 .622-.399l1.932.518a.5.5 0 0 1 .306.729c.14.09.266.19.373.297.408.408.78 1.05 1.095 1.772.32.733.599 1.591.805 2.466.206.875.34 1.78.364 2.606.024.816-.059 1.602-.328 2.21a1.42 1.42 0 0 1-1.445.83c-.636-.067-1.115-.394-1.513-.773-.245-.232-.496-.526-.739-.808-.126-.148-.25-.292-.368-.423-.728-.804-1.597-1.527-3.224-1.527-1.627 0-2.496.723-3.224 1.527-.119.131-.242.275-.368.423-.243.282-.494.575-.739.808-.398.38-.877.706-1.513.773a1.42 1.42 0 0 1-1.445-.83c-.27-.608-.352-1.395-.329-2.21.024-.826.16-1.73.365-2.606.206-.875.486-1.733.805-2.466.315-.722.687-1.364 1.094-1.772a2.34 2.34 0 0 1 .433-.335.504.504 0 0 1-.028-.079zm2.036.412c-.877.185-1.469.443-1.733.708-.276.276-.587.783-.885 1.465a13.748 13.748 0 0 0-.748 2.295 12.351 12.351 0 0 0-.339 2.406c-.022.755.062 1.368.243 1.776a.42.42 0 0 0 .426.24c.327-.034.61-.199.929-.502.212-.202.4-.423.615-.674.133-.156.276-.323.44-.504C4.861 9.969 5.978 9.027 8 9.027s3.139.942 3.965 1.855c.164.181.307.348.44.504.214.251.403.472.615.674.318.303.601.468.929.503a.42.42 0 0 0 .426-.241c.18-.408.265-1.02.243-1.776a12.354 12.354 0 0 0-.339-2.406 13.753 13.753 0 0 0-.748-2.295c-.298-.682-.61-1.19-.885-1.465-.264-.265-.856-.523-1.733-.708-.85-.179-1.877-.27-2.913-.27-1.036 0-2.063.091-2.913.27z"/>');// eslint-disable-next-line
var BIconCpu=/*#__PURE__*/makeIcon('Cpu','<path d="M5 0a.5.5 0 0 1 .5.5V2h1V.5a.5.5 0 0 1 1 0V2h1V.5a.5.5 0 0 1 1 0V2h1V.5a.5.5 0 0 1 1 0V2A2.5 2.5 0 0 1 14 4.5h1.5a.5.5 0 0 1 0 1H14v1h1.5a.5.5 0 0 1 0 1H14v1h1.5a.5.5 0 0 1 0 1H14v1h1.5a.5.5 0 0 1 0 1H14a2.5 2.5 0 0 1-2.5 2.5v1.5a.5.5 0 0 1-1 0V14h-1v1.5a.5.5 0 0 1-1 0V14h-1v1.5a.5.5 0 0 1-1 0V14h-1v1.5a.5.5 0 0 1-1 0V14A2.5 2.5 0 0 1 2 11.5H.5a.5.5 0 0 1 0-1H2v-1H.5a.5.5 0 0 1 0-1H2v-1H.5a.5.5 0 0 1 0-1H2v-1H.5a.5.5 0 0 1 0-1H2A2.5 2.5 0 0 1 4.5 2V.5A.5.5 0 0 1 5 0zm-.5 3A1.5 1.5 0 0 0 3 4.5v7A1.5 1.5 0 0 0 4.5 13h7a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 11.5 3h-7zM5 6.5A1.5 1.5 0 0 1 6.5 5h3A1.5 1.5 0 0 1 11 6.5v3A1.5 1.5 0 0 1 9.5 11h-3A1.5 1.5 0 0 1 5 9.5v-3zM6.5 6a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3z"/>');// eslint-disable-next-line
var BIconCpuFill=/*#__PURE__*/makeIcon('CpuFill','<path d="M6.5 6a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3z"/><path d="M5.5.5a.5.5 0 0 0-1 0V2A2.5 2.5 0 0 0 2 4.5H.5a.5.5 0 0 0 0 1H2v1H.5a.5.5 0 0 0 0 1H2v1H.5a.5.5 0 0 0 0 1H2v1H.5a.5.5 0 0 0 0 1H2A2.5 2.5 0 0 0 4.5 14v1.5a.5.5 0 0 0 1 0V14h1v1.5a.5.5 0 0 0 1 0V14h1v1.5a.5.5 0 0 0 1 0V14h1v1.5a.5.5 0 0 0 1 0V14a2.5 2.5 0 0 0 2.5-2.5h1.5a.5.5 0 0 0 0-1H14v-1h1.5a.5.5 0 0 0 0-1H14v-1h1.5a.5.5 0 0 0 0-1H14v-1h1.5a.5.5 0 0 0 0-1H14A2.5 2.5 0 0 0 11.5 2V.5a.5.5 0 0 0-1 0V2h-1V.5a.5.5 0 0 0-1 0V2h-1V.5a.5.5 0 0 0-1 0V2h-1V.5zm1 4.5h3A1.5 1.5 0 0 1 11 6.5v3A1.5 1.5 0 0 1 9.5 11h-3A1.5 1.5 0 0 1 5 9.5v-3A1.5 1.5 0 0 1 6.5 5z"/>');// eslint-disable-next-line
var BIconCreditCard=/*#__PURE__*/makeIcon('CreditCard','<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm2-1a1 1 0 0 0-1 1v1h14V4a1 1 0 0 0-1-1H2zm13 4H1v5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V7z"/><path d="M2 10a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1v-1z"/>');// eslint-disable-next-line
var BIconCreditCard2Back=/*#__PURE__*/makeIcon('CreditCard2Back','<path d="M11 5.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-1z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm13 2v5H1V4a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zm-1 9H2a1 1 0 0 1-1-1v-1h14v1a1 1 0 0 1-1 1z"/>');// eslint-disable-next-line
var BIconCreditCard2BackFill=/*#__PURE__*/makeIcon('CreditCard2BackFill','<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5H0V4zm11.5 1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-2zM0 11v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1H0z"/>');// eslint-disable-next-line
var BIconCreditCard2Front=/*#__PURE__*/makeIcon('CreditCard2Front','<path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/><path d="M2 5.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconCreditCard2FrontFill=/*#__PURE__*/makeIcon('CreditCard2FrontFill','<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm2.5 1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-2zm0 3a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm3 0a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm3 0a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm3 0a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/>');// eslint-disable-next-line
var BIconCreditCardFill=/*#__PURE__*/makeIcon('CreditCardFill','<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1H0V4zm0 3v5a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7H0zm3 2h1a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1v-1a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconCrop=/*#__PURE__*/makeIcon('Crop','<path d="M3.5.5A.5.5 0 0 1 4 1v13h13a.5.5 0 0 1 0 1h-2v2a.5.5 0 0 1-1 0v-2H3.5a.5.5 0 0 1-.5-.5V4H1a.5.5 0 0 1 0-1h2V1a.5.5 0 0 1 .5-.5zm2.5 3a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4H6.5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconCup=/*#__PURE__*/makeIcon('Cup','<path d="M1 2a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v1h.5A1.5 1.5 0 0 1 16 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-.55a2.5 2.5 0 0 1-2.45 2h-8A2.5 2.5 0 0 1 1 12.5V2zm13 10h.5a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5H14v8zM13 2H2v10.5A1.5 1.5 0 0 0 3.5 14h8a1.5 1.5 0 0 0 1.5-1.5V2z"/>');// eslint-disable-next-line
var BIconCupFill=/*#__PURE__*/makeIcon('CupFill','<path d="M1 2a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v1h.5A1.5 1.5 0 0 1 16 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-.55a2.5 2.5 0 0 1-2.45 2h-8A2.5 2.5 0 0 1 1 12.5V2zm13 10h.5a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5H14v8z"/>');// eslint-disable-next-line
var BIconCupStraw=/*#__PURE__*/makeIcon('CupStraw','<path d="M13.964 1.18a.5.5 0 0 1-.278.65l-2.255.902-.462 2.08c.375.096.714.216.971.368.228.135.56.396.56.82 0 .046-.004.09-.011.132l-.955 9.068a1.28 1.28 0 0 1-.524.93c-.488.34-1.494.87-3.01.87-1.516 0-2.522-.53-3.01-.87a1.28 1.28 0 0 1-.524-.93L3.51 6.132A.78.78 0 0 1 3.5 6c0-.424.332-.685.56-.82.262-.154.607-.276.99-.372C5.824 4.614 6.867 4.5 8 4.5c.712 0 1.389.045 1.985.127l.527-2.37a.5.5 0 0 1 .302-.355l2.5-1a.5.5 0 0 1 .65.279zM9.768 5.608A13.991 13.991 0 0 0 8 5.5c-1.076 0-2.033.11-2.707.278A3.284 3.284 0 0 0 4.645 6c.146.073.362.15.648.222C5.967 6.39 6.924 6.5 8 6.5c.571 0 1.109-.03 1.588-.085l.18-.808zm.292 1.756C9.445 7.45 8.742 7.5 8 7.5c-1.133 0-2.176-.114-2.95-.308a5.51 5.51 0 0 1-.435-.127l.845 8.03c.013.121.06.186.102.215.357.249 1.167.69 2.438.69 1.27 0 2.08-.441 2.438-.69.041-.029.09-.094.102-.214l.845-8.03a5.513 5.513 0 0 1-.435.126 8.88 8.88 0 0 1-.89.17zm-5.593-1.48s.003.002.005.006l-.005-.006zm7.066 0l-.005.006a.026.026 0 0 1 .005-.006zM11.354 6a3.174 3.174 0 0 0-.604-.21l-.099.445.055-.013c.286-.072.502-.149.648-.222z"/>');// eslint-disable-next-line
var BIconCursor=/*#__PURE__*/makeIcon('Cursor','<path d="M14.082 2.182a.5.5 0 0 1 .103.557L8.528 15.467a.5.5 0 0 1-.917-.007L5.57 10.694.803 8.652a.5.5 0 0 1-.006-.916l12.728-5.657a.5.5 0 0 1 .556.103zM2.25 8.184l3.897 1.67a.5.5 0 0 1 .262.263l1.67 3.897L12.743 3.52 2.25 8.184z"/>');// eslint-disable-next-line
var BIconCursorFill=/*#__PURE__*/makeIcon('CursorFill','<path d="M14.082 2.182a.5.5 0 0 1 .103.557L8.528 15.467a.5.5 0 0 1-.917-.007L5.57 10.694.803 8.652a.5.5 0 0 1-.006-.916l12.728-5.657a.5.5 0 0 1 .556.103z"/>');// eslint-disable-next-line
var BIconCursorText=/*#__PURE__*/makeIcon('CursorText','<path d="M5 2a.5.5 0 0 1 .5-.5c.862 0 1.573.287 2.06.566.174.099.321.198.44.286.119-.088.266-.187.44-.286A4.165 4.165 0 0 1 10.5 1.5a.5.5 0 0 1 0 1c-.638 0-1.177.213-1.564.434a3.49 3.49 0 0 0-.436.294V7.5H9a.5.5 0 0 1 0 1h-.5v4.272c.1.08.248.187.436.294.387.221.926.434 1.564.434a.5.5 0 0 1 0 1 4.165 4.165 0 0 1-2.06-.566A4.561 4.561 0 0 1 8 13.65a4.561 4.561 0 0 1-.44.285 4.165 4.165 0 0 1-2.06.566.5.5 0 0 1 0-1c.638 0 1.177-.213 1.564-.434.188-.107.335-.214.436-.294V8.5H7a.5.5 0 0 1 0-1h.5V3.228a3.49 3.49 0 0 0-.436-.294A3.166 3.166 0 0 0 5.5 2.5.5.5 0 0 1 5 2zm3.352 1.355zm-.704 9.29z"/>');// eslint-disable-next-line
var BIconDash=/*#__PURE__*/makeIcon('Dash','<path d="M4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8z"/>');// eslint-disable-next-line
var BIconDashCircle=/*#__PURE__*/makeIcon('DashCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8z"/>');// eslint-disable-next-line
var BIconDashCircleFill=/*#__PURE__*/makeIcon('DashCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.5 7.5a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-7z"/>');// eslint-disable-next-line
var BIconDashSquare=/*#__PURE__*/makeIcon('DashSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8z"/>');// eslint-disable-next-line
var BIconDashSquareFill=/*#__PURE__*/makeIcon('DashSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm2.5 7.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconDiagram2=/*#__PURE__*/makeIcon('Diagram2','<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H11a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 5 7h2.5V6A1.5 1.5 0 0 1 6 4.5v-1zM8.5 5a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1zM3 11.5A1.5 1.5 0 0 1 4.5 10h1A1.5 1.5 0 0 1 7 11.5v1A1.5 1.5 0 0 1 5.5 14h-1A1.5 1.5 0 0 1 3 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm4.5.5a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1A1.5 1.5 0 0 1 9 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>');// eslint-disable-next-line
var BIconDiagram2Fill=/*#__PURE__*/makeIcon('Diagram2Fill','<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H11a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 5 7h2.5V6A1.5 1.5 0 0 1 6 4.5v-1zm-3 8A1.5 1.5 0 0 1 4.5 10h1A1.5 1.5 0 0 1 7 11.5v1A1.5 1.5 0 0 1 5.5 14h-1A1.5 1.5 0 0 1 3 12.5v-1zm6 0a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1A1.5 1.5 0 0 1 9 12.5v-1z"/>');// eslint-disable-next-line
var BIconDiagram3=/*#__PURE__*/makeIcon('Diagram3','<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H14a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 2 7h5.5V6A1.5 1.5 0 0 1 6 4.5v-1zM8.5 5a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1zM0 11.5A1.5 1.5 0 0 1 1.5 10h1A1.5 1.5 0 0 1 4 11.5v1A1.5 1.5 0 0 1 2.5 14h-1A1.5 1.5 0 0 1 0 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm4.5.5A1.5 1.5 0 0 1 7.5 10h1a1.5 1.5 0 0 1 1.5 1.5v1A1.5 1.5 0 0 1 8.5 14h-1A1.5 1.5 0 0 1 6 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm4.5.5a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>');// eslint-disable-next-line
var BIconDiagram3Fill=/*#__PURE__*/makeIcon('Diagram3Fill','<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H14a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 2 7h5.5V6A1.5 1.5 0 0 1 6 4.5v-1zm-6 8A1.5 1.5 0 0 1 1.5 10h1A1.5 1.5 0 0 1 4 11.5v1A1.5 1.5 0 0 1 2.5 14h-1A1.5 1.5 0 0 1 0 12.5v-1zm6 0A1.5 1.5 0 0 1 7.5 10h1a1.5 1.5 0 0 1 1.5 1.5v1A1.5 1.5 0 0 1 8.5 14h-1A1.5 1.5 0 0 1 6 12.5v-1zm6 0a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5v-1z"/>');// eslint-disable-next-line
var BIconDiamond=/*#__PURE__*/makeIcon('Diamond','<path d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435zm1.4.7a.495.495 0 0 0-.7 0L1.134 7.65a.495.495 0 0 0 0 .7l6.516 6.516a.495.495 0 0 0 .7 0l6.516-6.516a.495.495 0 0 0 0-.7L8.35 1.134z"/>');// eslint-disable-next-line
var BIconDiamondFill=/*#__PURE__*/makeIcon('DiamondFill','<path fill-rule="evenodd" d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435z"/>');// eslint-disable-next-line
var BIconDiamondHalf=/*#__PURE__*/makeIcon('DiamondHalf','<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L.436 6.95c-.58.58-.58 1.519 0 2.098l6.516 6.516c.58.58 1.519.58 2.098 0l6.516-6.516c.58-.58.58-1.519 0-2.098L9.05.435zM8 .989c.127 0 .253.049.35.145l6.516 6.516a.495.495 0 0 1 0 .7L8.35 14.866a.493.493 0 0 1-.35.145V.989z"/>');// eslint-disable-next-line
var BIconDice1=/*#__PURE__*/makeIcon('Dice1','<circle cx="8" cy="8" r="1.5"/><path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/>');// eslint-disable-next-line
var BIconDice1Fill=/*#__PURE__*/makeIcon('Dice1Fill','<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm5 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconDice2=/*#__PURE__*/makeIcon('Dice2','<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconDice2Fill=/*#__PURE__*/makeIcon('Dice2Fill','<path d="M0 3a3 3 0 0 1 3-3h10a3 3 0 0 1 3 3v10a3 3 0 0 1-3 3H3a3 3 0 0 1-3-3V3zm5.5 1a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0zm6.5 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/>');// eslint-disable-next-line
var BIconDice3=/*#__PURE__*/makeIcon('Dice3','<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-4-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconDice3Fill=/*#__PURE__*/makeIcon('Dice3Fill','<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm2.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM8 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconDice4=/*#__PURE__*/makeIcon('Dice4','<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconDice4Fill=/*#__PURE__*/makeIcon('Dice4Fill','<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm1 5.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm8 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm1.5 6.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM4 13.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconDice5=/*#__PURE__*/makeIcon('Dice5','<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm4-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconDice5Fill=/*#__PURE__*/makeIcon('Dice5Fill','<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm2.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM12 13.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zM5.5 12a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM8 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconDice6=/*#__PURE__*/makeIcon('Dice6','<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-8 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconDice6Fill=/*#__PURE__*/makeIcon('Dice6Fill','<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm1 5.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm8 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm1.5 6.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM12 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zM5.5 12a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM4 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconDisc=/*#__PURE__*/makeIcon('Disc','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0zM8 4a4 4 0 0 0-4 4 .5.5 0 0 1-1 0 5 5 0 0 1 5-5 .5.5 0 0 1 0 1zm4.5 3.5a.5.5 0 0 1 .5.5 5 5 0 0 1-5 5 .5.5 0 0 1 0-1 4 4 0 0 0 4-4 .5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconDiscFill=/*#__PURE__*/makeIcon('DiscFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-6 0a2 2 0 1 0-4 0 2 2 0 0 0 4 0zM4 8a4 4 0 0 1 4-4 .5.5 0 0 0 0-1 5 5 0 0 0-5 5 .5.5 0 0 0 1 0zm9 0a.5.5 0 1 0-1 0 4 4 0 0 1-4 4 .5.5 0 0 0 0 1 5 5 0 0 0 5-5z"/>');// eslint-disable-next-line
var BIconDiscord=/*#__PURE__*/makeIcon('Discord','<path d="M6.552 6.712c-.456 0-.816.4-.816.888s.368.888.816.888c.456 0 .816-.4.816-.888.008-.488-.36-.888-.816-.888zm2.92 0c-.456 0-.816.4-.816.888s.368.888.816.888c.456 0 .816-.4.816-.888s-.36-.888-.816-.888z"/><path d="M13.36 0H2.64C1.736 0 1 .736 1 1.648v10.816c0 .912.736 1.648 1.64 1.648h9.072l-.424-1.48 1.024.952.968.896L15 16V1.648C15 .736 14.264 0 13.36 0zm-3.088 10.448s-.288-.344-.528-.648c1.048-.296 1.448-.952 1.448-.952-.328.216-.64.368-.92.472-.4.168-.784.28-1.16.344a5.604 5.604 0 0 1-2.072-.008 6.716 6.716 0 0 1-1.176-.344 4.688 4.688 0 0 1-.584-.272c-.024-.016-.048-.024-.072-.04-.016-.008-.024-.016-.032-.024-.144-.08-.224-.136-.224-.136s.384.64 1.4.944c-.24.304-.536.664-.536.664-1.768-.056-2.44-1.216-2.44-1.216 0-2.576 1.152-4.664 1.152-4.664 1.152-.864 2.248-.84 2.248-.84l.08.096c-1.44.416-2.104 1.048-2.104 1.048s.176-.096.472-.232c.856-.376 1.536-.48 1.816-.504.048-.008.088-.016.136-.016a6.521 6.521 0 0 1 4.024.752s-.632-.6-1.992-1.016l.112-.128s1.096-.024 2.248.84c0 0 1.152 2.088 1.152 4.664 0 0-.68 1.16-2.448 1.216z"/>');// eslint-disable-next-line
var BIconDisplay=/*#__PURE__*/makeIcon('Display','<path d="M0 4s0-2 2-2h12s2 0 2 2v6s0 2-2 2h-4c0 .667.083 1.167.25 1.5H11a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1h.75c.167-.333.25-.833.25-1.5H2s-2 0-2-2V4zm1.398-.855a.758.758 0 0 0-.254.302A1.46 1.46 0 0 0 1 4.01V10c0 .325.078.502.145.602.07.105.17.188.302.254a1.464 1.464 0 0 0 .538.143L2.01 11H14c.325 0 .502-.078.602-.145a.758.758 0 0 0 .254-.302 1.464 1.464 0 0 0 .143-.538L15 9.99V4c0-.325-.078-.502-.145-.602a.757.757 0 0 0-.302-.254A1.46 1.46 0 0 0 13.99 3H2c-.325 0-.502.078-.602.145z"/>');// eslint-disable-next-line
var BIconDisplayFill=/*#__PURE__*/makeIcon('DisplayFill','<path d="M6 12c0 .667-.083 1.167-.25 1.5H5a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-.75c-.167-.333-.25-.833-.25-1.5h4c2 0 2-2 2-2V4c0-2-2-2-2-2H2C0 2 0 4 0 4v6c0 2 2 2 2 2h4z"/>');// eslint-disable-next-line
var BIconDistributeHorizontal=/*#__PURE__*/makeIcon('DistributeHorizontal','<path fill-rule="evenodd" d="M14.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5zm-13 0a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5z"/><path d="M6 13a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v10z"/>');// eslint-disable-next-line
var BIconDistributeVertical=/*#__PURE__*/makeIcon('DistributeVertical','<path fill-rule="evenodd" d="M1 1.5a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 0-1h-13a.5.5 0 0 0-.5.5zm0 13a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 0-1h-13a.5.5 0 0 0-.5.5z"/><path d="M2 7a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V7z"/>');// eslint-disable-next-line
var BIconDoorClosed=/*#__PURE__*/makeIcon('DoorClosed','<path d="M3 2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v13h1.5a.5.5 0 0 1 0 1h-13a.5.5 0 0 1 0-1H3V2zm1 13h8V2H4v13z"/><path d="M9 9a1 1 0 1 0 2 0 1 1 0 0 0-2 0z"/>');// eslint-disable-next-line
var BIconDoorClosedFill=/*#__PURE__*/makeIcon('DoorClosedFill','<path d="M12 1a1 1 0 0 1 1 1v13h1.5a.5.5 0 0 1 0 1h-13a.5.5 0 0 1 0-1H3V2a1 1 0 0 1 1-1h8zm-2 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconDoorOpen=/*#__PURE__*/makeIcon('DoorOpen','<path d="M8.5 10c-.276 0-.5-.448-.5-1s.224-1 .5-1 .5.448.5 1-.224 1-.5 1z"/><path d="M10.828.122A.5.5 0 0 1 11 .5V1h.5A1.5 1.5 0 0 1 13 2.5V15h1.5a.5.5 0 0 1 0 1h-13a.5.5 0 0 1 0-1H3V1.5a.5.5 0 0 1 .43-.495l7-1a.5.5 0 0 1 .398.117zM11.5 2H11v13h1V2.5a.5.5 0 0 0-.5-.5zM4 1.934V15h6V1.077l-6 .857z"/>');// eslint-disable-next-line
var BIconDoorOpenFill=/*#__PURE__*/makeIcon('DoorOpenFill','<path d="M1.5 15a.5.5 0 0 0 0 1h13a.5.5 0 0 0 0-1H13V2.5A1.5 1.5 0 0 0 11.5 1H11V.5a.5.5 0 0 0-.57-.495l-7 1A.5.5 0 0 0 3 1.5V15H1.5zM11 2h.5a.5.5 0 0 1 .5.5V15h-1V2zm-2.5 8c-.276 0-.5-.448-.5-1s.224-1 .5-1 .5.448.5 1-.224 1-.5 1z"/>');// eslint-disable-next-line
var BIconDot=/*#__PURE__*/makeIcon('Dot','<path d="M8 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/>');// eslint-disable-next-line
var BIconDownload=/*#__PURE__*/makeIcon('Download','<path d="M.5 9.9a.5.5 0 0 1 .5.5v2.5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0v2.5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5z"/><path d="M7.646 11.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V1.5a.5.5 0 0 0-1 0v8.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3z"/>');// eslint-disable-next-line
var BIconDroplet=/*#__PURE__*/makeIcon('Droplet','<path fill-rule="evenodd" d="M7.21.8C7.69.295 8 0 8 0c.109.363.234.708.371 1.038.812 1.946 2.073 3.35 3.197 4.6C12.878 7.096 14 8.345 14 10a6 6 0 0 1-12 0C2 6.668 5.58 2.517 7.21.8zm.413 1.021A31.25 31.25 0 0 0 5.794 3.99c-.726.95-1.436 2.008-1.96 3.07C3.304 8.133 3 9.138 3 10a5 5 0 0 0 10 0c0-1.201-.796-2.157-2.181-3.7l-.03-.032C9.75 5.11 8.5 3.72 7.623 1.82z"/><path fill-rule="evenodd" d="M4.553 7.776c.82-1.641 1.717-2.753 2.093-3.13l.708.708c-.29.29-1.128 1.311-1.907 2.87l-.894-.448z"/>');// eslint-disable-next-line
var BIconDropletFill=/*#__PURE__*/makeIcon('DropletFill','<path fill-rule="evenodd" d="M8 16a6 6 0 0 0 6-6c0-1.655-1.122-2.904-2.432-4.362C10.254 4.176 8.75 2.503 8 0c0 0-6 5.686-6 10a6 6 0 0 0 6 6zM6.646 4.646c-.376.377-1.272 1.489-2.093 3.13l.894.448c.78-1.559 1.616-2.58 1.907-2.87l-.708-.708z"/>');// eslint-disable-next-line
var BIconDropletHalf=/*#__PURE__*/makeIcon('DropletHalf','<path fill-rule="evenodd" d="M7.21.8C7.69.295 8 0 8 0c.109.363.234.708.371 1.038.812 1.946 2.073 3.35 3.197 4.6C12.878 7.096 14 8.345 14 10a6 6 0 0 1-12 0C2 6.668 5.58 2.517 7.21.8zm.413 1.021A31.25 31.25 0 0 0 5.794 3.99c-.726.95-1.436 2.008-1.96 3.07C3.304 8.133 3 9.138 3 10c0 0 2.5 1.5 5 .5s5-.5 5-.5c0-1.201-.796-2.157-2.181-3.7l-.03-.032C9.75 5.11 8.5 3.72 7.623 1.82z"/><path fill-rule="evenodd" d="M4.553 7.776c.82-1.641 1.717-2.753 2.093-3.13l.708.708c-.29.29-1.128 1.311-1.907 2.87l-.894-.448z"/>');// eslint-disable-next-line
var BIconEarbuds=/*#__PURE__*/makeIcon('Earbuds','<path fill-rule="evenodd" d="M6.825 4.138c.596 2.141-.36 3.593-2.389 4.117a4.432 4.432 0 0 1-2.018.054c-.048-.01.9 2.778 1.522 4.61l.41 1.205a.52.52 0 0 1-.346.659l-.593.19a.548.548 0 0 1-.69-.34L.184 6.99c-.696-2.137.662-4.309 2.564-4.8 2.029-.523 3.402 0 4.076 1.948zm-.868 2.221c.43-.112.561-.993.292-1.969-.269-.975-.836-1.675-1.266-1.563-.43.112-.561.994-.292 1.969.269.975.836 1.675 1.266 1.563zm3.218-2.221c-.596 2.141.36 3.593 2.389 4.117a4.434 4.434 0 0 0 2.018.054c.048-.01-.9 2.778-1.522 4.61l-.41 1.205a.52.52 0 0 0 .346.659l.593.19c.289.092.6-.06.69-.34l2.536-7.643c.696-2.137-.662-4.309-2.564-4.8-2.029-.523-3.402 0-4.076 1.948zm.868 2.221c-.43-.112-.561-.993-.292-1.969.269-.975.836-1.675 1.266-1.563.43.112.561.994.292 1.969-.269.975-.836 1.675-1.266 1.563z"/>');// eslint-disable-next-line
var BIconEasel=/*#__PURE__*/makeIcon('Easel','<path d="M8 0a.5.5 0 0 1 .473.337L9.046 2H14a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1h-1.85l1.323 3.837a.5.5 0 1 1-.946.326L11.092 11H8.5v3a.5.5 0 0 1-1 0v-3H4.908l-1.435 4.163a.5.5 0 1 1-.946-.326L3.85 11H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h4.954L7.527.337A.5.5 0 0 1 8 0zM2 3v7h12V3H2z"/>');// eslint-disable-next-line
var BIconEaselFill=/*#__PURE__*/makeIcon('EaselFill','<path d="M8.473.337a.5.5 0 0 0-.946 0L6.954 2H2a1 1 0 0 0-1 1v7a1 1 0 0 0 1 1h1.85l-1.323 3.837a.5.5 0 1 0 .946.326L4.908 11H7.5v2.5a.5.5 0 0 0 1 0V11h2.592l1.435 4.163a.5.5 0 0 0 .946-.326L12.15 11H14a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H9.046L8.473.337z"/>');// eslint-disable-next-line
var BIconEgg=/*#__PURE__*/makeIcon('Egg','<path d="M8 15a5 5 0 0 1-5-5c0-1.956.69-4.286 1.742-6.12.524-.913 1.112-1.658 1.704-2.164C7.044 1.206 7.572 1 8 1c.428 0 .956.206 1.554.716.592.506 1.18 1.251 1.704 2.164C12.31 5.714 13 8.044 13 10a5 5 0 0 1-5 5zm0 1a6 6 0 0 0 6-6c0-4.314-3-10-6-10S2 5.686 2 10a6 6 0 0 0 6 6z"/>');// eslint-disable-next-line
var BIconEggFill=/*#__PURE__*/makeIcon('EggFill','<path d="M14 10a6 6 0 0 1-12 0C2 5.686 5 0 8 0s6 5.686 6 10z"/>');// eslint-disable-next-line
var BIconEggFried=/*#__PURE__*/makeIcon('EggFried','<path d="M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path d="M13.997 5.17a5 5 0 0 0-8.101-4.09A5 5 0 0 0 1.28 9.342a5 5 0 0 0 8.336 5.109 3.5 3.5 0 0 0 5.201-4.065 3.001 3.001 0 0 0-.822-5.216zm-1-.034a1 1 0 0 0 .668.977 2.001 2.001 0 0 1 .547 3.478 1 1 0 0 0-.341 1.113 2.5 2.5 0 0 1-3.715 2.905 1 1 0 0 0-1.262.152 4 4 0 0 1-6.67-4.087 1 1 0 0 0-.2-1 4 4 0 0 1 3.693-6.61 1 1 0 0 0 .8-.2 4 4 0 0 1 6.48 3.273z"/>');// eslint-disable-next-line
var BIconEject=/*#__PURE__*/makeIcon('Eject','<path d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H1.656C.78 9.5.326 8.455.926 7.816L7.27 1.047zM14.346 8.5L8 1.731 1.654 8.5h12.692zM.5 11.5a1 1 0 0 1 1-1h13a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-13a1 1 0 0 1-1-1v-1zm14 0h-13v1h13v-1z"/>');// eslint-disable-next-line
var BIconEjectFill=/*#__PURE__*/makeIcon('EjectFill','<path d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H1.656C.78 9.5.326 8.455.926 7.816L7.27 1.047zM.5 11.5a1 1 0 0 1 1-1h13a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-13a1 1 0 0 1-1-1v-1z"/>');// eslint-disable-next-line
var BIconEmojiAngry=/*#__PURE__*/makeIcon('EmojiAngry','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 12.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 10.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 9.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zm6.991-8.38a.5.5 0 1 1 .448.894l-1.009.504c.176.27.285.64.285 1.049 0 .828-.448 1.5-1 1.5s-1-.672-1-1.5c0-.247.04-.48.11-.686a.502.502 0 0 1 .166-.761l2-1zm-6.552 0a.5.5 0 0 0-.448.894l1.009.504A1.94 1.94 0 0 0 5 6.5C5 7.328 5.448 8 6 8s1-.672 1-1.5c0-.247-.04-.48-.11-.686a.502.502 0 0 0-.166-.761l-2-1z"/>');// eslint-disable-next-line
var BIconEmojiAngryFill=/*#__PURE__*/makeIcon('EmojiAngryFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM4.053 4.276a.5.5 0 0 1 .67-.223l2 1a.5.5 0 0 1 .166.76c.071.206.111.44.111.687C7 7.328 6.552 8 6 8s-1-.672-1-1.5c0-.408.109-.778.285-1.049l-1.009-.504a.5.5 0 0 1-.223-.67zm.232 8.157a.5.5 0 0 1-.183-.683A4.498 4.498 0 0 1 8 9.5a4.5 4.5 0 0 1 3.898 2.25.5.5 0 1 1-.866.5A3.498 3.498 0 0 0 8 10.5a3.498 3.498 0 0 0-3.032 1.75.5.5 0 0 1-.683.183zM10 8c-.552 0-1-.672-1-1.5 0-.247.04-.48.11-.686a.502.502 0 0 1 .166-.761l2-1a.5.5 0 1 1 .448.894l-1.009.504c.176.27.285.64.285 1.049 0 .828-.448 1.5-1 1.5z"/>');// eslint-disable-next-line
var BIconEmojiDizzy=/*#__PURE__*/makeIcon('EmojiDizzy','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M9.146 5.146a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708.708l-.647.646.647.646a.5.5 0 0 1-.708.708l-.646-.647-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zm-5 0a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 1 1 .708.708l-.647.646.647.646a.5.5 0 1 1-.708.708L5.5 7.207l-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zM10 11a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>');// eslint-disable-next-line
var BIconEmojiDizzyFill=/*#__PURE__*/makeIcon('EmojiDizzyFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM4.146 5.146a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 1 1 .708.708l-.647.646.647.646a.5.5 0 1 1-.708.708L5.5 7.207l-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zm5 0a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708.708l-.647.646.647.646a.5.5 0 0 1-.708.708l-.646-.647-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zM8 13a2 2 0 1 1 0-4 2 2 0 0 1 0 4z"/>');// eslint-disable-next-line
var BIconEmojiExpressionless=/*#__PURE__*/makeIcon('EmojiExpressionless','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4 10.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm5 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconEmojiExpressionlessFill=/*#__PURE__*/makeIcon('EmojiExpressionlessFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM4.5 6h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1zm5 0h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1zm-5 4h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconEmojiFrown=/*#__PURE__*/makeIcon('EmojiFrown','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 12.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 10.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 9.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm4 0c0 .828-.448 1.5-1 1.5s-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5z"/>');// eslint-disable-next-line
var BIconEmojiFrownFill=/*#__PURE__*/makeIcon('EmojiFrownFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm-2.715 5.933a.5.5 0 0 1-.183-.683A4.498 4.498 0 0 1 8 9.5a4.5 4.5 0 0 1 3.898 2.25.5.5 0 0 1-.866.5A3.498 3.498 0 0 0 8 10.5a3.498 3.498 0 0 0-3.032 1.75.5.5 0 0 1-.683.183zM10 8c-.552 0-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5S10.552 8 10 8z"/>');// eslint-disable-next-line
var BIconEmojiHeartEyes=/*#__PURE__*/makeIcon('EmojiHeartEyes','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11.315 10.014a.5.5 0 0 1 .548.736A4.498 4.498 0 0 1 7.965 13a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .548-.736h.005l.017.005.067.015.252.055c.215.046.515.108.857.169.693.124 1.522.242 2.152.242.63 0 1.46-.118 2.152-.242a26.58 26.58 0 0 0 1.109-.224l.067-.015.017-.004.005-.002zM4.756 4.566c.763-1.424 4.02-.12.952 3.434-4.496-1.596-2.35-4.298-.952-3.434zm6.488 0c1.398-.864 3.544 1.838-.952 3.434-3.067-3.554.19-4.858.952-3.434z"/>');// eslint-disable-next-line
var BIconEmojiHeartEyesFill=/*#__PURE__*/makeIcon('EmojiHeartEyesFill','<path d="M8 0a8 8 0 1 0 0 16A8 8 0 0 0 8 0zM4.756 4.566c.763-1.424 4.02-.12.952 3.434-4.496-1.596-2.35-4.298-.952-3.434zm6.559 5.448a.5.5 0 0 1 .548.736A4.498 4.498 0 0 1 7.965 13a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .548-.736h.005l.017.005.067.015.252.055c.215.046.515.108.857.169.693.124 1.522.242 2.152.242.63 0 1.46-.118 2.152-.242a26.58 26.58 0 0 0 1.109-.224l.067-.015.017-.004.005-.002zm-.07-5.448c1.397-.864 3.543 1.838-.953 3.434-3.067-3.554.19-4.858.952-3.434z"/>');// eslint-disable-next-line
var BIconEmojiLaughing=/*#__PURE__*/makeIcon('EmojiLaughing','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M12.331 9.5a1 1 0 0 1 0 1A4.998 4.998 0 0 1 8 13a4.998 4.998 0 0 1-4.33-2.5A1 1 0 0 1 4.535 9h6.93a1 1 0 0 1 .866.5zM7 6.5c0 .828-.448 0-1 0s-1 .828-1 0S5.448 5 6 5s1 .672 1 1.5zm4 0c0 .828-.448 0-1 0s-1 .828-1 0S9.448 5 10 5s1 .672 1 1.5z"/>');// eslint-disable-next-line
var BIconEmojiLaughingFill=/*#__PURE__*/makeIcon('EmojiLaughingFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5c0 .501-.164.396-.415.235C6.42 6.629 6.218 6.5 6 6.5c-.218 0-.42.13-.585.235C5.164 6.896 5 7 5 6.5 5 5.672 5.448 5 6 5s1 .672 1 1.5zm5.331 3a1 1 0 0 1 0 1A4.998 4.998 0 0 1 8 13a4.998 4.998 0 0 1-4.33-2.5A1 1 0 0 1 4.535 9h6.93a1 1 0 0 1 .866.5zm-1.746-2.765C10.42 6.629 10.218 6.5 10 6.5c-.218 0-.42.13-.585.235C9.164 6.896 9 7 9 6.5c0-.828.448-1.5 1-1.5s1 .672 1 1.5c0 .501-.164.396-.415.235z"/>');// eslint-disable-next-line
var BIconEmojiNeutral=/*#__PURE__*/makeIcon('EmojiNeutral','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4 10.5a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7a.5.5 0 0 0-.5.5zm3-4C7 5.672 6.552 5 6 5s-1 .672-1 1.5S5.448 8 6 8s1-.672 1-1.5zm4 0c0-.828-.448-1.5-1-1.5s-1 .672-1 1.5S9.448 8 10 8s1-.672 1-1.5z"/>');// eslint-disable-next-line
var BIconEmojiNeutralFill=/*#__PURE__*/makeIcon('EmojiNeutralFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm-3 4a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM10 8c-.552 0-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5S10.552 8 10 8z"/>');// eslint-disable-next-line
var BIconEmojiSmile=/*#__PURE__*/makeIcon('EmojiSmile','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 9.567a.5.5 0 0 1 .683.183A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .183-.683zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm4 0c0 .828-.448 1.5-1 1.5s-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5z"/>');// eslint-disable-next-line
var BIconEmojiSmileFill=/*#__PURE__*/makeIcon('EmojiSmileFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zM4.285 9.567a.5.5 0 0 1 .683.183A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .183-.683zM10 8c-.552 0-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5S10.552 8 10 8z"/>');// eslint-disable-next-line
var BIconEmojiSmileUpsideDown=/*#__PURE__*/makeIcon('EmojiSmileUpsideDown','<path d="M8 1a7 7 0 1 0 0 14A7 7 0 0 0 8 1zm0-1a8 8 0 1 1 0 16A8 8 0 0 1 8 0z"/><path d="M4.285 6.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 4.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 3.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zM7 9.5C7 8.672 6.552 8 6 8s-1 .672-1 1.5.448 1.5 1 1.5 1-.672 1-1.5zm4 0c0-.828-.448-1.5-1-1.5s-1 .672-1 1.5.448 1.5 1 1.5 1-.672 1-1.5z"/>');// eslint-disable-next-line
var BIconEmojiSmileUpsideDownFill=/*#__PURE__*/makeIcon('EmojiSmileUpsideDownFill','<path d="M8 0a8 8 0 1 1 0 16A8 8 0 0 1 8 0zM7 9.5C7 8.672 6.552 8 6 8s-1 .672-1 1.5.448 1.5 1 1.5 1-.672 1-1.5zM4.285 6.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 4.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 3.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zM10 8c-.552 0-1 .672-1 1.5s.448 1.5 1 1.5 1-.672 1-1.5S10.552 8 10 8z"/>');// eslint-disable-next-line
var BIconEmojiSunglasses=/*#__PURE__*/makeIcon('EmojiSunglasses','<path d="M4.968 9.75a.5.5 0 1 0-.866.5A4.498 4.498 0 0 0 8 12.5a4.5 4.5 0 0 0 3.898-2.25.5.5 0 1 0-.866-.5A3.498 3.498 0 0 1 8 11.5a3.498 3.498 0 0 1-3.032-1.75zM7 5.116V5a1 1 0 0 0-1-1H3.28a1 1 0 0 0-.97 1.243l.311 1.242A2 2 0 0 0 4.561 8H5a2 2 0 0 0 1.994-1.839A2.99 2.99 0 0 1 8 6c.393 0 .74.064 1.006.161A2 2 0 0 0 11 8h.438a2 2 0 0 0 1.94-1.515l.311-1.242A1 1 0 0 0 12.72 4H10a1 1 0 0 0-1 1v.116A4.22 4.22 0 0 0 8 5c-.35 0-.69.04-1 .116z"/><path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-1 0A7 7 0 1 0 1 8a7 7 0 0 0 14 0z"/>');// eslint-disable-next-line
var BIconEmojiSunglassesFill=/*#__PURE__*/makeIcon('EmojiSunglassesFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM2.31 5.243A1 1 0 0 1 3.28 4H6a1 1 0 0 1 1 1v.116A4.22 4.22 0 0 1 8 5c.35 0 .69.04 1 .116V5a1 1 0 0 1 1-1h2.72a1 1 0 0 1 .97 1.243l-.311 1.242A2 2 0 0 1 11.439 8H11a2 2 0 0 1-1.994-1.839A2.99 2.99 0 0 0 8 6c-.393 0-.74.064-1.006.161A2 2 0 0 1 5 8h-.438a2 2 0 0 1-1.94-1.515L2.31 5.243zM4.969 9.75A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .866-.5z"/>');// eslint-disable-next-line
var BIconEmojiWink=/*#__PURE__*/makeIcon('EmojiWink','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 9.567a.5.5 0 0 1 .683.183A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .183-.683zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm1.757-.437a.5.5 0 0 1 .68.194.934.934 0 0 0 .813.493c.339 0 .645-.19.813-.493a.5.5 0 1 1 .874.486A1.934 1.934 0 0 1 10.25 7.75c-.73 0-1.356-.412-1.687-1.007a.5.5 0 0 1 .194-.68z"/>');// eslint-disable-next-line
var BIconEmojiWinkFill=/*#__PURE__*/makeIcon('EmojiWinkFill','<path d="M8 0a8 8 0 1 1 0 16A8 8 0 0 1 8 0zM7 6.5C7 5.672 6.552 5 6 5s-1 .672-1 1.5S5.448 8 6 8s1-.672 1-1.5zM4.285 9.567a.5.5 0 0 0-.183.683A4.498 4.498 0 0 0 8 12.5a4.5 4.5 0 0 0 3.898-2.25.5.5 0 1 0-.866-.5A3.498 3.498 0 0 1 8 11.5a3.498 3.498 0 0 1-3.032-1.75.5.5 0 0 0-.683-.183zm5.152-3.31a.5.5 0 0 0-.874.486c.33.595.958 1.007 1.687 1.007.73 0 1.356-.412 1.687-1.007a.5.5 0 0 0-.874-.486.934.934 0 0 1-.813.493.934.934 0 0 1-.813-.493z"/>');// eslint-disable-next-line
var BIconEnvelope=/*#__PURE__*/makeIcon('Envelope','<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm2-1a1 1 0 0 0-1 1v.217l7 4.2 7-4.2V4a1 1 0 0 0-1-1H2zm13 2.383l-4.758 2.855L15 11.114v-5.73zm-.034 6.878L9.271 8.82 8 9.583 6.728 8.82l-5.694 3.44A1 1 0 0 0 2 13h12a1 1 0 0 0 .966-.739zM1 11.114l4.758-2.876L1 5.383v5.73z"/>');// eslint-disable-next-line
var BIconEnvelopeFill=/*#__PURE__*/makeIcon('EnvelopeFill','<path d="M.05 3.555A2 2 0 0 1 2 2h12a2 2 0 0 1 1.95 1.555L8 8.414.05 3.555zM0 4.697v7.104l5.803-3.558L0 4.697zM6.761 8.83l-6.57 4.027A2 2 0 0 0 2 14h12a2 2 0 0 0 1.808-1.144l-6.57-4.027L8 9.586l-1.239-.757zm3.436-.586L16 11.801V4.697l-5.803 3.546z"/>');// eslint-disable-next-line
var BIconEnvelopeOpen=/*#__PURE__*/makeIcon('EnvelopeOpen','<path d="M8.47 1.318a1 1 0 0 0-.94 0l-6 3.2A1 1 0 0 0 1 5.4v.818l5.724 3.465L8 8.917l1.276.766L15 6.218V5.4a1 1 0 0 0-.53-.882l-6-3.2zM15 7.388l-4.754 2.877L15 13.117v-5.73zm-.035 6.874L8 10.083l-6.965 4.18A1 1 0 0 0 2 15h12a1 1 0 0 0 .965-.738zM1 13.117l4.754-2.852L1 7.387v5.73zM7.059.435a2 2 0 0 1 1.882 0l6 3.2A2 2 0 0 1 16 5.4V14a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V5.4a2 2 0 0 1 1.059-1.765l6-3.2z"/>');// eslint-disable-next-line
var BIconEnvelopeOpenFill=/*#__PURE__*/makeIcon('EnvelopeOpenFill','<path d="M8.941.435a2 2 0 0 0-1.882 0l-6 3.2A2 2 0 0 0 0 5.4v.313l6.709 3.933L8 8.928l1.291.717L16 5.715V5.4a2 2 0 0 0-1.059-1.765l-6-3.2zM16 6.873l-5.693 3.337L16 13.372v-6.5zm-.059 7.611L8 10.072.059 14.484A2 2 0 0 0 2 16h12a2 2 0 0 0 1.941-1.516zM0 13.373l5.693-3.163L0 6.873v6.5z"/>');// eslint-disable-next-line
var BIconExclamation=/*#__PURE__*/makeIcon('Exclamation','<path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.553.553 0 0 1-1.1 0L7.1 4.995z"/>');// eslint-disable-next-line
var BIconExclamationCircle=/*#__PURE__*/makeIcon('ExclamationCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>');// eslint-disable-next-line
var BIconExclamationCircleFill=/*#__PURE__*/makeIcon('ExclamationCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8 4a.905.905 0 0 0-.9.995l.35 3.507a.552.552 0 0 0 1.1 0l.35-3.507A.905.905 0 0 0 8 4zm.002 6a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>');// eslint-disable-next-line
var BIconExclamationDiamond=/*#__PURE__*/makeIcon('ExclamationDiamond','<path d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435zm1.4.7a.495.495 0 0 0-.7 0L1.134 7.65a.495.495 0 0 0 0 .7l6.516 6.516a.495.495 0 0 0 .7 0l6.516-6.516a.495.495 0 0 0 0-.7L8.35 1.134z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>');// eslint-disable-next-line
var BIconExclamationDiamondFill=/*#__PURE__*/makeIcon('ExclamationDiamondFill','<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L.436 6.95c-.58.58-.58 1.519 0 2.098l6.516 6.516c.58.58 1.519.58 2.098 0l6.516-6.516c.58-.58.58-1.519 0-2.098L9.05.435zM8 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconExclamationOctagon=/*#__PURE__*/makeIcon('ExclamationOctagon','<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>');// eslint-disable-next-line
var BIconExclamationOctagonFill=/*#__PURE__*/makeIcon('ExclamationOctagonFill','<path d="M11.46.146A.5.5 0 0 0 11.107 0H4.893a.5.5 0 0 0-.353.146L.146 4.54A.5.5 0 0 0 0 4.893v6.214a.5.5 0 0 0 .146.353l4.394 4.394a.5.5 0 0 0 .353.146h6.214a.5.5 0 0 0 .353-.146l4.394-4.394a.5.5 0 0 0 .146-.353V4.893a.5.5 0 0 0-.146-.353L11.46.146zM8 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconExclamationSquare=/*#__PURE__*/makeIcon('ExclamationSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>');// eslint-disable-next-line
var BIconExclamationSquareFill=/*#__PURE__*/makeIcon('ExclamationSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm6 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconExclamationTriangle=/*#__PURE__*/makeIcon('ExclamationTriangle','<path d="M7.938 2.016A.13.13 0 0 1 8.002 2a.13.13 0 0 1 .063.016.146.146 0 0 1 .054.057l6.857 11.667c.036.06.035.124.002.183a.163.163 0 0 1-.054.06.116.116 0 0 1-.066.017H1.146a.115.115 0 0 1-.066-.017.163.163 0 0 1-.054-.06.176.176 0 0 1 .002-.183L7.884 2.073a.147.147 0 0 1 .054-.057zm1.044-.45a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566z"/><path d="M7.002 12a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 5.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995z"/>');// eslint-disable-next-line
var BIconExclamationTriangleFill=/*#__PURE__*/makeIcon('ExclamationTriangleFill','<path d="M8.982 1.566a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566zM8 5c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995A.905.905 0 0 1 8 5zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconExclude=/*#__PURE__*/makeIcon('Exclude','<path d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm12 2H5a1 1 0 0 0-1 1v7h7a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconEye=/*#__PURE__*/makeIcon('Eye','<path d="M16 8s-3-5.5-8-5.5S0 8 0 8s3 5.5 8 5.5S16 8 16 8zM1.173 8a13.133 13.133 0 0 1 1.66-2.043C4.12 4.668 5.88 3.5 8 3.5c2.12 0 3.879 1.168 5.168 2.457A13.133 13.133 0 0 1 14.828 8c-.058.087-.122.183-.195.288-.335.48-.83 1.12-1.465 1.755C11.879 11.332 10.119 12.5 8 12.5c-2.12 0-3.879-1.168-5.168-2.457A13.134 13.134 0 0 1 1.172 8z"/><path d="M8 5.5a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5zM4.5 8a3.5 3.5 0 1 1 7 0 3.5 3.5 0 0 1-7 0z"/>');// eslint-disable-next-line
var BIconEyeFill=/*#__PURE__*/makeIcon('EyeFill','<path d="M10.5 8a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0z"/><path d="M0 8s3-5.5 8-5.5S16 8 16 8s-3 5.5-8 5.5S0 8 0 8zm8 3.5a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7z"/>');// eslint-disable-next-line
var BIconEyeSlash=/*#__PURE__*/makeIcon('EyeSlash','<path d="M13.359 11.238C15.06 9.72 16 8 16 8s-3-5.5-8-5.5a7.028 7.028 0 0 0-2.79.588l.77.771A5.944 5.944 0 0 1 8 3.5c2.12 0 3.879 1.168 5.168 2.457A13.134 13.134 0 0 1 14.828 8c-.058.087-.122.183-.195.288-.335.48-.83 1.12-1.465 1.755-.165.165-.337.328-.517.486l.708.709z"/><path d="M11.297 9.176a3.5 3.5 0 0 0-4.474-4.474l.823.823a2.5 2.5 0 0 1 2.829 2.829l.822.822zm-2.943 1.299l.822.822a3.5 3.5 0 0 1-4.474-4.474l.823.823a2.5 2.5 0 0 0 2.829 2.829z"/><path d="M3.35 5.47c-.18.16-.353.322-.518.487A13.134 13.134 0 0 0 1.172 8l.195.288c.335.48.83 1.12 1.465 1.755C4.121 11.332 5.881 12.5 8 12.5c.716 0 1.39-.133 2.02-.36l.77.772A7.029 7.029 0 0 1 8 13.5C3 13.5 0 8 0 8s.939-1.721 2.641-3.238l.708.709zm10.296 8.884l-12-12 .708-.708 12 12-.708.708z"/>');// eslint-disable-next-line
var BIconEyeSlashFill=/*#__PURE__*/makeIcon('EyeSlashFill','<path d="M10.79 12.912l-1.614-1.615a3.5 3.5 0 0 1-4.474-4.474l-2.06-2.06C.938 6.278 0 8 0 8s3 5.5 8 5.5a7.027 7.027 0 0 0 2.79-.588zM5.21 3.088A7.028 7.028 0 0 1 8 2.5c5 0 8 5.5 8 5.5s-.939 1.721-2.641 3.238l-2.062-2.062a3.5 3.5 0 0 0-4.474-4.474L5.21 3.088z"/><path d="M5.525 7.646a2.5 2.5 0 0 0 2.829 2.829l-2.83-2.829zm4.95.708l-2.829-2.83a2.5 2.5 0 0 1 2.829 2.829zm3.171 6l-12-12 .708-.708 12 12-.708.707z"/>');// eslint-disable-next-line
var BIconEyeglasses=/*#__PURE__*/makeIcon('Eyeglasses','<path d="M4 6a2 2 0 1 1 0 4 2 2 0 0 1 0-4zm2.625.547a3 3 0 0 0-5.584.953H.5a.5.5 0 0 0 0 1h.541A3 3 0 0 0 7 8a1 1 0 0 1 2 0 3 3 0 0 0 5.959.5h.541a.5.5 0 0 0 0-1h-.541a3 3 0 0 0-5.584-.953A1.993 1.993 0 0 0 8 6c-.532 0-1.016.208-1.375.547zM14 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>');// eslint-disable-next-line
var BIconFacebook=/*#__PURE__*/makeIcon('Facebook','<path d="M16 8.049c0-4.446-3.582-8.05-8-8.05C3.58 0-.002 3.603-.002 8.05c0 4.017 2.926 7.347 6.75 7.951v-5.625h-2.03V8.05H6.75V6.275c0-2.017 1.195-3.131 3.022-3.131.876 0 1.791.157 1.791.157v1.98h-1.009c-.993 0-1.303.621-1.303 1.258v1.51h2.218l-.354 2.326H9.25V16c3.824-.604 6.75-3.934 6.75-7.951z"/>');// eslint-disable-next-line
var BIconFile=/*#__PURE__*/makeIcon('File','<path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileArrowDown=/*#__PURE__*/makeIcon('FileArrowDown','<path d="M8 5a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5A.5.5 0 0 1 8 5z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileArrowDownFill=/*#__PURE__*/makeIcon('FileArrowDownFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8 5a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5A.5.5 0 0 1 8 5z"/>');// eslint-disable-next-line
var BIconFileArrowUp=/*#__PURE__*/makeIcon('FileArrowUp','<path d="M8 11a.5.5 0 0 0 .5-.5V6.707l1.146 1.147a.5.5 0 0 0 .708-.708l-2-2a.5.5 0 0 0-.708 0l-2 2a.5.5 0 1 0 .708.708L7.5 6.707V10.5a.5.5 0 0 0 .5.5z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileArrowUpFill=/*#__PURE__*/makeIcon('FileArrowUpFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM7.5 6.707L6.354 7.854a.5.5 0 1 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 6.707V10.5a.5.5 0 0 1-1 0V6.707z"/>');// eslint-disable-next-line
var BIconFileBarGraph=/*#__PURE__*/makeIcon('FileBarGraph','<path d="M4.5 12a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1zm3 0a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm3 0a.5.5 0 0 1-.5-.5v-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-.5.5h-1z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileBarGraphFill=/*#__PURE__*/makeIcon('FileBarGraphFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-2 11.5v-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5zm-2.5.5a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm-3 0a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1z"/>');// eslint-disable-next-line
var BIconFileBinary=/*#__PURE__*/makeIcon('FileBinary','<path d="M5.526 13.09c.976 0 1.524-.79 1.524-2.205 0-1.412-.548-2.203-1.524-2.203-.978 0-1.526.79-1.526 2.203 0 1.415.548 2.206 1.526 2.206zm-.832-2.205c0-1.05.29-1.612.832-1.612.358 0 .607.247.733.721L4.7 11.137a6.749 6.749 0 0 1-.006-.252zm.832 1.614c-.36 0-.606-.246-.732-.718l1.556-1.145c.003.079.005.164.005.249 0 1.052-.29 1.614-.829 1.614zm5.329.501v-.595H9.73V8.772h-.69l-1.19.786v.688L8.986 9.5h.05v2.906h-1.18V13h3z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileBinaryFill=/*#__PURE__*/makeIcon('FileBinaryFill','<path d="M5.526 9.273c-.542 0-.832.563-.832 1.612 0 .088.003.173.006.252l1.56-1.143c-.126-.474-.375-.72-.733-.72zm-.732 2.508c.126.472.372.718.732.718.54 0 .83-.563.83-1.614 0-.085-.003-.17-.006-.25l-1.556 1.146z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM7.05 10.885c0 1.415-.548 2.206-1.524 2.206C4.548 13.09 4 12.3 4 10.885c0-1.412.548-2.203 1.526-2.203.976 0 1.524.79 1.524 2.203zm3.805 1.52V13h-3v-.595h1.181V9.5h-.05l-1.136.747v-.688l1.19-.786h.69v3.633h1.125z"/>');// eslint-disable-next-line
var BIconFileBreak=/*#__PURE__*/makeIcon('FileBreak','<path d="M0 10.5a.5.5 0 0 1 .5-.5h15a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5zM12 0H4a2 2 0 0 0-2 2v7h1V2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v7h1V2a2 2 0 0 0-2-2zm2 12h-1v2a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-2H2v2a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2v-2z"/>');// eslint-disable-next-line
var BIconFileBreakFill=/*#__PURE__*/makeIcon('FileBreakFill','<path d="M4 0h8a2 2 0 0 1 2 2v7H2V2a2 2 0 0 1 2-2zM2 12h12v2a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-2zM.5 10a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>');// eslint-disable-next-line
var BIconFileCheck=/*#__PURE__*/makeIcon('FileCheck','<path d="M10.854 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileCheckFill=/*#__PURE__*/makeIcon('FileCheckFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-1.146 6.854l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 8.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconFileCode=/*#__PURE__*/makeIcon('FileCode','<path d="M6.646 5.646a.5.5 0 1 1 .708.708L5.707 8l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zm2.708 0a.5.5 0 1 0-.708.708L10.293 8 8.646 9.646a.5.5 0 0 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFileCodeFill=/*#__PURE__*/makeIcon('FileCodeFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6.646 5.646a.5.5 0 1 1 .708.708L5.707 8l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zm2.708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 8 8.646 6.354a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconFileDiff=/*#__PURE__*/makeIcon('FileDiff','<path d="M8 4a.5.5 0 0 1 .5.5V6H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V7H6a.5.5 0 0 1 0-1h1.5V4.5A.5.5 0 0 1 8 4zm-2.5 6.5A.5.5 0 0 1 6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFileDiffFill=/*#__PURE__*/makeIcon('FileDiffFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 4.5V6H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V7H6a.5.5 0 0 1 0-1h1.5V4.5a.5.5 0 0 1 1 0zM6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileEarmark=/*#__PURE__*/makeIcon('FileEarmark','<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>');// eslint-disable-next-line
var BIconFileEarmarkArrowDown=/*#__PURE__*/makeIcon('FileEarmarkArrowDown','<path d="M8.5 6.5a.5.5 0 0 0-1 0v3.793L6.354 9.146a.5.5 0 1 0-.708.708l2 2a.5.5 0 0 0 .708 0l2-2a.5.5 0 0 0-.708-.708L8.5 10.293V6.5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkArrowDownFill=/*#__PURE__*/makeIcon('FileEarmarkArrowDownFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-1 4v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 .708-.708L7.5 11.293V7.5a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconFileEarmarkArrowUp=/*#__PURE__*/makeIcon('FileEarmarkArrowUp','<path d="M8.5 11.5a.5.5 0 0 1-1 0V7.707L6.354 8.854a.5.5 0 1 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 7.707V11.5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkArrowUpFill=/*#__PURE__*/makeIcon('FileEarmarkArrowUpFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.354 9.854a.5.5 0 0 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 8.707V12.5a.5.5 0 0 1-1 0V8.707L6.354 9.854z"/>');// eslint-disable-next-line
var BIconFileEarmarkBarGraph=/*#__PURE__*/makeIcon('FileEarmarkBarGraph','<path d="M10 13.5a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-6a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v6zm-2.5.5a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm-3 0a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkBarGraphFill=/*#__PURE__*/makeIcon('FileEarmarkBarGraphFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm.5 10v-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5zm-2.5.5a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm-3 0a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1z"/>');// eslint-disable-next-line
var BIconFileEarmarkBinary=/*#__PURE__*/makeIcon('FileEarmarkBinary','<path d="M7.05 11.885c0 1.415-.548 2.206-1.524 2.206C4.548 14.09 4 13.3 4 11.885c0-1.412.548-2.203 1.526-2.203.976 0 1.524.79 1.524 2.203zm-1.524-1.612c-.542 0-.832.563-.832 1.612 0 .088.003.173.006.252l1.559-1.143c-.126-.474-.375-.72-.733-.72zm-.732 2.508c.126.472.372.718.732.718.54 0 .83-.563.83-1.614 0-.085-.003-.17-.006-.25l-1.556 1.146zm6.061.624V14h-3v-.595h1.181V10.5h-.05l-1.136.747v-.688l1.19-.786h.69v3.633h1.125z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkBinaryFill=/*#__PURE__*/makeIcon('FileEarmarkBinaryFill','<path d="M5.526 10.273c-.542 0-.832.563-.832 1.612 0 .088.003.173.006.252l1.559-1.143c-.126-.474-.375-.72-.733-.72zm-.732 2.508c.126.472.372.718.732.718.54 0 .83-.563.83-1.614 0-.085-.003-.17-.006-.25l-1.556 1.146z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-2.45 8.385c0 1.415-.548 2.206-1.524 2.206C4.548 14.09 4 13.3 4 11.885c0-1.412.548-2.203 1.526-2.203.976 0 1.524.79 1.524 2.203zm3.805 1.52V14h-3v-.595h1.181V10.5h-.05l-1.136.747v-.688l1.19-.786h.69v3.633h1.125z"/>');// eslint-disable-next-line
var BIconFileEarmarkBreak=/*#__PURE__*/makeIcon('FileEarmarkBreak','<path d="M14 4.5V9h-1V4.5h-2A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v7H2V2a2 2 0 0 1 2-2h5.5L14 4.5zM13 12h1v2a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-2h1v2a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1v-2zM.5 10a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>');// eslint-disable-next-line
var BIconFileEarmarkBreakFill=/*#__PURE__*/makeIcon('FileEarmarkBreakFill','<path d="M4 0h5.293A1 1 0 0 1 10 .293L13.707 4a1 1 0 0 1 .293.707V9H2V2a2 2 0 0 1 2-2zm5.5 1.5v2a1 1 0 0 0 1 1h2l-3-3zM2 12h12v2a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-2zM.5 10a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>');// eslint-disable-next-line
var BIconFileEarmarkCheck=/*#__PURE__*/makeIcon('FileEarmarkCheck','<path d="M10.854 7.854a.5.5 0 0 0-.708-.708L7.5 9.793 6.354 8.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkCheckFill=/*#__PURE__*/makeIcon('FileEarmarkCheckFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm1.354 4.354l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 9.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconFileEarmarkCode=/*#__PURE__*/makeIcon('FileEarmarkCode','<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/><path d="M8.646 6.646a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 9 8.646 7.354a.5.5 0 0 1 0-.708zm-1.292 0a.5.5 0 0 0-.708 0l-2 2a.5.5 0 0 0 0 .708l2 2a.5.5 0 0 0 .708-.708L5.707 9l1.647-1.646a.5.5 0 0 0 0-.708z"/>');// eslint-disable-next-line
var BIconFileEarmarkCodeFill=/*#__PURE__*/makeIcon('FileEarmarkCodeFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.646 7.646a.5.5 0 1 1 .708.708L5.707 10l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zm2.708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 10 8.646 8.354a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconFileEarmarkDiff=/*#__PURE__*/makeIcon('FileEarmarkDiff','<path d="M8 5a.5.5 0 0 1 .5.5V7H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V8H6a.5.5 0 0 1 0-1h1.5V5.5A.5.5 0 0 1 8 5zm-2.5 6.5A.5.5 0 0 1 6 11h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkDiffFill=/*#__PURE__*/makeIcon('FileEarmarkDiffFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM8 6a.5.5 0 0 1 .5.5V8H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V9H6a.5.5 0 0 1 0-1h1.5V6.5A.5.5 0 0 1 8 6zm-2.5 6.5A.5.5 0 0 1 6 12h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFileEarmarkEasel=/*#__PURE__*/makeIcon('FileEarmarkEasel','<path d="M8.5 6a.5.5 0 1 0-1 0h-2A1.5 1.5 0 0 0 4 7.5v2A1.5 1.5 0 0 0 5.5 11h.473l-.447 1.342a.5.5 0 1 0 .948.316L7.027 11H7.5v1a.5.5 0 0 0 1 0v-1h.473l.553 1.658a.5.5 0 1 0 .948-.316L10.027 11h.473A1.5 1.5 0 0 0 12 9.5v-2A1.5 1.5 0 0 0 10.5 6h-2zM5 7.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkEaselFill=/*#__PURE__*/makeIcon('FileEarmarkEaselFill','<path d="M5 7.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM8.5 6h2A1.5 1.5 0 0 1 12 7.5v2a1.5 1.5 0 0 1-1.5 1.5h-.473l.447 1.342a.5.5 0 0 1-.948.316L8.973 11H8.5v1a.5.5 0 0 1-1 0v-1h-.473l-.553 1.658a.5.5 0 1 1-.948-.316L5.973 11H5.5A1.5 1.5 0 0 1 4 9.5v-2A1.5 1.5 0 0 1 5.5 6h2a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconFileEarmarkExcel=/*#__PURE__*/makeIcon('FileEarmarkExcel','<path d="M5.884 6.68a.5.5 0 1 0-.768.64L7.349 10l-2.233 2.68a.5.5 0 0 0 .768.64L8 10.781l2.116 2.54a.5.5 0 0 0 .768-.641L8.651 10l2.233-2.68a.5.5 0 0 0-.768-.64L8 9.219l-2.116-2.54z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkExcelFill=/*#__PURE__*/makeIcon('FileEarmarkExcelFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5.884 6.68L8 9.219l2.116-2.54a.5.5 0 1 1 .768.641L8.651 10l2.233 2.68a.5.5 0 0 1-.768.64L8 10.781l-2.116 2.54a.5.5 0 0 1-.768-.641L7.349 10 5.116 7.32a.5.5 0 1 1 .768-.64z"/>');// eslint-disable-next-line
var BIconFileEarmarkFill=/*#__PURE__*/makeIcon('FileEarmarkFill','<path d="M4 0h5.293A1 1 0 0 1 10 .293L13.707 4a1 1 0 0 1 .293.707V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2zm5.5 1.5v2a1 1 0 0 0 1 1h2l-3-3z"/>');// eslint-disable-next-line
var BIconFileEarmarkFont=/*#__PURE__*/makeIcon('FileEarmarkFont','<path d="M10.943 6H5.057L5 8h.5c.18-1.096.356-1.192 1.694-1.235l.293-.01v5.09c0 .47-.1.582-.898.655v.5H9.41v-.5c-.803-.073-.903-.184-.903-.654V6.755l.298.01c1.338.043 1.514.14 1.694 1.235h.5l-.057-2z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>');// eslint-disable-next-line
var BIconFileEarmarkFontFill=/*#__PURE__*/makeIcon('FileEarmarkFontFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5.057 6h5.886L11 8h-.5c-.18-1.096-.356-1.192-1.694-1.235l-.298-.01v5.09c0 .47.1.582.903.655v.5H6.59v-.5c.799-.073.898-.184.898-.654V6.755l-.293.01C5.856 6.808 5.68 6.905 5.5 8H5l.057-2z"/>');// eslint-disable-next-line
var BIconFileEarmarkImage=/*#__PURE__*/makeIcon('FileEarmarkImage','<path d="M6.502 7a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/><path d="M14 14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5V14zM4 1a1 1 0 0 0-1 1v10l2.224-2.224a.5.5 0 0 1 .61-.075L8 11l2.157-3.02a.5.5 0 0 1 .76-.063L13 10V4.5h-2A1.5 1.5 0 0 1 9.5 3V1H4z"/>');// eslint-disable-next-line
var BIconFileEarmarkImageFill=/*#__PURE__*/makeIcon('FileEarmarkImageFill','<path d="M4 0h5.293A1 1 0 0 1 10 .293L13.707 4a1 1 0 0 1 .293.707v5.586l-2.73-2.73a1 1 0 0 0-1.52.127l-1.889 2.644-1.769-1.062a1 1 0 0 0-1.222.15L2 12.292V2a2 2 0 0 1 2-2zm5.5 1.5v2a1 1 0 0 0 1 1h2l-3-3zm-1.498 4a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/><path d="M10.564 8.27L14 11.708V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-.293l3.578-3.577 2.56 1.536 2.426-3.395z"/>');// eslint-disable-next-line
var BIconFileEarmarkLock=/*#__PURE__*/makeIcon('FileEarmarkLock','<path d="M10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0zM7 7v1h2V7a1 1 0 0 0-2 0zM6 9.3v2.4c0 .042.02.107.105.175A.637.637 0 0 0 6.5 12h3a.64.64 0 0 0 .395-.125c.085-.068.105-.133.105-.175V9.3c0-.042-.02-.107-.105-.175A.637.637 0 0 0 9.5 9h-3a.637.637 0 0 0-.395.125C6.02 9.193 6 9.258 6 9.3z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkLock2=/*#__PURE__*/makeIcon('FileEarmarkLock2','<path d="M10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0zM7 7v1h2V7a1 1 0 0 0-2 0z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkLock2Fill=/*#__PURE__*/makeIcon('FileEarmarkLock2Fill','<path d="M7 7a1 1 0 0 1 2 0v1H7V7z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0z"/>');// eslint-disable-next-line
var BIconFileEarmarkLockFill=/*#__PURE__*/makeIcon('FileEarmarkLockFill','<path d="M7 7a1 1 0 0 1 2 0v1H7V7zM6 9.3c0-.042.02-.107.105-.175A.637.637 0 0 1 6.5 9h3a.64.64 0 0 1 .395.125c.085.068.105.133.105.175v2.4c0 .042-.02.107-.105.175A.637.637 0 0 1 9.5 12h-3a.637.637 0 0 1-.395-.125C6.02 11.807 6 11.742 6 11.7V9.3z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0z"/>');// eslint-disable-next-line
var BIconFileEarmarkMedical=/*#__PURE__*/makeIcon('FileEarmarkMedical','<path d="M7.5 5.5a.5.5 0 0 0-1 0v.634l-.549-.317a.5.5 0 1 0-.5.866L6 7l-.549.317a.5.5 0 1 0 .5.866l.549-.317V8.5a.5.5 0 1 0 1 0v-.634l.549.317a.5.5 0 1 0 .5-.866L8 7l.549-.317a.5.5 0 1 0-.5-.866l-.549.317V5.5zm-2 4.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkMedicalFill=/*#__PURE__*/makeIcon('FileEarmarkMedicalFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-3 2v.634l.549-.317a.5.5 0 1 1 .5.866L7 7l.549.317a.5.5 0 1 1-.5.866L6.5 7.866V8.5a.5.5 0 0 1-1 0v-.634l-.549.317a.5.5 0 1 1-.5-.866L5 7l-.549-.317a.5.5 0 0 1 .5-.866l.549.317V5.5a.5.5 0 1 1 1 0zm-2 4.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zm0 2h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileEarmarkMinus=/*#__PURE__*/makeIcon('FileEarmarkMinus','<path d="M5.5 9a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>');// eslint-disable-next-line
var BIconFileEarmarkMinusFill=/*#__PURE__*/makeIcon('FileEarmarkMinusFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6 8.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileEarmarkMusic=/*#__PURE__*/makeIcon('FileEarmarkMusic','<path d="M11 6.64a1 1 0 0 0-1.243-.97l-1 .25A1 1 0 0 0 8 6.89v4.306A2.572 2.572 0 0 0 7 11c-.5 0-.974.134-1.338.377-.36.24-.662.628-.662 1.123s.301.883.662 1.123c.364.243.839.377 1.338.377.5 0 .974-.134 1.338-.377.36-.24.662-.628.662-1.123V8.89l2-.5V6.64z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkMusicFill=/*#__PURE__*/makeIcon('FileEarmarkMusicFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM11 6.64v1.75l-2 .5v3.61c0 .495-.301.883-.662 1.123C7.974 13.866 7.499 14 7 14c-.5 0-.974-.134-1.338-.377-.36-.24-.662-.628-.662-1.123s.301-.883.662-1.123C6.026 11.134 6.501 11 7 11c.356 0 .7.068 1 .196V6.89a1 1 0 0 1 .757-.97l1-.25A1 1 0 0 1 11 6.64z"/>');// eslint-disable-next-line
var BIconFileEarmarkPerson=/*#__PURE__*/makeIcon('FileEarmarkPerson','<path d="M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2v9.255S12 12 8 12s-5 1.755-5 1.755V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkPersonFill=/*#__PURE__*/makeIcon('FileEarmarkPersonFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0zm2 5.755V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-.245S4 12 8 12s5 1.755 5 1.755z"/>');// eslint-disable-next-line
var BIconFileEarmarkPlay=/*#__PURE__*/makeIcon('FileEarmarkPlay','<path d="M6 6.883v4.234a.5.5 0 0 0 .757.429l3.528-2.117a.5.5 0 0 0 0-.858L6.757 6.454a.5.5 0 0 0-.757.43z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkPlayFill=/*#__PURE__*/makeIcon('FileEarmarkPlayFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6 6.883a.5.5 0 0 1 .757-.429l3.528 2.117a.5.5 0 0 1 0 .858l-3.528 2.117a.5.5 0 0 1-.757-.43V6.884z"/>');// eslint-disable-next-line
var BIconFileEarmarkPlus=/*#__PURE__*/makeIcon('FileEarmarkPlus','<path d="M8 6.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V9.5H6a.5.5 0 0 1 0-1h1.5V7a.5.5 0 0 1 .5-.5z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>');// eslint-disable-next-line
var BIconFileEarmarkPlusFill=/*#__PURE__*/makeIcon('FileEarmarkPlusFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM8.5 7v1.5H10a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V9.5H6a.5.5 0 0 1 0-1h1.5V7a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconFileEarmarkPost=/*#__PURE__*/makeIcon('FileEarmarkPost','<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/><path d="M4 6.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-7zm0-3a.5.5 0 0 1 .5-.5H7a.5.5 0 0 1 0 1H4.5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFileEarmarkPostFill=/*#__PURE__*/makeIcon('FileEarmarkPostFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-5-.5H7a.5.5 0 0 1 0 1H4.5a.5.5 0 0 1 0-1zm0 3h7a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-7a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconFileEarmarkPpt=/*#__PURE__*/makeIcon('FileEarmarkPpt','<path d="M5 6a.5.5 0 0 0-.496.438l-.5 4A.5.5 0 0 0 4.5 11h3v2.016c-.863.055-1.5.251-1.5.484 0 .276.895.5 2 .5s2-.224 2-.5c0-.233-.637-.429-1.5-.484V11h3a.5.5 0 0 0 .496-.562l-.5-4A.5.5 0 0 0 11 6H5zm2 3.78V7.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 9.778z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkPptFill=/*#__PURE__*/makeIcon('FileEarmarkPptFill','<path d="M6.5 8.5a2 2 0 1 0 4 0 2 2 0 0 0-4 0z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.5 6v.264a3 3 0 1 1 0 4.472V13.5a.5.5 0 0 1-1 0V6a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconFileEarmarkRichtext=/*#__PURE__*/makeIcon('FileEarmarkRichtext','<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/><path d="M4.5 12.5A.5.5 0 0 1 5 12h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zm0-2A.5.5 0 0 1 5 10h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zm1.639-3.708l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V8.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V8s1.54-1.274 1.639-1.208zM6.25 6a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5z"/>');// eslint-disable-next-line
var BIconFileEarmarkRichtextFill=/*#__PURE__*/makeIcon('FileEarmarkRichtextFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM7 6.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V9.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V9s1.54-1.274 1.639-1.208zM5 11h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm0 2h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileEarmarkRuled=/*#__PURE__*/makeIcon('FileEarmarkRuled','<path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V9H3V2a1 1 0 0 1 1-1h5.5v2zM3 12v-2h2v2H3zm0 1h2v2H4a1 1 0 0 1-1-1v-1zm3 2v-2h7v1a1 1 0 0 1-1 1H6zm7-3H6v-2h7v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkRuledFill=/*#__PURE__*/makeIcon('FileEarmarkRuledFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM3 9h10v1H6v2h7v1H6v2H5v-2H3v-1h2v-2H3V9z"/>');// eslint-disable-next-line
var BIconFileEarmarkSlides=/*#__PURE__*/makeIcon('FileEarmarkSlides','<path d="M4 0h5.5v1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h1V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2z"/><path d="M9.5 3V0L14 4.5h-3A1.5 1.5 0 0 1 9.5 3zm.5 10.5c0 .276-.895.5-2 .5s-2-.224-2-.5.895-.5 2-.5 2 .224 2 .5z"/><path fill-rule="evenodd" d="M4.504 6.438A.5.5 0 0 1 5 6h6a.5.5 0 0 1 .496.438l.5 4A.5.5 0 0 1 11.5 11h-3v2.016a7.795 7.795 0 0 0-1 0V11h-3a.5.5 0 0 1-.496-.562l.5-4zM7 7.221v2.558c0 .097.106.157.19.107l2.13-1.279a.125.125 0 0 0 0-.214l-2.13-1.28a.125.125 0 0 0-.19.109z"/>');// eslint-disable-next-line
var BIconFileEarmarkSlidesFill=/*#__PURE__*/makeIcon('FileEarmarkSlidesFill','<path d="M7 9.78V7.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 9.778z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5 6h6a.5.5 0 0 1 .496.438l.5 4A.5.5 0 0 1 11.5 11h-3v2.016c.863.055 1.5.251 1.5.484 0 .276-.895.5-2 .5s-2-.224-2-.5c0-.233.637-.429 1.5-.484V11h-3a.5.5 0 0 1-.496-.562l.5-4A.5.5 0 0 1 5 6z"/>');// eslint-disable-next-line
var BIconFileEarmarkSpreadsheet=/*#__PURE__*/makeIcon('FileEarmarkSpreadsheet','<path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V9H3V2a1 1 0 0 1 1-1h5.5v2zM3 12v-2h2v2H3zm0 1h2v2H4a1 1 0 0 1-1-1v-1zm3 2v-2h3v2H6zm4 0v-2h3v1a1 1 0 0 1-1 1h-2zm3-3h-3v-2h3v2zm-7 0v-2h3v2H6z"/>');// eslint-disable-next-line
var BIconFileEarmarkSpreadsheetFill=/*#__PURE__*/makeIcon('FileEarmarkSpreadsheetFill','<path d="M6 12v-2h3v2H6z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM3 9h10v1h-3v2h3v1h-3v2H9v-2H6v2H5v-2H3v-1h2v-2H3V9z"/>');// eslint-disable-next-line
var BIconFileEarmarkText=/*#__PURE__*/makeIcon('FileEarmarkText','<path d="M5.5 7a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zM5 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/><path d="M9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.5L9.5 0zm0 1v2A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5z"/>');// eslint-disable-next-line
var BIconFileEarmarkTextFill=/*#__PURE__*/makeIcon('FileEarmarkTextFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM4.5 9a.5.5 0 0 1 0-1h7a.5.5 0 0 1 0 1h-7zM4 10.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 1 0-1h4a.5.5 0 0 1 0 1h-4z"/>');// eslint-disable-next-line
var BIconFileEarmarkWord=/*#__PURE__*/makeIcon('FileEarmarkWord','<path d="M5.485 6.879a.5.5 0 1 0-.97.242l1.5 6a.5.5 0 0 0 .967.01L8 9.402l1.018 3.73a.5.5 0 0 0 .967-.01l1.5-6a.5.5 0 0 0-.97-.242l-1.036 4.144-.997-3.655a.5.5 0 0 0-.964 0l-.997 3.655L5.485 6.88z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkWordFill=/*#__PURE__*/makeIcon('FileEarmarkWordFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5.485 6.879l1.036 4.144.997-3.655a.5.5 0 0 1 .964 0l.997 3.655 1.036-4.144a.5.5 0 0 1 .97.242l-1.5 6a.5.5 0 0 1-.967.01L8 9.402l-1.018 3.73a.5.5 0 0 1-.967-.01l-1.5-6a.5.5 0 1 1 .97-.242z"/>');// eslint-disable-next-line
var BIconFileEarmarkX=/*#__PURE__*/makeIcon('FileEarmarkX','<path d="M6.854 7.146a.5.5 0 1 0-.708.708L7.293 9l-1.147 1.146a.5.5 0 0 0 .708.708L8 9.707l1.146 1.147a.5.5 0 0 0 .708-.708L8.707 9l1.147-1.146a.5.5 0 0 0-.708-.708L8 8.293 6.854 7.146z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconFileEarmarkXFill=/*#__PURE__*/makeIcon('FileEarmarkXFill','<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.854 7.146L8 8.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 9l1.147 1.146a.5.5 0 0 1-.708.708L8 9.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 9 6.146 7.854a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconFileEarmarkZip=/*#__PURE__*/makeIcon('FileEarmarkZip','<path d="M5 7.5a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v.938l.4 1.599a1 1 0 0 1-.416 1.074l-.93.62a1 1 0 0 1-1.11 0l-.929-.62a1 1 0 0 1-.415-1.074L5 8.438V7.5zm2 0H6v.938a1 1 0 0 1-.03.243l-.4 1.598.93.62.929-.62-.4-1.598A1 1 0 0 1 7 8.438V7.5z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1h-2v1h-1v1h1v1h-1v1h1v1H6V5H5V4h1V3H5V2h1V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>');// eslint-disable-next-line
var BIconFileEarmarkZipFill=/*#__PURE__*/makeIcon('FileEarmarkZipFill','<path d="M5.5 9.438V8.5h1v.938a1 1 0 0 0 .03.243l.4 1.598-.93.62-.93-.62.4-1.598a1 1 0 0 0 .03-.243z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-4-.5V2h-1V1H6v1h1v1H6v1h1v1H6v1h1v1H5.5V6h-1V5h1V4h-1V3h1zm0 4.5h1a1 1 0 0 1 1 1v.938l.4 1.599a1 1 0 0 1-.416 1.074l-.93.62a1 1 0 0 1-1.109 0l-.93-.62a1 1 0 0 1-.415-1.074l.4-1.599V8.5a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileEasel=/*#__PURE__*/makeIcon('FileEasel','<path d="M8.5 5a.5.5 0 1 0-1 0h-2A1.5 1.5 0 0 0 4 6.5v2A1.5 1.5 0 0 0 5.5 10h.473l-.447 1.342a.5.5 0 1 0 .948.316L7.027 10H7.5v1a.5.5 0 0 0 1 0v-1h.473l.553 1.658a.5.5 0 1 0 .948-.316L10.027 10h.473A1.5 1.5 0 0 0 12 8.5v-2A1.5 1.5 0 0 0 10.5 5h-2zM5 6.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFileEaselFill=/*#__PURE__*/makeIcon('FileEaselFill','<path d="M5 6.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 5h2A1.5 1.5 0 0 1 12 6.5v2a1.5 1.5 0 0 1-1.5 1.5h-.473l.447 1.342a.5.5 0 0 1-.948.316L8.973 10H8.5v1a.5.5 0 0 1-1 0v-1h-.473l-.553 1.658a.5.5 0 1 1-.948-.316L5.973 10H5.5A1.5 1.5 0 0 1 4 8.5v-2A1.5 1.5 0 0 1 5.5 5h2a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconFileExcel=/*#__PURE__*/makeIcon('FileExcel','<path d="M5.18 4.616a.5.5 0 0 1 .704.064L8 7.219l2.116-2.54a.5.5 0 1 1 .768.641L8.651 8l2.233 2.68a.5.5 0 0 1-.768.64L8 8.781l-2.116 2.54a.5.5 0 0 1-.768-.641L7.349 8 5.116 5.32a.5.5 0 0 1 .064-.704z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileExcelFill=/*#__PURE__*/makeIcon('FileExcelFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5.884 4.68L8 7.219l2.116-2.54a.5.5 0 1 1 .768.641L8.651 8l2.233 2.68a.5.5 0 0 1-.768.64L8 8.781l-2.116 2.54a.5.5 0 0 1-.768-.641L7.349 8 5.116 5.32a.5.5 0 1 1 .768-.64z"/>');// eslint-disable-next-line
var BIconFileFill=/*#__PURE__*/makeIcon('FileFill','<path fill-rule="evenodd" d="M4 0h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2z"/>');// eslint-disable-next-line
var BIconFileFont=/*#__PURE__*/makeIcon('FileFont','<path d="M10.943 4H5.057L5 6h.5c.18-1.096.356-1.192 1.694-1.235l.293-.01v6.09c0 .47-.1.582-.898.655v.5H9.41v-.5c-.803-.073-.903-.184-.903-.654V4.755l.298.01c1.338.043 1.514.14 1.694 1.235h.5l-.057-2z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileFontFill=/*#__PURE__*/makeIcon('FileFontFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5.057 4h5.886L11 6h-.5c-.18-1.096-.356-1.192-1.694-1.235l-.298-.01v6.09c0 .47.1.582.903.655v.5H6.59v-.5c.799-.073.898-.184.898-.654V4.755l-.293.01C5.856 4.808 5.68 4.905 5.5 6H5l.057-2z"/>');// eslint-disable-next-line
var BIconFileImage=/*#__PURE__*/makeIcon('FileImage','<path d="M8.002 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM3 2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v8l-2.083-2.083a.5.5 0 0 0-.76.063L8 11 5.835 9.7a.5.5 0 0 0-.611.076L3 12V2z"/>');// eslint-disable-next-line
var BIconFileImageFill=/*#__PURE__*/makeIcon('FileImageFill','<path d="M4 0h8a2 2 0 0 1 2 2v8.293l-2.73-2.73a1 1 0 0 0-1.52.127l-1.889 2.644-1.769-1.062a1 1 0 0 0-1.222.15L2 12.292V2a2 2 0 0 1 2-2zm4.002 5.5a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/><path d="M10.564 8.27L14 11.708V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-.293l3.578-3.577 2.56 1.536 2.426-3.395z"/>');// eslint-disable-next-line
var BIconFileLock=/*#__PURE__*/makeIcon('FileLock','<path d="M8 5a1 1 0 0 1 1 1v1H7V6a1 1 0 0 1 1-1zm2 2.076V6a2 2 0 1 0-4 0v1.076c-.54.166-1 .597-1 1.224v2.4c0 .816.781 1.3 1.5 1.3h3c.719 0 1.5-.484 1.5-1.3V8.3c0-.627-.46-1.058-1-1.224zM6.105 8.125A.637.637 0 0 1 6.5 8h3a.64.64 0 0 1 .395.125c.085.068.105.133.105.175v2.4c0 .042-.02.107-.105.175A.637.637 0 0 1 9.5 11h-3a.637.637 0 0 1-.395-.125C6.02 10.807 6 10.742 6 10.7V8.3c0-.042.02-.107.105-.175z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileLock2=/*#__PURE__*/makeIcon('FileLock2','<path d="M8 5a1 1 0 0 1 1 1v1H7V6a1 1 0 0 1 1-1zm2 2.076V6a2 2 0 1 0-4 0v1.076c-.54.166-1 .597-1 1.224v2.4c0 .816.781 1.3 1.5 1.3h3c.719 0 1.5-.484 1.5-1.3V8.3c0-.627-.46-1.058-1-1.224z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileLock2Fill=/*#__PURE__*/makeIcon('FileLock2Fill','<path d="M7 6a1 1 0 0 1 2 0v1H7V6z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-2 6v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V8.3c0-.627.46-1.058 1-1.224V6a2 2 0 1 1 4 0z"/>');// eslint-disable-next-line
var BIconFileLockFill=/*#__PURE__*/makeIcon('FileLockFill','<path d="M7 6a1 1 0 0 1 2 0v1H7V6zM6 8.3c0-.042.02-.107.105-.175A.637.637 0 0 1 6.5 8h3a.64.64 0 0 1 .395.125c.085.068.105.133.105.175v2.4c0 .042-.02.107-.105.175A.637.637 0 0 1 9.5 11h-3a.637.637 0 0 1-.395-.125C6.02 10.807 6 10.742 6 10.7V8.3z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-2 6v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V8.3c0-.627.46-1.058 1-1.224V6a2 2 0 1 1 4 0z"/>');// eslint-disable-next-line
var BIconFileMedical=/*#__PURE__*/makeIcon('FileMedical','<path d="M8.5 4.5a.5.5 0 0 0-1 0v.634l-.549-.317a.5.5 0 1 0-.5.866L7 6l-.549.317a.5.5 0 1 0 .5.866l.549-.317V7.5a.5.5 0 1 0 1 0v-.634l.549.317a.5.5 0 1 0 .5-.866L9 6l.549-.317a.5.5 0 1 0-.5-.866l-.549.317V4.5zM5.5 9a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFileMedicalFill=/*#__PURE__*/makeIcon('FileMedicalFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 4.5v.634l.549-.317a.5.5 0 1 1 .5.866L9 6l.549.317a.5.5 0 1 1-.5.866L8.5 6.866V7.5a.5.5 0 0 1-1 0v-.634l-.549.317a.5.5 0 1 1-.5-.866L7 6l-.549-.317a.5.5 0 0 1 .5-.866l.549.317V4.5a.5.5 0 1 1 1 0zM5.5 9h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zm0 2h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileMinus=/*#__PURE__*/makeIcon('FileMinus','<path d="M5.5 8a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileMinusFill=/*#__PURE__*/makeIcon('FileMinusFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6 7.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileMusic=/*#__PURE__*/makeIcon('FileMusic','<path d="M10.304 3.13a1 1 0 0 1 1.196.98v1.8l-2.5.5v5.09c0 .495-.301.883-.662 1.123C7.974 12.866 7.499 13 7 13c-.5 0-.974-.134-1.338-.377-.36-.24-.662-.628-.662-1.123s.301-.883.662-1.123C6.026 10.134 6.501 10 7 10c.356 0 .7.068 1 .196V4.41a1 1 0 0 1 .804-.98l1.5-.3z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileMusicFill=/*#__PURE__*/makeIcon('FileMusicFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-.5 4.11v1.8l-2.5.5v5.09c0 .495-.301.883-.662 1.123C7.974 12.866 7.499 13 7 13c-.5 0-.974-.134-1.338-.377-.36-.24-.662-.628-.662-1.123s.301-.883.662-1.123C6.026 10.134 6.501 10 7 10c.356 0 .7.068 1 .196V4.41a1 1 0 0 1 .804-.98l1.5-.3a1 1 0 0 1 1.196.98z"/>');// eslint-disable-next-line
var BIconFilePerson=/*#__PURE__*/makeIcon('FilePerson','<path d="M12 1a1 1 0 0 1 1 1v10.755S12 11 8 11s-5 1.755-5 1.755V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M8 10a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>');// eslint-disable-next-line
var BIconFilePersonFill=/*#__PURE__*/makeIcon('FilePersonFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-1 7a3 3 0 1 1-6 0 3 3 0 0 1 6 0zm-3 4c2.623 0 4.146.826 5 1.755V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-1.245C3.854 11.825 5.377 11 8 11z"/>');// eslint-disable-next-line
var BIconFilePlay=/*#__PURE__*/makeIcon('FilePlay','<path d="M6 10.117V5.883a.5.5 0 0 1 .757-.429l3.528 2.117a.5.5 0 0 1 0 .858l-3.528 2.117a.5.5 0 0 1-.757-.43z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFilePlayFill=/*#__PURE__*/makeIcon('FilePlayFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6 5.883a.5.5 0 0 1 .757-.429l3.528 2.117a.5.5 0 0 1 0 .858l-3.528 2.117a.5.5 0 0 1-.757-.43V5.884z"/>');// eslint-disable-next-line
var BIconFilePlus=/*#__PURE__*/makeIcon('FilePlus','<path d="M8.5 6a.5.5 0 0 0-1 0v1.5H6a.5.5 0 0 0 0 1h1.5V10a.5.5 0 0 0 1 0V8.5H10a.5.5 0 0 0 0-1H8.5V6z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFilePlusFill=/*#__PURE__*/makeIcon('FilePlusFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 6v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconFilePost=/*#__PURE__*/makeIcon('FilePost','<path d="M4 3.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-8z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFilePostFill=/*#__PURE__*/makeIcon('FilePostFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM4.5 3h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zm0 2h7a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-8a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconFilePpt=/*#__PURE__*/makeIcon('FilePpt','<path d="M6.5 4.5a.5.5 0 0 0-1 0V12a.5.5 0 0 0 1 0V9.236a3 3 0 1 0 0-4.472V4.5zm0 2.5a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFilePptFill=/*#__PURE__*/makeIcon('FilePptFill','<path d="M6.5 7a2 2 0 1 0 4 0 2 2 0 0 0-4 0z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6.5 4.5v.264a3 3 0 1 1 0 4.472V12a.5.5 0 0 1-1 0V4.5a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconFileRichtext=/*#__PURE__*/makeIcon('FileRichtext','<path d="M7 4.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V7.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V7s1.54-1.274 1.639-1.208zM5 9a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1H5zm0 2a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1H5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFileRichtextFill=/*#__PURE__*/makeIcon('FileRichtextFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM7 4.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V7.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V7s1.54-1.274 1.639-1.208zM5 9h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm0 2h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileRuled=/*#__PURE__*/makeIcon('FileRuled','<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v4h10V2a1 1 0 0 0-1-1H4zm9 6H6v2h7V7zm0 3H6v2h7v-2zm0 3H6v2h6a1 1 0 0 0 1-1v-1zm-8 2v-2H3v1a1 1 0 0 0 1 1h1zm-2-3h2v-2H3v2zm0-3h2V7H3v2z"/>');// eslint-disable-next-line
var BIconFileRuledFill=/*#__PURE__*/makeIcon('FileRuledFill','<path d="M12 0H4a2 2 0 0 0-2 2v4h12V2a2 2 0 0 0-2-2zm2 7H6v2h8V7zm0 3H6v2h8v-2zm0 3H6v3h6a2 2 0 0 0 2-2v-1zm-9 3v-3H2v1a2 2 0 0 0 2 2h1zm-3-4h3v-2H2v2zm0-3h3V7H2v2z"/>');// eslint-disable-next-line
var BIconFileSlides=/*#__PURE__*/makeIcon('FileSlides','<path d="M5 4a.5.5 0 0 0-.496.438l-.5 4A.5.5 0 0 0 4.5 9h3v2.016c-.863.055-1.5.251-1.5.484 0 .276.895.5 2 .5s2-.224 2-.5c0-.233-.637-.429-1.5-.484V9h3a.5.5 0 0 0 .496-.562l-.5-4A.5.5 0 0 0 11 4H5zm2 3.78V5.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 7.778z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFileSlidesFill=/*#__PURE__*/makeIcon('FileSlidesFill','<path d="M7 7.78V5.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 7.778z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5 4h6a.5.5 0 0 1 .496.438l.5 4A.5.5 0 0 1 11.5 9h-3v2.016c.863.055 1.5.251 1.5.484 0 .276-.895.5-2 .5s-2-.224-2-.5c0-.233.637-.429 1.5-.484V9h-3a.5.5 0 0 1-.496-.562l.5-4A.5.5 0 0 1 5 4z"/>');// eslint-disable-next-line
var BIconFileSpreadsheet=/*#__PURE__*/makeIcon('FileSpreadsheet','<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v4h10V2a1 1 0 0 0-1-1H4zm9 6h-3v2h3V7zm0 3h-3v2h3v-2zm0 3h-3v2h2a1 1 0 0 0 1-1v-1zm-4 2v-2H6v2h3zm-4 0v-2H3v1a1 1 0 0 0 1 1h1zm-2-3h2v-2H3v2zm0-3h2V7H3v2zm3-2v2h3V7H6zm3 3H6v2h3v-2z"/>');// eslint-disable-next-line
var BIconFileSpreadsheetFill=/*#__PURE__*/makeIcon('FileSpreadsheetFill','<path d="M12 0H4a2 2 0 0 0-2 2v4h12V2a2 2 0 0 0-2-2zm2 7h-4v2h4V7zm0 3h-4v2h4v-2zm0 3h-4v3h2a2 2 0 0 0 2-2v-1zm-5 3v-3H6v3h3zm-4 0v-3H2v1a2 2 0 0 0 2 2h1zm-3-4h3v-2H2v2zm0-3h3V7H2v2zm4 0V7h3v2H6zm0 1h3v2H6v-2z"/>');// eslint-disable-next-line
var BIconFileText=/*#__PURE__*/makeIcon('FileText','<path d="M5 4a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1H5zm-.5 2.5A.5.5 0 0 1 5 6h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zM5 8a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1H5zm0 2a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1H5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconFileTextFill=/*#__PURE__*/makeIcon('FileTextFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5 4h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm-.5 2.5A.5.5 0 0 1 5 6h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zM5 8h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm0 2h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconFileWord=/*#__PURE__*/makeIcon('FileWord','<path d="M4.879 4.515a.5.5 0 0 1 .606.364l1.036 4.144.997-3.655a.5.5 0 0 1 .964 0l.997 3.655 1.036-4.144a.5.5 0 0 1 .97.242l-1.5 6a.5.5 0 0 1-.967.01L8 7.402l-1.018 3.73a.5.5 0 0 1-.967-.01l-1.5-6a.5.5 0 0 1 .364-.606z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileWordFill=/*#__PURE__*/makeIcon('FileWordFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5.485 4.879l1.036 4.144.997-3.655a.5.5 0 0 1 .964 0l.997 3.655 1.036-4.144a.5.5 0 0 1 .97.242l-1.5 6a.5.5 0 0 1-.967.01L8 7.402l-1.018 3.73a.5.5 0 0 1-.967-.01l-1.5-6a.5.5 0 1 1 .97-.242z"/>');// eslint-disable-next-line
var BIconFileX=/*#__PURE__*/makeIcon('FileX','<path d="M6.146 6.146a.5.5 0 0 1 .708 0L8 7.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 8l1.147 1.146a.5.5 0 0 1-.708.708L8 8.707 6.854 9.854a.5.5 0 0 1-.708-.708L7.293 8 6.146 6.854a.5.5 0 0 1 0-.708z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconFileXFill=/*#__PURE__*/makeIcon('FileXFill','<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6.854 6.146L8 7.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 8l1.147 1.146a.5.5 0 0 1-.708.708L8 8.707 6.854 9.854a.5.5 0 0 1-.708-.708L7.293 8 6.146 6.854a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconFileZip=/*#__PURE__*/makeIcon('FileZip','<path d="M6.5 7.5a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v.938l.4 1.599a1 1 0 0 1-.416 1.074l-.93.62a1 1 0 0 1-1.109 0l-.93-.62a1 1 0 0 1-.415-1.074l.4-1.599V7.5zm2 0h-1v.938a1 1 0 0 1-.03.243l-.4 1.598.93.62.93-.62-.4-1.598a1 1 0 0 1-.03-.243V7.5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm5.5-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H9v1H8v1h1v1H8v1h1v1H7.5V5h-1V4h1V3h-1V2h1V1z"/>');// eslint-disable-next-line
var BIconFileZipFill=/*#__PURE__*/makeIcon('FileZipFill','<path d="M8.5 9.438V8.5h-1v.938a1 1 0 0 1-.03.243l-.4 1.598.93.62.93-.62-.4-1.598a1 1 0 0 1-.03-.243z"/><path d="M4 0h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2zm2.5 8.5v.938l-.4 1.599a1 1 0 0 0 .416 1.074l.93.62a1 1 0 0 0 1.109 0l.93-.62a1 1 0 0 0 .415-1.074l-.4-1.599V8.5a1 1 0 0 0-1-1h-1a1 1 0 0 0-1 1zm1-5.5h-1v1h1v1h-1v1h1v1H9V6H8V5h1V4H8V3h1V2H8V1H6.5v1h1v1z"/>');// eslint-disable-next-line
var BIconFiles=/*#__PURE__*/makeIcon('Files','<path d="M13 0H6a2 2 0 0 0-2 2 2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h7a2 2 0 0 0 2-2 2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm0 13V4a2 2 0 0 0-2-2H5a1 1 0 0 1 1-1h7a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1zM3 4a1 1 0 0 1 1-1h7a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V4z"/>');// eslint-disable-next-line
var BIconFilesAlt=/*#__PURE__*/makeIcon('FilesAlt','<path d="M11 0H3a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2 2 2 0 0 0 2-2V4a2 2 0 0 0-2-2 2 2 0 0 0-2-2zm2 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1V3zM2 2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V2z"/>');// eslint-disable-next-line
var BIconFilm=/*#__PURE__*/makeIcon('Film','<path d="M0 1a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v14a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V1zm4 0v6h8V1H4zm8 8H4v6h8V9zM1 1v2h2V1H1zm2 3H1v2h2V4zM1 7v2h2V7H1zm2 3H1v2h2v-2zm-2 3v2h2v-2H1zM15 1h-2v2h2V1zm-2 3v2h2V4h-2zm2 3h-2v2h2V7zm-2 3v2h2v-2h-2zm2 3h-2v2h2v-2z"/>');// eslint-disable-next-line
var BIconFilter=/*#__PURE__*/makeIcon('Filter','<path d="M6 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFilterCircle=/*#__PURE__*/makeIcon('FilterCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M7 11.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFilterCircleFill=/*#__PURE__*/makeIcon('FilterCircleFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM3.5 5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1 0-1zM5 8.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm2 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFilterLeft=/*#__PURE__*/makeIcon('FilterLeft','<path d="M2 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFilterRight=/*#__PURE__*/makeIcon('FilterRight','<path d="M14 10.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 .5-.5zm0-3a.5.5 0 0 0-.5-.5h-7a.5.5 0 0 0 0 1h7a.5.5 0 0 0 .5-.5zm0-3a.5.5 0 0 0-.5-.5h-11a.5.5 0 0 0 0 1h11a.5.5 0 0 0 .5-.5z"/>');// eslint-disable-next-line
var BIconFilterSquare=/*#__PURE__*/makeIcon('FilterSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M6 11.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFilterSquareFill=/*#__PURE__*/makeIcon('FilterSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm.5 5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1 0-1zM4 8.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm2 3a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFlag=/*#__PURE__*/makeIcon('Flag','<path d="M14.778.085A.5.5 0 0 1 15 .5V8a.5.5 0 0 1-.314.464L14.5 8l.186.464-.003.001-.006.003-.023.009a12.435 12.435 0 0 1-.397.15c-.264.095-.631.223-1.047.35-.816.252-1.879.523-2.71.523-.847 0-1.548-.28-2.158-.525l-.028-.01C7.68 8.71 7.14 8.5 6.5 8.5c-.7 0-1.638.23-2.437.477A19.626 19.626 0 0 0 3 9.342V15.5a.5.5 0 0 1-1 0V.5a.5.5 0 0 1 1 0v.282c.226-.079.496-.17.79-.26C4.606.272 5.67 0 6.5 0c.84 0 1.524.277 2.121.519l.043.018C9.286.788 9.828 1 10.5 1c.7 0 1.638-.23 2.437-.477a19.587 19.587 0 0 0 1.349-.476l.019-.007.004-.002h.001M14 1.221c-.22.078-.48.167-.766.255-.81.252-1.872.523-2.734.523-.886 0-1.592-.286-2.203-.534l-.008-.003C7.662 1.21 7.139 1 6.5 1c-.669 0-1.606.229-2.415.478A21.294 21.294 0 0 0 3 1.845v6.433c.22-.078.48-.167.766-.255C4.576 7.77 5.638 7.5 6.5 7.5c.847 0 1.548.28 2.158.525l.028.01C9.32 8.29 9.86 8.5 10.5 8.5c.668 0 1.606-.229 2.415-.478A21.317 21.317 0 0 0 14 7.655V1.222z"/>');// eslint-disable-next-line
var BIconFlagFill=/*#__PURE__*/makeIcon('FlagFill','<path d="M14.778.085A.5.5 0 0 1 15 .5V8a.5.5 0 0 1-.314.464L14.5 8l.186.464-.003.001-.006.003-.023.009a12.435 12.435 0 0 1-.397.15c-.264.095-.631.223-1.047.35-.816.252-1.879.523-2.71.523-.847 0-1.548-.28-2.158-.525l-.028-.01C7.68 8.71 7.14 8.5 6.5 8.5c-.7 0-1.638.23-2.437.477A19.626 19.626 0 0 0 3 9.342V15.5a.5.5 0 0 1-1 0V.5a.5.5 0 0 1 1 0v.282c.226-.079.496-.17.79-.26C4.606.272 5.67 0 6.5 0c.84 0 1.524.277 2.121.519l.043.018C9.286.788 9.828 1 10.5 1c.7 0 1.638-.23 2.437-.477a19.587 19.587 0 0 0 1.349-.476l.019-.007.004-.002h.001"/>');// eslint-disable-next-line
var BIconFlower1=/*#__PURE__*/makeIcon('Flower1','<path d="M6.174 1.184a2 2 0 0 1 3.652 0A2 2 0 0 1 12.99 3.01a2 2 0 0 1 1.826 3.164 2 2 0 0 1 0 3.652 2 2 0 0 1-1.826 3.164 2 2 0 0 1-3.164 1.826 2 2 0 0 1-3.652 0A2 2 0 0 1 3.01 12.99a2 2 0 0 1-1.826-3.164 2 2 0 0 1 0-3.652A2 2 0 0 1 3.01 3.01a2 2 0 0 1 3.164-1.826zM8 1a1 1 0 0 0-.998 1.03l.01.091c.012.077.029.176.054.296.049.241.122.542.213.887.182.688.428 1.513.676 2.314L8 5.762l.045-.144c.248-.8.494-1.626.676-2.314.091-.345.164-.646.213-.887a4.997 4.997 0 0 0 .064-.386L9 2a1 1 0 0 0-1-1zM2 9l.03-.002.091-.01a4.99 4.99 0 0 0 .296-.054c.241-.049.542-.122.887-.213a60.59 60.59 0 0 0 2.314-.676L5.762 8l-.144-.045a60.59 60.59 0 0 0-2.314-.676 16.705 16.705 0 0 0-.887-.213 4.99 4.99 0 0 0-.386-.064L2 7a1 1 0 1 0 0 2zm7 5l-.002-.03a5.005 5.005 0 0 0-.064-.386 16.398 16.398 0 0 0-.213-.888 60.582 60.582 0 0 0-.676-2.314L8 10.238l-.045.144c-.248.8-.494 1.626-.676 2.314-.091.345-.164.646-.213.887a4.996 4.996 0 0 0-.064.386L7 14a1 1 0 1 0 2 0zm-5.696-2.134l.025-.017a5.001 5.001 0 0 0 .303-.248c.184-.164.408-.377.661-.629A60.614 60.614 0 0 0 5.96 9.23l.103-.111-.147.033a60.88 60.88 0 0 0-2.343.572c-.344.093-.64.18-.874.258a5.063 5.063 0 0 0-.367.138l-.027.014a1 1 0 1 0 1 1.732zM4.5 14.062a1 1 0 0 0 1.366-.366l.014-.027c.01-.02.021-.048.036-.084a5.09 5.09 0 0 0 .102-.283c.078-.233.165-.53.258-.874a60.6 60.6 0 0 0 .572-2.343l.033-.147-.11.102a60.848 60.848 0 0 0-1.743 1.667 17.07 17.07 0 0 0-.629.66 5.06 5.06 0 0 0-.248.304l-.017.025a1 1 0 0 0 .366 1.366zm9.196-8.196a1 1 0 0 0-1-1.732l-.025.017a4.951 4.951 0 0 0-.303.248 16.69 16.69 0 0 0-.661.629A60.72 60.72 0 0 0 10.04 6.77l-.102.111.147-.033a60.6 60.6 0 0 0 2.342-.572c.345-.093.642-.18.875-.258a4.993 4.993 0 0 0 .367-.138.53.53 0 0 0 .027-.014zM11.5 1.938a1 1 0 0 0-1.366.366l-.014.027c-.01.02-.021.048-.036.084a5.09 5.09 0 0 0-.102.283c-.078.233-.165.53-.258.875a60.62 60.62 0 0 0-.572 2.342l-.033.147.11-.102a60.848 60.848 0 0 0 1.743-1.667c.252-.253.465-.477.629-.66a5.001 5.001 0 0 0 .248-.304l.017-.025a1 1 0 0 0-.366-1.366zM14 9a1 1 0 0 0 0-2l-.03.002a4.996 4.996 0 0 0-.386.064c-.242.049-.543.122-.888.213-.688.182-1.513.428-2.314.676L10.238 8l.144.045c.8.248 1.626.494 2.314.676.345.091.646.164.887.213a4.996 4.996 0 0 0 .386.064L14 9zM1.938 4.5a1 1 0 0 0 .393 1.38l.084.035c.072.03.166.064.283.103.233.078.53.165.874.258a60.88 60.88 0 0 0 2.343.572l.147.033-.103-.111a60.584 60.584 0 0 0-1.666-1.742 16.705 16.705 0 0 0-.66-.629 4.996 4.996 0 0 0-.304-.248l-.025-.017a1 1 0 0 0-1.366.366zm2.196-1.196l.017.025a4.996 4.996 0 0 0 .248.303c.164.184.377.408.629.661A60.597 60.597 0 0 0 6.77 5.96l.111.102-.033-.147a60.602 60.602 0 0 0-.572-2.342c-.093-.345-.18-.642-.258-.875a5.006 5.006 0 0 0-.138-.367l-.014-.027a1 1 0 1 0-1.732 1zm9.928 8.196a1 1 0 0 0-.366-1.366l-.027-.014a5 5 0 0 0-.367-.138c-.233-.078-.53-.165-.875-.258a60.619 60.619 0 0 0-2.342-.572l-.147-.033.102.111a60.73 60.73 0 0 0 1.667 1.742c.253.252.477.465.66.629a4.946 4.946 0 0 0 .304.248l.025.017a1 1 0 0 0 1.366-.366zm-3.928 2.196a1 1 0 0 0 1.732-1l-.017-.025a5.065 5.065 0 0 0-.248-.303 16.705 16.705 0 0 0-.629-.661A60.462 60.462 0 0 0 9.23 10.04l-.111-.102.033.147a60.6 60.6 0 0 0 .572 2.342c.093.345.18.642.258.875a4.985 4.985 0 0 0 .138.367.575.575 0 0 0 .014.027zM8 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/>');// eslint-disable-next-line
var BIconFlower2=/*#__PURE__*/makeIcon('Flower2','<path d="M8 16a4 4 0 0 0 4-4 4 4 0 0 0 0-8 4 4 0 0 0-8 0 4 4 0 1 0 0 8 4 4 0 0 0 4 4zm3-12c0 .073-.01.155-.03.247-.544.241-1.091.638-1.598 1.084A2.987 2.987 0 0 0 8 5c-.494 0-.96.12-1.372.331-.507-.446-1.054-.843-1.597-1.084A1.117 1.117 0 0 1 5 4a3 3 0 0 1 6 0zm-.812 6.052A2.99 2.99 0 0 0 11 8a2.99 2.99 0 0 0-.812-2.052c.215-.18.432-.346.647-.487C11.34 5.131 11.732 5 12 5a3 3 0 1 1 0 6c-.268 0-.66-.13-1.165-.461a6.833 6.833 0 0 1-.647-.487zm-3.56.617a3.001 3.001 0 0 0 2.744 0c.507.446 1.054.842 1.598 1.084.02.091.03.174.03.247a3 3 0 1 1-6 0c0-.073.01-.155.03-.247.544-.242 1.091-.638 1.598-1.084zm-.816-4.721A2.99 2.99 0 0 0 5 8c0 .794.308 1.516.812 2.052a6.83 6.83 0 0 1-.647.487C4.66 10.869 4.268 11 4 11a3 3 0 0 1 0-6c.268 0 .66.13 1.165.461.215.141.432.306.647.487zM8 9a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>');// eslint-disable-next-line
var BIconFlower3=/*#__PURE__*/makeIcon('Flower3','<path d="M11.424 8c.437-.052.811-.136 1.04-.268a2 2 0 0 0-2-3.464c-.229.132-.489.414-.752.767C9.886 4.63 10 4.264 10 4a2 2 0 1 0-4 0c0 .264.114.63.288 1.035-.263-.353-.523-.635-.752-.767a2 2 0 0 0-2 3.464c.229.132.603.216 1.04.268-.437.052-.811.136-1.04.268a2 2 0 1 0 2 3.464c.229-.132.489-.414.752-.767C6.114 11.37 6 11.736 6 12a2 2 0 1 0 4 0c0-.264-.114-.63-.288-1.035.263.353.523.635.752.767a2 2 0 1 0 2-3.464c-.229-.132-.603-.216-1.04-.268zM9 4a1.468 1.468 0 0 1-.045.205c-.039.132-.1.295-.183.484a12.88 12.88 0 0 1-.637 1.223L8 6.142a21.73 21.73 0 0 1-.135-.23 12.88 12.88 0 0 1-.637-1.223 4.216 4.216 0 0 1-.183-.484A1.473 1.473 0 0 1 7 4a1 1 0 1 1 2 0zM3.67 5.5a1 1 0 0 1 1.366-.366 1.472 1.472 0 0 1 .156.142c.094.1.204.233.326.4.245.333.502.747.742 1.163l.13.232a21.86 21.86 0 0 1-.265.002 12.88 12.88 0 0 1-1.379-.06 4.214 4.214 0 0 1-.51-.083 1.47 1.47 0 0 1-.2-.064A1 1 0 0 1 3.67 5.5zm1.366 5.366a1 1 0 0 1-1-1.732c.001 0 .016-.008.047-.02.037-.013.087-.028.153-.044.134-.032.305-.06.51-.083a12.88 12.88 0 0 1 1.379-.06c.09 0 .178 0 .266.002a21.82 21.82 0 0 1-.131.232c-.24.416-.497.83-.742 1.163a4.1 4.1 0 0 1-.327.4 1.483 1.483 0 0 1-.155.142zM9 12a1 1 0 0 1-2 0 1.476 1.476 0 0 1 .045-.206c.039-.131.1-.294.183-.483.166-.378.396-.808.637-1.223L8 9.858l.135.23c.241.415.47.845.637 1.223.083.19.144.352.183.484A1.338 1.338 0 0 1 9 12zm3.33-6.5a1 1 0 0 1-.366 1.366 1.478 1.478 0 0 1-.2.064c-.134.032-.305.06-.51.083-.412.045-.898.061-1.379.06-.09 0-.178 0-.266-.002l.131-.232c.24-.416.497-.83.742-1.163a4.1 4.1 0 0 1 .327-.4c.046-.05.085-.086.114-.11.026-.022.04-.03.041-.032a1 1 0 0 1 1.366.366zm-1.366 5.366a1.494 1.494 0 0 1-.155-.141 4.225 4.225 0 0 1-.327-.4A12.88 12.88 0 0 1 9.74 9.16a22 22 0 0 1-.13-.232l.265-.002c.48-.001.967.015 1.379.06.205.023.376.051.51.083.066.016.116.031.153.044l.048.02a1 1 0 1 1-1 1.732zM8 9a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>');// eslint-disable-next-line
var BIconFolder=/*#__PURE__*/makeIcon('Folder','<path d="M.54 3.87L.5 3a2 2 0 0 1 2-2h3.672a2 2 0 0 1 1.414.586l.828.828A2 2 0 0 0 9.828 3h3.982a2 2 0 0 1 1.992 2.181l-.637 7A2 2 0 0 1 13.174 14H2.826a2 2 0 0 1-1.991-1.819l-.637-7a1.99 1.99 0 0 1 .342-1.31zM2.19 4a1 1 0 0 0-.996 1.09l.637 7a1 1 0 0 0 .995.91h10.348a1 1 0 0 0 .995-.91l.637-7A1 1 0 0 0 13.81 4H2.19zm4.69-1.707A1 1 0 0 0 6.172 2H2.5a1 1 0 0 0-1 .981l.006.139C1.72 3.042 1.95 3 2.19 3h5.396l-.707-.707z"/>');// eslint-disable-next-line
var BIconFolder2=/*#__PURE__*/makeIcon('Folder2','<path d="M1 3.5A1.5 1.5 0 0 1 2.5 2h2.764c.958 0 1.76.56 2.311 1.184C7.985 3.648 8.48 4 9 4h4.5A1.5 1.5 0 0 1 15 5.5v7a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 12.5v-9zM2.5 3a.5.5 0 0 0-.5.5V6h12v-.5a.5.5 0 0 0-.5-.5H9c-.964 0-1.71-.629-2.174-1.154C6.374 3.334 5.82 3 5.264 3H2.5zM14 7H2v5.5a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 .5-.5V7z"/>');// eslint-disable-next-line
var BIconFolder2Open=/*#__PURE__*/makeIcon('Folder2Open','<path d="M1 3.5A1.5 1.5 0 0 1 2.5 2h2.764c.958 0 1.76.56 2.311 1.184C7.985 3.648 8.48 4 9 4h4.5A1.5 1.5 0 0 1 15 5.5v.64c.57.265.94.876.856 1.546l-.64 5.124A2.5 2.5 0 0 1 12.733 15H3.266a2.5 2.5 0 0 1-2.481-2.19l-.64-5.124A1.5 1.5 0 0 1 1 6.14V3.5zM2 6h12v-.5a.5.5 0 0 0-.5-.5H9c-.964 0-1.71-.629-2.174-1.154C6.374 3.334 5.82 3 5.264 3H2.5a.5.5 0 0 0-.5.5V6zm-.367 1a.5.5 0 0 0-.496.562l.64 5.124A1.5 1.5 0 0 0 3.266 14h9.468a1.5 1.5 0 0 0 1.489-1.314l.64-5.124A.5.5 0 0 0 14.367 7H1.633z"/>');// eslint-disable-next-line
var BIconFolderCheck=/*#__PURE__*/makeIcon('FolderCheck','<path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14H9v-1H2.826a1 1 0 0 1-.995-.91l-.637-7A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09L14.54 8h1.005l.256-2.819A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm5.672-1a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/><path d="M15.854 10.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708l1.146 1.147 2.646-2.647a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconFolderFill=/*#__PURE__*/makeIcon('FolderFill','<path d="M9.828 3h3.982a2 2 0 0 1 1.992 2.181l-.637 7A2 2 0 0 1 13.174 14H2.826a2 2 0 0 1-1.991-1.819l-.637-7a1.99 1.99 0 0 1 .342-1.31L.5 3a2 2 0 0 1 2-2h3.672a2 2 0 0 1 1.414.586l.828.828A2 2 0 0 0 9.828 3zm-8.322.12C1.72 3.042 1.95 3 2.19 3h5.396l-.707-.707A1 1 0 0 0 6.172 2H2.5a1 1 0 0 0-1 .981l.006.139z"/>');// eslint-disable-next-line
var BIconFolderMinus=/*#__PURE__*/makeIcon('FolderMinus','<path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14H9v-1H2.826a1 1 0 0 1-.995-.91l-.637-7A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09L14.54 8h1.005l.256-2.819A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm5.672-1a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/><path d="M11 11.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconFolderPlus=/*#__PURE__*/makeIcon('FolderPlus','<path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14H9v-1H2.826a1 1 0 0 1-.995-.91l-.637-7A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09L14.54 8h1.005l.256-2.819A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm5.672-1a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/><path d="M13.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H14v1.5a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H13v-1.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconFolderSymlink=/*#__PURE__*/makeIcon('FolderSymlink','<path d="M11.798 8.271l-3.182 1.97c-.27.166-.616-.036-.616-.372V9.1s-2.571-.3-4 2.4c.571-4.8 3.143-4.8 4-4.8v-.769c0-.336.346-.538.616-.371l3.182 1.969c.27.166.27.576 0 .742z"/><path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14h10.348a2 2 0 0 0 1.991-1.819l.637-7A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm.694 2.09A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09l-.636 7a1 1 0 0 1-.996.91H2.826a1 1 0 0 1-.995-.91l-.637-7zM6.172 2a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/>');// eslint-disable-next-line
var BIconFolderSymlinkFill=/*#__PURE__*/makeIcon('FolderSymlinkFill','<path d="M13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14h10.348a2 2 0 0 0 1.991-1.819l.637-7A2 2 0 0 0 13.81 3zM2.19 3c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672a1 1 0 0 1 .707.293L7.586 3H2.19zm9.608 5.271l-3.182 1.97c-.27.166-.616-.036-.616-.372V9.1s-2.571-.3-4 2.4c.571-4.8 3.143-4.8 4-4.8v-.769c0-.336.346-.538.616-.371l3.182 1.969c.27.166.27.576 0 .742z"/>');// eslint-disable-next-line
var BIconFolderX=/*#__PURE__*/makeIcon('FolderX','<path d="M.54 3.87L.5 3a2 2 0 0 1 2-2h3.672a2 2 0 0 1 1.414.586l.828.828A2 2 0 0 0 9.828 3h3.982a2 2 0 0 1 1.992 2.181L15.546 8H14.54l.265-2.91A1 1 0 0 0 13.81 4H2.19a1 1 0 0 0-.996 1.09l.637 7a1 1 0 0 0 .995.91H9v1H2.826a2 2 0 0 1-1.991-1.819l-.637-7a1.99 1.99 0 0 1 .342-1.31zm6.339-1.577A1 1 0 0 0 6.172 2H2.5a1 1 0 0 0-1 .981l.006.139C1.72 3.042 1.95 3 2.19 3h5.396l-.707-.707z"/><path d="M11.854 10.146a.5.5 0 0 0-.708.708L12.293 12l-1.147 1.146a.5.5 0 0 0 .708.708L13 12.707l1.146 1.147a.5.5 0 0 0 .708-.708L13.707 12l1.147-1.146a.5.5 0 0 0-.708-.708L13 11.293l-1.146-1.147z"/>');// eslint-disable-next-line
var BIconFonts=/*#__PURE__*/makeIcon('Fonts','<path d="M12.258 3H3.747l-.082 2.46h.478c.26-1.544.76-1.783 2.694-1.845l.424-.013v7.827c0 .663-.144.82-1.3.923v.52h4.082v-.52c-1.162-.103-1.306-.26-1.306-.923V3.602l.43.013c1.935.062 2.434.301 2.694 1.846h.479L12.258 3z"/>');// eslint-disable-next-line
var BIconForward=/*#__PURE__*/makeIcon('Forward','<path d="M9.502 5.513a.144.144 0 0 0-.202.134V6.65a.5.5 0 0 1-.5.5H2.5v2.9h6.3a.5.5 0 0 1 .5.5v1.003c0 .108.11.176.202.134l3.984-2.933a.51.51 0 0 1 .042-.028.147.147 0 0 0 0-.252.51.51 0 0 1-.042-.028L9.502 5.513zM8.3 5.647a1.144 1.144 0 0 1 1.767-.96l3.994 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a1.144 1.144 0 0 1-1.767-.96v-.503H2a.5.5 0 0 1-.5-.5v-3.9a.5.5 0 0 1 .5-.5h6.3v-.503z"/>');// eslint-disable-next-line
var BIconForwardFill=/*#__PURE__*/makeIcon('ForwardFill','<path d="M9.77 12.11l4.012-2.953a.647.647 0 0 0 0-1.114L9.771 5.09a.644.644 0 0 0-.971.557V6.65H2v3.9h6.8v1.003c0 .505.545.808.97.557z"/>');// eslint-disable-next-line
var BIconFront=/*#__PURE__*/makeIcon('Front','<path fill-rule="evenodd" d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm5 10v2a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1h-2v5a2 2 0 0 1-2 2H5z"/>');// eslint-disable-next-line
var BIconFullscreen=/*#__PURE__*/makeIcon('Fullscreen','<path d="M1.5 1a.5.5 0 0 0-.5.5v4a.5.5 0 0 1-1 0v-4A1.5 1.5 0 0 1 1.5 0h4a.5.5 0 0 1 0 1h-4zM10 .5a.5.5 0 0 1 .5-.5h4A1.5 1.5 0 0 1 16 1.5v4a.5.5 0 0 1-1 0v-4a.5.5 0 0 0-.5-.5h-4a.5.5 0 0 1-.5-.5zM.5 10a.5.5 0 0 1 .5.5v4a.5.5 0 0 0 .5.5h4a.5.5 0 0 1 0 1h-4A1.5 1.5 0 0 1 0 14.5v-4a.5.5 0 0 1 .5-.5zm15 0a.5.5 0 0 1 .5.5v4a1.5 1.5 0 0 1-1.5 1.5h-4a.5.5 0 0 1 0-1h4a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconFullscreenExit=/*#__PURE__*/makeIcon('FullscreenExit','<path d="M5.5 0a.5.5 0 0 1 .5.5v4A1.5 1.5 0 0 1 4.5 6h-4a.5.5 0 0 1 0-1h4a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 1 .5-.5zm5 0a.5.5 0 0 1 .5.5v4a.5.5 0 0 0 .5.5h4a.5.5 0 0 1 0 1h-4A1.5 1.5 0 0 1 10 4.5v-4a.5.5 0 0 1 .5-.5zM0 10.5a.5.5 0 0 1 .5-.5h4A1.5 1.5 0 0 1 6 11.5v4a.5.5 0 0 1-1 0v-4a.5.5 0 0 0-.5-.5h-4a.5.5 0 0 1-.5-.5zm10 1a1.5 1.5 0 0 1 1.5-1.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 0-.5.5v4a.5.5 0 0 1-1 0v-4z"/>');// eslint-disable-next-line
var BIconFunnel=/*#__PURE__*/makeIcon('Funnel','<path d="M1.5 1.5A.5.5 0 0 1 2 1h12a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.128.334L10 8.692V13.5a.5.5 0 0 1-.342.474l-3 1A.5.5 0 0 1 6 14.5V8.692L1.628 3.834A.5.5 0 0 1 1.5 3.5v-2zm1 .5v1.308l4.372 4.858A.5.5 0 0 1 7 8.5v5.306l2-.666V8.5a.5.5 0 0 1 .128-.334L13.5 3.308V2h-11z"/>');// eslint-disable-next-line
var BIconFunnelFill=/*#__PURE__*/makeIcon('FunnelFill','<path d="M1.5 1.5A.5.5 0 0 1 2 1h12a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.128.334L10 8.692V13.5a.5.5 0 0 1-.342.474l-3 1A.5.5 0 0 1 6 14.5V8.692L1.628 3.834A.5.5 0 0 1 1.5 3.5v-2z"/>');// eslint-disable-next-line
var BIconGear=/*#__PURE__*/makeIcon('Gear','<path d="M8 4.754a3.246 3.246 0 1 0 0 6.492 3.246 3.246 0 0 0 0-6.492zM5.754 8a2.246 2.246 0 1 1 4.492 0 2.246 2.246 0 0 1-4.492 0z"/><path d="M9.796 1.343c-.527-1.79-3.065-1.79-3.592 0l-.094.319a.873.873 0 0 1-1.255.52l-.292-.16c-1.64-.892-3.433.902-2.54 2.541l.159.292a.873.873 0 0 1-.52 1.255l-.319.094c-1.79.527-1.79 3.065 0 3.592l.319.094a.873.873 0 0 1 .52 1.255l-.16.292c-.892 1.64.901 3.434 2.541 2.54l.292-.159a.873.873 0 0 1 1.255.52l.094.319c.527 1.79 3.065 1.79 3.592 0l.094-.319a.873.873 0 0 1 1.255-.52l.292.16c1.64.893 3.434-.902 2.54-2.541l-.159-.292a.873.873 0 0 1 .52-1.255l.319-.094c1.79-.527 1.79-3.065 0-3.592l-.319-.094a.873.873 0 0 1-.52-1.255l.16-.292c.893-1.64-.902-3.433-2.541-2.54l-.292.159a.873.873 0 0 1-1.255-.52l-.094-.319zm-2.633.283c.246-.835 1.428-.835 1.674 0l.094.319a1.873 1.873 0 0 0 2.693 1.115l.291-.16c.764-.415 1.6.42 1.184 1.185l-.159.292a1.873 1.873 0 0 0 1.116 2.692l.318.094c.835.246.835 1.428 0 1.674l-.319.094a1.873 1.873 0 0 0-1.115 2.693l.16.291c.415.764-.42 1.6-1.185 1.184l-.291-.159a1.873 1.873 0 0 0-2.693 1.116l-.094.318c-.246.835-1.428.835-1.674 0l-.094-.319a1.873 1.873 0 0 0-2.692-1.115l-.292.16c-.764.415-1.6-.42-1.184-1.185l.159-.291A1.873 1.873 0 0 0 1.945 8.93l-.319-.094c-.835-.246-.835-1.428 0-1.674l.319-.094A1.873 1.873 0 0 0 3.06 4.377l-.16-.292c-.415-.764.42-1.6 1.185-1.184l.292.159a1.873 1.873 0 0 0 2.692-1.115l.094-.319z"/>');// eslint-disable-next-line
var BIconGearFill=/*#__PURE__*/makeIcon('GearFill','<path d="M9.405 1.05c-.413-1.4-2.397-1.4-2.81 0l-.1.34a1.464 1.464 0 0 1-2.105.872l-.31-.17c-1.283-.698-2.686.705-1.987 1.987l.169.311c.446.82.023 1.841-.872 2.105l-.34.1c-1.4.413-1.4 2.397 0 2.81l.34.1a1.464 1.464 0 0 1 .872 2.105l-.17.31c-.698 1.283.705 2.686 1.987 1.987l.311-.169a1.464 1.464 0 0 1 2.105.872l.1.34c.413 1.4 2.397 1.4 2.81 0l.1-.34a1.464 1.464 0 0 1 2.105-.872l.31.17c1.283.698 2.686-.705 1.987-1.987l-.169-.311a1.464 1.464 0 0 1 .872-2.105l.34-.1c1.4-.413 1.4-2.397 0-2.81l-.34-.1a1.464 1.464 0 0 1-.872-2.105l.17-.31c.698-1.283-.705-2.686-1.987-1.987l-.311.169a1.464 1.464 0 0 1-2.105-.872l-.1-.34zM8 10.93a2.929 2.929 0 1 1 0-5.86 2.929 2.929 0 0 1 0 5.858z"/>');// eslint-disable-next-line
var BIconGearWide=/*#__PURE__*/makeIcon('GearWide','<path d="M8.932.727c-.243-.97-1.62-.97-1.864 0l-.071.286a.96.96 0 0 1-1.622.434l-.205-.211c-.695-.719-1.888-.03-1.613.931l.08.284a.96.96 0 0 1-1.186 1.187l-.284-.081c-.96-.275-1.65.918-.931 1.613l.211.205a.96.96 0 0 1-.434 1.622l-.286.071c-.97.243-.97 1.62 0 1.864l.286.071a.96.96 0 0 1 .434 1.622l-.211.205c-.719.695-.03 1.888.931 1.613l.284-.08a.96.96 0 0 1 1.187 1.187l-.081.283c-.275.96.918 1.65 1.613.931l.205-.211a.96.96 0 0 1 1.622.434l.071.286c.243.97 1.62.97 1.864 0l.071-.286a.96.96 0 0 1 1.622-.434l.205.211c.695.719 1.888.03 1.613-.931l-.08-.284a.96.96 0 0 1 1.187-1.187l.283.081c.96.275 1.65-.918.931-1.613l-.211-.205a.96.96 0 0 1 .434-1.622l.286-.071c.97-.243.97-1.62 0-1.864l-.286-.071a.96.96 0 0 1-.434-1.622l.211-.205c.719-.695.03-1.888-.931-1.613l-.284.08a.96.96 0 0 1-1.187-1.186l.081-.284c.275-.96-.918-1.65-1.613-.931l-.205.211a.96.96 0 0 1-1.622-.434L8.932.727zM8 12.997a4.998 4.998 0 1 1 0-9.995 4.998 4.998 0 0 1 0 9.996z"/>');// eslint-disable-next-line
var BIconGearWideConnected=/*#__PURE__*/makeIcon('GearWideConnected','<path d="M7.068.727c.243-.97 1.62-.97 1.864 0l.071.286a.96.96 0 0 0 1.622.434l.205-.211c.695-.719 1.888-.03 1.613.931l-.08.284a.96.96 0 0 0 1.187 1.187l.283-.081c.96-.275 1.65.918.931 1.613l-.211.205a.96.96 0 0 0 .434 1.622l.286.071c.97.243.97 1.62 0 1.864l-.286.071a.96.96 0 0 0-.434 1.622l.211.205c.719.695.03 1.888-.931 1.613l-.284-.08a.96.96 0 0 0-1.187 1.187l.081.283c.275.96-.918 1.65-1.613.931l-.205-.211a.96.96 0 0 0-1.622.434l-.071.286c-.243.97-1.62.97-1.864 0l-.071-.286a.96.96 0 0 0-1.622-.434l-.205.211c-.695.719-1.888.03-1.613-.931l.08-.284a.96.96 0 0 0-1.186-1.187l-.284.081c-.96.275-1.65-.918-.931-1.613l.211-.205a.96.96 0 0 0-.434-1.622l-.286-.071c-.97-.243-.97-1.62 0-1.864l.286-.071a.96.96 0 0 0 .434-1.622l-.211-.205c-.719-.695-.03-1.888.931-1.613l.284.08a.96.96 0 0 0 1.187-1.186l-.081-.284c-.275-.96.918-1.65 1.613-.931l.205.211a.96.96 0 0 0 1.622-.434l.071-.286zM12.973 8.5H8.25l-2.834 3.779A4.998 4.998 0 0 0 12.973 8.5zm0-1a4.998 4.998 0 0 0-7.557-3.779l2.834 3.78h4.723zM5.048 3.967c-.03.021-.058.043-.087.065l.087-.065zm-.431.355A4.984 4.984 0 0 0 3.002 8c0 1.455.622 2.765 1.615 3.678L7.375 8 4.617 4.322zm.344 7.646l.087.065-.087-.065z"/>');// eslint-disable-next-line
var BIconGem=/*#__PURE__*/makeIcon('Gem','<path d="M3.1.7a.5.5 0 0 1 .4-.2h9a.5.5 0 0 1 .4.2l2.976 3.974c.149.185.156.45.01.644L8.4 15.3a.5.5 0 0 1-.8 0L.1 5.3a.5.5 0 0 1 0-.6l3-4zm11.386 3.785l-1.806-2.41-.776 2.413 2.582-.003zm-3.633.004l.961-2.989H4.186l.963 2.995 5.704-.006zM5.47 5.495L8 13.366l2.532-7.876-5.062.005zm-1.371-.999l-.78-2.422-1.818 2.425 2.598-.003zM1.499 5.5l5.113 6.817-2.192-6.82L1.5 5.5zm7.889 6.817l5.123-6.83-2.928.002-2.195 6.828z"/>');// eslint-disable-next-line
var BIconGeo=/*#__PURE__*/makeIcon('Geo','<path fill-rule="evenodd" d="M8 1a3 3 0 1 0 0 6 3 3 0 0 0 0-6zM4 4a4 4 0 1 1 4.5 3.969V13.5a.5.5 0 0 1-1 0V7.97A4 4 0 0 1 4 3.999zm2.493 8.574a.5.5 0 0 1-.411.575c-.712.118-1.28.295-1.655.493a1.319 1.319 0 0 0-.37.265.301.301 0 0 0-.057.09V14l.002.008a.147.147 0 0 0 .016.033.617.617 0 0 0 .145.15c.165.13.435.27.813.395.751.25 1.82.414 3.024.414s2.273-.163 3.024-.414c.378-.126.648-.265.813-.395a.619.619 0 0 0 .146-.15.148.148 0 0 0 .015-.033L12 14v-.004a.301.301 0 0 0-.057-.09 1.318 1.318 0 0 0-.37-.264c-.376-.198-.943-.375-1.655-.493a.5.5 0 1 1 .164-.986c.77.127 1.452.328 1.957.594C12.5 13 13 13.4 13 14c0 .426-.26.752-.544.977-.29.228-.68.413-1.116.558-.878.293-2.059.465-3.34.465-1.281 0-2.462-.172-3.34-.465-.436-.145-.826-.33-1.116-.558C3.26 14.752 3 14.426 3 14c0-.599.5-1 .961-1.243.505-.266 1.187-.467 1.957-.594a.5.5 0 0 1 .575.411z"/>');// eslint-disable-next-line
var BIconGeoAlt=/*#__PURE__*/makeIcon('GeoAlt','<path d="M12.166 8.94c-.524 1.062-1.234 2.12-1.96 3.07A31.493 31.493 0 0 1 8 14.58a31.481 31.481 0 0 1-2.206-2.57c-.726-.95-1.436-2.008-1.96-3.07C3.304 7.867 3 6.862 3 6a5 5 0 0 1 10 0c0 .862-.305 1.867-.834 2.94zM8 16s6-5.686 6-10A6 6 0 0 0 2 6c0 4.314 6 10 6 10z"/><path d="M8 8a2 2 0 1 1 0-4 2 2 0 0 1 0 4zm0 1a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>');// eslint-disable-next-line
var BIconGeoAltFill=/*#__PURE__*/makeIcon('GeoAltFill','<path d="M8 16s6-5.686 6-10A6 6 0 0 0 2 6c0 4.314 6 10 6 10zm0-7a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>');// eslint-disable-next-line
var BIconGeoFill=/*#__PURE__*/makeIcon('GeoFill','<path fill-rule="evenodd" d="M4 4a4 4 0 1 1 4.5 3.969V13.5a.5.5 0 0 1-1 0V7.97A4 4 0 0 1 4 3.999zm2.493 8.574a.5.5 0 0 1-.411.575c-.712.118-1.28.295-1.655.493a1.319 1.319 0 0 0-.37.265.301.301 0 0 0-.057.09V14l.002.008a.147.147 0 0 0 .016.033.617.617 0 0 0 .145.15c.165.13.435.27.813.395.751.25 1.82.414 3.024.414s2.273-.163 3.024-.414c.378-.126.648-.265.813-.395a.619.619 0 0 0 .146-.15.148.148 0 0 0 .015-.033L12 14v-.004a.301.301 0 0 0-.057-.09 1.318 1.318 0 0 0-.37-.264c-.376-.198-.943-.375-1.655-.493a.5.5 0 1 1 .164-.986c.77.127 1.452.328 1.957.594C12.5 13 13 13.4 13 14c0 .426-.26.752-.544.977-.29.228-.68.413-1.116.558-.878.293-2.059.465-3.34.465-1.281 0-2.462-.172-3.34-.465-.436-.145-.826-.33-1.116-.558C3.26 14.752 3 14.426 3 14c0-.599.5-1 .961-1.243.505-.266 1.187-.467 1.957-.594a.5.5 0 0 1 .575.411z"/>');// eslint-disable-next-line
var BIconGift=/*#__PURE__*/makeIcon('Gift','<path d="M3 2.5a2.5 2.5 0 0 1 5 0 2.5 2.5 0 0 1 5 0v.006c0 .07 0 .27-.038.494H15a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v7.5a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 14.5V7a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h2.038A2.968 2.968 0 0 1 3 2.506V2.5zm1.068.5H7v-.5a1.5 1.5 0 1 0-3 0c0 .085.002.274.045.43a.522.522 0 0 0 .023.07zM9 3h2.932a.56.56 0 0 0 .023-.07c.043-.156.045-.345.045-.43a1.5 1.5 0 0 0-3 0V3zM1 4v2h6V4H1zm8 0v2h6V4H9zm5 3H9v8h4.5a.5.5 0 0 0 .5-.5V7zm-7 8V7H2v7.5a.5.5 0 0 0 .5.5H7z"/>');// eslint-disable-next-line
var BIconGiftFill=/*#__PURE__*/makeIcon('GiftFill','<path d="M3 2.5a2.5 2.5 0 0 1 5 0 2.5 2.5 0 0 1 5 0v.006c0 .07 0 .27-.038.494H15a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h2.038A2.968 2.968 0 0 1 3 2.506V2.5zm1.068.5H7v-.5a1.5 1.5 0 1 0-3 0c0 .085.002.274.045.43a.522.522 0 0 0 .023.07zM9 3h2.932a.56.56 0 0 0 .023-.07c.043-.156.045-.345.045-.43a1.5 1.5 0 0 0-3 0V3zm6 4v7.5a1.5 1.5 0 0 1-1.5 1.5H9V7h6zM2.5 16A1.5 1.5 0 0 1 1 14.5V7h6v9H2.5z"/>');// eslint-disable-next-line
var BIconGithub=/*#__PURE__*/makeIcon('Github','<path d="M8 0C3.58 0 0 3.58 0 8c0 3.54 2.29 6.53 5.47 7.59.4.07.55-.17.55-.38 0-.19-.01-.82-.01-1.49-2.01.37-2.53-.49-2.69-.94-.09-.23-.48-.94-.82-1.13-.28-.15-.68-.52-.01-.53.63-.01 1.08.58 1.23.82.72 1.21 1.87.87 2.33.66.07-.52.28-.87.51-1.07-1.78-.2-3.64-.89-3.64-3.95 0-.87.31-1.59.82-2.15-.08-.2-.36-1.02.08-2.12 0 0 .67-.21 2.2.82.64-.18 1.32-.27 2-.27.68 0 1.36.09 2 .27 1.53-1.04 2.2-.82 2.2-.82.44 1.1.16 1.92.08 2.12.51.56.82 1.27.82 2.15 0 3.07-1.87 3.75-3.65 3.95.29.25.54.73.54 1.48 0 1.07-.01 1.93-.01 2.2 0 .21.15.46.55.38A8.012 8.012 0 0 0 16 8c0-4.42-3.58-8-8-8z"/>');// eslint-disable-next-line
var BIconGlobe=/*#__PURE__*/makeIcon('Globe','<path d="M0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8zm7.5-6.923c-.67.204-1.335.82-1.887 1.855A7.97 7.97 0 0 0 5.145 4H7.5V1.077zM4.09 4a9.267 9.267 0 0 1 .64-1.539 6.7 6.7 0 0 1 .597-.933A7.025 7.025 0 0 0 2.255 4H4.09zm-.582 3.5c.03-.877.138-1.718.312-2.5H1.674a6.958 6.958 0 0 0-.656 2.5h2.49zM4.847 5a12.5 12.5 0 0 0-.338 2.5H7.5V5H4.847zM8.5 5v2.5h2.99a12.495 12.495 0 0 0-.337-2.5H8.5zM4.51 8.5a12.5 12.5 0 0 0 .337 2.5H7.5V8.5H4.51zm3.99 0V11h2.653c.187-.765.306-1.608.338-2.5H8.5zM5.145 12c.138.386.295.744.468 1.068.552 1.035 1.218 1.65 1.887 1.855V12H5.145zm.182 2.472a6.696 6.696 0 0 1-.597-.933A9.268 9.268 0 0 1 4.09 12H2.255a7.024 7.024 0 0 0 3.072 2.472zM3.82 11a13.652 13.652 0 0 1-.312-2.5h-2.49c.062.89.291 1.733.656 2.5H3.82zm6.853 3.472A7.024 7.024 0 0 0 13.745 12H11.91a9.27 9.27 0 0 1-.64 1.539 6.688 6.688 0 0 1-.597.933zM8.5 12v2.923c.67-.204 1.335-.82 1.887-1.855.173-.324.33-.682.468-1.068H8.5zm3.68-1h2.146c.365-.767.594-1.61.656-2.5h-2.49a13.65 13.65 0 0 1-.312 2.5zm2.802-3.5a6.959 6.959 0 0 0-.656-2.5H12.18c.174.782.282 1.623.312 2.5h2.49zM11.27 2.461c.247.464.462.98.64 1.539h1.835a7.024 7.024 0 0 0-3.072-2.472c.218.284.418.598.597.933zM10.855 4a7.966 7.966 0 0 0-.468-1.068C9.835 1.897 9.17 1.282 8.5 1.077V4h2.355z"/>');// eslint-disable-next-line
var BIconGlobe2=/*#__PURE__*/makeIcon('Globe2','<path d="M0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8zm7.5-6.923c-.67.204-1.335.82-1.887 1.855-.143.268-.276.56-.395.872.705.157 1.472.257 2.282.287V1.077zM4.249 3.539c.142-.384.304-.744.481-1.078a6.7 6.7 0 0 1 .597-.933A7.01 7.01 0 0 0 3.051 3.05c.362.184.763.349 1.198.49zM3.509 7.5c.036-1.07.188-2.087.436-3.008a9.124 9.124 0 0 1-1.565-.667A6.964 6.964 0 0 0 1.018 7.5h2.49zm1.4-2.741a12.344 12.344 0 0 0-.4 2.741H7.5V5.091c-.91-.03-1.783-.145-2.591-.332zM8.5 5.09V7.5h2.99a12.342 12.342 0 0 0-.399-2.741c-.808.187-1.681.301-2.591.332zM4.51 8.5c.035.987.176 1.914.399 2.741A13.612 13.612 0 0 1 7.5 10.91V8.5H4.51zm3.99 0v2.409c.91.03 1.783.145 2.591.332.223-.827.364-1.754.4-2.741H8.5zm-3.282 3.696c.12.312.252.604.395.872.552 1.035 1.218 1.65 1.887 1.855V11.91c-.81.03-1.577.13-2.282.287zm.11 2.276a6.696 6.696 0 0 1-.598-.933 8.853 8.853 0 0 1-.481-1.079 8.38 8.38 0 0 0-1.198.49 7.01 7.01 0 0 0 2.276 1.522zm-1.383-2.964A13.36 13.36 0 0 1 3.508 8.5h-2.49a6.963 6.963 0 0 0 1.362 3.675c.47-.258.995-.482 1.565-.667zm6.728 2.964a7.009 7.009 0 0 0 2.275-1.521 8.376 8.376 0 0 0-1.197-.49 8.853 8.853 0 0 1-.481 1.078 6.688 6.688 0 0 1-.597.933zM8.5 11.909v3.014c.67-.204 1.335-.82 1.887-1.855.143-.268.276-.56.395-.872A12.63 12.63 0 0 0 8.5 11.91zm3.555-.401c.57.185 1.095.409 1.565.667A6.963 6.963 0 0 0 14.982 8.5h-2.49a13.36 13.36 0 0 1-.437 3.008zM14.982 7.5a6.963 6.963 0 0 0-1.362-3.675c-.47.258-.995.482-1.565.667.248.92.4 1.938.437 3.008h2.49zM11.27 2.461c.177.334.339.694.482 1.078a8.368 8.368 0 0 0 1.196-.49 7.01 7.01 0 0 0-2.275-1.52c.218.283.418.597.597.932zm-.488 1.343a7.765 7.765 0 0 0-.395-.872C9.835 1.897 9.17 1.282 8.5 1.077V4.09c.81-.03 1.577-.13 2.282-.287z"/>');// eslint-disable-next-line
var BIconGoogle=/*#__PURE__*/makeIcon('Google','<path d="M15.545 6.558a9.42 9.42 0 0 1 .139 1.626c0 2.434-.87 4.492-2.384 5.885h.002C11.978 15.292 10.158 16 8 16A8 8 0 1 1 8 0a7.689 7.689 0 0 1 5.352 2.082l-2.284 2.284A4.347 4.347 0 0 0 8 3.166c-2.087 0-3.86 1.408-4.492 3.304a4.792 4.792 0 0 0 0 3.063h.003c.635 1.893 2.405 3.301 4.492 3.301 1.078 0 2.004-.276 2.722-.764h-.003a3.702 3.702 0 0 0 1.599-2.431H8v-3.08h7.545z"/>');// eslint-disable-next-line
var BIconGraphDown=/*#__PURE__*/makeIcon('GraphDown','<path fill-rule="evenodd" d="M0 0h1v15h15v1H0V0zm10 11.5a.5.5 0 0 0 .5.5h4a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-1 0v2.6l-3.613-4.417a.5.5 0 0 0-.74-.037L7.06 8.233 3.404 3.206a.5.5 0 0 0-.808.588l4 5.5a.5.5 0 0 0 .758.06l2.609-2.61L13.445 11H10.5a.5.5 0 0 0-.5.5z"/>');// eslint-disable-next-line
var BIconGraphUp=/*#__PURE__*/makeIcon('GraphUp','<path fill-rule="evenodd" d="M0 0h1v15h15v1H0V0zm10 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V4.9l-3.613 4.417a.5.5 0 0 1-.74.037L7.06 6.767l-3.656 5.027a.5.5 0 0 1-.808-.588l4-5.5a.5.5 0 0 1 .758-.06l2.609 2.61L13.445 4H10.5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconGrid=/*#__PURE__*/makeIcon('Grid','<path d="M1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5v-3zM2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3zm6.5.5A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5v-3zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3zM1 10.5A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5v-3zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3zm6.5.5A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5v-3zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3z"/>');// eslint-disable-next-line
var BIconGrid1x2=/*#__PURE__*/makeIcon('Grid1x2','<path d="M6 1H1v14h5V1zm9 0h-5v5h5V1zm0 9v5h-5v-5h5zM0 1a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v14a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V1zm9 0a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1V1zm1 8a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1h-5z"/>');// eslint-disable-next-line
var BIconGrid1x2Fill=/*#__PURE__*/makeIcon('Grid1x2Fill','<path d="M0 1a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v14a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V1zm9 0a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1V1zm0 9a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-5z"/>');// eslint-disable-next-line
var BIconGrid3x2=/*#__PURE__*/makeIcon('Grid3x2','<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v8a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 11.5v-8zM1.5 3a.5.5 0 0 0-.5.5V7h4V3H1.5zM5 8H1v3.5a.5.5 0 0 0 .5.5H5V8zm1 0v4h4V8H6zm4-1V3H6v4h4zm1 1v4h3.5a.5.5 0 0 0 .5-.5V8h-4zm0-1h4V3.5a.5.5 0 0 0-.5-.5H11v4z"/>');// eslint-disable-next-line
var BIconGrid3x2Gap=/*#__PURE__*/makeIcon('Grid3x2Gap','<path d="M4 4v2H2V4h2zm1 7V9a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V4a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm5 5V9a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V4a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zM9 4v2H7V4h2zm5 0h-2v2h2V4zM4 9v2H2V9h2zm5 0v2H7V9h2zm5 0v2h-2V9h2zm-3-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V4zm1 4a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1h-2z"/>');// eslint-disable-next-line
var BIconGrid3x2GapFill=/*#__PURE__*/makeIcon('Grid3x2GapFill','<path d="M1 4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V4zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V4zM1 9a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V9zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V9zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V9z"/>');// eslint-disable-next-line
var BIconGrid3x3=/*#__PURE__*/makeIcon('Grid3x3','<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h13A1.5 1.5 0 0 1 16 1.5v13a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 14.5v-13zM1.5 1a.5.5 0 0 0-.5.5V5h4V1H1.5zM5 6H1v4h4V6zm1 4h4V6H6v4zm-1 1H1v3.5a.5.5 0 0 0 .5.5H5v-4zm1 0v4h4v-4H6zm5 0v4h3.5a.5.5 0 0 0 .5-.5V11h-4zm0-1h4V6h-4v4zm0-5h4V1.5a.5.5 0 0 0-.5-.5H11v4zm-1 0V1H6v4h4z"/>');// eslint-disable-next-line
var BIconGrid3x3Gap=/*#__PURE__*/makeIcon('Grid3x3Gap','<path d="M4 2v2H2V2h2zm1 12v-2a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V7a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V2a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm5 10v-2a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V7a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V2a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zM9 2v2H7V2h2zm5 0v2h-2V2h2zM4 7v2H2V7h2zm5 0v2H7V7h2zm5 0h-2v2h2V7zM4 12v2H2v-2h2zm5 0v2H7v-2h2zm5 0v2h-2v-2h2zM12 1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2zm-1 6a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V7zm1 4a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1h-2z"/>');// eslint-disable-next-line
var BIconGrid3x3GapFill=/*#__PURE__*/makeIcon('Grid3x3GapFill','<path d="M1 2a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V2zM1 7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V7zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V7zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V7zM1 12a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1v-2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1v-2z"/>');// eslint-disable-next-line
var BIconGridFill=/*#__PURE__*/makeIcon('GridFill','<path d="M1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5v-3zm8 0A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5v-3zm-8 8A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5v-3zm8 0A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5v-3z"/>');// eslint-disable-next-line
var BIconGripHorizontal=/*#__PURE__*/makeIcon('GripHorizontal','<path d="M2 8a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconGripVertical=/*#__PURE__*/makeIcon('GripVertical','<path d="M7 2a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM7 5a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM7 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-3 3a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-3 3a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconHammer=/*#__PURE__*/makeIcon('Hammer','<path d="M9.972 2.508a.5.5 0 0 0-.16-.556l-.178-.129a5.009 5.009 0 0 0-2.076-.783C6.215.862 4.504 1.229 2.84 3.133H1.786a.5.5 0 0 0-.354.147L.146 4.567a.5.5 0 0 0 0 .706l2.571 2.579a.5.5 0 0 0 .708 0l1.286-1.29a.5.5 0 0 0 .146-.353V5.57l8.387 8.873A.5.5 0 0 0 14 14.5l1.5-1.5a.5.5 0 0 0 .017-.689l-9.129-8.63c.747-.456 1.772-.839 3.112-.839a.5.5 0 0 0 .472-.334z"/>');// eslint-disable-next-line
var BIconHandIndex=/*#__PURE__*/makeIcon('HandIndex','<path d="M6.75 1a.75.75 0 0 1 .75.75V8a.5.5 0 0 0 1 0V5.467l.086-.004c.317-.012.637-.008.816.027.134.027.294.096.448.182.077.042.15.147.15.314V8a.5.5 0 1 0 1 0V6.435a4.9 4.9 0 0 1 .106-.01c.316-.024.584-.01.708.04.118.046.3.207.486.43.081.096.15.19.2.259V8.5a.5.5 0 0 0 1 0v-1h.342a1 1 0 0 1 .995 1.1l-.271 2.715a2.5 2.5 0 0 1-.317.991l-1.395 2.442a.5.5 0 0 1-.434.252H6.035a.5.5 0 0 1-.416-.223l-1.433-2.15a1.5 1.5 0 0 1-.243-.666l-.345-3.105a.5.5 0 0 1 .399-.546L5 8.11V9a.5.5 0 0 0 1 0V1.75A.75.75 0 0 1 6.75 1zM8.5 4.466V1.75a1.75 1.75 0 1 0-3.5 0v5.34l-1.2.24a1.5 1.5 0 0 0-1.196 1.636l.345 3.106a2.5 2.5 0 0 0 .405 1.11l1.433 2.15A1.5 1.5 0 0 0 6.035 16h6.385a1.5 1.5 0 0 0 1.302-.756l1.395-2.441a3.5 3.5 0 0 0 .444-1.389l.271-2.715a2 2 0 0 0-1.99-2.199h-.581a5.114 5.114 0 0 0-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 0 0-.56-.642 2.632 2.632 0 0 0-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"/>');// eslint-disable-next-line
var BIconHandIndexThumb=/*#__PURE__*/makeIcon('HandIndexThumb','<path d="M6.75 1a.75.75 0 0 1 .75.75V8a.5.5 0 0 0 1 0V5.467l.086-.004c.317-.012.637-.008.816.027.134.027.294.096.448.182.077.042.15.147.15.314V8a.5.5 0 0 0 1 0V6.435l.106-.01c.316-.024.584-.01.708.04.118.046.3.207.486.43.081.096.15.19.2.259V8.5a.5.5 0 1 0 1 0v-1h.342a1 1 0 0 1 .995 1.1l-.271 2.715a2.5 2.5 0 0 1-.317.991l-1.395 2.442a.5.5 0 0 1-.434.252H6.118a.5.5 0 0 1-.447-.276l-1.232-2.465-2.512-4.185a.517.517 0 0 1 .809-.631l2.41 2.41A.5.5 0 0 0 6 9.5V1.75A.75.75 0 0 1 6.75 1zM8.5 4.466V1.75a1.75 1.75 0 1 0-3.5 0v6.543L3.443 6.736A1.517 1.517 0 0 0 1.07 8.588l2.491 4.153 1.215 2.43A1.5 1.5 0 0 0 6.118 16h6.302a1.5 1.5 0 0 0 1.302-.756l1.395-2.441a3.5 3.5 0 0 0 .444-1.389l.271-2.715a2 2 0 0 0-1.99-2.199h-.581a5.114 5.114 0 0 0-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 0 0-.56-.642 2.632 2.632 0 0 0-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"/>');// eslint-disable-next-line
var BIconHandThumbsDown=/*#__PURE__*/makeIcon('HandThumbsDown','<path d="M8.864 15.674c-.956.24-1.843-.484-1.908-1.42-.072-1.05-.23-2.015-.428-2.59-.125-.36-.479-1.012-1.04-1.638-.557-.624-1.282-1.179-2.131-1.41C2.685 8.432 2 7.85 2 7V3c0-.845.682-1.464 1.448-1.546 1.07-.113 1.564-.415 2.068-.723l.048-.029c.272-.166.578-.349.97-.484C6.931.08 7.395 0 8 0h3.5c.937 0 1.599.478 1.934 1.064.164.287.254.607.254.913 0 .152-.023.312-.077.464.201.262.38.577.488.9.11.33.172.762.004 1.15.069.13.12.268.159.403.077.27.113.567.113.856 0 .289-.036.586-.113.856-.035.12-.08.244-.138.363.394.571.418 1.2.234 1.733-.206.592-.682 1.1-1.2 1.272-.847.283-1.803.276-2.516.211a9.877 9.877 0 0 1-.443-.05 9.364 9.364 0 0 1-.062 4.51c-.138.508-.55.848-1.012.964l-.261.065zM11.5 1H8c-.51 0-.863.068-1.14.163-.281.097-.506.229-.776.393l-.04.025c-.555.338-1.198.73-2.49.868-.333.035-.554.29-.554.55V7c0 .255.226.543.62.65 1.095.3 1.977.997 2.614 1.709.635.71 1.064 1.475 1.238 1.977.243.7.407 1.768.482 2.85.025.362.36.595.667.518l.262-.065c.16-.04.258-.144.288-.255a8.34 8.34 0 0 0-.145-4.726.5.5 0 0 1 .595-.643h.003l.014.004.058.013a8.912 8.912 0 0 0 1.036.157c.663.06 1.457.054 2.11-.163.175-.059.45-.301.57-.651.107-.308.087-.67-.266-1.021L12.793 7l.353-.354c.043-.042.105-.14.154-.315.048-.167.075-.37.075-.581 0-.211-.027-.414-.075-.581-.05-.174-.111-.273-.154-.315l-.353-.354.353-.354c.047-.047.109-.176.005-.488a2.224 2.224 0 0 0-.505-.804l-.353-.354.353-.354c.006-.005.041-.05.041-.17a.866.866 0 0 0-.121-.415C12.4 1.272 12.063 1 11.5 1z"/>');// eslint-disable-next-line
var BIconHandThumbsUp=/*#__PURE__*/makeIcon('HandThumbsUp','<path d="M8.864.046C7.908-.193 7.02.53 6.956 1.466c-.072 1.051-.23 2.016-.428 2.59-.125.36-.479 1.013-1.04 1.639-.557.623-1.282 1.178-2.131 1.41C2.685 7.288 2 7.87 2 8.72v4.001c0 .845.682 1.464 1.448 1.545 1.07.114 1.564.415 2.068.723l.048.03c.272.165.578.348.97.484.397.136.861.217 1.466.217h3.5c.937 0 1.599-.477 1.934-1.064a1.86 1.86 0 0 0 .254-.912c0-.152-.023-.312-.077-.464.201-.263.38-.578.488-.901.11-.33.172-.762.004-1.149.069-.13.12-.269.159-.403.077-.27.113-.568.113-.857 0-.288-.036-.585-.113-.856a2.144 2.144 0 0 0-.138-.362 1.9 1.9 0 0 0 .234-1.734c-.206-.592-.682-1.1-1.2-1.272-.847-.282-1.803-.276-2.516-.211a9.84 9.84 0 0 0-.443.05 9.365 9.365 0 0 0-.062-4.509A1.38 1.38 0 0 0 9.125.111L8.864.046zM11.5 14.721H8c-.51 0-.863-.069-1.14-.164-.281-.097-.506-.228-.776-.393l-.04-.024c-.555-.339-1.198-.731-2.49-.868-.333-.036-.554-.29-.554-.55V8.72c0-.254.226-.543.62-.65 1.095-.3 1.977-.996 2.614-1.708.635-.71 1.064-1.475 1.238-1.978.243-.7.407-1.768.482-2.85.025-.362.36-.594.667-.518l.262.066c.16.04.258.143.288.255a8.34 8.34 0 0 1-.145 4.725.5.5 0 0 0 .595.644l.003-.001.014-.003.058-.014a8.908 8.908 0 0 1 1.036-.157c.663-.06 1.457-.054 2.11.164.175.058.45.3.57.65.107.308.087.67-.266 1.022l-.353.353.353.354c.043.043.105.141.154.315.048.167.075.37.075.581 0 .212-.027.414-.075.582-.05.174-.111.272-.154.315l-.353.353.353.354c.047.047.109.177.005.488a2.224 2.224 0 0 1-.505.805l-.353.353.353.354c.006.005.041.05.041.17a.866.866 0 0 1-.121.416c-.165.288-.503.56-1.066.56z"/>');// eslint-disable-next-line
var BIconHandbag=/*#__PURE__*/makeIcon('Handbag','<path d="M8 1a2 2 0 0 1 2 2v2H6V3a2 2 0 0 1 2-2zm3 4V3a3 3 0 1 0-6 0v2H3.361a1.5 1.5 0 0 0-1.483 1.277L.85 13.13A2.5 2.5 0 0 0 3.322 16h9.356a2.5 2.5 0 0 0 2.472-2.87l-1.028-6.853A1.5 1.5 0 0 0 12.64 5H11zm-1 1v1.5a.5.5 0 0 0 1 0V6h1.639a.5.5 0 0 1 .494.426l1.028 6.851A1.5 1.5 0 0 1 12.678 15H3.322a1.5 1.5 0 0 1-1.483-1.723l1.028-6.851A.5.5 0 0 1 3.36 6H5v1.5a.5.5 0 0 0 1 0V6h4z"/>');// eslint-disable-next-line
var BIconHandbagFill=/*#__PURE__*/makeIcon('HandbagFill','<path d="M8 1a2 2 0 0 0-2 2v2H5V3a3 3 0 0 1 6 0v2h-1V3a2 2 0 0 0-2-2zM5 5H3.361a1.5 1.5 0 0 0-1.483 1.277L.85 13.13A2.5 2.5 0 0 0 3.322 16h9.356a2.5 2.5 0 0 0 2.472-2.87l-1.028-6.853A1.5 1.5 0 0 0 12.64 5H11v1.5a.5.5 0 0 1-1 0V5H6v1.5a.5.5 0 0 1-1 0V5z"/>');// eslint-disable-next-line
var BIconHash=/*#__PURE__*/makeIcon('Hash','<path d="M8.39 12.648a1.32 1.32 0 0 0-.015.18c0 .305.21.508.5.508.266 0 .492-.172.555-.477l.554-2.703h1.204c.421 0 .617-.234.617-.547 0-.312-.188-.53-.617-.53h-.985l.516-2.524h1.265c.43 0 .618-.227.618-.547 0-.313-.188-.524-.618-.524h-1.046l.476-2.304a1.06 1.06 0 0 0 .016-.164.51.51 0 0 0-.516-.516.54.54 0 0 0-.539.43l-.523 2.554H7.617l.477-2.304c.008-.04.015-.118.015-.164a.512.512 0 0 0-.523-.516.539.539 0 0 0-.531.43L6.53 5.484H5.414c-.43 0-.617.22-.617.532 0 .312.187.539.617.539h.906l-.515 2.523H4.609c-.421 0-.609.219-.609.531 0 .313.188.547.61.547h.976l-.516 2.492c-.008.04-.015.125-.015.18 0 .305.21.508.5.508.265 0 .492-.172.554-.477l.555-2.703h2.242l-.515 2.492zm-1-6.109h2.266l-.515 2.563H6.859l.532-2.563z"/>');// eslint-disable-next-line
var BIconHdd=/*#__PURE__*/makeIcon('Hdd','<path d="M4.5 11a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM3 10.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/><path d="M16 11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V9.51c0-.418.105-.83.305-1.197l2.472-4.531A1.5 1.5 0 0 1 4.094 3h7.812a1.5 1.5 0 0 1 1.317.782l2.472 4.53c.2.368.305.78.305 1.198V11zM3.655 4.26L1.592 8.043C1.724 8.014 1.86 8 2 8h12c.14 0 .276.014.408.042L12.345 4.26a.5.5 0 0 0-.439-.26H4.094a.5.5 0 0 0-.44.26zM1 10v1a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-1a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1z"/>');// eslint-disable-next-line
var BIconHddFill=/*#__PURE__*/makeIcon('HddFill','<path d="M0 10a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-1zm2.5 1a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm2 0a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM.91 7.204A2.993 2.993 0 0 1 2 7h12c.384 0 .752.072 1.09.204l-1.867-3.422A1.5 1.5 0 0 0 11.906 3H4.094a1.5 1.5 0 0 0-1.317.782L.91 7.204z"/>');// eslint-disable-next-line
var BIconHddNetwork=/*#__PURE__*/makeIcon('HddNetwork','<path d="M4.5 5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM3 4.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1a2 2 0 0 1-2 2H8.5v3a1.5 1.5 0 0 1 1.5 1.5h5.5a.5.5 0 0 1 0 1H10A1.5 1.5 0 0 1 8.5 14h-1A1.5 1.5 0 0 1 6 12.5H.5a.5.5 0 0 1 0-1H6A1.5 1.5 0 0 1 7.5 10V7H2a2 2 0 0 1-2-2V4zm1 0v1a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1zm6 7.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5z"/>');// eslint-disable-next-line
var BIconHddNetworkFill=/*#__PURE__*/makeIcon('HddNetworkFill','<path d="M2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h5.5v3A1.5 1.5 0 0 0 6 11.5H.5a.5.5 0 0 0 0 1H6A1.5 1.5 0 0 0 7.5 14h1a1.5 1.5 0 0 0 1.5-1.5h5.5a.5.5 0 0 0 0-1H10A1.5 1.5 0 0 0 8.5 10V7H14a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1z"/>');// eslint-disable-next-line
var BIconHddRack=/*#__PURE__*/makeIcon('HddRack','<path d="M4.5 5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM3 4.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm2 7a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-2.5.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/><path d="M2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h1v2H2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2h-1V7h1a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm13 2v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zm0 7v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-1a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zm-3-4v2H4V7h8z"/>');// eslint-disable-next-line
var BIconHddRackFill=/*#__PURE__*/makeIcon('HddRackFill','<path d="M2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h1v2H2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2h-1V7h1a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm-2 7a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM12 7v2H4V7h8z"/>');// eslint-disable-next-line
var BIconHddStack=/*#__PURE__*/makeIcon('HddStack','<path d="M14 10a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-1a1 1 0 0 1 1-1h12zM2 9a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2H2z"/><path d="M5 11.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-2 0a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zM14 3a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/><path d="M5 4.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-2 0a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconHddStackFill=/*#__PURE__*/makeIcon('HddStackFill','<path d="M2 9a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1z"/>');// eslint-disable-next-line
var BIconHeadphones=/*#__PURE__*/makeIcon('Headphones','<path d="M8 3a5 5 0 0 0-5 5v1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V8a6 6 0 1 1 12 0v5a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1v-3a1 1 0 0 1 1-1h1V8a5 5 0 0 0-5-5z"/>');// eslint-disable-next-line
var BIconHeadset=/*#__PURE__*/makeIcon('Headset','<path d="M8 1a5 5 0 0 0-5 5v1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V6a6 6 0 1 1 12 0v6a2.5 2.5 0 0 1-2.5 2.5H9.366a1 1 0 0 1-.866.5h-1a1 1 0 1 1 0-2h1a1 1 0 0 1 .866.5H11.5A1.5 1.5 0 0 0 13 12h-1a1 1 0 0 1-1-1V8a1 1 0 0 1 1-1h1V6a5 5 0 0 0-5-5z"/>');// eslint-disable-next-line
var BIconHeart=/*#__PURE__*/makeIcon('Heart','<path d="M8 2.748l-.717-.737C5.6.281 2.514.878 1.4 3.053c-.523 1.023-.641 2.5.314 4.385.92 1.815 2.834 3.989 6.286 6.357 3.452-2.368 5.365-4.542 6.286-6.357.955-1.886.838-3.362.314-4.385C13.486.878 10.4.28 8.717 2.01L8 2.748zM8 15C-7.333 4.868 3.279-3.04 7.824 1.143c.06.055.119.112.176.171a3.12 3.12 0 0 1 .176-.17C12.72-3.042 23.333 4.867 8 15z"/>');// eslint-disable-next-line
var BIconHeartFill=/*#__PURE__*/makeIcon('HeartFill','<path fill-rule="evenodd" d="M8 1.314C12.438-3.248 23.534 4.735 8 15-7.534 4.736 3.562-3.248 8 1.314z"/>');// eslint-disable-next-line
var BIconHeartHalf=/*#__PURE__*/makeIcon('HeartHalf','<path d="M8 2.748v11.047c3.452-2.368 5.365-4.542 6.286-6.357.955-1.886.838-3.362.314-4.385C13.486.878 10.4.28 8.717 2.01L8 2.748zM8 15C-7.333 4.868 3.279-3.04 7.824 1.143c.06.055.119.112.176.171a3.12 3.12 0 0 1 .176-.17C12.72-3.042 23.333 4.867 8 15z"/>');// eslint-disable-next-line
var BIconHeptagon=/*#__PURE__*/makeIcon('Heptagon','<path d="M7.779.052a.5.5 0 0 1 .442 0l6.015 2.97a.5.5 0 0 1 .267.34l1.485 6.676a.5.5 0 0 1-.093.415l-4.162 5.354a.5.5 0 0 1-.395.193H4.662a.5.5 0 0 1-.395-.193L.105 10.453a.5.5 0 0 1-.093-.415l1.485-6.676a.5.5 0 0 1 .267-.34L7.779.053zM2.422 3.813l-1.383 6.212L4.907 15h6.186l3.868-4.975-1.383-6.212L8 1.058 2.422 3.813z"/>');// eslint-disable-next-line
var BIconHeptagonFill=/*#__PURE__*/makeIcon('HeptagonFill','<path fill-rule="evenodd" d="M7.779.052a.5.5 0 0 1 .442 0l6.015 2.97a.5.5 0 0 1 .267.34l1.485 6.676a.5.5 0 0 1-.093.415l-4.162 5.354a.5.5 0 0 1-.395.193H4.662a.5.5 0 0 1-.395-.193L.105 10.453a.5.5 0 0 1-.093-.415l1.485-6.676a.5.5 0 0 1 .267-.34L7.779.053z"/>');// eslint-disable-next-line
var BIconHeptagonHalf=/*#__PURE__*/makeIcon('HeptagonHalf','<path d="M7.779.052a.5.5 0 0 1 .442 0l6.015 2.97a.5.5 0 0 1 .267.34l1.485 6.676a.5.5 0 0 1-.093.415l-4.162 5.354a.5.5 0 0 1-.395.193H4.662a.5.5 0 0 1-.395-.193L.105 10.453a.5.5 0 0 1-.093-.415l1.485-6.676a.5.5 0 0 1 .267-.34L7.779.053zM8 15h3.093l3.868-4.975-1.383-6.212L8 1.058V15z"/>');// eslint-disable-next-line
var BIconHexagon=/*#__PURE__*/makeIcon('Hexagon','<path d="M14 4.577v6.846L8 15l-6-3.577V4.577L8 1l6 3.577zM8.5.134a1 1 0 0 0-1 0l-6 3.577a1 1 0 0 0-.5.866v6.846a1 1 0 0 0 .5.866l6 3.577a1 1 0 0 0 1 0l6-3.577a1 1 0 0 0 .5-.866V4.577a1 1 0 0 0-.5-.866L8.5.134z"/>');// eslint-disable-next-line
var BIconHexagonFill=/*#__PURE__*/makeIcon('HexagonFill','<path fill-rule="evenodd" d="M8.5.134a1 1 0 0 0-1 0l-6 3.577a1 1 0 0 0-.5.866v6.846a1 1 0 0 0 .5.866l6 3.577a1 1 0 0 0 1 0l6-3.577a1 1 0 0 0 .5-.866V4.577a1 1 0 0 0-.5-.866L8.5.134z"/>');// eslint-disable-next-line
var BIconHexagonHalf=/*#__PURE__*/makeIcon('HexagonHalf','<path d="M14 4.577v6.846L8 15V1l6 3.577zM8.5.134a1 1 0 0 0-1 0l-6 3.577a1 1 0 0 0-.5.866v6.846a1 1 0 0 0 .5.866l6 3.577a1 1 0 0 0 1 0l6-3.577a1 1 0 0 0 .5-.866V4.577a1 1 0 0 0-.5-.866L8.5.134z"/>');// eslint-disable-next-line
var BIconHourglass=/*#__PURE__*/makeIcon('Hourglass','<path d="M2 1.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-1v1a4.5 4.5 0 0 1-2.557 4.06c-.29.139-.443.377-.443.59v.7c0 .213.154.451.443.59A4.5 4.5 0 0 1 12.5 13v1h1a.5.5 0 0 1 0 1h-11a.5.5 0 1 1 0-1h1v-1a4.5 4.5 0 0 1 2.557-4.06c.29-.139.443-.377.443-.59v-.7c0-.213-.154-.451-.443-.59A4.5 4.5 0 0 1 3.5 3V2h-1a.5.5 0 0 1-.5-.5zm2.5.5v1a3.5 3.5 0 0 0 1.989 3.158c.533.256 1.011.791 1.011 1.491v.702c0 .7-.478 1.235-1.011 1.491A3.5 3.5 0 0 0 4.5 13v1h7v-1a3.5 3.5 0 0 0-1.989-3.158C8.978 9.586 8.5 9.052 8.5 8.351v-.702c0-.7.478-1.235 1.011-1.491A3.5 3.5 0 0 0 11.5 3V2h-7z"/>');// eslint-disable-next-line
var BIconHourglassBottom=/*#__PURE__*/makeIcon('HourglassBottom','<path d="M2 1.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-1v1a4.5 4.5 0 0 1-2.557 4.06c-.29.139-.443.377-.443.59v.7c0 .213.154.451.443.59A4.5 4.5 0 0 1 12.5 13v1h1a.5.5 0 0 1 0 1h-11a.5.5 0 1 1 0-1h1v-1a4.5 4.5 0 0 1 2.557-4.06c.29-.139.443-.377.443-.59v-.7c0-.213-.154-.451-.443-.59A4.5 4.5 0 0 1 3.5 3V2h-1a.5.5 0 0 1-.5-.5zm2.5.5v1a3.5 3.5 0 0 0 1.989 3.158c.533.256 1.011.791 1.011 1.491v.702s.18.149.5.149.5-.15.5-.15v-.7c0-.701.478-1.236 1.011-1.492A3.5 3.5 0 0 0 11.5 3V2h-7z"/>');// eslint-disable-next-line
var BIconHourglassSplit=/*#__PURE__*/makeIcon('HourglassSplit','<path d="M2.5 15a.5.5 0 1 1 0-1h1v-1a4.5 4.5 0 0 1 2.557-4.06c.29-.139.443-.377.443-.59v-.7c0-.213-.154-.451-.443-.59A4.5 4.5 0 0 1 3.5 3V2h-1a.5.5 0 0 1 0-1h11a.5.5 0 0 1 0 1h-1v1a4.5 4.5 0 0 1-2.557 4.06c-.29.139-.443.377-.443.59v.7c0 .213.154.451.443.59A4.5 4.5 0 0 1 12.5 13v1h1a.5.5 0 0 1 0 1h-11zm2-13v1c0 .537.12 1.045.337 1.5h6.326c.216-.455.337-.963.337-1.5V2h-7zm3 6.35c0 .701-.478 1.236-1.011 1.492A3.5 3.5 0 0 0 4.5 13s.866-1.299 3-1.48V8.35zm1 0v3.17c2.134.181 3 1.48 3 1.48a3.5 3.5 0 0 0-1.989-3.158C8.978 9.586 8.5 9.052 8.5 8.351z"/>');// eslint-disable-next-line
var BIconHourglassTop=/*#__PURE__*/makeIcon('HourglassTop','<path d="M2 14.5a.5.5 0 0 0 .5.5h11a.5.5 0 1 0 0-1h-1v-1a4.5 4.5 0 0 0-2.557-4.06c-.29-.139-.443-.377-.443-.59v-.7c0-.213.154-.451.443-.59A4.5 4.5 0 0 0 12.5 3V2h1a.5.5 0 0 0 0-1h-11a.5.5 0 0 0 0 1h1v1a4.5 4.5 0 0 0 2.557 4.06c.29.139.443.377.443.59v.7c0 .213-.154.451-.443.59A4.5 4.5 0 0 0 3.5 13v1h-1a.5.5 0 0 0-.5.5zm2.5-.5v-1a3.5 3.5 0 0 1 1.989-3.158c.533-.256 1.011-.79 1.011-1.491v-.702s.18.101.5.101.5-.1.5-.1v.7c0 .701.478 1.236 1.011 1.492A3.5 3.5 0 0 1 11.5 13v1h-7z"/>');// eslint-disable-next-line
var BIconHouse=/*#__PURE__*/makeIcon('House','<path fill-rule="evenodd" d="M2 13.5V7h1v6.5a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5V7h1v6.5a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 13.5zm11-11V6l-2-2V2.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M7.293 1.5a1 1 0 0 1 1.414 0l6.647 6.646a.5.5 0 0 1-.708.708L8 2.207 1.354 8.854a.5.5 0 1 1-.708-.708L7.293 1.5z"/>');// eslint-disable-next-line
var BIconHouseDoor=/*#__PURE__*/makeIcon('HouseDoor','<path d="M8.354 1.146a.5.5 0 0 0-.708 0l-6 6A.5.5 0 0 0 1.5 7.5v7a.5.5 0 0 0 .5.5h4.5a.5.5 0 0 0 .5-.5v-4h2v4a.5.5 0 0 0 .5.5H14a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.146-.354L13 5.793V2.5a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1.293L8.354 1.146zM2.5 14V7.707l5.5-5.5 5.5 5.5V14H10v-4a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v4H2.5z"/>');// eslint-disable-next-line
var BIconHouseDoorFill=/*#__PURE__*/makeIcon('HouseDoorFill','<path d="M6.5 14.5v-3.505c0-.245.25-.495.5-.495h2c.25 0 .5.25.5.5v3.5a.5.5 0 0 0 .5.5h4a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.146-.354L13 5.793V2.5a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1.293L8.354 1.146a.5.5 0 0 0-.708 0l-6 6A.5.5 0 0 0 1.5 7.5v7a.5.5 0 0 0 .5.5h4a.5.5 0 0 0 .5-.5z"/>');// eslint-disable-next-line
var BIconHouseFill=/*#__PURE__*/makeIcon('HouseFill','<path fill-rule="evenodd" d="M8 3.293l6 6V13.5a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 13.5V9.293l6-6zm5-.793V6l-2-2V2.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M7.293 1.5a1 1 0 0 1 1.414 0l6.647 6.646a.5.5 0 0 1-.708.708L8 2.207 1.354 8.854a.5.5 0 1 1-.708-.708L7.293 1.5z"/>');// eslint-disable-next-line
var BIconHr=/*#__PURE__*/makeIcon('Hr','<path d="M12 3H4a1 1 0 0 0-1 1v2.5H2V4a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2.5h-1V4a1 1 0 0 0-1-1zM2 9.5h1V12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V9.5h1V12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V9.5zm-1.5-2a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>');// eslint-disable-next-line
var BIconImage=/*#__PURE__*/makeIcon('Image','<path d="M6.002 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M2.002 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2h-12zm12 1a1 1 0 0 1 1 1v6.5l-3.777-1.947a.5.5 0 0 0-.577.093l-3.71 3.71-2.66-1.772a.5.5 0 0 0-.63.062L1.002 12V3a1 1 0 0 1 1-1h12z"/>');// eslint-disable-next-line
var BIconImageAlt=/*#__PURE__*/makeIcon('ImageAlt','<path d="M7 2.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0zm4.225 4.053a.5.5 0 0 0-.577.093l-3.71 4.71-2.66-2.772a.5.5 0 0 0-.63.062L.002 13v2a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1v-4.5l-4.777-3.947z"/>');// eslint-disable-next-line
var BIconImageFill=/*#__PURE__*/makeIcon('ImageFill','<path d="M.002 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-12a2 2 0 0 1-2-2V3zm1 9v1a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V9.5l-3.777-1.947a.5.5 0 0 0-.577.093l-3.71 3.71-2.66-1.772a.5.5 0 0 0-.63.062L1.002 12zm5-6.5a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/>');// eslint-disable-next-line
var BIconImages=/*#__PURE__*/makeIcon('Images','<path d="M4.502 9a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/><path d="M14.002 13a2 2 0 0 1-2 2h-10a2 2 0 0 1-2-2V5A2 2 0 0 1 2 3a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v8a2 2 0 0 1-1.998 2zM14 2H4a1 1 0 0 0-1 1h9.002a2 2 0 0 1 2 2v7A1 1 0 0 0 15 11V3a1 1 0 0 0-1-1zM2.002 4a1 1 0 0 0-1 1v8l2.646-2.354a.5.5 0 0 1 .63-.062l2.66 1.773 3.71-3.71a.5.5 0 0 1 .577-.094l1.777 1.947V5a1 1 0 0 0-1-1h-10z"/>');// eslint-disable-next-line
var BIconInbox=/*#__PURE__*/makeIcon('Inbox','<path d="M4.98 4a.5.5 0 0 0-.39.188L1.54 8H6a.5.5 0 0 1 .5.5 1.5 1.5 0 1 0 3 0A.5.5 0 0 1 10 8h4.46l-3.05-3.812A.5.5 0 0 0 11.02 4H4.98zm9.954 5H10.45a2.5 2.5 0 0 1-4.9 0H1.066l.32 2.562a.5.5 0 0 0 .497.438h12.234a.5.5 0 0 0 .496-.438L14.933 9zM3.809 3.563A1.5 1.5 0 0 1 4.981 3h6.038a1.5 1.5 0 0 1 1.172.563l3.7 4.625a.5.5 0 0 1 .105.374l-.39 3.124A1.5 1.5 0 0 1 14.117 13H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .106-.374l3.7-4.625z"/>');// eslint-disable-next-line
var BIconInboxFill=/*#__PURE__*/makeIcon('InboxFill','<path d="M4.98 4a.5.5 0 0 0-.39.188L1.54 8H6a.5.5 0 0 1 .5.5 1.5 1.5 0 1 0 3 0A.5.5 0 0 1 10 8h4.46l-3.05-3.812A.5.5 0 0 0 11.02 4H4.98zm-1.17-.437A1.5 1.5 0 0 1 4.98 3h6.04a1.5 1.5 0 0 1 1.17.563l3.7 4.625a.5.5 0 0 1 .106.374l-.39 3.124A1.5 1.5 0 0 1 14.117 13H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .106-.374l3.7-4.625z"/>');// eslint-disable-next-line
var BIconInboxes=/*#__PURE__*/makeIcon('Inboxes','<path d="M4.98 1a.5.5 0 0 0-.39.188L1.54 5H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0A.5.5 0 0 1 10 5h4.46l-3.05-3.812A.5.5 0 0 0 11.02 1H4.98zm9.954 5H10.45a2.5 2.5 0 0 1-4.9 0H1.066l.32 2.562A.5.5 0 0 0 1.884 9h12.234a.5.5 0 0 0 .496-.438L14.933 6zM3.809.563A1.5 1.5 0 0 1 4.981 0h6.038a1.5 1.5 0 0 1 1.172.563l3.7 4.625a.5.5 0 0 1 .105.374l-.39 3.124A1.5 1.5 0 0 1 14.117 10H1.883A1.5 1.5 0 0 1 .394 8.686l-.39-3.124a.5.5 0 0 1 .106-.374L3.81.563zM.125 11.17A.5.5 0 0 1 .5 11H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0 .5.5 0 0 1 .5-.5h5.5a.5.5 0 0 1 .496.562l-.39 3.124A1.5 1.5 0 0 1 14.117 16H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .121-.393zm.941.83l.32 2.562a.5.5 0 0 0 .497.438h12.234a.5.5 0 0 0 .496-.438l.32-2.562H10.45a2.5 2.5 0 0 1-4.9 0H1.066z"/>');// eslint-disable-next-line
var BIconInboxesFill=/*#__PURE__*/makeIcon('InboxesFill','<path d="M4.98 1a.5.5 0 0 0-.39.188L1.54 5H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0A.5.5 0 0 1 10 5h4.46l-3.05-3.812A.5.5 0 0 0 11.02 1H4.98zM3.81.563A1.5 1.5 0 0 1 4.98 0h6.04a1.5 1.5 0 0 1 1.17.563l3.7 4.625a.5.5 0 0 1 .106.374l-.39 3.124A1.5 1.5 0 0 1 14.117 10H1.883A1.5 1.5 0 0 1 .394 8.686l-.39-3.124a.5.5 0 0 1 .106-.374L3.81.563zM.125 11.17A.5.5 0 0 1 .5 11H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0 .5.5 0 0 1 .5-.5h5.5a.5.5 0 0 1 .496.562l-.39 3.124A1.5 1.5 0 0 1 14.117 16H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .121-.393z"/>');// eslint-disable-next-line
var BIconInfo=/*#__PURE__*/makeIcon('Info','<path d="M8.93 6.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM9 4.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconInfoCircle=/*#__PURE__*/makeIcon('InfoCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8.93 6.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM9 4.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconInfoCircleFill=/*#__PURE__*/makeIcon('InfoCircleFill','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm.93-9.412l-1 4.705c-.07.34.029.533.304.533.194 0 .487-.07.686-.246l-.088.416c-.287.346-.92.598-1.465.598-.703 0-1.002-.422-.808-1.319l.738-3.468c.064-.293.006-.399-.287-.47l-.451-.081.082-.381 2.29-.287zM8 5.5a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>');// eslint-disable-next-line
var BIconInfoSquare=/*#__PURE__*/makeIcon('InfoSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M8.93 6.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM9 4.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconInfoSquareFill=/*#__PURE__*/makeIcon('InfoSquareFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm8.93 4.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM8 5.5a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconInputCursor=/*#__PURE__*/makeIcon('InputCursor','<path d="M10 5h4a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1h-4v1h4a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-4v1zM6 5V4H2a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h4v-1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h4z"/><path fill-rule="evenodd" d="M8 1a.5.5 0 0 1 .5.5v13a.5.5 0 0 1-1 0v-13A.5.5 0 0 1 8 1z"/>');// eslint-disable-next-line
var BIconInputCursorText=/*#__PURE__*/makeIcon('InputCursorText','<path fill-rule="evenodd" d="M5 2a.5.5 0 0 1 .5-.5c.862 0 1.573.287 2.06.566.174.099.321.198.44.286.119-.088.266-.187.44-.286A4.165 4.165 0 0 1 10.5 1.5a.5.5 0 0 1 0 1c-.638 0-1.177.213-1.564.434a3.49 3.49 0 0 0-.436.294V7.5H9a.5.5 0 0 1 0 1h-.5v4.272c.1.08.248.187.436.294.387.221.926.434 1.564.434a.5.5 0 0 1 0 1 4.165 4.165 0 0 1-2.06-.566A4.561 4.561 0 0 1 8 13.65a4.561 4.561 0 0 1-.44.285 4.165 4.165 0 0 1-2.06.566.5.5 0 0 1 0-1c.638 0 1.177-.213 1.564-.434.188-.107.335-.214.436-.294V8.5H7a.5.5 0 0 1 0-1h.5V3.228a3.49 3.49 0 0 0-.436-.294A3.166 3.166 0 0 0 5.5 2.5.5.5 0 0 1 5 2z"/><path d="M10 5h4a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1h-4v1h4a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-4v1zM6 5V4H2a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h4v-1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h4z"/>');// eslint-disable-next-line
var BIconInstagram=/*#__PURE__*/makeIcon('Instagram','<path d="M8 0C5.829 0 5.556.01 4.703.048 3.85.088 3.269.222 2.76.42a3.917 3.917 0 0 0-1.417.923A3.927 3.927 0 0 0 .42 2.76C.222 3.268.087 3.85.048 4.7.01 5.555 0 5.827 0 8.001c0 2.172.01 2.444.048 3.297.04.852.174 1.433.372 1.942.205.526.478.972.923 1.417.444.445.89.719 1.416.923.51.198 1.09.333 1.942.372C5.555 15.99 5.827 16 8 16s2.444-.01 3.298-.048c.851-.04 1.434-.174 1.943-.372a3.916 3.916 0 0 0 1.416-.923c.445-.445.718-.891.923-1.417.197-.509.332-1.09.372-1.942C15.99 10.445 16 10.173 16 8s-.01-2.445-.048-3.299c-.04-.851-.175-1.433-.372-1.941a3.926 3.926 0 0 0-.923-1.417A3.911 3.911 0 0 0 13.24.42c-.51-.198-1.092-.333-1.943-.372C10.443.01 10.172 0 7.998 0h.003zm-.717 1.442h.718c2.136 0 2.389.007 3.232.046.78.035 1.204.166 1.486.275.373.145.64.319.92.599.28.28.453.546.598.92.11.281.24.705.275 1.485.039.843.047 1.096.047 3.231s-.008 2.389-.047 3.232c-.035.78-.166 1.203-.275 1.485a2.47 2.47 0 0 1-.599.919c-.28.28-.546.453-.92.598-.28.11-.704.24-1.485.276-.843.038-1.096.047-3.232.047s-2.39-.009-3.233-.047c-.78-.036-1.203-.166-1.485-.276a2.478 2.478 0 0 1-.92-.598 2.48 2.48 0 0 1-.6-.92c-.109-.281-.24-.705-.275-1.485-.038-.843-.046-1.096-.046-3.233 0-2.136.008-2.388.046-3.231.036-.78.166-1.204.276-1.486.145-.373.319-.64.599-.92.28-.28.546-.453.92-.598.282-.11.705-.24 1.485-.276.738-.034 1.024-.044 2.515-.045v.002zm4.988 1.328a.96.96 0 1 0 0 1.92.96.96 0 0 0 0-1.92zm-4.27 1.122a4.109 4.109 0 1 0 0 8.217 4.109 4.109 0 0 0 0-8.217zm0 1.441a2.667 2.667 0 1 1 0 5.334 2.667 2.667 0 0 1 0-5.334z"/>');// eslint-disable-next-line
var BIconIntersect=/*#__PURE__*/makeIcon('Intersect','<path fill-rule="evenodd" d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm5 10v2a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1h-2v5a2 2 0 0 1-2 2H5zm6-8H6a2 2 0 0 0-2 2v5H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v2z"/>');// eslint-disable-next-line
var BIconJournal=/*#__PURE__*/makeIcon('Journal','<path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalAlbum=/*#__PURE__*/makeIcon('JournalAlbum','<path d="M5.5 4a.5.5 0 0 0-.5.5v5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 .5-.5v-5a.5.5 0 0 0-.5-.5h-5zm1 7a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalArrowDown=/*#__PURE__*/makeIcon('JournalArrowDown','<path fill-rule="evenodd" d="M8 5a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5A.5.5 0 0 1 8 5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalArrowUp=/*#__PURE__*/makeIcon('JournalArrowUp','<path fill-rule="evenodd" d="M8 11a.5.5 0 0 0 .5-.5V6.707l1.146 1.147a.5.5 0 0 0 .708-.708l-2-2a.5.5 0 0 0-.708 0l-2 2a.5.5 0 1 0 .708.708L7.5 6.707V10.5a.5.5 0 0 0 .5.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalBookmark=/*#__PURE__*/makeIcon('JournalBookmark','<path fill-rule="evenodd" d="M6 8V1h1v6.117L8.743 6.07a.5.5 0 0 1 .514 0L11 7.117V1h1v7a.5.5 0 0 1-.757.429L9 7.083 6.757 8.43A.5.5 0 0 1 6 8z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalBookmarkFill=/*#__PURE__*/makeIcon('JournalBookmarkFill','<path fill-rule="evenodd" d="M6 1h6v7a.5.5 0 0 1-.757.429L9 7.083 6.757 8.43A.5.5 0 0 1 6 8V1z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalCheck=/*#__PURE__*/makeIcon('JournalCheck','<path fill-rule="evenodd" d="M10.854 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalCode=/*#__PURE__*/makeIcon('JournalCode','<path fill-rule="evenodd" d="M8.646 5.646a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 8 8.646 6.354a.5.5 0 0 1 0-.708zm-1.292 0a.5.5 0 0 0-.708 0l-2 2a.5.5 0 0 0 0 .708l2 2a.5.5 0 0 0 .708-.708L5.707 8l1.647-1.646a.5.5 0 0 0 0-.708z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalMedical=/*#__PURE__*/makeIcon('JournalMedical','<path fill-rule="evenodd" d="M8 4a.5.5 0 0 1 .5.5v.634l.549-.317a.5.5 0 1 1 .5.866L9 6l.549.317a.5.5 0 1 1-.5.866L8.5 6.866V7.5a.5.5 0 0 1-1 0v-.634l-.549.317a.5.5 0 1 1-.5-.866L7 6l-.549-.317a.5.5 0 0 1 .5-.866l.549.317V4.5A.5.5 0 0 1 8 4zM5 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalMinus=/*#__PURE__*/makeIcon('JournalMinus','<path fill-rule="evenodd" d="M5.5 8a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalPlus=/*#__PURE__*/makeIcon('JournalPlus','<path fill-rule="evenodd" d="M8 5.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 .5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalRichtext=/*#__PURE__*/makeIcon('JournalRichtext','<path d="M7.5 3.75a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047L11 4.75V7a.5.5 0 0 1-.5.5h-5A.5.5 0 0 1 5 7v-.5s1.54-1.274 1.639-1.208zM5 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalText=/*#__PURE__*/makeIcon('JournalText','<path d="M5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm0-2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0-2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0-2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournalX=/*#__PURE__*/makeIcon('JournalX','<path fill-rule="evenodd" d="M6.146 6.146a.5.5 0 0 1 .708 0L8 7.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 8l1.147 1.146a.5.5 0 0 1-.708.708L8 8.707 6.854 9.854a.5.5 0 0 1-.708-.708L7.293 8 6.146 6.854a.5.5 0 0 1 0-.708z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>');// eslint-disable-next-line
var BIconJournals=/*#__PURE__*/makeIcon('Journals','<path d="M5 0h8a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2 2 2 0 0 1-2 2H3a2 2 0 0 1-2-2h1a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1H1a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v9a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H5a1 1 0 0 0-1 1H3a2 2 0 0 1 2-2z"/><path d="M1 6v-.5a.5.5 0 0 1 1 0V6h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V9h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 2.5v.5H.5a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1H2v-.5a.5.5 0 0 0-1 0z"/>');// eslint-disable-next-line
var BIconJoystick=/*#__PURE__*/makeIcon('Joystick','<path d="M10 2a2 2 0 0 1-1.5 1.937v5.087c.863.083 1.5.377 1.5.726 0 .414-.895.75-2 .75s-2-.336-2-.75c0-.35.637-.643 1.5-.726V3.937A2 2 0 1 1 10 2z"/><path d="M0 9.665v1.717a1 1 0 0 0 .553.894l6.553 3.277a2 2 0 0 0 1.788 0l6.553-3.277a1 1 0 0 0 .553-.894V9.665c0-.1-.06-.19-.152-.23L9.5 6.715v.993l5.227 2.178a.125.125 0 0 1 .001.23l-5.94 2.546a2 2 0 0 1-1.576 0l-5.94-2.546a.125.125 0 0 1 .001-.23L6.5 7.708l-.013-.988L.152 9.435a.25.25 0 0 0-.152.23z"/>');// eslint-disable-next-line
var BIconJustify=/*#__PURE__*/makeIcon('Justify','<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconJustifyLeft=/*#__PURE__*/makeIcon('JustifyLeft','<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconJustifyRight=/*#__PURE__*/makeIcon('JustifyRight','<path fill-rule="evenodd" d="M6 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-4-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconKanban=/*#__PURE__*/makeIcon('Kanban','<path d="M13.5 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1h-11a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h11zm-11-1a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2h-11z"/><path d="M6.5 3a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3zm-4 0a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3zm8 0a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3z"/>');// eslint-disable-next-line
var BIconKanbanFill=/*#__PURE__*/makeIcon('KanbanFill','<path d="M2.5 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2h-11zm5 2h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1zm-5 1a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3zm9-1h1a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconKey=/*#__PURE__*/makeIcon('Key','<path d="M0 8a4 4 0 0 1 7.465-2H14a.5.5 0 0 1 .354.146l1.5 1.5a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0L13 9.207l-.646.647a.5.5 0 0 1-.708 0L11 9.207l-.646.647a.5.5 0 0 1-.708 0L9 9.207l-.646.647A.5.5 0 0 1 8 10h-.535A4 4 0 0 1 0 8zm4-3a3 3 0 1 0 2.712 4.285A.5.5 0 0 1 7.163 9h.63l.853-.854a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708 0l.646.647.793-.793-1-1h-6.63a.5.5 0 0 1-.451-.285A3 3 0 0 0 4 5z"/><path d="M4 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconKeyFill=/*#__PURE__*/makeIcon('KeyFill','<path d="M3.5 11.5a3.5 3.5 0 1 1 3.163-5H14L15.5 8 14 9.5l-1-1-1 1-1-1-1 1-1-1-1 1H6.663a3.5 3.5 0 0 1-3.163 2zM2.5 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconKeyboard=/*#__PURE__*/makeIcon('Keyboard','<path d="M14 5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h12zM2 4a2 2 0 0 0-2 2v5a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H2z"/><path d="M13 10.25a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm0-2a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-5 0A.25.25 0 0 1 8.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 8 8.75v-.5zm2 0a.25.25 0 0 1 .25-.25h1.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-1.5a.25.25 0 0 1-.25-.25v-.5zm1 2a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-5-2A.25.25 0 0 1 6.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 6 8.75v-.5zm-2 0A.25.25 0 0 1 4.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 4 8.75v-.5zm-2 0A.25.25 0 0 1 2.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 2 8.75v-.5zm11-2a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-2 0a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-2 0A.25.25 0 0 1 9.25 6h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 9 6.75v-.5zm-2 0A.25.25 0 0 1 7.25 6h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 7 6.75v-.5zm-2 0A.25.25 0 0 1 5.25 6h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 5 6.75v-.5zm-3 0A.25.25 0 0 1 2.25 6h1.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-1.5A.25.25 0 0 1 2 6.75v-.5zm0 4a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm2 0a.25.25 0 0 1 .25-.25h5.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-5.5a.25.25 0 0 1-.25-.25v-.5z"/>');// eslint-disable-next-line
var BIconKeyboardFill=/*#__PURE__*/makeIcon('KeyboardFill','<path d="M0 6a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V6zm13 .25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5a.25.25 0 0 0-.25.25zM2.25 8a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 3 8.75v-.5A.25.25 0 0 0 2.75 8h-.5zM4 8.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 5 8.75v-.5A.25.25 0 0 0 4.75 8h-.5a.25.25 0 0 0-.25.25zM6.25 8a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 7 8.75v-.5A.25.25 0 0 0 6.75 8h-.5zM8 8.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 9 8.75v-.5A.25.25 0 0 0 8.75 8h-.5a.25.25 0 0 0-.25.25zM13.25 8a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5zm0 2a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5zm-3-2a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-1.5zm.75 2.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5a.25.25 0 0 0-.25.25zM11.25 6a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5zM9 6.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5A.25.25 0 0 0 9.75 6h-.5a.25.25 0 0 0-.25.25zM7.25 6a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 8 6.75v-.5A.25.25 0 0 0 7.75 6h-.5zM5 6.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 6 6.75v-.5A.25.25 0 0 0 5.75 6h-.5a.25.25 0 0 0-.25.25zM2.25 6a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h1.5A.25.25 0 0 0 4 6.75v-.5A.25.25 0 0 0 3.75 6h-1.5zM2 10.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5a.25.25 0 0 0-.25.25zM4.25 10a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h5.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-5.5z"/>');// eslint-disable-next-line
var BIconLadder=/*#__PURE__*/makeIcon('Ladder','<path d="M4.5 1a.5.5 0 0 1 .5.5V2h6v-.5a.5.5 0 0 1 1 0v14a.5.5 0 0 1-1 0V15H5v.5a.5.5 0 0 1-1 0v-14a.5.5 0 0 1 .5-.5zM5 14h6v-2H5v2zm0-3h6V9H5v2zm0-3h6V6H5v2zm0-3h6V3H5v2z"/>');// eslint-disable-next-line
var BIconLamp=/*#__PURE__*/makeIcon('Lamp','<path d="M13 3v4H3V3h10zM3 2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H3zm4.5-1l.276-.553a.25.25 0 0 1 .448 0L8.5 1h-1zm-.012 9h1.024c.337.646.677 1.33.95 1.949.176.396.318.75.413 1.042.048.146.081.266.102.36A1.347 1.347 0 0 1 10 13.5c0 .665-.717 1.5-2 1.5s-2-.835-2-1.5c0 0 0-.013.004-.039.003-.027.01-.063.02-.11.02-.094.053-.214.1-.36.096-.291.238-.646.413-1.042.274-.62.614-1.303.95-1.949zm1.627-1h-2.23C6.032 10.595 5 12.69 5 13.5 5 14.88 6.343 16 8 16s3-1.12 3-2.5c0-.81-1.032-2.905-1.885-4.5z"/>');// eslint-disable-next-line
var BIconLampFill=/*#__PURE__*/makeIcon('LampFill','<path d="M2 3a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3zm5.5-2l.276-.553a.25.25 0 0 1 .448 0L8.5 1h-1zm-.615 8h2.23C9.968 10.595 11 12.69 11 13.5c0 1.38-1.343 2.5-3 2.5s-3-1.12-3-2.5c0-.81 1.032-2.905 1.885-4.5z"/>');// eslint-disable-next-line
var BIconLaptop=/*#__PURE__*/makeIcon('Laptop','<path d="M13.5 3a.5.5 0 0 1 .5.5V11H2V3.5a.5.5 0 0 1 .5-.5h11zm-11-1A1.5 1.5 0 0 0 1 3.5V12h14V3.5A1.5 1.5 0 0 0 13.5 2h-11zM0 12.5h16a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5z"/>');// eslint-disable-next-line
var BIconLaptopFill=/*#__PURE__*/makeIcon('LaptopFill','<path d="M2.5 2A1.5 1.5 0 0 0 1 3.5V12h14V3.5A1.5 1.5 0 0 0 13.5 2h-11zM0 12.5h16a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5z"/>');// eslint-disable-next-line
var BIconLayers=/*#__PURE__*/makeIcon('Layers','<path d="M8.235 1.559a.5.5 0 0 0-.47 0l-7.5 4a.5.5 0 0 0 0 .882L3.188 8 .264 9.559a.5.5 0 0 0 0 .882l7.5 4a.5.5 0 0 0 .47 0l7.5-4a.5.5 0 0 0 0-.882L12.813 8l2.922-1.559a.5.5 0 0 0 0-.882l-7.5-4zm3.515 7.008L14.438 10 8 13.433 1.562 10 4.25 8.567l3.515 1.874a.5.5 0 0 0 .47 0l3.515-1.874zM8 9.433L1.562 6 8 2.567 14.438 6 8 9.433z"/>');// eslint-disable-next-line
var BIconLayersFill=/*#__PURE__*/makeIcon('LayersFill','<path d="M7.765 1.559a.5.5 0 0 1 .47 0l7.5 4a.5.5 0 0 1 0 .882l-7.5 4a.5.5 0 0 1-.47 0l-7.5-4a.5.5 0 0 1 0-.882l7.5-4z"/><path d="M2.125 8.567l-1.86.992a.5.5 0 0 0 0 .882l7.5 4a.5.5 0 0 0 .47 0l7.5-4a.5.5 0 0 0 0-.882l-1.86-.992-5.17 2.756a1.5 1.5 0 0 1-1.41 0l-5.17-2.756z"/>');// eslint-disable-next-line
var BIconLayersHalf=/*#__PURE__*/makeIcon('LayersHalf','<path d="M8.235 1.559a.5.5 0 0 0-.47 0l-7.5 4a.5.5 0 0 0 0 .882L3.188 8 .264 9.559a.5.5 0 0 0 0 .882l7.5 4a.5.5 0 0 0 .47 0l7.5-4a.5.5 0 0 0 0-.882L12.813 8l2.922-1.559a.5.5 0 0 0 0-.882l-7.5-4zM8 9.433L1.562 6 8 2.567 14.438 6 8 9.433z"/>');// eslint-disable-next-line
var BIconLayoutSidebar=/*#__PURE__*/makeIcon('LayoutSidebar','<path d="M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3zm5-1v12h9a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H5zM4 2H2a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h2V2z"/>');// eslint-disable-next-line
var BIconLayoutSidebarInset=/*#__PURE__*/makeIcon('LayoutSidebarInset','<path d="M14 2a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h12zM2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2z"/><path d="M3 4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V4z"/>');// eslint-disable-next-line
var BIconLayoutSidebarInsetReverse=/*#__PURE__*/makeIcon('LayoutSidebarInsetReverse','<path d="M2 2a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h12z"/><path d="M13 4a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconLayoutSidebarReverse=/*#__PURE__*/makeIcon('LayoutSidebarReverse','<path d="M16 3a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3zm-5-1v12H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h9zm1 0h2a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1h-2V2z"/>');// eslint-disable-next-line
var BIconLayoutSplit=/*#__PURE__*/makeIcon('LayoutSplit','<path d="M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3zm8.5-1v12H14a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H8.5zm-1 0H2a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h5.5V2z"/>');// eslint-disable-next-line
var BIconLayoutTextSidebar=/*#__PURE__*/makeIcon('LayoutTextSidebar','<path d="M3.5 3a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 3a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zM3 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm12-1v14h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2zm-1 0H2a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h9V1z"/>');// eslint-disable-next-line
var BIconLayoutTextSidebarReverse=/*#__PURE__*/makeIcon('LayoutTextSidebarReverse','<path d="M12.5 3a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5zm0 3a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5zm.5 3.5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 .5-.5zm-.5 2.5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5z"/><path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2zM4 1v14H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h2zm1 0h9a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H5V1z"/>');// eslint-disable-next-line
var BIconLayoutTextWindow=/*#__PURE__*/makeIcon('LayoutTextWindow','<path d="M3 6.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm12 1a1 1 0 0 1 1 1v1H1V2a1 1 0 0 1 1-1h12zm1 3v10a1 1 0 0 1-1 1h-2V4h3zm-4 0v11H2a1 1 0 0 1-1-1V4h10z"/>');// eslint-disable-next-line
var BIconLayoutTextWindowReverse=/*#__PURE__*/makeIcon('LayoutTextWindowReverse','<path d="M13 6.5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 .5-.5zm0 3a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 .5-.5zm-.5 2.5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5z"/><path d="M14 0a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12zM2 1a1 1 0 0 0-1 1v1h14V2a1 1 0 0 0-1-1H2zM1 4v10a1 1 0 0 0 1 1h2V4H1zm4 0v11h9a1 1 0 0 0 1-1V4H5z"/>');// eslint-disable-next-line
var BIconLayoutThreeColumns=/*#__PURE__*/makeIcon('LayoutThreeColumns','<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h13A1.5 1.5 0 0 1 16 1.5v13a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 14.5v-13zM1.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 .5.5H5V1H1.5zM10 15V1H6v14h4zm1 0h3.5a.5.5 0 0 0 .5-.5v-13a.5.5 0 0 0-.5-.5H11v14z"/>');// eslint-disable-next-line
var BIconLayoutWtf=/*#__PURE__*/makeIcon('LayoutWtf','<path d="M5 1v8H1V1h4zM1 0a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1H1zm13 2v5H9V2h5zM9 1a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H9zM5 13v2H3v-2h2zm-2-1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1H3zm12-1v2H9v-2h6zm-6-1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1H9z"/>');// eslint-disable-next-line
var BIconLifePreserver=/*#__PURE__*/makeIcon('LifePreserver','<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm6.43-5.228a7.025 7.025 0 0 1-3.658 3.658l-1.115-2.788a4.015 4.015 0 0 0 1.985-1.985l2.788 1.115zM5.228 14.43a7.025 7.025 0 0 1-3.658-3.658l2.788-1.115a4.015 4.015 0 0 0 1.985 1.985L5.228 14.43zm9.202-9.202l-2.788 1.115a4.015 4.015 0 0 0-1.985-1.985l1.115-2.788a7.025 7.025 0 0 1 3.658 3.658zm-8.087-.87a4.015 4.015 0 0 0-1.985 1.985L1.57 5.228A7.025 7.025 0 0 1 5.228 1.57l1.115 2.788zM8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>');// eslint-disable-next-line
var BIconLightning=/*#__PURE__*/makeIcon('Lightning','<path d="M11.251.068a.5.5 0 0 1 .227.58L9.677 6.5H13a.5.5 0 0 1 .364.843l-8 8.5a.5.5 0 0 1-.842-.49L6.323 9.5H3a.5.5 0 0 1-.364-.843l8-8.5a.5.5 0 0 1 .615-.09zM4.157 8.5H7a.5.5 0 0 1 .478.647L6.11 13.59l5.732-6.09H9a.5.5 0 0 1-.478-.647L9.89 2.41 4.157 8.5z"/>');// eslint-disable-next-line
var BIconLightningFill=/*#__PURE__*/makeIcon('LightningFill','<path d="M11.251.068a.5.5 0 0 1 .227.58L9.677 6.5H13a.5.5 0 0 1 .364.843l-8 8.5a.5.5 0 0 1-.842-.49L6.323 9.5H3a.5.5 0 0 1-.364-.843l8-8.5a.5.5 0 0 1 .615-.09z"/>');// eslint-disable-next-line
var BIconLink=/*#__PURE__*/makeIcon('Link','<path d="M6.354 5.5H4a3 3 0 0 0 0 6h3a3 3 0 0 0 2.83-4H9c-.086 0-.17.01-.25.031A2 2 0 0 1 7 10.5H4a2 2 0 1 1 0-4h1.535c.218-.376.495-.714.82-1z"/><path d="M9 5.5a3 3 0 0 0-2.83 4h1.098A2 2 0 0 1 9 6.5h3a2 2 0 1 1 0 4h-1.535a4.02 4.02 0 0 1-.82 1H12a3 3 0 1 0 0-6H9z"/>');// eslint-disable-next-line
var BIconLink45deg=/*#__PURE__*/makeIcon('Link45deg','<path d="M4.715 6.542L3.343 7.914a3 3 0 1 0 4.243 4.243l1.828-1.829A3 3 0 0 0 8.586 5.5L8 6.086a1.001 1.001 0 0 0-.154.199 2 2 0 0 1 .861 3.337L6.88 11.45a2 2 0 1 1-2.83-2.83l.793-.792a4.018 4.018 0 0 1-.128-1.287z"/><path d="M6.586 4.672A3 3 0 0 0 7.414 9.5l.775-.776a2 2 0 0 1-.896-3.346L9.12 3.55a2 2 0 0 1 2.83 2.83l-.793.792c.112.42.155.855.128 1.287l1.372-1.372a3 3 0 0 0-4.243-4.243L6.586 4.672z"/>');// eslint-disable-next-line
var BIconLinkedin=/*#__PURE__*/makeIcon('Linkedin','<path d="M0 1.146C0 .513.526 0 1.175 0h13.65C15.474 0 16 .513 16 1.146v13.708c0 .633-.526 1.146-1.175 1.146H1.175C.526 16 0 15.487 0 14.854V1.146zm4.943 12.248V6.169H2.542v7.225h2.401zm-1.2-8.212c.837 0 1.358-.554 1.358-1.248-.015-.709-.52-1.248-1.342-1.248-.822 0-1.359.54-1.359 1.248 0 .694.521 1.248 1.327 1.248h.016zm4.908 8.212V9.359c0-.216.016-.432.08-.586.173-.431.568-.878 1.232-.878.869 0 1.216.662 1.216 1.634v3.865h2.401V9.25c0-2.22-1.184-3.252-2.764-3.252-1.274 0-1.845.7-2.165 1.193v.025h-.016a5.54 5.54 0 0 1 .016-.025V6.169h-2.4c.03.678 0 7.225 0 7.225h2.4z"/>');// eslint-disable-next-line
var BIconList=/*#__PURE__*/makeIcon('List','<path fill-rule="evenodd" d="M2.5 11.5A.5.5 0 0 1 3 11h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 3 7h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 3 3h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconListCheck=/*#__PURE__*/makeIcon('ListCheck','<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3.854 2.146a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 1 1 .708-.708L2 3.293l1.146-1.147a.5.5 0 0 1 .708 0zm0 4a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 1 1 .708-.708L2 7.293l1.146-1.147a.5.5 0 0 1 .708 0zm0 4a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 0 1 .708-.708l.146.147 1.146-1.147a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconListNested=/*#__PURE__*/makeIcon('ListNested','<path fill-rule="evenodd" d="M4.5 11.5A.5.5 0 0 1 5 11h10a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zm-2-4A.5.5 0 0 1 3 7h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm-2-4A.5.5 0 0 1 1 3h10a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconListOl=/*#__PURE__*/makeIcon('ListOl','<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5z"/><path d="M1.713 11.865v-.474H2c.217 0 .363-.137.363-.317 0-.185-.158-.31-.361-.31-.223 0-.367.152-.373.31h-.59c.016-.467.373-.787.986-.787.588-.002.954.291.957.703a.595.595 0 0 1-.492.594v.033a.615.615 0 0 1 .569.631c.003.533-.502.8-1.051.8-.656 0-1-.37-1.008-.794h.582c.008.178.186.306.422.309.254 0 .424-.145.422-.35-.002-.195-.155-.348-.414-.348h-.3zm-.004-4.699h-.604v-.035c0-.408.295-.844.958-.844.583 0 .96.326.96.756 0 .389-.257.617-.476.848l-.537.572v.03h1.054V9H1.143v-.395l.957-.99c.138-.142.293-.304.293-.508 0-.18-.147-.32-.342-.32a.33.33 0 0 0-.342.338v.041zM2.564 5h-.635V2.924h-.031l-.598.42v-.567l.629-.443h.635V5z"/>');// eslint-disable-next-line
var BIconListStars=/*#__PURE__*/makeIcon('ListStars','<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5z"/><path d="M2.242 2.194a.27.27 0 0 1 .516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 0 0-.094.3l.173.569c.078.256-.213.462-.423.3l-.417-.324a.267.267 0 0 0-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 0 0-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 0 0 .259-.194l.162-.53zm0 4a.27.27 0 0 1 .516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 0 0-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 0 0-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 0 0-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 0 0 .259-.194l.162-.53zm0 4a.27.27 0 0 1 .516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 0 0-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 0 0-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 0 0-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 0 0 .259-.194l.162-.53z"/>');// eslint-disable-next-line
var BIconListTask=/*#__PURE__*/makeIcon('ListTask','<path fill-rule="evenodd" d="M2 2.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5V3a.5.5 0 0 0-.5-.5H2zM3 3H2v1h1V3z"/><path d="M5 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM5.5 7a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 4a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9z"/><path fill-rule="evenodd" d="M1.5 7a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H2a.5.5 0 0 1-.5-.5V7zM2 7h1v1H2V7zm0 3.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5H2zm1 .5H2v1h1v-1z"/>');// eslint-disable-next-line
var BIconListUl=/*#__PURE__*/makeIcon('ListUl','<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm-3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm0 4a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm0 4a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconLock=/*#__PURE__*/makeIcon('Lock','<path d="M8 1a2 2 0 0 1 2 2v4H6V3a2 2 0 0 1 2-2zm3 6V3a3 3 0 0 0-6 0v4a2 2 0 0 0-2 2v5a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2zM5 8h6a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V9a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconLockFill=/*#__PURE__*/makeIcon('LockFill','<path d="M8 1a2 2 0 0 1 2 2v4H6V3a2 2 0 0 1 2-2zm3 6V3a3 3 0 0 0-6 0v4a2 2 0 0 0-2 2v5a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2z"/>');// eslint-disable-next-line
var BIconMailbox=/*#__PURE__*/makeIcon('Mailbox','<path d="M4 4a3 3 0 0 0-3 3v6h6V7a3 3 0 0 0-3-3zm0-1h8a4 4 0 0 1 4 4v6a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V7a4 4 0 0 1 4-4zm2.646 1A3.99 3.99 0 0 1 8 7v6h7V7a3 3 0 0 0-3-3H6.646z"/><path d="M11.793 8.5H9v-1h5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.354-.146l-.853-.854zM5 7c0 .552-.448 0-1 0s-1 .552-1 0a1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconMailbox2=/*#__PURE__*/makeIcon('Mailbox2','<path d="M9 8.5h2.793l.853.854A.5.5 0 0 0 13 9.5h1a.5.5 0 0 0 .5-.5V8a.5.5 0 0 0-.5-.5H9v1z"/><path d="M12 3H4a4 4 0 0 0-4 4v6a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1V7a4 4 0 0 0-4-4zM8 7a3.99 3.99 0 0 0-1.354-3H12a3 3 0 0 1 3 3v6H8V7zm-3.415.157C4.42 7.087 4.218 7 4 7c-.218 0-.42.086-.585.157C3.164 7.264 3 7.334 3 7a1 1 0 0 1 2 0c0 .334-.164.264-.415.157z"/>');// eslint-disable-next-line
var BIconMap=/*#__PURE__*/makeIcon('Map','<path fill-rule="evenodd" d="M15.817.113A.5.5 0 0 1 16 .5v14a.5.5 0 0 1-.402.49l-5 1a.502.502 0 0 1-.196 0L5.5 15.01l-4.902.98A.5.5 0 0 1 0 15.5v-14a.5.5 0 0 1 .402-.49l5-1a.5.5 0 0 1 .196 0L10.5.99l4.902-.98a.5.5 0 0 1 .415.103zM10 1.91l-4-.8v12.98l4 .8V1.91zm1 12.98l4-.8V1.11l-4 .8v12.98zm-6-.8V1.11l-4 .8v12.98l4-.8z"/>');// eslint-disable-next-line
var BIconMapFill=/*#__PURE__*/makeIcon('MapFill','<path fill-rule="evenodd" d="M16 .5a.5.5 0 0 0-.598-.49L10.5.99 5.598.01a.5.5 0 0 0-.196 0l-5 1A.5.5 0 0 0 0 1.5v14a.5.5 0 0 0 .598.49l4.902-.98 4.902.98a.502.502 0 0 0 .196 0l5-1A.5.5 0 0 0 16 14.5V.5zM5 14.09V1.11l.5-.1.5.1v12.98l-.402-.08a.498.498 0 0 0-.196 0L5 14.09zm5 .8V1.91l.402.08a.5.5 0 0 0 .196 0L11 1.91v12.98l-.5.1-.5-.1z"/>');// eslint-disable-next-line
var BIconMarkdown=/*#__PURE__*/makeIcon('Markdown','<path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/><path fill-rule="evenodd" d="M9.146 8.146a.5.5 0 0 1 .708 0L11.5 9.793l1.646-1.647a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 0-.708z"/><path fill-rule="evenodd" d="M11.5 5a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0v-4a.5.5 0 0 1 .5-.5z"/><path d="M3.56 11V7.01h.056l1.428 3.239h.774l1.42-3.24h.056V11h1.073V5.001h-1.2l-1.71 3.894h-.039l-1.71-3.894H2.5V11h1.06z"/>');// eslint-disable-next-line
var BIconMarkdownFill=/*#__PURE__*/makeIcon('MarkdownFill','<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm11.5 1a.5.5 0 0 0-.5.5v3.793L9.854 8.146a.5.5 0 1 0-.708.708l2 2a.5.5 0 0 0 .708 0l2-2a.5.5 0 0 0-.708-.708L12 9.293V5.5a.5.5 0 0 0-.5-.5zM3.56 7.01h.056l1.428 3.239h.774l1.42-3.24h.056V11h1.073V5.001h-1.2l-1.71 3.894h-.039l-1.71-3.894H2.5V11h1.06V7.01z"/>');// eslint-disable-next-line
var BIconMenuApp=/*#__PURE__*/makeIcon('MenuApp','<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h2A1.5 1.5 0 0 1 5 1.5v2A1.5 1.5 0 0 1 3.5 5h-2A1.5 1.5 0 0 1 0 3.5v-2zM1.5 1a.5.5 0 0 0-.5.5v2a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-2zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMenuAppFill=/*#__PURE__*/makeIcon('MenuAppFill','<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h2A1.5 1.5 0 0 1 5 1.5v2A1.5 1.5 0 0 1 3.5 5h-2A1.5 1.5 0 0 1 0 3.5v-2zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMenuButton=/*#__PURE__*/makeIcon('MenuButton','<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h8A1.5 1.5 0 0 1 11 1.5v2A1.5 1.5 0 0 1 9.5 5h-8A1.5 1.5 0 0 1 0 3.5v-2zM1.5 1a.5.5 0 0 0-.5.5v2a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-8z"/><path d="M7.823 2.823l-.396-.396A.25.25 0 0 1 7.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMenuButtonFill=/*#__PURE__*/makeIcon('MenuButtonFill','<path d="M1.5 0A1.5 1.5 0 0 0 0 1.5v2A1.5 1.5 0 0 0 1.5 5h8A1.5 1.5 0 0 0 11 3.5v-2A1.5 1.5 0 0 0 9.5 0h-8zm5.927 2.427A.25.25 0 0 1 7.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0l-.396-.396zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMenuButtonWide=/*#__PURE__*/makeIcon('MenuButtonWide','<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h13A1.5 1.5 0 0 1 16 1.5v2A1.5 1.5 0 0 1 14.5 5h-13A1.5 1.5 0 0 1 0 3.5v-2zM1.5 1a.5.5 0 0 0-.5.5v2a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-13z"/><path d="M2 2.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm10.823.323l-.396-.396A.25.25 0 0 1 12.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMenuButtonWideFill=/*#__PURE__*/makeIcon('MenuButtonWideFill','<path d="M1.5 0A1.5 1.5 0 0 0 0 1.5v2A1.5 1.5 0 0 0 1.5 5h13A1.5 1.5 0 0 0 16 3.5v-2A1.5 1.5 0 0 0 14.5 0h-13zm1 2h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1 0-1zm9.927.427A.25.25 0 0 1 12.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0l-.396-.396zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMenuDown=/*#__PURE__*/makeIcon('MenuDown','<path d="M7.646.146a.5.5 0 0 1 .708 0L10.207 2H14a2 2 0 0 1 2 2v9a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h3.793L7.646.146zM1 7v3h14V7H1zm14-1V4a1 1 0 0 0-1-1h-3.793a1 1 0 0 1-.707-.293L8 1.207l-1.5 1.5A1 1 0 0 1 5.793 3H2a1 1 0 0 0-1 1v2h14zm0 5H1v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2zM2 4.5a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 0 1h-8a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMenuUp=/*#__PURE__*/makeIcon('MenuUp','<path d="M7.646 15.854a.5.5 0 0 0 .708 0L10.207 14H14a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2h3.793l1.853 1.854zM1 9V6h14v3H1zm14 1v2a1 1 0 0 1-1 1h-3.793a1 1 0 0 0-.707.293l-1.5 1.5-1.5-1.5A1 1 0 0 0 5.793 13H2a1 1 0 0 1-1-1v-2h14zm0-5H1V3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v2zM2 11.5a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 0-1h-8a.5.5 0 0 0-.5.5zm0-4a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 0-1h-11a.5.5 0 0 0-.5.5zm0-4a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 0-1h-6a.5.5 0 0 0-.5.5z"/>');// eslint-disable-next-line
var BIconMic=/*#__PURE__*/makeIcon('Mic','<path fill-rule="evenodd" d="M3.5 6.5A.5.5 0 0 1 4 7v1a4 4 0 0 0 8 0V7a.5.5 0 0 1 1 0v1a5 5 0 0 1-4.5 4.975V15h3a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1h3v-2.025A5 5 0 0 1 3 8V7a.5.5 0 0 1 .5-.5z"/><path fill-rule="evenodd" d="M10 8V3a2 2 0 1 0-4 0v5a2 2 0 1 0 4 0zM8 0a3 3 0 0 0-3 3v5a3 3 0 0 0 6 0V3a3 3 0 0 0-3-3z"/>');// eslint-disable-next-line
var BIconMicFill=/*#__PURE__*/makeIcon('MicFill','<path d="M5 3a3 3 0 0 1 6 0v5a3 3 0 0 1-6 0V3z"/><path fill-rule="evenodd" d="M3.5 6.5A.5.5 0 0 1 4 7v1a4 4 0 0 0 8 0V7a.5.5 0 0 1 1 0v1a5 5 0 0 1-4.5 4.975V15h3a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1h3v-2.025A5 5 0 0 1 3 8V7a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconMicMute=/*#__PURE__*/makeIcon('MicMute','<path fill-rule="evenodd" d="M12.734 9.613A4.995 4.995 0 0 0 13 8V7a.5.5 0 0 0-1 0v1c0 .274-.027.54-.08.799l.814.814zm-2.522 1.72A4 4 0 0 1 4 8V7a.5.5 0 0 0-1 0v1a5 5 0 0 0 4.5 4.975V15h-3a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-3v-2.025a4.973 4.973 0 0 0 2.43-.923l-.718-.719zM11 7.88V3a3 3 0 0 0-5.842-.963l.845.845A2 2 0 0 1 10 3v3.879l1 1zM8.738 9.86l.748.748A3 3 0 0 1 5 8V6.121l1 1V8a2 2 0 0 0 2.738 1.86zm4.908 3.494l-12-12 .708-.708 12 12-.708.707z"/>');// eslint-disable-next-line
var BIconMicMuteFill=/*#__PURE__*/makeIcon('MicMuteFill','<path fill-rule="evenodd" d="M12.734 9.613A4.995 4.995 0 0 0 13 8V7a.5.5 0 0 0-1 0v1c0 .274-.027.54-.08.799l.814.814zm-2.522 1.72A4 4 0 0 1 4 8V7a.5.5 0 0 0-1 0v1a5 5 0 0 0 4.5 4.975V15h-3a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-3v-2.025a4.973 4.973 0 0 0 2.43-.923l-.718-.719zM11 7.88V3a3 3 0 0 0-5.842-.963L11 7.879zM5 6.12l4.486 4.486A3 3 0 0 1 5 8V6.121zm8.646 7.234l-12-12 .708-.708 12 12-.708.707z"/>');// eslint-disable-next-line
var BIconMinecart=/*#__PURE__*/makeIcon('Minecart','<path d="M4 15a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm8-1a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zM.115 3.18A.5.5 0 0 1 .5 3h15a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 14 12H2a.5.5 0 0 1-.491-.408l-1.5-8a.5.5 0 0 1 .106-.411zm.987.82l1.313 7h11.17l1.313-7H1.102z"/>');// eslint-disable-next-line
var BIconMinecartLoaded=/*#__PURE__*/makeIcon('MinecartLoaded','<path d="M4 15a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm8-1a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zM.115 3.18A.5.5 0 0 1 .5 3h15a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 14 12H2a.5.5 0 0 1-.491-.408l-1.5-8a.5.5 0 0 1 .106-.411zm.987.82l1.313 7h11.17l1.313-7H1.102z"/><path fill-rule="evenodd" d="M6 1a2.498 2.498 0 0 1 4 0c.818 0 1.545.394 2 1 .67 0 1.552.57 2 1h-2c-.314 0-.611-.15-.8-.4-.274-.365-.71-.6-1.2-.6-.314 0-.611-.15-.8-.4a1.497 1.497 0 0 0-2.4 0c-.189.25-.486.4-.8.4-.507 0-.955.251-1.228.638-.09.13-.194.25-.308.362H3c.13-.147.401-.432.562-.545a1.63 1.63 0 0 0 .393-.393A2.498 2.498 0 0 1 6 1z"/>');// eslint-disable-next-line
var BIconMoon=/*#__PURE__*/makeIcon('Moon','<path fill-rule="evenodd" d="M14.53 10.53a7 7 0 0 1-9.058-9.058A7.003 7.003 0 0 0 8 15a7.002 7.002 0 0 0 6.53-4.47z"/>');// eslint-disable-next-line
var BIconMouse=/*#__PURE__*/makeIcon('Mouse','<path d="M8 3a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 3zm4 8a4 4 0 0 1-8 0V5a4 4 0 1 1 8 0v6zM8 0a5 5 0 0 0-5 5v6a5 5 0 0 0 10 0V5a5 5 0 0 0-5-5z"/>');// eslint-disable-next-line
var BIconMouse2=/*#__PURE__*/makeIcon('Mouse2','<path d="M3 5.188C3 2.341 5.22 0 8 0s5 2.342 5 5.188v5.625C13 13.658 10.78 16 8 16s-5-2.342-5-5.188V5.189zm4.5-4.155C5.541 1.289 4 3.035 4 5.188V5.5h3.5V1.033zm1 0V5.5H12v-.313c0-2.152-1.541-3.898-3.5-4.154zM12 6.5H4v4.313C4 13.145 5.81 15 8 15s4-1.855 4-4.188V6.5z"/>');// eslint-disable-next-line
var BIconMouse3=/*#__PURE__*/makeIcon('Mouse3','<path d="M7 0c-.593 0-1.104.157-1.527.463-.418.302-.717.726-.93 1.208C4.123 2.619 4 3.879 4 5.187v.504L3.382 6A2.5 2.5 0 0 0 2 8.236v2.576C2 13.659 4.22 16 7 16h2c2.78 0 5-2.342 5-5.188V7.51a.71.71 0 0 0 0-.02V5.186c0-1.13-.272-2.044-.748-2.772-.474-.726-1.13-1.235-1.849-1.59C9.981.123 8.26 0 7 0zm2.5 6.099V1.232c.51.11 1.008.267 1.46.49.596.293 1.099.694 1.455 1.24.355.543.585 1.262.585 2.225v1.69l-3.5-.778zm-1-5.025v4.803L5 5.099c.006-1.242.134-2.293.457-3.024.162-.366.363-.63.602-.801C6.292 1.105 6.593 1 7 1c.468 0 .98.018 1.5.074zM5 6.124L13 7.9v2.912C13 13.145 11.19 15 9 15H7c-2.19 0-4-1.855-4-4.188V8.236a1.5 1.5 0 0 1 .83-1.342l.187-.093c.01.265.024.58.047.92.062.938.19 2.12.462 2.937a.5.5 0 1 0 .948-.316c-.227-.683-.35-1.75-.413-2.688a29.17 29.17 0 0 1-.06-1.528v-.002z"/>');// eslint-disable-next-line
var BIconMusicNote=/*#__PURE__*/makeIcon('MusicNote','<path d="M9 13c0 1.105-1.12 2-2.5 2S4 14.105 4 13s1.12-2 2.5-2 2.5.895 2.5 2z"/><path fill-rule="evenodd" d="M9 3v10H8V3h1z"/><path d="M8 2.82a1 1 0 0 1 .804-.98l3-.6A1 1 0 0 1 13 2.22V4L8 5V2.82z"/>');// eslint-disable-next-line
var BIconMusicNoteBeamed=/*#__PURE__*/makeIcon('MusicNoteBeamed','<path d="M6 13c0 1.105-1.12 2-2.5 2S1 14.105 1 13c0-1.104 1.12-2 2.5-2s2.5.896 2.5 2zm9-2c0 1.105-1.12 2-2.5 2s-2.5-.895-2.5-2 1.12-2 2.5-2 2.5.895 2.5 2z"/><path fill-rule="evenodd" d="M14 11V2h1v9h-1zM6 3v10H5V3h1z"/><path d="M5 2.905a1 1 0 0 1 .9-.995l8-.8a1 1 0 0 1 1.1.995V3L5 4V2.905z"/>');// eslint-disable-next-line
var BIconMusicNoteList=/*#__PURE__*/makeIcon('MusicNoteList','<path d="M12 13c0 1.105-1.12 2-2.5 2S7 14.105 7 13s1.12-2 2.5-2 2.5.895 2.5 2z"/><path fill-rule="evenodd" d="M12 3v10h-1V3h1z"/><path d="M11 2.82a1 1 0 0 1 .804-.98l3-.6A1 1 0 0 1 16 2.22V4l-5 1V2.82z"/><path fill-rule="evenodd" d="M0 11.5a.5.5 0 0 1 .5-.5H4a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 .5 7H8a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 .5 3H8a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconMusicPlayer=/*#__PURE__*/makeIcon('MusicPlayer','<path d="M4 3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V3zm1 0v3h6V3H5zm3 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/><path d="M11 11a3 3 0 1 1-6 0 3 3 0 0 1 6 0zm-3 2a2 2 0 1 0 0-4 2 2 0 0 0 0 4z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H4z"/>');// eslint-disable-next-line
var BIconMusicPlayerFill=/*#__PURE__*/makeIcon('MusicPlayerFill','<path d="M8 12a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm1 2h6a1 1 0 0 1 1 1v2.5a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1zm3 12a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>');// eslint-disable-next-line
var BIconNewspaper=/*#__PURE__*/makeIcon('Newspaper','<path d="M0 2.5A1.5 1.5 0 0 1 1.5 1h11A1.5 1.5 0 0 1 14 2.5v10.528c0 .3-.05.654-.238.972h.738a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 1 1 0v9a1.5 1.5 0 0 1-1.5 1.5H1.497A1.497 1.497 0 0 1 0 13.5v-11zM12 14c.37 0 .654-.211.853-.441.092-.106.147-.279.147-.531V2.5a.5.5 0 0 0-.5-.5h-11a.5.5 0 0 0-.5.5v11c0 .278.223.5.497.5H12z"/><path d="M2 3h10v2H2V3zm0 3h4v3H2V6zm0 4h4v1H2v-1zm0 2h4v1H2v-1zm5-6h2v1H7V6zm3 0h2v1h-2V6zM7 8h2v1H7V8zm3 0h2v1h-2V8zm-3 2h2v1H7v-1zm3 0h2v1h-2v-1zm-3 2h2v1H7v-1zm3 0h2v1h-2v-1z"/>');// eslint-disable-next-line
var BIconNodeMinus=/*#__PURE__*/makeIcon('NodeMinus','<path fill-rule="evenodd" d="M11 4a4 4 0 1 0 0 8 4 4 0 0 0 0-8zM6.025 7.5a5 5 0 1 1 0 1H4A1.5 1.5 0 0 1 2.5 10h-1A1.5 1.5 0 0 1 0 8.5v-1A1.5 1.5 0 0 1 1.5 6h1A1.5 1.5 0 0 1 4 7.5h2.025zM1.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM8 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 8 8z"/>');// eslint-disable-next-line
var BIconNodeMinusFill=/*#__PURE__*/makeIcon('NodeMinusFill','<path fill-rule="evenodd" d="M16 8a5 5 0 0 1-9.975.5H4A1.5 1.5 0 0 1 2.5 10h-1A1.5 1.5 0 0 1 0 8.5v-1A1.5 1.5 0 0 1 1.5 6h1A1.5 1.5 0 0 1 4 7.5h2.025A5 5 0 0 1 16 8zm-2 0a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5A.5.5 0 0 0 14 8z"/>');// eslint-disable-next-line
var BIconNodePlus=/*#__PURE__*/makeIcon('NodePlus','<path fill-rule="evenodd" d="M11 4a4 4 0 1 0 0 8 4 4 0 0 0 0-8zM6.025 7.5a5 5 0 1 1 0 1H4A1.5 1.5 0 0 1 2.5 10h-1A1.5 1.5 0 0 1 0 8.5v-1A1.5 1.5 0 0 1 1.5 6h1A1.5 1.5 0 0 1 4 7.5h2.025zM11 5a.5.5 0 0 1 .5.5v2h2a.5.5 0 0 1 0 1h-2v2a.5.5 0 0 1-1 0v-2h-2a.5.5 0 0 1 0-1h2v-2A.5.5 0 0 1 11 5zM1.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>');// eslint-disable-next-line
var BIconNodePlusFill=/*#__PURE__*/makeIcon('NodePlusFill','<path d="M11 13a5 5 0 1 0-4.975-5.5H4A1.5 1.5 0 0 0 2.5 6h-1A1.5 1.5 0 0 0 0 7.5v1A1.5 1.5 0 0 0 1.5 10h1A1.5 1.5 0 0 0 4 8.5h2.025A5 5 0 0 0 11 13zm.5-7.5v2h2a.5.5 0 0 1 0 1h-2v2a.5.5 0 0 1-1 0v-2h-2a.5.5 0 0 1 0-1h2v-2a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconNut=/*#__PURE__*/makeIcon('Nut','<path d="M11.42 2l3.428 6-3.428 6H4.58L1.152 8 4.58 2h6.84zM4.58 1a1 1 0 0 0-.868.504l-3.429 6a1 1 0 0 0 0 .992l3.429 6A1 1 0 0 0 4.58 15h6.84a1 1 0 0 0 .868-.504l3.428-6a1 1 0 0 0 0-.992l-3.428-6A1 1 0 0 0 11.42 1H4.58z"/><path d="M6.848 5.933a2.5 2.5 0 1 0 2.5 4.33 2.5 2.5 0 0 0-2.5-4.33zM5.067 9.848a3.5 3.5 0 1 1 6.062-3.5 3.5 3.5 0 0 1-6.062 3.5z"/>');// eslint-disable-next-line
var BIconNutFill=/*#__PURE__*/makeIcon('NutFill','<path d="M4.58 1a1 1 0 0 0-.868.504l-3.429 6a1 1 0 0 0 0 .992l3.429 6A1 1 0 0 0 4.58 15h6.84a1 1 0 0 0 .868-.504l3.428-6a1 1 0 0 0 0-.992l-3.428-6A1 1 0 0 0 11.42 1H4.58zm5.018 9.696a3 3 0 1 1-3-5.196 3 3 0 0 1 3 5.196z"/>');// eslint-disable-next-line
var BIconOctagon=/*#__PURE__*/makeIcon('Octagon','<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/>');// eslint-disable-next-line
var BIconOctagonFill=/*#__PURE__*/makeIcon('OctagonFill','<path d="M11.107 0a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146A.5.5 0 0 1 4.893 0h6.214z"/>');// eslint-disable-next-line
var BIconOctagonHalf=/*#__PURE__*/makeIcon('OctagonHalf','<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM8 15h2.9l4.1-4.1V5.1L10.9 1H8v14z"/>');// eslint-disable-next-line
var BIconOption=/*#__PURE__*/makeIcon('Option','<path d="M1 2.5a.5.5 0 0 1 .5-.5h3.797a.5.5 0 0 1 .439.26L11 13h3.5a.5.5 0 0 1 0 1h-3.797a.5.5 0 0 1-.439-.26L5 3H1.5a.5.5 0 0 1-.5-.5zm10 0a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconOutlet=/*#__PURE__*/makeIcon('Outlet','<path d="M3.34 2.994c.275-.338.68-.494 1.074-.494h7.172c.393 0 .798.156 1.074.494.578.708 1.84 2.534 1.84 5.006 0 2.472-1.262 4.297-1.84 5.006-.276.338-.68.494-1.074.494H4.414c-.394 0-.799-.156-1.074-.494C2.762 12.297 1.5 10.472 1.5 8c0-2.472 1.262-4.297 1.84-5.006zm1.074.506a.376.376 0 0 0-.299.126C3.599 4.259 2.5 5.863 2.5 8c0 2.137 1.099 3.74 1.615 4.374.06.073.163.126.3.126h7.17c.137 0 .24-.053.3-.126.516-.633 1.615-2.237 1.615-4.374 0-2.137-1.099-3.74-1.615-4.374a.376.376 0 0 0-.3-.126h-7.17z"/><path d="M6 5.5a.5.5 0 0 1 .5.5v1.5a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm4 0a.5.5 0 0 1 .5.5v1.5a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zM7 10v1h2v-1a1 1 0 0 0-2 0z"/>');// eslint-disable-next-line
var BIconPaperclip=/*#__PURE__*/makeIcon('Paperclip','<path d="M4.5 3a2.5 2.5 0 0 1 5 0v9a1.5 1.5 0 0 1-3 0V5a.5.5 0 0 1 1 0v7a.5.5 0 0 0 1 0V3a1.5 1.5 0 1 0-3 0v9a2.5 2.5 0 0 0 5 0V5a.5.5 0 0 1 1 0v7a3.5 3.5 0 1 1-7 0V3z"/>');// eslint-disable-next-line
var BIconParagraph=/*#__PURE__*/makeIcon('Paragraph','<path d="M10.5 15a.5.5 0 0 1-.5-.5V2H9v12.5a.5.5 0 0 1-1 0V9H7a4 4 0 1 1 0-8h5.5a.5.5 0 0 1 0 1H11v12.5a.5.5 0 0 1-.5.5z"/>');// eslint-disable-next-line
var BIconPatchCheck=/*#__PURE__*/makeIcon('PatchCheck','<path fill-rule="evenodd" d="M10.354 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>');// eslint-disable-next-line
var BIconPatchCheckFill=/*#__PURE__*/makeIcon('PatchCheckFill','<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zm.287 5.984l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconPatchExclamation=/*#__PURE__*/makeIcon('PatchExclamation','<path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>');// eslint-disable-next-line
var BIconPatchExclamationFill=/*#__PURE__*/makeIcon('PatchExclamationFill','<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zM8 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>');// eslint-disable-next-line
var BIconPatchMinus=/*#__PURE__*/makeIcon('PatchMinus','<path fill-rule="evenodd" d="M5.5 8a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>');// eslint-disable-next-line
var BIconPatchMinusFill=/*#__PURE__*/makeIcon('PatchMinusFill','<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zM6 7.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>');// eslint-disable-next-line
var BIconPatchPlus=/*#__PURE__*/makeIcon('PatchPlus','<path fill-rule="evenodd" d="M8 5.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 .5-.5z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>');// eslint-disable-next-line
var BIconPatchPlusFill=/*#__PURE__*/makeIcon('PatchPlusFill','<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zM8.5 6v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconPatchQuestion=/*#__PURE__*/makeIcon('PatchQuestion','<path d="M8.05 9.6c.336 0 .504-.24.554-.627.04-.534.198-.815.847-1.26.673-.475 1.049-1.09 1.049-1.986 0-1.325-.92-2.227-2.262-2.227-1.02 0-1.792.492-2.1 1.29A1.71 1.71 0 0 0 6 5.48c0 .393.203.64.545.64.272 0 .455-.147.564-.51.158-.592.525-.915 1.074-.915.61 0 1.03.446 1.03 1.084 0 .563-.208.885-.822 1.325-.619.433-.926.914-.926 1.64v.111c0 .428.208.745.585.745z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0z"/>');// eslint-disable-next-line
var BIconPatchQuestionFill=/*#__PURE__*/makeIcon('PatchQuestionFill','<path d="M5.933.87a2.89 2.89 0 0 1 4.134 0l.622.638.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636zM7.002 11a1 1 0 1 0 2 0 1 1 0 0 0-2 0zm1.602-2.027c.04-.534.198-.815.846-1.26.674-.475 1.05-1.09 1.05-1.986 0-1.325-.92-2.227-2.262-2.227-1.02 0-1.792.492-2.1 1.29A1.71 1.71 0 0 0 6 5.48c0 .393.203.64.545.64.272 0 .455-.147.564-.51.158-.592.525-.915 1.074-.915.61 0 1.03.446 1.03 1.084 0 .563-.208.885-.822 1.325-.619.433-.926.914-.926 1.64v.111c0 .428.208.745.585.745.336 0 .504-.24.554-.627z"/>');// eslint-disable-next-line
var BIconPause=/*#__PURE__*/makeIcon('Pause','<path d="M6 3.5a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5zm4 0a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconPauseBtn=/*#__PURE__*/makeIcon('PauseBtn','<path d="M6.25 5C5.56 5 5 5.56 5 6.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C7.5 5.56 6.94 5 6.25 5zm3.5 0c-.69 0-1.25.56-1.25 1.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C11 5.56 10.44 5 9.75 5z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconPauseBtnFill=/*#__PURE__*/makeIcon('PauseBtnFill','<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.25-7C5.56 5 5 5.56 5 6.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C7.5 5.56 6.94 5 6.25 5zm3.5 0c-.69 0-1.25.56-1.25 1.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C11 5.56 10.44 5 9.75 5z"/>');// eslint-disable-next-line
var BIconPauseCircle=/*#__PURE__*/makeIcon('PauseCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M5 6.25a1.25 1.25 0 1 1 2.5 0v3.5a1.25 1.25 0 1 1-2.5 0v-3.5zm3.5 0a1.25 1.25 0 1 1 2.5 0v3.5a1.25 1.25 0 1 1-2.5 0v-3.5z"/>');// eslint-disable-next-line
var BIconPauseCircleFill=/*#__PURE__*/makeIcon('PauseCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.25 5C5.56 5 5 5.56 5 6.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C7.5 5.56 6.94 5 6.25 5zm3.5 0c-.69 0-1.25.56-1.25 1.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C11 5.56 10.44 5 9.75 5z"/>');// eslint-disable-next-line
var BIconPauseFill=/*#__PURE__*/makeIcon('PauseFill','<path d="M5.5 3.5A1.5 1.5 0 0 1 7 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5zm5 0A1.5 1.5 0 0 1 12 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5z"/>');// eslint-disable-next-line
var BIconPeace=/*#__PURE__*/makeIcon('Peace','<path d="M7.5 1.018a7 7 0 0 0-4.79 11.566L7.5 7.793V1.018zm1 0v6.775l4.79 4.79A7 7 0 0 0 8.5 1.018zm4.084 12.273L8.5 9.207v5.775a6.97 6.97 0 0 0 4.084-1.691zM7.5 14.982V9.207l-4.084 4.084A6.97 6.97 0 0 0 7.5 14.982zM0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8z"/>');// eslint-disable-next-line
var BIconPeaceFill=/*#__PURE__*/makeIcon('PeaceFill','<path d="M14 13.292A8 8 0 0 0 8.5.015v7.778l5.5 5.5zm-.708.708L8.5 9.206v6.778a7.967 7.967 0 0 0 4.792-1.986zM7.5 15.985V9.207L2.708 14A7.967 7.967 0 0 0 7.5 15.985zM2 13.292A8 8 0 0 1 7.5.015v7.778l-5.5 5.5z"/>');// eslint-disable-next-line
var BIconPen=/*#__PURE__*/makeIcon('Pen','<path d="M13.498.795l.149-.149a1.207 1.207 0 1 1 1.707 1.708l-.149.148a1.5 1.5 0 0 1-.059 2.059L4.854 14.854a.5.5 0 0 1-.233.131l-4 1a.5.5 0 0 1-.606-.606l1-4a.5.5 0 0 1 .131-.232l9.642-9.642a.5.5 0 0 0-.642.056L6.854 4.854a.5.5 0 1 1-.708-.708L9.44.854A1.5 1.5 0 0 1 11.5.796a1.5 1.5 0 0 1 1.998-.001zm-.644.766a.5.5 0 0 0-.707 0L1.95 11.756l-.764 3.057 3.057-.764L14.44 3.854a.5.5 0 0 0 0-.708l-1.585-1.585z"/>');// eslint-disable-next-line
var BIconPenFill=/*#__PURE__*/makeIcon('PenFill','<path d="M13.498.795l.149-.149a1.207 1.207 0 1 1 1.707 1.708l-.149.148a1.5 1.5 0 0 1-.059 2.059L4.854 14.854a.5.5 0 0 1-.233.131l-4 1a.5.5 0 0 1-.606-.606l1-4a.5.5 0 0 1 .131-.232l9.642-9.642a.5.5 0 0 0-.642.056L6.854 4.854a.5.5 0 1 1-.708-.708L9.44.854A1.5 1.5 0 0 1 11.5.796a1.5 1.5 0 0 1 1.998-.001z"/>');// eslint-disable-next-line
var BIconPencil=/*#__PURE__*/makeIcon('Pencil','<path d="M12.146.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708l-10 10a.5.5 0 0 1-.168.11l-5 2a.5.5 0 0 1-.65-.65l2-5a.5.5 0 0 1 .11-.168l10-10zM11.207 2.5L13.5 4.793 14.793 3.5 12.5 1.207 11.207 2.5zm1.586 3L10.5 3.207 4 9.707V10h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.293l6.5-6.5zm-9.761 5.175l-.106.106-1.528 3.821 3.821-1.528.106-.106A.5.5 0 0 1 5 12.5V12h-.5a.5.5 0 0 1-.5-.5V11h-.5a.5.5 0 0 1-.468-.325z"/>');// eslint-disable-next-line
var BIconPencilFill=/*#__PURE__*/makeIcon('PencilFill','<path d="M12.854.146a.5.5 0 0 0-.707 0L10.5 1.793 14.207 5.5l1.647-1.646a.5.5 0 0 0 0-.708l-3-3zm.646 6.061L9.793 2.5 3.293 9H3.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.207l6.5-6.5zm-7.468 7.468A.5.5 0 0 1 6 13.5V13h-.5a.5.5 0 0 1-.5-.5V12h-.5a.5.5 0 0 1-.5-.5V11h-.5a.5.5 0 0 1-.5-.5V10h-.5a.499.499 0 0 1-.175-.032l-.179.178a.5.5 0 0 0-.11.168l-2 5a.5.5 0 0 0 .65.65l5-2a.5.5 0 0 0 .168-.11l.178-.178z"/>');// eslint-disable-next-line
var BIconPencilSquare=/*#__PURE__*/makeIcon('PencilSquare','<path d="M15.502 1.94a.5.5 0 0 1 0 .706L14.459 3.69l-2-2L13.502.646a.5.5 0 0 1 .707 0l1.293 1.293zm-1.75 2.456l-2-2L4.939 9.21a.5.5 0 0 0-.121.196l-.805 2.414a.25.25 0 0 0 .316.316l2.414-.805a.5.5 0 0 0 .196-.12l6.813-6.814z"/><path fill-rule="evenodd" d="M1 13.5A1.5 1.5 0 0 0 2.5 15h11a1.5 1.5 0 0 0 1.5-1.5v-6a.5.5 0 0 0-1 0v6a.5.5 0 0 1-.5.5h-11a.5.5 0 0 1-.5-.5v-11a.5.5 0 0 1 .5-.5H9a.5.5 0 0 0 0-1H2.5A1.5 1.5 0 0 0 1 2.5v11z"/>');// eslint-disable-next-line
var BIconPentagon=/*#__PURE__*/makeIcon('Pentagon','<path d="M8 1.288l6.842 5.56L12.267 15H3.733L1.158 6.847 8 1.288zM16 6.5L8 0 0 6.5 3 16h10l3-9.5z"/>');// eslint-disable-next-line
var BIconPentagonFill=/*#__PURE__*/makeIcon('PentagonFill','<path d="M8 0l8 6.5-3 9.5H3L0 6.5 8 0z"/>');// eslint-disable-next-line
var BIconPentagonHalf=/*#__PURE__*/makeIcon('PentagonHalf','<path d="M8 1.288l6.842 5.56L12.267 15H8V1.288zM16 6.5L8 0 0 6.5 3 16h10l3-9.5z"/>');// eslint-disable-next-line
var BIconPeople=/*#__PURE__*/makeIcon('People','<path d="M15 14s1 0 1-1-1-4-5-4-5 3-5 4 1 1 1 1h8zm-7.978-1A.261.261 0 0 1 7 12.996c.001-.264.167-1.03.76-1.72C8.312 10.629 9.282 10 11 10c1.717 0 2.687.63 3.24 1.276.593.69.758 1.457.76 1.72l-.008.002a.274.274 0 0 1-.014.002H7.022zM11 7a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm3-2a3 3 0 1 1-6 0 3 3 0 0 1 6 0zM6.936 9.28a5.88 5.88 0 0 0-1.23-.247A7.35 7.35 0 0 0 5 9c-4 0-5 3-5 4 0 .667.333 1 1 1h4.216A2.238 2.238 0 0 1 5 13c0-1.01.377-2.042 1.09-2.904.243-.294.526-.569.846-.816zM4.92 10A5.493 5.493 0 0 0 4 13H1c0-.26.164-1.03.76-1.724.545-.636 1.492-1.256 3.16-1.275zM1.5 5.5a3 3 0 1 1 6 0 3 3 0 0 1-6 0zm3-2a2 2 0 1 0 0 4 2 2 0 0 0 0-4z"/>');// eslint-disable-next-line
var BIconPeopleFill=/*#__PURE__*/makeIcon('PeopleFill','<path d="M7 14s-1 0-1-1 1-4 5-4 5 3 5 4-1 1-1 1H7zm4-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path fill-rule="evenodd" d="M5.216 14A2.238 2.238 0 0 1 5 13c0-1.355.68-2.75 1.936-3.72A6.325 6.325 0 0 0 5 9c-4 0-5 3-5 4s1 1 1 1h4.216z"/><path d="M4.5 8a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5z"/>');// eslint-disable-next-line
var BIconPercent=/*#__PURE__*/makeIcon('Percent','<path d="M13.442 2.558a.625.625 0 0 1 0 .884l-10 10a.625.625 0 1 1-.884-.884l10-10a.625.625 0 0 1 .884 0zM4.5 6a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm0 1a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5zm7 6a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm0 1a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5z"/>');// eslint-disable-next-line
var BIconPerson=/*#__PURE__*/makeIcon('Person','<path d="M8 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H3s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C11.516 10.68 10.289 10 8 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/>');// eslint-disable-next-line
var BIconPersonBadge=/*#__PURE__*/makeIcon('PersonBadge','<path d="M6.5 2a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M4.5 0A2.5 2.5 0 0 0 2 2.5V14a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2.5A2.5 2.5 0 0 0 11.5 0h-7zM3 2.5A1.5 1.5 0 0 1 4.5 1h7A1.5 1.5 0 0 1 13 2.5v10.795a4.2 4.2 0 0 0-.776-.492C11.392 12.387 10.063 12 8 12s-3.392.387-4.224.803a4.2 4.2 0 0 0-.776.492V2.5z"/>');// eslint-disable-next-line
var BIconPersonBadgeFill=/*#__PURE__*/makeIcon('PersonBadgeFill','<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm4.5 0a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zM8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm5 2.755C12.146 12.825 10.623 12 8 12s-4.146.826-5 1.755V14a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1v-.245z"/>');// eslint-disable-next-line
var BIconPersonBoundingBox=/*#__PURE__*/makeIcon('PersonBoundingBox','<path d="M1.5 1a.5.5 0 0 0-.5.5v3a.5.5 0 0 1-1 0v-3A1.5 1.5 0 0 1 1.5 0h3a.5.5 0 0 1 0 1h-3zM11 .5a.5.5 0 0 1 .5-.5h3A1.5 1.5 0 0 1 16 1.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 1-.5-.5zM.5 11a.5.5 0 0 1 .5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 1 0 1h-3A1.5 1.5 0 0 1 0 14.5v-3a.5.5 0 0 1 .5-.5zm15 0a.5.5 0 0 1 .5.5v3a1.5 1.5 0 0 1-1.5 1.5h-3a.5.5 0 0 1 0-1h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 1 .5-.5z"/><path d="M3 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H3zm8-9a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/>');// eslint-disable-next-line
var BIconPersonCheck=/*#__PURE__*/makeIcon('PersonCheck','<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M15.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L12.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconPersonCheckFill=/*#__PURE__*/makeIcon('PersonCheckFill','<path fill-rule="evenodd" d="M15.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L12.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>');// eslint-disable-next-line
var BIconPersonCircle=/*#__PURE__*/makeIcon('PersonCircle','<path d="M13.468 12.37C12.758 11.226 11.195 10 8 10s-4.757 1.225-5.468 2.37A6.987 6.987 0 0 0 8 15a6.987 6.987 0 0 0 5.468-2.63z"/><path fill-rule="evenodd" d="M8 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path fill-rule="evenodd" d="M8 1a7 7 0 1 0 0 14A7 7 0 0 0 8 1zM0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8z"/>');// eslint-disable-next-line
var BIconPersonDash=/*#__PURE__*/makeIcon('PersonDash','<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M11 7.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconPersonDashFill=/*#__PURE__*/makeIcon('PersonDashFill','<path fill-rule="evenodd" d="M11 7.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/><path d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>');// eslint-disable-next-line
var BIconPersonFill=/*#__PURE__*/makeIcon('PersonFill','<path d="M3 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H3zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>');// eslint-disable-next-line
var BIconPersonLinesFill=/*#__PURE__*/makeIcon('PersonLinesFill','<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm-5 6s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zM11 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1h-4zm2 3a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1h-2zm0 3a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1h-2z"/>');// eslint-disable-next-line
var BIconPersonPlus=/*#__PURE__*/makeIcon('PersonPlus','<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M13.5 5a.5.5 0 0 1 .5.5V7h1.5a.5.5 0 0 1 0 1H14v1.5a.5.5 0 0 1-1 0V8h-1.5a.5.5 0 0 1 0-1H13V5.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconPersonPlusFill=/*#__PURE__*/makeIcon('PersonPlusFill','<path d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path fill-rule="evenodd" d="M13.5 5a.5.5 0 0 1 .5.5V7h1.5a.5.5 0 0 1 0 1H14v1.5a.5.5 0 0 1-1 0V8h-1.5a.5.5 0 0 1 0-1H13V5.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconPersonSquare=/*#__PURE__*/makeIcon('PersonSquare','<path d="M11 6a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1v-1c0-1-1-4-6-4s-6 3-6 4v1a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12z"/>');// eslint-disable-next-line
var BIconPersonX=/*#__PURE__*/makeIcon('PersonX','<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M12.146 5.146a.5.5 0 0 1 .708 0L14 6.293l1.146-1.147a.5.5 0 0 1 .708.708L14.707 7l1.147 1.146a.5.5 0 0 1-.708.708L14 7.707l-1.146 1.147a.5.5 0 0 1-.708-.708L13.293 7l-1.147-1.146a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconPersonXFill=/*#__PURE__*/makeIcon('PersonXFill','<path fill-rule="evenodd" d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm6.146-2.854a.5.5 0 0 1 .708 0L14 6.293l1.146-1.147a.5.5 0 0 1 .708.708L14.707 7l1.147 1.146a.5.5 0 0 1-.708.708L14 7.707l-1.146 1.147a.5.5 0 0 1-.708-.708L13.293 7l-1.147-1.146a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconPhone=/*#__PURE__*/makeIcon('Phone','<path d="M11 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h6zM5 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H5z"/><path d="M8 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconPhoneFill=/*#__PURE__*/makeIcon('PhoneFill','<path d="M3 2a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V2zm6 11a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>');// eslint-disable-next-line
var BIconPhoneLandscape=/*#__PURE__*/makeIcon('PhoneLandscape','<path d="M1 4.5a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v6a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-6zm-1 6a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-6a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v6z"/><path d="M14 7.5a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>');// eslint-disable-next-line
var BIconPhoneLandscapeFill=/*#__PURE__*/makeIcon('PhoneLandscapeFill','<path d="M2 12.5a2 2 0 0 1-2-2v-6a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H2zm11-6a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>');// eslint-disable-next-line
var BIconPhoneVibrate=/*#__PURE__*/makeIcon('PhoneVibrate','<path d="M10 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h4zM6 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H6z"/><path d="M8 12a1 1 0 1 0 0-2 1 1 0 0 0 0 2zM1.599 4.058a.5.5 0 0 1 .208.676A6.967 6.967 0 0 0 1 8c0 1.18.292 2.292.807 3.266a.5.5 0 0 1-.884.468A7.968 7.968 0 0 1 0 8c0-1.347.334-2.619.923-3.734a.5.5 0 0 1 .676-.208zm12.802 0a.5.5 0 0 1 .676.208A7.967 7.967 0 0 1 16 8a7.967 7.967 0 0 1-.923 3.734.5.5 0 0 1-.884-.468A6.967 6.967 0 0 0 15 8c0-1.18-.292-2.292-.807-3.266a.5.5 0 0 1 .208-.676zM3.057 5.534a.5.5 0 0 1 .284.648A4.986 4.986 0 0 0 3 8c0 .642.12 1.255.34 1.818a.5.5 0 1 1-.93.364A5.986 5.986 0 0 1 2 8c0-.769.145-1.505.41-2.182a.5.5 0 0 1 .647-.284zm9.886 0a.5.5 0 0 1 .648.284C13.855 6.495 14 7.231 14 8c0 .769-.145 1.505-.41 2.182a.5.5 0 0 1-.93-.364C12.88 9.255 13 8.642 13 8c0-.642-.12-1.255-.34-1.818a.5.5 0 0 1 .283-.648z"/>');// eslint-disable-next-line
var BIconPieChart=/*#__PURE__*/makeIcon('PieChart','<path d="M7.5 1.018a7 7 0 0 0-4.79 11.566L7.5 7.793V1.018zm1 0V7.5h6.482A7.001 7.001 0 0 0 8.5 1.018zM14.982 8.5H8.207l-4.79 4.79A7 7 0 0 0 14.982 8.5zM0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8z"/>');// eslint-disable-next-line
var BIconPieChartFill=/*#__PURE__*/makeIcon('PieChartFill','<path d="M15.985 8.5H8.207l-5.5 5.5a8 8 0 0 0 13.277-5.5zM2 13.292A8 8 0 0 1 7.5.015v7.778l-5.5 5.5zM8.5.015V7.5h7.485A8.001 8.001 0 0 0 8.5.015z"/>');// eslint-disable-next-line
var BIconPip=/*#__PURE__*/makeIcon('Pip','<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5v-9zM1.5 3a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-13z"/><path d="M8 8.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-3z"/>');// eslint-disable-next-line
var BIconPipFill=/*#__PURE__*/makeIcon('PipFill','<path d="M1.5 2A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13zm7 6h5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-3a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconPlay=/*#__PURE__*/makeIcon('Play','<path d="M10.804 8L5 4.633v6.734L10.804 8zm.792-.696a.802.802 0 0 1 0 1.392l-6.363 3.692C4.713 12.69 4 12.345 4 11.692V4.308c0-.653.713-.998 1.233-.696l6.363 3.692z"/>');// eslint-disable-next-line
var BIconPlayBtn=/*#__PURE__*/makeIcon('PlayBtn','<path d="M6.79 5.093A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407l3.5-2.5a.5.5 0 0 0 0-.814l-3.5-2.5z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconPlayBtnFill=/*#__PURE__*/makeIcon('PlayBtnFill','<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.79-6.907A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407l3.5-2.5a.5.5 0 0 0 0-.814l-3.5-2.5z"/>');// eslint-disable-next-line
var BIconPlayCircle=/*#__PURE__*/makeIcon('PlayCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M6.271 5.055a.5.5 0 0 1 .52.038l3.5 2.5a.5.5 0 0 1 0 .814l-3.5 2.5A.5.5 0 0 1 6 10.5v-5a.5.5 0 0 1 .271-.445z"/>');// eslint-disable-next-line
var BIconPlayCircleFill=/*#__PURE__*/makeIcon('PlayCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.79 5.093A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407l3.5-2.5a.5.5 0 0 0 0-.814l-3.5-2.5z"/>');// eslint-disable-next-line
var BIconPlayFill=/*#__PURE__*/makeIcon('PlayFill','<path d="M11.596 8.697l-6.363 3.692c-.54.313-1.233-.066-1.233-.697V4.308c0-.63.692-1.01 1.233-.696l6.363 3.692a.802.802 0 0 1 0 1.393z"/>');// eslint-disable-next-line
var BIconPlug=/*#__PURE__*/makeIcon('Plug','<path d="M6 0a.5.5 0 0 1 .5.5V3h3V.5a.5.5 0 0 1 1 0V3h1a.5.5 0 0 1 .5.5v3A3.5 3.5 0 0 1 8.5 10c-.002.434-.01.845-.04 1.22-.041.514-.126 1.003-.317 1.424a2.083 2.083 0 0 1-.97 1.028C6.725 13.9 6.169 14 5.5 14c-.998 0-1.61.33-1.974.718A1.922 1.922 0 0 0 3 16H2c0-.616.232-1.367.797-1.968C3.374 13.42 4.261 13 5.5 13c.581 0 .962-.088 1.218-.219.241-.123.4-.3.514-.55.121-.266.193-.621.23-1.09.027-.34.035-.718.037-1.141A3.5 3.5 0 0 1 4 6.5v-3a.5.5 0 0 1 .5-.5h1V.5A.5.5 0 0 1 6 0zM5 4v2.5A2.5 2.5 0 0 0 7.5 9h1A2.5 2.5 0 0 0 11 6.5V4H5z"/>');// eslint-disable-next-line
var BIconPlugFill=/*#__PURE__*/makeIcon('PlugFill','<path d="M6 0a.5.5 0 0 1 .5.5V3h3V.5a.5.5 0 0 1 1 0V3h1a.5.5 0 0 1 .5.5v3A3.5 3.5 0 0 1 8.5 10c-.002.434-.01.845-.04 1.22-.041.514-.126 1.003-.317 1.424a2.083 2.083 0 0 1-.97 1.028C6.725 13.9 6.169 14 5.5 14c-.998 0-1.61.33-1.974.718A1.922 1.922 0 0 0 3 16H2c0-.616.232-1.367.797-1.968C3.374 13.42 4.261 13 5.5 13c.581 0 .962-.088 1.218-.219.241-.123.4-.3.514-.55.121-.266.193-.621.23-1.09.027-.34.035-.718.037-1.141A3.5 3.5 0 0 1 4 6.5v-3a.5.5 0 0 1 .5-.5h1V.5A.5.5 0 0 1 6 0z"/>');// eslint-disable-next-line
var BIconPlus=/*#__PURE__*/makeIcon('Plus','<path d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"/>');// eslint-disable-next-line
var BIconPlusCircle=/*#__PURE__*/makeIcon('PlusCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"/>');// eslint-disable-next-line
var BIconPlusCircleFill=/*#__PURE__*/makeIcon('PlusCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v3h-3a.5.5 0 0 0 0 1h3v3a.5.5 0 0 0 1 0v-3h3a.5.5 0 0 0 0-1h-3v-3z"/>');// eslint-disable-next-line
var BIconPlusSquare=/*#__PURE__*/makeIcon('PlusSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"/>');// eslint-disable-next-line
var BIconPlusSquareFill=/*#__PURE__*/makeIcon('PlusSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm6.5 4.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconPower=/*#__PURE__*/makeIcon('Power','<path d="M7.5 1v7h1V1h-1z"/><path d="M3 8.812a4.999 4.999 0 0 1 2.578-4.375l-.485-.874A6 6 0 1 0 11 3.616l-.501.865A5 5 0 1 1 3 8.812z"/>');// eslint-disable-next-line
var BIconPrinter=/*#__PURE__*/makeIcon('Printer','<path d="M2.5 8a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/><path d="M5 1a2 2 0 0 0-2 2v2H2a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h1v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-1h1a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-1V3a2 2 0 0 0-2-2H5zM4 3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v2H4V3zm1 5a2 2 0 0 0-2 2v1H2a1 1 0 0 1-1-1V7a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-1v-1a2 2 0 0 0-2-2H5zm7 2v3a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1v-3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1z"/>');// eslint-disable-next-line
var BIconPrinterFill=/*#__PURE__*/makeIcon('PrinterFill','<path d="M5 1a2 2 0 0 0-2 2v1h10V3a2 2 0 0 0-2-2H5zm6 8H5a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1z"/><path d="M0 7a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2h-1v-2a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2H2a2 2 0 0 1-2-2V7zm2.5 1a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/>');// eslint-disable-next-line
var BIconPuzzle=/*#__PURE__*/makeIcon('Puzzle','<path d="M3.112 3.645A1.5 1.5 0 0 1 4.605 2H7a.5.5 0 0 1 .5.5v.382c0 .696-.497 1.182-.872 1.469a.459.459 0 0 0-.115.118.113.113 0 0 0-.012.025L6.5 4.5v.003l.003.01c.004.01.014.028.036.053a.86.86 0 0 0 .27.194C7.09 4.9 7.51 5 8 5c.492 0 .912-.1 1.19-.24a.86.86 0 0 0 .271-.194.213.213 0 0 0 .039-.063v-.009a.112.112 0 0 0-.012-.025.459.459 0 0 0-.115-.118c-.375-.287-.872-.773-.872-1.469V2.5A.5.5 0 0 1 9 2h2.395a1.5 1.5 0 0 1 1.493 1.645L12.645 6.5h.237c.195 0 .42-.147.675-.48.21-.274.528-.52.943-.52.568 0 .947.447 1.154.862C15.877 6.807 16 7.387 16 8s-.123 1.193-.346 1.638c-.207.415-.586.862-1.154.862-.415 0-.733-.246-.943-.52-.255-.333-.48-.48-.675-.48h-.237l.243 2.855A1.5 1.5 0 0 1 11.395 14H9a.5.5 0 0 1-.5-.5v-.382c0-.696.497-1.182.872-1.469a.459.459 0 0 0 .115-.118.113.113 0 0 0 .012-.025L9.5 11.5v-.003a.214.214 0 0 0-.039-.064.859.859 0 0 0-.27-.193C8.91 11.1 8.49 11 8 11c-.491 0-.912.1-1.19.24a.859.859 0 0 0-.271.194.214.214 0 0 0-.039.063v.003l.001.006a.113.113 0 0 0 .012.025c.016.027.05.068.115.118.375.287.872.773.872 1.469v.382a.5.5 0 0 1-.5.5H4.605a1.5 1.5 0 0 1-1.493-1.645L3.356 9.5h-.238c-.195 0-.42.147-.675.48-.21.274-.528.52-.943.52-.568 0-.947-.447-1.154-.862C.123 9.193 0 8.613 0 8s.123-1.193.346-1.638C.553 5.947.932 5.5 1.5 5.5c.415 0 .733.246.943.52.255.333.48.48.675.48h.238l-.244-2.855zM4.605 3a.5.5 0 0 0-.498.55l.001.007.29 3.4A.5.5 0 0 1 3.9 7.5h-.782c-.696 0-1.182-.497-1.469-.872a.459.459 0 0 0-.118-.115.112.112 0 0 0-.025-.012L1.5 6.5h-.003a.213.213 0 0 0-.064.039.86.86 0 0 0-.193.27C1.1 7.09 1 7.51 1 8c0 .491.1.912.24 1.19.07.14.14.225.194.271a.213.213 0 0 0 .063.039H1.5l.006-.001a.112.112 0 0 0 .025-.012.459.459 0 0 0 .118-.115c.287-.375.773-.872 1.469-.872H3.9a.5.5 0 0 1 .498.542l-.29 3.408a.5.5 0 0 0 .497.55h1.878c-.048-.166-.195-.352-.463-.557-.274-.21-.52-.528-.52-.943 0-.568.447-.947.862-1.154C6.807 10.123 7.387 10 8 10s1.193.123 1.638.346c.415.207.862.586.862 1.154 0 .415-.246.733-.52.943-.268.205-.415.39-.463.557h1.878a.5.5 0 0 0 .498-.55l-.001-.007-.29-3.4A.5.5 0 0 1 12.1 8.5h.782c.696 0 1.182.497 1.469.872.05.065.091.099.118.115.013.008.021.01.025.012a.02.02 0 0 0 .006.001h.003a.214.214 0 0 0 .064-.039.86.86 0 0 0 .193-.27c.14-.28.24-.7.24-1.191 0-.492-.1-.912-.24-1.19a.86.86 0 0 0-.194-.271.215.215 0 0 0-.063-.039H14.5l-.006.001a.113.113 0 0 0-.025.012.459.459 0 0 0-.118.115c-.287.375-.773.872-1.469.872H12.1a.5.5 0 0 1-.498-.543l.29-3.407a.5.5 0 0 0-.497-.55H9.517c.048.166.195.352.463.557.274.21.52.528.52.943 0 .568-.447.947-.862 1.154C9.193 5.877 8.613 6 8 6s-1.193-.123-1.638-.346C5.947 5.447 5.5 5.068 5.5 4.5c0-.415.246-.733.52-.943.268-.205.415-.39.463-.557H4.605z"/>');// eslint-disable-next-line
var BIconPuzzleFill=/*#__PURE__*/makeIcon('PuzzleFill','<path d="M3.112 3.645A1.5 1.5 0 0 1 4.605 2H7a.5.5 0 0 1 .5.5v.382c0 .696-.497 1.182-.872 1.469a.459.459 0 0 0-.115.118.113.113 0 0 0-.012.025L6.5 4.5v.003l.003.01c.004.01.014.028.036.053a.86.86 0 0 0 .27.194C7.09 4.9 7.51 5 8 5c.492 0 .912-.1 1.19-.24a.86.86 0 0 0 .271-.194.213.213 0 0 0 .036-.054l.003-.01v-.008a.112.112 0 0 0-.012-.025.459.459 0 0 0-.115-.118c-.375-.287-.872-.773-.872-1.469V2.5A.5.5 0 0 1 9 2h2.395a1.5 1.5 0 0 1 1.493 1.645L12.645 6.5h.237c.195 0 .42-.147.675-.48.21-.274.528-.52.943-.52.568 0 .947.447 1.154.862C15.877 6.807 16 7.387 16 8s-.123 1.193-.346 1.638c-.207.415-.586.862-1.154.862-.415 0-.733-.246-.943-.52-.255-.333-.48-.48-.675-.48h-.237l.243 2.855A1.5 1.5 0 0 1 11.395 14H9a.5.5 0 0 1-.5-.5v-.382c0-.696.497-1.182.872-1.469a.459.459 0 0 0 .115-.118.113.113 0 0 0 .012-.025L9.5 11.5v-.003l-.003-.01a.214.214 0 0 0-.036-.053.859.859 0 0 0-.27-.194C8.91 11.1 8.49 11 8 11c-.491 0-.912.1-1.19.24a.859.859 0 0 0-.271.194.214.214 0 0 0-.036.054l-.003.01v.002l.001.006a.113.113 0 0 0 .012.025c.016.027.05.068.115.118.375.287.872.773.872 1.469v.382a.5.5 0 0 1-.5.5H4.605a1.5 1.5 0 0 1-1.493-1.645L3.356 9.5h-.238c-.195 0-.42.147-.675.48-.21.274-.528.52-.943.52-.568 0-.947-.447-1.154-.862C.123 9.193 0 8.613 0 8s.123-1.193.346-1.638C.553 5.947.932 5.5 1.5 5.5c.415 0 .733.246.943.52.255.333.48.48.675.48h.238l-.244-2.855z"/>');// eslint-disable-next-line
var BIconQuestion=/*#__PURE__*/makeIcon('Question','<path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>');// eslint-disable-next-line
var BIconQuestionCircle=/*#__PURE__*/makeIcon('QuestionCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>');// eslint-disable-next-line
var BIconQuestionCircleFill=/*#__PURE__*/makeIcon('QuestionCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.496 6.033h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286a.237.237 0 0 0 .241.247zm2.325 6.443c.61 0 1.029-.394 1.029-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94 0 .533.425.927 1.01.927z"/>');// eslint-disable-next-line
var BIconQuestionDiamond=/*#__PURE__*/makeIcon('QuestionDiamond','<path d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435zm1.4.7a.495.495 0 0 0-.7 0L1.134 7.65a.495.495 0 0 0 0 .7l6.516 6.516a.495.495 0 0 0 .7 0l6.516-6.516a.495.495 0 0 0 0-.7L8.35 1.134z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>');// eslint-disable-next-line
var BIconQuestionDiamondFill=/*#__PURE__*/makeIcon('QuestionDiamondFill','<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L.436 6.95c-.58.58-.58 1.519 0 2.098l6.516 6.516c.58.58 1.519.58 2.098 0l6.516-6.516c.58-.58.58-1.519 0-2.098L9.05.435zM5.495 6.033a.237.237 0 0 1-.24-.247C5.35 4.091 6.737 3.5 8.005 3.5c1.396 0 2.672.73 2.672 2.24 0 1.08-.635 1.594-1.244 2.057-.737.559-1.01.768-1.01 1.486v.105a.25.25 0 0 1-.25.25h-.81a.25.25 0 0 1-.25-.246l-.004-.217c-.038-.927.495-1.498 1.168-1.987.59-.444.965-.736.965-1.371 0-.825-.628-1.168-1.314-1.168-.803 0-1.253.478-1.342 1.134-.018.137-.128.25-.266.25h-.825zm2.325 6.443c-.584 0-1.009-.394-1.009-.927 0-.552.425-.94 1.01-.94.609 0 1.028.388 1.028.94 0 .533-.42.927-1.029.927z"/>');// eslint-disable-next-line
var BIconQuestionOctagon=/*#__PURE__*/makeIcon('QuestionOctagon','<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>');// eslint-disable-next-line
var BIconQuestionOctagonFill=/*#__PURE__*/makeIcon('QuestionOctagonFill','<path d="M11.46.146A.5.5 0 0 0 11.107 0H4.893a.5.5 0 0 0-.353.146L.146 4.54A.5.5 0 0 0 0 4.893v6.214a.5.5 0 0 0 .146.353l4.394 4.394a.5.5 0 0 0 .353.146h6.214a.5.5 0 0 0 .353-.146l4.394-4.394a.5.5 0 0 0 .146-.353V4.893a.5.5 0 0 0-.146-.353L11.46.146zM5.496 6.033a.237.237 0 0 1-.24-.247C5.35 4.091 6.737 3.5 8.005 3.5c1.396 0 2.672.73 2.672 2.24 0 1.08-.635 1.594-1.244 2.057-.737.559-1.01.768-1.01 1.486v.105a.25.25 0 0 1-.25.25h-.81a.25.25 0 0 1-.25-.246l-.004-.217c-.038-.927.495-1.498 1.168-1.987.59-.444.965-.736.965-1.371 0-.825-.628-1.168-1.314-1.168-.803 0-1.253.478-1.342 1.134-.018.137-.128.25-.266.25h-.825zm2.325 6.443c-.584 0-1.009-.394-1.009-.927 0-.552.425-.94 1.01-.94.609 0 1.028.388 1.028.94 0 .533-.42.927-1.029.927z"/>');// eslint-disable-next-line
var BIconQuestionSquare=/*#__PURE__*/makeIcon('QuestionSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>');// eslint-disable-next-line
var BIconQuestionSquareFill=/*#__PURE__*/makeIcon('QuestionSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm3.496 6.033a.237.237 0 0 1-.24-.247C5.35 4.091 6.737 3.5 8.005 3.5c1.396 0 2.672.73 2.672 2.24 0 1.08-.635 1.594-1.244 2.057-.737.559-1.01.768-1.01 1.486v.105a.25.25 0 0 1-.25.25h-.81a.25.25 0 0 1-.25-.246l-.004-.217c-.038-.927.495-1.498 1.168-1.987.59-.444.965-.736.965-1.371 0-.825-.628-1.168-1.314-1.168-.803 0-1.253.478-1.342 1.134-.018.137-.128.25-.266.25h-.825zm2.325 6.443c-.584 0-1.009-.394-1.009-.927 0-.552.425-.94 1.01-.94.609 0 1.028.388 1.028.94 0 .533-.42.927-1.029.927z"/>');// eslint-disable-next-line
var BIconReceipt=/*#__PURE__*/makeIcon('Receipt','<path d="M1.92.506a.5.5 0 0 1 .434.14L3 1.293l.646-.647a.5.5 0 0 1 .708 0L5 1.293l.646-.647a.5.5 0 0 1 .708 0L7 1.293l.646-.647a.5.5 0 0 1 .708 0L9 1.293l.646-.647a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .801.13l.5 1A.5.5 0 0 1 15 2v12a.5.5 0 0 1-.053.224l-.5 1a.5.5 0 0 1-.8.13L13 14.707l-.646.647a.5.5 0 0 1-.708 0L11 14.707l-.646.647a.5.5 0 0 1-.708 0L9 14.707l-.646.647a.5.5 0 0 1-.708 0L7 14.707l-.646.647a.5.5 0 0 1-.708 0L5 14.707l-.646.647a.5.5 0 0 1-.708 0L3 14.707l-.646.647a.5.5 0 0 1-.801-.13l-.5-1A.5.5 0 0 1 1 14V2a.5.5 0 0 1 .053-.224l.5-1a.5.5 0 0 1 .367-.27zm.217 1.338L2 2.118v11.764l.137.274.51-.51a.5.5 0 0 1 .707 0l.646.647.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.509.509.137-.274V2.118l-.137-.274-.51.51a.5.5 0 0 1-.707 0L12 1.707l-.646.647a.5.5 0 0 1-.708 0L10 1.707l-.646.647a.5.5 0 0 1-.708 0L8 1.707l-.646.647a.5.5 0 0 1-.708 0L6 1.707l-.646.647a.5.5 0 0 1-.708 0L4 1.707l-.646.647a.5.5 0 0 1-.708 0l-.509-.51z"/><path d="M3 4.5a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm8-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconReceiptCutoff=/*#__PURE__*/makeIcon('ReceiptCutoff','<path d="M3 4.5a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zM11.5 4a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/><path d="M2.354.646a.5.5 0 0 0-.801.13l-.5 1A.5.5 0 0 0 1 2v13H.5a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H15V2a.5.5 0 0 0-.053-.224l-.5-1a.5.5 0 0 0-.8-.13L13 1.293l-.646-.647a.5.5 0 0 0-.708 0L11 1.293l-.646-.647a.5.5 0 0 0-.708 0L9 1.293 8.354.646a.5.5 0 0 0-.708 0L7 1.293 6.354.646a.5.5 0 0 0-.708 0L5 1.293 4.354.646a.5.5 0 0 0-.708 0L3 1.293 2.354.646zm-.217 1.198l.51.51a.5.5 0 0 0 .707 0L4 1.707l.646.647a.5.5 0 0 0 .708 0L6 1.707l.646.647a.5.5 0 0 0 .708 0L8 1.707l.646.647a.5.5 0 0 0 .708 0L10 1.707l.646.647a.5.5 0 0 0 .708 0L12 1.707l.646.647a.5.5 0 0 0 .708 0l.509-.51.137.274V15H2V2.118l.137-.274z"/>');// eslint-disable-next-line
var BIconReception0=/*#__PURE__*/makeIcon('Reception0','<path d="M0 13.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconReception1=/*#__PURE__*/makeIcon('Reception1','<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4 2a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconReception2=/*#__PURE__*/makeIcon('Reception2','<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-5zm4 5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconReception3=/*#__PURE__*/makeIcon('Reception3','<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-5zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-8zm4 8a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconReception4=/*#__PURE__*/makeIcon('Reception4','<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-5zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-8zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v11a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-11z"/>');// eslint-disable-next-line
var BIconRecord=/*#__PURE__*/makeIcon('Record','<path fill-rule="evenodd" d="M8 12a4 4 0 1 0 0-8 4 4 0 0 0 0 8zm0 1A5 5 0 1 0 8 3a5 5 0 0 0 0 10z"/>');// eslint-disable-next-line
var BIconRecord2=/*#__PURE__*/makeIcon('Record2','<path d="M8 12a4 4 0 1 1 0-8 4 4 0 0 1 0 8zm0 1A5 5 0 1 0 8 3a5 5 0 0 0 0 10z"/><path d="M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>');// eslint-disable-next-line
var BIconRecord2Fill=/*#__PURE__*/makeIcon('Record2Fill','<path d="M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/><path d="M8 13A5 5 0 1 0 8 3a5 5 0 0 0 0 10zm0-2a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>');// eslint-disable-next-line
var BIconRecordBtn=/*#__PURE__*/makeIcon('RecordBtn','<path d="M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconRecordBtnFill=/*#__PURE__*/makeIcon('RecordBtnFill','<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm8-1a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>');// eslint-disable-next-line
var BIconRecordCircle=/*#__PURE__*/makeIcon('RecordCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/>');// eslint-disable-next-line
var BIconRecordCircleFill=/*#__PURE__*/makeIcon('RecordCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-8 3a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>');// eslint-disable-next-line
var BIconRecordFill=/*#__PURE__*/makeIcon('RecordFill','<path fill-rule="evenodd" d="M8 13A5 5 0 1 0 8 3a5 5 0 0 0 0 10z"/>');// eslint-disable-next-line
var BIconReply=/*#__PURE__*/makeIcon('Reply','<path d="M9.502 5.013a.144.144 0 0 0-.202.134V6.3a.5.5 0 0 1-.5.5c-.667 0-2.013.005-3.3.822-.984.624-1.99 1.76-2.595 3.876C3.925 10.515 5.09 9.982 6.11 9.7a8.741 8.741 0 0 1 1.921-.306 7.403 7.403 0 0 1 .798.008h.013l.005.001h.001L8.8 9.9l.05-.498a.5.5 0 0 1 .45.498v1.153c0 .108.11.176.202.134l3.984-2.933a.494.494 0 0 1 .042-.028.147.147 0 0 0 0-.252.494.494 0 0 1-.042-.028L9.502 5.013zM8.3 10.386a7.745 7.745 0 0 0-1.923.277c-1.326.368-2.896 1.201-3.94 3.08a.5.5 0 0 1-.933-.305c.464-3.71 1.886-5.662 3.46-6.66 1.245-.79 2.527-.942 3.336-.971v-.66a1.144 1.144 0 0 1 1.767-.96l3.994 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a1.144 1.144 0 0 1-1.767-.96v-.667z"/>');// eslint-disable-next-line
var BIconReplyAll=/*#__PURE__*/makeIcon('ReplyAll','<path d="M8.002 5.013a.144.144 0 0 0-.202.134V6.3a.5.5 0 0 1-.5.5c-.667 0-2.013.005-3.3.822-.984.624-1.99 1.76-2.595 3.876C2.425 10.515 3.59 9.982 4.61 9.7a8.741 8.741 0 0 1 1.921-.306 7.403 7.403 0 0 1 .798.008h.013l.005.001h.001L7.3 9.9l.05-.498a.5.5 0 0 1 .45.498v1.153c0 .108.11.176.202.134l3.984-2.933a.494.494 0 0 1 .042-.028.147.147 0 0 0 0-.252.494.494 0 0 1-.042-.028L8.002 5.013zM6.8 10.386a7.745 7.745 0 0 0-1.923.277c-1.326.368-2.896 1.201-3.94 3.08a.5.5 0 0 1-.933-.305c.464-3.71 1.886-5.662 3.46-6.66 1.245-.79 2.527-.942 3.336-.971v-.66a1.144 1.144 0 0 1 1.767-.96l3.994 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a1.144 1.144 0 0 1-1.767-.96v-.667z"/><path d="M10.868 4.293a.5.5 0 0 1 .7-.106l3.993 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a.5.5 0 1 1-.593-.805l4.012-2.954a.508.508 0 0 1 .042-.028.147.147 0 0 0 0-.252.508.508 0 0 1-.042-.028l-4.012-2.954a.5.5 0 0 1-.106-.699z"/>');// eslint-disable-next-line
var BIconReplyAllFill=/*#__PURE__*/makeIcon('ReplyAllFill','<path d="M8.079 11.9l4.568-3.281a.719.719 0 0 0 0-1.238L8.079 4.1A.716.716 0 0 0 7 4.719V6c-1.5 0-6 0-7 8 2.5-4.5 7-4 7-4v1.281c0 .56.606.898 1.079.62z"/><path d="M10.868 4.293a.5.5 0 0 0 .106.7l4.012 2.953a.51.51 0 0 0 .042.028.147.147 0 0 1 0 .252.512.512 0 0 0-.042.028l-4.012 2.954a.5.5 0 1 0 .593.805l3.994-2.94a1.147 1.147 0 0 0 0-1.946l-3.994-2.94a.5.5 0 0 0-.699.106z"/>');// eslint-disable-next-line
var BIconReplyFill=/*#__PURE__*/makeIcon('ReplyFill','<path d="M9.079 11.9l4.568-3.281a.719.719 0 0 0 0-1.238L9.079 4.1A.716.716 0 0 0 8 4.719V6c-1.5 0-6 0-7 8 2.5-4.5 7-4 7-4v1.281c0 .56.606.898 1.079.62z"/>');// eslint-disable-next-line
var BIconRss=/*#__PURE__*/makeIcon('Rss','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5.5 12a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-3-8.5a1 1 0 0 1 1-1c5.523 0 10 4.477 10 10a1 1 0 1 1-2 0 8 8 0 0 0-8-8 1 1 0 0 1-1-1zm0 4a1 1 0 0 1 1-1 6 6 0 0 1 6 6 1 1 0 1 1-2 0 4 4 0 0 0-4-4 1 1 0 0 1-1-1z"/>');// eslint-disable-next-line
var BIconRssFill=/*#__PURE__*/makeIcon('RssFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm1.5 2.5c5.523 0 10 4.477 10 10a1 1 0 1 1-2 0 8 8 0 0 0-8-8 1 1 0 0 1 0-2zm0 4a6 6 0 0 1 6 6 1 1 0 1 1-2 0 4 4 0 0 0-4-4 1 1 0 0 1 0-2zm.5 7a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconScissors=/*#__PURE__*/makeIcon('Scissors','<path d="M3.5 3.5c-.614-.884-.074-1.962.858-2.5L8 7.226 11.642 1c.932.538 1.472 1.616.858 2.5L8.81 8.61l1.556 2.661a2.5 2.5 0 1 1-.794.637L8 9.73l-1.572 2.177a2.5 2.5 0 1 1-.794-.637L7.19 8.61 3.5 3.5zm2.5 10a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0zm7 0a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/>');// eslint-disable-next-line
var BIconScrewdriver=/*#__PURE__*/makeIcon('Screwdriver','<path d="M0 1l1-1 3.081 2.2a1 1 0 0 1 .419.815v.07a1 1 0 0 0 .293.708L10.5 9.5l.914-.305a1 1 0 0 1 1.023.242l3.356 3.356a1 1 0 0 1 0 1.414l-1.586 1.586a1 1 0 0 1-1.414 0l-3.356-3.356a1 1 0 0 1-.242-1.023L9.5 10.5 3.793 4.793a1 1 0 0 0-.707-.293h-.071a1 1 0 0 1-.814-.419L0 1zm11.354 9.646a.5.5 0 0 0-.708.708l3 3a.5.5 0 0 0 .708-.708l-3-3z"/>');// eslint-disable-next-line
var BIconSearch=/*#__PURE__*/makeIcon('Search','<path d="M11.742 10.344a6.5 6.5 0 1 0-1.397 1.398h-.001c.03.04.062.078.098.115l3.85 3.85a1 1 0 0 0 1.415-1.414l-3.85-3.85a1.007 1.007 0 0 0-.115-.1zM12 6.5a5.5 5.5 0 1 1-11 0 5.5 5.5 0 0 1 11 0z"/>');// eslint-disable-next-line
var BIconSegmentedNav=/*#__PURE__*/makeIcon('SegmentedNav','<path d="M0 6a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V6zm6 3h4V5H6v4zm9-1V6a1 1 0 0 0-1-1h-3v4h3a1 1 0 0 0 1-1z"/>');// eslint-disable-next-line
var BIconServer=/*#__PURE__*/makeIcon('Server','<path d="M1.333 2.667C1.333 1.194 4.318 0 8 0s6.667 1.194 6.667 2.667V4c0 1.473-2.985 2.667-6.667 2.667S1.333 5.473 1.333 4V2.667z"/><path d="M1.333 6.334v3C1.333 10.805 4.318 12 8 12s6.667-1.194 6.667-2.667V6.334c-.43.32-.931.58-1.458.79C11.81 7.684 9.967 8 8 8c-1.967 0-3.81-.317-5.21-.876a6.508 6.508 0 0 1-1.457-.79z"/><path d="M14.667 11.668c-.43.319-.931.578-1.458.789-1.4.56-3.242.876-5.209.876-1.967 0-3.81-.316-5.21-.876a6.51 6.51 0 0 1-1.457-.79v1.666C1.333 14.806 4.318 16 8 16s6.667-1.194 6.667-2.667v-1.665z"/>');// eslint-disable-next-line
var BIconShare=/*#__PURE__*/makeIcon('Share','<path d="M13.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zM11 2.5a2.5 2.5 0 1 1 .603 1.628l-6.718 3.12a2.499 2.499 0 0 1 0 1.504l6.718 3.12a2.5 2.5 0 1 1-.488.876l-6.718-3.12a2.5 2.5 0 1 1 0-3.256l6.718-3.12A2.5 2.5 0 0 1 11 2.5zm-8.5 4a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zm11 5.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3z"/>');// eslint-disable-next-line
var BIconShareFill=/*#__PURE__*/makeIcon('ShareFill','<path d="M11 2.5a2.5 2.5 0 1 1 .603 1.628l-6.718 3.12a2.499 2.499 0 0 1 0 1.504l6.718 3.12a2.5 2.5 0 1 1-.488.876l-6.718-3.12a2.5 2.5 0 1 1 0-3.256l6.718-3.12A2.5 2.5 0 0 1 11 2.5z"/>');// eslint-disable-next-line
var BIconShield=/*#__PURE__*/makeIcon('Shield','<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/>');// eslint-disable-next-line
var BIconShieldCheck=/*#__PURE__*/makeIcon('ShieldCheck','<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M10.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconShieldExclamation=/*#__PURE__*/makeIcon('ShieldExclamation','<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>');// eslint-disable-next-line
var BIconShieldFill=/*#__PURE__*/makeIcon('ShieldFill','<path d="M5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/>');// eslint-disable-next-line
var BIconShieldFillCheck=/*#__PURE__*/makeIcon('ShieldFillCheck','<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm2.146 5.146a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 7.793l2.646-2.647z"/>');// eslint-disable-next-line
var BIconShieldFillExclamation=/*#__PURE__*/makeIcon('ShieldFillExclamation','<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm-.55 8.502L7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0zM8.002 12a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>');// eslint-disable-next-line
var BIconShieldFillMinus=/*#__PURE__*/makeIcon('ShieldFillMinus','<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zM6 7.5a.5.5 0 0 1 0-1h4a.5.5 0 0 1 0 1H6z"/>');// eslint-disable-next-line
var BIconShieldFillPlus=/*#__PURE__*/makeIcon('ShieldFillPlus','<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm-.5 5a.5.5 0 0 1 1 0v1.5H10a.5.5 0 0 1 0 1H8.5V9a.5.5 0 0 1-1 0V7.5H6a.5.5 0 0 1 0-1h1.5V5z"/>');// eslint-disable-next-line
var BIconShieldFillX=/*#__PURE__*/makeIcon('ShieldFillX','<path d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zM6.854 5.146L8 6.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 7l1.147 1.146a.5.5 0 0 1-.708.708L8 7.707 6.854 8.854a.5.5 0 1 1-.708-.708L7.293 7 6.146 5.854a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconShieldLock=/*#__PURE__*/makeIcon('ShieldLock','<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M9.5 6.5a1.5 1.5 0 0 1-1 1.415l.385 1.99a.5.5 0 0 1-.491.595h-.788a.5.5 0 0 1-.49-.595l.384-1.99a1.5 1.5 0 1 1 2-1.415z"/>');// eslint-disable-next-line
var BIconShieldLockFill=/*#__PURE__*/makeIcon('ShieldLockFill','<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm0 5a1.5 1.5 0 0 1 .5 2.915l.385 1.99a.5.5 0 0 1-.491.595h-.788a.5.5 0 0 1-.49-.595l.384-1.99A1.5 1.5 0 0 1 8 5z"/>');// eslint-disable-next-line
var BIconShieldMinus=/*#__PURE__*/makeIcon('ShieldMinus','<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M5.5 7a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconShieldPlus=/*#__PURE__*/makeIcon('ShieldPlus','<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M8 4.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V9a.5.5 0 0 1-1 0V7.5H6a.5.5 0 0 1 0-1h1.5V5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconShieldShaded=/*#__PURE__*/makeIcon('ShieldShaded','<path fill-rule="evenodd" d="M8 14.933a.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067v13.866zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/>');// eslint-disable-next-line
var BIconShieldSlash=/*#__PURE__*/makeIcon('ShieldSlash','<path fill-rule="evenodd" d="M1.093 3.093c-.465 4.275.885 7.46 2.513 9.589a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.32 11.32 0 0 0 1.733-1.525l-.745-.745a10.27 10.27 0 0 1-1.578 1.392c-.346.244-.652.42-.893.533-.12.057-.218.095-.293.118a.55.55 0 0 1-.101.025.615.615 0 0 1-.1-.025 2.348 2.348 0 0 1-.294-.118 6.141 6.141 0 0 1-.893-.533 10.725 10.725 0 0 1-2.287-2.233C3.053 10.228 1.879 7.594 2.06 4.06l-.967-.967zM3.98 1.98l-.852-.852A58.935 58.935 0 0 1 5.072.559C6.157.266 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.483 3.626-.332 6.491-1.551 8.616l-.77-.77c1.042-1.915 1.72-4.469 1.29-7.702a.48.48 0 0 0-.33-.39c-.65-.213-1.75-.56-2.836-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524a49.7 49.7 0 0 0-1.357.39zm9.666 12.374l-13-13 .708-.708 13 13-.707.707z"/>');// eslint-disable-next-line
var BIconShieldSlashFill=/*#__PURE__*/makeIcon('ShieldSlashFill','<path fill-rule="evenodd" d="M1.093 3.093c-.465 4.275.885 7.46 2.513 9.589a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.32 11.32 0 0 0 1.733-1.525L1.093 3.093zm12.215 8.215L3.128 1.128A61.369 61.369 0 0 1 5.073.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.483 3.626-.332 6.491-1.551 8.616zm.338 3.046l-13-13 .708-.708 13 13-.707.707z"/>');// eslint-disable-next-line
var BIconShieldX=/*#__PURE__*/makeIcon('ShieldX','<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M6.146 5.146a.5.5 0 0 1 .708 0L8 6.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 7l1.147 1.146a.5.5 0 0 1-.708.708L8 7.707 6.854 8.854a.5.5 0 1 1-.708-.708L7.293 7 6.146 5.854a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconShift=/*#__PURE__*/makeIcon('Shift','<path d="M7.27 2.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v3a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-3H1.654C.78 10.5.326 9.455.924 8.816L7.27 2.047zM14.346 9.5L8 2.731 1.654 9.5H4.5a1 1 0 0 1 1 1v3h5v-3a1 1 0 0 1 1-1h2.846z"/>');// eslint-disable-next-line
var BIconShiftFill=/*#__PURE__*/makeIcon('ShiftFill','<path d="M7.27 2.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v3a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-3H1.654C.78 10.5.326 9.455.924 8.816L7.27 2.047z"/>');// eslint-disable-next-line
var BIconShop=/*#__PURE__*/makeIcon('Shop','<path d="M2.97 1.35A1 1 0 0 1 3.73 1h8.54a1 1 0 0 1 .76.35l2.609 3.044A1.5 1.5 0 0 1 16 5.37v.255a2.375 2.375 0 0 1-4.25 1.458A2.371 2.371 0 0 1 9.875 8 2.37 2.37 0 0 1 8 7.083 2.37 2.37 0 0 1 6.125 8a2.37 2.37 0 0 1-1.875-.917A2.375 2.375 0 0 1 0 5.625V5.37a1.5 1.5 0 0 1 .361-.976l2.61-3.045zm1.78 4.275a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 1 0 2.75 0V5.37a.5.5 0 0 0-.12-.325L12.27 2H3.73L1.12 5.045A.5.5 0 0 0 1 5.37v.255a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0zM1.5 8.5A.5.5 0 0 1 2 9v6h1v-5a1 1 0 0 1 1-1h3a1 1 0 0 1 1 1v5h6V9a.5.5 0 0 1 1 0v6h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1V9a.5.5 0 0 1 .5-.5zM4 15h3v-5H4v5zm5-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1v-3zm3 0h-2v3h2v-3z"/>');// eslint-disable-next-line
var BIconShopWindow=/*#__PURE__*/makeIcon('ShopWindow','<path d="M2.97 1.35A1 1 0 0 1 3.73 1h8.54a1 1 0 0 1 .76.35l2.609 3.044A1.5 1.5 0 0 1 16 5.37v.255a2.375 2.375 0 0 1-4.25 1.458A2.371 2.371 0 0 1 9.875 8 2.37 2.37 0 0 1 8 7.083 2.37 2.37 0 0 1 6.125 8a2.37 2.37 0 0 1-1.875-.917A2.375 2.375 0 0 1 0 5.625V5.37a1.5 1.5 0 0 1 .361-.976l2.61-3.045zm1.78 4.275a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 1 0 2.75 0V5.37a.5.5 0 0 0-.12-.325L12.27 2H3.73L1.12 5.045A.5.5 0 0 0 1 5.37v.255a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0zM1.5 8.5A.5.5 0 0 1 2 9v6h12V9a.5.5 0 0 1 1 0v6h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1V9a.5.5 0 0 1 .5-.5zm2 .5a.5.5 0 0 1 .5.5V13h8V9.5a.5.5 0 0 1 1 0V13a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V9.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconShuffle=/*#__PURE__*/makeIcon('Shuffle','<path fill-rule="evenodd" d="M0 3.5A.5.5 0 0 1 .5 3H1c2.202 0 3.827 1.24 4.874 2.418.49.552.865 1.102 1.126 1.532.26-.43.636-.98 1.126-1.532C9.173 4.24 10.798 3 13 3v1c-1.798 0-3.173 1.01-4.126 2.082A9.624 9.624 0 0 0 7.556 8a9.624 9.624 0 0 0 1.317 1.918C9.828 10.99 11.204 12 13 12v1c-2.202 0-3.827-1.24-4.874-2.418A10.595 10.595 0 0 1 7 9.05c-.26.43-.636.98-1.126 1.532C4.827 11.76 3.202 13 1 13H.5a.5.5 0 0 1 0-1H1c1.798 0 3.173-1.01 4.126-2.082A9.624 9.624 0 0 0 6.444 8a9.624 9.624 0 0 0-1.317-1.918C4.172 5.01 2.796 4 1 4H.5a.5.5 0 0 1-.5-.5z"/><path d="M13 5.466V1.534a.25.25 0 0 1 .41-.192l2.36 1.966c.12.1.12.284 0 .384l-2.36 1.966a.25.25 0 0 1-.41-.192zm0 9v-3.932a.25.25 0 0 1 .41-.192l2.36 1.966c.12.1.12.284 0 .384l-2.36 1.966a.25.25 0 0 1-.41-.192z"/>');// eslint-disable-next-line
var BIconSignpost=/*#__PURE__*/makeIcon('Signpost','<path d="M7 1.414V4H2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h5v6h2v-6h3.532a1 1 0 0 0 .768-.36l1.933-2.32a.5.5 0 0 0 0-.64L13.3 4.36a1 1 0 0 0-.768-.36H9V1.414a1 1 0 0 0-2 0zM12.532 5l1.666 2-1.666 2H2V5h10.532z"/>');// eslint-disable-next-line
var BIconSignpost2=/*#__PURE__*/makeIcon('Signpost2','<path d="M7 1.414V2H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h5v1H2.5a1 1 0 0 0-.8.4L.725 8.7a.5.5 0 0 0 0 .6l.975 1.3a1 1 0 0 0 .8.4H7v5h2v-5h5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H9V6h4.5a1 1 0 0 0 .8-.4l.975-1.3a.5.5 0 0 0 0-.6L14.3 2.4a1 1 0 0 0-.8-.4H9v-.586a1 1 0 0 0-2 0zM13.5 3l.75 1-.75 1H2V3h11.5zm.5 5v2H2.5l-.75-1 .75-1H14z"/>');// eslint-disable-next-line
var BIconSignpost2Fill=/*#__PURE__*/makeIcon('Signpost2Fill','<path d="M7.293.707A1 1 0 0 0 7 1.414V2H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h5v1H2.5a1 1 0 0 0-.8.4L.725 8.7a.5.5 0 0 0 0 .6l.975 1.3a1 1 0 0 0 .8.4H7v5h2v-5h5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H9V6h4.5a1 1 0 0 0 .8-.4l.975-1.3a.5.5 0 0 0 0-.6L14.3 2.4a1 1 0 0 0-.8-.4H9v-.586A1 1 0 0 0 7.293.707z"/>');// eslint-disable-next-line
var BIconSignpostFill=/*#__PURE__*/makeIcon('SignpostFill','<path d="M7.293.707A1 1 0 0 0 7 1.414V4H2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h5v6h2v-6h3.532a1 1 0 0 0 .768-.36l1.933-2.32a.5.5 0 0 0 0-.64L13.3 4.36a1 1 0 0 0-.768-.36H9V1.414A1 1 0 0 0 7.293.707z"/>');// eslint-disable-next-line
var BIconSignpostSplit=/*#__PURE__*/makeIcon('SignpostSplit','<path d="M7 7V1.414a1 1 0 0 1 2 0V2h5a1 1 0 0 1 .8.4l.975 1.3a.5.5 0 0 1 0 .6L14.8 5.6a1 1 0 0 1-.8.4H9v10H7v-5H2a1 1 0 0 1-.8-.4L.225 9.3a.5.5 0 0 1 0-.6L1.2 7.4A1 1 0 0 1 2 7h5zm1 3V8H2l-.75 1L2 10h6zm0-5h6l.75-1L14 3H8v2z"/>');// eslint-disable-next-line
var BIconSignpostSplitFill=/*#__PURE__*/makeIcon('SignpostSplitFill','<path d="M7 16h2V6h5a1 1 0 0 0 .8-.4l.975-1.3a.5.5 0 0 0 0-.6L14.8 2.4A1 1 0 0 0 14 2H9v-.586a1 1 0 0 0-2 0V7H2a1 1 0 0 0-.8.4L.225 8.7a.5.5 0 0 0 0 .6l.975 1.3a1 1 0 0 0 .8.4h5v5z"/>');// eslint-disable-next-line
var BIconSim=/*#__PURE__*/makeIcon('Sim','<path d="M2 1.5A1.5 1.5 0 0 1 3.5 0h7.086a1.5 1.5 0 0 1 1.06.44l1.915 1.914A1.5 1.5 0 0 1 14 3.414V14.5a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 14.5v-13zM3.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5V3.414a.5.5 0 0 0-.146-.353l-1.915-1.915A.5.5 0 0 0 10.586 1H3.5z"/><path d="M5.5 4a.5.5 0 0 0-.5.5V6h2.5V4h-2zm3 0v2H11V4.5a.5.5 0 0 0-.5-.5h-2zM11 7H5v2h6V7zm0 3H8.5v2h2a.5.5 0 0 0 .5-.5V10zm-3.5 2v-2H5v1.5a.5.5 0 0 0 .5.5h2zM4 4.5A1.5 1.5 0 0 1 5.5 3h5A1.5 1.5 0 0 1 12 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-5A1.5 1.5 0 0 1 4 11.5v-7z"/>');// eslint-disable-next-line
var BIconSimFill=/*#__PURE__*/makeIcon('SimFill','<path d="M5 4.5a.5.5 0 0 1 .5-.5h2v2H5V4.5zM8.5 6V4h2a.5.5 0 0 1 .5.5V6H8.5zM5 7h6v2H5V7zm3.5 3H11v1.5a.5.5 0 0 1-.5.5h-2v-2zm-1 0v2h-2a.5.5 0 0 1-.5-.5V10h2.5z"/><path d="M3.5 0A1.5 1.5 0 0 0 2 1.5v13A1.5 1.5 0 0 0 3.5 16h9a1.5 1.5 0 0 0 1.5-1.5V3.414a1.5 1.5 0 0 0-.44-1.06L11.647.439A1.5 1.5 0 0 0 10.586 0H3.5zm2 3h5A1.5 1.5 0 0 1 12 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-5A1.5 1.5 0 0 1 4 11.5v-7A1.5 1.5 0 0 1 5.5 3z"/>');// eslint-disable-next-line
var BIconSkipBackward=/*#__PURE__*/makeIcon('SkipBackward','<path d="M.5 3.5A.5.5 0 0 1 1 4v3.248l6.267-3.636c.52-.302 1.233.043 1.233.696v2.94l6.267-3.636c.52-.302 1.233.043 1.233.696v7.384c0 .653-.713.998-1.233.696L8.5 8.752v2.94c0 .653-.713.998-1.233.696L1 8.752V12a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5zm7 1.133L1.696 8 7.5 11.367V4.633zm7.5 0L9.196 8 15 11.367V4.633z"/>');// eslint-disable-next-line
var BIconSkipBackwardBtn=/*#__PURE__*/makeIcon('SkipBackwardBtn','<path d="M4.79 5.093A.5.5 0 0 0 4 5.5v5a.5.5 0 0 0 .79.407L7.5 8.972V10.5a.5.5 0 0 0 .79.407L11 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 5.093a.5.5 0 0 0-.79.407v1.528L4.79 5.093z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconSkipBackwardBtnFill=/*#__PURE__*/makeIcon('SkipBackwardBtnFill','<path d="M0 10V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm4.79-6.907A.5.5 0 0 0 4 3.5v5a.5.5 0 0 0 .79.407L7.5 6.972V8.5a.5.5 0 0 0 .79.407L11 6.972V8.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 3.093a.5.5 0 0 0-.79.407v1.528L4.79 3.093z"/>');// eslint-disable-next-line
var BIconSkipBackwardCircle=/*#__PURE__*/makeIcon('SkipBackwardCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.271 5.055a.5.5 0 0 1 .52.038L7.5 7.028V5.5a.5.5 0 0 1 .79-.407L11 7.028V5.5a.5.5 0 0 1 1 0v5a.5.5 0 0 1-1 0V8.972l-2.71 1.935a.5.5 0 0 1-.79-.407V8.972l-2.71 1.935A.5.5 0 0 1 4 10.5v-5a.5.5 0 0 1 .271-.445z"/>');// eslint-disable-next-line
var BIconSkipBackwardCircleFill=/*#__PURE__*/makeIcon('SkipBackwardCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.79 5.093A.5.5 0 0 0 4 5.5v5a.5.5 0 0 0 .79.407L7.5 8.972V10.5a.5.5 0 0 0 .79.407L11 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 5.093a.5.5 0 0 0-.79.407v1.528L4.79 5.093z"/>');// eslint-disable-next-line
var BIconSkipBackwardFill=/*#__PURE__*/makeIcon('SkipBackwardFill','<path d="M.5 3.5A.5.5 0 0 0 0 4v8a.5.5 0 0 0 1 0V8.753l6.267 3.636c.54.313 1.233-.066 1.233-.697v-2.94l6.267 3.636c.54.314 1.233-.065 1.233-.696V4.308c0-.63-.693-1.01-1.233-.696L8.5 7.248v-2.94c0-.63-.692-1.01-1.233-.696L1 7.248V4a.5.5 0 0 0-.5-.5z"/>');// eslint-disable-next-line
var BIconSkipEnd=/*#__PURE__*/makeIcon('SkipEnd','<path d="M12.5 4a.5.5 0 0 0-1 0v3.248L5.233 3.612C4.713 3.31 4 3.655 4 4.308v7.384c0 .653.713.998 1.233.696L11.5 8.752V12a.5.5 0 0 0 1 0V4zM5 4.633L10.804 8 5 11.367V4.633z"/>');// eslint-disable-next-line
var BIconSkipEndBtn=/*#__PURE__*/makeIcon('SkipEndBtn','<path d="M6.79 5.093L9.5 7.028V5.5a.5.5 0 0 1 1 0v5a.5.5 0 0 1-1 0V8.972l-2.71 1.935A.5.5 0 0 1 6 10.5v-5a.5.5 0 0 1 .79-.407z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconSkipEndBtnFill=/*#__PURE__*/makeIcon('SkipEndBtnFill','<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.79-6.907A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407L9.5 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L6.79 5.093z"/>');// eslint-disable-next-line
var BIconSkipEndCircle=/*#__PURE__*/makeIcon('SkipEndCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M6.271 5.055a.5.5 0 0 1 .52.038L9.5 7.028V5.5a.5.5 0 0 1 1 0v5a.5.5 0 0 1-1 0V8.972l-2.71 1.935A.5.5 0 0 1 6 10.5v-5a.5.5 0 0 1 .271-.445z"/>');// eslint-disable-next-line
var BIconSkipEndCircleFill=/*#__PURE__*/makeIcon('SkipEndCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.79 5.093A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407L9.5 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L6.79 5.093z"/>');// eslint-disable-next-line
var BIconSkipEndFill=/*#__PURE__*/makeIcon('SkipEndFill','<path d="M12.5 4a.5.5 0 0 0-1 0v3.248L5.233 3.612C4.693 3.3 4 3.678 4 4.308v7.384c0 .63.692 1.01 1.233.697L11.5 8.753V12a.5.5 0 0 0 1 0V4z"/>');// eslint-disable-next-line
var BIconSkipForward=/*#__PURE__*/makeIcon('SkipForward','<path d="M15.5 3.5a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V8.752l-6.267 3.636c-.52.302-1.233-.043-1.233-.696v-2.94l-6.267 3.636C.713 12.69 0 12.345 0 11.692V4.308c0-.653.713-.998 1.233-.696L7.5 7.248v-2.94c0-.653.713-.998 1.233-.696L15 7.248V4a.5.5 0 0 1 .5-.5zM1 4.633v6.734L6.804 8 1 4.633zm7.5 0v6.734L14.304 8 8.5 4.633z"/>');// eslint-disable-next-line
var BIconSkipForwardBtn=/*#__PURE__*/makeIcon('SkipForwardBtn','<path d="M11.21 5.093A.5.5 0 0 1 12 5.5v5a.5.5 0 0 1-.79.407L8.5 8.972V10.5a.5.5 0 0 1-.79.407L5 8.972V10.5a.5.5 0 0 1-1 0v-5a.5.5 0 0 1 1 0v1.528l2.71-1.935a.5.5 0 0 1 .79.407v1.528l2.71-1.935z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconSkipForwardBtnFill=/*#__PURE__*/makeIcon('SkipForwardBtnFill','<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm11.21-6.907L8.5 7.028V5.5a.5.5 0 0 0-.79-.407L5 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407V8.972l2.71 1.935A.5.5 0 0 0 12 10.5v-5a.5.5 0 0 0-.79-.407z"/>');// eslint-disable-next-line
var BIconSkipForwardCircle=/*#__PURE__*/makeIcon('SkipForwardCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11.729 5.055a.5.5 0 0 0-.52.038L8.5 7.028V5.5a.5.5 0 0 0-.79-.407L5 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407V8.972l2.71 1.935A.5.5 0 0 0 12 10.5v-5a.5.5 0 0 0-.271-.445z"/>');// eslint-disable-next-line
var BIconSkipForwardCircleFill=/*#__PURE__*/makeIcon('SkipForwardCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.79-2.907L8.5 7.028V5.5a.5.5 0 0 0-.79-.407L5 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407V8.972l2.71 1.935A.5.5 0 0 0 12 10.5v-5a.5.5 0 0 0-.79-.407z"/>');// eslint-disable-next-line
var BIconSkipForwardFill=/*#__PURE__*/makeIcon('SkipForwardFill','<path d="M15.5 3.5a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V8.753l-6.267 3.636c-.54.313-1.233-.066-1.233-.697v-2.94l-6.267 3.636C.693 12.703 0 12.324 0 11.693V4.308c0-.63.693-1.01 1.233-.696L7.5 7.248v-2.94c0-.63.693-1.01 1.233-.696L15 7.248V4a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconSkipStart=/*#__PURE__*/makeIcon('SkipStart','<path d="M4 4a.5.5 0 0 1 1 0v3.248l6.267-3.636c.52-.302 1.233.043 1.233.696v7.384c0 .653-.713.998-1.233.696L5 8.752V12a.5.5 0 0 1-1 0V4zm7.5.633L5.696 8l5.804 3.367V4.633z"/>');// eslint-disable-next-line
var BIconSkipStartBtn=/*#__PURE__*/makeIcon('SkipStartBtn','<path d="M9.71 5.093a.5.5 0 0 1 .79.407v5a.5.5 0 0 1-.79.407L7 8.972V10.5a.5.5 0 0 1-1 0v-5a.5.5 0 0 1 1 0v1.528l2.71-1.935z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconSkipStartBtnFill=/*#__PURE__*/makeIcon('SkipStartBtnFill','<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm9.71-6.907L7 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407v-5a.5.5 0 0 0-.79-.407z"/>');// eslint-disable-next-line
var BIconSkipStartCircle=/*#__PURE__*/makeIcon('SkipStartCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M10.229 5.055a.5.5 0 0 0-.52.038L7 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407v-5a.5.5 0 0 0-.271-.445z"/>');// eslint-disable-next-line
var BIconSkipStartCircleFill=/*#__PURE__*/makeIcon('SkipStartCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM9.71 5.093L7 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407v-5a.5.5 0 0 0-.79-.407z"/>');// eslint-disable-next-line
var BIconSkipStartFill=/*#__PURE__*/makeIcon('SkipStartFill','<path d="M4 4a.5.5 0 0 1 1 0v3.248l6.267-3.636c.54-.313 1.232.066 1.232.696v7.384c0 .63-.692 1.01-1.232.697L5 8.753V12a.5.5 0 0 1-1 0V4z"/>');// eslint-disable-next-line
var BIconSlack=/*#__PURE__*/makeIcon('Slack','<path d="M3.362 10.11c0 .926-.756 1.681-1.681 1.681S0 11.036 0 10.111C0 9.186.756 8.43 1.68 8.43h1.682v1.68zm.846 0c0-.924.756-1.68 1.681-1.68s1.681.756 1.681 1.68v4.21c0 .924-.756 1.68-1.68 1.68a1.685 1.685 0 0 1-1.682-1.68v-4.21zM5.89 3.362c-.926 0-1.682-.756-1.682-1.681S4.964 0 5.89 0s1.68.756 1.68 1.68v1.682H5.89zm0 .846c.924 0 1.68.756 1.68 1.681S6.814 7.57 5.89 7.57H1.68C.757 7.57 0 6.814 0 5.89c0-.926.756-1.682 1.68-1.682h4.21zm6.749 1.682c0-.926.755-1.682 1.68-1.682.925 0 1.681.756 1.681 1.681s-.756 1.681-1.68 1.681h-1.681V5.89zm-.848 0c0 .924-.755 1.68-1.68 1.68A1.685 1.685 0 0 1 8.43 5.89V1.68C8.43.757 9.186 0 10.11 0c.926 0 1.681.756 1.681 1.68v4.21zm-1.681 6.748c.926 0 1.682.756 1.682 1.681S11.036 16 10.11 16s-1.681-.756-1.681-1.68v-1.682h1.68zm0-.847c-.924 0-1.68-.755-1.68-1.68 0-.925.756-1.681 1.68-1.681h4.21c.924 0 1.68.756 1.68 1.68 0 .926-.756 1.681-1.68 1.681h-4.21z"/>');// eslint-disable-next-line
var BIconSlash=/*#__PURE__*/makeIcon('Slash','<path d="M11.354 4.646a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708l6-6a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconSlashCircle=/*#__PURE__*/makeIcon('SlashCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11.354 4.646a.5.5 0 0 0-.708 0l-6 6a.5.5 0 0 0 .708.708l6-6a.5.5 0 0 0 0-.708z"/>');// eslint-disable-next-line
var BIconSlashCircleFill=/*#__PURE__*/makeIcon('SlashCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.646-2.646a.5.5 0 0 0-.708-.708l-6 6a.5.5 0 0 0 .708.708l6-6z"/>');// eslint-disable-next-line
var BIconSlashSquare=/*#__PURE__*/makeIcon('SlashSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M11.354 4.646a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708l6-6a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconSlashSquareFill=/*#__PURE__*/makeIcon('SlashSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm9.354 5.354l-6 6a.5.5 0 0 1-.708-.708l6-6a.5.5 0 0 1 .708.708z"/>');// eslint-disable-next-line
var BIconSliders=/*#__PURE__*/makeIcon('Sliders','<path fill-rule="evenodd" d="M11.5 2a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zM9.05 3a2.5 2.5 0 0 1 4.9 0H16v1h-2.05a2.5 2.5 0 0 1-4.9 0H0V3h9.05zM4.5 7a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zM2.05 8a2.5 2.5 0 0 1 4.9 0H16v1H6.95a2.5 2.5 0 0 1-4.9 0H0V8h2.05zm9.45 4a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zm-2.45 1a2.5 2.5 0 0 1 4.9 0H16v1h-2.05a2.5 2.5 0 0 1-4.9 0H0v-1h9.05z"/>');// eslint-disable-next-line
var BIconSmartwatch=/*#__PURE__*/makeIcon('Smartwatch','<path d="M9 5a.5.5 0 0 0-1 0v3H6a.5.5 0 0 0 0 1h2.5a.5.5 0 0 0 .5-.5V5z"/><path d="M4 1.667v.383A2.5 2.5 0 0 0 2 4.5v7a2.5 2.5 0 0 0 2 2.45v.383C4 15.253 4.746 16 5.667 16h4.666c.92 0 1.667-.746 1.667-1.667v-.383a2.5 2.5 0 0 0 2-2.45V8h.5a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5H14v-.5a2.5 2.5 0 0 0-2-2.45v-.383C12 .747 11.254 0 10.333 0H5.667C4.747 0 4 .746 4 1.667zM4.5 3h7A1.5 1.5 0 0 1 13 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-7A1.5 1.5 0 0 1 3 11.5v-7A1.5 1.5 0 0 1 4.5 3z"/>');// eslint-disable-next-line
var BIconSortAlphaDown=/*#__PURE__*/makeIcon('SortAlphaDown','<path fill-rule="evenodd" d="M10.082 5.629L9.664 7H8.598l1.789-5.332h1.234L13.402 7h-1.12l-.419-1.371h-1.781zm1.57-.785L11 2.687h-.047l-.652 2.157h1.351z"/><path d="M12.96 14H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V14zM4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>');// eslint-disable-next-line
var BIconSortAlphaDownAlt=/*#__PURE__*/makeIcon('SortAlphaDownAlt','<path d="M12.96 7H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V7z"/><path fill-rule="evenodd" d="M10.082 12.629L9.664 14H8.598l1.789-5.332h1.234L13.402 14h-1.12l-.419-1.371h-1.781zm1.57-.785L11 9.688h-.047l-.652 2.156h1.351z"/><path d="M4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>');// eslint-disable-next-line
var BIconSortAlphaUp=/*#__PURE__*/makeIcon('SortAlphaUp','<path fill-rule="evenodd" d="M10.082 5.629L9.664 7H8.598l1.789-5.332h1.234L13.402 7h-1.12l-.419-1.371h-1.781zm1.57-.785L11 2.687h-.047l-.652 2.157h1.351z"/><path d="M12.96 14H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V14zm-8.46-.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>');// eslint-disable-next-line
var BIconSortAlphaUpAlt=/*#__PURE__*/makeIcon('SortAlphaUpAlt','<path d="M12.96 7H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V7z"/><path fill-rule="evenodd" d="M10.082 12.629L9.664 14H8.598l1.789-5.332h1.234L13.402 14h-1.12l-.419-1.371h-1.781zm1.57-.785L11 9.688h-.047l-.652 2.156h1.351z"/><path d="M4.5 13.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>');// eslint-disable-next-line
var BIconSortDown=/*#__PURE__*/makeIcon('SortDown','<path d="M3.5 2.5a.5.5 0 0 0-1 0v8.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L3.5 11.293V2.5zm3.5 1a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM7.5 6a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zm0 3a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/>');// eslint-disable-next-line
var BIconSortDownAlt=/*#__PURE__*/makeIcon('SortDownAlt','<path d="M3.5 3.5a.5.5 0 0 0-1 0v8.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L3.5 12.293V3.5zm4 .5a.5.5 0 0 1 0-1h1a.5.5 0 0 1 0 1h-1zm0 3a.5.5 0 0 1 0-1h3a.5.5 0 0 1 0 1h-3zm0 3a.5.5 0 0 1 0-1h5a.5.5 0 0 1 0 1h-5zM7 12.5a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7a.5.5 0 0 0-.5.5z"/>');// eslint-disable-next-line
var BIconSortNumericDown=/*#__PURE__*/makeIcon('SortNumericDown','<path d="M12.438 1.668V7H11.39V2.684h-.051l-1.211.859v-.969l1.262-.906h1.046z"/><path fill-rule="evenodd" d="M11.36 14.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.835 1.973-1.835 1.09 0 2.063.636 2.063 2.687 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>');// eslint-disable-next-line
var BIconSortNumericDownAlt=/*#__PURE__*/makeIcon('SortNumericDownAlt','<path fill-rule="evenodd" d="M11.36 7.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.836 1.973-1.836 1.09 0 2.063.637 2.063 2.688 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M12.438 8.668V14H11.39V9.684h-.051l-1.211.859v-.969l1.262-.906h1.046zM4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>');// eslint-disable-next-line
var BIconSortNumericUp=/*#__PURE__*/makeIcon('SortNumericUp','<path d="M12.438 1.668V7H11.39V2.684h-.051l-1.211.859v-.969l1.262-.906h1.046z"/><path fill-rule="evenodd" d="M11.36 14.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.835 1.973-1.835 1.09 0 2.063.636 2.063 2.687 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M4.5 13.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>');// eslint-disable-next-line
var BIconSortNumericUpAlt=/*#__PURE__*/makeIcon('SortNumericUpAlt','<path fill-rule="evenodd" d="M11.36 7.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.836 1.973-1.836 1.09 0 2.063.637 2.063 2.688 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M12.438 8.668V14H11.39V9.684h-.051l-1.211.859v-.969l1.262-.906h1.046zM4.5 13.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>');// eslint-disable-next-line
var BIconSortUp=/*#__PURE__*/makeIcon('SortUp','<path d="M3.5 12.5a.5.5 0 0 1-1 0V3.707L1.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L3.5 3.707V12.5zm3.5-9a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM7.5 6a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zm0 3a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/>');// eslint-disable-next-line
var BIconSortUpAlt=/*#__PURE__*/makeIcon('SortUpAlt','<path d="M3.5 13.5a.5.5 0 0 1-1 0V4.707L1.354 5.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L3.5 4.707V13.5zm4-9.5a.5.5 0 0 1 0-1h1a.5.5 0 0 1 0 1h-1zm0 3a.5.5 0 0 1 0-1h3a.5.5 0 0 1 0 1h-3zm0 3a.5.5 0 0 1 0-1h5a.5.5 0 0 1 0 1h-5zM7 12.5a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7a.5.5 0 0 0-.5.5z"/>');// eslint-disable-next-line
var BIconSoundwave=/*#__PURE__*/makeIcon('Soundwave','<path fill-rule="evenodd" d="M8.5 2a.5.5 0 0 1 .5.5v11a.5.5 0 0 1-1 0v-11a.5.5 0 0 1 .5-.5zm-2 2a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 .5-.5zm4 0a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 .5-.5zm-6 1.5A.5.5 0 0 1 5 6v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm8 0a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm-10 1A.5.5 0 0 1 3 7v2a.5.5 0 0 1-1 0V7a.5.5 0 0 1 .5-.5zm12 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0V7a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconSpeaker=/*#__PURE__*/makeIcon('Speaker','<path d="M12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M8 4.75a.75.75 0 1 1 0-1.5.75.75 0 0 1 0 1.5zM8 6a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm0 3a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zm-3.5 1.5a3.5 3.5 0 1 1 7 0 3.5 3.5 0 0 1-7 0z"/>');// eslint-disable-next-line
var BIconSpeakerFill=/*#__PURE__*/makeIcon('SpeakerFill','<path d="M9 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-2.5 6.5a1.5 1.5 0 1 1 3 0 1.5 1.5 0 0 1-3 0z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm6 4a2 2 0 1 1-4 0 2 2 0 0 1 4 0zM8 7a3.5 3.5 0 1 1 0 7 3.5 3.5 0 0 1 0-7z"/>');// eslint-disable-next-line
var BIconSpellcheck=/*#__PURE__*/makeIcon('Spellcheck','<path d="M8.217 11.068c1.216 0 1.948-.869 1.948-2.31v-.702c0-1.44-.727-2.305-1.929-2.305-.742 0-1.328.347-1.499.889h-.063V3.983h-1.29V11h1.27v-.791h.064c.21.532.776.86 1.499.86zm-.43-1.025c-.66 0-1.113-.518-1.113-1.28V8.12c0-.825.42-1.343 1.098-1.343.684 0 1.075.518 1.075 1.416v.45c0 .888-.386 1.401-1.06 1.401zm-5.583 1.035c.767 0 1.201-.356 1.406-.737h.059V11h1.216V7.519c0-1.314-.947-1.783-2.11-1.783C1.355 5.736.75 6.42.69 7.27h1.216c.064-.323.313-.552.84-.552.527 0 .864.249.864.771v.464H2.346C1.145 7.953.5 8.568.5 9.496c0 .977.693 1.582 1.704 1.582zm.42-.947c-.44 0-.845-.235-.845-.718 0-.395.269-.684.84-.684h.991v.538c0 .503-.444.864-.986.864zm8.897.567c-.577-.4-.9-1.088-.9-1.983v-.65c0-1.42.894-2.338 2.305-2.338 1.352 0 2.119.82 2.139 1.806h-1.187c-.04-.351-.283-.776-.918-.776-.674 0-1.045.517-1.045 1.328v.625c0 .468.121.834.343 1.067l-.737.92z"/><path d="M14.469 9.414a.75.75 0 0 1 .117 1.055l-4 5a.75.75 0 0 1-1.116.061l-2.5-2.5a.75.75 0 1 1 1.06-1.06l1.908 1.907 3.476-4.346a.75.75 0 0 1 1.055-.117z"/>');// eslint-disable-next-line
var BIconSquare=/*#__PURE__*/makeIcon('Square','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>');// eslint-disable-next-line
var BIconSquareFill=/*#__PURE__*/makeIcon('SquareFill','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2z"/>');// eslint-disable-next-line
var BIconSquareHalf=/*#__PURE__*/makeIcon('SquareHalf','<path d="M8 15V1h6a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H8zm6 1a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12z"/>');// eslint-disable-next-line
var BIconStar=/*#__PURE__*/makeIcon('Star','<path d="M2.866 14.85c-.078.444.36.791.746.593l4.39-2.256 4.389 2.256c.386.198.824-.149.746-.592l-.83-4.73 3.523-3.356c.329-.314.158-.888-.283-.95l-4.898-.696L8.465.792a.513.513 0 0 0-.927 0L5.354 5.12l-4.898.696c-.441.062-.612.636-.283.95l3.523 3.356-.83 4.73zm4.905-2.767l-3.686 1.894.694-3.957a.565.565 0 0 0-.163-.505L1.71 6.745l4.052-.576a.525.525 0 0 0 .393-.288l1.847-3.658 1.846 3.658a.525.525 0 0 0 .393.288l4.052.575-2.906 2.77a.564.564 0 0 0-.163.506l.694 3.957-3.686-1.894a.503.503 0 0 0-.461 0z"/>');// eslint-disable-next-line
var BIconStarFill=/*#__PURE__*/makeIcon('StarFill','<path d="M3.612 15.443c-.386.198-.824-.149-.746-.592l.83-4.73L.173 6.765c-.329-.314-.158-.888.283-.95l4.898-.696L7.538.792c.197-.39.73-.39.927 0l2.184 4.327 4.898.696c.441.062.612.636.283.95l-3.523 3.356.83 4.73c.078.443-.36.79-.746.592L8 13.187l-4.389 2.256z"/>');// eslint-disable-next-line
var BIconStarHalf=/*#__PURE__*/makeIcon('StarHalf','<path d="M5.354 5.119L7.538.792A.516.516 0 0 1 8 .5c.183 0 .366.097.465.292l2.184 4.327 4.898.696A.537.537 0 0 1 16 6.32a.55.55 0 0 1-.17.445l-3.523 3.356.83 4.73c.078.443-.36.79-.746.592L8 13.187l-4.389 2.256a.519.519 0 0 1-.146.05c-.341.06-.668-.254-.6-.642l.83-4.73L.173 6.765a.55.55 0 0 1-.171-.403.59.59 0 0 1 .084-.302.513.513 0 0 1 .37-.245l4.898-.696zM8 12.027c.08 0 .16.018.232.056l3.686 1.894-.694-3.957a.564.564 0 0 1 .163-.505l2.906-2.77-4.052-.576a.525.525 0 0 1-.393-.288L8.002 2.223 8 2.226v9.8z"/>');// eslint-disable-next-line
var BIconStickies=/*#__PURE__*/makeIcon('Stickies','<path d="M1.5 0A1.5 1.5 0 0 0 0 1.5V13a1 1 0 0 0 1 1V1.5a.5.5 0 0 1 .5-.5H14a1 1 0 0 0-1-1H1.5z"/><path d="M3.5 2A1.5 1.5 0 0 0 2 3.5v11A1.5 1.5 0 0 0 3.5 16h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 16 9.586V3.5A1.5 1.5 0 0 0 14.5 2h-11zM3 3.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 .5.5V9h-4.5A1.5 1.5 0 0 0 9 10.5V15H3.5a.5.5 0 0 1-.5-.5v-11zm7 11.293V10.5a.5.5 0 0 1 .5-.5h4.293L10 14.793z"/>');// eslint-disable-next-line
var BIconStickiesFill=/*#__PURE__*/makeIcon('StickiesFill','<path d="M0 1.5V13a1 1 0 0 0 1 1V1.5a.5.5 0 0 1 .5-.5H14a1 1 0 0 0-1-1H1.5A1.5 1.5 0 0 0 0 1.5z"/><path d="M3.5 2A1.5 1.5 0 0 0 2 3.5v11A1.5 1.5 0 0 0 3.5 16h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 16 9.586V3.5A1.5 1.5 0 0 0 14.5 2h-11zm6 8.5a1 1 0 0 1 1-1h4.396a.25.25 0 0 1 .177.427l-5.146 5.146a.25.25 0 0 1-.427-.177V10.5z"/>');// eslint-disable-next-line
var BIconSticky=/*#__PURE__*/makeIcon('Sticky','<path d="M2.5 1A1.5 1.5 0 0 0 1 2.5v11A1.5 1.5 0 0 0 2.5 15h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 15 8.586V2.5A1.5 1.5 0 0 0 13.5 1h-11zM2 2.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 .5.5V8H9.5A1.5 1.5 0 0 0 8 9.5V14H2.5a.5.5 0 0 1-.5-.5v-11zm7 11.293V9.5a.5.5 0 0 1 .5-.5h4.293L9 13.793z"/>');// eslint-disable-next-line
var BIconStickyFill=/*#__PURE__*/makeIcon('StickyFill','<path d="M2.5 1A1.5 1.5 0 0 0 1 2.5v11A1.5 1.5 0 0 0 2.5 15h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 15 8.586V2.5A1.5 1.5 0 0 0 13.5 1h-11zm6 8.5a1 1 0 0 1 1-1h4.396a.25.25 0 0 1 .177.427l-5.146 5.146a.25.25 0 0 1-.427-.177V9.5z"/>');// eslint-disable-next-line
var BIconStop=/*#__PURE__*/makeIcon('Stop','<path d="M3.5 5A1.5 1.5 0 0 1 5 3.5h6A1.5 1.5 0 0 1 12.5 5v6a1.5 1.5 0 0 1-1.5 1.5H5A1.5 1.5 0 0 1 3.5 11V5zM5 4.5a.5.5 0 0 0-.5.5v6a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 .5-.5V5a.5.5 0 0 0-.5-.5H5z"/>');// eslint-disable-next-line
var BIconStopBtn=/*#__PURE__*/makeIcon('StopBtn','<path d="M6.5 5A1.5 1.5 0 0 0 5 6.5v3A1.5 1.5 0 0 0 6.5 11h3A1.5 1.5 0 0 0 11 9.5v-3A1.5 1.5 0 0 0 9.5 5h-3z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>');// eslint-disable-next-line
var BIconStopBtnFill=/*#__PURE__*/makeIcon('StopBtnFill','<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.5-7A1.5 1.5 0 0 0 5 6.5v3A1.5 1.5 0 0 0 6.5 11h3A1.5 1.5 0 0 0 11 9.5v-3A1.5 1.5 0 0 0 9.5 5h-3z"/>');// eslint-disable-next-line
var BIconStopCircle=/*#__PURE__*/makeIcon('StopCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M5 6.5A1.5 1.5 0 0 1 6.5 5h3A1.5 1.5 0 0 1 11 6.5v3A1.5 1.5 0 0 1 9.5 11h-3A1.5 1.5 0 0 1 5 9.5v-3z"/>');// eslint-disable-next-line
var BIconStopCircleFill=/*#__PURE__*/makeIcon('StopCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.5 5A1.5 1.5 0 0 0 5 6.5v3A1.5 1.5 0 0 0 6.5 11h3A1.5 1.5 0 0 0 11 9.5v-3A1.5 1.5 0 0 0 9.5 5h-3z"/>');// eslint-disable-next-line
var BIconStopFill=/*#__PURE__*/makeIcon('StopFill','<path d="M5 3.5h6A1.5 1.5 0 0 1 12.5 5v6a1.5 1.5 0 0 1-1.5 1.5H5A1.5 1.5 0 0 1 3.5 11V5A1.5 1.5 0 0 1 5 3.5z"/>');// eslint-disable-next-line
var BIconStoplights=/*#__PURE__*/makeIcon('Stoplights','<path d="M8 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zm0 4a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zm1.5 2.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M4 2a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2h2c-.167.5-.8 1.6-2 2v2h2c-.167.5-.8 1.6-2 2v2h2c-.167.5-.8 1.6-2 2v1a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-1c-1.2-.4-1.833-1.5-2-2h2V8c-1.2-.4-1.833-1.5-2-2h2V4c-1.2-.4-1.833-1.5-2-2h2zm2-1a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H6z"/>');// eslint-disable-next-line
var BIconStoplightsFill=/*#__PURE__*/makeIcon('StoplightsFill','<path fill-rule="evenodd" d="M6 0a2 2 0 0 0-2 2H2c.167.5.8 1.6 2 2v2H2c.167.5.8 1.6 2 2v2H2c.167.5.8 1.6 2 2v1a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2v-1c1.2-.4 1.833-1.5 2-2h-2V8c1.2-.4 1.833-1.5 2-2h-2V4c1.2-.4 1.833-1.5 2-2h-2a2 2 0 0 0-2-2H6zm3.5 3.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM8 13a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconStopwatch=/*#__PURE__*/makeIcon('Stopwatch','<path d="M8.5 5.6a.5.5 0 1 0-1 0v2.9h-3a.5.5 0 0 0 0 1H8a.5.5 0 0 0 .5-.5V5.6z"/><path d="M6.5 1A.5.5 0 0 1 7 .5h2a.5.5 0 0 1 0 1v.57c1.36.196 2.594.78 3.584 1.64a.715.715 0 0 1 .012-.013l.354-.354-.354-.353a.5.5 0 0 1 .707-.708l1.414 1.415a.5.5 0 1 1-.707.707l-.353-.354-.354.354a.512.512 0 0 1-.013.012A7 7 0 1 1 7 2.071V1.5a.5.5 0 0 1-.5-.5zM8 3a6 6 0 1 0 .001 12A6 6 0 0 0 8 3z"/>');// eslint-disable-next-line
var BIconStopwatchFill=/*#__PURE__*/makeIcon('StopwatchFill','<path d="M6.5 0a.5.5 0 0 0 0 1H7v1.07A7.001 7.001 0 0 0 8 16a7 7 0 0 0 5.29-11.584.531.531 0 0 0 .013-.012l.354-.354.353.354a.5.5 0 1 0 .707-.707l-1.414-1.415a.5.5 0 1 0-.707.707l.354.354-.354.354a.717.717 0 0 0-.012.012A6.973 6.973 0 0 0 9 2.071V1h.5a.5.5 0 0 0 0-1h-3zm2 5.6V9a.5.5 0 0 1-.5.5H4.5a.5.5 0 0 1 0-1h3V5.6a.5.5 0 1 1 1 0z"/>');// eslint-disable-next-line
var BIconSubtract=/*#__PURE__*/makeIcon('Subtract','<path d="M0 10V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm4.79-6.907A.5.5 0 0 0 4 3.5v5a.5.5 0 0 0 .79.407L7.5 6.972V8.5a.5.5 0 0 0 .79.407L11 6.972V8.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 3.093a.5.5 0 0 0-.79.407v1.528L4.79 3.093z"/>');// eslint-disable-next-line
var BIconSuitClub=/*#__PURE__*/makeIcon('SuitClub','<path d="M8 1a3.25 3.25 0 0 0-3.25 3.25c0 .186 0 .29.016.41.014.12.045.27.12.527l.19.665-.692-.028a3.25 3.25 0 1 0 2.357 5.334.5.5 0 0 1 .844.518l-.003.005-.006.015-.024.055a21.893 21.893 0 0 1-.438.92 22.38 22.38 0 0 1-1.266 2.197c-.013.018-.02.05.001.09.01.02.021.03.03.036A.036.036 0 0 0 5.9 15h4.2c.01 0 .016-.002.022-.006a.092.092 0 0 0 .029-.035c.02-.04.014-.073.001-.091a22.875 22.875 0 0 1-1.704-3.117l-.024-.054-.006-.015-.002-.004a.5.5 0 0 1 .838-.524c.601.7 1.516 1.168 2.496 1.168a3.25 3.25 0 1 0-.139-6.498l-.699.03.199-.671c.14-.47.14-.745.139-.927V4.25A3.25 3.25 0 0 0 8 1zm2.207 12.024c.225.405.487.848.78 1.294C11.437 15 10.975 16 10.1 16H5.9c-.876 0-1.338-1-.887-1.683.291-.442.552-.88.776-1.283a4.25 4.25 0 1 1-2.007-8.187 2.79 2.79 0 0 1-.009-.064c-.023-.187-.023-.348-.023-.52V4.25a4.25 4.25 0 0 1 8.5 0c0 .14 0 .333-.04.596a4.25 4.25 0 0 1-.46 8.476 4.186 4.186 0 0 1-1.543-.298z"/>');// eslint-disable-next-line
var BIconSuitClubFill=/*#__PURE__*/makeIcon('SuitClubFill','<path d="M11.5 12.5a3.493 3.493 0 0 1-2.684-1.254 19.92 19.92 0 0 0 1.582 2.907c.231.35-.02.847-.438.847H6.04c-.419 0-.67-.497-.438-.847a19.919 19.919 0 0 0 1.582-2.907 3.5 3.5 0 1 1-2.538-5.743 3.5 3.5 0 1 1 6.708 0A3.5 3.5 0 1 1 11.5 12.5z"/>');// eslint-disable-next-line
var BIconSuitDiamond=/*#__PURE__*/makeIcon('SuitDiamond','<path d="M8.384 1.226a.463.463 0 0 0-.768 0l-4.56 6.468a.537.537 0 0 0 0 .612l4.56 6.469a.463.463 0 0 0 .768 0l4.56-6.469a.537.537 0 0 0 0-.612l-4.56-6.468zM6.848.613a1.39 1.39 0 0 1 2.304 0l4.56 6.468a1.61 1.61 0 0 1 0 1.838l-4.56 6.468a1.39 1.39 0 0 1-2.304 0L2.288 8.92a1.61 1.61 0 0 1 0-1.838L6.848.613z"/>');// eslint-disable-next-line
var BIconSuitDiamondFill=/*#__PURE__*/makeIcon('SuitDiamondFill','<path d="M2.45 7.4L7.2 1.067a1 1 0 0 1 1.6 0L13.55 7.4a1 1 0 0 1 0 1.2L8.8 14.933a1 1 0 0 1-1.6 0L2.45 8.6a1 1 0 0 1 0-1.2z"/>');// eslint-disable-next-line
var BIconSuitHeart=/*#__PURE__*/makeIcon('SuitHeart','<path d="M8 6.236l-.894-1.789c-.222-.443-.607-1.08-1.152-1.595C5.418 2.345 4.776 2 4 2 2.324 2 1 3.326 1 4.92c0 1.211.554 2.066 1.868 3.37.337.334.721.695 1.146 1.093C5.122 10.423 6.5 11.717 8 13.447c1.5-1.73 2.878-3.024 3.986-4.064.425-.398.81-.76 1.146-1.093C14.446 6.986 15 6.131 15 4.92 15 3.326 13.676 2 12 2c-.777 0-1.418.345-1.954.852-.545.515-.93 1.152-1.152 1.595L8 6.236zm.392 8.292a.513.513 0 0 1-.784 0c-1.601-1.902-3.05-3.262-4.243-4.381C1.3 8.208 0 6.989 0 4.92 0 2.755 1.79 1 4 1c1.6 0 2.719 1.05 3.404 2.008.26.365.458.716.596.992a7.55 7.55 0 0 1 .596-.992C9.281 2.049 10.4 1 12 1c2.21 0 4 1.755 4 3.92 0 2.069-1.3 3.288-3.365 5.227-1.193 1.12-2.642 2.48-4.243 4.38z"/>');// eslint-disable-next-line
var BIconSuitHeartFill=/*#__PURE__*/makeIcon('SuitHeartFill','<path d="M4 1c2.21 0 4 1.755 4 3.92C8 2.755 9.79 1 12 1s4 1.755 4 3.92c0 3.263-3.234 4.414-7.608 9.608a.513.513 0 0 1-.784 0C3.234 9.334 0 8.183 0 4.92 0 2.755 1.79 1 4 1z"/>');// eslint-disable-next-line
var BIconSuitSpade=/*#__PURE__*/makeIcon('SuitSpade','<path d="M8 0a.5.5 0 0 1 .429.243c1.359 2.265 2.925 3.682 4.25 4.882.096.086.19.17.282.255C14.308 6.604 15.5 7.747 15.5 9.5a4 4 0 0 1-5.406 3.746c.235.39.491.782.722 1.131.434.659-.01 1.623-.856 1.623H6.04c-.845 0-1.29-.964-.856-1.623.263-.397.51-.777.728-1.134A4 4 0 0 1 .5 9.5c0-1.753 1.192-2.896 2.539-4.12l.281-.255c1.326-1.2 2.892-2.617 4.251-4.882A.5.5 0 0 1 8 0zM3.711 6.12C2.308 7.396 1.5 8.253 1.5 9.5a3 3 0 0 0 5.275 1.956.5.5 0 0 1 .868.43c-.094.438-.33.932-.611 1.428a29.247 29.247 0 0 1-1.013 1.614.03.03 0 0 0-.005.018.074.074 0 0 0 .024.054h3.924a.074.074 0 0 0 .024-.054.03.03 0 0 0-.005-.018c-.3-.455-.658-1.005-.96-1.535-.294-.514-.57-1.064-.664-1.507a.5.5 0 0 1 .868-.43A3 3 0 0 0 14.5 9.5c0-1.247-.808-2.104-2.211-3.38L12 5.86c-1.196-1.084-2.668-2.416-4-4.424-1.332 2.008-2.804 3.34-4 4.422l-.289.261z"/>');// eslint-disable-next-line
var BIconSuitSpadeFill=/*#__PURE__*/makeIcon('SuitSpadeFill','<path d="M7.184 11.246A3.5 3.5 0 0 1 1 9c0-1.602 1.14-2.633 2.66-4.008C4.986 3.792 6.602 2.33 8 0c1.398 2.33 3.014 3.792 4.34 4.992C13.86 6.367 15 7.398 15 9a3.5 3.5 0 0 1-6.184 2.246 19.92 19.92 0 0 0 1.582 2.907c.231.35-.02.847-.438.847H6.04c-.419 0-.67-.497-.438-.847a19.919 19.919 0 0 0 1.582-2.907z"/>');// eslint-disable-next-line
var BIconSun=/*#__PURE__*/makeIcon('Sun','<path d="M3.5 8a4.5 4.5 0 1 1 9 0 4.5 4.5 0 0 1-9 0z"/><path d="M8.202.28a.25.25 0 0 0-.404 0l-.91 1.255a.25.25 0 0 1-.334.067L5.232.79a.25.25 0 0 0-.374.154l-.36 1.51a.25.25 0 0 1-.282.188l-1.532-.244a.25.25 0 0 0-.286.286l.244 1.532a.25.25 0 0 1-.189.282l-1.509.36a.25.25 0 0 0-.154.374l.812 1.322a.25.25 0 0 1-.067.333l-1.256.91a.25.25 0 0 0 0 .405l1.256.91a.25.25 0 0 1 .067.334L.79 10.768a.25.25 0 0 0 .154.374l1.51.36a.25.25 0 0 1 .188.282l-.244 1.532a.25.25 0 0 0 .286.286l1.532-.244a.25.25 0 0 1 .282.189l.36 1.508a.25.25 0 0 0 .374.155l1.322-.812a.25.25 0 0 1 .333.067l.91 1.256a.25.25 0 0 0 .405 0l.91-1.256a.25.25 0 0 1 .334-.067l1.322.812a.25.25 0 0 0 .374-.155l.36-1.508a.25.25 0 0 1 .282-.19l1.532.245a.25.25 0 0 0 .286-.286l-.244-1.532a.25.25 0 0 1 .189-.282l1.508-.36a.25.25 0 0 0 .155-.374l-.812-1.322a.25.25 0 0 1 .067-.333l1.256-.91a.25.25 0 0 0 0-.405l-1.256-.91a.25.25 0 0 1-.067-.334l.812-1.322a.25.25 0 0 0-.155-.374l-1.508-.36a.25.25 0 0 1-.19-.282l.245-1.532a.25.25 0 0 0-.286-.286l-1.532.244a.25.25 0 0 1-.282-.189l-.36-1.509a.25.25 0 0 0-.374-.154l-1.322.812a.25.25 0 0 1-.333-.067L8.203.28zM8 2.5a5.5 5.5 0 1 1 0 11 5.5 5.5 0 0 1 0-11z"/>');// eslint-disable-next-line
var BIconSunglasses=/*#__PURE__*/makeIcon('Sunglasses','<path d="M3 5a2 2 0 0 0-2 2v.5H.5a.5.5 0 0 0 0 1H1V9a2 2 0 0 0 2 2h1a3 3 0 0 0 3-3 1 1 0 1 1 2 0 3 3 0 0 0 3 3h1a2 2 0 0 0 2-2v-.5h.5a.5.5 0 0 0 0-1H15V7a2 2 0 0 0-2-2h-2a2 2 0 0 0-1.888 1.338A1.99 1.99 0 0 0 8 6a1.99 1.99 0 0 0-1.112.338A2 2 0 0 0 5 5H3zm0 1h.941c.264 0 .348.356.112.474l-.457.228a2 2 0 0 0-.894.894l-.228.457C2.356 8.289 2 8.205 2 7.94V7a1 1 0 0 1 1-1z"/>');// eslint-disable-next-line
var BIconTable=/*#__PURE__*/makeIcon('Table','<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm15 2h-4v3h4V4zm0 4h-4v3h4V8zm0 4h-4v3h3a1 1 0 0 0 1-1v-2zm-5 3v-3H6v3h4zm-5 0v-3H1v2a1 1 0 0 0 1 1h3zm-4-4h4V8H1v3zm0-4h4V4H1v3zm5-3v3h4V4H6zm4 4H6v3h4V8z"/>');// eslint-disable-next-line
var BIconTablet=/*#__PURE__*/makeIcon('Tablet','<path d="M12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M8 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>');// eslint-disable-next-line
var BIconTabletFill=/*#__PURE__*/makeIcon('TabletFill','<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm7 11a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>');// eslint-disable-next-line
var BIconTabletLandscape=/*#__PURE__*/makeIcon('TabletLandscape','<path d="M1 4a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4zm-1 8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8z"/><path d="M14 8a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>');// eslint-disable-next-line
var BIconTabletLandscapeFill=/*#__PURE__*/makeIcon('TabletLandscapeFill','<path d="M2 14a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2zm11-7a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>');// eslint-disable-next-line
var BIconTag=/*#__PURE__*/makeIcon('Tag','<path d="M6 4.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-1 0a.5.5 0 1 0-1 0 .5.5 0 0 0 1 0z"/><path d="M2 1h4.586a1 1 0 0 1 .707.293l7 7a1 1 0 0 1 0 1.414l-4.586 4.586a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 1 6.586V2a1 1 0 0 1 1-1zm0 5.586l7 7L13.586 9l-7-7H2v4.586z"/>');// eslint-disable-next-line
var BIconTagFill=/*#__PURE__*/makeIcon('TagFill','<path d="M2 1a1 1 0 0 0-1 1v4.586a1 1 0 0 0 .293.707l7 7a1 1 0 0 0 1.414 0l4.586-4.586a1 1 0 0 0 0-1.414l-7-7A1 1 0 0 0 6.586 1H2zm4 3.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconTags=/*#__PURE__*/makeIcon('Tags','<path d="M3 2v4.586l7 7L14.586 9l-7-7H3zM2 2a1 1 0 0 1 1-1h4.586a1 1 0 0 1 .707.293l7 7a1 1 0 0 1 0 1.414l-4.586 4.586a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 2 6.586V2z"/><path d="M5.5 5a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm0 1a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zM1 7.086a1 1 0 0 0 .293.707L8.75 15.25l-.043.043a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 0 7.586V3a1 1 0 0 1 1-1v5.086z"/>');// eslint-disable-next-line
var BIconTagsFill=/*#__PURE__*/makeIcon('TagsFill','<path d="M2 2a1 1 0 0 1 1-1h4.586a1 1 0 0 1 .707.293l7 7a1 1 0 0 1 0 1.414l-4.586 4.586a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 2 6.586V2zm3.5 4a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/><path d="M1.293 7.793A1 1 0 0 1 1 7.086V2a1 1 0 0 0-1 1v4.586a1 1 0 0 0 .293.707l7 7a1 1 0 0 0 1.414 0l.043-.043-7.457-7.457z"/>');// eslint-disable-next-line
var BIconTelephone=/*#__PURE__*/makeIcon('Telephone','<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>');// eslint-disable-next-line
var BIconTelephoneFill=/*#__PURE__*/makeIcon('TelephoneFill','<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>');// eslint-disable-next-line
var BIconTelephoneForward=/*#__PURE__*/makeIcon('TelephoneForward','<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zm10.762.135a.5.5 0 0 1 .708 0l2.5 2.5a.5.5 0 0 1 0 .708l-2.5 2.5a.5.5 0 0 1-.708-.708L14.293 4H9.5a.5.5 0 0 1 0-1h4.793l-1.647-1.646a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconTelephoneForwardFill=/*#__PURE__*/makeIcon('TelephoneForwardFill','<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zm10.761.135a.5.5 0 0 1 .708 0l2.5 2.5a.5.5 0 0 1 0 .708l-2.5 2.5a.5.5 0 0 1-.708-.708L14.293 4H9.5a.5.5 0 0 1 0-1h4.793l-1.647-1.646a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconTelephoneInbound=/*#__PURE__*/makeIcon('TelephoneInbound','<path d="M15.854.146a.5.5 0 0 1 0 .708L11.707 5H14.5a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 1 0v2.793L15.146.146a.5.5 0 0 1 .708 0zm-12.2 1.182a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>');// eslint-disable-next-line
var BIconTelephoneInboundFill=/*#__PURE__*/makeIcon('TelephoneInboundFill','<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM15.854.146a.5.5 0 0 1 0 .708L11.707 5H14.5a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 1 0v2.793L15.146.146a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconTelephoneMinus=/*#__PURE__*/makeIcon('TelephoneMinus','<path fill-rule="evenodd" d="M10 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/><path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>');// eslint-disable-next-line
var BIconTelephoneMinusFill=/*#__PURE__*/makeIcon('TelephoneMinusFill','<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM10 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTelephoneOutbound=/*#__PURE__*/makeIcon('TelephoneOutbound','<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM11 .5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V1.707l-4.146 4.147a.5.5 0 0 1-.708-.708L14.293 1H11.5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTelephoneOutboundFill=/*#__PURE__*/makeIcon('TelephoneOutboundFill','<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM11 .5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V1.707l-4.146 4.147a.5.5 0 0 1-.708-.708L14.293 1H11.5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTelephonePlus=/*#__PURE__*/makeIcon('TelephonePlus','<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/><path fill-rule="evenodd" d="M12.5 1a.5.5 0 0 1 .5.5V3h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V4h-1.5a.5.5 0 0 1 0-1H12V1.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconTelephonePlusFill=/*#__PURE__*/makeIcon('TelephonePlusFill','<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM12.5 1a.5.5 0 0 1 .5.5V3h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V4h-1.5a.5.5 0 0 1 0-1H12V1.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconTelephoneX=/*#__PURE__*/makeIcon('TelephoneX','<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/><path fill-rule="evenodd" d="M11.146 1.646a.5.5 0 0 1 .708 0L13 2.793l1.146-1.147a.5.5 0 0 1 .708.708L13.707 3.5l1.147 1.146a.5.5 0 0 1-.708.708L13 4.207l-1.146 1.147a.5.5 0 0 1-.708-.708L12.293 3.5l-1.147-1.146a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconTelephoneXFill=/*#__PURE__*/makeIcon('TelephoneXFill','<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zm9.261 1.135a.5.5 0 0 1 .708 0L13 2.793l1.146-1.147a.5.5 0 0 1 .708.708L13.707 3.5l1.147 1.146a.5.5 0 0 1-.708.708L13 4.207l-1.146 1.147a.5.5 0 0 1-.708-.708L12.293 3.5l-1.147-1.146a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconTerminal=/*#__PURE__*/makeIcon('Terminal','<path d="M6 9a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3A.5.5 0 0 1 6 9zM3.854 4.146a.5.5 0 1 0-.708.708L4.793 6.5 3.146 8.146a.5.5 0 1 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2z"/><path d="M2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2zm12 1a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h12z"/>');// eslint-disable-next-line
var BIconTerminalFill=/*#__PURE__*/makeIcon('TerminalFill','<path d="M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3zm9.5 5.5h-3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1zm-6.354-.354a.5.5 0 1 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2a.5.5 0 1 0-.708.708L4.793 6.5 3.146 8.146z"/>');// eslint-disable-next-line
var BIconTextCenter=/*#__PURE__*/makeIcon('TextCenter','<path fill-rule="evenodd" d="M4 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm2-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTextIndentLeft=/*#__PURE__*/makeIcon('TextIndentLeft','<path d="M2 3.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm.646 2.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L4.293 8 2.646 6.354a.5.5 0 0 1 0-.708zM7 6.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm-5 3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTextIndentRight=/*#__PURE__*/makeIcon('TextIndentRight','<path d="M2 3.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm10.646 2.146a.5.5 0 0 1 .708.708L11.707 8l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zM2 6.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTextLeft=/*#__PURE__*/makeIcon('TextLeft','<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTextParagraph=/*#__PURE__*/makeIcon('TextParagraph','<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm4-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTextRight=/*#__PURE__*/makeIcon('TextRight','<path fill-rule="evenodd" d="M6 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-4-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm4-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-4-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconTextarea=/*#__PURE__*/makeIcon('Textarea','<path d="M1.5 2.5A1.5 1.5 0 0 1 3 1h10a1.5 1.5 0 0 1 1.5 1.5v3.563a2 2 0 0 1 0 3.874V13.5A1.5 1.5 0 0 1 13 15H3a1.5 1.5 0 0 1-1.5-1.5V9.937a2 2 0 0 1 0-3.874V2.5zm1 3.563a2 2 0 0 1 0 3.874V13.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5V9.937a2 2 0 0 1 0-3.874V2.5A.5.5 0 0 0 13 2H3a.5.5 0 0 0-.5.5v3.563zM2 7a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm12 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>');// eslint-disable-next-line
var BIconTextareaResize=/*#__PURE__*/makeIcon('TextareaResize','<path d="M.5 4A2.5 2.5 0 0 1 3 1.5h12A2.5 2.5 0 0 1 17.5 4v8a2.5 2.5 0 0 1-2.5 2.5H3A2.5 2.5 0 0 1 .5 12V4zM3 2.5A1.5 1.5 0 0 0 1.5 4v8A1.5 1.5 0 0 0 3 13.5h12a1.5 1.5 0 0 0 1.5-1.5V4A1.5 1.5 0 0 0 15 2.5H3zm11.854 5.646a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708-.708l3-3a.5.5 0 0 1 .708 0zm0 2.5a.5.5 0 0 1 0 .708l-.5.5a.5.5 0 0 1-.708-.708l.5-.5a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconTextareaT=/*#__PURE__*/makeIcon('TextareaT','<path d="M1.5 2.5A1.5 1.5 0 0 1 3 1h10a1.5 1.5 0 0 1 1.5 1.5v3.563a2 2 0 0 1 0 3.874V13.5A1.5 1.5 0 0 1 13 15H3a1.5 1.5 0 0 1-1.5-1.5V9.937a2 2 0 0 1 0-3.874V2.5zm1 3.563a2 2 0 0 1 0 3.874V13.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5V9.937a2 2 0 0 1 0-3.874V2.5A.5.5 0 0 0 13 2H3a.5.5 0 0 0-.5.5v3.563zM2 7a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm12 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/><path d="M11.434 4H4.566L4.5 5.994h.386c.21-1.252.612-1.446 2.173-1.495l.343-.011v6.343c0 .537-.116.665-1.049.748V12h3.294v-.421c-.938-.083-1.054-.21-1.054-.748V4.488l.348.01c1.56.05 1.963.244 2.173 1.496h.386L11.434 4z"/>');// eslint-disable-next-line
var BIconThermometer=/*#__PURE__*/makeIcon('Thermometer','<path d="M6 2a2 2 0 1 1 4 0v7.627a3.5 3.5 0 1 1-4 0V2zm2-1a1 1 0 0 0-1 1v7.901a.5.5 0 0 1-.25.433A2.499 2.499 0 0 0 8 15a2.5 2.5 0 0 0 1.25-4.666.5.5 0 0 1-.25-.433V2a1 1 0 0 0-1-1z"/><path d="M9.5 12.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconThermometerHalf=/*#__PURE__*/makeIcon('ThermometerHalf','<path d="M8 1.75a.25.25 0 0 1 .25.25v9.02a1.5 1.5 0 1 1-.5 0V2A.25.25 0 0 1 8 1.75z"/><path d="M6 2a2 2 0 1 1 4 0v7.627a3.5 3.5 0 1 1-4 0V2zm2-1a1 1 0 0 0-1 1v7.901a.5.5 0 0 1-.25.433A2.499 2.499 0 0 0 8 15a2.5 2.5 0 0 0 1.25-4.666.5.5 0 0 1-.25-.433V2a1 1 0 0 0-1-1z"/>');// eslint-disable-next-line
var BIconThreeDots=/*#__PURE__*/makeIcon('ThreeDots','<path d="M3 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm5 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm5 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconThreeDotsVertical=/*#__PURE__*/makeIcon('ThreeDotsVertical','<path d="M9.5 13a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>');// eslint-disable-next-line
var BIconToggle2Off=/*#__PURE__*/makeIcon('Toggle2Off','<path d="M9 11c.628-.836 1-1.874 1-3a4.978 4.978 0 0 0-1-3h4a3 3 0 1 1 0 6H9z"/><path d="M5 12a4 4 0 1 1 0-8 4 4 0 0 1 0 8zm0 1A5 5 0 1 0 5 3a5 5 0 0 0 0 10z"/>');// eslint-disable-next-line
var BIconToggle2On=/*#__PURE__*/makeIcon('Toggle2On','<path d="M7 5H3a3 3 0 0 0 0 6h4a4.995 4.995 0 0 1-.584-1H3a2 2 0 1 1 0-4h3.416c.156-.357.352-.692.584-1z"/><path d="M16 8A5 5 0 1 1 6 8a5 5 0 0 1 10 0z"/>');// eslint-disable-next-line
var BIconToggleOff=/*#__PURE__*/makeIcon('ToggleOff','<path d="M11 4a4 4 0 0 1 0 8H8a4.992 4.992 0 0 0 2-4 4.992 4.992 0 0 0-2-4h3zm-6 8a4 4 0 1 1 0-8 4 4 0 0 1 0 8zM0 8a5 5 0 0 0 5 5h6a5 5 0 0 0 0-10H5a5 5 0 0 0-5 5z"/>');// eslint-disable-next-line
var BIconToggleOn=/*#__PURE__*/makeIcon('ToggleOn','<path d="M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10H5zm6 9a4 4 0 1 1 0-8 4 4 0 0 1 0 8z"/>');// eslint-disable-next-line
var BIconToggles=/*#__PURE__*/makeIcon('Toggles','<path d="M4.5 9a3.5 3.5 0 1 0 0 7h7a3.5 3.5 0 1 0 0-7h-7zm7 6a2.5 2.5 0 1 1 0-5 2.5 2.5 0 0 1 0 5zm-7-14a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5zm2.45 0A3.49 3.49 0 0 1 8 3.5 3.49 3.49 0 0 1 6.95 6h4.55a2.5 2.5 0 0 0 0-5H6.95zM4.5 0h7a3.5 3.5 0 1 1 0 7h-7a3.5 3.5 0 1 1 0-7z"/>');// eslint-disable-next-line
var BIconToggles2=/*#__PURE__*/makeIcon('Toggles2','<path d="M9.465 10H12a2 2 0 1 1 0 4H9.465c.34-.588.535-1.271.535-2 0-.729-.195-1.412-.535-2z"/><path d="M6 15a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm0 1a4 4 0 1 1 0-8 4 4 0 0 1 0 8zm.535-10a3.975 3.975 0 0 1-.409-1H4a1 1 0 0 1 0-2h2.126c.091-.355.23-.69.41-1H4a2 2 0 1 0 0 4h2.535z"/><path d="M14 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0z"/>');// eslint-disable-next-line
var BIconTools=/*#__PURE__*/makeIcon('Tools','<path d="M1 0L0 1l2.2 3.081a1 1 0 0 0 .815.419h.07a1 1 0 0 1 .708.293l2.675 2.675-2.617 2.654A3.003 3.003 0 0 0 0 13a3 3 0 1 0 5.878-.851l2.654-2.617.968.968-.305.914a1 1 0 0 0 .242 1.023l3.356 3.356a1 1 0 0 0 1.414 0l1.586-1.586a1 1 0 0 0 0-1.414l-3.356-3.356a1 1 0 0 0-1.023-.242L10.5 9.5l-.96-.96 2.68-2.643A3.005 3.005 0 0 0 16 3c0-.269-.035-.53-.102-.777l-2.14 2.141L12 4l-.364-1.757L13.777.102a3 3 0 0 0-3.675 3.68L7.462 6.46 4.793 3.793a1 1 0 0 1-.293-.707v-.071a1 1 0 0 0-.419-.814L1 0zm9.646 10.646a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708zM3 11l.471.242.529.026.287.445.445.287.026.529L5 13l-.242.471-.026.529-.445.287-.287.445-.529.026L3 15l-.471-.242L2 14.732l-.287-.445L1.268 14l-.026-.529L1 13l.242-.471.026-.529.445-.287.287-.445.529-.026L3 11z"/>');// eslint-disable-next-line
var BIconTrash=/*#__PURE__*/makeIcon('Trash','<path d="M5.5 5.5A.5.5 0 0 1 6 6v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm2.5 0a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm3 .5a.5.5 0 0 0-1 0v6a.5.5 0 0 0 1 0V6z"/><path fill-rule="evenodd" d="M14.5 3a1 1 0 0 1-1 1H13v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V4h-.5a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1H6a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1h3.5a1 1 0 0 1 1 1v1zM4.118 4L4 4.059V13a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1V4.059L11.882 4H4.118zM2.5 3V2h11v1h-11z"/>');// eslint-disable-next-line
var BIconTrash2=/*#__PURE__*/makeIcon('Trash2','<path d="M14 3a.702.702 0 0 1-.037.225l-1.684 10.104A2 2 0 0 1 10.305 15H5.694a2 2 0 0 1-1.973-1.671L2.037 3.225A.703.703 0 0 1 2 3c0-1.105 2.686-2 6-2s6 .895 6 2zM3.215 4.207l1.493 8.957a1 1 0 0 0 .986.836h4.612a1 1 0 0 0 .986-.836l1.493-8.957C11.69 4.689 9.954 5 8 5c-1.954 0-3.69-.311-4.785-.793z"/>');// eslint-disable-next-line
var BIconTrash2Fill=/*#__PURE__*/makeIcon('Trash2Fill','<path d="M2.037 3.225A.703.703 0 0 1 2 3c0-1.105 2.686-2 6-2s6 .895 6 2a.702.702 0 0 1-.037.225l-1.684 10.104A2 2 0 0 1 10.305 15H5.694a2 2 0 0 1-1.973-1.671L2.037 3.225zm9.89-.69C10.966 2.214 9.578 2 8 2c-1.58 0-2.968.215-3.926.534-.477.16-.795.327-.975.466.18.14.498.307.975.466C5.032 3.786 6.42 4 8 4s2.967-.215 3.926-.534c.477-.16.795-.327.975-.466-.18-.14-.498-.307-.975-.466z"/>');// eslint-disable-next-line
var BIconTrashFill=/*#__PURE__*/makeIcon('TrashFill','<path d="M2.5 1a1 1 0 0 0-1 1v1a1 1 0 0 0 1 1H3v9a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V4h.5a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H10a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1H2.5zm3 4a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 .5-.5zM8 5a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7A.5.5 0 0 1 8 5zm3 .5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 1 0z"/>');// eslint-disable-next-line
var BIconTree=/*#__PURE__*/makeIcon('Tree','<path d="M8.416.223a.5.5 0 0 0-.832 0l-3 4.5A.5.5 0 0 0 5 5.5h.098L3.076 8.735A.5.5 0 0 0 3.5 9.5h.191l-1.638 3.276a.5.5 0 0 0 .447.724H7V16h2v-2.5h4.5a.5.5 0 0 0 .447-.724L12.31 9.5h.191a.5.5 0 0 0 .424-.765L10.902 5.5H11a.5.5 0 0 0 .416-.777l-3-4.5zM6.437 4.758A.5.5 0 0 0 6 4.5h-.066L8 1.401 10.066 4.5H10a.5.5 0 0 0-.424.765L11.598 8.5H11.5a.5.5 0 0 0-.447.724L12.69 12.5H3.309l1.638-3.276A.5.5 0 0 0 4.5 8.5h-.098l2.022-3.235a.5.5 0 0 0 .013-.507z"/>');// eslint-disable-next-line
var BIconTreeFill=/*#__PURE__*/makeIcon('TreeFill','<path d="M8.416.223a.5.5 0 0 0-.832 0l-3 4.5A.5.5 0 0 0 5 5.5h.098L3.076 8.735A.5.5 0 0 0 3.5 9.5h.191l-1.638 3.276a.5.5 0 0 0 .447.724H7V16h2v-2.5h4.5a.5.5 0 0 0 .447-.724L12.31 9.5h.191a.5.5 0 0 0 .424-.765L10.902 5.5H11a.5.5 0 0 0 .416-.777l-3-4.5z"/>');// eslint-disable-next-line
var BIconTriangle=/*#__PURE__*/makeIcon('Triangle','<path d="M7.938 2.016A.13.13 0 0 1 8.002 2a.13.13 0 0 1 .063.016.146.146 0 0 1 .054.057l6.857 11.667c.036.06.035.124.002.183a.163.163 0 0 1-.054.06.116.116 0 0 1-.066.017H1.146a.115.115 0 0 1-.066-.017.163.163 0 0 1-.054-.06.176.176 0 0 1 .002-.183L7.884 2.073a.147.147 0 0 1 .054-.057zm1.044-.45a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566z"/>');// eslint-disable-next-line
var BIconTriangleFill=/*#__PURE__*/makeIcon('TriangleFill','<path fill-rule="evenodd" d="M7.022 1.566a1.13 1.13 0 0 1 1.96 0l6.857 11.667c.457.778-.092 1.767-.98 1.767H1.144c-.889 0-1.437-.99-.98-1.767L7.022 1.566z"/>');// eslint-disable-next-line
var BIconTriangleHalf=/*#__PURE__*/makeIcon('TriangleHalf','<path d="M8.065 2.016A.13.13 0 0 0 8.002 2v11.983l6.856.017a.12.12 0 0 0 .066-.017.162.162 0 0 0 .055-.06.177.177 0 0 0-.003-.183L8.12 2.073a.146.146 0 0 0-.054-.057zm-1.043-.45a1.13 1.13 0 0 1 1.96 0l6.857 11.667c.457.778-.092 1.767-.98 1.767H1.144c-.889 0-1.437-.99-.98-1.767L7.022 1.566z"/>');// eslint-disable-next-line
var BIconTrophy=/*#__PURE__*/makeIcon('Trophy','<path d="M2.5.5A.5.5 0 0 1 3 0h10a.5.5 0 0 1 .5.5c0 .538-.012 1.05-.034 1.536a3 3 0 1 1-1.133 5.89c-.79 1.865-1.878 2.777-2.833 3.011v2.173l1.425.356c.194.048.377.135.537.255L13.3 15.1a.5.5 0 0 1-.3.9H3a.5.5 0 0 1-.3-.9l1.838-1.379c.16-.12.343-.207.537-.255L6.5 13.11v-2.173c-.955-.234-2.043-1.146-2.833-3.012a3 3 0 1 1-1.132-5.89A33.076 33.076 0 0 1 2.5.5zm.099 2.54a2 2 0 0 0 .72 3.935c-.333-1.05-.588-2.346-.72-3.935zm10.083 3.935a2 2 0 0 0 .72-3.935c-.133 1.59-.388 2.885-.72 3.935zM3.504 1c.007.517.026 1.006.056 1.469.13 2.028.457 3.546.87 4.667C5.294 9.48 6.484 10 7 10a.5.5 0 0 1 .5.5v2.61a1 1 0 0 1-.757.97l-1.426.356a.5.5 0 0 0-.179.085L4.5 15h7l-.638-.479a.501.501 0 0 0-.18-.085l-1.425-.356a1 1 0 0 1-.757-.97V10.5A.5.5 0 0 1 9 10c.516 0 1.706-.52 2.57-2.864.413-1.12.74-2.64.87-4.667.03-.463.049-.952.056-1.469H3.504z"/>');// eslint-disable-next-line
var BIconTrophyFill=/*#__PURE__*/makeIcon('TrophyFill','<path d="M2.5.5A.5.5 0 0 1 3 0h10a.5.5 0 0 1 .5.5c0 .538-.012 1.05-.034 1.536a3 3 0 1 1-1.133 5.89c-.79 1.865-1.878 2.777-2.833 3.011v2.173l1.425.356c.194.048.377.135.537.255L13.3 15.1a.5.5 0 0 1-.3.9H3a.5.5 0 0 1-.3-.9l1.838-1.379c.16-.12.343-.207.537-.255L6.5 13.11v-2.173c-.955-.234-2.043-1.146-2.833-3.012a3 3 0 1 1-1.132-5.89A33.076 33.076 0 0 1 2.5.5zm.099 2.54a2 2 0 0 0 .72 3.935c-.333-1.05-.588-2.346-.72-3.935zm10.083 3.935a2 2 0 0 0 .72-3.935c-.133 1.59-.388 2.885-.72 3.935z"/>');// eslint-disable-next-line
var BIconTruck=/*#__PURE__*/makeIcon('Truck','<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h9A1.5 1.5 0 0 1 12 3.5V5h1.02a1.5 1.5 0 0 1 1.17.563l1.481 1.85a1.5 1.5 0 0 1 .329.938V10.5a1.5 1.5 0 0 1-1.5 1.5H14a2 2 0 1 1-4 0H5a2 2 0 1 1-3.998-.085A1.5 1.5 0 0 1 0 10.5v-7zm1.294 7.456A1.999 1.999 0 0 1 4.732 11h5.536a2.01 2.01 0 0 1 .732-.732V3.5a.5.5 0 0 0-.5-.5h-9a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .294.456zM12 10a2 2 0 0 1 1.732 1h.768a.5.5 0 0 0 .5-.5V8.35a.5.5 0 0 0-.11-.312l-1.48-1.85A.5.5 0 0 0 13.02 6H12v4zm-9 1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm9 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>');// eslint-disable-next-line
var BIconTruckFlatbed=/*#__PURE__*/makeIcon('TruckFlatbed','<path d="M11.5 4a.5.5 0 0 1 .5.5V5h1.02a1.5 1.5 0 0 1 1.17.563l1.481 1.85a1.5 1.5 0 0 1 .329.938V10.5a1.5 1.5 0 0 1-1.5 1.5H14a2 2 0 1 1-4 0H5a2 2 0 1 1-4 0 1 1 0 0 1-1-1v-1h11V4.5a.5.5 0 0 1 .5-.5zM3 11a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm9 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm1.732 0h.768a.5.5 0 0 0 .5-.5V8.35a.5.5 0 0 0-.11-.312l-1.48-1.85A.5.5 0 0 0 13.02 6H12v4a2 2 0 0 1 1.732 1z"/>');// eslint-disable-next-line
var BIconTv=/*#__PURE__*/makeIcon('Tv','<path d="M2.5 13.5A.5.5 0 0 1 3 13h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zM13.991 3l.024.001a1.46 1.46 0 0 1 .538.143.757.757 0 0 1 .302.254c.067.1.145.277.145.602v5.991l-.001.024a1.464 1.464 0 0 1-.143.538.758.758 0 0 1-.254.302c-.1.067-.277.145-.602.145H2.009l-.024-.001a1.464 1.464 0 0 1-.538-.143.758.758 0 0 1-.302-.254C1.078 10.502 1 10.325 1 10V4.009l.001-.024a1.46 1.46 0 0 1 .143-.538.758.758 0 0 1 .254-.302C1.498 3.078 1.675 3 2 3h11.991zM14 2H2C0 2 0 4 0 4v6c0 2 2 2 2 2h12c2 0 2-2 2-2V4c0-2-2-2-2-2z"/>');// eslint-disable-next-line
var BIconTvFill=/*#__PURE__*/makeIcon('TvFill','<path d="M2.5 13.5A.5.5 0 0 1 3 13h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zM2 2h12s2 0 2 2v6s0 2-2 2H2s-2 0-2-2V4s0-2 2-2z"/>');// eslint-disable-next-line
var BIconTwitch=/*#__PURE__*/makeIcon('Twitch','<path d="M3.857 0L1 2.857v10.286h3.429V16l2.857-2.857H9.57L14.714 8V0H3.857zm9.714 7.429l-2.285 2.285H9l-2 2v-2H4.429V1.143h9.142v6.286z"/><path d="M11.857 3.143h-1.143V6.57h1.143V3.143zm-3.143 0H7.571V6.57h1.143V3.143z"/>');// eslint-disable-next-line
var BIconTwitter=/*#__PURE__*/makeIcon('Twitter','<path d="M5.026 15c6.038 0 9.341-5.003 9.341-9.334 0-.14 0-.282-.006-.422A6.685 6.685 0 0 0 16 3.542a6.658 6.658 0 0 1-1.889.518 3.301 3.301 0 0 0 1.447-1.817 6.533 6.533 0 0 1-2.087.793A3.286 3.286 0 0 0 7.875 6.03a9.325 9.325 0 0 1-6.767-3.429 3.289 3.289 0 0 0 1.018 4.382A3.323 3.323 0 0 1 .64 6.575v.045a3.288 3.288 0 0 0 2.632 3.218 3.203 3.203 0 0 1-.865.115 3.23 3.23 0 0 1-.614-.057 3.283 3.283 0 0 0 3.067 2.277A6.588 6.588 0 0 1 .78 13.58a6.32 6.32 0 0 1-.78-.045A9.344 9.344 0 0 0 5.026 15z"/>');// eslint-disable-next-line
var BIconType=/*#__PURE__*/makeIcon('Type','<path d="M2.244 13.081l.943-2.803H6.66l.944 2.803H8.86L5.54 3.75H4.322L1 13.081h1.244zm2.7-7.923L6.34 9.314H3.51l1.4-4.156h.034zm9.146 7.027h.035v.896h1.128V8.125c0-1.51-1.114-2.345-2.646-2.345-1.736 0-2.59.916-2.666 2.174h1.108c.068-.718.595-1.19 1.517-1.19.971 0 1.518.52 1.518 1.464v.731H12.19c-1.647.007-2.522.8-2.522 2.058 0 1.319.957 2.18 2.345 2.18 1.06 0 1.716-.43 2.078-1.011zm-1.763.035c-.752 0-1.456-.397-1.456-1.244 0-.65.424-1.115 1.408-1.115h1.805v.834c0 .896-.752 1.525-1.757 1.525z"/>');// eslint-disable-next-line
var BIconTypeBold=/*#__PURE__*/makeIcon('TypeBold','<path d="M8.21 13c2.106 0 3.412-1.087 3.412-2.823 0-1.306-.984-2.283-2.324-2.386v-.055a2.176 2.176 0 0 0 1.852-2.14c0-1.51-1.162-2.46-3.014-2.46H3.843V13H8.21zM5.908 4.674h1.696c.963 0 1.517.451 1.517 1.244 0 .834-.629 1.32-1.73 1.32H5.908V4.673zm0 6.788V8.598h1.73c1.217 0 1.88.492 1.88 1.415 0 .943-.643 1.449-1.832 1.449H5.907z"/>');// eslint-disable-next-line
var BIconTypeH1=/*#__PURE__*/makeIcon('TypeH1','<path d="M8.637 13V3.669H7.379V7.62H2.758V3.67H1.5V13h1.258V8.728h4.62V13h1.259zm5.329 0V3.669h-1.244L10.5 5.316v1.265l2.16-1.565h.062V13h1.244z"/>');// eslint-disable-next-line
var BIconTypeH2=/*#__PURE__*/makeIcon('TypeH2','<path d="M7.638 13V3.669H6.38V7.62H1.759V3.67H.5V13h1.258V8.728h4.62V13h1.259zm3.022-6.733v-.048c0-.889.63-1.668 1.716-1.668.957 0 1.675.608 1.675 1.572 0 .855-.554 1.504-1.067 2.085l-3.513 3.999V13H15.5v-1.094h-4.245v-.075l2.481-2.844c.875-.998 1.586-1.784 1.586-2.953 0-1.463-1.155-2.556-2.919-2.556-1.941 0-2.966 1.326-2.966 2.74v.049h1.223z"/>');// eslint-disable-next-line
var BIconTypeH3=/*#__PURE__*/makeIcon('TypeH3','<path d="M7.637 13V3.669H6.379V7.62H1.758V3.67H.5V13h1.258V8.728h4.62V13h1.259zm3.625-4.272h1.018c1.142 0 1.935.67 1.949 1.674.013 1.005-.78 1.737-2.01 1.73-1.08-.007-1.853-.588-1.935-1.32H9.108c.069 1.327 1.224 2.386 3.083 2.386 1.935 0 3.343-1.155 3.309-2.789-.027-1.51-1.251-2.16-2.037-2.249v-.068c.704-.123 1.764-.91 1.723-2.229-.035-1.353-1.176-2.4-2.954-2.385-1.873.006-2.857 1.162-2.898 2.358h1.196c.062-.69.711-1.299 1.696-1.299.998 0 1.695.622 1.695 1.525.007.922-.718 1.592-1.695 1.592h-.964v1.074z"/>');// eslint-disable-next-line
var BIconTypeItalic=/*#__PURE__*/makeIcon('TypeItalic','<path d="M7.991 11.674L9.53 4.455c.123-.595.246-.71 1.347-.807l.11-.52H7.211l-.11.52c1.06.096 1.128.212 1.005.807L6.57 11.674c-.123.595-.246.71-1.346.806l-.11.52h3.774l.11-.52c-1.06-.095-1.129-.211-1.006-.806z"/>');// eslint-disable-next-line
var BIconTypeStrikethrough=/*#__PURE__*/makeIcon('TypeStrikethrough','<path d="M6.333 5.686c0 .31.083.581.27.814H5.166a2.776 2.776 0 0 1-.099-.76c0-1.627 1.436-2.768 3.48-2.768 1.969 0 3.39 1.175 3.445 2.85h-1.23c-.11-1.08-.964-1.743-2.25-1.743-1.23 0-2.18.602-2.18 1.607zm2.194 7.478c-2.153 0-3.589-1.107-3.705-2.81h1.23c.144 1.06 1.129 1.703 2.544 1.703 1.34 0 2.31-.705 2.31-1.675 0-.827-.547-1.374-1.914-1.675L8.046 8.5H1v-1h14v1h-3.504c.468.437.675.994.675 1.697 0 1.826-1.436 2.967-3.644 2.967z"/>');// eslint-disable-next-line
var BIconTypeUnderline=/*#__PURE__*/makeIcon('TypeUnderline','<path d="M5.313 3.136h-1.23V9.54c0 2.105 1.47 3.623 3.917 3.623s3.917-1.518 3.917-3.623V3.136h-1.23v6.323c0 1.49-.978 2.57-2.687 2.57-1.709 0-2.687-1.08-2.687-2.57V3.136zM12.5 15h-9v-1h9v1z"/>');// eslint-disable-next-line
var BIconUiChecks=/*#__PURE__*/makeIcon('UiChecks','<path d="M7 2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zM2 1a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2zm0 8a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2v-2a2 2 0 0 0-2-2H2zm.854-3.646a.5.5 0 0 1-.708 0l-1-1a.5.5 0 1 1 .708-.708l.646.647 1.646-1.647a.5.5 0 1 1 .708.708l-2 2zm0 8a.5.5 0 0 1-.708 0l-1-1a.5.5 0 0 1 .708-.708l.646.647 1.646-1.647a.5.5 0 0 1 .708.708l-2 2zM7 10.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zm0-5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>');// eslint-disable-next-line
var BIconUiChecksGrid=/*#__PURE__*/makeIcon('UiChecksGrid','<path d="M2 10h3a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-3a1 1 0 0 1 1-1zm9-9h3a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-3a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1zm0 9a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h3a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1h-3zm0-10a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h3a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2h-3zM2 9a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h3a2 2 0 0 0 2-2v-3a2 2 0 0 0-2-2H2zm7 2a2 2 0 0 1 2-2h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2h-3a2 2 0 0 1-2-2v-3zM0 2a2 2 0 0 1 2-2h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm5.354.854a.5.5 0 1 0-.708-.708L3 3.793l-.646-.647a.5.5 0 1 0-.708.708l1 1a.5.5 0 0 0 .708 0l2-2z"/>');// eslint-disable-next-line
var BIconUiRadios=/*#__PURE__*/makeIcon('UiRadios','<path d="M7 2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zM0 12a3 3 0 1 1 6 0 3 3 0 0 1-6 0zm7-1.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zm0-5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zM3 1a3 3 0 1 0 0 6 3 3 0 0 0 0-6zm0 4.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>');// eslint-disable-next-line
var BIconUiRadiosGrid=/*#__PURE__*/makeIcon('UiRadiosGrid','<path d="M3.5 15a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5zm9-9a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5zm0 9a2.5 2.5 0 1 1 0-5 2.5 2.5 0 0 1 0 5zM16 3.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0zm-9 9a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0zm5.5 3.5a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7zm-9-11a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm0 2a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7z"/>');// eslint-disable-next-line
var BIconUnion=/*#__PURE__*/makeIcon('Union','<path d="M3 6a.5.5 0 0 0-.496.438l-.5 4A.5.5 0 0 0 2.5 11h3v2.016c-.863.055-1.5.251-1.5.484 0 .276.895.5 2 .5s2-.224 2-.5c0-.233-.637-.429-1.5-.484V11h3a.5.5 0 0 0 .496-.562l-.5-4A.5.5 0 0 0 9 6H3zm2 3.78V7.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 5 9.778z"/><path d="M12 14V4.5L7.5 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM7.5 3A1.5 1.5 0 0 0 9 4.5h2V14a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>');// eslint-disable-next-line
var BIconUnlock=/*#__PURE__*/makeIcon('Unlock','<path d="M11 1a2 2 0 0 0-2 2v4a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V9a2 2 0 0 1 2-2h5V3a3 3 0 0 1 6 0v4a.5.5 0 0 1-1 0V3a2 2 0 0 0-2-2zM3 8a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1H3z"/>');// eslint-disable-next-line
var BIconUnlockFill=/*#__PURE__*/makeIcon('UnlockFill','<path d="M11 1a2 2 0 0 0-2 2v4a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V9a2 2 0 0 1 2-2h5V3a3 3 0 0 1 6 0v4a.5.5 0 0 1-1 0V3a2 2 0 0 0-2-2z"/>');// eslint-disable-next-line
var BIconUpc=/*#__PURE__*/makeIcon('Upc','<path d="M3 4.5a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-7zm3 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7z"/>');// eslint-disable-next-line
var BIconUpcScan=/*#__PURE__*/makeIcon('UpcScan','<path d="M1.5 1a.5.5 0 0 0-.5.5v3a.5.5 0 0 1-1 0v-3A1.5 1.5 0 0 1 1.5 0h3a.5.5 0 0 1 0 1h-3zM11 .5a.5.5 0 0 1 .5-.5h3A1.5 1.5 0 0 1 16 1.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 1-.5-.5zM.5 11a.5.5 0 0 1 .5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 1 0 1h-3A1.5 1.5 0 0 1 0 14.5v-3a.5.5 0 0 1 .5-.5zm15 0a.5.5 0 0 1 .5.5v3a1.5 1.5 0 0 1-1.5 1.5h-3a.5.5 0 0 1 0-1h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 1 .5-.5zM3 4.5a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-7zm3 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7z"/>');// eslint-disable-next-line
var BIconUpload=/*#__PURE__*/makeIcon('Upload','<path d="M.5 9.9a.5.5 0 0 1 .5.5v2.5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0v2.5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5z"/><path d="M7.646 1.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 2.707V11.5a.5.5 0 0 1-1 0V2.707L5.354 4.854a.5.5 0 1 1-.708-.708l3-3z"/>');// eslint-disable-next-line
var BIconVectorPen=/*#__PURE__*/makeIcon('VectorPen','<path fill-rule="evenodd" d="M10.646.646a.5.5 0 0 1 .708 0l4 4a.5.5 0 0 1 0 .708l-1.902 1.902-.829 3.313a1.5 1.5 0 0 1-1.024 1.073L1.254 14.746 4.358 4.4A1.5 1.5 0 0 1 5.43 3.377l3.313-.828L10.646.646zm-1.8 2.908l-3.173.793a.5.5 0 0 0-.358.342l-2.57 8.565 8.567-2.57a.5.5 0 0 0 .34-.357l.794-3.174-3.6-3.6z"/><path fill-rule="evenodd" d="M2.832 13.228L8 9a1 1 0 1 0-1-1l-4.228 5.168-.026.086.086-.026z"/>');// eslint-disable-next-line
var BIconViewList=/*#__PURE__*/makeIcon('ViewList','<path d="M3 4.5h10a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2zm0 1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1H3zM1 2a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 2zm0 12a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 14z"/>');// eslint-disable-next-line
var BIconViewStacked=/*#__PURE__*/makeIcon('ViewStacked','<path d="M3 0h10a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2zm0 1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3zm0 8h10a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2zm0 1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1H3z"/>');// eslint-disable-next-line
var BIconVinyl=/*#__PURE__*/makeIcon('Vinyl','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8 6a2 2 0 1 0 0 4 2 2 0 0 0 0-4zM4 8a4 4 0 1 1 8 0 4 4 0 0 1-8 0z"/><path d="M9 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>');// eslint-disable-next-line
var BIconVinylFill=/*#__PURE__*/makeIcon('VinylFill','<path d="M8 6a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm0 3a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/><path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4 8a4 4 0 1 0 8 0 4 4 0 0 0-8 0z"/>');// eslint-disable-next-line
var BIconVoicemail=/*#__PURE__*/makeIcon('Voicemail','<path d="M7 8.5A3.49 3.49 0 0 1 5.95 11h4.1a3.5 3.5 0 1 1 2.45 1h-9A3.5 3.5 0 1 1 7 8.5zm-6 0a2.5 2.5 0 1 0 5 0 2.5 2.5 0 0 0-5 0zm14 0a2.5 2.5 0 1 0-5 0 2.5 2.5 0 0 0 5 0z"/>');// eslint-disable-next-line
var BIconVolumeDown=/*#__PURE__*/makeIcon('VolumeDown','<path d="M9 4a.5.5 0 0 0-.812-.39L5.825 5.5H3.5A.5.5 0 0 0 3 6v4a.5.5 0 0 0 .5.5h2.325l2.363 1.89A.5.5 0 0 0 9 12V4zM6.312 6.39L8 5.04v5.92L6.312 9.61A.5.5 0 0 0 6 9.5H4v-3h2a.5.5 0 0 0 .312-.11zM12.025 8a4.486 4.486 0 0 1-1.318 3.182L10 10.475A3.489 3.489 0 0 0 11.025 8 3.49 3.49 0 0 0 10 5.525l.707-.707A4.486 4.486 0 0 1 12.025 8z"/>');// eslint-disable-next-line
var BIconVolumeDownFill=/*#__PURE__*/makeIcon('VolumeDownFill','<path d="M9 4a.5.5 0 0 0-.812-.39L5.825 5.5H3.5A.5.5 0 0 0 3 6v4a.5.5 0 0 0 .5.5h2.325l2.363 1.89A.5.5 0 0 0 9 12V4zm3.025 4a4.486 4.486 0 0 1-1.318 3.182L10 10.475A3.489 3.489 0 0 0 11.025 8 3.49 3.49 0 0 0 10 5.525l.707-.707A4.486 4.486 0 0 1 12.025 8z"/>');// eslint-disable-next-line
var BIconVolumeMute=/*#__PURE__*/makeIcon('VolumeMute','<path d="M6.717 3.55A.5.5 0 0 1 7 4v8a.5.5 0 0 1-.812.39L3.825 10.5H1.5A.5.5 0 0 1 1 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06zM6 5.04L4.312 6.39A.5.5 0 0 1 4 6.5H2v3h2a.5.5 0 0 1 .312.11L6 10.96V5.04zm7.854.606a.5.5 0 0 1 0 .708L12.207 8l1.647 1.646a.5.5 0 0 1-.708.708L11.5 8.707l-1.646 1.647a.5.5 0 0 1-.708-.708L10.793 8 9.146 6.354a.5.5 0 1 1 .708-.708L11.5 7.293l1.646-1.647a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconVolumeMuteFill=/*#__PURE__*/makeIcon('VolumeMuteFill','<path d="M6.717 3.55A.5.5 0 0 1 7 4v8a.5.5 0 0 1-.812.39L3.825 10.5H1.5A.5.5 0 0 1 1 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06zm7.137 2.096a.5.5 0 0 1 0 .708L12.207 8l1.647 1.646a.5.5 0 0 1-.708.708L11.5 8.707l-1.646 1.647a.5.5 0 0 1-.708-.708L10.793 8 9.146 6.354a.5.5 0 1 1 .708-.708L11.5 7.293l1.646-1.647a.5.5 0 0 1 .708 0z"/>');// eslint-disable-next-line
var BIconVolumeOff=/*#__PURE__*/makeIcon('VolumeOff','<path d="M10.717 3.55A.5.5 0 0 1 11 4v8a.5.5 0 0 1-.812.39L7.825 10.5H5.5A.5.5 0 0 1 5 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06zM10 5.04L8.312 6.39A.5.5 0 0 1 8 6.5H6v3h2a.5.5 0 0 1 .312.11L10 10.96V5.04z"/>');// eslint-disable-next-line
var BIconVolumeOffFill=/*#__PURE__*/makeIcon('VolumeOffFill','<path d="M10.717 3.55A.5.5 0 0 1 11 4v8a.5.5 0 0 1-.812.39L7.825 10.5H5.5A.5.5 0 0 1 5 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06z"/>');// eslint-disable-next-line
var BIconVolumeUp=/*#__PURE__*/makeIcon('VolumeUp','<path d="M11.536 14.01A8.473 8.473 0 0 0 14.026 8a8.473 8.473 0 0 0-2.49-6.01l-.708.707A7.476 7.476 0 0 1 13.025 8c0 2.071-.84 3.946-2.197 5.303l.708.707z"/><path d="M10.121 12.596A6.48 6.48 0 0 0 12.025 8a6.48 6.48 0 0 0-1.904-4.596l-.707.707A5.483 5.483 0 0 1 11.025 8a5.483 5.483 0 0 1-1.61 3.89l.706.706z"/><path d="M10.025 8a4.486 4.486 0 0 1-1.318 3.182L8 10.475A3.489 3.489 0 0 0 9.025 8c0-.966-.392-1.841-1.025-2.475l.707-.707A4.486 4.486 0 0 1 10.025 8zM7 4a.5.5 0 0 0-.812-.39L3.825 5.5H1.5A.5.5 0 0 0 1 6v4a.5.5 0 0 0 .5.5h2.325l2.363 1.89A.5.5 0 0 0 7 12V4zM4.312 6.39L6 5.04v5.92L4.312 9.61A.5.5 0 0 0 4 9.5H2v-3h2a.5.5 0 0 0 .312-.11z"/>');// eslint-disable-next-line
var BIconVolumeUpFill=/*#__PURE__*/makeIcon('VolumeUpFill','<path d="M11.536 14.01A8.473 8.473 0 0 0 14.026 8a8.473 8.473 0 0 0-2.49-6.01l-.708.707A7.476 7.476 0 0 1 13.025 8c0 2.071-.84 3.946-2.197 5.303l.708.707z"/><path d="M10.121 12.596A6.48 6.48 0 0 0 12.025 8a6.48 6.48 0 0 0-1.904-4.596l-.707.707A5.483 5.483 0 0 1 11.025 8a5.483 5.483 0 0 1-1.61 3.89l.706.706z"/><path d="M8.707 11.182A4.486 4.486 0 0 0 10.025 8a4.486 4.486 0 0 0-1.318-3.182L8 5.525A3.489 3.489 0 0 1 9.025 8 3.49 3.49 0 0 1 8 10.475l.707.707zM6.717 3.55A.5.5 0 0 1 7 4v8a.5.5 0 0 1-.812.39L3.825 10.5H1.5A.5.5 0 0 1 1 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06z"/>');// eslint-disable-next-line
var BIconVr=/*#__PURE__*/makeIcon('Vr','<path d="M3 12V4a1 1 0 0 1 1-1h2.5V2H4a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5v-1H4a1 1 0 0 1-1-1zm6.5 1v1H12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H9.5v1H12a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H9.5zM8 16a.5.5 0 0 1-.5-.5V.5a.5.5 0 0 1 1 0v15a.5.5 0 0 1-.5.5z"/>');// eslint-disable-next-line
var BIconWallet=/*#__PURE__*/makeIcon('Wallet','<path d="M0 3a2 2 0 0 1 2-2h13.5a.5.5 0 0 1 0 1H15v2a1 1 0 0 1 1 1v8.5a1.5 1.5 0 0 1-1.5 1.5h-12A2.5 2.5 0 0 1 0 12.5V3zm1 1.732V12.5A1.5 1.5 0 0 0 2.5 14h12a.5.5 0 0 0 .5-.5V5H2a1.99 1.99 0 0 1-1-.268zM1 3a1 1 0 0 0 1 1h12V2H2a1 1 0 0 0-1 1z"/>');// eslint-disable-next-line
var BIconWallet2=/*#__PURE__*/makeIcon('Wallet2','<path d="M12.136.326A1.5 1.5 0 0 1 14 1.78V3h.5A1.5 1.5 0 0 1 16 4.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 13.5v-9a1.5 1.5 0 0 1 1.432-1.499L12.136.326zM5.562 3H13V1.78a.5.5 0 0 0-.621-.484L5.562 3zM1.5 4a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-13z"/>');// eslint-disable-next-line
var BIconWalletFill=/*#__PURE__*/makeIcon('WalletFill','<path d="M1.5 2A1.5 1.5 0 0 0 0 3.5v2h6a.5.5 0 0 1 .5.5c0 .253.08.644.306.958.207.288.557.542 1.194.542.637 0 .987-.254 1.194-.542.226-.314.306-.705.306-.958a.5.5 0 0 1 .5-.5h6v-2A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M16 6.5h-5.551a2.678 2.678 0 0 1-.443 1.042C9.613 8.088 8.963 8.5 8 8.5c-.963 0-1.613-.412-2.006-.958A2.679 2.679 0 0 1 5.551 6.5H0v6A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-6z"/>');// eslint-disable-next-line
var BIconWatch=/*#__PURE__*/makeIcon('Watch','<path d="M8.5 5a.5.5 0 0 0-1 0v2.5H6a.5.5 0 0 0 0 1h2a.5.5 0 0 0 .5-.5V5z"/><path d="M5.667 16C4.747 16 4 15.254 4 14.333v-1.86A5.985 5.985 0 0 1 2 8c0-1.777.772-3.374 2-4.472V1.667C4 .747 4.746 0 5.667 0h4.666C11.253 0 12 .746 12 1.667v1.86a5.99 5.99 0 0 1 1.918 3.48.502.502 0 0 1 .582.493v1a.5.5 0 0 1-.582.493A5.99 5.99 0 0 1 12 12.473v1.86c0 .92-.746 1.667-1.667 1.667H5.667zM13 8A5 5 0 1 0 3 8a5 5 0 0 0 10 0z"/>');// eslint-disable-next-line
var BIconWifi=/*#__PURE__*/makeIcon('Wifi','<path d="M15.385 6.115a.485.485 0 0 0-.048-.736A12.443 12.443 0 0 0 8 3 12.44 12.44 0 0 0 .663 5.379a.485.485 0 0 0-.048.736.518.518 0 0 0 .668.05A11.448 11.448 0 0 1 8 4c2.507 0 4.827.802 6.717 2.164.204.148.489.13.668-.049z"/><path d="M13.229 8.271c.216-.216.194-.578-.063-.745A9.456 9.456 0 0 0 8 6c-1.905 0-3.68.56-5.166 1.526a.48.48 0 0 0-.063.745.525.525 0 0 0 .652.065A8.46 8.46 0 0 1 8 7a8.46 8.46 0 0 1 4.577 1.336c.205.132.48.108.652-.065zm-2.183 2.183c.226-.226.185-.605-.1-.75A6.472 6.472 0 0 0 8 9c-1.06 0-2.062.254-2.946.704-.285.145-.326.524-.1.75l.015.015c.16.16.408.19.611.09A5.478 5.478 0 0 1 8 10c.868 0 1.69.201 2.42.56.203.1.45.07.611-.091l.015-.015zM9.06 12.44c.196-.196.198-.52-.04-.66A1.99 1.99 0 0 0 8 11.5a1.99 1.99 0 0 0-1.02.28c-.238.14-.236.464-.04.66l.706.706a.5.5 0 0 0 .708 0l.707-.707z"/>');// eslint-disable-next-line
var BIconWifi1=/*#__PURE__*/makeIcon('Wifi1','<path d="M11.046 10.454c.226-.226.185-.605-.1-.75A6.473 6.473 0 0 0 8 9c-1.06 0-2.062.254-2.946.704-.285.145-.326.524-.1.75l.015.015c.16.16.407.19.611.09A5.478 5.478 0 0 1 8 10c.868 0 1.69.201 2.42.56.203.1.45.07.611-.091l.015-.015zM9.06 12.44c.196-.196.198-.52-.04-.66A1.99 1.99 0 0 0 8 11.5a1.99 1.99 0 0 0-1.02.28c-.238.14-.236.464-.04.66l.706.706a.5.5 0 0 0 .707 0l.708-.707z"/>');// eslint-disable-next-line
var BIconWifi2=/*#__PURE__*/makeIcon('Wifi2','<path d="M13.229 8.271c.216-.216.194-.578-.063-.745A9.456 9.456 0 0 0 8 6c-1.905 0-3.68.56-5.166 1.526a.48.48 0 0 0-.063.745.525.525 0 0 0 .652.065A8.46 8.46 0 0 1 8 7a8.46 8.46 0 0 1 4.577 1.336c.205.132.48.108.652-.065zm-2.183 2.183c.226-.226.185-.605-.1-.75A6.473 6.473 0 0 0 8 9c-1.06 0-2.062.254-2.946.704-.285.145-.326.524-.1.75l.015.015c.16.16.408.19.611.09A5.478 5.478 0 0 1 8 10c.868 0 1.69.201 2.42.56.203.1.45.07.611-.091l.015-.015zM9.06 12.44c.196-.196.198-.52-.04-.66A1.99 1.99 0 0 0 8 11.5a1.99 1.99 0 0 0-1.02.28c-.238.14-.236.464-.04.66l.706.706a.5.5 0 0 0 .708 0l.707-.707z"/>');// eslint-disable-next-line
var BIconWifiOff=/*#__PURE__*/makeIcon('WifiOff','<path d="M10.706 3.294A12.546 12.546 0 0 0 8 3 12.44 12.44 0 0 0 .663 5.379a.485.485 0 0 0-.048.736.518.518 0 0 0 .668.05A11.448 11.448 0 0 1 8 4c.63 0 1.249.05 1.852.148l.854-.854zM8 6c-1.905 0-3.68.56-5.166 1.526a.48.48 0 0 0-.063.745.525.525 0 0 0 .652.065 8.448 8.448 0 0 1 3.51-1.27L8 6zm2.596 1.404l.785-.785c.63.24 1.228.545 1.785.907a.482.482 0 0 1 .063.745.525.525 0 0 1-.652.065 8.462 8.462 0 0 0-1.98-.932zM8 10l.934-.933a6.454 6.454 0 0 1 2.012.637c.285.145.326.524.1.75l-.015.015a.532.532 0 0 1-.611.09A5.478 5.478 0 0 0 8 10zm4.905-4.905l.747-.747c.59.3 1.153.645 1.685 1.03a.485.485 0 0 1 .048.737.518.518 0 0 1-.668.05 11.496 11.496 0 0 0-1.812-1.07zM9.02 11.78c.238.14.236.464.04.66l-.706.706a.5.5 0 0 1-.708 0l-.707-.707c-.195-.195-.197-.518.04-.66A1.99 1.99 0 0 1 8 11.5c.373 0 .722.102 1.02.28zm4.355-9.905a.53.53 0 1 1 .75.75l-10.75 10.75a.53.53 0 0 1-.75-.75l10.75-10.75z"/>');// eslint-disable-next-line
var BIconWindow=/*#__PURE__*/makeIcon('Window','<path d="M2.5 4a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm2-.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm1 .5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/><path d="M2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2zm13 2v2H1V3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zM2 14a1 1 0 0 1-1-1V6h14v7a1 1 0 0 1-1 1H2z"/>');// eslint-disable-next-line
var BIconWrench=/*#__PURE__*/makeIcon('Wrench','<path d="M.102 2.223A3.004 3.004 0 0 0 3.78 5.897l6.341 6.252A3.003 3.003 0 0 0 13 16a3 3 0 1 0-.851-5.878L5.897 3.781A3.004 3.004 0 0 0 2.223.1l2.141 2.142L4 4l-1.757.364L.102 2.223zm13.37 9.019l.528.026.287.445.445.287.026.529L15 13l-.242.471-.026.529-.445.287-.287.445-.529.026L13 15l-.471-.242-.529-.026-.287-.445-.445-.287-.026-.529L11 13l.242-.471.026-.529.445-.287.287-.445.529-.026L13 11l.471.242z"/>');// eslint-disable-next-line
var BIconX=/*#__PURE__*/makeIcon('X','<path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconXCircle=/*#__PURE__*/makeIcon('XCircle','<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconXCircleFill=/*#__PURE__*/makeIcon('XCircleFill','<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.354 4.646a.5.5 0 1 0-.708.708L7.293 8l-2.647 2.646a.5.5 0 0 0 .708.708L8 8.707l2.646 2.647a.5.5 0 0 0 .708-.708L8.707 8l2.647-2.646a.5.5 0 0 0-.708-.708L8 7.293 5.354 4.646z"/>');// eslint-disable-next-line
var BIconXDiamond=/*#__PURE__*/makeIcon('XDiamond','<path d="M7.987 16a1.526 1.526 0 0 1-1.07-.448L.45 9.082a1.531 1.531 0 0 1 0-2.165L6.917.45a1.531 1.531 0 0 1 2.166 0l6.469 6.468A1.526 1.526 0 0 1 16 8.013a1.526 1.526 0 0 1-.448 1.07l-6.47 6.469A1.526 1.526 0 0 1 7.988 16zM7.639 1.17L4.766 4.044 8 7.278l3.234-3.234L8.361 1.17a.51.51 0 0 0-.722 0zM8.722 8l3.234 3.234 2.873-2.873c.2-.2.2-.523 0-.722l-2.873-2.873L8.722 8zM8 8.722l-3.234 3.234 2.873 2.873c.2.2.523.2.722 0l2.873-2.873L8 8.722zM7.278 8L4.044 4.766 1.17 7.639a.511.511 0 0 0 0 .722l2.874 2.873L7.278 8z"/>');// eslint-disable-next-line
var BIconXDiamondFill=/*#__PURE__*/makeIcon('XDiamondFill','<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L4.047 3.339 8 7.293l3.954-3.954L9.049.435zm3.61 3.611L8.708 8l3.954 3.954 2.904-2.905c.58-.58.58-1.519 0-2.098l-2.904-2.905zm-.706 8.614L8 8.708l-3.954 3.954 2.905 2.904c.58.58 1.519.58 2.098 0l2.905-2.904zm-8.614-.706L7.292 8 3.339 4.046.435 6.951c-.58.58-.58 1.519 0 2.098l2.904 2.905z"/>');// eslint-disable-next-line
var BIconXOctagon=/*#__PURE__*/makeIcon('XOctagon','<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/><path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconXOctagonFill=/*#__PURE__*/makeIcon('XOctagonFill','<path d="M11.46.146A.5.5 0 0 0 11.107 0H4.893a.5.5 0 0 0-.353.146L.146 4.54A.5.5 0 0 0 0 4.893v6.214a.5.5 0 0 0 .146.353l4.394 4.394a.5.5 0 0 0 .353.146h6.214a.5.5 0 0 0 .353-.146l4.394-4.394a.5.5 0 0 0 .146-.353V4.893a.5.5 0 0 0-.146-.353L11.46.146zm-6.106 4.5L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconXSquare=/*#__PURE__*/makeIcon('XSquare','<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>');// eslint-disable-next-line
var BIconXSquareFill=/*#__PURE__*/makeIcon('XSquareFill','<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm3.354 4.646L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 1 1 .708-.708z"/>');// eslint-disable-next-line
var BIconYoutube=/*#__PURE__*/makeIcon('Youtube','<path d="M8.051 1.999h.089c.822.003 4.987.033 6.11.335a2.01 2.01 0 0 1 1.415 1.42c.101.38.172.883.22 1.402l.01.104.022.26.008.104c.065.914.073 1.77.074 1.957v.075c-.001.194-.01 1.108-.082 2.06l-.008.105-.009.104c-.05.572-.124 1.14-.235 1.558a2.007 2.007 0 0 1-1.415 1.42c-1.16.312-5.569.334-6.18.335h-.142c-.309 0-1.587-.006-2.927-.052l-.17-.006-.087-.004-.171-.007-.171-.007c-1.11-.049-2.167-.128-2.654-.26a2.007 2.007 0 0 1-1.415-1.419c-.111-.417-.185-.986-.235-1.558L.09 9.82l-.008-.104A31.4 31.4 0 0 1 0 7.68v-.122C.002 7.343.01 6.6.064 5.78l.007-.103.003-.052.008-.104.022-.26.01-.104c.048-.519.119-1.023.22-1.402a2.007 2.007 0 0 1 1.415-1.42c.487-.13 1.544-.21 2.654-.26l.17-.007.172-.006.086-.003.171-.007A99.788 99.788 0 0 1 7.858 2h.193zM6.4 5.209v4.818l4.157-2.408L6.4 5.209z"/>');// eslint-disable-next-line
var BIconZoomIn=/*#__PURE__*/makeIcon('ZoomIn','<path fill-rule="evenodd" d="M6.5 12a5.5 5.5 0 1 0 0-11 5.5 5.5 0 0 0 0 11zM13 6.5a6.5 6.5 0 1 1-13 0 6.5 6.5 0 0 1 13 0z"/><path d="M10.344 11.742c.03.04.062.078.098.115l3.85 3.85a1 1 0 0 0 1.415-1.414l-3.85-3.85a1.007 1.007 0 0 0-.115-.1 6.538 6.538 0 0 1-1.398 1.4z"/><path fill-rule="evenodd" d="M6.5 3a.5.5 0 0 1 .5.5V6h2.5a.5.5 0 0 1 0 1H7v2.5a.5.5 0 0 1-1 0V7H3.5a.5.5 0 0 1 0-1H6V3.5a.5.5 0 0 1 .5-.5z"/>');// eslint-disable-next-line
var BIconZoomOut=/*#__PURE__*/makeIcon('ZoomOut','<path fill-rule="evenodd" d="M6.5 12a5.5 5.5 0 1 0 0-11 5.5 5.5 0 0 0 0 11zM13 6.5a6.5 6.5 0 1 1-13 0 6.5 6.5 0 0 1 13 0z"/><path d="M10.344 11.742c.03.04.062.078.098.115l3.85 3.85a1 1 0 0 0 1.415-1.414l-3.85-3.85a1.007 1.007 0 0 0-.115-.1 6.538 6.538 0 0 1-1.398 1.4z"/><path fill-rule="evenodd" d="M3 6.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');// --- END AUTO-GENERATED FILE ---

var findIconComponent=function findIconComponent(ctx,iconName){
if(!ctx){
return null;
}

var components=(ctx.$options||{}).components;
var iconComponent=components[iconName];
return iconComponent||findIconComponent(ctx.$parent,iconName);
};// --- Props ---


var iconProps=omit(props$4,['content']);
var props$5=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},iconProps),{},{
icon:makeProp(PROP_TYPE_STRING)})),
NAME_ICON);// --- Main component ---
// Helper BIcon component
// Requires the requested icon component to be installed
// @vue/component

var BIcon=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_ICON,
functional:true,
props:props$5,
render:function render(h,_ref){
var data=_ref.data,
props=_ref.props,
parent=_ref.parent;
var icon=pascalCase(trim(props.icon||'')).replace(RX_ICON_PREFIX,'');// If parent context exists, we check to see if the icon has been registered
// either locally in the parent component, or globally at the `$root` level
// If not registered, we render a blank icon

return h(icon?findIconComponent(parent,"BIcon".concat(icon))||BIconBlank:BIconBlank,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
props:pluckProps(iconProps,props)}));

}});


var CODE_BACKSPACE=8;
var CODE_DELETE=46;
var CODE_DOWN=40;
var CODE_END=35;
var CODE_ENTER=13;
var CODE_ESC=27;
var CODE_HOME=36;
var CODE_LEFT=37;
var CODE_PAGEDOWN=34;
var CODE_PAGEUP=33;
var CODE_RIGHT=39;
var CODE_SPACE=32;
var CODE_UP=38;

// Handles when arrays are "sparse" (array.every(...) doesn't handle sparse)

var compareArrays=function compareArrays(a,b){
if(a.length!==b.length){
return false;
}

var equal=true;

for(var i=0;equal&&i<a.length;i++){
equal=looseEqual(a[i],b[i]);
}

return equal;
};
/**
 * Check if two values are loosely equal - that is,
 * if they are plain objects, do they have the same shape?
 * Returns boolean true or false
 */


var looseEqual=function looseEqual(a,b){
if(a===b){
return true;
}

var aValidType=isDate(a);
var bValidType=isDate(b);

if(aValidType||bValidType){
return aValidType&&bValidType?a.getTime()===b.getTime():false;
}

aValidType=isArray(a);
bValidType=isArray(b);

if(aValidType||bValidType){
return aValidType&&bValidType?compareArrays(a,b):false;
}

aValidType=isObject(a);
bValidType=isObject(b);

if(aValidType||bValidType){
/* istanbul ignore if: this if will probably never be called */
if(!aValidType||!bValidType){
return false;
}

var aKeysCount=keys(a).length;
var bKeysCount=keys(b).length;

if(aKeysCount!==bKeysCount){
return false;
}

for(var key in a){
var aHasKey=hasOwnProperty(a,key);
var bHasKey=hasOwnProperty(b,key);

if(aHasKey&&!bHasKey||!aHasKey&&bHasKey||!looseEqual(a[key],b[key])){
return false;
}
}
}

return String(a)===String(b);
};

var isEmpty=function isEmpty(value){
return !value||keys(value).length===0;
};

var makePropWatcher=function makePropWatcher(propName){
return {
handler:function handler(newValue,oldValue){
if(looseEqual(newValue,oldValue)){
return;
}

if(isEmpty(newValue)||isEmpty(oldValue)){
this[propName]=cloneDeep(newValue);
return;
}

for(var key in oldValue){
if(!hasOwnProperty(newValue,key)){
this.$delete(this.$data[propName],key);
}
}

for(var _key in newValue){
this.$set(this.$data[propName],_key,newValue[_key]);
}
}};

};
var makePropCacheMixin=function makePropCacheMixin(propName,proxyPropName){
return vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
data:function data(){
return _defineProperty({},proxyPropName,cloneDeep(this[propName]));
},
watch:_defineProperty({},propName,makePropWatcher(proxyPropName))});

};

var attrsMixin=makePropCacheMixin('$attrs','bvAttrs');

var listenOnRootMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
methods:{
/**
     * Safely register event listeners on the root Vue node
     * While Vue automatically removes listeners for individual components,
     * when a component registers a listener on root and is destroyed,
     * this orphans a callback because the node is gone,
     * but the root does not clear the callback
     *
     * When registering a `$root` listener, it also registers a listener on
     * the component's `beforeDestroy()` hook to automatically remove the
     * event listener from the `$root` instance
     *
     * @param {string} event
     * @param {function} callback
     */
listenOnRoot:function listenOnRoot(event,callback){
var _this=this;

this.$root.$on(event,callback);
this.$on(HOOK_EVENT_NAME_BEFORE_DESTROY,function(){
_this.$root.$off(event,callback);
});
},

/**
     * Safely register a `$once()` event listener on the root Vue node
     * While Vue automatically removes listeners for individual components,
     * when a component registers a listener on root and is destroyed,
     * this orphans a callback because the node is gone,
     * but the root does not clear the callback
     *
     * When registering a $root listener, it also registers a listener on
     * the component's `beforeDestroy` hook to automatically remove the
     * event listener from the $root instance.
     *
     * @param {string} event
     * @param {function} callback
     */
listenOnRootOnce:function listenOnRootOnce(event,callback){
var _this2=this;

this.$root.$once(event,callback);
this.$on(HOOK_EVENT_NAME_BEFORE_DESTROY,function(){
_this2.$root.$off(event,callback);
});
},

/**
     * Convenience method for calling `vm.$emit()` on `vm.$root`
     *
     * @param {string} event
     * @param {*} args
     */
emitOnRoot:function emitOnRoot(event){
var _this$$root;

for(var _len=arguments.length,args=new Array(_len>1?_len-1:0),_key=1;_key<_len;_key++){
args[_key-1]=arguments[_key];
}

(_this$$root=this.$root).$emit.apply(_this$$root,[event].concat(args));
}}});



var listenersMixin=makePropCacheMixin('$listeners','bvListeners');

var ROOT_EVENT_NAME_CLICKED=getRootEventName(NAME_LINK,'clicked');// --- Props ---
// `<router-link>` specific props

var routerLinkProps={
activeClass:makeProp(PROP_TYPE_STRING),
append:makeProp(PROP_TYPE_BOOLEAN,false),
event:makeProp(PROP_TYPE_ARRAY_STRING,EVENT_NAME_CLICK),
exact:makeProp(PROP_TYPE_BOOLEAN,false),
exactActiveClass:makeProp(PROP_TYPE_STRING),
replace:makeProp(PROP_TYPE_BOOLEAN,false),
routerTag:makeProp(PROP_TYPE_STRING,'a'),
to:makeProp(PROP_TYPE_OBJECT_STRING)};
// `<nuxt-link>` specific props

var nuxtLinkProps={
noPrefetch:makeProp(PROP_TYPE_BOOLEAN,false),
// Must be `null` to fall back to the value defined in the
// `nuxt.config.js` configuration file for `router.prefetchLinks`
// We convert `null` to `undefined`, so that Nuxt.js will use the
// compiled default
// Vue treats `undefined` as default of `false` for Boolean props,
// so we must set it as `null` here to be a true tri-state prop
prefetch:makeProp(PROP_TYPE_BOOLEAN,null)};
// All `<b-link>` props

var props$6=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},nuxtLinkProps),routerLinkProps),{},{
active:makeProp(PROP_TYPE_BOOLEAN,false),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
href:makeProp(PROP_TYPE_STRING),
// Must be `null` if no value provided
rel:makeProp(PROP_TYPE_STRING,null),
// To support 3rd party router links based on `<router-link>` (i.e. `g-link` for Gridsome)
// Default is to auto choose between `<router-link>` and `<nuxt-link>`
// Gridsome doesn't provide a mechanism to auto detect and has caveats
// such as not supporting FQDN URLs or hash only URLs
routerComponentName:makeProp(PROP_TYPE_STRING),
target:makeProp(PROP_TYPE_STRING,'_self')})),
NAME_LINK);// --- Main component ---
// @vue/component

var BLink=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_LINK,
// Mixin order is important!
mixins:[attrsMixin,listenersMixin,listenOnRootMixin,normalizeSlotMixin],
inheritAttrs:false,
props:props$6,
computed:{
computedTag:function computedTag(){
// We don't pass `this` as the first arg as we need reactivity of the props
var to=this.to,
disabled=this.disabled,
routerComponentName=this.routerComponentName;
return computeTag({
to:to,
disabled:disabled,
routerComponentName:routerComponentName},
this);
},
isRouterLink:function isRouterLink$1(){
return isRouterLink(this.computedTag);
},
computedRel:function computedRel(){
// We don't pass `this` as the first arg as we need reactivity of the props
var target=this.target,
rel=this.rel;
return computeRel({
target:target,
rel:rel});

},
computedHref:function computedHref(){
// We don't pass `this` as the first arg as we need reactivity of the props
var to=this.to,
href=this.href;
return computeHref({
to:to,
href:href},
this.computedTag);
},
computedProps:function computedProps(){
var prefetch=this.prefetch;
return this.isRouterLink?_objectSpread2(_objectSpread2({},pluckProps(_objectSpread2(_objectSpread2({},routerLinkProps),nuxtLinkProps),this)),{},{
// Coerce `prefetch` value `null` to be `undefined`
prefetch:isBoolean(prefetch)?prefetch:undefined,
// Pass `router-tag` as `tag` prop
tag:this.routerTag}):
{};
},
computedAttrs:function computedAttrs(){
var bvAttrs=this.bvAttrs,
href=this.computedHref,
rel=this.computedRel,
disabled=this.disabled,
target=this.target,
routerTag=this.routerTag,
isRouterLink=this.isRouterLink;
return _objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},bvAttrs),href?{
href:href}:
{}),isRouterLink&&!isTag(routerTag,'a')?{}:{
rel:rel,
target:target}),
{},{
tabindex:disabled?'-1':isUndefined(bvAttrs.tabindex)?null:bvAttrs.tabindex,
'aria-disabled':disabled?'true':null});

},
computedListeners:function computedListeners(){
return _objectSpread2(_objectSpread2({},this.bvListeners),{},{
// We want to overwrite any click handler since our callback
// will invoke the user supplied handler(s) if `!this.disabled`
click:this.onClick});

}},

methods:{
onClick:function onClick(event){
var _arguments=arguments;
var eventIsEvent=isEvent(event);
var isRouterLink=this.isRouterLink;
var suppliedHandler=this.bvListeners.click;

if(eventIsEvent&&this.disabled){
// Stop event from bubbling up
// Kill the event loop attached to this specific `EventTarget`
// Needed to prevent `vue-router` for doing its thing
stopEvent(event,{
immediatePropagation:true});

}else {
/* istanbul ignore next: difficult to test, but we know it works */
if(isRouterLink&&event.currentTarget.__vue__){
// Router links do not emit instance `click` events, so we
// add in an `$emit('click', event)` on its Vue instance
event.currentTarget.__vue__.$emit(EVENT_NAME_CLICK,event);
}// Call the suppliedHandler(s), if any provided


concat(suppliedHandler).filter(function(h){
return isFunction(h);
}).forEach(function(handler){
handler.apply(void 0,_toConsumableArray(_arguments));
});// Emit the global `$root` click event

this.emitOnRoot(ROOT_EVENT_NAME_CLICKED,event);// TODO: Remove deprecated 'clicked::link' event with next major release

this.emitOnRoot('clicked::link',event);
}// Stop scroll-to-top behavior or navigation on
// regular links when href is just '#'


if(eventIsEvent&&!isRouterLink&&this.computedHref==='#'){
stopEvent(event,{
propagation:false});

}
},
focus:function focus(){
attemptFocus(this.$el);
},
blur:function blur(){
attemptBlur(this.$el);
}},

render:function render(h){
var active=this.active,
disabled=this.disabled;
return h(this.computedTag,_defineProperty({
class:{
active:active,
disabled:disabled},

attrs:this.computedAttrs,
props:this.computedProps},
this.isRouterLink?'nativeOn':'on',this.computedListeners),this.normalizeSlot());
}});


var linkProps=omit(props$6,['event','routerTag']);
delete linkProps.href.default;
delete linkProps.to.default;
var props$7=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},linkProps),{},{
block:makeProp(PROP_TYPE_BOOLEAN,false),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
pill:makeProp(PROP_TYPE_BOOLEAN,false),
// Tri-state: `true`, `false` or `null`
// => On, off, not a toggle
pressed:makeProp(PROP_TYPE_BOOLEAN,null),
size:makeProp(PROP_TYPE_STRING),
squared:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'button'),
type:makeProp(PROP_TYPE_STRING,'button'),
variant:makeProp(PROP_TYPE_STRING,'secondary')})),
NAME_BUTTON);// --- Helper methods ---
// Focus handler for toggle buttons
// Needs class of 'focus' when focused

var handleFocus=function handleFocus(event){
if(event.type==='focusin'){
addClass(event.target,'focus');
}else if(event.type==='focusout'){
removeClass(event.target,'focus');
}
};// Is the requested button a link?
// If tag prop is set to `a`, we use a <b-link> to get proper disabled handling


var isLink$1=function isLink$1(props){
return isLink(props)||isTag(props.tag,'a');
};// Is the button to be a toggle button?


var isToggle=function isToggle(props){
return isBoolean(props.pressed);
};// Is the button "really" a button?


var isButton=function isButton(props){
return !(isLink$1(props)||props.tag&&!isTag(props.tag,'button'));
};// Is the requested tag not a button or link?


var isNonStandardTag=function isNonStandardTag(props){
return !isLink$1(props)&&!isButton(props);
};// Compute required classes (non static classes)


var computeClass=function computeClass(props){
var _ref;

return ["btn-".concat(props.variant||'secondary'),(_ref={},_defineProperty(_ref,"btn-".concat(props.size),props.size),_defineProperty(_ref,'btn-block',props.block),_defineProperty(_ref,'rounded-pill',props.pill),_defineProperty(_ref,'rounded-0',props.squared&&!props.pill),_defineProperty(_ref,"disabled",props.disabled),_defineProperty(_ref,"active",props.pressed),_ref)];
};// Compute the link props to pass to b-link (if required)


var computeLinkProps=function computeLinkProps(props){
return isLink$1(props)?pluckProps(linkProps,props):{};
};// Compute the attributes for a button


var computeAttrs=function computeAttrs(props,data){
var button=isButton(props);
var link=isLink$1(props);
var toggle=isToggle(props);
var nonStandardTag=isNonStandardTag(props);
var hashLink=link&&props.href==='#';
var role=data.attrs&&data.attrs.role?data.attrs.role:null;
var tabindex=data.attrs?data.attrs.tabindex:null;

if(nonStandardTag||hashLink){
tabindex='0';
}

return {
// Type only used for "real" buttons
type:button&&!link?props.type:null,
// Disabled only set on "real" buttons
disabled:button?props.disabled:null,
// We add a role of button when the tag is not a link or button for ARIA
// Don't bork any role provided in `data.attrs` when `isLink` or `isButton`
// Except when link has `href` of `#`
role:nonStandardTag||hashLink?'button':role,
// We set the `aria-disabled` state for non-standard tags
'aria-disabled':nonStandardTag?String(props.disabled):null,
// For toggles, we need to set the pressed state for ARIA
'aria-pressed':toggle?String(props.pressed):null,
// `autocomplete="off"` is needed in toggle mode to prevent some browsers
// from remembering the previous setting when using the back button
autocomplete:toggle?'off':null,
// `tabindex` is used when the component is not a button
// Links are tabbable, but don't allow disabled, while non buttons or links
// are not tabbable, so we mimic that functionality by disabling tabbing
// when disabled, and adding a `tabindex="0"` to non buttons or non links
tabindex:props.disabled&&!button?'-1':tabindex};

};// --- Main component ---
// @vue/component


var BButton=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BUTTON,
functional:true,
props:props$7,
render:function render(h,_ref2){
var props=_ref2.props,
data=_ref2.data,
listeners=_ref2.listeners,
children=_ref2.children;
var toggle=isToggle(props);
var link=isLink$1(props);
var nonStandardTag=isNonStandardTag(props);
var hashLink=link&&props.href==='#';
var on={
keydown:function keydown(event){
// When the link is a `href="#"` or a non-standard tag (has `role="button"`),
// we add a keydown handlers for CODE_SPACE/CODE_ENTER

/* istanbul ignore next */
if(props.disabled||!(nonStandardTag||hashLink)){
return;
}

var keyCode=event.keyCode;// Add CODE_SPACE handler for `href="#"` and CODE_ENTER handler for non-standard tags

if(keyCode===CODE_SPACE||keyCode===CODE_ENTER&&nonStandardTag){
var target=event.currentTarget||event.target;
stopEvent(event,{
propagation:false});

target.click();
}
},
click:function click(event){
/* istanbul ignore if: blink/button disabled should handle this */
if(props.disabled&&isEvent(event)){
stopEvent(event);
}else if(toggle&&listeners&&listeners['update:pressed']){
// Send `.sync` updates to any "pressed" prop (if `.sync` listeners)
// `concat()` will normalize the value to an array without
// double wrapping an array value in an array
concat(listeners['update:pressed']).forEach(function(fn){
if(isFunction(fn)){
fn(!props.pressed);
}
});
}
}};


if(toggle){
on.focusin=handleFocus;
on.focusout=handleFocus;
}

var componentData={
staticClass:'btn',
class:computeClass(props),
props:computeLinkProps(props),
attrs:computeAttrs(props,data),
on:on};

return h(link?BLink:props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,componentData),children);
}});


var CLASS_NAME$1='b-avatar';
var SIZES=['sm',null,'lg'];
var FONT_SIZE_SCALE=0.4;
var BADGE_FONT_SIZE_SCALE=FONT_SIZE_SCALE*0.7;// --- Helper methods ---

var computeSize=function computeSize(value){
// Parse to number when value is a float-like string
value=isString(value)&&isNumeric(value)?toFloat(value,0):value;// Convert all numbers to pixel values

return isNumber(value)?"".concat(value,"px"):value||null;
};// --- Props ---

var linkProps$1=omit(props$6,['active','event','routerTag']);
var props$8=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},linkProps$1),{},{
alt:makeProp(PROP_TYPE_STRING,'avatar'),
ariaLabel:makeProp(PROP_TYPE_STRING),
badge:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
badgeLeft:makeProp(PROP_TYPE_BOOLEAN,false),
badgeOffset:makeProp(PROP_TYPE_STRING),
badgeTop:makeProp(PROP_TYPE_BOOLEAN,false),
badgeVariant:makeProp(PROP_TYPE_STRING,'primary'),
button:makeProp(PROP_TYPE_BOOLEAN,false),
buttonType:makeProp(PROP_TYPE_STRING,'button'),
icon:makeProp(PROP_TYPE_STRING),
rounded:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
size:makeProp(PROP_TYPE_NUMBER_STRING),
square:makeProp(PROP_TYPE_BOOLEAN,false),
src:makeProp(PROP_TYPE_STRING),
text:makeProp(PROP_TYPE_STRING),
variant:makeProp(PROP_TYPE_STRING,'secondary')})),
NAME_AVATAR);// --- Main component ---
// @vue/component

var BAvatar=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_AVATAR,
mixins:[normalizeSlotMixin],
inject:{
bvAvatarGroup:{
default:null}},


props:props$8,
data:function data(){
return {
localSrc:this.src||null};

},
computed:{
computedSize:function computedSize(){
// Always use the avatar group size
var bvAvatarGroup=this.bvAvatarGroup;
return computeSize(bvAvatarGroup?bvAvatarGroup.size:this.size);
},
computedVariant:function computedVariant(){
var bvAvatarGroup=this.bvAvatarGroup;
return bvAvatarGroup&&bvAvatarGroup.variant?bvAvatarGroup.variant:this.variant;
},
computedRounded:function computedRounded(){
var bvAvatarGroup=this.bvAvatarGroup;
var square=bvAvatarGroup&&bvAvatarGroup.square?true:this.square;
var rounded=bvAvatarGroup&&bvAvatarGroup.rounded?bvAvatarGroup.rounded:this.rounded;
return square?'0':rounded===''?true:rounded||'circle';
},
fontStyle:function fontStyle(){
var size=this.computedSize;
var fontSize=SIZES.indexOf(size)===-1?"calc(".concat(size," * ").concat(FONT_SIZE_SCALE,")"):null;
return fontSize?{
fontSize:fontSize}:
{};
},
marginStyle:function marginStyle(){
var size=this.computedSize,
bvAvatarGroup=this.bvAvatarGroup;
var overlapScale=bvAvatarGroup?bvAvatarGroup.overlapScale:0;
var value=size&&overlapScale?"calc(".concat(size," * -").concat(overlapScale,")"):null;
return value?{
marginLeft:value,
marginRight:value}:
{};
},
badgeStyle:function badgeStyle(){
var size=this.computedSize,
badgeTop=this.badgeTop,
badgeLeft=this.badgeLeft,
badgeOffset=this.badgeOffset;
var offset=badgeOffset||'0px';
return {
fontSize:SIZES.indexOf(size)===-1?"calc(".concat(size," * ").concat(BADGE_FONT_SIZE_SCALE," )"):null,
top:badgeTop?offset:null,
bottom:badgeTop?null:offset,
left:badgeLeft?offset:null,
right:badgeLeft?null:offset};

}},

watch:{
src:function src(newValue,oldValue){
if(newValue!==oldValue){
this.localSrc=newValue||null;
}
}},

methods:{
onImgError:function onImgError(event){
this.localSrc=null;
this.$emit(EVENT_NAME_IMG_ERROR,event);
},
onClick:function onClick(event){
this.$emit(EVENT_NAME_CLICK,event);
}},

render:function render(h){
var _class2;

var variant=this.computedVariant,
disabled=this.disabled,
rounded=this.computedRounded,
icon=this.icon,
src=this.localSrc,
text=this.text,
fontStyle=this.fontStyle,
marginStyle=this.marginStyle,
size=this.computedSize,
button=this.button,
type=this.buttonType,
badge=this.badge,
badgeVariant=this.badgeVariant,
badgeStyle=this.badgeStyle;
var link=!button&&isLink(this);
var tag=button?BButton:link?BLink:'span';
var alt=this.alt;
var ariaLabel=this.ariaLabel||null;
var $content=null;

if(this.hasNormalizedSlot()){
// Default slot overrides props
$content=h('span',{
staticClass:'b-avatar-custom'},
[this.normalizeSlot()]);
}else if(src){
$content=h('img',{
style:variant?{}:{
width:'100%',
height:'100%'},

attrs:{
src:src,
alt:alt},

on:{
error:this.onImgError}});


$content=h('span',{
staticClass:'b-avatar-img'},
[$content]);
}else if(icon){
$content=h(BIcon,{
props:{
icon:icon},

attrs:{
'aria-hidden':'true',
alt:alt}});


}else if(text){
$content=h('span',{
staticClass:'b-avatar-text',
style:fontStyle},
[h('span',text)]);
}else {
// Fallback default avatar content
$content=h(BIconPersonFill,{
attrs:{
'aria-hidden':'true',
alt:alt}});


}

var $badge=h();
var hasBadgeSlot=this.hasNormalizedSlot(SLOT_NAME_BADGE);

if(badge||badge===''||hasBadgeSlot){
var badgeText=badge===true?'':badge;
$badge=h('span',{
staticClass:'b-avatar-badge',
class:_defineProperty({},"badge-".concat(badgeVariant),badgeVariant),
style:badgeStyle},
[hasBadgeSlot?this.normalizeSlot(SLOT_NAME_BADGE):badgeText]);
}

var componentData={
staticClass:CLASS_NAME$1,
class:(_class2={},_defineProperty(_class2,"".concat(CLASS_NAME$1,"-").concat(size),size&&SIZES.indexOf(size)!==-1),_defineProperty(_class2,"badge-".concat(variant),!button&&variant),_defineProperty(_class2,"rounded",rounded===true),_defineProperty(_class2,"rounded-".concat(rounded),rounded&&rounded!==true),_defineProperty(_class2,"disabled",disabled),_class2),
style:_objectSpread2(_objectSpread2({},marginStyle),{},{
width:size,
height:size}),

attrs:{
'aria-label':ariaLabel||null},

props:button?{
variant:variant,
disabled:disabled,
type:type}:
link?pluckProps(linkProps$1,this):{},
on:button||link?{
click:this.onClick}:
{}};

return h(tag,componentData,[$content,$badge]);
}});


var props$9=makePropsConfigurable({
overlap:makeProp(PROP_TYPE_NUMBER_STRING,0.3),
// Child avatars will prefer this prop (if set) over their own
rounded:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
// Child avatars will always use this over their own size
size:makeProp(PROP_TYPE_STRING),
// Child avatars will prefer this prop (if set) over their own
square:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div'),
// Child avatars will prefer this variant over their own
variant:makeProp(PROP_TYPE_STRING)},
NAME_AVATAR_GROUP);// --- Main component ---
// @vue/component

var BAvatarGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_AVATAR_GROUP,
mixins:[normalizeSlotMixin],
provide:function provide(){
return {
bvAvatarGroup:this};

},
props:props$9,
computed:{
computedSize:function computedSize(){
return computeSize(this.size);
},
overlapScale:function overlapScale(){
return mathMin(mathMax(toFloat(this.overlap,0),0),1)/2;
},
paddingStyle:function paddingStyle(){
var value=this.computedSize;
value=value?"calc(".concat(value," * ").concat(this.overlapScale,")"):null;
return value?{
paddingLeft:value,
paddingRight:value}:
{};
}},

render:function render(h){
var $inner=h('div',{
staticClass:'b-avatar-group-inner',
style:this.paddingStyle},
this.normalizeSlot());
return h(this.tag,{
staticClass:'b-avatar-group',
attrs:{
role:'group'}},

[$inner]);
}});


var AvatarPlugin=/*#__PURE__*/pluginFactory({
components:{
BAvatar:BAvatar,
BAvatarGroup:BAvatarGroup}});



var linkProps$2=omit(props$6,['event','routerTag']);
delete linkProps$2.href.default;
delete linkProps$2.to.default;
var props$a=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},linkProps$2),{},{
pill:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'span'),
variant:makeProp(PROP_TYPE_STRING,'secondary')})),
NAME_BADGE);// --- Main component ---
// @vue/component

var BBadge=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BADGE,
functional:true,
props:props$a,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var active=props.active,
disabled=props.disabled;
var link=isLink(props);
var tag=link?BLink:props.tag;
var variant=props.variant||'secondary';
return h(tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'badge',
class:["badge-".concat(variant),{
'badge-pill':props.pill,
active:active,
disabled:disabled}],

props:link?pluckProps(linkProps$2,props):{}}),
children);
}});


var BadgePlugin=/*#__PURE__*/pluginFactory({
components:{
BBadge:BBadge}});



var stripTags=function stripTags(){
var text=arguments.length>0&&arguments[0]!==undefined?arguments[0]:'';
return String(text).replace(RX_HTML_TAGS,'');
};// Generate a `domProps` object for either `innerHTML`, `textContent` or an empty object

var htmlOrText=function htmlOrText(innerHTML,textContent){
return innerHTML?{
innerHTML:innerHTML}:
textContent?{
textContent:textContent}:
{};
};

var props$b=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},omit(props$6,['event','routerTag'])),{},{
ariaCurrent:makeProp(PROP_TYPE_STRING,'location'),
html:makeProp(PROP_TYPE_STRING),
text:makeProp(PROP_TYPE_STRING)})),
NAME_BREADCRUMB_LINK);// --- Main component ---
// @vue/component

var BBreadcrumbLink=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BREADCRUMB_LINK,
functional:true,
props:props$b,
render:function render(h,_ref){
var suppliedProps=_ref.props,
data=_ref.data,
children=_ref.children;
var active=suppliedProps.active;
var tag=active?'span':BLink;
var componentData={
attrs:{
'aria-current':active?suppliedProps.ariaCurrent:null},

props:pluckProps(props$b,suppliedProps)};


if(!children){
componentData.domProps=htmlOrText(suppliedProps.html,suppliedProps.text);
}

return h(tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,componentData),children);
}});


var props$c=makePropsConfigurable(props$b,NAME_BREADCRUMB_ITEM);// --- Main component ---
// @vue/component

var BBreadcrumbItem=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BREADCRUMB_ITEM,
functional:true,
props:props$c,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'breadcrumb-item',
class:{
active:props.active}}),

[h(BBreadcrumbLink,{
props:props},
children)]);
}});


var props$d=makePropsConfigurable({
items:makeProp(PROP_TYPE_ARRAY)},
NAME_BREADCRUMB);// --- Main component ---
// @vue/component

var BBreadcrumb=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BREADCRUMB,
functional:true,
props:props$d,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var items=props.items;// Build child nodes from items, if given

var childNodes=children;

if(isArray(items)){
var activeDefined=false;
childNodes=items.map(function(item,idx){
if(!isObject(item)){
item={
text:toString$1(item)};

}// Copy the value here so we can normalize it


var _item=item,
active=_item.active;

if(active){
activeDefined=true;
}// Auto-detect active by position in list


if(!active&&!activeDefined){
active=idx+1===items.length;
}

return h(BBreadcrumbItem,{
props:_objectSpread2(_objectSpread2({},item),{},{
active:active})});


});
}

return h('ol',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'breadcrumb'}),
childNodes);
}});


var BreadcrumbPlugin=/*#__PURE__*/pluginFactory({
components:{
BBreadcrumb:BBreadcrumb,
BBreadcrumbItem:BBreadcrumbItem,
BBreadcrumbLink:BBreadcrumbLink}});



var ButtonPlugin=/*#__PURE__*/pluginFactory({
components:{
BButton:BButton,
BBtn:BButton,
BButtonClose:BButtonClose,
BBtnClose:BButtonClose}});



var props$e=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},pick(props$7,['size'])),{},{
ariaRole:makeProp(PROP_TYPE_STRING,'group'),
size:makeProp(PROP_TYPE_STRING),
tag:makeProp(PROP_TYPE_STRING,'div'),
vertical:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_BUTTON_GROUP);// --- Main component ---
// @vue/component

var BButtonGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BUTTON_GROUP,
functional:true,
props:props$e,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:_defineProperty({
'btn-group':!props.vertical,
'btn-group-vertical':props.vertical},
"btn-group-".concat(props.size),props.size),
attrs:{
role:props.ariaRole}}),

children);
}});


var ButtonGroupPlugin=/*#__PURE__*/pluginFactory({
components:{
BButtonGroup:BButtonGroup,
BBtnGroup:BButtonGroup}});



var ITEM_SELECTOR=['.btn:not(.disabled):not([disabled]):not(.dropdown-item)','.form-control:not(.disabled):not([disabled])','select:not(.disabled):not([disabled])','input[type="checkbox"]:not(.disabled)','input[type="radio"]:not(.disabled)'].join(',');// --- Props ---

var props$f=makePropsConfigurable({
justify:makeProp(PROP_TYPE_BOOLEAN,false),
keyNav:makeProp(PROP_TYPE_BOOLEAN,false)},
NAME_BUTTON_TOOLBAR);// --- Main component ---
// @vue/component

var BButtonToolbar=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_BUTTON_TOOLBAR,
mixins:[normalizeSlotMixin],
props:props$f,
mounted:function mounted(){
// Pre-set the tabindexes if the markup does not include
// `tabindex="-1"` on the toolbar items
if(this.keyNav){
this.getItems();
}
},
methods:{
getItems:function getItems(){
var items=selectAll(ITEM_SELECTOR,this.$el);// Ensure `tabindex="-1"` is set on every item

items.forEach(function(item){
item.tabIndex=-1;
});
return items.filter(function(el){
return isVisible(el);
});
},
focusFirst:function focusFirst(){
var items=this.getItems();
attemptFocus(items[0]);
},
focusPrev:function focusPrev(event){
var items=this.getItems();
var index=items.indexOf(event.target);

if(index>-1){
items=items.slice(0,index).reverse();
attemptFocus(items[0]);
}
},
focusNext:function focusNext(event){
var items=this.getItems();
var index=items.indexOf(event.target);

if(index>-1){
items=items.slice(index+1);
attemptFocus(items[0]);
}
},
focusLast:function focusLast(){
var items=this.getItems().reverse();
attemptFocus(items[0]);
},
onFocusin:function onFocusin(event){
var $el=this.$el;

if(event.target===$el&&!contains($el,event.relatedTarget)){
stopEvent(event);
this.focusFirst(event);
}
},
onKeydown:function onKeydown(event){
var keyCode=event.keyCode,
shiftKey=event.shiftKey;

if(keyCode===CODE_UP||keyCode===CODE_LEFT){
stopEvent(event);
shiftKey?this.focusFirst(event):this.focusPrev(event);
}else if(keyCode===CODE_DOWN||keyCode===CODE_RIGHT){
stopEvent(event);
shiftKey?this.focusLast(event):this.focusNext(event);
}
}},

render:function render(h){
var keyNav=this.keyNav;
return h('div',{
staticClass:'btn-toolbar',
class:{
'justify-content-between':this.justify},

attrs:{
role:'toolbar',
tabindex:keyNav?'0':null},

on:keyNav?{
focusin:this.onFocusin,
keydown:this.onKeydown}:
{}},
[this.normalizeSlot()]);
}});


var ButtonToolbarPlugin=/*#__PURE__*/pluginFactory({
components:{
BButtonToolbar:BButtonToolbar,
BBtnToolbar:BButtonToolbar}});



var CALENDAR_GREGORY='gregory';
var CALENDAR_LONG='long';
var CALENDAR_NARROW='narrow';
var CALENDAR_SHORT='short';
var DATE_FORMAT_2_DIGIT='2-digit';
var DATE_FORMAT_NUMERIC='numeric';

// Create or clone a date (`new Date(...)` shortcut)

var createDate=function createDate(){
for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){
args[_key]=arguments[_key];
}

return _construct(Date,args);
};// Parse a date sting, or Date object, into a Date object (with no time information)

var parseYMD=function parseYMD(date){
if(isString(date)&&RX_DATE.test(date.trim())){
var _date$split$map=date.split(RX_DATE_SPLIT).map(function(v){
return toInteger(v,1);
}),
_date$split$map2=_slicedToArray(_date$split$map,3),
year=_date$split$map2[0],
month=_date$split$map2[1],
day=_date$split$map2[2];

return createDate(year,month-1,day);
}else if(isDate(date)){
return createDate(date.getFullYear(),date.getMonth(),date.getDate());
}

return null;
};// Format a date object as `YYYY-MM-DD` format

var formatYMD=function formatYMD(date){
date=parseYMD(date);

if(!date){
return null;
}

var year=date.getFullYear();
var month="0".concat(date.getMonth()+1).slice(-2);
var day="0".concat(date.getDate()).slice(-2);
return "".concat(year,"-").concat(month,"-").concat(day);
};// Given a locale (or locales), resolve the browser available locale

var resolveLocale=function resolveLocale(locales)
/* istanbul ignore next */
{
var calendar=arguments.length>1&&arguments[1]!==undefined?arguments[1]:CALENDAR_GREGORY;
locales=concat(locales).filter(identity);
var fmt=new Intl.DateTimeFormat(locales,{
calendar:calendar});

return fmt.resolvedOptions().locale;
};// Create a `Intl.DateTimeFormat` formatter function

var createDateFormatter=function createDateFormatter(locale,options)
/* istanbul ignore next */
{
var dtf=new Intl.DateTimeFormat(locale,options);
return dtf.format;
};// Determine if two dates are the same date (ignoring time portion)

var datesEqual=function datesEqual(date1,date2){
// Returns true of the date portion of two date objects are equal
// We don't compare the time portion
return formatYMD(date1)===formatYMD(date2);
};// --- Date "math" utility methods (for BCalendar component mainly) ---

var firstDateOfMonth=function firstDateOfMonth(date){
date=createDate(date);
date.setDate(1);
return date;
};
var lastDateOfMonth=function lastDateOfMonth(date){
date=createDate(date);
date.setMonth(date.getMonth()+1);
date.setDate(0);
return date;
};
var addYears=function addYears(date,numberOfYears){
date=createDate(date);
var month=date.getMonth();
date.setFullYear(date.getFullYear()+numberOfYears);// Handle Feb 29th for leap years

if(date.getMonth()!==month){
date.setDate(0);
}

return date;
};
var oneMonthAgo=function oneMonthAgo(date){
date=createDate(date);
var month=date.getMonth();
date.setMonth(month-1);// Handle when days in month are different

if(date.getMonth()===month){
date.setDate(0);
}

return date;
};
var oneMonthAhead=function oneMonthAhead(date){
date=createDate(date);
var month=date.getMonth();
date.setMonth(month+1);// Handle when days in month are different

if(date.getMonth()===(month+2)%12){
date.setDate(0);
}

return date;
};
var oneYearAgo=function oneYearAgo(date){
return addYears(date,-1);
};
var oneYearAhead=function oneYearAhead(date){
return addYears(date,1);
};
var oneDecadeAgo=function oneDecadeAgo(date){
return addYears(date,-10);
};
var oneDecadeAhead=function oneDecadeAhead(date){
return addYears(date,10);
};// Helper function to constrain a date between two values
// Always returns a `Date` object or `null` if no date passed

var constrainDate=function constrainDate(date){
var min=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;
var max=arguments.length>2&&arguments[2]!==undefined?arguments[2]:null;
// Ensure values are `Date` objects (or `null`)
date=parseYMD(date);
min=parseYMD(min)||date;
max=parseYMD(max)||date;// Return a new `Date` object (or `null`)

return date?date<min?min:date>max?max:date:null;
};

// Localization utilities

var RTL_LANGS=['ar','az','ckb','fa','he','ks','lrc','mzn','ps','sd','te','ug','ur','yi'].map(function(locale){
return locale.toLowerCase();
});// Returns true if the locale is RTL

var isLocaleRTL=function isLocaleRTL(locale){
// Determines if the locale is RTL (only single locale supported)
var parts=toString$1(locale).toLowerCase().replace(RX_STRIP_LOCALE_MODS,'').split('-');
var locale1=parts.slice(0,2).join('-');
var locale2=parts[0];
return arrayIncludes(RTL_LANGS,locale1)||arrayIncludes(RTL_LANGS,locale2);
};

// SSR safe client-side ID attribute generation

var props$g={
id:makeProp(PROP_TYPE_STRING)};
// --- Mixin ---
// @vue/component

var idMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$g,
data:function data(){
return {
localId_:null};

},
computed:{
safeId:function safeId(){
// Computed property that returns a dynamic function for creating the ID
// Reacts to changes in both `.id` and `.localId_` and regenerates a new function
var id=this.id||this.localId_;// We return a function that accepts an optional suffix string
// So this computed prop looks and works like a method
// but benefits from Vue's computed prop caching

var fn=function fn(suffix){
if(!id){
return null;
}

suffix=String(suffix||'').replace(/\s+/g,'_');
return suffix?id+'_'+suffix:id;
};

return fn;
}},

mounted:function mounted(){
var _this=this;

// `mounted()` only occurs client-side
this.$nextTick(function(){
// Update DOM with auto-generated ID after mount
// to prevent SSR hydration errors
_this.localId_="__BVID__".concat(_this[COMPONENT_UID_KEY]);
});
}});


var _watch$1;

var _makeModelMixin$1=makeModelMixin('value',{
type:PROP_TYPE_DATE_STRING}),

modelMixin$1=_makeModelMixin$1.mixin,
modelProps$1=_makeModelMixin$1.props,
MODEL_PROP_NAME$1=_makeModelMixin$1.prop,
MODEL_EVENT_NAME$1=_makeModelMixin$1.event;// --- Props ---


var props$h=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$1),{},{
ariaControls:makeProp(PROP_TYPE_STRING),
// Makes calendar the full width of its parent container
block:makeProp(PROP_TYPE_BOOLEAN,false),
dateDisabledFn:makeProp(PROP_TYPE_FUNCTION),
// `Intl.DateTimeFormat` object
dateFormatOptions:makeProp(PROP_TYPE_OBJECT,{
year:DATE_FORMAT_NUMERIC,
month:CALENDAR_LONG,
day:DATE_FORMAT_NUMERIC,
weekday:CALENDAR_LONG}),

// Function to set a class of (classes) on the date cell
// if passed a string or an array
// TODO:
//   If the function returns an object, look for class prop for classes,
//   and other props for handling events/details/descriptions
dateInfoFn:makeProp(PROP_TYPE_FUNCTION),
// 'ltr', 'rtl', or `null` (for auto detect)
direction:makeProp(PROP_TYPE_STRING),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
// When `true`, renders a comment node, but keeps the component instance active
// Mainly for <b-form-date>, so that we can get the component's value and locale
// But we might just use separate date formatters, using the resolved locale
// (adjusted for the gregorian calendar)
hidden:makeProp(PROP_TYPE_BOOLEAN,false),
// When `true` makes the selected date header `sr-only`
hideHeader:makeProp(PROP_TYPE_BOOLEAN,false),
// This specifies the calendar year/month/day that will be shown when
// first opening the datepicker if no v-model value is provided
// Default is the current date (or `min`/`max`)
initialDate:makeProp(PROP_TYPE_DATE_STRING),
// Labels for buttons and keyboard shortcuts
labelCalendar:makeProp(PROP_TYPE_STRING,'Calendar'),
labelCurrentMonth:makeProp(PROP_TYPE_STRING,'Current month'),
labelHelp:makeProp(PROP_TYPE_STRING,'Use cursor keys to navigate calendar dates'),
labelNav:makeProp(PROP_TYPE_STRING,'Calendar navigation'),
labelNextDecade:makeProp(PROP_TYPE_STRING,'Next decade'),
labelNextMonth:makeProp(PROP_TYPE_STRING,'Next month'),
labelNextYear:makeProp(PROP_TYPE_STRING,'Next year'),
labelNoDateSelected:makeProp(PROP_TYPE_STRING,'No date selected'),
labelPrevDecade:makeProp(PROP_TYPE_STRING,'Previous decade'),
labelPrevMonth:makeProp(PROP_TYPE_STRING,'Previous month'),
labelPrevYear:makeProp(PROP_TYPE_STRING,'Previous year'),
labelSelected:makeProp(PROP_TYPE_STRING,'Selected date'),
labelToday:makeProp(PROP_TYPE_STRING,'Today'),
// Locale(s) to use
// Default is to use page/browser default setting
locale:makeProp(PROP_TYPE_ARRAY_STRING),
max:makeProp(PROP_TYPE_DATE_STRING),
min:makeProp(PROP_TYPE_DATE_STRING),
// Variant color to use for the navigation buttons
navButtonVariant:makeProp(PROP_TYPE_STRING,'secondary'),
// Disable highlighting today's date
noHighlightToday:makeProp(PROP_TYPE_BOOLEAN,false),
noKeyNav:makeProp(PROP_TYPE_BOOLEAN,false),
readonly:makeProp(PROP_TYPE_BOOLEAN,false),
roleDescription:makeProp(PROP_TYPE_STRING),
// Variant color to use for the selected date
selectedVariant:makeProp(PROP_TYPE_STRING,'primary'),
// When `true` enables the decade navigation buttons
showDecadeNav:makeProp(PROP_TYPE_BOOLEAN,false),
// Day of week to start calendar on
// `0` (Sunday), `1` (Monday), ... `6` (Saturday)
startWeekday:makeProp(PROP_TYPE_NUMBER_STRING,0),
// Variant color to use for today's date (defaults to `selectedVariant`)
todayVariant:makeProp(PROP_TYPE_STRING),
// Always return the `v-model` value as a date object
valueAsDate:makeProp(PROP_TYPE_BOOLEAN,false),
// Format of the weekday names at the top of the calendar
// `short` is typically a 3 letter abbreviation,
// `narrow` is typically a single letter
// `long` is the full week day name
// Although some locales may override this (i.e `ar`, etc.)
weekdayHeaderFormat:makeProp(PROP_TYPE_STRING,CALENDAR_SHORT,function(value){
return arrayIncludes([CALENDAR_LONG,CALENDAR_SHORT,CALENDAR_NARROW],value);
}),
// Has no effect if prop `block` is set
width:makeProp(PROP_TYPE_STRING,'270px')})),
NAME_CALENDAR);// --- Main component ---
// @vue/component

var BCalendar=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CALENDAR,
// Mixin order is important!
mixins:[attrsMixin,idMixin,modelMixin$1,normalizeSlotMixin],
props:props$h,
data:function data(){
var selected=formatYMD(this[MODEL_PROP_NAME$1])||'';
return {
// Selected date
selectedYMD:selected,
// Date in calendar grid that has `tabindex` of `0`
activeYMD:selected||formatYMD(constrainDate(this.initialDate||this.getToday()),this.min,this.max),
// Will be true if the calendar grid has/contains focus
gridHasFocus:false,
// Flag to enable the `aria-live` region(s) after mount
// to prevent screen reader "outbursts" when mounting
isLive:false};

},
computed:{
valueId:function valueId(){
return this.safeId();
},
widgetId:function widgetId(){
return this.safeId('_calendar-wrapper_');
},
navId:function navId(){
return this.safeId('_calendar-nav_');
},
gridId:function gridId(){
return this.safeId('_calendar-grid_');
},
gridCaptionId:function gridCaptionId(){
return this.safeId('_calendar-grid-caption_');
},
gridHelpId:function gridHelpId(){
return this.safeId('_calendar-grid-help_');
},
activeId:function activeId(){
return this.activeYMD?this.safeId("_cell-".concat(this.activeYMD,"_")):null;
},
// TODO: Use computed props to convert `YYYY-MM-DD` to `Date` object
selectedDate:function selectedDate(){
// Selected as a `Date` object
return parseYMD(this.selectedYMD);
},
activeDate:function activeDate(){
// Active as a `Date` object
return parseYMD(this.activeYMD);
},
computedMin:function computedMin(){
return parseYMD(this.min);
},
computedMax:function computedMax(){
return parseYMD(this.max);
},
computedWeekStarts:function computedWeekStarts(){
// `startWeekday` is a prop (constrained to `0` through `6`)
return mathMax(toInteger(this.startWeekday,0),0)%7;
},
computedLocale:function computedLocale(){
// Returns the resolved locale used by the calendar
return resolveLocale(concat(this.locale).filter(identity),CALENDAR_GREGORY);
},
computedDateDisabledFn:function computedDateDisabledFn(){
var dateDisabledFn=this.dateDisabledFn;
return hasPropFunction(dateDisabledFn)?dateDisabledFn:function(){
return false;
};
},
// TODO: Change `dateInfoFn` to handle events and notes as well as classes
computedDateInfoFn:function computedDateInfoFn(){
var dateInfoFn=this.dateInfoFn;
return hasPropFunction(dateInfoFn)?dateInfoFn:function(){
return {};
};
},
calendarLocale:function calendarLocale(){
// This locale enforces the gregorian calendar (for use in formatter functions)
// Needed because IE 11 resolves `ar-IR` as islamic-civil calendar
// and IE 11 (and some other browsers) do not support the `calendar` option
// And we currently only support the gregorian calendar
var fmt=new Intl.DateTimeFormat(this.computedLocale,{
calendar:CALENDAR_GREGORY});

var calendar=fmt.resolvedOptions().calendar;
var locale=fmt.resolvedOptions().locale;
/* istanbul ignore if: mainly for IE 11 and a few other browsers, hard to test in JSDOM */

if(calendar!==CALENDAR_GREGORY){
// Ensure the locale requests the gregorian calendar
// Mainly for IE 11, and currently we can't handle non-gregorian calendars
// TODO: Should we always return this value?
locale=locale.replace(/-u-.+$/i,'').concat('-u-ca-gregory');
}

return locale;
},
calendarYear:function calendarYear(){
return this.activeDate.getFullYear();
},
calendarMonth:function calendarMonth(){
return this.activeDate.getMonth();
},
calendarFirstDay:function calendarFirstDay(){
// We set the time for this date to 12pm to work around
// date formatting issues in Firefox and Safari
// See: https://github.com/bootstrap-vue/bootstrap-vue/issues/5818
return createDate(this.calendarYear,this.calendarMonth,1,12);
},
calendarDaysInMonth:function calendarDaysInMonth(){
// We create a new date as to not mutate the original
var date=createDate(this.calendarFirstDay);
date.setMonth(date.getMonth()+1,0);
return date.getDate();
},
computedVariant:function computedVariant(){
return "btn-".concat(this.selectedVariant||'primary');
},
computedTodayVariant:function computedTodayVariant(){
return "btn-outline-".concat(this.todayVariant||this.selectedVariant||'primary');
},
computedNavButtonVariant:function computedNavButtonVariant(){
return "btn-outline-".concat(this.navButtonVariant||'primary');
},
isRTL:function isRTL(){
// `true` if the language requested is RTL
var dir=toString$1(this.direction).toLowerCase();

if(dir==='rtl'){
/* istanbul ignore next */
return true;
}else if(dir==='ltr'){
/* istanbul ignore next */
return false;
}

return isLocaleRTL(this.computedLocale);
},
context:function context(){
var selectedYMD=this.selectedYMD,
activeYMD=this.activeYMD;
var selectedDate=parseYMD(selectedYMD);
var activeDate=parseYMD(activeYMD);
return {
// The current value of the `v-model`
selectedYMD:selectedYMD,
selectedDate:selectedDate,
selectedFormatted:selectedDate?this.formatDateString(selectedDate):this.labelNoDateSelected,
// Which date cell is considered active due to navigation
activeYMD:activeYMD,
activeDate:activeDate,
activeFormatted:activeDate?this.formatDateString(activeDate):'',
// `true` if the date is disabled (when using keyboard navigation)
disabled:this.dateDisabled(activeDate),
// Locales used in formatting dates
locale:this.computedLocale,
calendarLocale:this.calendarLocale,
rtl:this.isRTL};

},
// Computed props that return a function reference
dateOutOfRange:function dateOutOfRange(){
// Check whether a date is within the min/max range
// Returns a new function ref if the pops change
// We do this as we need to trigger the calendar computed prop
// to update when these props update
var min=this.computedMin,
max=this.computedMax;
return function(date){
// Handle both `YYYY-MM-DD` and `Date` objects
date=parseYMD(date);
return min&&date<min||max&&date>max;
};
},
dateDisabled:function dateDisabled(){
var _this=this;

// Returns a function for validating if a date is within range
// We grab this variables first to ensure a new function ref
// is generated when the props value changes
// We do this as we need to trigger the calendar computed prop
// to update when these props update
var rangeFn=this.dateOutOfRange;// Return the function ref

return function(date){
// Handle both `YYYY-MM-DD` and `Date` objects
date=parseYMD(date);
var ymd=formatYMD(date);
return !!(rangeFn(date)||_this.computedDateDisabledFn(ymd,date));
};
},
// Computed props that return date formatter functions
formatDateString:function formatDateString(){
// Returns a date formatter function
return createDateFormatter(this.calendarLocale,_objectSpread2(_objectSpread2({
// Ensure we have year, month, day shown for screen readers/ARIA
// If users really want to leave one of these out, they can
// pass `undefined` for the property value
year:DATE_FORMAT_NUMERIC,
month:DATE_FORMAT_2_DIGIT,
day:DATE_FORMAT_2_DIGIT},
this.dateFormatOptions),{},{
// Ensure hours/minutes/seconds are not shown
// As we do not support the time portion (yet)
hour:undefined,
minute:undefined,
second:undefined,
// Ensure calendar is gregorian
calendar:CALENDAR_GREGORY}));

},
formatYearMonth:function formatYearMonth(){
// Returns a date formatter function
return createDateFormatter(this.calendarLocale,{
year:DATE_FORMAT_NUMERIC,
month:CALENDAR_LONG,
calendar:CALENDAR_GREGORY});

},
formatWeekdayName:function formatWeekdayName(){
// Long weekday name for weekday header aria-label
return createDateFormatter(this.calendarLocale,{
weekday:CALENDAR_LONG,
calendar:CALENDAR_GREGORY});

},
formatWeekdayNameShort:function formatWeekdayNameShort(){
// Weekday header cell format
// defaults to 'short' 3 letter days, where possible
return createDateFormatter(this.calendarLocale,{
weekday:this.weekdayHeaderFormat||CALENDAR_SHORT,
calendar:CALENDAR_GREGORY});

},
formatDay:function formatDay(){
// Calendar grid day number formatter
// We don't use DateTimeFormatter here as it can place extra
// character(s) after the number (i.e the `zh` locale)
var nf=new Intl.NumberFormat([this.computedLocale],{
style:'decimal',
minimumIntegerDigits:1,
minimumFractionDigits:0,
maximumFractionDigits:0,
notation:'standard'});
// Return a formatter function instance

return function(date){
return nf.format(date.getDate());
};
},
// Disabled states for the nav buttons
prevDecadeDisabled:function prevDecadeDisabled(){
var min=this.computedMin;
return this.disabled||min&&lastDateOfMonth(oneDecadeAgo(this.activeDate))<min;
},
prevYearDisabled:function prevYearDisabled(){
var min=this.computedMin;
return this.disabled||min&&lastDateOfMonth(oneYearAgo(this.activeDate))<min;
},
prevMonthDisabled:function prevMonthDisabled(){
var min=this.computedMin;
return this.disabled||min&&lastDateOfMonth(oneMonthAgo(this.activeDate))<min;
},
thisMonthDisabled:function thisMonthDisabled(){
// TODO: We could/should check if today is out of range
return this.disabled;
},
nextMonthDisabled:function nextMonthDisabled(){
var max=this.computedMax;
return this.disabled||max&&firstDateOfMonth(oneMonthAhead(this.activeDate))>max;
},
nextYearDisabled:function nextYearDisabled(){
var max=this.computedMax;
return this.disabled||max&&firstDateOfMonth(oneYearAhead(this.activeDate))>max;
},
nextDecadeDisabled:function nextDecadeDisabled(){
var max=this.computedMax;
return this.disabled||max&&firstDateOfMonth(oneDecadeAhead(this.activeDate))>max;
},
// Calendar dates generation
calendar:function calendar(){
var matrix=[];
var firstDay=this.calendarFirstDay;
var calendarYear=firstDay.getFullYear();
var calendarMonth=firstDay.getMonth();
var daysInMonth=this.calendarDaysInMonth;
var startIndex=firstDay.getDay();// `0`..`6`

var weekOffset=(this.computedWeekStarts>startIndex?7:0)-this.computedWeekStarts;// Build the calendar matrix

var currentDay=0-weekOffset-startIndex;

for(var week=0;week<6&&currentDay<daysInMonth;week++){
// For each week
matrix[week]=[];// The following could be a map function

for(var j=0;j<7;j++){
// For each day in week
currentDay++;
var date=createDate(calendarYear,calendarMonth,currentDay);
var month=date.getMonth();
var dayYMD=formatYMD(date);
var dayDisabled=this.dateDisabled(date);// TODO: This could be a normalizer method

var dateInfo=this.computedDateInfoFn(dayYMD,parseYMD(dayYMD));
dateInfo=isString(dateInfo)||isArray(dateInfo)?
/* istanbul ignore next */
{
class:dateInfo}:
isPlainObject(dateInfo)?_objectSpread2({
class:''},
dateInfo):
/* istanbul ignore next */
{
class:''};

matrix[week].push({
ymd:dayYMD,
// Cell content
day:this.formatDay(date),
label:this.formatDateString(date),
// Flags for styling
isThisMonth:month===calendarMonth,
isDisabled:dayDisabled,
// TODO: Handle other dateInfo properties such as notes/events
info:dateInfo});

}
}

return matrix;
},
calendarHeadings:function calendarHeadings(){
var _this2=this;

return this.calendar[0].map(function(d){
return {
text:_this2.formatWeekdayNameShort(parseYMD(d.ymd)),
label:_this2.formatWeekdayName(parseYMD(d.ymd))};

});
}},

watch:(_watch$1={},_defineProperty(_watch$1,MODEL_PROP_NAME$1,function(newValue,oldValue){
var selected=formatYMD(newValue)||'';
var old=formatYMD(oldValue)||'';

if(!datesEqual(selected,old)){
this.activeYMD=selected||this.activeYMD;
this.selectedYMD=selected;
}
}),_defineProperty(_watch$1,"selectedYMD",function selectedYMD(newYMD,oldYMD){
// TODO:
//   Should we compare to `formatYMD(this.value)` and emit
//   only if they are different?
if(newYMD!==oldYMD){
this.$emit(MODEL_EVENT_NAME$1,this.valueAsDate?parseYMD(newYMD)||null:newYMD||'');
}
}),_defineProperty(_watch$1,"context",function context(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.$emit(EVENT_NAME_CONTEXT,newValue);
}
}),_defineProperty(_watch$1,"hidden",function hidden(newValue){
// Reset the active focused day when hidden
this.activeYMD=this.selectedYMD||formatYMD(this[MODEL_PROP_NAME$1]||this.constrainDate(this.initialDate||this.getToday()));// Enable/disable the live regions

this.setLive(!newValue);
}),_watch$1),
created:function created(){
var _this3=this;

this.$nextTick(function(){
_this3.$emit(EVENT_NAME_CONTEXT,_this3.context);
});
},
mounted:function mounted(){
this.setLive(true);
},

/* istanbul ignore next */
activated:function activated(){
this.setLive(true);
},

/* istanbul ignore next */
deactivated:function deactivated(){
this.setLive(false);
},
beforeDestroy:function beforeDestroy(){
this.setLive(false);
},
methods:{
// Public method(s)
focus:function focus(){
if(!this.disabled){
attemptFocus(this.$refs.grid);
}
},
blur:function blur(){
if(!this.disabled){
attemptBlur(this.$refs.grid);
}
},
// Private methods
setLive:function setLive(on){
var _this4=this;

if(on){
this.$nextTick(function(){
requestAF(function(){
_this4.isLive=true;
});
});
}else {
this.isLive=false;
}
},
getToday:function getToday(){
return parseYMD(createDate());
},
constrainDate:function constrainDate$1(date){
// Constrains a date between min and max
// returns a new `Date` object instance
return constrainDate(date,this.computedMin,this.computedMax);
},
emitSelected:function emitSelected(date){
var _this5=this;

// Performed in a `$nextTick()` to (probably) ensure
// the input event has emitted first
this.$nextTick(function(){
_this5.$emit(EVENT_NAME_SELECTED,formatYMD(date)||'',parseYMD(date)||null);
});
},
// Event handlers
setGridFocusFlag:function setGridFocusFlag(event){
// Sets the gridHasFocus flag to make date "button" look focused
this.gridHasFocus=!this.disabled&&event.type==='focus';
},
onKeydownWrapper:function onKeydownWrapper(event){
// Calendar keyboard navigation
// Handles PAGEUP/PAGEDOWN/END/HOME/LEFT/UP/RIGHT/DOWN
// Focuses grid after updating
if(this.noKeyNav){
/* istanbul ignore next */
return;
}

var altKey=event.altKey,
ctrlKey=event.ctrlKey,
keyCode=event.keyCode;

if(!arrayIncludes([CODE_PAGEUP,CODE_PAGEDOWN,CODE_END,CODE_HOME,CODE_LEFT,CODE_UP,CODE_RIGHT,CODE_DOWN],keyCode)){
/* istanbul ignore next */
return;
}

stopEvent(event);
var activeDate=createDate(this.activeDate);
var checkDate=createDate(this.activeDate);
var day=activeDate.getDate();
var constrainedToday=this.constrainDate(this.getToday());
var isRTL=this.isRTL;

if(keyCode===CODE_PAGEUP){
// PAGEUP - Previous month/year
activeDate=(altKey?ctrlKey?oneDecadeAgo:oneYearAgo:oneMonthAgo)(activeDate);// We check the first day of month to be in rage

checkDate=createDate(activeDate);
checkDate.setDate(1);
}else if(keyCode===CODE_PAGEDOWN){
// PAGEDOWN - Next month/year
activeDate=(altKey?ctrlKey?oneDecadeAhead:oneYearAhead:oneMonthAhead)(activeDate);// We check the last day of month to be in rage

checkDate=createDate(activeDate);
checkDate.setMonth(checkDate.getMonth()+1);
checkDate.setDate(0);
}else if(keyCode===CODE_LEFT){
// LEFT - Previous day (or next day for RTL)
activeDate.setDate(day+(isRTL?1:-1));
activeDate=this.constrainDate(activeDate);
checkDate=activeDate;
}else if(keyCode===CODE_RIGHT){
// RIGHT - Next day (or previous day for RTL)
activeDate.setDate(day+(isRTL?-1:1));
activeDate=this.constrainDate(activeDate);
checkDate=activeDate;
}else if(keyCode===CODE_UP){
// UP - Previous week
activeDate.setDate(day-7);
activeDate=this.constrainDate(activeDate);
checkDate=activeDate;
}else if(keyCode===CODE_DOWN){
// DOWN - Next week
activeDate.setDate(day+7);
activeDate=this.constrainDate(activeDate);
checkDate=activeDate;
}else if(keyCode===CODE_HOME){
// HOME - Today
activeDate=constrainedToday;
checkDate=activeDate;
}else if(keyCode===CODE_END){
// END - Selected date, or today if no selected date
activeDate=parseYMD(this.selectedDate)||constrainedToday;
checkDate=activeDate;
}

if(!this.dateOutOfRange(checkDate)&&!datesEqual(activeDate,this.activeDate)){
// We only jump to date if within min/max
// We don't check for individual disabled dates though (via user function)
this.activeYMD=formatYMD(activeDate);
}// Ensure grid is focused


this.focus();
},
onKeydownGrid:function onKeydownGrid(event){
// Pressing enter/space on grid to select active date
var keyCode=event.keyCode;
var activeDate=this.activeDate;

if(keyCode===CODE_ENTER||keyCode===CODE_SPACE){
stopEvent(event);

if(!this.disabled&&!this.readonly&&!this.dateDisabled(activeDate)){
this.selectedYMD=formatYMD(activeDate);
this.emitSelected(activeDate);
}// Ensure grid is focused


this.focus();
}
},
onClickDay:function onClickDay(day){
// Clicking on a date "button" to select it
var selectedDate=this.selectedDate,
activeDate=this.activeDate;
var clickedDate=parseYMD(day.ymd);

if(!this.disabled&&!day.isDisabled&&!this.dateDisabled(clickedDate)){
if(!this.readonly){
// If readonly mode, we don't set the selected date, just the active date
// If the clicked date is equal to the already selected date, we don't update the model
this.selectedYMD=formatYMD(datesEqual(clickedDate,selectedDate)?selectedDate:clickedDate);
this.emitSelected(clickedDate);
}

this.activeYMD=formatYMD(datesEqual(clickedDate,activeDate)?activeDate:createDate(clickedDate));// Ensure grid is focused

this.focus();
}
},
gotoPrevDecade:function gotoPrevDecade(){
this.activeYMD=formatYMD(this.constrainDate(oneDecadeAgo(this.activeDate)));
},
gotoPrevYear:function gotoPrevYear(){
this.activeYMD=formatYMD(this.constrainDate(oneYearAgo(this.activeDate)));
},
gotoPrevMonth:function gotoPrevMonth(){
this.activeYMD=formatYMD(this.constrainDate(oneMonthAgo(this.activeDate)));
},
gotoCurrentMonth:function gotoCurrentMonth(){
// TODO: Maybe this goto date should be configurable?
this.activeYMD=formatYMD(this.constrainDate(this.getToday()));
},
gotoNextMonth:function gotoNextMonth(){
this.activeYMD=formatYMD(this.constrainDate(oneMonthAhead(this.activeDate)));
},
gotoNextYear:function gotoNextYear(){
this.activeYMD=formatYMD(this.constrainDate(oneYearAhead(this.activeDate)));
},
gotoNextDecade:function gotoNextDecade(){
this.activeYMD=formatYMD(this.constrainDate(oneDecadeAhead(this.activeDate)));
},
onHeaderClick:function onHeaderClick(){
if(!this.disabled){
this.activeYMD=this.selectedYMD||formatYMD(this.getToday());
this.focus();
}
}},

render:function render(h){
var _this6=this;

// If `hidden` prop is set, render just a placeholder node
if(this.hidden){
return h();
}

var valueId=this.valueId,
widgetId=this.widgetId,
navId=this.navId,
gridId=this.gridId,
gridCaptionId=this.gridCaptionId,
gridHelpId=this.gridHelpId,
activeId=this.activeId,
disabled=this.disabled,
noKeyNav=this.noKeyNav,
isLive=this.isLive,
isRTL=this.isRTL,
activeYMD=this.activeYMD,
selectedYMD=this.selectedYMD,
safeId=this.safeId;
var hideDecadeNav=!this.showDecadeNav;
var todayYMD=formatYMD(this.getToday());
var highlightToday=!this.noHighlightToday;// Header showing current selected date

var $header=h('output',{
staticClass:'form-control form-control-sm text-center',
class:{
'text-muted':disabled,
readonly:this.readonly||disabled},

attrs:{
id:valueId,
for:gridId,
role:'status',
tabindex:disabled?null:'-1',
// Mainly for testing purposes, as we do not know
// the exact format `Intl` will format the date string
'data-selected':toString$1(selectedYMD),
// We wait until after mount to enable `aria-live`
// to prevent initial announcement on page render
'aria-live':isLive?'polite':'off',
'aria-atomic':isLive?'true':null},

on:{
// Transfer focus/click to focus grid
// and focus active date (or today if no selection)
click:this.onHeaderClick,
focus:this.onHeaderClick}},

this.selectedDate?[// We use `bdi` elements here in case the label doesn't match the locale
// Although IE 11 does not deal with <BDI> at all (equivalent to a span)
h('bdi',{
staticClass:'sr-only'},
" (".concat(toString$1(this.labelSelected),") ")),h('bdi',this.formatDateString(this.selectedDate))]:this.labelNoDateSelected||"\xA0"// '&nbsp;'
);
$header=h('header',{
staticClass:'b-calendar-header',
class:{
'sr-only':this.hideHeader},

attrs:{
title:this.selectedDate?this.labelSelectedDate||null:null}},

[$header]);// Content for the date navigation buttons

var navScope={
isRTL:isRTL};

var navProps={
shiftV:0.5};


var navPrevProps=_objectSpread2(_objectSpread2({},navProps),{},{
flipH:isRTL});


var navNextProps=_objectSpread2(_objectSpread2({},navProps),{},{
flipH:!isRTL});


var $prevDecadeIcon=this.normalizeSlot(SLOT_NAME_NAV_PEV_DECADE,navScope)||h(BIconChevronBarLeft,{
props:navPrevProps});

var $prevYearIcon=this.normalizeSlot(SLOT_NAME_NAV_PEV_YEAR,navScope)||h(BIconChevronDoubleLeft,{
props:navPrevProps});

var $prevMonthIcon=this.normalizeSlot(SLOT_NAME_NAV_PEV_MONTH,navScope)||h(BIconChevronLeft,{
props:navPrevProps});

var $thisMonthIcon=this.normalizeSlot(SLOT_NAME_NAV_THIS_MONTH,navScope)||h(BIconCircleFill,{
props:navProps});

var $nextMonthIcon=this.normalizeSlot(SLOT_NAME_NAV_NEXT_MONTH,navScope)||h(BIconChevronLeft,{
props:navNextProps});

var $nextYearIcon=this.normalizeSlot(SLOT_NAME_NAV_NEXT_YEAR,navScope)||h(BIconChevronDoubleLeft,{
props:navNextProps});

var $nextDecadeIcon=this.normalizeSlot(SLOT_NAME_NAV_NEXT_DECADE,navScope)||h(BIconChevronBarLeft,{
props:navNextProps});
// Utility to create the date navigation buttons

var makeNavBtn=function makeNavBtn(content,label,handler,btnDisabled,shortcut){
return h('button',{
staticClass:'btn btn-sm border-0 flex-fill',
class:[_this6.computedNavButtonVariant,{
disabled:btnDisabled}],

attrs:{
title:label||null,
type:'button',
tabindex:noKeyNav?'-1':null,
'aria-label':label||null,
'aria-disabled':btnDisabled?'true':null,
'aria-keyshortcuts':shortcut||null},

on:btnDisabled?{}:{
click:handler}},

[h('div',{
attrs:{
'aria-hidden':'true'}},

[content])]);
};// Generate the date navigation buttons


var $nav=h('div',{
staticClass:'b-calendar-nav d-flex',
attrs:{
id:navId,
role:'group',
tabindex:noKeyNav?'-1':null,
'aria-hidden':disabled?'true':null,
'aria-label':this.labelNav||null,
'aria-controls':gridId}},

[hideDecadeNav?h():makeNavBtn($prevDecadeIcon,this.labelPrevDecade,this.gotoPrevDecade,this.prevDecadeDisabled,'Ctrl+Alt+PageDown'),makeNavBtn($prevYearIcon,this.labelPrevYear,this.gotoPrevYear,this.prevYearDisabled,'Alt+PageDown'),makeNavBtn($prevMonthIcon,this.labelPrevMonth,this.gotoPrevMonth,this.prevMonthDisabled,'PageDown'),makeNavBtn($thisMonthIcon,this.labelCurrentMonth,this.gotoCurrentMonth,this.thisMonthDisabled,'Home'),makeNavBtn($nextMonthIcon,this.labelNextMonth,this.gotoNextMonth,this.nextMonthDisabled,'PageUp'),makeNavBtn($nextYearIcon,this.labelNextYear,this.gotoNextYear,this.nextYearDisabled,'Alt+PageUp'),hideDecadeNav?h():makeNavBtn($nextDecadeIcon,this.labelNextDecade,this.gotoNextDecade,this.nextDecadeDisabled,'Ctrl+Alt+PageUp')]);// Caption for calendar grid

var $gridCaption=h('header',{
staticClass:'b-calendar-grid-caption text-center font-weight-bold',
class:{
'text-muted':disabled},

attrs:{
id:gridCaptionId,
'aria-live':isLive?'polite':null,
'aria-atomic':isLive?'true':null},

key:'grid-caption'},
this.formatYearMonth(this.calendarFirstDay));// Calendar weekday headings

var $gridWeekDays=h('div',{
staticClass:'b-calendar-grid-weekdays row no-gutters border-bottom',
attrs:{
'aria-hidden':'true'}},

this.calendarHeadings.map(function(d,idx){
return h('small',{
staticClass:'col text-truncate',
class:{
'text-muted':disabled},

attrs:{
title:d.label===d.text?null:d.label,
'aria-label':d.label},

key:idx},
d.text);
}));// Calendar day grid

var $gridBody=this.calendar.map(function(week){
var $cells=week.map(function(day,dIndex){
var _class;

var isSelected=day.ymd===selectedYMD;
var isActive=day.ymd===activeYMD;
var isToday=day.ymd===todayYMD;
var idCell=safeId("_cell-".concat(day.ymd,"_"));// "fake" button

var $btn=h('span',{
staticClass:'btn border-0 rounded-circle text-nowrap',
// Should we add some classes to signify if today/selected/etc?
class:(_class={
// Give the fake button a focus ring
focus:isActive&&_this6.gridHasFocus,
// Styling
disabled:day.isDisabled||disabled,
active:isSelected},
_defineProperty(_class,_this6.computedVariant,isSelected),_defineProperty(_class,_this6.computedTodayVariant,isToday&&highlightToday&&!isSelected&&day.isThisMonth),_defineProperty(_class,'btn-outline-light',!(isToday&&highlightToday)&&!isSelected&&!isActive),_defineProperty(_class,'btn-light',!(isToday&&highlightToday)&&!isSelected&&isActive),_defineProperty(_class,'text-muted',!day.isThisMonth&&!isSelected),_defineProperty(_class,'text-dark',!(isToday&&highlightToday)&&!isSelected&&!isActive&&day.isThisMonth),_defineProperty(_class,'font-weight-bold',(isSelected||day.isThisMonth)&&!day.isDisabled),_class),
on:{
click:function click(){
return _this6.onClickDay(day);
}}},

day.day);
return h('div',// Cell with button
{
staticClass:'col p-0',
class:day.isDisabled?'bg-light':day.info.class||'',
attrs:{
id:idCell,
role:'button',
'data-date':day.ymd,
// Primarily for testing purposes
// Only days in the month are presented as buttons to screen readers
'aria-hidden':day.isThisMonth?null:'true',
'aria-disabled':day.isDisabled||disabled?'true':null,
'aria-label':[day.label,isSelected?"(".concat(_this6.labelSelected,")"):null,isToday?"(".concat(_this6.labelToday,")"):null].filter(identity).join(' '),
// NVDA doesn't convey `aria-selected`, but does `aria-current`,
// ChromeVox doesn't convey `aria-current`, but does `aria-selected`,
// so we set both attributes for robustness
'aria-selected':isSelected?'true':null,
'aria-current':isSelected?'date':null},

key:dIndex},
[$btn]);
});// Return the week "row"
// We use the first day of the weeks YMD value as a
// key for efficient DOM patching / element re-use

return h('div',{
staticClass:'row no-gutters',
key:week[0].ymd},
$cells);
});
$gridBody=h('div',{
// A key is only required on the body if we add in transition support
staticClass:'b-calendar-grid-body',
style:disabled?{
pointerEvents:'none'}:
{}// key: this.activeYMD.slice(0, -3)
},
$gridBody);
var $gridHelp=h('footer',{
staticClass:'b-calendar-grid-help border-top small text-muted text-center bg-light',
attrs:{
id:gridHelpId}},

[h('div',{
staticClass:'small'},
this.labelHelp)]);
var $grid=h('div',{
staticClass:'b-calendar-grid form-control h-auto text-center',
attrs:{
id:gridId,
role:'application',
tabindex:noKeyNav?'-1':disabled?null:'0',
'data-month':activeYMD.slice(0,-3),
// `YYYY-MM`, mainly for testing
'aria-roledescription':this.labelCalendar||null,
'aria-labelledby':gridCaptionId,
'aria-describedby':gridHelpId,
// `aria-readonly` is not considered valid on `role="application"`
// https://www.w3.org/TR/wai-aria-1.1/#aria-readonly
// 'aria-readonly': this.readonly && !disabled ? 'true' : null,
'aria-disabled':disabled?'true':null,
'aria-activedescendant':activeId},

on:{
keydown:this.onKeydownGrid,
focus:this.setGridFocusFlag,
blur:this.setGridFocusFlag},

ref:'grid'},
[$gridCaption,$gridWeekDays,$gridBody,$gridHelp]);// Optional bottom slot

var $slot=this.normalizeSlot();
$slot=$slot?h('footer',{
staticClass:'b-calendar-footer'},
$slot):h();
var $widget=h('div',{
staticClass:'b-calendar-inner',
style:this.block?{}:{
width:this.width},

attrs:{
id:widgetId,
dir:isRTL?'rtl':'ltr',
lang:this.computedLocale||null,
role:'group',
'aria-disabled':disabled?'true':null,
// If datepicker controls an input, this will specify the ID of the input
'aria-controls':this.ariaControls||null,
// This should be a prop (so it can be changed to Date picker, etc, localized
'aria-roledescription':this.roleDescription||null,
'aria-describedby':[// Should the attr (if present) go last?
// Or should this attr be a prop?
this.bvAttrs['aria-describedby'],valueId,gridHelpId].filter(identity).join(' ')},

on:{
keydown:this.onKeydownWrapper}},

[$header,$nav,$grid,$slot]);// Wrap in an outer div that can be styled

return h('div',{
staticClass:'b-calendar',
class:{
'd-block':this.block}},

[$widget]);
}});


var CalendarPlugin=/*#__PURE__*/pluginFactory({
components:{
BCalendar:BCalendar}});



var props$i=makePropsConfigurable({
bgVariant:makeProp(PROP_TYPE_STRING),
borderVariant:makeProp(PROP_TYPE_STRING),
tag:makeProp(PROP_TYPE_STRING,'div'),
textVariant:makeProp(PROP_TYPE_STRING)},
NAME_CARD);// --- Mixin ---
// @vue/component

var cardMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$i});


var props$j=makePropsConfigurable({
title:makeProp(PROP_TYPE_STRING),
titleTag:makeProp(PROP_TYPE_STRING,'h4')},
NAME_CARD_TITLE);// --- Main component ---
// @vue/component

var BCardTitle=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_TITLE,
functional:true,
props:props$j,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.titleTag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'card-title'}),
children||toString$1(props.title));
}});


var props$k=makePropsConfigurable({
subTitle:makeProp(PROP_TYPE_STRING),
subTitleTag:makeProp(PROP_TYPE_STRING,'h6'),
subTitleTextVariant:makeProp(PROP_TYPE_STRING,'muted')},
NAME_CARD_SUB_TITLE);// --- Main component ---
// @vue/component

var BCardSubTitle=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_SUB_TITLE,
functional:true,
props:props$k,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.subTitleTag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'card-subtitle',
class:[props.subTitleTextVariant?"text-".concat(props.subTitleTextVariant):null]}),
children||toString$1(props.subTitle));
}});


var props$l=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$j),props$k),copyProps(props$i,prefixPropName.bind(null,'body'))),{},{
bodyClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
overlay:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_CARD_BODY);// --- Main component ---
// @vue/component

var BCardBody=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_BODY,
functional:true,
props:props$l,
render:function render(h,_ref){
var _ref2;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var bodyBgVariant=props.bodyBgVariant,
bodyBorderVariant=props.bodyBorderVariant,
bodyTextVariant=props.bodyTextVariant;
var $title=h();

if(props.title){
$title=h(BCardTitle,{
props:pluckProps(props$j,props)});

}

var $subTitle=h();

if(props.subTitle){
$subTitle=h(BCardSubTitle,{
props:pluckProps(props$k,props),
class:['mb-2']});

}

return h(props.bodyTag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'card-body',
class:[(_ref2={
'card-img-overlay':props.overlay},
_defineProperty(_ref2,"bg-".concat(bodyBgVariant),bodyBgVariant),_defineProperty(_ref2,"border-".concat(bodyBorderVariant),bodyBorderVariant),_defineProperty(_ref2,"text-".concat(bodyTextVariant),bodyTextVariant),_ref2),props.bodyClass]}),
[$title,$subTitle,children]);
}});


var props$m=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},copyProps(props$i,prefixPropName.bind(null,'header'))),{},{
header:makeProp(PROP_TYPE_STRING),
headerClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
headerHtml:makeProp(PROP_TYPE_STRING)})),
NAME_CARD_HEADER);// --- Main component ---
// @vue/component

var BCardHeader=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_HEADER,
functional:true,
props:props$m,
render:function render(h,_ref){
var _ref2;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var headerBgVariant=props.headerBgVariant,
headerBorderVariant=props.headerBorderVariant,
headerTextVariant=props.headerTextVariant;
return h(props.headerTag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'card-header',
class:[props.headerClass,(_ref2={},_defineProperty(_ref2,"bg-".concat(headerBgVariant),headerBgVariant),_defineProperty(_ref2,"border-".concat(headerBorderVariant),headerBorderVariant),_defineProperty(_ref2,"text-".concat(headerTextVariant),headerTextVariant),_ref2)],
domProps:children?{}:htmlOrText(props.headerHtml,props.header)}),
children);
}});


var props$n=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},copyProps(props$i,prefixPropName.bind(null,'footer'))),{},{
footer:makeProp(PROP_TYPE_STRING),
footerClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
footerHtml:makeProp(PROP_TYPE_STRING)})),
NAME_CARD_FOOTER);// --- Main component ---
// @vue/component

var BCardFooter=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_FOOTER,
functional:true,
props:props$n,
render:function render(h,_ref){
var _ref2;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var footerBgVariant=props.footerBgVariant,
footerBorderVariant=props.footerBorderVariant,
footerTextVariant=props.footerTextVariant;
return h(props.footerTag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'card-footer',
class:[props.footerClass,(_ref2={},_defineProperty(_ref2,"bg-".concat(footerBgVariant),footerBgVariant),_defineProperty(_ref2,"border-".concat(footerBorderVariant),footerBorderVariant),_defineProperty(_ref2,"text-".concat(footerTextVariant),footerTextVariant),_ref2)],
domProps:children?{}:htmlOrText(props.footerHtml,props.footer)}),
children);
}});


// Blank image with fill template

var BLANK_TEMPLATE='<svg width="%{w}" height="%{h}" '+'xmlns="http://www.w3.org/2000/svg" '+'viewBox="0 0 %{w} %{h}" preserveAspectRatio="none">'+'<rect width="100%" height="100%" style="fill:%{f};"></rect>'+'</svg>';// --- Helper methods ---

var makeBlankImgSrc=function makeBlankImgSrc(width,height,color){
var src=encodeURIComponent(BLANK_TEMPLATE.replace('%{w}',toString$1(width)).replace('%{h}',toString$1(height)).replace('%{f}',color));
return "data:image/svg+xml;charset=UTF-8,".concat(src);
};// --- Props ---


var props$o=makePropsConfigurable({
alt:makeProp(PROP_TYPE_STRING),
blank:makeProp(PROP_TYPE_BOOLEAN,false),
blankColor:makeProp(PROP_TYPE_STRING,'transparent'),
block:makeProp(PROP_TYPE_BOOLEAN,false),
center:makeProp(PROP_TYPE_BOOLEAN,false),
fluid:makeProp(PROP_TYPE_BOOLEAN,false),
// Gives fluid images class `w-100` to make them grow to fit container
fluidGrow:makeProp(PROP_TYPE_BOOLEAN,false),
height:makeProp(PROP_TYPE_NUMBER_STRING),
left:makeProp(PROP_TYPE_BOOLEAN,false),
right:makeProp(PROP_TYPE_BOOLEAN,false),
// Possible values:
//   `false`: no rounding of corners
//   `true`: slightly rounded corners
//   'top': top corners rounded
//   'right': right corners rounded
//   'bottom': bottom corners rounded
//   'left': left corners rounded
//   'circle': circle/oval
//   '0': force rounding off
rounded:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
sizes:makeProp(PROP_TYPE_ARRAY_STRING),
src:makeProp(PROP_TYPE_STRING),
srcset:makeProp(PROP_TYPE_ARRAY_STRING),
thumbnail:makeProp(PROP_TYPE_BOOLEAN,false),
width:makeProp(PROP_TYPE_NUMBER_STRING)},
NAME_IMG);// --- Main component ---
// @vue/component

var BImg=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_IMG,
functional:true,
props:props$o,
render:function render(h,_ref){
var _class;

var props=_ref.props,
data=_ref.data;
var alt=props.alt,
src=props.src,
block=props.block,
fluidGrow=props.fluidGrow,
rounded=props.rounded;
var width=toInteger(props.width)||null;
var height=toInteger(props.height)||null;
var align=null;
var srcset=concat(props.srcset).filter(identity).join(',');
var sizes=concat(props.sizes).filter(identity).join(',');

if(props.blank){
if(!height&&width){
height=width;
}else if(!width&&height){
width=height;
}

if(!width&&!height){
width=1;
height=1;
}// Make a blank SVG image


src=makeBlankImgSrc(width,height,props.blankColor||'transparent');// Disable srcset and sizes

srcset=null;
sizes=null;
}

if(props.left){
align='float-left';
}else if(props.right){
align='float-right';
}else if(props.center){
align='mx-auto';
block=true;
}

return h('img',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
attrs:{
src:src,
alt:alt,
width:width?toString$1(width):null,
height:height?toString$1(height):null,
srcset:srcset||null,
sizes:sizes||null},

class:(_class={
'img-thumbnail':props.thumbnail,
'img-fluid':props.fluid||fluidGrow,
'w-100':fluidGrow,
rounded:rounded===''||rounded===true},
_defineProperty(_class,"rounded-".concat(rounded),isString(rounded)&&rounded!==''),_defineProperty(_class,align,align),_defineProperty(_class,'d-block',block),_class)}));

}});


var props$p=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},pick(props$o,['src','alt','width','height','left','right'])),{},{
bottom:makeProp(PROP_TYPE_BOOLEAN,false),
end:makeProp(PROP_TYPE_BOOLEAN,false),
start:makeProp(PROP_TYPE_BOOLEAN,false),
top:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_CARD_IMG);// --- Main component ---
// @vue/component

var BCardImg=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_IMG,
functional:true,
props:props$p,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data;
var src=props.src,
alt=props.alt,
width=props.width,
height=props.height;
var baseClass='card-img';

if(props.top){
baseClass+='-top';
}else if(props.right||props.end){
baseClass+='-right';
}else if(props.bottom){
baseClass+='-bottom';
}else if(props.left||props.start){
baseClass+='-left';
}

return h('img',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:baseClass,
attrs:{
src:src,
alt:alt,
width:width,
height:height}}));


}});


var cardImgProps=copyProps(props$p,prefixPropName.bind(null,'img'));
cardImgProps.imgSrc.required=false;
var props$q=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$l),props$m),props$n),cardImgProps),props$i),{},{
align:makeProp(PROP_TYPE_STRING),
noBody:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_CARD);// --- Main component ---
// @vue/component

var BCard=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD,
functional:true,
props:props$q,
render:function render(h,_ref){
var _class;

var props=_ref.props,
data=_ref.data,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots;
var imgSrc=props.imgSrc,
imgLeft=props.imgLeft,
imgRight=props.imgRight,
imgStart=props.imgStart,
imgEnd=props.imgEnd,
imgBottom=props.imgBottom,
header=props.header,
headerHtml=props.headerHtml,
footer=props.footer,
footerHtml=props.footerHtml,
align=props.align,
textVariant=props.textVariant,
bgVariant=props.bgVariant,
borderVariant=props.borderVariant;
var $scopedSlots=scopedSlots||{};
var $slots=slots();
var slotScope={};
var $imgFirst=h();
var $imgLast=h();

if(imgSrc){
var $img=h(BCardImg,{
props:pluckProps(cardImgProps,props,unprefixPropName.bind(null,'img'))});


if(imgBottom){
$imgLast=$img;
}else {
$imgFirst=$img;
}
}

var $header=h();
var hasHeaderSlot=hasNormalizedSlot(SLOT_NAME_HEADER,$scopedSlots,$slots);

if(hasHeaderSlot||header||headerHtml){
$header=h(BCardHeader,{
props:pluckProps(props$m,props),
domProps:hasHeaderSlot?{}:htmlOrText(headerHtml,header)},
normalizeSlot(SLOT_NAME_HEADER,slotScope,$scopedSlots,$slots));
}

var $content=normalizeSlot(SLOT_NAME_DEFAULT,slotScope,$scopedSlots,$slots);// Wrap content in `<card-body>` when `noBody` prop set

if(!props.noBody){
$content=h(BCardBody,{
props:pluckProps(props$l,props)},
$content);// When the `overlap` prop is set we need to wrap the `<b-card-img>` and `<b-card-body>`
// into a relative positioned wrapper to don't distract a potential header or footer

if(props.overlay&&imgSrc){
$content=h('div',{
staticClass:'position-relative'},
[$imgFirst,$content,$imgLast]);// Reset image variables since they are already in the wrapper

$imgFirst=h();
$imgLast=h();
}
}

var $footer=h();
var hasFooterSlot=hasNormalizedSlot(SLOT_NAME_FOOTER,$scopedSlots,$slots);

if(hasFooterSlot||footer||footerHtml){
$footer=h(BCardFooter,{
props:pluckProps(props$n,props),
domProps:hasHeaderSlot?{}:htmlOrText(footerHtml,footer)},
normalizeSlot(SLOT_NAME_FOOTER,slotScope,$scopedSlots,$slots));
}

return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'card',
class:(_class={
'flex-row':imgLeft||imgStart,
'flex-row-reverse':(imgRight||imgEnd)&&!(imgLeft||imgStart)},
_defineProperty(_class,"text-".concat(align),align),_defineProperty(_class,"bg-".concat(bgVariant),bgVariant),_defineProperty(_class,"border-".concat(borderVariant),borderVariant),_defineProperty(_class,"text-".concat(textVariant),textVariant),_class)}),
[$imgFirst,$header,$content,$footer,$imgLast]);
}});


var OBSERVER_PROP_NAME='__bv__visibility_observer';

var VisibilityObserver=/*#__PURE__*/function(){
function VisibilityObserver(el,options,vnode){
_classCallCheck(this,VisibilityObserver);

this.el=el;
this.callback=options.callback;
this.margin=options.margin||0;
this.once=options.once||false;
this.observer=null;
this.visible=undefined;
this.doneOnce=false;// Create the observer instance (if possible)

this.createObserver(vnode);
}

_createClass(VisibilityObserver,[{
key:"createObserver",
value:function createObserver(vnode){
var _this=this;

// Remove any previous observer
if(this.observer){
/* istanbul ignore next */
this.stop();
}// Should only be called once and `callback` prop should be a function


if(this.doneOnce||!isFunction(this.callback)){
/* istanbul ignore next */
return;
}// Create the observer instance


try{
// Future: Possibly add in other modifiers for left/right/top/bottom
// offsets, root element reference, and thresholds
this.observer=new IntersectionObserver(this.handler.bind(this),{
// `null` = 'viewport'
root:null,
// Pixels away from view port to consider "visible"
rootMargin:this.margin,
// Intersection ratio of el and root (as a value from 0 to 1)
threshold:0});

}catch(_unused){
// No IntersectionObserver support, so just stop trying to observe
this.doneOnce=true;
this.observer=undefined;
this.callback(null);
return;
}// Start observing in a `$nextTick()` (to allow DOM to complete rendering)

/* istanbul ignore next: IntersectionObserver not supported in JSDOM */


vnode.context.$nextTick(function(){
requestAF(function(){
// Placed in an `if` just in case we were destroyed before
// this `requestAnimationFrame` runs
if(_this.observer){
_this.observer.observe(_this.el);
}
});
});
}
/* istanbul ignore next */},

{
key:"handler",
value:function handler(entries){
var entry=entries?entries[0]:{};
var isIntersecting=Boolean(entry.isIntersecting||entry.intersectionRatio>0.0);

if(isIntersecting!==this.visible){
this.visible=isIntersecting;
this.callback(isIntersecting);

if(this.once&&this.visible){
this.doneOnce=true;
this.stop();
}
}
}},
{
key:"stop",
value:function stop(){
/* istanbul ignore next */
this.observer&&this.observer.disconnect();
this.observer=null;
}}]);


return VisibilityObserver;
}();

var destroy=function destroy(el){
var observer=el[OBSERVER_PROP_NAME];

if(observer&&observer.stop){
observer.stop();
}

delete el[OBSERVER_PROP_NAME];
};

var bind=function bind(el,_ref,vnode){
var value=_ref.value,
modifiers=_ref.modifiers;
// `value` is the callback function
var options={
margin:'0px',
once:false,
callback:value};
// Parse modifiers

keys(modifiers).forEach(function(mod){
/* istanbul ignore else: Until <b-img-lazy> is switched to use this directive */
if(RX_DIGITS.test(mod)){
options.margin="".concat(mod,"px");
}else if(mod.toLowerCase()==='once'){
options.once=true;
}
});// Destroy any previous observer

destroy(el);// Create new observer

el[OBSERVER_PROP_NAME]=new VisibilityObserver(el,options,vnode);// Store the current modifiers on the object (cloned)

el[OBSERVER_PROP_NAME]._prevModifiers=clone(modifiers);
};// When the directive options may have been updated (or element)


var componentUpdated=function componentUpdated(el,_ref2,vnode){
var value=_ref2.value,
oldValue=_ref2.oldValue,
modifiers=_ref2.modifiers;
// Compare value/oldValue and modifiers to see if anything has changed
// and if so, destroy old observer and create new observer

/* istanbul ignore next */
modifiers=clone(modifiers);
/* istanbul ignore next */

if(el&&(value!==oldValue||!el[OBSERVER_PROP_NAME]||!looseEqual(modifiers,el[OBSERVER_PROP_NAME]._prevModifiers))){
// Re-bind on element
bind(el,{
value:value,
modifiers:modifiers},
vnode);
}
};// When directive un-binds from element


var unbind=function unbind(el){
// Remove the observer
destroy(el);
};// Export the directive


var VBVisible={
bind:bind,
componentUpdated:componentUpdated,
unbind:unbind};


var _watch$2;

var MODEL_PROP_NAME_SHOW='show';
var MODEL_EVENT_NAME_SHOW=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_SHOW;// --- Props ---

var imgProps=omit(props$o,['blank']);
var props$r=makePropsConfigurable(_objectSpread2(_objectSpread2({},imgProps),{},_defineProperty({
blankColor:makeProp(PROP_TYPE_STRING,'transparent'),
blankHeight:makeProp(PROP_TYPE_NUMBER_STRING),
// If `null`, a blank image is generated
blankSrc:makeProp(PROP_TYPE_STRING,null),
blankWidth:makeProp(PROP_TYPE_NUMBER_STRING),
// Distance away from viewport (in pixels)
// before being considered "visible"
offset:makeProp(PROP_TYPE_NUMBER_STRING,360)},
MODEL_PROP_NAME_SHOW,makeProp(PROP_TYPE_BOOLEAN,false))),NAME_IMG_LAZY);// --- Main component ---
// @vue/component

var BImgLazy=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_IMG_LAZY,
directives:{
'b-visible':VBVisible},

props:props$r,
data:function data(){
return {
isShown:this[MODEL_PROP_NAME_SHOW]};

},
computed:{
computedSrc:function computedSrc(){
var blankSrc=this.blankSrc;
return !blankSrc||this.isShown?this.src:blankSrc;
},
computedBlank:function computedBlank(){
return !(this.isShown||this.blankSrc);
},
computedWidth:function computedWidth(){
var width=this.width;
return this.isShown?width:this.blankWidth||width;
},
computedHeight:function computedHeight(){
var height=this.height;
return this.isShown?height:this.blankHeight||height;
},
computedSrcset:function computedSrcset(){
var srcset=concat(this.srcset).filter(identity).join(',');
return !this.blankSrc||this.isShown?srcset:null;
},
computedSizes:function computedSizes(){
var sizes=concat(this.sizes).filter(identity).join(',');
return !this.blankSrc||this.isShown?sizes:null;
}},

watch:(_watch$2={},_defineProperty(_watch$2,MODEL_PROP_NAME_SHOW,function(newValue,oldValue){
if(newValue!==oldValue){
// If `IntersectionObserver` support is not available, image is always shown
var visible=HAS_INTERACTION_OBSERVER_SUPPORT?newValue:true;
this.isShown=visible;// Ensure the show prop is synced (when no `IntersectionObserver`)

if(visible!==newValue){
this.$nextTick(this.updateShowProp);
}
}
}),_defineProperty(_watch$2,"isShown",function isShown(newValue,oldValue){
// Update synched show prop
if(newValue!==oldValue){
this.updateShowProp();
}
}),_watch$2),
mounted:function mounted(){
// If `IntersectionObserver` is not available, image is always shown
this.isShown=HAS_INTERACTION_OBSERVER_SUPPORT?this[MODEL_PROP_NAME_SHOW]:true;
},
methods:{
updateShowProp:function updateShowProp(){
this.$emit(MODEL_EVENT_NAME_SHOW,this.isShown);
},
doShow:function doShow(visible){
// If IntersectionObserver is not supported, the callback
// will be called with `null` rather than `true` or `false`
if((visible||visible===null)&&!this.isShown){
this.isShown=true;
}
}},

render:function render(h){
var directives=[];

if(!this.isShown){
var _modifiers;

// We only add the visible directive if we are not shown
directives.push({
// Visible directive will silently do nothing if
// IntersectionObserver is not supported
name:'b-visible',
// Value expects a callback (passed one arg of `visible` = `true` or `false`)
value:this.doShow,
modifiers:(_modifiers={},_defineProperty(_modifiers,"".concat(toInteger(this.offset,0)),true),_defineProperty(_modifiers,"once",true),_modifiers)});

}

return h(BImg,{
directives:directives,
props:_objectSpread2({
// Computed value props
src:this.computedSrc,
blank:this.computedBlank,
width:this.computedWidth,
height:this.computedHeight,
srcset:this.computedSrcset||null,
sizes:this.computedSizes||null},
pluckProps(imgProps,this.$props))});

}});


var props$s=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},omit(props$r,keys(props$o))),omit(props$p,['src','alt','width','height']))),NAME_CARD_IMG_LAZY);// --- Main component ---
// @vue/component

var BCardImgLazy=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_IMG_LAZY,
functional:true,
props:props$s,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data;
var baseClass='card-img';

if(props.top){
baseClass+='-top';
}else if(props.right||props.end){
baseClass+='-right';
}else if(props.bottom){
baseClass+='-bottom';
}else if(props.left||props.start){
baseClass+='-left';
}

return h(BImgLazy,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:[baseClass],
// Exclude `left` and `right` props before passing to `<b-img-lazy>`
props:omit(props,['left','right'])}));

}});


var props$t=makePropsConfigurable({
textTag:makeProp(PROP_TYPE_STRING,'p')},
NAME_CARD_TEXT);// --- Main component ---
// @vue/component

var BCardText=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_TEXT,
functional:true,
props:props$t,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.textTag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'card-text'}),
children);
}});


var props$u=makePropsConfigurable({
columns:makeProp(PROP_TYPE_BOOLEAN,false),
deck:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_CARD_GROUP);// --- Main component ---
// @vue/component

var BCardGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CARD_GROUP,
functional:true,
props:props$u,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:props.deck?'card-deck':props.columns?'card-columns':'card-group'}),
children);
}});


var CardPlugin=/*#__PURE__*/pluginFactory({
components:{
BCard:BCard,
BCardHeader:BCardHeader,
BCardBody:BCardBody,
BCardTitle:BCardTitle,
BCardSubTitle:BCardSubTitle,
BCardFooter:BCardFooter,
BCardImg:BCardImg,
BCardImgLazy:BCardImgLazy,
BCardText:BCardText,
BCardGroup:BCardGroup}});



var noop=function noop(){};

/**
 * Observe a DOM element changes, falls back to eventListener mode
 * @param {Element} el The DOM element to observe
 * @param {Function} callback callback to be called on change
 * @param {object} [options={childList: true, subtree: true}] observe options
 * @see https://stackoverflow.com/questions/3219758
 */

var observeDom=function observeDom(el,callback,options)
/* istanbul ignore next: difficult to test in JSDOM */
{
// Handle cases where we might be passed a Vue instance
el=el?el.$el||el:null;// Early exit when we have no element

/* istanbul ignore next: difficult to test in JSDOM */

if(!isElement(el)){
return null;
}// Exit and throw a warning when `MutationObserver` isn't available


if(warnNoMutationObserverSupport('observeDom')){
return null;
}// Define a new observer


var obs=new MutationObs(function(mutations){
var changed=false;// A mutation can contain several change records, so we loop
// through them to see what has changed
// We break out of the loop early if any "significant" change
// has been detected

for(var i=0;i<mutations.length&&!changed;i++){
// The mutation record
var mutation=mutations[i];// Mutation type

var type=mutation.type;// DOM node (could be any DOM node type - HTMLElement, Text, comment, etc.)

var target=mutation.target;// Detect whether a change happened based on type and target

if(type==='characterData'&&target.nodeType===Node.TEXT_NODE){
// We ignore nodes that are not TEXT (i.e. comments, etc.)
// as they don't change layout
changed=true;
}else if(type==='attributes'){
changed=true;
}else if(type==='childList'&&(mutation.addedNodes.length>0||mutation.removedNodes.length>0)){
// This includes HTMLElement and text nodes being
// added/removed/re-arranged
changed=true;
}
}// We only call the callback if a change that could affect
// layout/size truly happened


if(changed){
callback();
}
});// Have the observer observe foo for changes in children, etc

obs.observe(el,_objectSpread2({
childList:true,
subtree:true},
options));// We return a reference to the observer so that `obs.disconnect()`
// can be called if necessary
// To reduce overhead when the root element is hidden

return obs;
};

var _watch$3;

var _makeModelMixin$2=makeModelMixin('value',{
type:PROP_TYPE_NUMBER,
defaultValue:0}),

modelMixin$2=_makeModelMixin$2.mixin,
modelProps$2=_makeModelMixin$2.props,
MODEL_PROP_NAME$2=_makeModelMixin$2.prop,
MODEL_EVENT_NAME$2=_makeModelMixin$2.event;// Slide directional classes


var DIRECTION={
next:{
dirClass:'carousel-item-left',
overlayClass:'carousel-item-next'},

prev:{
dirClass:'carousel-item-right',
overlayClass:'carousel-item-prev'}};

// Fallback Transition duration (with a little buffer) in ms

var TRANS_DURATION=600+50;// Time for mouse compat events to fire after touch

var TOUCH_EVENT_COMPAT_WAIT=500;// Number of pixels to consider touch move a swipe

var SWIPE_THRESHOLD=40;// PointerEvent pointer types

var PointerType={
TOUCH:'touch',
PEN:'pen'};
// Transition Event names

var TransitionEndEvents={
WebkitTransition:'webkitTransitionEnd',
MozTransition:'transitionend',
OTransition:'otransitionend oTransitionEnd',
transition:'transitionend'};
// --- Helper methods ---
// Return the browser specific transitionEnd event name

var getTransitionEndEvent=function getTransitionEndEvent(el){
for(var name in TransitionEndEvents){
if(!isUndefined(el.style[name])){
return TransitionEndEvents[name];
}
}// Fallback

/* istanbul ignore next */


return null;
};// --- Props ---


var props$v=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$2),{},{
background:makeProp(PROP_TYPE_STRING),
controls:makeProp(PROP_TYPE_BOOLEAN,false),
// Enable cross-fade animation instead of slide animation
fade:makeProp(PROP_TYPE_BOOLEAN,false),
// Sniffed by carousel-slide
imgHeight:makeProp(PROP_TYPE_NUMBER_STRING),
// Sniffed by carousel-slide
imgWidth:makeProp(PROP_TYPE_NUMBER_STRING),
indicators:makeProp(PROP_TYPE_BOOLEAN,false),
interval:makeProp(PROP_TYPE_NUMBER,5000),
labelGotoSlide:makeProp(PROP_TYPE_STRING,'Goto slide'),
labelIndicators:makeProp(PROP_TYPE_STRING,'Select a slide to display'),
labelNext:makeProp(PROP_TYPE_STRING,'Next slide'),
labelPrev:makeProp(PROP_TYPE_STRING,'Previous slide'),
// Disable slide/fade animation
noAnimation:makeProp(PROP_TYPE_BOOLEAN,false),
// Disable pause on hover
noHoverPause:makeProp(PROP_TYPE_BOOLEAN,false),
// Sniffed by carousel-slide
noTouch:makeProp(PROP_TYPE_BOOLEAN,false),
// Disable wrapping/looping when start/end is reached
noWrap:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_CAROUSEL);// --- Main component ---
// @vue/component

var BCarousel=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CAROUSEL,
mixins:[idMixin,modelMixin$2,normalizeSlotMixin],
provide:function provide(){
return {
bvCarousel:this};

},
props:props$v,
data:function data(){
return {
index:this[MODEL_PROP_NAME$2]||0,
isSliding:false,
transitionEndEvent:null,
slides:[],
direction:null,
isPaused:!(toInteger(this.interval,0)>0),
// Touch event handling values
touchStartX:0,
touchDeltaX:0};

},
computed:{
numSlides:function numSlides(){
return this.slides.length;
}},

watch:(_watch$3={},_defineProperty(_watch$3,MODEL_PROP_NAME$2,function(newValue,oldValue){
if(newValue!==oldValue){
this.setSlide(toInteger(newValue,0));
}
}),_defineProperty(_watch$3,"interval",function interval(newValue,oldValue){
/* istanbul ignore next */
if(newValue===oldValue){
return;
}

if(!newValue){
// Pausing slide show
this.pause(false);
}else {
// Restarting or Changing interval
this.pause(true);
this.start(false);
}
}),_defineProperty(_watch$3,"isPaused",function isPaused(newValue,oldValue){
if(newValue!==oldValue){
this.$emit(newValue?EVENT_NAME_PAUSED:EVENT_NAME_UNPAUSED);
}
}),_defineProperty(_watch$3,"index",function index(to,from){
/* istanbul ignore next */
if(to===from||this.isSliding){
return;
}

this.doSlide(to,from);
}),_watch$3),
created:function created(){
// Create private non-reactive props
this.$_interval=null;
this.$_animationTimeout=null;
this.$_touchTimeout=null;
this.$_observer=null;// Set initial paused state

this.isPaused=!(toInteger(this.interval,0)>0);
},
mounted:function mounted(){
// Cache current browser transitionend event name
this.transitionEndEvent=getTransitionEndEvent(this.$el)||null;// Get all slides

this.updateSlides();// Observe child changes so we can update slide list

this.setObserver(true);
},
beforeDestroy:function beforeDestroy(){
this.clearInterval();
this.clearAnimationTimeout();
this.clearTouchTimeout();
this.setObserver(false);
},
methods:{
clearInterval:function(_clearInterval){
function clearInterval(){
return _clearInterval.apply(this,arguments);
}

clearInterval.toString=function(){
return _clearInterval.toString();
};

return clearInterval;
}(function(){
clearInterval(this.$_interval);
this.$_interval=null;
}),
clearAnimationTimeout:function clearAnimationTimeout(){
clearTimeout(this.$_animationTimeout);
this.$_animationTimeout=null;
},
clearTouchTimeout:function clearTouchTimeout(){
clearTimeout(this.$_touchTimeout);
this.$_touchTimeout=null;
},
setObserver:function setObserver(){
var on=arguments.length>0&&arguments[0]!==undefined?arguments[0]:false;
this.$_observer&&this.$_observer.disconnect();
this.$_observer=null;

if(on){
this.$_observer=observeDom(this.$refs.inner,this.updateSlides.bind(this),{
subtree:false,
childList:true,
attributes:true,
attributeFilter:['id']});

}
},
// Set slide
setSlide:function setSlide(slide){
var _this=this;

var direction=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;

// Don't animate when page is not visible

/* istanbul ignore if: difficult to test */
if(IS_BROWSER&&document.visibilityState&&document.hidden){
return;
}

var noWrap=this.noWrap;
var numSlides=this.numSlides;// Make sure we have an integer (you never know!)

slide=mathFloor(slide);// Don't do anything if nothing to slide to

if(numSlides===0){
return;
}// Don't change slide while transitioning, wait until transition is done


if(this.isSliding){
// Schedule slide after sliding complete
this.$once(EVENT_NAME_SLIDING_END,function(){
// Wrap in `requestAF()` to allow the slide to properly finish to avoid glitching
requestAF(function(){
return _this.setSlide(slide,direction);
});
});
return;
}

this.direction=direction;// Set new slide index
// Wrap around if necessary (if no-wrap not enabled)

this.index=slide>=numSlides?noWrap?numSlides-1:0:slide<0?noWrap?0:numSlides-1:slide;// Ensure the v-model is synched up if no-wrap is enabled
// and user tried to slide pass either ends

if(noWrap&&this.index!==slide&&this.index!==this[MODEL_PROP_NAME$2]){
this.$emit(MODEL_EVENT_NAME$2,this.index);
}
},
// Previous slide
prev:function prev(){
this.setSlide(this.index-1,'prev');
},
// Next slide
next:function next(){
this.setSlide(this.index+1,'next');
},
// Pause auto rotation
pause:function pause(event){
if(!event){
this.isPaused=true;
}

this.clearInterval();
},
// Start auto rotate slides
start:function start(event){
if(!event){
this.isPaused=false;
}
/* istanbul ignore next: most likely will never happen, but just in case */


this.clearInterval();// Don't start if no interval, or less than 2 slides

if(this.interval&&this.numSlides>1){
this.$_interval=setInterval(this.next,mathMax(1000,this.interval));
}
},
// Restart auto rotate slides when focus/hover leaves the carousel

/* istanbul ignore next */
restart:function restart(){
if(!this.$el.contains(getActiveElement())){
this.start();
}
},
doSlide:function doSlide(to,from){
var _this2=this;

var isCycling=Boolean(this.interval);// Determine sliding direction

var direction=this.calcDirection(this.direction,from,to);
var overlayClass=direction.overlayClass;
var dirClass=direction.dirClass;// Determine current and next slides

var currentSlide=this.slides[from];
var nextSlide=this.slides[to];// Don't do anything if there aren't any slides to slide to

if(!currentSlide||!nextSlide){
/* istanbul ignore next */
return;
}// Start animating


this.isSliding=true;

if(isCycling){
this.pause(false);
}

this.$emit(EVENT_NAME_SLIDING_START,to);// Update v-model

this.$emit(MODEL_EVENT_NAME$2,this.index);

if(this.noAnimation){
addClass(nextSlide,'active');
removeClass(currentSlide,'active');
this.isSliding=false;// Notify ourselves that we're done sliding (slid)

this.$nextTick(function(){
return _this2.$emit(EVENT_NAME_SLIDING_END,to);
});
}else {
addClass(nextSlide,overlayClass);// Trigger a reflow of next slide

reflow(nextSlide);
addClass(currentSlide,dirClass);
addClass(nextSlide,dirClass);// Transition End handler

var called=false;
/* istanbul ignore next: difficult to test */

var onceTransEnd=function onceTransEnd(){
if(called){
return;
}

called=true;
/* istanbul ignore if: transition events cant be tested in JSDOM */

if(_this2.transitionEndEvent){
var events=_this2.transitionEndEvent.split(/\s+/);

events.forEach(function(event){
return eventOff(nextSlide,event,onceTransEnd,EVENT_OPTIONS_NO_CAPTURE);
});
}

_this2.clearAnimationTimeout();

removeClass(nextSlide,dirClass);
removeClass(nextSlide,overlayClass);
addClass(nextSlide,'active');
removeClass(currentSlide,'active');
removeClass(currentSlide,dirClass);
removeClass(currentSlide,overlayClass);
setAttr(currentSlide,'aria-current','false');
setAttr(nextSlide,'aria-current','true');
setAttr(currentSlide,'aria-hidden','true');
setAttr(nextSlide,'aria-hidden','false');
_this2.isSliding=false;
_this2.direction=null;// Notify ourselves that we're done sliding (slid)

_this2.$nextTick(function(){
return _this2.$emit(EVENT_NAME_SLIDING_END,to);
});
};// Set up transitionend handler

/* istanbul ignore if: transition events cant be tested in JSDOM */


if(this.transitionEndEvent){
var events=this.transitionEndEvent.split(/\s+/);
events.forEach(function(event){
return eventOn(nextSlide,event,onceTransEnd,EVENT_OPTIONS_NO_CAPTURE);
});
}// Fallback to setTimeout()


this.$_animationTimeout=setTimeout(onceTransEnd,TRANS_DURATION);
}

if(isCycling){
this.start(false);
}
},
// Update slide list
updateSlides:function updateSlides(){
this.pause(true);// Get all slides as DOM elements

this.slides=selectAll('.carousel-item',this.$refs.inner);
var numSlides=this.slides.length;// Keep slide number in range

var index=mathMax(0,mathMin(mathFloor(this.index),numSlides-1));
this.slides.forEach(function(slide,idx){
var n=idx+1;

if(idx===index){
addClass(slide,'active');
setAttr(slide,'aria-current','true');
}else {
removeClass(slide,'active');
setAttr(slide,'aria-current','false');
}

setAttr(slide,'aria-posinset',String(n));
setAttr(slide,'aria-setsize',String(numSlides));
});// Set slide as active

this.setSlide(index);
this.start(this.isPaused);
},
calcDirection:function calcDirection(){
var direction=arguments.length>0&&arguments[0]!==undefined?arguments[0]:null;
var curIndex=arguments.length>1&&arguments[1]!==undefined?arguments[1]:0;
var nextIndex=arguments.length>2&&arguments[2]!==undefined?arguments[2]:0;

if(!direction){
return nextIndex>curIndex?DIRECTION.next:DIRECTION.prev;
}

return DIRECTION[direction];
},
handleClick:function handleClick(event,fn){
var keyCode=event.keyCode;

if(event.type==='click'||keyCode===CODE_SPACE||keyCode===CODE_ENTER){
stopEvent(event);
fn();
}
},

/* istanbul ignore next: JSDOM doesn't support touch events */
handleSwipe:function handleSwipe(){
var absDeltaX=mathAbs(this.touchDeltaX);

if(absDeltaX<=SWIPE_THRESHOLD){
return;
}

var direction=absDeltaX/this.touchDeltaX;// Reset touch delta X
// https://github.com/twbs/bootstrap/pull/28558

this.touchDeltaX=0;

if(direction>0){
// Swipe left
this.prev();
}else if(direction<0){
// Swipe right
this.next();
}
},

/* istanbul ignore next: JSDOM doesn't support touch events */
touchStart:function touchStart(event){
if(HAS_POINTER_EVENT_SUPPORT&&PointerType[event.pointerType.toUpperCase()]){
this.touchStartX=event.clientX;
}else if(!HAS_POINTER_EVENT_SUPPORT){
this.touchStartX=event.touches[0].clientX;
}
},

/* istanbul ignore next: JSDOM doesn't support touch events */
touchMove:function touchMove(event){
// Ensure swiping with one touch and not pinching
if(event.touches&&event.touches.length>1){
this.touchDeltaX=0;
}else {
this.touchDeltaX=event.touches[0].clientX-this.touchStartX;
}
},

/* istanbul ignore next: JSDOM doesn't support touch events */
touchEnd:function touchEnd(event){
if(HAS_POINTER_EVENT_SUPPORT&&PointerType[event.pointerType.toUpperCase()]){
this.touchDeltaX=event.clientX-this.touchStartX;
}

this.handleSwipe();// If it's a touch-enabled device, mouseenter/leave are fired as
// part of the mouse compatibility events on first tap - the carousel
// would stop cycling until user tapped out of it;
// here, we listen for touchend, explicitly pause the carousel
// (as if it's the second time we tap on it, mouseenter compat event
// is NOT fired) and after a timeout (to allow for mouse compatibility
// events to fire) we explicitly restart cycling

this.pause(false);
this.clearTouchTimeout();
this.$_touchTimeout=setTimeout(this.start,TOUCH_EVENT_COMPAT_WAIT+mathMax(1000,this.interval));
}},

render:function render(h){
var _this3=this;

var indicators=this.indicators,
background=this.background,
noAnimation=this.noAnimation,
noHoverPause=this.noHoverPause,
noTouch=this.noTouch,
index=this.index,
isSliding=this.isSliding,
pause=this.pause,
restart=this.restart,
touchStart=this.touchStart,
touchEnd=this.touchEnd;
var idInner=this.safeId('__BV_inner_');// Wrapper for slides

var $inner=h('div',{
staticClass:'carousel-inner',
attrs:{
id:idInner,
role:'list'},

ref:'inner'},
[this.normalizeSlot()]);// Prev and next controls

var $controls=h();

if(this.controls){
var makeControl=function makeControl(direction,label,handler){
var handlerWrapper=function handlerWrapper(event){
/* istanbul ignore next */
if(!isSliding){
_this3.handleClick(event,handler);
}else {
stopEvent(event,{
propagation:false});

}
};

return h('a',{
staticClass:"carousel-control-".concat(direction),
attrs:{
href:'#',
role:'button',
'aria-controls':idInner,
'aria-disabled':isSliding?'true':null},

on:{
click:handlerWrapper,
keydown:handlerWrapper}},

[h('span',{
staticClass:"carousel-control-".concat(direction,"-icon"),
attrs:{
'aria-hidden':'true'}}),

h('span',{
class:'sr-only'},
[label])]);
};

$controls=[makeControl('prev',this.labelPrev,this.prev),makeControl('next',this.labelNext,this.next)];
}// Indicators


var $indicators=h('ol',{
staticClass:'carousel-indicators',
directives:[{
name:'show',
value:indicators}],

attrs:{
id:this.safeId('__BV_indicators_'),
'aria-hidden':indicators?'false':'true',
'aria-label':this.labelIndicators,
'aria-owns':idInner}},

this.slides.map(function(slide,i){
var handler=function handler(event){
_this3.handleClick(event,function(){
_this3.setSlide(i);
});
};

return h('li',{
class:{
active:i===index},

attrs:{
role:'button',
id:_this3.safeId("__BV_indicator_".concat(i+1,"_")),
tabindex:indicators?'0':'-1',
'aria-current':i===index?'true':'false',
'aria-label':"".concat(_this3.labelGotoSlide," ").concat(i+1),
'aria-describedby':slide.id||null,
'aria-controls':idInner},

on:{
click:handler,
keydown:handler},

key:"slide_".concat(i)});

}));
var on={
mouseenter:noHoverPause?noop:pause,
mouseleave:noHoverPause?noop:restart,
focusin:pause,
focusout:restart,
keydown:function keydown(event){
/* istanbul ignore next */
if(/input|textarea/i.test(event.target.tagName)){
return;
}

var keyCode=event.keyCode;

if(keyCode===CODE_LEFT||keyCode===CODE_RIGHT){
stopEvent(event);

_this3[keyCode===CODE_LEFT?'prev':'next']();
}
}};
// Touch support event handlers for environment

if(HAS_TOUCH_SUPPORT&&!noTouch){
// Attach appropriate listeners (prepend event name with '&' for passive mode)

/* istanbul ignore next: JSDOM doesn't support touch events */
if(HAS_POINTER_EVENT_SUPPORT){
on['&pointerdown']=touchStart;
on['&pointerup']=touchEnd;
}else {
on['&touchstart']=touchStart;
on['&touchmove']=this.touchMove;
on['&touchend']=touchEnd;
}
}// Return the carousel


return h('div',{
staticClass:'carousel',
class:{
slide:!noAnimation,
'carousel-fade':!noAnimation&&this.fade,
'pointer-event':HAS_TOUCH_SUPPORT&&HAS_POINTER_EVENT_SUPPORT&&!noTouch},

style:{
background:background},

attrs:{
role:'region',
id:this.safeId(),
'aria-busy':isSliding?'true':'false'},

on:on},
[$inner,$controls,$indicators]);
}});


var imgProps$1={
imgAlt:makeProp(PROP_TYPE_STRING),
imgBlank:makeProp(PROP_TYPE_BOOLEAN,false),
imgBlankColor:makeProp(PROP_TYPE_STRING,'transparent'),
imgHeight:makeProp(PROP_TYPE_NUMBER_STRING),
imgSrc:makeProp(PROP_TYPE_STRING),
imgWidth:makeProp(PROP_TYPE_NUMBER_STRING)};

var props$w=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),imgProps$1),{},{
background:makeProp(PROP_TYPE_STRING),
caption:makeProp(PROP_TYPE_STRING),
captionHtml:makeProp(PROP_TYPE_STRING),
captionTag:makeProp(PROP_TYPE_STRING,'h3'),
contentTag:makeProp(PROP_TYPE_STRING,'div'),
contentVisibleUp:makeProp(PROP_TYPE_STRING),
text:makeProp(PROP_TYPE_STRING),
textHtml:makeProp(PROP_TYPE_STRING),
textTag:makeProp(PROP_TYPE_STRING,'p')})),
NAME_CAROUSEL_SLIDE);// --- Main component ---
// @vue/component

var BCarouselSlide=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CAROUSEL_SLIDE,
mixins:[idMixin,normalizeSlotMixin],
inject:{
bvCarousel:{
// Explicitly disable touch if not a child of carousel
default:function _default(){
return {
noTouch:true};

}}},


props:props$w,
computed:{
contentClasses:function contentClasses(){
return [this.contentVisibleUp?'d-none':'',this.contentVisibleUp?"d-".concat(this.contentVisibleUp,"-block"):''];
},
computedWidth:function computedWidth(){
// Use local width, or try parent width
return this.imgWidth||this.bvCarousel.imgWidth||null;
},
computedHeight:function computedHeight(){
// Use local height, or try parent height
return this.imgHeight||this.bvCarousel.imgHeight||null;
}},

render:function render(h){
var $img=this.normalizeSlot(SLOT_NAME_IMG);

if(!$img&&(this.imgSrc||this.imgBlank)){
var on={};// Touch support event handler

/* istanbul ignore if: difficult to test in JSDOM */

if(!this.bvCarousel.noTouch&&HAS_TOUCH_SUPPORT){
on.dragstart=function(event){
return stopEvent(event,{
propagation:false});

};
}

$img=h(BImg,{
props:_objectSpread2(_objectSpread2({},pluckProps(imgProps$1,this.$props,unprefixPropName.bind(null,'img'))),{},{
width:this.computedWidth,
height:this.computedHeight,
fluidGrow:true,
block:true}),

on:on});

}

var $contentChildren=[// Caption
this.caption||this.captionHtml?h(this.captionTag,{
domProps:htmlOrText(this.captionHtml,this.caption)}):
false,// Text
this.text||this.textHtml?h(this.textTag,{
domProps:htmlOrText(this.textHtml,this.text)}):
false,// Children
this.normalizeSlot()||false];
var $content=h();

if($contentChildren.some(identity)){
$content=h(this.contentTag,{
staticClass:'carousel-caption',
class:this.contentClasses},
$contentChildren.map(function($child){
return $child||h();
}));
}

return h('div',{
staticClass:'carousel-item',
style:{
background:this.background||this.bvCarousel.background||null},

attrs:{
id:this.safeId(),
role:'listitem'}},

[$img,$content]);
}});


var CarouselPlugin=
/*#__PURE*/
pluginFactory({
components:{
BCarousel:BCarousel,
BCarouselSlide:BCarouselSlide}});



var CLASS_NAME_SHOW='show';

// Generic collapse transion helper component
// Transition event handler helpers

var onEnter=function onEnter(el){
setStyle(el,'height',0);// In a `requestAF()` for `appear` to work

requestAF(function(){
reflow(el);
setStyle(el,'height',"".concat(el.scrollHeight,"px"));
});
};

var onAfterEnter=function onAfterEnter(el){
removeStyle(el,'height');
};

var onLeave=function onLeave(el){
setStyle(el,'height','auto');
setStyle(el,'display','block');
setStyle(el,'height',"".concat(getBCR(el).height,"px"));
reflow(el);
setStyle(el,'height',0);
};

var onAfterLeave=function onAfterLeave(el){
removeStyle(el,'height');
};// --- Constants ---
// Default transition props
// `appear` will use the enter classes


var TRANSITION_PROPS={
css:true,
enterClass:'',
enterActiveClass:'collapsing',
enterToClass:'collapse show',
leaveClass:'collapse show',
leaveActiveClass:'collapsing',
leaveToClass:'collapse'};
// Default transition handlers
// `appear` will use the enter handlers

var TRANSITION_HANDLERS={
enter:onEnter,
afterEnter:onAfterEnter,
leave:onLeave,
afterLeave:onAfterLeave};
// --- Main component ---

var props$x={
// // If `true` (and `visible` is `true` on mount), animate initially visible
appear:makeProp(PROP_TYPE_BOOLEAN,false)};
// --- Main component ---
// @vue/component

var BVCollapse=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_COLLAPSE_HELPER,
functional:true,
props:props$x,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h('transition',// We merge in the `appear` prop last
Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
props:TRANSITION_PROPS,
on:TRANSITION_HANDLERS},
{
props:props}),
// Note: `<transition>` supports a single root element only
children);
}});


var _watch$4;

var ROOT_ACTION_EVENT_NAME_TOGGLE=getRootActionEventName(NAME_COLLAPSE,'toggle');
var ROOT_ACTION_EVENT_NAME_REQUEST_STATE=getRootActionEventName(NAME_COLLAPSE,'request-state');
var ROOT_EVENT_NAME_ACCORDION=getRootEventName(NAME_COLLAPSE,'accordion');
var ROOT_EVENT_NAME_STATE=getRootEventName(NAME_COLLAPSE,'state');
var ROOT_EVENT_NAME_SYNC_STATE=getRootEventName(NAME_COLLAPSE,'sync-state');

var _makeModelMixin$3=makeModelMixin('visible',{
type:PROP_TYPE_BOOLEAN,
defaultValue:false}),

modelMixin$3=_makeModelMixin$3.mixin,
modelProps$3=_makeModelMixin$3.props,
MODEL_PROP_NAME$3=_makeModelMixin$3.prop,
MODEL_EVENT_NAME$3=_makeModelMixin$3.event;// --- Props ---


var props$y=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$3),{},{
// If `true` (and `visible` is `true` on mount), animate initially visible
accordion:makeProp(PROP_TYPE_STRING),
appear:makeProp(PROP_TYPE_BOOLEAN,false),
isNav:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div')})),
NAME_COLLAPSE);// --- Main component ---
// @vue/component

var BCollapse=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_COLLAPSE,
mixins:[idMixin,modelMixin$3,normalizeSlotMixin,listenOnRootMixin],
props:props$y,
data:function data(){
return {
show:this[MODEL_PROP_NAME$3],
transitioning:false};

},
computed:{
classObject:function classObject(){
var transitioning=this.transitioning;
return {
'navbar-collapse':this.isNav,
collapse:!transitioning,
show:this.show&&!transitioning};

},
slotScope:function slotScope(){
var _this=this;

return {
visible:this.show,
close:function close(){
_this.show=false;
}};

}},

watch:(_watch$4={},_defineProperty(_watch$4,MODEL_PROP_NAME$3,function(newValue){
if(newValue!==this.show){
this.show=newValue;
}
}),_defineProperty(_watch$4,"show",function show(newValue,oldValue){
if(newValue!==oldValue){
this.emitState();
}
}),_watch$4),
created:function created(){
this.show=this[MODEL_PROP_NAME$3];
},
mounted:function mounted(){
var _this2=this;

this.show=this[MODEL_PROP_NAME$3];// Listen for toggle events to open/close us

this.listenOnRoot(ROOT_ACTION_EVENT_NAME_TOGGLE,this.handleToggleEvt);// Listen to other collapses for accordion events

this.listenOnRoot(ROOT_EVENT_NAME_ACCORDION,this.handleAccordionEvt);

if(this.isNav){
// Set up handlers
this.setWindowEvents(true);
this.handleResize();
}

this.$nextTick(function(){
_this2.emitState();
});// Listen for "Sync state" requests from `v-b-toggle`

this.listenOnRoot(ROOT_ACTION_EVENT_NAME_REQUEST_STATE,function(id){
if(id===_this2.safeId()){
_this2.$nextTick(_this2.emitSync);
}
});
},
updated:function updated(){
// Emit a private event every time this component updates to ensure
// the toggle button is in sync with the collapse's state
// It is emitted regardless if the visible state changes
this.emitSync();
},

/* istanbul ignore next */
deactivated:function deactivated(){
if(this.isNav){
this.setWindowEvents(false);
}
},

/* istanbul ignore next */
activated:function activated(){
if(this.isNav){
this.setWindowEvents(true);
}

this.emitSync();
},
beforeDestroy:function beforeDestroy(){
// Trigger state emit if needed
this.show=false;

if(this.isNav&&IS_BROWSER){
this.setWindowEvents(false);
}
},
methods:{
setWindowEvents:function setWindowEvents(on){
eventOnOff(on,window,'resize',this.handleResize,EVENT_OPTIONS_NO_CAPTURE);
eventOnOff(on,window,'orientationchange',this.handleResize,EVENT_OPTIONS_NO_CAPTURE);
},
toggle:function toggle(){
this.show=!this.show;
},
onEnter:function onEnter(){
this.transitioning=true;// This should be moved out so we can add cancellable events

this.$emit(EVENT_NAME_SHOW);
},
onAfterEnter:function onAfterEnter(){
this.transitioning=false;
this.$emit(EVENT_NAME_SHOWN);
},
onLeave:function onLeave(){
this.transitioning=true;// This should be moved out so we can add cancellable events

this.$emit(EVENT_NAME_HIDE);
},
onAfterLeave:function onAfterLeave(){
this.transitioning=false;
this.$emit(EVENT_NAME_HIDDEN);
},
emitState:function emitState(){
var show=this.show,
accordion=this.accordion;
var id=this.safeId();
this.$emit(MODEL_EVENT_NAME$3,show);// Let `v-b-toggle` know the state of this collapse

this.emitOnRoot(ROOT_EVENT_NAME_STATE,id,show);

if(accordion&&show){
// Tell the other collapses in this accordion to close
this.emitOnRoot(ROOT_EVENT_NAME_ACCORDION,id,accordion);
}
},
emitSync:function emitSync(){
// Emit a private event every time this component updates to ensure
// the toggle button is in sync with the collapse's state
// It is emitted regardless if the visible state changes
this.emitOnRoot(ROOT_EVENT_NAME_SYNC_STATE,this.safeId(),this.show);
},
checkDisplayBlock:function checkDisplayBlock(){
// Check to see if the collapse has `display: block !important` set
// We can't set `display: none` directly on `this.$el`, as it would
// trigger a new transition to start (or cancel a current one)
var $el=this.$el;
var restore=hasClass($el,CLASS_NAME_SHOW);
removeClass($el,CLASS_NAME_SHOW);
var isBlock=getCS($el).display==='block';

if(restore){
addClass($el,CLASS_NAME_SHOW);
}

return isBlock;
},
clickHandler:function clickHandler(event){
var el=event.target;// If we are in a nav/navbar, close the collapse when non-disabled link clicked

/* istanbul ignore next: can't test `getComputedStyle()` in JSDOM */

if(!this.isNav||!el||getCS(this.$el).display!=='block'){
return;
}// Only close the collapse if it is not forced to be `display: block !important`


if((matches(el,'.nav-link,.dropdown-item')||closest('.nav-link,.dropdown-item',el))&&!this.checkDisplayBlock()){
this.show=false;
}
},
handleToggleEvt:function handleToggleEvt(id){
if(id===this.safeId()){
this.toggle();
}
},
handleAccordionEvt:function handleAccordionEvt(openedId,openAccordion){
var accordion=this.accordion,
show=this.show;

if(!accordion||accordion!==openAccordion){
return;
}

var isThis=openedId===this.safeId();// Open this collapse if not shown or
// close this collapse if shown

if(isThis&&!show||!isThis&&show){
this.toggle();
}
},
handleResize:function handleResize(){
// Handler for orientation/resize to set collapsed state in nav/navbar
this.show=getCS(this.$el).display==='block';
}},

render:function render(h){
var appear=this.appear;
var $content=h(this.tag,{
class:this.classObject,
directives:[{
name:'show',
value:this.show}],

attrs:{
id:this.safeId()},

on:{
click:this.clickHandler}},

this.normalizeSlot(SLOT_NAME_DEFAULT,this.slotScope));
return h(BVCollapse,{
props:{
appear:appear},

on:{
enter:this.onEnter,
afterEnter:this.onAfterEnter,
leave:this.onLeave,
afterLeave:this.onAfterLeave}},

[$content]);
}});


// Classes to apply to trigger element

var CLASS_BV_TOGGLE_COLLAPSED='collapsed';
var CLASS_BV_TOGGLE_NOT_COLLAPSED='not-collapsed';// Property key for handler storage

var BV_BASE='__BV_toggle';// Root event listener property (Function)

var BV_TOGGLE_ROOT_HANDLER="".concat(BV_BASE,"_HANDLER__");// Trigger element click handler property (Function)

var BV_TOGGLE_CLICK_HANDLER="".concat(BV_BASE,"_CLICK__");// Target visibility state property (Boolean)

var BV_TOGGLE_STATE="".concat(BV_BASE,"_STATE__");// Target ID list property (Array)

var BV_TOGGLE_TARGETS="".concat(BV_BASE,"_TARGETS__");// Commonly used strings

var STRING_FALSE='false';
var STRING_TRUE='true';// Commonly used attribute names

var ATTR_ARIA_CONTROLS='aria-controls';
var ATTR_ARIA_EXPANDED='aria-expanded';
var ATTR_ROLE='role';
var ATTR_TABINDEX='tabindex';// Commonly used style properties

var STYLE_OVERFLOW_ANCHOR='overflow-anchor';// Emitted control event for collapse (emitted to collapse)

var ROOT_ACTION_EVENT_NAME_TOGGLE$1=getRootActionEventName(NAME_COLLAPSE,'toggle');// Listen to event for toggle state update (emitted by collapse)

var ROOT_EVENT_NAME_STATE$1=getRootEventName(NAME_COLLAPSE,'state');// Private event emitted on `$root` to ensure the toggle state is always synced
// Gets emitted even if the state of b-collapse has not changed
// This event is NOT to be documented as people should not be using it

var ROOT_EVENT_NAME_SYNC_STATE$1=getRootEventName(NAME_COLLAPSE,'sync-state');// Private event we send to collapse to request state update sync event

var ROOT_ACTION_EVENT_NAME_REQUEST_STATE$1=getRootActionEventName(NAME_COLLAPSE,'request-state');
var KEYDOWN_KEY_CODES=[CODE_ENTER,CODE_SPACE];// --- Helper methods ---

var isNonStandardTag$1=function isNonStandardTag(el){
return !arrayIncludes(['button','a'],el.tagName.toLowerCase());
};

var getTargets=function getTargets(_ref,el){
var modifiers=_ref.modifiers,
arg=_ref.arg,
value=_ref.value;
// Any modifiers are considered target IDs
var targets=keys(modifiers||{});// If value is a string, split out individual targets (if space delimited)

value=isString(value)?value.split(RX_SPACE_SPLIT):value;// Support target ID as link href (`href="#id"`)

if(isTag(el.tagName,'a')){
var href=getAttr(el,'href')||'';

if(RX_HASH_ID.test(href)){
targets.push(href.replace(RX_HASH,''));
}
}// Add ID from `arg` (if provided), and support value
// as a single string ID or an array of string IDs
// If `value` is not an array or string, then it gets filtered out


concat(arg,value).forEach(function(t){
return isString(t)&&targets.push(t);
});// Return only unique and truthy target IDs

return targets.filter(function(t,index,arr){
return t&&arr.indexOf(t)===index;
});
};

var removeClickListener=function removeClickListener(el){
var handler=el[BV_TOGGLE_CLICK_HANDLER];

if(handler){
eventOff(el,'click',handler,EVENT_OPTIONS_PASSIVE);
eventOff(el,'keydown',handler,EVENT_OPTIONS_PASSIVE);
}

el[BV_TOGGLE_CLICK_HANDLER]=null;
};

var addClickListener=function addClickListener(el,vnode){
removeClickListener(el);

if(vnode.context){
var handler=function handler(event){
if(!(event.type==='keydown'&&!arrayIncludes(KEYDOWN_KEY_CODES,event.keyCode))&&!isDisabled(el)){
var targets=el[BV_TOGGLE_TARGETS]||[];
targets.forEach(function(target){
vnode.context.$root.$emit(ROOT_ACTION_EVENT_NAME_TOGGLE$1,target);
});
}
};

el[BV_TOGGLE_CLICK_HANDLER]=handler;
eventOn(el,'click',handler,EVENT_OPTIONS_PASSIVE);

if(isNonStandardTag$1(el)){
eventOn(el,'keydown',handler,EVENT_OPTIONS_PASSIVE);
}
}
};

var removeRootListeners=function removeRootListeners(el,vnode){
if(el[BV_TOGGLE_ROOT_HANDLER]&&vnode.context){
vnode.context.$root.$off([ROOT_EVENT_NAME_STATE$1,ROOT_EVENT_NAME_SYNC_STATE$1],el[BV_TOGGLE_ROOT_HANDLER]);
}

el[BV_TOGGLE_ROOT_HANDLER]=null;
};

var addRootListeners=function addRootListeners(el,vnode){
removeRootListeners(el,vnode);

if(vnode.context){
var handler=function handler(id,state){
// `state` will be `true` if target is expanded
if(arrayIncludes(el[BV_TOGGLE_TARGETS]||[],id)){
// Set/Clear 'collapsed' visibility class state
el[BV_TOGGLE_STATE]=state;// Set `aria-expanded` and class state on trigger element

setToggleState(el,state);
}
};

el[BV_TOGGLE_ROOT_HANDLER]=handler;// Listen for toggle state changes (public) and sync (private)

vnode.context.$root.$on([ROOT_EVENT_NAME_STATE$1,ROOT_EVENT_NAME_SYNC_STATE$1],handler);
}
};

var setToggleState=function setToggleState(el,state){
// State refers to the visibility of the collapse/sidebar
if(state){
removeClass(el,CLASS_BV_TOGGLE_COLLAPSED);
addClass(el,CLASS_BV_TOGGLE_NOT_COLLAPSED);
setAttr(el,ATTR_ARIA_EXPANDED,STRING_TRUE);
}else {
removeClass(el,CLASS_BV_TOGGLE_NOT_COLLAPSED);
addClass(el,CLASS_BV_TOGGLE_COLLAPSED);
setAttr(el,ATTR_ARIA_EXPANDED,STRING_FALSE);
}
};// Reset and remove a property from the provided element


var resetProp=function resetProp(el,prop){
el[prop]=null;
delete el[prop];
};// Handle directive updates


var handleUpdate=function handleUpdate(el,binding,vnode){
/* istanbul ignore next: should never happen */
if(!IS_BROWSER||!vnode.context){
return;
}// If element is not a button or link, we add `role="button"`
// and `tabindex="0"` for accessibility reasons


if(isNonStandardTag$1(el)){
if(!hasAttr(el,ATTR_ROLE)){
setAttr(el,ATTR_ROLE,'button');
}

if(!hasAttr(el,ATTR_TABINDEX)){
setAttr(el,ATTR_TABINDEX,'0');
}
}// Ensure the collapse class and `aria-*` attributes persist
// after element is updated (either by parent re-rendering
// or changes to this element or its contents)


setToggleState(el,el[BV_TOGGLE_STATE]);// Parse list of target IDs

var targets=getTargets(binding,el);// Ensure the `aria-controls` hasn't been overwritten
// or removed when vnode updates
// Also ensure to set `overflow-anchor` to `none` to prevent
// the browser's scroll anchoring behavior

/* istanbul ignore else */

if(targets.length>0){
setAttr(el,ATTR_ARIA_CONTROLS,targets.join(' '));
setStyle(el,STYLE_OVERFLOW_ANCHOR,'none');
}else {
removeAttr(el,ATTR_ARIA_CONTROLS);
removeStyle(el,STYLE_OVERFLOW_ANCHOR);
}// Add/Update our click listener(s)
// Wrap in a `requestAF()` to allow any previous
// click handling to occur first


requestAF(function(){
addClickListener(el,vnode);
});// If targets array has changed, update

if(!looseEqual(targets,el[BV_TOGGLE_TARGETS])){
// Update targets array to element storage
el[BV_TOGGLE_TARGETS]=targets;// Ensure `aria-controls` is up to date
// Request a state update from targets so that we can
// ensure expanded state is correct (in most cases)

targets.forEach(function(target){
vnode.context.$root.$emit(ROOT_ACTION_EVENT_NAME_REQUEST_STATE$1,target);
});
}
};
/*
 * Export our directive
 */


var VBToggle={
bind:function bind(el,binding,vnode){
// State is initially collapsed until we receive a state event
el[BV_TOGGLE_STATE]=false;// Assume no targets initially

el[BV_TOGGLE_TARGETS]=[];// Add our root listeners

addRootListeners(el,vnode);// Initial update of trigger

handleUpdate(el,binding,vnode);
},
componentUpdated:handleUpdate,
updated:handleUpdate,
unbind:function unbind(el,binding,vnode){
removeClickListener(el);// Remove our $root listener

removeRootListeners(el,vnode);// Reset custom props

resetProp(el,BV_TOGGLE_ROOT_HANDLER);
resetProp(el,BV_TOGGLE_CLICK_HANDLER);
resetProp(el,BV_TOGGLE_STATE);
resetProp(el,BV_TOGGLE_TARGETS);// Reset classes/attrs/styles

removeClass(el,CLASS_BV_TOGGLE_COLLAPSED);
removeClass(el,CLASS_BV_TOGGLE_NOT_COLLAPSED);
removeAttr(el,ATTR_ARIA_EXPANDED);
removeAttr(el,ATTR_ARIA_CONTROLS);
removeAttr(el,ATTR_ROLE);
removeStyle(el,STYLE_OVERFLOW_ANCHOR);
}};


var VBTogglePlugin=/*#__PURE__*/pluginFactory({
directives:{
VBToggle:VBToggle}});



var CollapsePlugin=/*#__PURE__*/pluginFactory({
components:{
BCollapse:BCollapse},

plugins:{
VBTogglePlugin:VBTogglePlugin}});



var PLACEMENT_TOP_START='top-start';
var PLACEMENT_TOP_END='top-end';
var PLACEMENT_BOTTOM_START='bottom-start';
var PLACEMENT_BOTTOM_END='bottom-end';
var PLACEMENT_RIGHT_START='right-start';
var PLACEMENT_LEFT_START='left-start';

var BvEvent=/*#__PURE__*/function(){
function BvEvent(type){
var eventInit=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

_classCallCheck(this,BvEvent);

// Start by emulating native Event constructor
if(!type){
/* istanbul ignore next */
throw new TypeError("Failed to construct '".concat(this.constructor.name,"'. 1 argument required, ").concat(arguments.length," given."));
}// Merge defaults first, the eventInit, and the type last
// so it can't be overwritten


assign(this,BvEvent.Defaults,this.constructor.Defaults,eventInit,{
type:type});
// Freeze some props as readonly, but leave them enumerable

defineProperties(this,{
type:readonlyDescriptor(),
cancelable:readonlyDescriptor(),
nativeEvent:readonlyDescriptor(),
target:readonlyDescriptor(),
relatedTarget:readonlyDescriptor(),
vueTarget:readonlyDescriptor(),
componentId:readonlyDescriptor()});
// Create a private variable using closure scoping

var defaultPrevented=false;// Recreate preventDefault method. One way setter

this.preventDefault=function preventDefault(){
if(this.cancelable){
defaultPrevented=true;
}
};// Create `defaultPrevented` publicly accessible prop that
// can only be altered by the preventDefault method


defineProperty(this,'defaultPrevented',{
enumerable:true,
get:function get(){
return defaultPrevented;
}});

}

_createClass(BvEvent,null,[{
key:"Defaults",
get:function get(){
return {
type:'',
cancelable:true,
nativeEvent:null,
target:null,
relatedTarget:null,
vueTarget:null,
componentId:null};

}}]);


return BvEvent;
}();

var clickOutMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
data:function data(){
return {
listenForClickOut:false};

},
watch:{
listenForClickOut:function listenForClickOut(newValue,oldValue){
if(newValue!==oldValue){
eventOff(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,EVENT_OPTIONS_NO_CAPTURE);

if(newValue){
eventOn(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,EVENT_OPTIONS_NO_CAPTURE);
}
}
}},

beforeCreate:function beforeCreate(){
// Declare non-reactive properties
this.clickOutElement=null;
this.clickOutEventName=null;
},
mounted:function mounted(){
if(!this.clickOutElement){
this.clickOutElement=document;
}

if(!this.clickOutEventName){
this.clickOutEventName='click';
}

if(this.listenForClickOut){
eventOn(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,EVENT_OPTIONS_NO_CAPTURE);
}
},
beforeDestroy:function beforeDestroy(){
eventOff(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,EVENT_OPTIONS_NO_CAPTURE);
},
methods:{
isClickOut:function isClickOut(event){
return !contains(this.$el,event.target);
},
_clickOutHandler:function _clickOutHandler(event){
if(this.clickOutHandler&&this.isClickOut(event)){
this.clickOutHandler(event);
}
}}});



var focusInMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
data:function data(){
return {
listenForFocusIn:false};

},
watch:{
listenForFocusIn:function listenForFocusIn(newValue,oldValue){
if(newValue!==oldValue){
eventOff(this.focusInElement,'focusin',this._focusInHandler,EVENT_OPTIONS_NO_CAPTURE);

if(newValue){
eventOn(this.focusInElement,'focusin',this._focusInHandler,EVENT_OPTIONS_NO_CAPTURE);
}
}
}},

beforeCreate:function beforeCreate(){
// Declare non-reactive properties
this.focusInElement=null;
},
mounted:function mounted(){
if(!this.focusInElement){
this.focusInElement=document;
}

if(this.listenForFocusIn){
eventOn(this.focusInElement,'focusin',this._focusInHandler,EVENT_OPTIONS_NO_CAPTURE);
}
},
beforeDestroy:function beforeDestroy(){
eventOff(this.focusInElement,'focusin',this._focusInHandler,EVENT_OPTIONS_NO_CAPTURE);
},
methods:{
_focusInHandler:function _focusInHandler(event){
if(this.focusInHandler){
this.focusInHandler(event);
}
}}});



var ROOT_EVENT_NAME_SHOWN=getRootEventName(NAME_DROPDOWN,EVENT_NAME_SHOWN);
var ROOT_EVENT_NAME_HIDDEN=getRootEventName(NAME_DROPDOWN,EVENT_NAME_HIDDEN);// CSS selectors

var SELECTOR_FORM_CHILD='.dropdown form';
var SELECTOR_ITEM=['.dropdown-item','.b-dropdown-form'].map(function(selector){
return "".concat(selector,":not(.disabled):not([disabled])");
}).join(', ');// --- Helper methods ---
// Return an array of visible items

var filterVisibles=function filterVisibles(els){
return (els||[]).filter(isVisible);
};// --- Props ---


var props$z=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$g),{},{
// String: `scrollParent`, `window` or `viewport`
// HTMLElement: HTML Element reference
boundary:makeProp([HTMLElement,PROP_TYPE_STRING],'scrollParent'),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
// Place left if possible
dropleft:makeProp(PROP_TYPE_BOOLEAN,false),
// Place right if possible
dropright:makeProp(PROP_TYPE_BOOLEAN,false),
// Place on top if possible
dropup:makeProp(PROP_TYPE_BOOLEAN,false),
// Disable auto-flipping of menu from bottom <=> top
noFlip:makeProp(PROP_TYPE_BOOLEAN,false),
// Number of pixels or a CSS unit value to offset menu
// (i.e. `1px`, `1rem`, etc.)
offset:makeProp(PROP_TYPE_NUMBER_STRING,0),
popperOpts:makeProp(PROP_TYPE_OBJECT,{}),
// Right align menu (default is left align)
right:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_DROPDOWN);// --- Mixin ---
// @vue/component

var dropdownMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[idMixin,listenOnRootMixin,clickOutMixin,focusInMixin],
provide:function provide(){
return {
bvDropdown:this};

},
inject:{
bvNavbar:{
default:null}},


props:props$z,
data:function data(){
return {
visible:false,
visibleChangePrevented:false};

},
computed:{
inNavbar:function inNavbar(){
return !isNull(this.bvNavbar);
},
toggler:function toggler(){
var toggle=this.$refs.toggle;
return toggle?toggle.$el||toggle:null;
},
directionClass:function directionClass(){
if(this.dropup){
return 'dropup';
}else if(this.dropright){
return 'dropright';
}else if(this.dropleft){
return 'dropleft';
}

return '';
},
boundaryClass:function boundaryClass(){
// Position `static` is needed to allow menu to "breakout" of the `scrollParent`
// boundaries when boundary is anything other than `scrollParent`
// See: https://github.com/twbs/bootstrap/issues/24251#issuecomment-341413786
return this.boundary!=='scrollParent'&&!this.inNavbar?'position-static':'';
}},

watch:{
visible:function visible(newValue,oldValue){
if(this.visibleChangePrevented){
this.visibleChangePrevented=false;
return;
}

if(newValue!==oldValue){
var eventName=newValue?EVENT_NAME_SHOW:EVENT_NAME_HIDE;
var bvEvent=new BvEvent(eventName,{
cancelable:true,
vueTarget:this,
target:this.$refs.menu,
relatedTarget:null,
componentId:this.safeId?this.safeId():this.id||null});

this.emitEvent(bvEvent);

if(bvEvent.defaultPrevented){
// Reset value and exit if canceled
this.visibleChangePrevented=true;
this.visible=oldValue;// Just in case a child element triggered `this.hide(true)`

this.$off(EVENT_NAME_HIDDEN,this.focusToggler);
return;
}

if(newValue){
this.showMenu();
}else {
this.hideMenu();
}
}
},
disabled:function disabled(newValue,oldValue){
if(newValue!==oldValue&&newValue&&this.visible){
// Hide dropdown if disabled changes to true
this.visible=false;
}
}},

created:function created(){
// Create private non-reactive props
this.$_popper=null;
this.$_hideTimeout=null;
},

/* istanbul ignore next */
deactivated:function deactivated(){
// In case we are inside a `<keep-alive>`
this.visible=false;
this.whileOpenListen(false);
this.destroyPopper();
},
beforeDestroy:function beforeDestroy(){
this.visible=false;
this.whileOpenListen(false);
this.destroyPopper();
this.clearHideTimeout();
},
methods:{
// Event emitter
emitEvent:function emitEvent(bvEvent){
var type=bvEvent.type;
this.emitOnRoot(getRootEventName(NAME_DROPDOWN,type),bvEvent);
this.$emit(type,bvEvent);
},
showMenu:function showMenu(){
var _this=this;

if(this.disabled){
/* istanbul ignore next */
return;
}// Only instantiate Popper.js when dropdown is not in `<b-navbar>`


if(!this.inNavbar){
if(typeof popper_js__WEBPACK_IMPORTED_MODULE_2__["default"]==='undefined'){
/* istanbul ignore next */
warn('Popper.js not found. Falling back to CSS positioning',NAME_DROPDOWN);
}else {
// For dropup with alignment we use the parent element as popper container
var el=this.dropup&&this.right||this.split?this.$el:this.$refs.toggle;// Make sure we have a reference to an element, not a component!

el=el.$el||el;// Instantiate Popper.js

this.createPopper(el);
}
}// Ensure other menus are closed


this.emitOnRoot(ROOT_EVENT_NAME_SHOWN,this);// Enable listeners

this.whileOpenListen(true);// Wrap in `$nextTick()` to ensure menu is fully rendered/shown

this.$nextTick(function(){
// Focus on the menu container on show
_this.focusMenu();// Emit the shown event


_this.$emit(EVENT_NAME_SHOWN);
});
},
hideMenu:function hideMenu(){
this.whileOpenListen(false);
this.emitOnRoot(ROOT_EVENT_NAME_HIDDEN,this);
this.$emit(EVENT_NAME_HIDDEN);
this.destroyPopper();
},
createPopper:function createPopper(element){
this.destroyPopper();
this.$_popper=new popper_js__WEBPACK_IMPORTED_MODULE_2__["default"](element,this.$refs.menu,this.getPopperConfig());
},
// Ensure popper event listeners are removed cleanly
destroyPopper:function destroyPopper(){
this.$_popper&&this.$_popper.destroy();
this.$_popper=null;
},
// Instructs popper to re-computes the dropdown position
// useful if the content changes size
updatePopper:function updatePopper(){
try{
this.$_popper.scheduleUpdate();
}catch(_unused){}
},
clearHideTimeout:function clearHideTimeout(){
clearTimeout(this.$_hideTimeout);
this.$_hideTimeout=null;
},
getPopperConfig:function getPopperConfig(){
var placement=PLACEMENT_BOTTOM_START;

if(this.dropup){
placement=this.right?PLACEMENT_TOP_END:PLACEMENT_TOP_START;
}else if(this.dropright){
placement=PLACEMENT_RIGHT_START;
}else if(this.dropleft){
placement=PLACEMENT_LEFT_START;
}else if(this.right){
placement=PLACEMENT_BOTTOM_END;
}

var popperConfig={
placement:placement,
modifiers:{
offset:{
offset:this.offset||0},

flip:{
enabled:!this.noFlip}}};



var boundariesElement=this.boundary;

if(boundariesElement){
popperConfig.modifiers.preventOverflow={
boundariesElement:boundariesElement};

}

return mergeDeep(popperConfig,this.popperOpts||{});
},
// Turn listeners on/off while open
whileOpenListen:function whileOpenListen(isOpen){
// Hide the dropdown when clicked outside
this.listenForClickOut=isOpen;// Hide the dropdown when it loses focus

this.listenForFocusIn=isOpen;// Hide the dropdown when another dropdown is opened

var method=isOpen?'$on':'$off';
this.$root[method](ROOT_EVENT_NAME_SHOWN,this.rootCloseListener);
},
rootCloseListener:function rootCloseListener(vm){
if(vm!==this){
this.visible=false;
}
},
// Public method to show dropdown
show:function show(){
var _this2=this;

if(this.disabled){
return;
}// Wrap in a `requestAF()` to allow any previous
// click handling to occur first


requestAF(function(){
_this2.visible=true;
});
},
// Public method to hide dropdown
hide:function hide(){
var refocus=arguments.length>0&&arguments[0]!==undefined?arguments[0]:false;

/* istanbul ignore next */
if(this.disabled){
return;
}

this.visible=false;

if(refocus){
// Child element is closing the dropdown on click
this.$once(EVENT_NAME_HIDDEN,this.focusToggler);
}
},
// Called only by a button that toggles the menu
toggle:function toggle(event){
event=event||{};// Early exit when not a click event or ENTER, SPACE or DOWN were pressed

var _event=event,
type=_event.type,
keyCode=_event.keyCode;

if(type!=='click'&&!(type==='keydown'&&[CODE_ENTER,CODE_SPACE,CODE_DOWN].indexOf(keyCode)!==-1)){
/* istanbul ignore next */
return;
}
/* istanbul ignore next */


if(this.disabled){
this.visible=false;
return;
}

this.$emit(EVENT_NAME_TOGGLE,event);
stopEvent(event);// Toggle visibility

if(this.visible){
this.hide(true);
}else {
this.show();
}
},
// Mousedown handler for the toggle

/* istanbul ignore next */
onMousedown:function onMousedown(event){
// We prevent the 'mousedown' event for the toggle to stop the
// 'focusin' event from being fired
// The event would otherwise be picked up by the global 'focusin'
// listener and there is no cross-browser solution to detect it
// relates to the toggle click
// The 'click' event will still be fired and we handle closing
// other dropdowns there too
// See https://github.com/bootstrap-vue/bootstrap-vue/issues/4328
stopEvent(event,{
propagation:false});

},
// Called from dropdown menu context
onKeydown:function onKeydown(event){
var keyCode=event.keyCode;

if(keyCode===CODE_ESC){
// Close on ESC
this.onEsc(event);
}else if(keyCode===CODE_DOWN){
// Down Arrow
this.focusNext(event,false);
}else if(keyCode===CODE_UP){
// Up Arrow
this.focusNext(event,true);
}
},
// If user presses ESC, close the menu
onEsc:function onEsc(event){
if(this.visible){
this.visible=false;
stopEvent(event);// Return focus to original trigger button

this.$once(EVENT_NAME_HIDDEN,this.focusToggler);
}
},
// Called only in split button mode, for the split button
onSplitClick:function onSplitClick(event){
/* istanbul ignore next */
if(this.disabled){
this.visible=false;
return;
}

this.$emit(EVENT_NAME_CLICK,event);
},
// Shared hide handler between click-out and focus-in events
hideHandler:function hideHandler(event){
var _this3=this;

var target=event.target;

if(this.visible&&!contains(this.$refs.menu,target)&&!contains(this.toggler,target)){
this.clearHideTimeout();
this.$_hideTimeout=setTimeout(function(){
return _this3.hide();
},this.inNavbar?300:0);
}
},
// Document click-out listener
clickOutHandler:function clickOutHandler(event){
this.hideHandler(event);
},
// Document focus-in listener
focusInHandler:function focusInHandler(event){
this.hideHandler(event);
},
// Keyboard nav
focusNext:function focusNext(event,up){
var _this4=this;

// Ignore key up/down on form elements
var target=event.target;

if(!this.visible||event&&closest(SELECTOR_FORM_CHILD,target)){
/* istanbul ignore next: should never happen */
return;
}

stopEvent(event);
this.$nextTick(function(){
var items=_this4.getItems();

if(items.length<1){
/* istanbul ignore next: should never happen */
return;
}

var index=items.indexOf(target);

if(up&&index>0){
index--;
}else if(!up&&index<items.length-1){
index++;
}

if(index<0){
/* istanbul ignore next: should never happen */
index=0;
}

_this4.focusItem(index,items);
});
},
focusItem:function focusItem(index,items){
var el=items.find(function(el,i){
return i===index;
});
attemptFocus(el);
},
getItems:function getItems(){
// Get all items
return filterVisibles(selectAll(SELECTOR_ITEM,this.$refs.menu));
},
focusMenu:function focusMenu(){
attemptFocus(this.$refs.menu);
},
focusToggler:function focusToggler(){
var _this5=this;

this.$nextTick(function(){
attemptFocus(_this5.toggler);
});
}}});



var props$A=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$z),{},{
block:makeProp(PROP_TYPE_BOOLEAN,false),
html:makeProp(PROP_TYPE_STRING),
// If `true`, only render menu contents when open
lazy:makeProp(PROP_TYPE_BOOLEAN,false),
menuClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
noCaret:makeProp(PROP_TYPE_BOOLEAN,false),
role:makeProp(PROP_TYPE_STRING,'menu'),
size:makeProp(PROP_TYPE_STRING),
split:makeProp(PROP_TYPE_BOOLEAN,false),
splitButtonType:makeProp(PROP_TYPE_STRING,'button',function(value){
return arrayIncludes(['button','submit','reset'],value);
}),
splitClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
splitHref:makeProp(PROP_TYPE_STRING),
splitTo:makeProp(PROP_TYPE_OBJECT_STRING),
splitVariant:makeProp(PROP_TYPE_STRING),
text:makeProp(PROP_TYPE_STRING),
toggleClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
toggleTag:makeProp(PROP_TYPE_STRING,'button'),
// TODO: This really should be `toggleLabel`
toggleText:makeProp(PROP_TYPE_STRING,'Toggle dropdown'),
variant:makeProp(PROP_TYPE_STRING,'secondary')})),
NAME_DROPDOWN);// --- Main component ---
// @vue/component

var BDropdown=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN,
mixins:[idMixin,dropdownMixin,normalizeSlotMixin],
props:props$A,
computed:{
dropdownClasses:function dropdownClasses(){
var block=this.block,
split=this.split;
return [this.directionClass,this.boundaryClass,{
show:this.visible,
// The 'btn-group' class is required in `split` mode for button alignment
// It needs also to be applied when `block` is disabled to allow multiple
// dropdowns to be aligned one line
'btn-group':split||!block,
// When `block` is enabled and we are in `split` mode the 'd-flex' class
// needs to be applied to allow the buttons to stretch to full width
'd-flex':block&&split}];

},
menuClasses:function menuClasses(){
return [this.menuClass,{
'dropdown-menu-right':this.right,
show:this.visible}];

},
toggleClasses:function toggleClasses(){
var split=this.split;
return [this.toggleClass,{
'dropdown-toggle-split':split,
'dropdown-toggle-no-caret':this.noCaret&&!split}];

}},

render:function render(h){
var visible=this.visible,
variant=this.variant,
size=this.size,
block=this.block,
disabled=this.disabled,
split=this.split,
role=this.role,
hide=this.hide,
toggle=this.toggle;
var commonProps={
variant:variant,
size:size,
block:block,
disabled:disabled};

var $buttonChildren=this.normalizeSlot(SLOT_NAME_BUTTON_CONTENT);
var buttonContentDomProps=this.hasNormalizedSlot(SLOT_NAME_BUTTON_CONTENT)?{}:htmlOrText(this.html,this.text);
var $split=h();

if(split){
var splitTo=this.splitTo,
splitHref=this.splitHref,
splitButtonType=this.splitButtonType;

var btnProps=_objectSpread2(_objectSpread2({},commonProps),{},{
variant:this.splitVariant||variant});
// We add these as needed due to <router-link> issues with
// defined property with `undefined`/`null` values


if(splitTo){
btnProps.to=splitTo;
}else if(splitHref){
btnProps.href=splitHref;
}else if(splitButtonType){
btnProps.type=splitButtonType;
}

$split=h(BButton,{
class:this.splitClass,
attrs:{
id:this.safeId('_BV_button_')},

props:btnProps,
domProps:buttonContentDomProps,
on:{
click:this.onSplitClick},

ref:'button'},
$buttonChildren);// Overwrite button content for the toggle when in `split` mode

$buttonChildren=[h('span',{
class:['sr-only']},
[this.toggleText])];
buttonContentDomProps={};
}

var $toggle=h(BButton,{
staticClass:'dropdown-toggle',
class:this.toggleClasses,
attrs:{
id:this.safeId('_BV_toggle_'),
'aria-haspopup':'true',
'aria-expanded':toString$1(visible)},

props:_objectSpread2(_objectSpread2({},commonProps),{},{
tag:this.toggleTag,
block:block&&!split}),

domProps:buttonContentDomProps,
on:{
mousedown:this.onMousedown,
click:toggle,
keydown:toggle// Handle ENTER, SPACE and DOWN
},

ref:'toggle'},
$buttonChildren);
var $menu=h('ul',{
staticClass:'dropdown-menu',
class:this.menuClasses,
attrs:{
role:role,
tabindex:'-1',
'aria-labelledby':this.safeId(split?'_BV_button_':'_BV_toggle_')},

on:{
keydown:this.onKeydown// Handle UP, DOWN and ESC
},

ref:'menu'},
[!this.lazy||visible?this.normalizeSlot(SLOT_NAME_DEFAULT,{
hide:hide}):
h()]);
return h('div',{
staticClass:'dropdown b-dropdown',
class:this.dropdownClasses,
attrs:{
id:this.safeId()}},

[$split,$toggle,$menu]);
}});


var linkProps$3=omit(props$6,['event','routerTag']);
var props$B=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},linkProps$3),{},{
linkClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
variant:makeProp(PROP_TYPE_STRING)})),
NAME_DROPDOWN_ITEM);// --- Main component ---
// @vue/component

var BDropdownItem=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN_ITEM,
mixins:[attrsMixin,normalizeSlotMixin],
inject:{
bvDropdown:{
default:null}},


inheritAttrs:false,
props:props$B,
computed:{
computedAttrs:function computedAttrs(){
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
role:'menuitem'});

}},

methods:{
closeDropdown:function closeDropdown(){
var _this=this;

// Close on next animation frame to allow <b-link> time to process
requestAF(function(){
if(_this.bvDropdown){
_this.bvDropdown.hide(true);
}
});
},
onClick:function onClick(event){
this.$emit(EVENT_NAME_CLICK,event);
this.closeDropdown();
}},

render:function render(h){
var linkClass=this.linkClass,
variant=this.variant,
active=this.active,
disabled=this.disabled,
onClick=this.onClick,
bvAttrs=this.bvAttrs;
return h('li',{
class:bvAttrs.class,
style:bvAttrs.style,
attrs:{
role:'presentation'}},

[h(BLink,{
staticClass:'dropdown-item',
class:[linkClass,_defineProperty({},"text-".concat(variant),variant&&!(active||disabled))],
props:pluckProps(linkProps$3,this.$props),
attrs:this.computedAttrs,
on:{
click:onClick},

ref:'item'},
this.normalizeSlot())]);
}});


var props$C=makePropsConfigurable({
active:makeProp(PROP_TYPE_BOOLEAN,false),
activeClass:makeProp(PROP_TYPE_STRING,'active'),
buttonClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
variant:makeProp(PROP_TYPE_STRING)},
NAME_DROPDOWN_ITEM_BUTTON);// --- Main component ---
// @vue/component

var BDropdownItemButton=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN_ITEM_BUTTON,
mixins:[attrsMixin,normalizeSlotMixin],
inject:{
bvDropdown:{
default:null}},


inheritAttrs:false,
props:props$C,
computed:{
computedAttrs:function computedAttrs(){
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
role:'menuitem',
type:'button',
disabled:this.disabled});

}},

methods:{
closeDropdown:function closeDropdown(){
if(this.bvDropdown){
this.bvDropdown.hide(true);
}
},
onClick:function onClick(event){
this.$emit(EVENT_NAME_CLICK,event);
this.closeDropdown();
}},

render:function render(h){
var _ref;

var active=this.active,
variant=this.variant,
bvAttrs=this.bvAttrs;
return h('li',{
class:bvAttrs.class,
style:bvAttrs.style,
attrs:{
role:'presentation'}},

[h('button',{
staticClass:'dropdown-item',
class:[this.buttonClass,(_ref={},_defineProperty(_ref,this.activeClass,active),_defineProperty(_ref,"text-".concat(variant),variant&&!(active||this.disabled)),_ref)],
attrs:this.computedAttrs,
on:{
click:this.onClick},

ref:'button'},
this.normalizeSlot())]);
}});


var props$D=makePropsConfigurable({
id:makeProp(PROP_TYPE_STRING),
tag:makeProp(PROP_TYPE_STRING,'header'),
variant:makeProp(PROP_TYPE_STRING)},
NAME_DROPDOWN_HEADER);// --- Main component ---
// @vue/component

var BDropdownHeader=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN_HEADER,
functional:true,
props:props$D,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var tag=props.tag,
variant=props.variant;
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['attrs']),{
attrs:{
role:'presentation'}}),

[h(tag,{
staticClass:'dropdown-header',
class:_defineProperty({},"text-".concat(variant),variant),
attrs:_objectSpread2(_objectSpread2({},data.attrs||{}),{},{
id:props.id||null,
role:isTag(tag,'header')?null:'heading'}),

ref:'header'},
children)]);
}});


var props$E=makePropsConfigurable({
tag:makeProp(PROP_TYPE_STRING,'hr')},
NAME_DROPDOWN_DIVIDER);// --- Main component ---
// @vue/component

var BDropdownDivider=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN_DIVIDER,
functional:true,
props:props$E,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data;
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['attrs']),{
attrs:{
role:'presentation'}}),

[h(props.tag,{
staticClass:'dropdown-divider',
attrs:_objectSpread2(_objectSpread2({},data.attrs||{}),{},{
role:'separator',
'aria-orientation':'horizontal'}),

ref:'divider'})]);

}});


var props$F=makePropsConfigurable({
id:makeProp(PROP_TYPE_STRING),
inline:makeProp(PROP_TYPE_BOOLEAN,false),
novalidate:makeProp(PROP_TYPE_BOOLEAN,false),
validated:makeProp(PROP_TYPE_BOOLEAN,false)},
NAME_FORM);// --- Main component ---
// @vue/component

var BForm=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM,
functional:true,
props:props$F,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h('form',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:{
'form-inline':props.inline,
'was-validated':props.validated},

attrs:{
id:props.id,
novalidate:props.novalidate}}),

children);
}});


var props$G=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$F),{},{
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
formClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)})),
NAME_DROPDOWN_FORM);// --- Main component ---
// @vue/component

var BDropdownForm=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN_FORM,
functional:true,
props:props$G,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
listeners=_ref.listeners,
children=_ref.children;
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['attrs','on']),{
attrs:{
role:'presentation'}}),

[h(BForm,{
staticClass:'b-dropdown-form',
class:[props.formClass,{
disabled:props.disabled}],

props:props,
attrs:_objectSpread2(_objectSpread2({},data.attrs||{}),{},{
disabled:props.disabled,
// Tab index of -1 for keyboard navigation
tabindex:props.disabled?null:'-1'}),

on:listeners,
ref:'form'},
children)]);
}});


var props$H=makePropsConfigurable({
tag:makeProp(PROP_TYPE_STRING,'p'),
textClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
variant:makeProp(PROP_TYPE_STRING)},
NAME_DROPDOWN_TEXT);// --- Main component ---
// @vue/component

var BDropdownText=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN_TEXT,
functional:true,
props:props$H,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var tag=props.tag,
textClass=props.textClass,
variant=props.variant;
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['attrs']),{
attrs:{
role:'presentation'}}),

[h(tag,{
staticClass:'b-dropdown-text',
class:[textClass,_defineProperty({},"text-".concat(variant),variant)],
props:props,
attrs:data.attrs||{},
ref:'text'},
children)]);
}});


var props$I=makePropsConfigurable({
ariaDescribedby:makeProp(PROP_TYPE_STRING),
header:makeProp(PROP_TYPE_STRING),
headerClasses:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
headerTag:makeProp(PROP_TYPE_STRING,'header'),
headerVariant:makeProp(PROP_TYPE_STRING),
id:makeProp(PROP_TYPE_STRING)},
NAME_DROPDOWN_GROUP);// --- Main component ---
// @vue/component

var BDropdownGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_DROPDOWN_GROUP,
functional:true,
props:props$I,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots;
var id=props.id,
variant=props.variant,
header=props.header,
headerTag=props.headerTag;
var $slots=slots();
var $scopedSlots=scopedSlots||{};
var slotScope={};
var headerId=id?"_bv_".concat(id,"_group_dd_header"):null;
var $header=h();

if(hasNormalizedSlot(SLOT_NAME_HEADER,$scopedSlots,$slots)||header){
$header=h(headerTag,{
staticClass:'dropdown-header',
class:[props.headerClasses,_defineProperty({},"text-".concat(variant),variant)],
attrs:{
id:headerId,
role:isTag(headerTag,'header')?null:'heading'}},

normalizeSlot(SLOT_NAME_HEADER,slotScope,$scopedSlots,$slots)||header);
}

return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['attrs']),{
attrs:{
role:'presentation'}}),

[$header,h('ul',{
staticClass:'list-unstyled',
attrs:_objectSpread2(_objectSpread2({},data.attrs||{}),{},{
id:id,
role:'group',
'aria-describedby':[headerId,props.ariaDescribedBy].filter(identity).join(' ').trim()||null})},

normalizeSlot(SLOT_NAME_DEFAULT,slotScope,$scopedSlots,$slots))]);
}});


var DropdownPlugin=/*#__PURE__*/pluginFactory({
components:{
BDropdown:BDropdown,
BDd:BDropdown,
BDropdownItem:BDropdownItem,
BDdItem:BDropdownItem,
BDropdownItemButton:BDropdownItemButton,
BDropdownItemBtn:BDropdownItemButton,
BDdItemButton:BDropdownItemButton,
BDdItemBtn:BDropdownItemButton,
BDropdownHeader:BDropdownHeader,
BDdHeader:BDropdownHeader,
BDropdownDivider:BDropdownDivider,
BDdDivider:BDropdownDivider,
BDropdownForm:BDropdownForm,
BDdForm:BDropdownForm,
BDropdownText:BDropdownText,
BDdText:BDropdownText,
BDropdownGroup:BDropdownGroup,
BDdGroup:BDropdownGroup}});



var TYPES=['iframe','embed','video','object','img','b-img','b-img-lazy'];// --- Props ---

var props$J=makePropsConfigurable({
aspect:makeProp(PROP_TYPE_STRING,'16by9'),
tag:makeProp(PROP_TYPE_STRING,'div'),
type:makeProp(PROP_TYPE_STRING,'iframe',function(value){
return arrayIncludes(TYPES,value);
})},
NAME_EMBED);// --- Main component ---
// @vue/component

var BEmbed=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_EMBED,
functional:true,
props:props$J,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var aspect=props.aspect;
return h(props.tag,{
staticClass:'embed-responsive',
class:_defineProperty({},"embed-responsive-".concat(aspect),aspect),
ref:data.ref},
[h(props.type,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['ref']),{
staticClass:'embed-responsive-item'}),
children)]);
}});


var EmbedPlugin=/*#__PURE__*/pluginFactory({
components:{
BEmbed:BEmbed}});



var OPTIONS_OBJECT_DEPRECATED_MSG='Setting prop "options" to an object is deprecated. Use the array format instead.';// --- Props ---

var props$K=makePropsConfigurable({
disabledField:makeProp(PROP_TYPE_STRING,'disabled'),
htmlField:makeProp(PROP_TYPE_STRING,'html'),
options:makeProp(PROP_TYPE_ARRAY_OBJECT,[]),
textField:makeProp(PROP_TYPE_STRING,'text'),
valueField:makeProp(PROP_TYPE_STRING,'value')},
'formOptionControls');// --- Mixin ---
// @vue/component

var formOptionsMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$K,
computed:{
formOptions:function formOptions(){
return this.normalizeOptions(this.options);
}},

methods:{
normalizeOption:function normalizeOption(option){
var key=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;

// When the option is an object, normalize it
if(isPlainObject(option)){
var value=get(option,this.valueField);
var text=get(option,this.textField);
return {
value:isUndefined(value)?key||text:value,
text:stripTags(String(isUndefined(text)?key:text)),
html:get(option,this.htmlField),
disabled:Boolean(get(option,this.disabledField))};

}// Otherwise create an `<option>` object from the given value


return {
value:key||option,
text:stripTags(String(option)),
disabled:false};

},
normalizeOptions:function normalizeOptions(options){
var _this=this;

// Normalize the given options array
if(isArray(options)){
return options.map(function(option){
return _this.normalizeOption(option);
});
}else if(isPlainObject(options)){
// Deprecate the object options format
warn(OPTIONS_OBJECT_DEPRECATED_MSG,this.$options.name);// Normalize a `options` object to an array of options

return keys(options).map(function(key){
return _this.normalizeOption(options[key]||{},key);
});
}// If not an array or object, return an empty array

/* istanbul ignore next */


return [];
}}});



var props$L=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$K),{},{
id:makeProp(PROP_TYPE_STRING,undefined,true)// Required
})),
NAME_FORM_DATALIST);// --- Main component ---
// @vue/component

var BFormDatalist=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_DATALIST,
mixins:[formOptionsMixin,normalizeSlotMixin],
props:props$L,
render:function render(h){
var id=this.id;
var $options=this.formOptions.map(function(option,index){
var value=option.value,
text=option.text,
html=option.html,
disabled=option.disabled;
return h('option',{
attrs:{
value:value,
disabled:disabled},

domProps:htmlOrText(html,text),
key:"option_".concat(index)});

});
return h('datalist',{
attrs:{
id:id}},

[$options,this.normalizeSlot()]);
}});


var props$M=makePropsConfigurable({
id:makeProp(PROP_TYPE_STRING),
inline:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'small'),
textVariant:makeProp(PROP_TYPE_STRING,'muted')},
NAME_FORM_TEXT);// --- Main component ---
// @vue/component

var BFormText=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_TEXT,
functional:true,
props:props$M,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:_defineProperty({
'form-text':!props.inline},
"text-".concat(props.textVariant),props.textVariant),
attrs:{
id:props.id}}),

children);
}});


var props$N=makePropsConfigurable({
ariaLive:makeProp(PROP_TYPE_STRING),
forceShow:makeProp(PROP_TYPE_BOOLEAN,false),
id:makeProp(PROP_TYPE_STRING),
role:makeProp(PROP_TYPE_STRING),
// Tri-state prop: `true`, `false`, or `null`
state:makeProp(PROP_TYPE_BOOLEAN,null),
tag:makeProp(PROP_TYPE_STRING,'div'),
tooltip:makeProp(PROP_TYPE_BOOLEAN,false)},
NAME_FORM_INVALID_FEEDBACK);// --- Main component ---
// @vue/component

var BFormInvalidFeedback=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_INVALID_FEEDBACK,
functional:true,
props:props$N,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var tooltip=props.tooltip,
ariaLive=props.ariaLive;
var show=props.forceShow===true||props.state===false;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:{
'd-block':show,
'invalid-feedback':!tooltip,
'invalid-tooltip':tooltip},

attrs:{
id:props.id||null,
role:props.role||null,
'aria-live':ariaLive||null,
'aria-atomic':ariaLive?'true':null}}),

children);
}});


var props$O=makePropsConfigurable({
ariaLive:makeProp(PROP_TYPE_STRING),
forceShow:makeProp(PROP_TYPE_BOOLEAN,false),
id:makeProp(PROP_TYPE_STRING),
role:makeProp(PROP_TYPE_STRING),
// Tri-state prop: `true`, `false`, or `null`
state:makeProp(PROP_TYPE_BOOLEAN,null),
tag:makeProp(PROP_TYPE_STRING,'div'),
tooltip:makeProp(PROP_TYPE_BOOLEAN,false)},
NAME_FORM_VALID_FEEDBACK);// --- Main component ---
// @vue/component

var BFormValidFeedback=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_VALID_FEEDBACK,
functional:true,
props:props$O,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var tooltip=props.tooltip,
ariaLive=props.ariaLive;
var show=props.forceShow===true||props.state===true;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:{
'd-block':show,
'valid-feedback':!tooltip,
'valid-tooltip':tooltip},

attrs:{
id:props.id||null,
role:props.role||null,
'aria-live':ariaLive||null,
'aria-atomic':ariaLive?'true':null}}),

children);
}});


var props$P=makePropsConfigurable({
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_FORM_ROW);// --- Main component ---
// @vue/component

var BFormRow=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_ROW,
functional:true,
props:props$P,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'form-row'}),
children);
}});


var FormPlugin=/*#__PURE__*/pluginFactory({
components:{
BForm:BForm,
BFormDatalist:BFormDatalist,
BDatalist:BFormDatalist,
BFormText:BFormText,
BFormInvalidFeedback:BFormInvalidFeedback,
BFormFeedback:BFormInvalidFeedback,
BFormValidFeedback:BFormValidFeedback,
// Added here for convenience
BFormRow:BFormRow}});

// BFormRow is not exported here as a named export, as it is exported by Layout

var looseIndexOf=function looseIndexOf(array,value){
for(var i=0;i<array.length;i++){
if(looseEqual(array[i],value)){
return i;
}
}

return -1;
};

var SELECTOR='input, textarea, select';// --- Props ---

var props$Q=makePropsConfigurable({
autofocus:makeProp(PROP_TYPE_BOOLEAN,false),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
form:makeProp(PROP_TYPE_STRING),
id:makeProp(PROP_TYPE_STRING),
name:makeProp(PROP_TYPE_STRING),
required:makeProp(PROP_TYPE_BOOLEAN,false)},
'formControls');// --- Mixin ---
// @vue/component

var formControlMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$Q,
mounted:function mounted(){
this.handleAutofocus();
},

/* istanbul ignore next */
activated:function activated(){
this.handleAutofocus();
},
methods:{
handleAutofocus:function handleAutofocus(){
var _this=this;

this.$nextTick(function(){
requestAF(function(){
var el=_this.$el;

if(_this.autofocus&&isVisible(el)){
if(!matches(el,SELECTOR)){
el=select(SELECTOR,el);
}

attemptFocus(el);
}
});
});
}}});



var props$R=makePropsConfigurable({
plain:makeProp(PROP_TYPE_BOOLEAN,false)},
'formControls');// --- Mixin ---
// @vue/component

var formCustomMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$R,
computed:{
custom:function custom(){
return !this.plain;
}}});



var props$S=makePropsConfigurable({
size:makeProp(PROP_TYPE_STRING)},
'formControls');// --- Mixin ---
// @vue/component

var formSizeMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$S,
computed:{
sizeFormClass:function sizeFormClass(){
return [this.size?"form-control-".concat(this.size):null];
}}});



/* Form control contextual state class computation
 *
 * Returned class is either 'is-valid' or 'is-invalid' based on the 'state' prop
 * state can be one of five values:
 *  - true for is-valid
 *  - false for is-invalid
 *  - null for no contextual state
 */

var props$T=makePropsConfigurable({
// Tri-state prop: true, false, null (or undefined)
state:makeProp(PROP_TYPE_BOOLEAN,null)},
'formState');// --- Mixin ---
// @vue/component

var formStateMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$T,
computed:{
computedState:function computedState(){
// If not a boolean, ensure that value is null
return isBoolean(this.state)?this.state:null;
},
stateClass:function stateClass(){
var state=this.computedState;
return state===true?'is-valid':state===false?'is-invalid':null;
},
computedAriaInvalid:function computedAriaInvalid(){
var ariaInvalid=this.ariaInvalid;

if(ariaInvalid===true||ariaInvalid==='true'||ariaInvalid===''){
return 'true';
}

return this.computedState===false?'true':ariaInvalid;
}}});



var _watch$5,_methods;

var _makeModelMixin$4=makeModelMixin('checked',{
defaultValue:null}),

modelMixin$4=_makeModelMixin$4.mixin,
modelProps$4=_makeModelMixin$4.props,
MODEL_PROP_NAME$4=_makeModelMixin$4.prop,
MODEL_EVENT_NAME$4=_makeModelMixin$4.event;

var props$U=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$4),props$Q),props$S),props$T),props$R),{},{
ariaLabel:makeProp(PROP_TYPE_STRING),
ariaLabelledby:makeProp(PROP_TYPE_STRING),
// Only applicable in standalone mode (non group)
button:makeProp(PROP_TYPE_BOOLEAN,false),
// Only applicable when rendered with button style
buttonVariant:makeProp(PROP_TYPE_STRING),
inline:makeProp(PROP_TYPE_BOOLEAN,false),
value:makeProp(PROP_TYPE_ANY)})),
'formRadioCheckControls');// --- Mixin ---
// @vue/component

var formRadioCheckMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[attrsMixin,idMixin,modelMixin$4,normalizeSlotMixin,formControlMixin,formSizeMixin,formStateMixin,formCustomMixin],
inheritAttrs:false,
props:props$U,
data:function data(){
return {
localChecked:this.isGroup?this.bvGroup[MODEL_PROP_NAME$4]:this[MODEL_PROP_NAME$4],
hasFocus:false};

},
computed:{
computedLocalChecked:{
get:function get(){
return this.isGroup?this.bvGroup.localChecked:this.localChecked;
},
set:function set(value){
if(this.isGroup){
this.bvGroup.localChecked=value;
}else {
this.localChecked=value;
}
}},

isChecked:function isChecked(){
return looseEqual(this.value,this.computedLocalChecked);
},
isRadio:function isRadio(){
return true;
},
isGroup:function isGroup(){
// Is this check/radio a child of check-group or radio-group?
return !!this.bvGroup;
},
isBtnMode:function isBtnMode(){
// Support button style in single input mode
return this.isGroup?this.bvGroup.buttons:this.button;
},
isPlain:function isPlain(){
return this.isBtnMode?false:this.isGroup?this.bvGroup.plain:this.plain;
},
isCustom:function isCustom(){
return this.isBtnMode?false:!this.isPlain;
},
isSwitch:function isSwitch(){
// Custom switch styling (checkboxes only)
return this.isBtnMode||this.isRadio||this.isPlain?false:this.isGroup?this.bvGroup.switches:this.switch;
},
isInline:function isInline(){
return this.isGroup?this.bvGroup.inline:this.inline;
},
isDisabled:function isDisabled(){
// Child can be disabled while parent isn't, but is always disabled if group is
return this.isGroup?this.bvGroup.disabled||this.disabled:this.disabled;
},
isRequired:function isRequired(){
// Required only works when a name is provided for the input(s)
// Child can only be required when parent is
// Groups will always have a name (either user supplied or auto generated)
return this.computedName&&(this.isGroup?this.bvGroup.required:this.required);
},
computedName:function computedName(){
// Group name preferred over local name
return (this.isGroup?this.bvGroup.groupName:this.name)||null;
},
computedForm:function computedForm(){
return (this.isGroup?this.bvGroup.form:this.form)||null;
},
computedSize:function computedSize(){
return (this.isGroup?this.bvGroup.size:this.size)||'';
},
computedState:function computedState(){
return this.isGroup?this.bvGroup.computedState:isBoolean(this.state)?this.state:null;
},
computedButtonVariant:function computedButtonVariant(){
// Local variant preferred over group variant
var buttonVariant=this.buttonVariant;

if(buttonVariant){
return buttonVariant;
}

if(this.isGroup&&this.bvGroup.buttonVariant){
return this.bvGroup.buttonVariant;
}

return 'secondary';
},
buttonClasses:function buttonClasses(){
var _ref;

var computedSize=this.computedSize;
return ['btn',"btn-".concat(this.computedButtonVariant),(_ref={},_defineProperty(_ref,"btn-".concat(computedSize),computedSize),_defineProperty(_ref,"disabled",this.isDisabled),_defineProperty(_ref,"active",this.isChecked),_defineProperty(_ref,"focus",this.hasFocus),_ref)];
},
computedAttrs:function computedAttrs(){
var disabled=this.isDisabled,
required=this.isRequired;
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
id:this.safeId(),
type:this.isRadio?'radio':'checkbox',
name:this.computedName,
form:this.computedForm,
disabled:disabled,
required:required,
'aria-required':required||null,
'aria-label':this.ariaLabel||null,
'aria-labelledby':this.ariaLabelledby||null});

}},

watch:(_watch$5={},_defineProperty(_watch$5,MODEL_PROP_NAME$4,function(){
this["".concat(MODEL_PROP_NAME$4,"Watcher")].apply(this,arguments);
}),_defineProperty(_watch$5,"computedLocalChecked",function computedLocalChecked(){
this.computedLocalCheckedWatcher.apply(this,arguments);
}),_watch$5),
methods:(_methods={},_defineProperty(_methods,"".concat(MODEL_PROP_NAME$4,"Watcher"),function Watcher(newValue){
if(!looseEqual(newValue,this.computedLocalChecked)){
this.computedLocalChecked=newValue;
}
}),_defineProperty(_methods,"computedLocalCheckedWatcher",function computedLocalCheckedWatcher(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.$emit(MODEL_EVENT_NAME$4,newValue);
}
}),_defineProperty(_methods,"handleChange",function handleChange(_ref2){
var _this=this;

var checked=_ref2.target.checked;
var value=this.value;
var localChecked=checked?value:null;
this.computedLocalChecked=value;// Fire events in a `$nextTick()` to ensure the `v-model` is updated

this.$nextTick(function(){
// Change is only emitted on user interaction
_this.$emit(EVENT_NAME_CHANGE,localChecked);// If this is a child of a group, we emit a change event on it as well


if(_this.isGroup){
_this.bvGroup.$emit(EVENT_NAME_CHANGE,localChecked);
}
});
}),_defineProperty(_methods,"handleFocus",function handleFocus(event){
// When in buttons mode, we need to add 'focus' class to label when input focused
// As it is the hidden input which has actual focus
if(event.target){
if(event.type==='focus'){
this.hasFocus=true;
}else if(event.type==='blur'){
this.hasFocus=false;
}
}
}),_defineProperty(_methods,"focus",function focus(){
if(!this.isDisabled){
attemptFocus(this.$refs.input);
}
}),_defineProperty(_methods,"blur",function blur(){
if(!this.isDisabled){
attemptBlur(this.$refs.input);
}
}),_methods),
render:function render(h){
var isRadio=this.isRadio,
isBtnMode=this.isBtnMode,
isPlain=this.isPlain,
isCustom=this.isCustom,
isInline=this.isInline,
isSwitch=this.isSwitch,
computedSize=this.computedSize,
bvAttrs=this.bvAttrs;
var $content=this.normalizeSlot();
var $input=h('input',{
class:[{
'form-check-input':isPlain,
'custom-control-input':isCustom,
// https://github.com/bootstrap-vue/bootstrap-vue/issues/2911
'position-static':isPlain&&!$content},
isBtnMode?'':this.stateClass],
directives:[{
name:'model',
value:this.computedLocalChecked}],

attrs:this.computedAttrs,
domProps:{
value:this.value,
checked:this.isChecked},

on:_objectSpread2({
change:this.handleChange},
isBtnMode?{
focus:this.handleFocus,
blur:this.handleFocus}:
{}),
key:'input',
ref:'input'});


if(isBtnMode){
var $button=h('label',{
class:this.buttonClasses},
[$input,$content]);

if(!this.isGroup){
// Standalone button mode, so wrap in 'btn-group-toggle'
// and flag it as inline-block to mimic regular buttons
$button=h('div',{
class:['btn-group-toggle','d-inline-block']},
[$button]);
}

return $button;
}// If no label content in plain mode we dont render the label
// See: https://github.com/bootstrap-vue/bootstrap-vue/issues/2911


var $label=h();

if(!(isPlain&&!$content)){
$label=h('label',{
class:{
'form-check-label':isPlain,
'custom-control-label':isCustom},

attrs:{
for:this.safeId()}},

$content);
}

return h('div',{
class:[_defineProperty({
'form-check':isPlain,
'form-check-inline':isPlain&&isInline,
'custom-control':isCustom,
'custom-control-inline':isCustom&&isInline,
'custom-checkbox':isCustom&&!isRadio&&!isSwitch,
'custom-switch':isSwitch,
'custom-radio':isCustom&&isRadio},
"b-custom-control-".concat(computedSize),computedSize&&!isBtnMode),bvAttrs.class],
style:bvAttrs.style},
[$input,$label]);
}});


var _objectSpread2$1;

var MODEL_PROP_NAME_INDETERMINATE='indeterminate';
var MODEL_EVENT_NAME_INDETERMINATE=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_INDETERMINATE;// --- Props ---

var props$V=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$U),{},(_objectSpread2$1={},_defineProperty(_objectSpread2$1,MODEL_PROP_NAME_INDETERMINATE,makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_objectSpread2$1,"switch",makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_objectSpread2$1,"uncheckedValue",makeProp(PROP_TYPE_ANY,false)),_defineProperty(_objectSpread2$1,"value",makeProp(PROP_TYPE_ANY,true)),_objectSpread2$1))),NAME_FORM_CHECKBOX);// --- Main component ---
// @vue/component

var BFormCheckbox=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_CHECKBOX,
mixins:[formRadioCheckMixin],
inject:{
bvGroup:{
from:'bvCheckGroup',
default:null}},


props:props$V,
computed:{
isChecked:function isChecked(){
var value=this.value,
checked=this.computedLocalChecked;
return isArray(checked)?looseIndexOf(checked,value)>-1:looseEqual(checked,value);
},
isRadio:function isRadio(){
return false;
}},

watch:_defineProperty({},MODEL_PROP_NAME_INDETERMINATE,function(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.setIndeterminate(newValue);
}
}),
mounted:function mounted(){
// Set initial indeterminate state
this.setIndeterminate(this[MODEL_PROP_NAME_INDETERMINATE]);
},
methods:{
computedLocalCheckedWatcher:function computedLocalCheckedWatcher(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.$emit(MODEL_EVENT_NAME$4,newValue);
var $input=this.$refs.input;

if($input){
this.$emit(MODEL_EVENT_NAME_INDETERMINATE,$input.indeterminate);
}
}
},
handleChange:function handleChange(_ref){
var _this=this;

var _ref$target=_ref.target,
checked=_ref$target.checked,
indeterminate=_ref$target.indeterminate;
var value=this.value,
uncheckedValue=this.uncheckedValue;// Update `computedLocalChecked`

var localChecked=this.computedLocalChecked;

if(isArray(localChecked)){
var index=looseIndexOf(localChecked,value);

if(checked&&index<0){
// Add value to array
localChecked=localChecked.concat(value);
}else if(!checked&&index>-1){
// Remove value from array
localChecked=localChecked.slice(0,index).concat(localChecked.slice(index+1));
}
}else {
localChecked=checked?value:uncheckedValue;
}

this.computedLocalChecked=localChecked;// Fire events in a `$nextTick()` to ensure the `v-model` is updated

this.$nextTick(function(){
// Change is only emitted on user interaction
_this.$emit(EVENT_NAME_CHANGE,localChecked);// If this is a child of a group, we emit a change event on it as well


if(_this.isGroup){
_this.bvGroup.$emit(EVENT_NAME_CHANGE,localChecked);
}

_this.$emit(MODEL_EVENT_NAME_INDETERMINATE,indeterminate);
});
},
setIndeterminate:function setIndeterminate(state){
// Indeterminate only supported in single checkbox mode
if(isArray(this.computedLocalChecked)){
state=false;
}

var $input=this.$refs.input;

if($input){
$input.indeterminate=state;// Emit update event to prop

this.$emit(MODEL_EVENT_NAME_INDETERMINATE,state);
}
}}});



var props$W=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$Q),props$U),props$S),props$T)),NAME_FORM_RADIO);// --- Main component ---
// @vue/component

var BFormRadio=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_RADIO,
mixins:[idMixin,formRadioCheckMixin,// Includes shared render function
formControlMixin,formSizeMixin,formStateMixin],
inject:{
bvGroup:{
from:'bvRadioGroup',
default:false}},


props:props$W,
watch:{
computedLocalChecked:function computedLocalChecked(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.$emit(MODEL_EVENT_NAME$4,newValue);
}
}}});



var _watch$6;
// Attributes to pass down to checks/radios instead of applying them to the group

var PASS_DOWN_ATTRS=['aria-describedby','aria-labelledby'];

var _makeModelMixin$5=makeModelMixin('checked'),
modelMixin$5=_makeModelMixin$5.mixin,
modelProps$5=_makeModelMixin$5.props,
MODEL_PROP_NAME$5=_makeModelMixin$5.prop,
MODEL_EVENT_NAME$5=_makeModelMixin$5.event;

var props$X=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$5),props$Q),props$K),props$S),props$T),props$R),{},{
ariaInvalid:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
// Only applicable when rendered with button style
buttonVariant:makeProp(PROP_TYPE_STRING),
// Render as button style
buttons:makeProp(PROP_TYPE_BOOLEAN,false),
stacked:makeProp(PROP_TYPE_BOOLEAN,false),
validated:makeProp(PROP_TYPE_BOOLEAN,false)})),
'formRadioCheckGroups');// --- Mixin ---
// @vue/component

var formRadioCheckGroupMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[idMixin,modelMixin$5,normalizeSlotMixin,formControlMixin,formOptionsMixin,formSizeMixin,formStateMixin,formCustomMixin],
inheritAttrs:false,
props:props$X,
data:function data(){
return {
localChecked:this[MODEL_PROP_NAME$5]};

},
computed:{
inline:function inline(){
return !this.stacked;
},
groupName:function groupName(){
// Checks/Radios tied to the same model must have the same name,
// especially for ARIA accessibility
return this.name||this.safeId();
},
groupClasses:function groupClasses(){
var inline=this.inline,
size=this.size,
validated=this.validated;
var classes={
'was-validated':validated};


if(this.buttons){
classes=[classes,'btn-group-toggle',_defineProperty({
'btn-group':inline,
'btn-group-vertical':!inline},
"btn-group-".concat(size),size)];
}

return classes;
}},

watch:(_watch$6={},_defineProperty(_watch$6,MODEL_PROP_NAME$5,function(newValue){
if(!looseEqual(newValue,this.localChecked)){
this.localChecked=newValue;
}
}),_defineProperty(_watch$6,"localChecked",function localChecked(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.$emit(MODEL_EVENT_NAME$5,newValue);
}
}),_watch$6),
render:function render(h){
var _this=this;

var isRadioGroup=this.isRadioGroup;
var attrs=pick(this.$attrs,PASS_DOWN_ATTRS);
var optionComponent=isRadioGroup?BFormRadio:BFormCheckbox;
var $inputs=this.formOptions.map(function(option,index){
var key="BV_option_".concat(index);
return h(optionComponent,{
props:{
// Individual radios or checks can be disabled in a group
disabled:option.disabled||false,
id:_this.safeId(key),
value:option.value// We don't need to include these, since the input's will know they are inside here
// form: this.form || null,
// name: this.groupName,
// required: Boolean(this.name && this.required)
},

attrs:attrs,
key:key},
[h('span',{
domProps:htmlOrText(option.html,option.text)})]);

});
return h('div',{
class:[this.groupClasses,'bv-no-focus-ring'],
attrs:_objectSpread2(_objectSpread2({},omit(this.$attrs,PASS_DOWN_ATTRS)),{},{
'aria-invalid':this.computedAriaInvalid,
'aria-required':this.required?'true':null,
id:this.safeId(),
role:isRadioGroup?'radiogroup':'group',
// Add `tabindex="-1"` to allow group to be focused if needed by screen readers
tabindex:'-1'})},

[this.normalizeSlot(SLOT_NAME_FIRST),$inputs,this.normalizeSlot()]);
}});


var _objectSpread2$2;

var props$Y=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$X),{},(_objectSpread2$2={},_defineProperty(_objectSpread2$2,MODEL_PROP_NAME$5,makeProp(PROP_TYPE_ARRAY,[])),_defineProperty(_objectSpread2$2,"switches",makeProp(PROP_TYPE_BOOLEAN,false)),_objectSpread2$2))),NAME_FORM_CHECKBOX_GROUP);// --- Main component ---
// @vue/component

var BFormCheckboxGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_CHECKBOX_GROUP,
// Includes render function
mixins:[formRadioCheckGroupMixin],
provide:function provide(){
return {
bvCheckGroup:this};

},
props:props$Y,
computed:{
isRadioGroup:function isRadioGroup(){
return false;
}}});



var FormCheckboxPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormCheckbox:BFormCheckbox,
BCheckbox:BFormCheckbox,
BCheck:BFormCheckbox,
BFormCheckboxGroup:BFormCheckboxGroup,
BCheckboxGroup:BFormCheckboxGroup,
BCheckGroup:BFormCheckboxGroup}});



// v-b-hover directive

var PROP='__BV_hover_handler__';
var MOUSEENTER='mouseenter';
var MOUSELEAVE='mouseleave';// --- Helper methods ---

var createListener=function createListener(handler){
var listener=function listener(event){
handler(event.type===MOUSEENTER,event);
};

listener.fn=handler;
return listener;
};

var updateListeners=function updateListeners(on,el,listener){
eventOnOff(on,el,MOUSEENTER,listener,EVENT_OPTIONS_NO_CAPTURE);
eventOnOff(on,el,MOUSELEAVE,listener,EVENT_OPTIONS_NO_CAPTURE);
};// --- Directive bind/unbind/update handler ---


var directive=function directive(el,_ref){
var _ref$value=_ref.value,
handler=_ref$value===void 0?null:_ref$value;

if(IS_BROWSER){
var listener=el[PROP];
var hasListener=isFunction(listener);
var handlerChanged=!(hasListener&&listener.fn===handler);

if(hasListener&&handlerChanged){
updateListeners(false,el,listener);
delete el[PROP];
}

if(isFunction(handler)&&handlerChanged){
el[PROP]=createListener(handler);
updateListeners(true,el,el[PROP]);
}
}
};// VBHover directive


var VBHover={
bind:directive,
componentUpdated:directive,
unbind:function unbind(el){
directive(el,{
value:null});

}};


var props$Z=sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$S),props$T),omit(props$z,['disabled'])),omit(props$Q,['autofocus'])),{},{
// When `true`, renders a `btn-group` wrapper and visually hides the label
buttonOnly:makeProp(PROP_TYPE_BOOLEAN,false),
// Applicable in button mode only
buttonVariant:makeProp(PROP_TYPE_STRING,'secondary'),
// This is the value shown in the label
// Defaults back to `value`
formattedValue:makeProp(PROP_TYPE_STRING),
// Value placed in `.sr-only` span inside label when value is present
labelSelected:makeProp(PROP_TYPE_STRING),
lang:makeProp(PROP_TYPE_STRING),
// Extra classes to apply to the `dropdown-menu` div
menuClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
// This is the value placed on the hidden input when no value selected
placeholder:makeProp(PROP_TYPE_STRING),
readonly:makeProp(PROP_TYPE_BOOLEAN,false),
// Tri-state prop: `true`, `false` or `null`
rtl:makeProp(PROP_TYPE_BOOLEAN,null),
value:makeProp(PROP_TYPE_STRING,'')}));
// --- Main component ---
// @vue/component

var BVFormBtnLabelControl=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_BUTTON_LABEL_CONTROL,
directives:{
'b-hover':VBHover},

mixins:[idMixin,formSizeMixin,formStateMixin,dropdownMixin,normalizeSlotMixin],
props:props$Z,
data:function data(){
return {
isHovered:false,
hasFocus:false};

},
computed:{
idButton:function idButton(){
return this.safeId();
},
idLabel:function idLabel(){
return this.safeId('_value_');
},
idMenu:function idMenu(){
return this.safeId('_dialog_');
},
idWrapper:function idWrapper(){
return this.safeId('_outer_');
},
computedDir:function computedDir(){
return this.rtl===true?'rtl':this.rtl===false?'ltr':null;
}},

methods:{
focus:function focus(){
if(!this.disabled){
attemptFocus(this.$refs.toggle);
}
},
blur:function blur(){
if(!this.disabled){
attemptBlur(this.$refs.toggle);
}
},
setFocus:function setFocus(event){
this.hasFocus=event.type==='focus';
},
handleHover:function handleHover(hovered){
this.isHovered=hovered;
}},

render:function render(h){
var _class;

var idButton=this.idButton,
idLabel=this.idLabel,
idMenu=this.idMenu,
idWrapper=this.idWrapper,
disabled=this.disabled,
readonly=this.readonly,
required=this.required,
name=this.name,
state=this.state,
visible=this.visible,
size=this.size,
isHovered=this.isHovered,
hasFocus=this.hasFocus,
labelSelected=this.labelSelected,
buttonVariant=this.buttonVariant,
buttonOnly=this.buttonOnly;
var value=toString$1(this.value)||'';
var invalid=state===false||required&&!value;
var btnScope={
isHovered:isHovered,
hasFocus:hasFocus,
state:state,
opened:visible};

var $button=h('button',{
staticClass:'btn',
class:(_class={},_defineProperty(_class,"btn-".concat(buttonVariant),buttonOnly),_defineProperty(_class,"btn-".concat(size),size),_defineProperty(_class,'h-auto',!buttonOnly),_defineProperty(_class,'dropdown-toggle',buttonOnly),_defineProperty(_class,'dropdown-toggle-no-caret',buttonOnly),_class),
attrs:{
id:idButton,
type:'button',
disabled:disabled,
'aria-haspopup':'dialog',
'aria-expanded':visible?'true':'false',
'aria-invalid':invalid?'true':null,
'aria-required':required?'true':null},

directives:[{
name:'b-hover',
value:this.handleHover}],

on:{
mousedown:this.onMousedown,
click:this.toggle,
keydown:this.toggle,
// Handle ENTER, SPACE and DOWN
'!focus':this.setFocus,
'!blur':this.setFocus},

ref:'toggle'},
[this.hasNormalizedSlot(SLOT_NAME_BUTTON_CONTENT)?this.normalizeSlot(SLOT_NAME_BUTTON_CONTENT,btnScope):
/* istanbul ignore next */
h(BIconChevronDown,{
props:{
scale:1.25}})]);

// Hidden input

var $hidden=h();

if(name&&!disabled){
$hidden=h('input',{
attrs:{
type:'hidden',
name:name||null,
form:this.form||null,
value:value}});


}// Dropdown content


var $menu=h('div',{
staticClass:'dropdown-menu',
class:[this.menuClass,{
show:visible,
'dropdown-menu-right':this.right}],

attrs:{
id:idMenu,
role:'dialog',
tabindex:'-1',
'aria-modal':'false',
'aria-labelledby':idLabel},

on:{
keydown:this.onKeydown// Handle ESC
},

ref:'menu'},
[this.normalizeSlot(SLOT_NAME_DEFAULT,{
opened:visible})]);
// Value label

var $label=h('label',{
class:buttonOnly?'sr-only'// Hidden in button only mode
:['form-control',// Mute the text if showing the placeholder
{
'text-muted':!value},
this.stateClass,this.sizeFormClass],
attrs:{
id:idLabel,
for:idButton,
'aria-invalid':invalid?'true':null,
'aria-required':required?'true':null},

directives:[{
name:'b-hover',
value:this.handleHover}],

on:{
// Disable bubbling of the click event to
// prevent menu from closing and re-opening
'!click':
/* istanbul ignore next */
function click(event){
stopEvent(event,{
preventDefault:false});

}}},

[value?this.formattedValue||value:this.placeholder||'',// Add the selected label for screen readers when a value is provided
value&&labelSelected?h('bdi',{
staticClass:'sr-only'},
labelSelected):'']);// Return the custom form control wrapper

return h('div',{
staticClass:'b-form-btn-label-control dropdown',
class:[this.directionClass,this.boundaryClass,[{
'btn-group':buttonOnly,
'form-control':!buttonOnly,
focus:hasFocus&&!buttonOnly,
show:visible,
'is-valid':state===true,
'is-invalid':state===false},
buttonOnly?null:this.sizeFormClass]],
attrs:{
id:idWrapper,
role:buttonOnly?null:'group',
lang:this.lang||null,
dir:this.computedDir,
'aria-disabled':disabled,
'aria-readonly':readonly&&!disabled,
'aria-labelledby':idLabel,
'aria-invalid':state===false||required&&!value?'true':null,
'aria-required':required?'true':null}},

[$button,$hidden,$menu,$label]);
}});


var _watch$7;

var _makeModelMixin$6=makeModelMixin('value',{
type:PROP_TYPE_DATE_STRING}),

modelMixin$6=_makeModelMixin$6.mixin,
modelProps$6=_makeModelMixin$6.props,
MODEL_PROP_NAME$6=_makeModelMixin$6.prop,
MODEL_EVENT_NAME$6=_makeModelMixin$6.event;// --- Props ---


var calendarProps=omit(props$h,['block','hidden','id','noKeyNav','roleDescription','value','width']);
var formBtnLabelControlProps=omit(props$Z,['formattedValue','id','lang','rtl','value']);
var props$_=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$6),calendarProps),formBtnLabelControlProps),{},{
// Width of the calendar dropdown
calendarWidth:makeProp(PROP_TYPE_STRING,'270px'),
closeButton:makeProp(PROP_TYPE_BOOLEAN,false),
closeButtonVariant:makeProp(PROP_TYPE_STRING,'outline-secondary'),
// Dark mode
dark:makeProp(PROP_TYPE_BOOLEAN,false),
labelCloseButton:makeProp(PROP_TYPE_STRING,'Close'),
labelResetButton:makeProp(PROP_TYPE_STRING,'Reset'),
labelTodayButton:makeProp(PROP_TYPE_STRING,'Select today'),
noCloseOnSelect:makeProp(PROP_TYPE_BOOLEAN,false),
resetButton:makeProp(PROP_TYPE_BOOLEAN,false),
resetButtonVariant:makeProp(PROP_TYPE_STRING,'outline-danger'),
resetValue:makeProp(PROP_TYPE_DATE_STRING),
todayButton:makeProp(PROP_TYPE_BOOLEAN,false),
todayButtonVariant:makeProp(PROP_TYPE_STRING,'outline-primary')})),
NAME_FORM_DATEPICKER);// --- Main component ---
// @vue/component

var BFormDatepicker=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_DATEPICKER,
mixins:[idMixin,modelMixin$6],
props:props$_,
data:function data(){
return {
// We always use `YYYY-MM-DD` value internally
localYMD:formatYMD(this[MODEL_PROP_NAME$6])||'',
// If the popup is open
isVisible:false,
// Context data from BCalendar
localLocale:null,
isRTL:false,
formattedValue:'',
activeYMD:''};

},
computed:{
calendarYM:function calendarYM(){
// Returns the calendar year/month
// Returns the `YYYY-MM` portion of the active calendar date
return this.activeYMD.slice(0,-3);
},
computedLang:function computedLang(){
return (this.localLocale||'').replace(/-u-.*$/i,'')||null;
},
computedResetValue:function computedResetValue(){
return formatYMD(constrainDate(this.resetValue))||'';
}},

watch:(_watch$7={},_defineProperty(_watch$7,MODEL_PROP_NAME$6,function(newValue){
this.localYMD=formatYMD(newValue)||'';
}),_defineProperty(_watch$7,"localYMD",function localYMD(newValue){
// We only update the v-model when the datepicker is open
if(this.isVisible){
this.$emit(MODEL_EVENT_NAME$6,this.valueAsDate?parseYMD(newValue)||null:newValue||'');
}
}),_defineProperty(_watch$7,"calendarYM",function calendarYM(newValue,oldValue){
// Displayed calendar month has changed
// So possibly the calendar height has changed...
// We need to update popper computed position
if(newValue!==oldValue&&oldValue){
try{
this.$refs.control.updatePopper();
}catch(_unused){}
}
}),_watch$7),
methods:{
// Public methods
focus:function focus(){
if(!this.disabled){
attemptFocus(this.$refs.control);
}
},
blur:function blur(){
if(!this.disabled){
attemptBlur(this.$refs.control);
}
},
// Private methods
setAndClose:function setAndClose(ymd){
var _this=this;

this.localYMD=ymd;// Close calendar popup, unless `noCloseOnSelect`

if(!this.noCloseOnSelect){
this.$nextTick(function(){
_this.$refs.control.hide(true);
});
}
},
onSelected:function onSelected(ymd){
var _this2=this;

this.$nextTick(function(){
_this2.setAndClose(ymd);
});
},
onInput:function onInput(ymd){
if(this.localYMD!==ymd){
this.localYMD=ymd;
}
},
onContext:function onContext(ctx){
var activeYMD=ctx.activeYMD,
isRTL=ctx.isRTL,
locale=ctx.locale,
selectedYMD=ctx.selectedYMD,
selectedFormatted=ctx.selectedFormatted;
this.isRTL=isRTL;
this.localLocale=locale;
this.formattedValue=selectedFormatted;
this.localYMD=selectedYMD;
this.activeYMD=activeYMD;// Re-emit the context event

this.$emit(EVENT_NAME_CONTEXT,ctx);
},
onTodayButton:function onTodayButton(){
// Set to today (or min/max if today is out of range)
this.setAndClose(formatYMD(constrainDate(createDate(),this.min,this.max)));
},
onResetButton:function onResetButton(){
this.setAndClose(this.computedResetValue);
},
onCloseButton:function onCloseButton(){
this.$refs.control.hide(true);
},
// Menu handlers
onShow:function onShow(){
this.isVisible=true;
},
onShown:function onShown(){
var _this3=this;

this.$nextTick(function(){
attemptFocus(_this3.$refs.calendar);

_this3.$emit(EVENT_NAME_SHOWN);
});
},
onHidden:function onHidden(){
this.isVisible=false;
this.$emit(EVENT_NAME_HIDDEN);
},
// Render helpers
defaultButtonFn:function defaultButtonFn(_ref){
var isHovered=_ref.isHovered,
hasFocus=_ref.hasFocus;
return this.$createElement(isHovered||hasFocus?BIconCalendarFill:BIconCalendar,{
attrs:{
'aria-hidden':'true'}});


}},

render:function render(h){
var localYMD=this.localYMD,
disabled=this.disabled,
readonly=this.readonly,
dark=this.dark,
$props=this.$props,
$scopedSlots=this.$scopedSlots;
var placeholder=isUndefinedOrNull(this.placeholder)?this.labelNoDateSelected:this.placeholder;// Optional footer buttons

var $footer=[];

if(this.todayButton){
var label=this.labelTodayButton;
$footer.push(h(BButton,{
props:{
disabled:disabled||readonly,
size:'sm',
variant:this.todayButtonVariant},

attrs:{
'aria-label':label||null},

on:{
click:this.onTodayButton}},

label));
}

if(this.resetButton){
var _label=this.labelResetButton;
$footer.push(h(BButton,{
props:{
disabled:disabled||readonly,
size:'sm',
variant:this.resetButtonVariant},

attrs:{
'aria-label':_label||null},

on:{
click:this.onResetButton}},

_label));
}

if(this.closeButton){
var _label2=this.labelCloseButton;
$footer.push(h(BButton,{
props:{
disabled:disabled,
size:'sm',
variant:this.closeButtonVariant},

attrs:{
'aria-label':_label2||null},

on:{
click:this.onCloseButton}},

_label2));
}

if($footer.length>0){
$footer=[h('div',{
staticClass:'b-form-date-controls d-flex flex-wrap',
class:{
'justify-content-between':$footer.length>1,
'justify-content-end':$footer.length<2}},

$footer)];
}

var $calendar=h(BCalendar,{
staticClass:'b-form-date-calendar w-100',
props:_objectSpread2(_objectSpread2({},pluckProps(calendarProps,$props)),{},{
hidden:!this.isVisible,
value:localYMD,
valueAsDate:false,
width:this.calendarWidth}),

on:{
selected:this.onSelected,
input:this.onInput,
context:this.onContext},

scopedSlots:pick($scopedSlots,['nav-prev-decade','nav-prev-year','nav-prev-month','nav-this-month','nav-next-month','nav-next-year','nav-next-decade']),
key:'calendar',
ref:'calendar'},
$footer);
return h(BVFormBtnLabelControl,{
staticClass:'b-form-datepicker',
props:_objectSpread2(_objectSpread2({},pluckProps(formBtnLabelControlProps,$props)),{},{
formattedValue:localYMD?this.formattedValue:'',
id:this.safeId(),
lang:this.computedLang,
menuClass:[{
'bg-dark':dark,
'text-light':dark},
this.menuClass],
placeholder:placeholder,
rtl:this.isRTL,
value:localYMD}),

on:{
show:this.onShow,
shown:this.onShown,
hidden:this.onHidden},

scopedSlots:_defineProperty({},SLOT_NAME_BUTTON_CONTENT,$scopedSlots[SLOT_NAME_BUTTON_CONTENT]||this.defaultButtonFn),
ref:'control'},
[$calendar]);
}});


var FormDatepickerPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormDatepicker:BFormDatepicker,
BDatepicker:BFormDatepicker}});



var _watch$8;

var _makeModelMixin$7=makeModelMixin('value',{
type:[PROP_TYPE_ARRAY,File],
defaultValue:null,
validator:function validator(value){
/* istanbul ignore next */
if(value===''){
warn(VALUE_EMPTY_DEPRECATED_MSG,NAME_FORM_FILE);
return true;
}

return isUndefinedOrNull(value)||isValidValue(value);
}}),

modelMixin$7=_makeModelMixin$7.mixin,
modelProps$7=_makeModelMixin$7.props,
MODEL_PROP_NAME$7=_makeModelMixin$7.prop,
MODEL_EVENT_NAME$7=_makeModelMixin$7.event;

var VALUE_EMPTY_DEPRECATED_MSG='Setting "value"/"v-model" to an empty string for reset is deprecated. Set to "null" instead.';// --- Helper methods ---

var isValidValue=function isValidValue(value){
return isFile(value)||isArray(value)&&value.every(function(v){
return isValidValue(v);
});
};// Helper method to "safely" get the entry from a data-transfer item

/* istanbul ignore next: not supported in JSDOM */


var getDataTransferItemEntry=function getDataTransferItemEntry(item){
return isFunction(item.getAsEntry)?item.getAsEntry():isFunction(item.webkitGetAsEntry)?item.webkitGetAsEntry():null;
};// Drop handler function to get all files

/* istanbul ignore next: not supported in JSDOM */


var getAllFileEntries=function getAllFileEntries(dataTransferItemList){
var traverseDirectories=arguments.length>1&&arguments[1]!==undefined?arguments[1]:true;
return Promise.all(from(dataTransferItemList).filter(function(item){
return item.kind==='file';
}).map(function(item){
var entry=getDataTransferItemEntry(item);

if(entry){
if(entry.isDirectory&&traverseDirectories){
return getAllFileEntriesInDirectory(entry.createReader(),"".concat(entry.name,"/"));
}else if(entry.isFile){
return new Promise(function(resolve){
entry.file(function(file){
file.$path='';
resolve(file);
});
});
}
}

return null;
}).filter(identity));
};// Get all the file entries (recursive) in a directory

/* istanbul ignore next: not supported in JSDOM */


var getAllFileEntriesInDirectory=function getAllFileEntriesInDirectory(directoryReader){
var path=arguments.length>1&&arguments[1]!==undefined?arguments[1]:'';
return new Promise(function(resolve){
var entryPromises=[];

var readDirectoryEntries=function readDirectoryEntries(){
directoryReader.readEntries(function(entries){
if(entries.length===0){
resolve(Promise.all(entryPromises).then(function(entries){
return flatten(entries);
}));
}else {
entryPromises.push(Promise.all(entries.map(function(entry){
if(entry){
if(entry.isDirectory){
return getAllFileEntriesInDirectory(entry.createReader(),"".concat(path).concat(entry.name,"/"));
}else if(entry.isFile){
return new Promise(function(resolve){
entry.file(function(file){
file.$path="".concat(path).concat(file.name);
resolve(file);
});
});
}
}

return null;
}).filter(identity)));
readDirectoryEntries();
}
});
};

readDirectoryEntries();
});
};// --- Props ---


var props$$=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$7),props$Q),props$R),props$T),props$S),{},{
accept:makeProp(PROP_TYPE_STRING,''),
browseText:makeProp(PROP_TYPE_STRING,'Browse'),
// Instruct input to capture from camera
capture:makeProp(PROP_TYPE_BOOLEAN,false),
directory:makeProp(PROP_TYPE_BOOLEAN,false),
dropPlaceholder:makeProp(PROP_TYPE_STRING,'Drop files here'),
fileNameFormatter:makeProp(PROP_TYPE_FUNCTION),
multiple:makeProp(PROP_TYPE_BOOLEAN,false),
noDrop:makeProp(PROP_TYPE_BOOLEAN,false),
noDropPlaceholder:makeProp(PROP_TYPE_STRING,'Not allowed'),
// TODO:
//   Should we deprecate this and only support flat file structures?
//   Nested file structures are only supported when files are dropped
//   A Chromium "bug" prevents `webkitEntries` from being populated
//   on the file input's `change` event and is marked as "WontFix"
//   Mozilla implemented the behavior the same way as Chromium
//   See: https://bugs.chromium.org/p/chromium/issues/detail?id=138987
//   See: https://bugzilla.mozilla.org/show_bug.cgi?id=1326031
noTraverse:makeProp(PROP_TYPE_BOOLEAN,false),
placeholder:makeProp(PROP_TYPE_STRING,'No file chosen')})),
NAME_FORM_FILE);// --- Main component ---
// @vue/component

var BFormFile=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_FILE,
mixins:[attrsMixin,idMixin,modelMixin$7,normalizeSlotMixin,formControlMixin,formStateMixin,formCustomMixin,normalizeSlotMixin],
inheritAttrs:false,
props:props$$,
data:function data(){
return {
files:[],
dragging:false,
// IE 11 doesn't respect setting `event.dataTransfer.dropEffect`,
// so we handle it ourselves as well
// https://stackoverflow.com/a/46915971/2744776
dropAllowed:!this.noDrop,
hasFocus:false};

},
computed:{
// Convert `accept` to an array of `[{ RegExpr, isMime }, ...]`
computedAccept:function computedAccept(){
var accept=this.accept;
accept=(accept||'').trim().split(/[,\s]+/).filter(identity);// Allow any file type/extension

if(accept.length===0){
return null;
}

return accept.map(function(extOrType){
var prop='name';
var startMatch='^';
var endMatch='$';

if(RX_EXTENSION.test(extOrType)){
// File extension /\.ext$/
startMatch='';
}else {
// MIME type /^mime\/.+$/ or /^mime\/type$/
prop='type';

if(RX_STAR.test(extOrType)){
endMatch='.+$';// Remove trailing `*`

extOrType=extOrType.slice(0,-1);
}
}// Escape all RegExp special chars


extOrType=escapeRegExp(extOrType);
var rx=new RegExp("".concat(startMatch).concat(extOrType).concat(endMatch));
return {
rx:rx,
prop:prop};

});
},
computedCapture:function computedCapture(){
var capture=this.capture;
return capture===true||capture===''?true:capture||null;
},
computedAttrs:function computedAttrs(){
var name=this.name,
disabled=this.disabled,
required=this.required,
form=this.form,
computedCapture=this.computedCapture,
accept=this.accept,
multiple=this.multiple,
directory=this.directory;
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
type:'file',
id:this.safeId(),
name:name,
disabled:disabled,
required:required,
form:form||null,
capture:computedCapture,
accept:accept||null,
multiple:multiple,
directory:directory,
webkitdirectory:directory,
'aria-required':required?'true':null});

},
computedFileNameFormatter:function computedFileNameFormatter(){
var fileNameFormatter=this.fileNameFormatter;
return hasPropFunction(fileNameFormatter)?fileNameFormatter:this.defaultFileNameFormatter;
},
clonedFiles:function clonedFiles(){
return cloneDeep(this.files);
},
flattenedFiles:function flattenedFiles(){
return flattenDeep(this.files);
},
fileNames:function fileNames(){
return this.flattenedFiles.map(function(file){
return file.name;
});
},
labelContent:function labelContent(){
// Draging active

/* istanbul ignore next: used by drag/drop which can't be tested easily */
if(this.dragging&&!this.noDrop){
return(// TODO: Add additional scope with file count, and other not-allowed reasons
this.normalizeSlot(SLOT_NAME_DROP_PLACEHOLDER,{
allowed:this.dropAllowed})||(
this.dropAllowed?this.dropPlaceholder:this.$createElement('span',{
staticClass:'text-danger'},
this.noDropPlaceholder)));

}// No file chosen


if(this.files.length===0){
return this.normalizeSlot(SLOT_NAME_PLACEHOLDER)||this.placeholder;
}

var flattenedFiles=this.flattenedFiles,
clonedFiles=this.clonedFiles,
fileNames=this.fileNames,
computedFileNameFormatter=this.computedFileNameFormatter;// There is a slot for formatting the files/names

if(this.hasNormalizedSlot(SLOT_NAME_FILE_NAME)){
return this.normalizeSlot(SLOT_NAME_FILE_NAME,{
files:flattenedFiles,
filesTraversed:clonedFiles,
names:fileNames});

}

return computedFileNameFormatter(flattenedFiles,clonedFiles,fileNames);
}},

watch:(_watch$8={},_defineProperty(_watch$8,MODEL_PROP_NAME$7,function(newValue){
if(!newValue||isArray(newValue)&&newValue.length===0){
this.reset();
}
}),_defineProperty(_watch$8,"files",function files(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
var multiple=this.multiple,
noTraverse=this.noTraverse;
var files=!multiple||noTraverse?flattenDeep(newValue):newValue;
this.$emit(MODEL_EVENT_NAME$7,multiple?files:files[0]||null);
}
}),_watch$8),
created:function created(){
// Create private non-reactive props
this.$_form=null;
},
mounted:function mounted(){
// Listen for form reset events, to reset the file input
var $form=closest('form',this.$el);

if($form){
eventOn($form,'reset',this.reset,EVENT_OPTIONS_PASSIVE);
this.$_form=$form;
}
},
beforeDestroy:function beforeDestroy(){
var $form=this.$_form;

if($form){
eventOff($form,'reset',this.reset,EVENT_OPTIONS_PASSIVE);
}
},
methods:{
isFileValid:function isFileValid(file){
if(!file){
return false;
}

var accept=this.computedAccept;
return accept?accept.some(function(a){
return a.rx.test(file[a.prop]);
}):true;
},
isFilesArrayValid:function isFilesArrayValid(files){
var _this=this;

return isArray(files)?files.every(function(file){
return _this.isFileValid(file);
}):this.isFileValid(files);
},
defaultFileNameFormatter:function defaultFileNameFormatter(flattenedFiles,clonedFiles,fileNames){
return fileNames.join(', ');
},
setFiles:function setFiles(files){
// Reset the dragging flags
this.dropAllowed=!this.noDrop;
this.dragging=false;// Set the selected files

this.files=this.multiple?this.directory?files:flattenDeep(files):flattenDeep(files).slice(0,1);
},

/* istanbul ignore next: used by Drag/Drop */
setInputFiles:function setInputFiles(files){
// Try an set the file input files array so that `required`
// constraint works for dropped files (will fail in IE11 though)
// To be used only when dropping files
try{
// Firefox < 62 workaround exploiting https://bugzilla.mozilla.org/show_bug.cgi?id=1422655
var dataTransfer=new ClipboardEvent('').clipboardData||new DataTransfer();// Add flattened files to temp `dataTransfer` object to get a true `FileList` array

flattenDeep(cloneDeep(files)).forEach(function(file){
// Make sure to remove the custom `$path` attribute
delete file.$path;
dataTransfer.items.add(file);
});
this.$refs.input.files=dataTransfer.files;
}catch(_unused){}
},
reset:function reset(){
// IE 11 doesn't support setting `$input.value` to `''` or `null`
// So we use this little extra hack to reset the value, just in case
// This also appears to work on modern browsers as well
// Wrapped in try in case IE 11 or mobile Safari crap out
try{
var $input=this.$refs.input;
$input.value='';
$input.type='';
$input.type='file';
}catch(_unused2){}

this.files=[];
},
handleFiles:function handleFiles(files){
var isDrop=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;

if(isDrop){
// When dropped, make sure to filter files with the internal `accept` logic
var filteredFiles=files.filter(this.isFilesArrayValid);// Only update files when we have any after filtering

if(filteredFiles.length>0){
this.setFiles(filteredFiles);// Try an set the file input's files array so that `required`
// constraint works for dropped files (will fail in IE 11 though)

this.setInputFiles(filteredFiles);
}
}else {
// We always update the files from the `change` event
this.setFiles(files);
}
},
focusHandler:function focusHandler(event){
// Bootstrap v4 doesn't have focus styling for custom file input
// Firefox has a `[type=file]:focus ~ sibling` selector issue,
// so we add a `focus` class to get around these bugs
if(this.plain||event.type==='focusout'){
this.hasFocus=false;
}else {
// Add focus styling for custom file input
this.hasFocus=true;
}
},
onChange:function onChange(event){
var _this2=this;

var type=event.type,
target=event.target,
_event$dataTransfer=event.dataTransfer,
dataTransfer=_event$dataTransfer===void 0?{}:_event$dataTransfer;
var isDrop=type==='drop';// Always emit original event

this.$emit(EVENT_NAME_CHANGE,event);
var items=from(dataTransfer.items||[]);

if(HAS_PROMISE_SUPPORT&&items.length>0&&!isNull(getDataTransferItemEntry(items[0]))){
// Drop handling for modern browsers
// Supports nested directory structures in `directory` mode

/* istanbul ignore next: not supported in JSDOM */
getAllFileEntries(items,this.directory).then(function(files){
return _this2.handleFiles(files,isDrop);
});
}else {
// Standard file input handling (native file input change event),
// or fallback drop mode (IE 11 / Opera) which don't support `directory` mode
var files=from(target.files||dataTransfer.files||[]).map(function(file){
// Add custom `$path` property to each file (to be consistent with drop mode)
file.$path=file.webkitRelativePath||'';
return file;
});
this.handleFiles(files,isDrop);
}
},
onDragenter:function onDragenter(event){
stopEvent(event);
this.dragging=true;
var _event$dataTransfer2=event.dataTransfer,
dataTransfer=_event$dataTransfer2===void 0?{}:_event$dataTransfer2;// Early exit when the input or dropping is disabled

if(this.noDrop||this.disabled||!this.dropAllowed){
// Show deny feedback

/* istanbul ignore next: not supported in JSDOM */
dataTransfer.dropEffect='none';
this.dropAllowed=false;
return;
}
/* istanbul ignore next: not supported in JSDOM */


dataTransfer.dropEffect='copy';
},
// Note this event fires repeatedly while the mouse is over the dropzone at
// intervals in the milliseconds, so avoid doing much processing in here
onDragover:function onDragover(event){
stopEvent(event);
this.dragging=true;
var _event$dataTransfer3=event.dataTransfer,
dataTransfer=_event$dataTransfer3===void 0?{}:_event$dataTransfer3;// Early exit when the input or dropping is disabled

if(this.noDrop||this.disabled||!this.dropAllowed){
// Show deny feedback

/* istanbul ignore next: not supported in JSDOM */
dataTransfer.dropEffect='none';
this.dropAllowed=false;
return;
}
/* istanbul ignore next: not supported in JSDOM */


dataTransfer.dropEffect='copy';
},
onDragleave:function onDragleave(event){
var _this3=this;

stopEvent(event);
this.$nextTick(function(){
_this3.dragging=false;// Reset `dropAllowed` to default

_this3.dropAllowed=!_this3.noDrop;
});
},
// Triggered by a file drop onto drop target
onDrop:function onDrop(event){
var _this4=this;

stopEvent(event);
this.dragging=false;// Early exit when the input or dropping is disabled

if(this.noDrop||this.disabled||!this.dropAllowed){
this.$nextTick(function(){
// Reset `dropAllowed` to default
_this4.dropAllowed=!_this4.noDrop;
});
return;
}

this.onChange(event);
}},

render:function render(h){
var custom=this.custom,
plain=this.plain,
size=this.size,
dragging=this.dragging,
stateClass=this.stateClass,
bvAttrs=this.bvAttrs;// Form Input

var $input=h('input',{
class:[{
'form-control-file':plain,
'custom-file-input':custom,
focus:custom&&this.hasFocus},
stateClass],
// With IE 11, the input gets in the "way" of the drop events,
// so we move it out of the way by putting it behind the label
// Bootstrap v4 has it in front
style:custom?{
zIndex:-5}:
{},
attrs:this.computedAttrs,
on:{
change:this.onChange,
focusin:this.focusHandler,
focusout:this.focusHandler,
reset:this.reset},

ref:'input'});


if(plain){
return $input;
}// Overlay label


var $label=h('label',{
staticClass:'custom-file-label',
class:{
dragging:dragging},

attrs:{
for:this.safeId(),
// This goes away in Bootstrap v5
'data-browse':this.browseText||null}},

[h('span',{
staticClass:'d-block form-file-text',
// `pointer-events: none` is used to make sure
// the drag events fire only on the label
style:{
pointerEvents:'none'}},

[this.labelContent])]);// Return rendered custom file input

return h('div',{
staticClass:'custom-file b-form-file',
class:[_defineProperty({},"b-custom-control-".concat(size),size),stateClass,bvAttrs.class],
style:bvAttrs.style,
attrs:{
id:this.safeId('_BV_file_outer_')},

on:{
dragenter:this.onDragenter,
dragover:this.onDragover,
dragleave:this.onDragleave,
drop:this.onDrop}},

[$input,$label]);
}});


var FormFilePlugin=/*#__PURE__*/pluginFactory({
components:{
BFormFile:BFormFile,
BFile:BFormFile}});



var escapeChar=function escapeChar(value){
return '\\'+value;
};// The `cssEscape()` util is based on this `CSS.escape()` polyfill:
// https://github.com/mathiasbynens/CSS.escape


var cssEscape=function cssEscape(value){
value=toString$1(value);
var length=value.length;
var firstCharCode=value.charCodeAt(0);
return value.split('').reduce(function(result,char,index){
var charCode=value.charCodeAt(index);// If the character is NULL (U+0000), use (U+FFFD) as replacement

if(charCode===0x0000){
return result+"\uFFFD";
}// If the character ...


if(// ... is U+007F OR
charCode===0x007f||// ... is in the range [\1-\1F] (U+0001 to U+001F) OR ...
charCode>=0x0001&&charCode<=0x001f||// ... is the first character and is in the range [0-9] (U+0030 to U+0039) OR ...
index===0&&charCode>=0x0030&&charCode<=0x0039||// ... is the second character and is in the range [0-9] (U+0030 to U+0039)
// and the first character is a `-` (U+002D) ...
index===1&&charCode>=0x0030&&charCode<=0x0039&&firstCharCode===0x002d){
// ... https://drafts.csswg.org/cssom/#escape-a-character-as-code-point
return result+escapeChar("".concat(charCode.toString(16)," "));
}// If the character ...


if(// ... is the first character AND ...
index===0&&// ... is a `-` (U+002D) AND ...
charCode===0x002d&&// ... there is no second character ...
length===1){
// ... use the escaped character
return result+escapeChar(char);
}// If the character ...


if(// ... is greater than or equal to U+0080 OR ...
charCode>=0x0080||// ... is `-` (U+002D) OR ...
charCode===0x002d||// ... is `_` (U+005F) OR ...
charCode===0x005f||// ... is in the range [0-9] (U+0030 to U+0039) OR ...
charCode>=0x0030&&charCode<=0x0039||// ... is in the range [A-Z] (U+0041 to U+005A) OR ...
charCode>=0x0041&&charCode<=0x005a||// ... is in the range [a-z] (U+0061 to U+007A) ...
charCode>=0x0061&&charCode<=0x007a){
// ... use the character itself
return result+char;
}// Otherwise use the escaped character
// See: https://drafts.csswg.org/cssom/#escape-a-character


return result+escapeChar(char);
},'');
};

var ALIGN_SELF_VALUES=['auto','start','end','center','baseline','stretch'];// --- Helper methods ---
// Compute a breakpoint class name

var computeBreakpoint=function computeBreakpoint(type,breakpoint,value){
var className=type;

if(isUndefinedOrNull(value)||value===false){
return undefined;
}

if(breakpoint){
className+="-".concat(breakpoint);
}// Handling the boolean style prop when accepting `[Boolean, String, Number]`
// means Vue will not convert `<b-col sm></b-col>` to `sm: true` for us
// Since the default is `false`, '' indicates the prop's presence


if(type==='col'&&(value===''||value===true)){
// .col-md
return lowerCase(className);
}// .order-md-6


className+="-".concat(value);
return lowerCase(className);
};// Memoized function for better performance on generating class names


var computeBreakpointClass=memoize(computeBreakpoint);// Cached copy of the breakpoint prop names

var breakpointPropMap=create(null);// --- Props ---
// Prop generator for lazy generation of props

var generateProps=function generateProps(){
// Grab the breakpoints from the cached config (exclude the '' (xs) breakpoint)
var breakpoints=getBreakpointsUpCached().filter(identity);// i.e. 'col-sm', 'col-md-6', 'col-lg-auto', ...

var breakpointCol=breakpoints.reduce(function(props,breakpoint){
props[breakpoint]=makeProp(PROP_TYPE_BOOLEAN_NUMBER_STRING);
return props;
},create(null));// i.e. 'offset-md-1', 'offset-lg-12', ...

var breakpointOffset=breakpoints.reduce(function(props,breakpoint){
props[suffixPropName(breakpoint,'offset')]=makeProp(PROP_TYPE_NUMBER_STRING);
return props;
},create(null));// i.e. 'order-md-1', 'order-lg-12', ...

var breakpointOrder=breakpoints.reduce(function(props,breakpoint){
props[suffixPropName(breakpoint,'order')]=makeProp(PROP_TYPE_NUMBER_STRING);
return props;
},create(null));// For loop doesn't need to check `.hasOwnProperty()`
// when using an object created from `null`

breakpointPropMap=assign(create(null),{
col:keys(breakpointCol),
offset:keys(breakpointOffset),
order:keys(breakpointOrder)});
// Return the generated props

return makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},breakpointCol),breakpointOffset),breakpointOrder),{},{
// Flex alignment
alignSelf:makeProp(PROP_TYPE_STRING,null,function(value){
return arrayIncludes(ALIGN_SELF_VALUES,value);
}),
// Generic flexbox 'col' (xs)
col:makeProp(PROP_TYPE_BOOLEAN,false),
// i.e. 'col-1', 'col-2', 'col-auto', ...
cols:makeProp(PROP_TYPE_NUMBER_STRING),
offset:makeProp(PROP_TYPE_NUMBER_STRING),
order:makeProp(PROP_TYPE_NUMBER_STRING),
tag:makeProp(PROP_TYPE_STRING,'div')})),
NAME_COL);
};// --- Main component ---
// We do not use Vue.extend here as that would evaluate the props
// immediately, which we do not want to happen
// @vue/component

var BCol={
name:NAME_COL,
functional:true,

get props(){
// Allow props to be lazy evaled on first access and
// then they become a non-getter afterwards.
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Functions/get#Smart_self-overwriting_lazy_getters
delete this.props;// eslint-disable-next-line no-return-assign

return this.props=generateProps();
},

render:function render(h,_ref){
var _classList$push;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var cols=props.cols,
offset=props.offset,
order=props.order,
alignSelf=props.alignSelf;
var classList=[];// Loop through `col`, `offset`, `order` breakpoint props

for(var type in breakpointPropMap){
// Returns colSm, offset, offsetSm, orderMd, etc.
var _keys=breakpointPropMap[type];

for(var i=0;i<_keys.length;i++){
// computeBreakpoint(col, colSm => Sm, value=[String, Number, Boolean])
var c=computeBreakpointClass(type,_keys[i].replace(type,''),props[_keys[i]]);// If a class is returned, push it onto the array.

if(c){
classList.push(c);
}
}
}

var hasColClasses=classList.some(function(className){
return RX_COL_CLASS.test(className);
});
classList.push((_classList$push={
// Default to .col if no other col-{bp}-* classes generated nor `cols` specified.
col:props.col||!hasColClasses&&!cols},
_defineProperty(_classList$push,"col-".concat(cols),cols),_defineProperty(_classList$push,"offset-".concat(offset),offset),_defineProperty(_classList$push,"order-".concat(order),order),_defineProperty(_classList$push,"align-self-".concat(alignSelf),alignSelf),_classList$push));
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:classList}),
children);
}};


var INPUTS=['input','select','textarea'];// Selector for finding first input in the form group

var INPUT_SELECTOR=INPUTS.map(function(v){
return "".concat(v,":not([disabled])");
}).join();// A list of interactive elements (tag names) inside `<b-form-group>`'s legend

var LEGEND_INTERACTIVE_ELEMENTS=[].concat(INPUTS,['a','button','label']);// --- Props ---
// Prop generator for lazy generation of props

var generateProps$1=function generateProps(){
return makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$T),getBreakpointsUpCached().reduce(function(props,breakpoint){
// i.e. 'content-cols', 'content-cols-sm', 'content-cols-md', ...
props[suffixPropName(breakpoint,'contentCols')]=makeProp(PROP_TYPE_BOOLEAN_NUMBER_STRING);// i.e. 'label-align', 'label-align-sm', 'label-align-md', ...

props[suffixPropName(breakpoint,'labelAlign')]=makeProp(PROP_TYPE_STRING);// i.e. 'label-cols', 'label-cols-sm', 'label-cols-md', ...

props[suffixPropName(breakpoint,'labelCols')]=makeProp(PROP_TYPE_BOOLEAN_NUMBER_STRING);
return props;
},create(null))),{},{
description:makeProp(PROP_TYPE_STRING),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
feedbackAriaLive:makeProp(PROP_TYPE_STRING,'assertive'),
invalidFeedback:makeProp(PROP_TYPE_STRING),
label:makeProp(PROP_TYPE_STRING),
labelClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
labelFor:makeProp(PROP_TYPE_STRING),
labelSize:makeProp(PROP_TYPE_STRING),
labelSrOnly:makeProp(PROP_TYPE_BOOLEAN,false),
tooltip:makeProp(PROP_TYPE_BOOLEAN,false),
validFeedback:makeProp(PROP_TYPE_STRING),
validated:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_FORM_GROUP);
};// --- Main component ---
// We do not use `Vue.extend()` here as that would evaluate the props
// immediately, which we do not want to happen
// @vue/component

var BFormGroup={
name:NAME_FORM_GROUP,
mixins:[idMixin,formStateMixin,normalizeSlotMixin],

get props(){
// Allow props to be lazy evaled on first access and
// then they become a non-getter afterwards
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Functions/get#Smart_self-overwriting_lazy_getters
delete this.props;// eslint-disable-next-line no-return-assign

return this.props=generateProps$1();
},

data:function data(){
return {
ariaDescribedby:null};

},
computed:{
contentColProps:function contentColProps(){
return this.getColProps(this.$props,'content');
},
labelAlignClasses:function labelAlignClasses(){
return this.getAlignClasses(this.$props,'label');
},
labelColProps:function labelColProps(){
return this.getColProps(this.$props,'label');
},
isHorizontal:function isHorizontal(){
// Determine if the form group will be rendered horizontal
// based on the existence of 'content-col' or 'label-col' props
return keys(this.contentColProps).length>0||keys(this.labelColProps).length>0;
}},

watch:{
ariaDescribedby:function ariaDescribedby(newValue,oldValue){
if(newValue!==oldValue){
this.updateAriaDescribedby(newValue,oldValue);
}
}},

mounted:function mounted(){
var _this=this;

this.$nextTick(function(){
// Set `aria-describedby` on the input specified by `labelFor`
// We do this in a `$nextTick()` to ensure the children have finished rendering
_this.updateAriaDescribedby(_this.ariaDescribedby);
});
},
methods:{
getAlignClasses:function getAlignClasses(props,prefix){
return getBreakpointsUpCached().reduce(function(result,breakpoint){
var propValue=props[suffixPropName(breakpoint,"".concat(prefix,"Align"))]||null;

if(propValue){
result.push(['text',breakpoint,propValue].filter(identity).join('-'));
}

return result;
},[]);
},
getColProps:function getColProps(props,prefix){
return getBreakpointsUpCached().reduce(function(result,breakpoint){
var propValue=props[suffixPropName(breakpoint,"".concat(prefix,"Cols"))];// Handle case where the prop's value is an empty string,
// which represents `true`

propValue=propValue===''?true:propValue||false;

if(!isBoolean(propValue)&&propValue!=='auto'){
// Convert to column size to number
propValue=toInteger(propValue,0);// Ensure column size is greater than `0`

propValue=propValue>0?propValue:false;
}// Add the prop to the list of props to give to `<b-col>`
// If breakpoint is '' (`${prefix}Cols` is `true`), then we use
// the 'col' prop to make equal width at 'xs'


if(propValue){
result[breakpoint||(isBoolean(propValue)?'col':'cols')]=propValue;
}

return result;
},{});
},
// Sets the `aria-describedby` attribute on the input if `labelFor` is set
// Optionally accepts a string of IDs to remove as the second parameter
// Preserves any `aria-describedby` value(s) user may have on input
updateAriaDescribedby:function updateAriaDescribedby(newValue,oldValue){
var labelFor=this.labelFor;

if(IS_BROWSER&&labelFor){
// We need to escape `labelFor` since it can be user-provided
var $input=select("#".concat(cssEscape(labelFor)),this.$refs.content);

if($input){
var attr='aria-describedby';
var newIds=(newValue||'').split(RX_SPACE_SPLIT);
var oldIds=(oldValue||'').split(RX_SPACE_SPLIT);// Update ID list, preserving any original IDs
// and ensuring the ID's are unique

var ids=(getAttr($input,attr)||'').split(RX_SPACE_SPLIT).filter(function(id){
return !arrayIncludes(oldIds,id);
}).concat(newIds).filter(function(id,index,ids){
return ids.indexOf(id)===index;
}).filter(identity).join(' ').trim();

if(ids){
setAttr($input,attr,ids);
}else {
removeAttr($input,attr);
}
}
}
},
onLegendClick:function onLegendClick(event){
// Don't do anything if `labelFor` is set

/* istanbul ignore next: clicking a label will focus the input, so no need to test */
if(this.labelFor){
return;
}

var target=event.target;
var tagName=target?target.tagName:'';// If clicked an interactive element inside legend,
// we just let the default happen

/* istanbul ignore next */

if(LEGEND_INTERACTIVE_ELEMENTS.indexOf(tagName)!==-1){
return;
}// If only a single input, focus it, emulating label behaviour


var inputs=selectAll(INPUT_SELECTOR,this.$refs.content).filter(isVisible);

if(inputs.length===1){
attemptFocus(inputs[0]);
}
}},

render:function render(h){
var state=this.computedState,
feedbackAriaLive=this.feedbackAriaLive,
isHorizontal=this.isHorizontal,
labelFor=this.labelFor,
normalizeSlot=this.normalizeSlot,
safeId=this.safeId,
tooltip=this.tooltip;
var id=safeId();
var isFieldset=!labelFor;
var $label=h();
var labelContent=normalizeSlot(SLOT_NAME_LABEL)||this.label;
var labelId=labelContent?safeId('_BV_label_'):null;

if(labelContent||isHorizontal){
var labelSize=this.labelSize,
labelColProps=this.labelColProps;
var labelTag=isFieldset?'legend':'label';

if(this.labelSrOnly){
if(labelContent){
$label=h(labelTag,{
class:'sr-only',
attrs:{
id:labelId,
for:labelFor||null}},

[labelContent]);
}

$label=h(isHorizontal?BCol:'div',{
props:isHorizontal?labelColProps:{}},
[$label]);
}else {
$label=h(isHorizontal?BCol:labelTag,{
on:isFieldset?{
click:this.onLegendClick}:
{},
props:isHorizontal?_objectSpread2(_objectSpread2({},labelColProps),{},{
tag:labelTag}):
{},
attrs:{
id:labelId,
for:labelFor||null,
// We add a `tabindex` to legend so that screen readers
// will properly read the `aria-labelledby` in IE
tabindex:isFieldset?'-1':null},

class:[// Hide the focus ring on the legend
isFieldset?'bv-no-focus-ring':'',// When horizontal or if a legend is rendered, add 'col-form-label' class
// for correct sizing as Bootstrap has inconsistent font styling for
// legend in non-horizontal form groups
// See: https://github.com/twbs/bootstrap/issues/27805
isHorizontal||isFieldset?'col-form-label':'',// Emulate label padding top of `0` on legend when not horizontal
!isHorizontal&&isFieldset?'pt-0':'',// If not horizontal and not a legend, we add 'd-block' class to label
// so that label-align works
!isHorizontal&&!isFieldset?'d-block':'',labelSize?"col-form-label-".concat(labelSize):'',this.labelAlignClasses,this.labelClass]},
[labelContent]);
}
}

var $invalidFeedback=h();
var invalidFeedbackContent=normalizeSlot(SLOT_NAME_INVALID_FEEDBACK)||this.invalidFeedback;
var invalidFeedbackId=invalidFeedbackContent?safeId('_BV_feedback_invalid_'):null;

if(invalidFeedbackContent){
$invalidFeedback=h(BFormInvalidFeedback,{
props:{
ariaLive:feedbackAriaLive,
id:invalidFeedbackId,
role:feedbackAriaLive?'alert':null,
// If state is explicitly `false`, always show the feedback
state:state,
tooltip:tooltip},

attrs:{
tabindex:invalidFeedbackContent?'-1':null}},

[invalidFeedbackContent]);
}

var $validFeedback=h();
var validFeedbackContent=normalizeSlot(SLOT_NAME_VALID_FEEDBACK)||this.validFeedback;
var validFeedbackId=validFeedbackContent?safeId('_BV_feedback_valid_'):null;

if(validFeedbackContent){
$validFeedback=h(BFormValidFeedback,{
props:{
ariaLive:feedbackAriaLive,
id:validFeedbackId,
role:feedbackAriaLive?'alert':null,
// If state is explicitly `true`, always show the feedback
state:state,
tooltip:tooltip},

attrs:{
tabindex:validFeedbackContent?'-1':null}},

[validFeedbackContent]);
}

var $description=h();
var descriptionContent=normalizeSlot(SLOT_NAME_DESCRIPTION)||this.description;
var descriptionId=descriptionContent?safeId('_BV_description_'):null;

if(descriptionContent){
$description=h(BFormText,{
attrs:{
id:descriptionId,
tabindex:'-1'}},

[descriptionContent]);
}// Update `ariaDescribedby`
// Screen readers will read out any content linked to by `aria-describedby`
// even if the content is hidden with `display: none;`, hence we only include
// feedback IDs if the form group's state is explicitly valid or invalid


var ariaDescribedby=this.ariaDescribedby=[descriptionId,state===false?invalidFeedbackId:null,state===true?validFeedbackId:null].filter(identity).join(' ')||null;
var $content=h(isHorizontal?BCol:'div',{
props:isHorizontal?this.contentColProps:{},
ref:'content'},
[normalizeSlot(SLOT_NAME_DEFAULT,{
ariaDescribedby:ariaDescribedby,
descriptionId:descriptionId,
id:id,
labelId:labelId})||
h(),$invalidFeedback,$validFeedback,$description]);// Return it wrapped in a form group
// Note: Fieldsets do not support adding `row` or `form-row` directly
// to them due to browser specific render issues, so we move the `form-row`
// to an inner wrapper div when horizontal and using a fieldset

return h(isFieldset?'fieldset':isHorizontal?BFormRow:'div',{
staticClass:'form-group',
class:[{
'was-validated':this.validated},
this.stateClass],
attrs:{
id:id,
disabled:isFieldset?this.disabled:null,
role:isFieldset?null:'group',
'aria-invalid':this.computedAriaInvalid,
// Only apply `aria-labelledby` if we are a horizontal fieldset
// as the legend is no longer a direct child of fieldset
'aria-labelledby':isFieldset&&isHorizontal?labelId:null}},

isHorizontal&&isFieldset?[h(BFormRow,[$label,$content])]:[$label,$content]);
}};


var FormGroupPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormGroup:BFormGroup,
BFormFieldset:BFormGroup}});



var formSelectionMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
computed:{
selectionStart:{
// Expose selectionStart for formatters, etc
cache:false,

/* istanbul ignore next */
get:function get(){
return this.$refs.input.selectionStart;
},

/* istanbul ignore next */
set:function set(val){
this.$refs.input.selectionStart=val;
}},

selectionEnd:{
// Expose selectionEnd for formatters, etc
cache:false,

/* istanbul ignore next */
get:function get(){
return this.$refs.input.selectionEnd;
},

/* istanbul ignore next */
set:function set(val){
this.$refs.input.selectionEnd=val;
}},

selectionDirection:{
// Expose selectionDirection for formatters, etc
cache:false,

/* istanbul ignore next */
get:function get(){
return this.$refs.input.selectionDirection;
},

/* istanbul ignore next */
set:function set(val){
this.$refs.input.selectionDirection=val;
}}},


methods:{
/* istanbul ignore next */
select:function select(){
var _this$$refs$input;

// For external handler that may want a select() method
(_this$$refs$input=this.$refs.input).select.apply(_this$$refs$input,arguments);
},

/* istanbul ignore next */
setSelectionRange:function setSelectionRange(){
var _this$$refs$input2;

// For external handler that may want a setSelectionRange(a,b,c) method
(_this$$refs$input2=this.$refs.input).setSelectionRange.apply(_this$$refs$input2,arguments);
},

/* istanbul ignore next */
setRangeText:function setRangeText(){
var _this$$refs$input3;

// For external handler that may want a setRangeText(a,b,c) method
(_this$$refs$input3=this.$refs.input).setRangeText.apply(_this$$refs$input3,arguments);
}}});



var _makeModelMixin$8=makeModelMixin('value',{
type:PROP_TYPE_NUMBER_STRING,
defaultValue:'',
event:EVENT_NAME_UPDATE}),

modelMixin$8=_makeModelMixin$8.mixin,
modelProps$8=_makeModelMixin$8.props,
MODEL_PROP_NAME$8=_makeModelMixin$8.prop,
MODEL_EVENT_NAME$8=_makeModelMixin$8.event;

var props$10=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},modelProps$8),{},{
ariaInvalid:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
autocomplete:makeProp(PROP_TYPE_STRING),
// Debounce timeout (in ms). Not applicable with `lazy` prop
debounce:makeProp(PROP_TYPE_NUMBER_STRING,0),
formatter:makeProp(PROP_TYPE_FUNCTION),
// Only update the `v-model` on blur/change events
lazy:makeProp(PROP_TYPE_BOOLEAN,false),
lazyFormatter:makeProp(PROP_TYPE_BOOLEAN,false),
number:makeProp(PROP_TYPE_BOOLEAN,false),
placeholder:makeProp(PROP_TYPE_STRING),
plaintext:makeProp(PROP_TYPE_BOOLEAN,false),
readonly:makeProp(PROP_TYPE_BOOLEAN,false),
trim:makeProp(PROP_TYPE_BOOLEAN,false)})),
'formTextControls');// --- Mixin ---
// @vue/component

var formTextMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[modelMixin$8],
props:props$10,
data:function data(){
var value=this[MODEL_PROP_NAME$8];
return {
localValue:toString$1(value),
vModelValue:this.modifyValue(value)};

},
computed:{
computedClass:function computedClass(){
var plaintext=this.plaintext,
type=this.type;
var isRange=type==='range';
var isColor=type==='color';
return [{
// Range input needs class `custom-range`
'custom-range':isRange,
// `plaintext` not supported by `type="range"` or `type="color"`
'form-control-plaintext':plaintext&&!isRange&&!isColor,
// `form-control` not used by `type="range"` or `plaintext`
// Always used by `type="color"`
'form-control':isColor||!plaintext&&!isRange},
this.sizeFormClass,this.stateClass];
},
computedDebounce:function computedDebounce(){
// Ensure we have a positive number equal to or greater than 0
return mathMax(toInteger(this.debounce,0),0);
},
hasFormatter:function hasFormatter(){
return hasPropFunction(this.formatter);
}},

watch:_defineProperty({},MODEL_PROP_NAME$8,function(newValue){
var stringifyValue=toString$1(newValue);
var modifiedValue=this.modifyValue(newValue);

if(stringifyValue!==this.localValue||modifiedValue!==this.vModelValue){
// Clear any pending debounce timeout, as we are overwriting the user input
this.clearDebounce();// Update the local values

this.localValue=stringifyValue;
this.vModelValue=modifiedValue;
}
}),
created:function created(){
// Create private non-reactive props
this.$_inputDebounceTimer=null;
},
mounted:function mounted(){
// Set up destroy handler
this.$on(HOOK_EVENT_NAME_BEFORE_DESTROY,this.clearDebounce);
},
beforeDestroy:function beforeDestroy(){
this.clearDebounce();
},
methods:{
clearDebounce:function clearDebounce(){
clearTimeout(this.$_inputDebounceTimer);
this.$_inputDebounceTimer=null;
},
formatValue:function formatValue(value,event){
var force=arguments.length>2&&arguments[2]!==undefined?arguments[2]:false;
value=toString$1(value);

if(this.hasFormatter&&(!this.lazyFormatter||force)){
value=this.formatter(value,event);
}

return value;
},
modifyValue:function modifyValue(value){
value=toString$1(value);// Emulate `.trim` modifier behaviour

if(this.trim){
value=value.trim();
}// Emulate `.number` modifier behaviour


if(this.number){
value=toFloat(value,value);
}

return value;
},
updateValue:function updateValue(value){
var _this=this;

var force=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;
var lazy=this.lazy;

if(lazy&&!force){
return;
}// Make sure to always clear the debounce when `updateValue()`
// is called, even when the v-model hasn't changed


this.clearDebounce();// Define the shared update logic in a method to be able to use
// it for immediate and debounced value changes

var doUpdate=function doUpdate(){
value=_this.modifyValue(value);

if(value!==_this.vModelValue){
_this.vModelValue=value;

_this.$emit(MODEL_EVENT_NAME$8,value);
}else if(_this.hasFormatter){
// When the `vModelValue` hasn't changed but the actual input value
// is out of sync, make sure to change it to the given one
// Usually caused by browser autocomplete and how it triggers the
// change or input event, or depending on the formatter function
// https://github.com/bootstrap-vue/bootstrap-vue/issues/2657
// https://github.com/bootstrap-vue/bootstrap-vue/issues/3498

/* istanbul ignore next: hard to test */
var $input=_this.$refs.input;
/* istanbul ignore if: hard to test out of sync value */

if($input&&value!==$input.value){
$input.value=value;
}
}
};// Only debounce the value update when a value greater than `0`
// is set and we are not in lazy mode or this is a forced update


var debounce=this.computedDebounce;

if(debounce>0&&!lazy&&!force){
this.$_inputDebounceTimer=setTimeout(doUpdate,debounce);
}else {
// Immediately update the v-model
doUpdate();
}
},
onInput:function onInput(event){
// `event.target.composing` is set by Vue
// https://github.com/vuejs/vue/blob/dev/src/platforms/web/runtime/directives/model.js
// TODO: Is this needed now with the latest Vue?

/* istanbul ignore if: hard to test composition events */
if(event.target.composing){
return;
}

var value=event.target.value;
var formattedValue=this.formatValue(value,event);// Exit when the `formatter` function strictly returned `false`
// or prevented the input event

/* istanbul ignore next */

if(formattedValue===false||event.defaultPrevented){
stopEvent(event,{
propagation:false});

return;
}

this.localValue=formattedValue;
this.updateValue(formattedValue);
this.$emit(EVENT_NAME_INPUT,formattedValue);
},
onChange:function onChange(event){
var value=event.target.value;
var formattedValue=this.formatValue(value,event);// Exit when the `formatter` function strictly returned `false`
// or prevented the input event

/* istanbul ignore next */

if(formattedValue===false||event.defaultPrevented){
stopEvent(event,{
propagation:false});

return;
}

this.localValue=formattedValue;
this.updateValue(formattedValue,true);
this.$emit(EVENT_NAME_CHANGE,formattedValue);
},
onBlur:function onBlur(event){
// Apply the `localValue` on blur to prevent cursor jumps
// on mobile browsers (e.g. caused by autocomplete)
var value=event.target.value;
var formattedValue=this.formatValue(value,event,true);

if(formattedValue!==false){
// We need to use the modified value here to apply the
// `.trim` and `.number` modifiers properly
this.localValue=toString$1(this.modifyValue(formattedValue));// We pass the formatted value here since the `updateValue` method
// handles the modifiers itself

this.updateValue(formattedValue,true);
}// Emit native blur event


this.$emit(EVENT_NAME_BLUR,event);
},
focus:function focus(){
// For external handler that may want a focus method
if(!this.disabled){
attemptFocus(this.$el);
}
},
blur:function blur(){
// For external handler that may want a blur method
if(!this.disabled){
attemptBlur(this.$el);
}
}}});



var formValidityMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
computed:{
validity:{
// Expose validity property
cache:false,

/* istanbul ignore next */
get:function get(){
return this.$refs.input.validity;
}},

validationMessage:{
// Expose validationMessage property
cache:false,

/* istanbul ignore next */
get:function get(){
return this.$refs.input.validationMessage;
}},

willValidate:{
// Expose willValidate property
cache:false,

/* istanbul ignore next */
get:function get(){
return this.$refs.input.willValidate;
}}},


methods:{
/* istanbul ignore next */
setCustomValidity:function setCustomValidity(){
var _this$$refs$input;

// For external handler that may want a setCustomValidity(...) method
return (_this$$refs$input=this.$refs.input).setCustomValidity.apply(_this$$refs$input,arguments);
},

/* istanbul ignore next */
checkValidity:function checkValidity(){
var _this$$refs$input2;

// For external handler that may want a checkValidity(...) method
return (_this$$refs$input2=this.$refs.input).checkValidity.apply(_this$$refs$input2,arguments);
},

/* istanbul ignore next */
reportValidity:function reportValidity(){
var _this$$refs$input3;

// For external handler that may want a reportValidity(...) method
return (_this$$refs$input3=this.$refs.input).reportValidity.apply(_this$$refs$input3,arguments);
}}});



// Valid supported input types

var TYPES$1=['text','password','email','number','url','tel','search','range','color','date','time','datetime','datetime-local','month','week'];// --- Props ---

var props$11=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$Q),props$S),props$T),props$10),{},{
list:makeProp(PROP_TYPE_STRING),
max:makeProp(PROP_TYPE_NUMBER_STRING),
min:makeProp(PROP_TYPE_NUMBER_STRING),
// Disable mousewheel to prevent wheel from changing values (i.e. number/date)
noWheel:makeProp(PROP_TYPE_BOOLEAN,false),
step:makeProp(PROP_TYPE_NUMBER_STRING),
type:makeProp(PROP_TYPE_STRING,'text',function(type){
return arrayIncludes(TYPES$1,type);
})})),
NAME_FORM_INPUT);// --- Main component ---
// @vue/component

var BFormInput=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_INPUT,
// Mixin order is important!
mixins:[listenersMixin,idMixin,formControlMixin,formSizeMixin,formStateMixin,formTextMixin,formSelectionMixin,formValidityMixin],
props:props$11,
computed:{
localType:function localType(){
// We only allow certain types
var type=this.type;
return arrayIncludes(TYPES$1,type)?type:'text';
},
computedAttrs:function computedAttrs(){
var type=this.localType,
name=this.name,
form=this.form,
disabled=this.disabled,
placeholder=this.placeholder,
required=this.required,
min=this.min,
max=this.max,
step=this.step;
return {
id:this.safeId(),
name:name,
form:form,
type:type,
disabled:disabled,
placeholder:placeholder,
required:required,
autocomplete:this.autocomplete||null,
readonly:this.readonly||this.plaintext,
min:min,
max:max,
step:step,
list:type!=='password'?this.list:null,
'aria-required':required?'true':null,
'aria-invalid':this.computedAriaInvalid};

},
computedListeners:function computedListeners(){
return _objectSpread2(_objectSpread2({},this.bvListeners),{},{
input:this.onInput,
change:this.onChange,
blur:this.onBlur});

}},

watch:{
noWheel:function noWheel(newValue){
this.setWheelStopper(newValue);
}},

mounted:function mounted(){
this.setWheelStopper(this.noWheel);
},

/* istanbul ignore next */
deactivated:function deactivated(){
// Turn off listeners when keep-alive component deactivated

/* istanbul ignore next */
this.setWheelStopper(false);
},

/* istanbul ignore next */
activated:function activated(){
// Turn on listeners (if no-wheel) when keep-alive component activated

/* istanbul ignore next */
this.setWheelStopper(this.noWheel);
},
beforeDestroy:function beforeDestroy(){
/* istanbul ignore next */
this.setWheelStopper(false);
},
methods:{
setWheelStopper:function setWheelStopper(on){
var input=this.$el;// We use native events, so that we don't interfere with propagation

eventOnOff(on,input,'focus',this.onWheelFocus);
eventOnOff(on,input,'blur',this.onWheelBlur);

if(!on){
eventOff(document,'wheel',this.stopWheel);
}
},
onWheelFocus:function onWheelFocus(){
eventOn(document,'wheel',this.stopWheel);
},
onWheelBlur:function onWheelBlur(){
eventOff(document,'wheel',this.stopWheel);
},
stopWheel:function stopWheel(event){
stopEvent(event,{
propagation:false});

attemptBlur(this.$el);
}},

render:function render(h){
return h('input',{
class:this.computedClass,
attrs:this.computedAttrs,
domProps:{
value:this.localValue},

on:this.computedListeners,
ref:'input'});

}});


var FormInputPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormInput:BFormInput,
BInput:BFormInput}});



var props$12=makePropsConfigurable(props$X,NAME_FORM_RADIO_GROUP);// --- Main component ---
// @vue/component

var BFormRadioGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_RADIO_GROUP,
mixins:[formRadioCheckGroupMixin],
provide:function provide(){
return {
bvRadioGroup:this};

},
props:props$12,
computed:{
isRadioGroup:function isRadioGroup(){
return true;
}}});



var FormRadioPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormRadio:BFormRadio,
BRadio:BFormRadio,
BFormRadioGroup:BFormRadioGroup,
BRadioGroup:BFormRadioGroup}});



var _watch$9;

var _makeModelMixin$9=makeModelMixin('value',{
type:PROP_TYPE_NUMBER_STRING,
event:EVENT_NAME_CHANGE}),

modelMixin$9=_makeModelMixin$9.mixin,
modelProps$9=_makeModelMixin$9.props,
MODEL_PROP_NAME$9=_makeModelMixin$9.prop,
MODEL_EVENT_NAME$9=_makeModelMixin$9.event;

var MIN_STARS=3;
var DEFAULT_STARS=5;// --- Helper methods ---

var computeStars=function computeStars(stars){
return mathMax(MIN_STARS,toInteger(stars,DEFAULT_STARS));
};

var clampValue=function clampValue(value,min,max){
return mathMax(mathMin(value,max),min);
};// --- Helper components ---
// @vue/component


var BVFormRatingStar=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_RATING_STAR,
mixins:[normalizeSlotMixin],
props:{
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
// If parent is focused
focused:makeProp(PROP_TYPE_BOOLEAN,false),
hasClear:makeProp(PROP_TYPE_BOOLEAN,false),
rating:makeProp(PROP_TYPE_NUMBER,0),
readonly:makeProp(PROP_TYPE_BOOLEAN,false),
star:makeProp(PROP_TYPE_NUMBER,0),
variant:makeProp(PROP_TYPE_STRING)},

methods:{
onClick:function onClick(event){
if(!this.disabled&&!this.readonly){
stopEvent(event,{
propagation:false});

this.$emit(EVENT_NAME_SELECTED,this.star);
}
}},

render:function render(h){
var rating=this.rating,
star=this.star,
focused=this.focused,
hasClear=this.hasClear,
variant=this.variant,
disabled=this.disabled,
readonly=this.readonly;
var minStar=hasClear?0:1;
var type=rating>=star?'full':rating>=star-0.5?'half':'empty';
var slotScope={
variant:variant,
disabled:disabled,
readonly:readonly};

return h('span',{
staticClass:'b-rating-star',
class:{
// When not hovered, we use this class to focus the current (or first) star
focused:focused&&rating===star||!toInteger(rating)&&star===minStar,
// We add type classes to we can handle RTL styling
'b-rating-star-empty':type==='empty',
'b-rating-star-half':type==='half',
'b-rating-star-full':type==='full'},

attrs:{
tabindex:!disabled&&!readonly?'-1':null},

on:{
click:this.onClick}},

[h('span',{
staticClass:'b-rating-icon'},
[this.normalizeSlot(type,slotScope)])]);
}});
// --- Props ---

var props$13=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$9),omit(props$Q,['required','autofocus'])),props$S),{},{
// CSS color string (overrides variant)
color:makeProp(PROP_TYPE_STRING),
iconClear:makeProp(PROP_TYPE_STRING,'x'),
iconEmpty:makeProp(PROP_TYPE_STRING,'star'),
iconFull:makeProp(PROP_TYPE_STRING,'star-fill'),
iconHalf:makeProp(PROP_TYPE_STRING,'star-half'),
inline:makeProp(PROP_TYPE_BOOLEAN,false),
// Locale for the formatted value (if shown)
// Defaults to the browser locale. Falls back to `en`
locale:makeProp(PROP_TYPE_ARRAY_STRING),
noBorder:makeProp(PROP_TYPE_BOOLEAN,false),
precision:makeProp(PROP_TYPE_NUMBER_STRING),
readonly:makeProp(PROP_TYPE_BOOLEAN,false),
showClear:makeProp(PROP_TYPE_BOOLEAN,false),
showValue:makeProp(PROP_TYPE_BOOLEAN,false),
showValueMax:makeProp(PROP_TYPE_BOOLEAN,false),
stars:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_STARS,function(value){
return toInteger(value)>=MIN_STARS;
}),
variant:makeProp(PROP_TYPE_STRING)})),
NAME_FORM_RATING);// --- Main component ---
// @vue/component

var BFormRating=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_RATING,
components:{
BIconStar:BIconStar,
BIconStarHalf:BIconStarHalf,
BIconStarFill:BIconStarFill,
BIconX:BIconX},

mixins:[idMixin,modelMixin$9,formSizeMixin],
props:props$13,
data:function data(){
var value=toFloat(this[MODEL_PROP_NAME$9],null);
var stars=computeStars(this.stars);
return {
localValue:isNull(value)?null:clampValue(value,0,stars),
hasFocus:false};

},
computed:{
computedStars:function computedStars(){
return computeStars(this.stars);
},
computedRating:function computedRating(){
var value=toFloat(this.localValue,0);
var precision=toInteger(this.precision,3);// We clamp the value between `0` and stars

return clampValue(toFloat(value.toFixed(precision)),0,this.computedStars);
},
computedLocale:function computedLocale(){
var locales=concat(this.locale).filter(identity);
var nf=new Intl.NumberFormat(locales);
return nf.resolvedOptions().locale;
},
isInteractive:function isInteractive(){
return !this.disabled&&!this.readonly;
},
isRTL:function isRTL(){
return isLocaleRTL(this.computedLocale);
},
formattedRating:function formattedRating(){
var precision=toInteger(this.precision);
var showValueMax=this.showValueMax;
var locale=this.computedLocale;
var formatOptions={
notation:'standard',
minimumFractionDigits:isNaN(precision)?0:precision,
maximumFractionDigits:isNaN(precision)?3:precision};

var stars=this.computedStars.toLocaleString(locale);
var value=this.localValue;
value=isNull(value)?showValueMax?'-':'':value.toLocaleString(locale,formatOptions);
return showValueMax?"".concat(value,"/").concat(stars):value;
}},

watch:(_watch$9={},_defineProperty(_watch$9,MODEL_PROP_NAME$9,function(newValue,oldValue){
if(newValue!==oldValue){
var value=toFloat(newValue,null);
this.localValue=isNull(value)?null:clampValue(value,0,this.computedStars);
}
}),_defineProperty(_watch$9,"localValue",function localValue(newValue,oldValue){
if(newValue!==oldValue&&newValue!==(this.value||0)){
this.$emit(MODEL_EVENT_NAME$9,newValue||null);
}
}),_defineProperty(_watch$9,"disabled",function disabled(newValue){
if(newValue){
this.hasFocus=false;
this.blur();
}
}),_watch$9),
methods:{
// --- Public methods ---
focus:function focus(){
if(!this.disabled){
attemptFocus(this.$el);
}
},
blur:function blur(){
if(!this.disabled){
attemptBlur(this.$el);
}
},
// --- Private methods ---
onKeydown:function onKeydown(event){
var keyCode=event.keyCode;

if(this.isInteractive&&arrayIncludes([CODE_LEFT,CODE_DOWN,CODE_RIGHT,CODE_UP],keyCode)){
stopEvent(event,{
propagation:false});

var value=toInteger(this.localValue,0);
var min=this.showClear?0:1;
var stars=this.computedStars;// In RTL mode, LEFT/RIGHT are swapped

var amountRtl=this.isRTL?-1:1;

if(keyCode===CODE_LEFT){
this.localValue=clampValue(value-amountRtl,min,stars)||null;
}else if(keyCode===CODE_RIGHT){
this.localValue=clampValue(value+amountRtl,min,stars);
}else if(keyCode===CODE_DOWN){
this.localValue=clampValue(value-1,min,stars)||null;
}else if(keyCode===CODE_UP){
this.localValue=clampValue(value+1,min,stars);
}
}
},
onSelected:function onSelected(value){
if(this.isInteractive){
this.localValue=value;
}
},
onFocus:function onFocus(event){
this.hasFocus=!this.isInteractive?false:event.type==='focus';
},
// --- Render methods ---
renderIcon:function renderIcon(icon){
return this.$createElement(BIcon,{
props:{
icon:icon,
variant:this.disabled||this.color?null:this.variant||null}});


},
iconEmptyFn:function iconEmptyFn(){
return this.renderIcon(this.iconEmpty);
},
iconHalfFn:function iconHalfFn(){
return this.renderIcon(this.iconHalf);
},
iconFullFn:function iconFullFn(){
return this.renderIcon(this.iconFull);
},
iconClearFn:function iconClearFn(){
return this.$createElement(BIcon,{
props:{
icon:this.iconClear}});


}},

render:function render(h){
var _this=this;

var disabled=this.disabled,
readonly=this.readonly,
name=this.name,
form=this.form,
inline=this.inline,
variant=this.variant,
color=this.color,
noBorder=this.noBorder,
hasFocus=this.hasFocus,
computedRating=this.computedRating,
computedStars=this.computedStars,
formattedRating=this.formattedRating,
showClear=this.showClear,
isRTL=this.isRTL,
isInteractive=this.isInteractive,
$scopedSlots=this.$scopedSlots;
var $content=[];

if(showClear&&!disabled&&!readonly){
var $icon=h('span',{
staticClass:'b-rating-icon'},
[($scopedSlots[SLOT_NAME_ICON_CLEAR]||this.iconClearFn)()]);
$content.push(h('span',{
staticClass:'b-rating-star b-rating-star-clear flex-grow-1',
class:{
focused:hasFocus&&computedRating===0},

attrs:{
tabindex:isInteractive?'-1':null},

on:{
click:function click(){
return _this.onSelected(null);
}},

key:'clear'},
[$icon]));
}

for(var index=0;index<computedStars;index++){
var value=index+1;
$content.push(h(BVFormRatingStar,{
staticClass:'flex-grow-1',
style:color&&!disabled?{
color:color}:
{},
props:{
rating:computedRating,
star:value,
variant:disabled?null:variant||null,
disabled:disabled,
readonly:readonly,
focused:hasFocus,
hasClear:showClear},

on:{
selected:this.onSelected},

scopedSlots:{
empty:$scopedSlots[SLOT_NAME_ICON_EMPTY]||this.iconEmptyFn,
half:$scopedSlots[SLOT_NAME_ICON_HALF]||this.iconHalfFn,
full:$scopedSlots[SLOT_NAME_ICON_FULL]||this.iconFullFn},

key:index}));

}

if(name){
$content.push(h('input',{
attrs:{
type:'hidden',
value:isNull(this.localValue)?'':computedRating,
name:name,
form:form||null},

key:'hidden'}));

}

if(this.showValue){
$content.push(h('b',{
staticClass:'b-rating-value flex-grow-1',
attrs:{
'aria-hidden':'true'},

key:'value'},
toString$1(formattedRating)));
}

return h('output',{
staticClass:'b-rating form-control align-items-center',
class:[{
'd-inline-flex':inline,
'd-flex':!inline,
'border-0':noBorder,
disabled:disabled,
readonly:!disabled&&readonly},
this.sizeFormClass],
attrs:{
id:this.safeId(),
dir:isRTL?'rtl':'ltr',
tabindex:disabled?null:'0',
disabled:disabled,
role:'slider',
'aria-disabled':disabled?'true':null,
'aria-readonly':!disabled&&readonly?'true':null,
'aria-live':'off',
'aria-valuemin':showClear?'0':'1',
'aria-valuemax':toString$1(computedStars),
'aria-valuenow':computedRating?toString$1(computedRating):null},

on:{
keydown:this.onKeydown,
focus:this.onFocus,
blur:this.onFocus}},

$content);
}});


var FormRatingPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormRating:BFormRating,
BRating:BFormRating}});



var _makeModelMixin$a=makeModelMixin('value'),
mixin=_makeModelMixin$a.mixin,
props$14=_makeModelMixin$a.props,
prop=_makeModelMixin$a.prop,
event=_makeModelMixin$a.event;

var props$15=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$K),{},{
labelField:makeProp(PROP_TYPE_STRING,'label'),
optionsField:makeProp(PROP_TYPE_STRING,'options')})),
'formOptions');// --- Mixin ---
// @vue/component

var optionsMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[formOptionsMixin],
props:props$15,
methods:{
normalizeOption:function normalizeOption(option){
var key=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;

// When the option is an object, normalize it
if(isPlainObject(option)){
var value=get(option,this.valueField);
var text=get(option,this.textField);
var options=get(option,this.optionsField,null);// When it has options, create an `<optgroup>` object

if(!isNull(options)){
return {
label:String(get(option,this.labelField)||text),
options:this.normalizeOptions(options)};

}// Otherwise create an `<option>` object


return {
value:isUndefined(value)?key||text:value,
text:String(isUndefined(text)?key:text),
html:get(option,this.htmlField),
disabled:Boolean(get(option,this.disabledField))};

}// Otherwise create an `<option>` object from the given value


return {
value:key||option,
text:String(option),
disabled:false};

}}});



var props$16=makePropsConfigurable({
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
value:makeProp(PROP_TYPE_ANY,undefined,true)// Required
},
NAME_FORM_SELECT_OPTION);// --- Main component ---
// @vue/component

var BFormSelectOption=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_SELECT_OPTION,
functional:true,
props:props$16,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var value=props.value,
disabled=props.disabled;
return h('option',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
attrs:{
disabled:disabled},

domProps:{
value:value}}),

children);
}});


var props$17=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$K),{},{
label:makeProp(PROP_TYPE_STRING,undefined,true)// Required
})),
NAME_FORM_SELECT_OPTION_GROUP);// --- Main component ---
// @vue/component

var BFormSelectOptionGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_SELECT_OPTION_GROUP,
mixins:[normalizeSlotMixin,formOptionsMixin],
props:props$17,
render:function render(h){
var label=this.label;
var $options=this.formOptions.map(function(option,index){
var value=option.value,
text=option.text,
html=option.html,
disabled=option.disabled;
return h(BFormSelectOption,{
attrs:{
value:value,
disabled:disabled},

domProps:htmlOrText(html,text),
key:"option_".concat(index)});

});
return h('optgroup',{
attrs:{
label:label}},

[this.normalizeSlot(SLOT_NAME_FIRST),$options,this.normalizeSlot()]);
}});


var props$18=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$14),props$Q),props$R),props$S),props$T),{},{
ariaInvalid:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
multiple:makeProp(PROP_TYPE_BOOLEAN,false),
// Browsers default size to `0`, which shows 4 rows in most browsers in multiple mode
// Size of `1` can bork out Firefox
selectSize:makeProp(PROP_TYPE_NUMBER,0)})),
NAME_FORM_SELECT);// --- Main component ---
// @vue/component

var BFormSelect=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_SELECT,
mixins:[idMixin,mixin,formControlMixin,formSizeMixin,formStateMixin,formCustomMixin,optionsMixin,normalizeSlotMixin],
props:props$18,
data:function data(){
return {
localValue:this[prop]};

},
computed:{
computedSelectSize:function computedSelectSize(){
// Custom selects with a size of zero causes the arrows to be hidden,
// so dont render the size attribute in this case
return !this.plain&&this.selectSize===0?null:this.selectSize;
},
inputClass:function inputClass(){
return [this.plain?'form-control':'custom-select',this.size&&this.plain?"form-control-".concat(this.size):null,this.size&&!this.plain?"custom-select-".concat(this.size):null,this.stateClass];
}},

watch:{
value:function value(newValue){
this.localValue=newValue;
},
localValue:function localValue(){
this.$emit(event,this.localValue);
}},

methods:{
focus:function focus(){
attemptFocus(this.$refs.input);
},
blur:function blur(){
attemptBlur(this.$refs.input);
},
onChange:function onChange(event){
var _this=this;

var target=event.target;
var selectedValue=from(target.options).filter(function(o){
return o.selected;
}).map(function(o){
return '_value'in o?o._value:o.value;
});
this.localValue=target.multiple?selectedValue:selectedValue[0];
this.$nextTick(function(){
_this.$emit(EVENT_NAME_CHANGE,_this.localValue);
});
}},

render:function render(h){
var name=this.name,
disabled=this.disabled,
required=this.required,
size=this.computedSelectSize,
value=this.localValue;
var $options=this.formOptions.map(function(option,index){
var value=option.value,
label=option.label,
options=option.options,
disabled=option.disabled;
var key="option_".concat(index);
return isArray(options)?h(BFormSelectOptionGroup,{
props:{
label:label,
options:options},

key:key}):
h(BFormSelectOption,{
props:{
value:value,
disabled:disabled},

domProps:htmlOrText(option.html,option.text),
key:key});

});
return h('select',{
class:this.inputClass,
attrs:{
id:this.safeId(),
name:name,
form:this.form||null,
multiple:this.multiple||null,
size:size,
disabled:disabled,
required:required,
'aria-required':required?'true':null,
'aria-invalid':this.computedAriaInvalid},

on:{
change:this.onChange},

directives:[{
name:'model',
value:value}],

ref:'input'},
[this.normalizeSlot(SLOT_NAME_FIRST),$options,this.normalizeSlot()]);
}});


var FormSelectPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormSelect:BFormSelect,
BFormSelectOption:BFormSelectOption,
BFormSelectOptionGroup:BFormSelectOptionGroup,
BSelect:BFormSelect,
BSelectOption:BFormSelectOption,
BSelectOptionGroup:BFormSelectOptionGroup}});



var _watch$a;

var _makeModelMixin$b=makeModelMixin('value',{
// Should this really be String, to match native number inputs?
type:PROP_TYPE_BOOLEAN_NUMBER}),

modelMixin$a=_makeModelMixin$b.mixin,
modelProps$a=_makeModelMixin$b.props,
MODEL_PROP_NAME$a=_makeModelMixin$b.prop,
MODEL_EVENT_NAME$a=_makeModelMixin$b.event;// Default for spin button range and step


var DEFAULT_MIN=1;
var DEFAULT_MAX=100;
var DEFAULT_STEP=1;// Delay before auto-repeat in ms

var DEFAULT_REPEAT_DELAY=500;// Repeat interval in ms

var DEFAULT_REPEAT_INTERVAL=100;// Repeat rate increased after number of repeats

var DEFAULT_REPEAT_THRESHOLD=10;// Repeat speed multiplier (step multiplier, must be an integer)

var DEFAULT_REPEAT_MULTIPLIER=4;
var KEY_CODES=[CODE_UP,CODE_DOWN,CODE_HOME,CODE_END,CODE_PAGEUP,CODE_PAGEDOWN];// --- Props ---

var props$19=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$a),omit(props$Q,['required','autofocus'])),props$S),props$T),{},{
ariaControls:makeProp(PROP_TYPE_STRING),
ariaLabel:makeProp(PROP_TYPE_STRING),
formatterFn:makeProp(PROP_TYPE_FUNCTION),
inline:makeProp(PROP_TYPE_BOOLEAN,false),
labelDecrement:makeProp(PROP_TYPE_STRING,'Decrement'),
labelIncrement:makeProp(PROP_TYPE_STRING,'Increment'),
locale:makeProp(PROP_TYPE_ARRAY_STRING),
max:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_MAX),
min:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_MIN),
placeholder:makeProp(PROP_TYPE_STRING),
readonly:makeProp(PROP_TYPE_BOOLEAN,false),
repeatDelay:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_REPEAT_DELAY),
repeatInterval:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_REPEAT_INTERVAL),
repeatStepMultiplier:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_REPEAT_MULTIPLIER),
repeatThreshold:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_REPEAT_THRESHOLD),
step:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_STEP),
vertical:makeProp(PROP_TYPE_BOOLEAN,false),
wrap:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_FORM_SPINBUTTON);// --- Main Component ---
// @vue/component

var BFormSpinbutton=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_SPINBUTTON,
// Mixin order is important!
mixins:[attrsMixin,idMixin,modelMixin$a,formSizeMixin,formStateMixin,normalizeSlotMixin],
inheritAttrs:false,
props:props$19,
data:function data(){
return {
localValue:toFloat(this[MODEL_PROP_NAME$a],null),
hasFocus:false};

},
computed:{
spinId:function spinId(){
return this.safeId();
},
computedInline:function computedInline(){
return this.inline&&!this.vertical;
},
computedReadonly:function computedReadonly(){
return this.readonly&&!this.disabled;
},
computedRequired:function computedRequired(){
return this.required&&!this.computedReadonly&&!this.disabled;
},
computedStep:function computedStep(){
return toFloat(this.step,DEFAULT_STEP);
},
computedMin:function computedMin(){
return toFloat(this.min,DEFAULT_MIN);
},
computedMax:function computedMax(){
// We round down to the nearest maximum step value
var max=toFloat(this.max,DEFAULT_MAX);
var step=this.computedStep;
var min=this.computedMin;
return mathFloor((max-min)/step)*step+min;
},
computedDelay:function computedDelay(){
var delay=toInteger(this.repeatDelay,0);
return delay>0?delay:DEFAULT_REPEAT_DELAY;
},
computedInterval:function computedInterval(){
var interval=toInteger(this.repeatInterval,0);
return interval>0?interval:DEFAULT_REPEAT_INTERVAL;
},
computedThreshold:function computedThreshold(){
return mathMax(toInteger(this.repeatThreshold,DEFAULT_REPEAT_THRESHOLD),1);
},
computedStepMultiplier:function computedStepMultiplier(){
return mathMax(toInteger(this.repeatStepMultiplier,DEFAULT_REPEAT_MULTIPLIER),1);
},
computedPrecision:function computedPrecision(){
// Quick and dirty way to get the number of decimals
var step=this.computedStep;
return mathFloor(step)===step?0:(step.toString().split('.')[1]||'').length;
},
computedMultiplier:function computedMultiplier(){
return mathPow(10,this.computedPrecision||0);
},
valueAsFixed:function valueAsFixed(){
var value=this.localValue;
return isNull(value)?'':value.toFixed(this.computedPrecision);
},
computedLocale:function computedLocale(){
var locales=concat(this.locale).filter(identity);
var nf=new Intl.NumberFormat(locales);
return nf.resolvedOptions().locale;
},
computedRTL:function computedRTL(){
return isLocaleRTL(this.computedLocale);
},
defaultFormatter:function defaultFormatter(){
// Returns and `Intl.NumberFormat` formatter method reference
var precision=this.computedPrecision;
var nf=new Intl.NumberFormat(this.computedLocale,{
style:'decimal',
useGrouping:false,
minimumIntegerDigits:1,
minimumFractionDigits:precision,
maximumFractionDigits:precision,
notation:'standard'});
// Return the format method reference

return nf.format;
},
computedFormatter:function computedFormatter(){
var formatterFn=this.formatterFn;
return hasPropFunction(formatterFn)?formatterFn:this.defaultFormatter;
},
computedAttrs:function computedAttrs(){
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
role:'group',
lang:this.computedLocale,
tabindex:this.disabled?null:'-1',
title:this.ariaLabel});

},
computedSpinAttrs:function computedSpinAttrs(){
var spinId=this.spinId,
value=this.localValue,
required=this.computedRequired,
disabled=this.disabled,
state=this.state,
computedFormatter=this.computedFormatter;
var hasValue=!isNull(value);
return _objectSpread2(_objectSpread2({
dir:this.computedRTL?'rtl':'ltr'},
this.bvAttrs),{},{
id:spinId,
role:'spinbutton',
tabindex:disabled?null:'0',
'aria-live':'off',
'aria-label':this.ariaLabel||null,
'aria-controls':this.ariaControls||null,
// TODO: May want to check if the value is in range
'aria-invalid':state===false||!hasValue&&required?'true':null,
'aria-required':required?'true':null,
// These attrs are required for role spinbutton
'aria-valuemin':toString$1(this.computedMin),
'aria-valuemax':toString$1(this.computedMax),
// These should be `null` if the value is out of range
// They must also be non-existent attrs if the value is out of range or `null`
'aria-valuenow':hasValue?value:null,
'aria-valuetext':hasValue?computedFormatter(value):null});

}},

watch:(_watch$a={},_defineProperty(_watch$a,MODEL_PROP_NAME$a,function(value){
this.localValue=toFloat(value,null);
}),_defineProperty(_watch$a,"localValue",function localValue(value){
this.$emit(MODEL_EVENT_NAME$a,value);
}),_defineProperty(_watch$a,"disabled",function disabled(_disabled){
if(_disabled){
this.clearRepeat();
}
}),_defineProperty(_watch$a,"readonly",function readonly(_readonly){
if(_readonly){
this.clearRepeat();
}
}),_watch$a),
created:function created(){
// Create non reactive properties
this.$_autoDelayTimer=null;
this.$_autoRepeatTimer=null;
this.$_keyIsDown=false;
},
beforeDestroy:function beforeDestroy(){
this.clearRepeat();
},

/* istanbul ignore next */
deactivated:function deactivated(){
this.clearRepeat();
},
methods:{
// --- Public methods ---
focus:function focus(){
if(!this.disabled){
attemptFocus(this.$refs.spinner);
}
},
blur:function blur(){
if(!this.disabled){
attemptBlur(this.$refs.spinner);
}
},
// --- Private methods ---
emitChange:function emitChange(){
this.$emit(EVENT_NAME_CHANGE,this.localValue);
},
stepValue:function stepValue(direction){
// Sets a new incremented or decremented value, supporting optional wrapping
// Direction is either +1 or -1 (or a multiple thereof)
var value=this.localValue;

if(!this.disabled&&!isNull(value)){
var step=this.computedStep*direction;
var min=this.computedMin;
var max=this.computedMax;
var multiplier=this.computedMultiplier;
var wrap=this.wrap;// We ensure that the value steps like a native input

value=mathRound((value-min)/step)*step+min+step;// We ensure that precision is maintained (decimals)

value=mathRound(value*multiplier)/multiplier;// Handle if wrapping is enabled

this.localValue=value>max?wrap?min:max:value<min?wrap?max:min:value;
}
},
onFocusBlur:function onFocusBlur(event){
if(!this.disabled){
this.hasFocus=event.type==='focus';
}else {
this.hasFocus=false;
}
},
stepUp:function stepUp(){
var multiplier=arguments.length>0&&arguments[0]!==undefined?arguments[0]:1;
var value=this.localValue;

if(isNull(value)){
this.localValue=this.computedMin;
}else {
this.stepValue(+1*multiplier);
}
},
stepDown:function stepDown(){
var multiplier=arguments.length>0&&arguments[0]!==undefined?arguments[0]:1;
var value=this.localValue;

if(isNull(value)){
this.localValue=this.wrap?this.computedMax:this.computedMin;
}else {
this.stepValue(-1*multiplier);
}
},
onKeydown:function onKeydown(event){
var keyCode=event.keyCode,
altKey=event.altKey,
ctrlKey=event.ctrlKey,
metaKey=event.metaKey;
/* istanbul ignore if */

if(this.disabled||this.readonly||altKey||ctrlKey||metaKey){
return;
}

if(arrayIncludes(KEY_CODES,keyCode)){
// https://w3c.github.io/aria-practices/#spinbutton
stopEvent(event,{
propagation:false});

/* istanbul ignore if */

if(this.$_keyIsDown){
// Keypress is already in progress
return;
}

this.resetTimers();

if(arrayIncludes([CODE_UP,CODE_DOWN],keyCode)){
// The following use the custom auto-repeat handling
this.$_keyIsDown=true;

if(keyCode===CODE_UP){
this.handleStepRepeat(event,this.stepUp);
}else if(keyCode===CODE_DOWN){
this.handleStepRepeat(event,this.stepDown);
}
}else {
// These use native OS key repeating
if(keyCode===CODE_PAGEUP){
this.stepUp(this.computedStepMultiplier);
}else if(keyCode===CODE_PAGEDOWN){
this.stepDown(this.computedStepMultiplier);
}else if(keyCode===CODE_HOME){
this.localValue=this.computedMin;
}else if(keyCode===CODE_END){
this.localValue=this.computedMax;
}
}
}
},
onKeyup:function onKeyup(event){
// Emit a change event when the keyup happens
var keyCode=event.keyCode,
altKey=event.altKey,
ctrlKey=event.ctrlKey,
metaKey=event.metaKey;
/* istanbul ignore if */

if(this.disabled||this.readonly||altKey||ctrlKey||metaKey){
return;
}

if(arrayIncludes(KEY_CODES,keyCode)){
stopEvent(event,{
propagation:false});

this.resetTimers();
this.$_keyIsDown=false;
this.emitChange();
}
},
handleStepRepeat:function handleStepRepeat(event,stepper){
var _this=this;

var _ref=event||{},
type=_ref.type,
button=_ref.button;

if(!this.disabled&&!this.readonly){
/* istanbul ignore if */
if(type==='mousedown'&&button){
// We only respond to left (main === 0) button clicks
return;
}

this.resetTimers();// Step the counter initially

stepper(1);
var threshold=this.computedThreshold;
var multiplier=this.computedStepMultiplier;
var delay=this.computedDelay;
var interval=this.computedInterval;// Initiate the delay/repeat interval

this.$_autoDelayTimer=setTimeout(function(){
var count=0;
_this.$_autoRepeatTimer=setInterval(function(){
// After N initial repeats, we increase the incrementing step amount
// We do this to minimize screen reader announcements of the value
// (values are announced every change, which can be chatty for SR users)
// And to make it easer to select a value when the range is large
stepper(count<threshold?1:multiplier);
count++;
},interval);
},delay);
}
},
onMouseup:function onMouseup(event){
// `<body>` listener, only enabled when mousedown starts
var _ref2=event||{},
type=_ref2.type,
button=_ref2.button;
/* istanbul ignore if */


if(type==='mouseup'&&button){
// Ignore non left button (main === 0) mouse button click
return;
}

stopEvent(event,{
propagation:false});

this.resetTimers();
this.setMouseup(false);// Trigger the change event

this.emitChange();
},
setMouseup:function setMouseup(on){
// Enable or disabled the body mouseup/touchend handlers
// Use try/catch to handle case when called server side
try{
eventOnOff(on,document.body,'mouseup',this.onMouseup,false);
eventOnOff(on,document.body,'touchend',this.onMouseup,false);
}catch(_unused){}
},
resetTimers:function resetTimers(){
clearTimeout(this.$_autoDelayTimer);
clearInterval(this.$_autoRepeatTimer);
this.$_autoDelayTimer=null;
this.$_autoRepeatTimer=null;
},
clearRepeat:function clearRepeat(){
this.resetTimers();
this.setMouseup(false);
this.$_keyIsDown=false;
}},

render:function render(h){
var _this2=this;

var spinId=this.spinId,
value=this.localValue,
inline=this.computedInline,
readonly=this.computedReadonly,
vertical=this.vertical,
disabled=this.disabled,
computedFormatter=this.computedFormatter;
var hasValue=!isNull(value);

var makeButton=function makeButton(stepper,label,IconCmp,keyRef,shortcut,btnDisabled,slotName){
var $icon=h(IconCmp,{
props:{
scale:_this2.hasFocus?1.5:1.25},

attrs:{
'aria-hidden':'true'}});


var scope={
hasFocus:_this2.hasFocus};


var handler=function handler(event){
if(!disabled&&!readonly){
stopEvent(event,{
propagation:false});


_this2.setMouseup(true);// Since we `preventDefault()`, we must manually focus the button


attemptFocus(event.currentTarget);

_this2.handleStepRepeat(event,stepper);
}
};

return h('button',{
staticClass:'btn btn-sm border-0 rounded-0',
class:{
'py-0':!vertical},

attrs:{
tabindex:'-1',
type:'button',
disabled:disabled||readonly||btnDisabled,
'aria-disabled':disabled||readonly||btnDisabled?'true':null,
'aria-controls':spinId,
'aria-label':label||null,
'aria-keyshortcuts':shortcut||null},

on:{
mousedown:handler,
touchstart:handler},

key:keyRef||null,
ref:keyRef},
[_this2.normalizeSlot(slotName,scope)||$icon]);
};// TODO: Add button disabled state when `wrap` is `false` and at value max/min


var $increment=makeButton(this.stepUp,this.labelIncrement,BIconPlus,'inc','ArrowUp',false,SLOT_NAME_INCREMENT);
var $decrement=makeButton(this.stepDown,this.labelDecrement,BIconDash,'dec','ArrowDown',false,SLOT_NAME_DECREMENT);
var $hidden=h();

if(this.name&&!disabled){
$hidden=h('input',{
attrs:{
type:'hidden',
name:this.name,
form:this.form||null,
// TODO: Should this be set to '' if value is out of range?
value:this.valueAsFixed},

key:'hidden'});

}

var $spin=h(// We use 'output' element to make this accept a `<label for="id">` (Except IE)
'output',{
staticClass:'flex-grow-1',
class:{
'd-flex':vertical,
'align-self-center':!vertical,
'align-items-center':vertical,
'border-top':vertical,
'border-bottom':vertical,
'border-left':!vertical,
'border-right':!vertical},

attrs:this.computedSpinAttrs,
key:'output',
ref:'spinner'},
[h('bdi',hasValue?computedFormatter(value):this.placeholder||'')]);
return h('div',{
staticClass:'b-form-spinbutton form-control',
class:[{
disabled:disabled,
readonly:readonly,
focus:this.hasFocus,
'd-inline-flex':inline||vertical,
'd-flex':!inline&&!vertical,
'align-items-stretch':!vertical,
'flex-column':vertical},
this.sizeFormClass,this.stateClass],
attrs:this.computedAttrs,
on:{
keydown:this.onKeydown,
keyup:this.onKeyup,
// We use capture phase (`!` prefix) since focus and blur do not bubble
'!focus':this.onFocusBlur,
'!blur':this.onFocusBlur}},

vertical?[$increment,$hidden,$spin,$decrement]:[$decrement,$hidden,$spin,$increment]);
}});


var FormSpinbuttonPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormSpinbutton:BFormSpinbutton,
BSpinbutton:BFormSpinbutton}});



var props$1a=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$g),{},{
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
noRemove:makeProp(PROP_TYPE_BOOLEAN,false),
pill:makeProp(PROP_TYPE_BOOLEAN,false),
removeLabel:makeProp(PROP_TYPE_STRING,'Remove tag'),
tag:makeProp(PROP_TYPE_STRING,'span'),
title:makeProp(PROP_TYPE_STRING),
variant:makeProp(PROP_TYPE_STRING,'secondary')})),
NAME_FORM_TAG);// --- Main component ---
// @vue/component

var BFormTag=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_TAG,
mixins:[idMixin,normalizeSlotMixin],
props:props$1a,
methods:{
onRemove:function onRemove(event){
var type=event.type,
keyCode=event.keyCode;

if(!this.disabled&&(type==='click'||type==='keydown'&&keyCode===CODE_DELETE)){
this.$emit(EVENT_NAME_REMOVE);
}
}},

render:function render(h){
var title=this.title,
tag=this.tag,
variant=this.variant,
pill=this.pill,
disabled=this.disabled;
var tagId=this.safeId();
var tagLabelId=this.safeId('_taglabel_');
var $remove=h();

if(!this.noRemove&&!disabled){
$remove=h(BButtonClose,{
staticClass:'b-form-tag-remove',
props:{
ariaLabel:this.removeLabel},

attrs:{
'aria-controls':tagId,
'aria-describedby':tagLabelId,
'aria-keyshortcuts':'Delete'},

on:{
click:this.onRemove,
keydown:this.onRemove}});


}

var $tag=h('span',{
staticClass:'b-form-tag-content flex-grow-1 text-truncate',
attrs:{
id:tagLabelId}},

this.normalizeSlot()||title);
return h(BBadge,{
staticClass:'b-form-tag d-inline-flex align-items-baseline mw-100',
class:{
disabled:disabled},

props:{
tag:tag,
variant:variant,
pill:pill},

attrs:{
id:tagId,
title:title||null,
'aria-labelledby':tagLabelId}},

[$tag,$remove]);
}});


var _watch$b;

var _makeModelMixin$c=makeModelMixin('value',{
type:PROP_TYPE_ARRAY,
defaultValue:[]}),

modelMixin$b=_makeModelMixin$c.mixin,
modelProps$b=_makeModelMixin$c.props,
MODEL_PROP_NAME$b=_makeModelMixin$c.prop,
MODEL_EVENT_NAME$b=_makeModelMixin$c.event;// Supported input types (for built in input)


var TYPES$2=['text','email','tel','url','number'];// Default ignore input focus selector

var DEFAULT_INPUT_FOCUS_SELECTOR=['.b-form-tag','button','input','select'].join(' ');// --- Helper methods ---
// Escape special chars in string and replace
// contiguous spaces with a whitespace match

var escapeRegExpChars=function escapeRegExpChars(str){
return escapeRegExp(str).replace(RX_SPACES,'\\s');
};// Remove leading/trailing spaces from array of tags and remove duplicates


var cleanTags=function cleanTags(tags){
return concat(tags).map(function(tag){
return trim(toString$1(tag));
}).filter(function(tag,index,arr){
return tag.length>0&&arr.indexOf(tag)===index;
});
};// Processes an input/change event, normalizing string or event argument


var processEventValue=function processEventValue(event){
return isString(event)?event:isEvent(event)?event.target.value||'':'';
};// Returns a fresh empty `tagsState` object


var cleanTagsState=function cleanTagsState(){
return {
all:[],
valid:[],
invalid:[],
duplicate:[]};

};// --- Props ---


var props$1b=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$b),props$Q),props$S),props$T),{},{
addButtonText:makeProp(PROP_TYPE_STRING,'Add'),
addButtonVariant:makeProp(PROP_TYPE_STRING,'outline-secondary'),
// Enable change event triggering tag addition
// Handy if using <select> as the input
addOnChange:makeProp(PROP_TYPE_BOOLEAN,false),
duplicateTagText:makeProp(PROP_TYPE_STRING,'Duplicate tag(s)'),
// Disable the input focus behavior when clicking
// on element matching the selector (or selectors)
ignoreInputFocusSelector:makeProp(PROP_TYPE_ARRAY_STRING,DEFAULT_INPUT_FOCUS_SELECTOR),
// Additional attributes to add to the input element
inputAttrs:makeProp(PROP_TYPE_OBJECT,{}),
inputClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
inputId:makeProp(PROP_TYPE_STRING),
inputType:makeProp(PROP_TYPE_STRING,'text',function(value){
return arrayIncludes(TYPES$2,value);
}),
invalidTagText:makeProp(PROP_TYPE_STRING,'Invalid tag(s)'),
limit:makeProp(PROP_TYPE_NUMBER),
limitTagsText:makeProp(PROP_TYPE_STRING,'Tag limit reached'),
// Disable ENTER key from triggering tag addition
noAddOnEnter:makeProp(PROP_TYPE_BOOLEAN,false),
// Disable the focus ring on the root element
noOuterFocus:makeProp(PROP_TYPE_BOOLEAN,false),
noTagRemove:makeProp(PROP_TYPE_BOOLEAN,false),
placeholder:makeProp(PROP_TYPE_STRING,'Add tag...'),
// Enable deleting last tag in list when CODE_BACKSPACE is
// pressed and input is empty
removeOnDelete:makeProp(PROP_TYPE_BOOLEAN,false),
// Character (or characters) that trigger adding tags
separator:makeProp(PROP_TYPE_ARRAY_STRING),
tagClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
tagPills:makeProp(PROP_TYPE_BOOLEAN,false),
tagRemoveLabel:makeProp(PROP_TYPE_STRING,'Remove tag'),
tagRemovedLabel:makeProp(PROP_TYPE_STRING,'Tag removed'),
tagValidator:makeProp(PROP_TYPE_FUNCTION),
tagVariant:makeProp(PROP_TYPE_STRING,'secondary')})),
NAME_FORM_TAGS);// --- Main component ---
// @vue/component

var BFormTags=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_TAGS,
mixins:[idMixin,modelMixin$b,formControlMixin,formSizeMixin,formStateMixin,normalizeSlotMixin],
props:props$1b,
data:function data(){
return {
hasFocus:false,
newTag:'',
tags:[],
// Tags that were removed
removedTags:[],
// Populated when tags are parsed
tagsState:cleanTagsState()};

},
computed:{
computedInputId:function computedInputId(){
return this.inputId||this.safeId('__input__');
},
computedInputType:function computedInputType(){
// We only allow certain types
return arrayIncludes(TYPES$2,this.inputType)?this.inputType:'text';
},
computedInputAttrs:function computedInputAttrs(){
var disabled=this.disabled,
form=this.form;
return _objectSpread2(_objectSpread2({},this.inputAttrs),{},{
// Must have attributes
id:this.computedInputId,
value:this.newTag,
disabled:disabled,
form:form});

},
computedInputHandlers:function computedInputHandlers(){
return {
input:this.onInputInput,
change:this.onInputChange,
keydown:this.onInputKeydown,
reset:this.reset};

},
computedSeparator:function computedSeparator(){
// Merge the array into a string
return concat(this.separator).filter(isString).filter(identity).join('');
},
computedSeparatorRegExp:function computedSeparatorRegExp(){
// We use a computed prop here to precompile the RegExp
// The RegExp is a character class RE in the form of `/[abc]+/`
// where a, b, and c are the valid separator characters
// -> `tags = str.split(/[abc]+/).filter(t => t)`
var separator=this.computedSeparator;
return separator?new RegExp("[".concat(escapeRegExpChars(separator),"]+")):null;
},
computedJoiner:function computedJoiner(){
// When tag(s) are invalid or duplicate, we leave them
// in the input so that the user can see them
// If there are more than one tag in the input, we use the
// first separator character as the separator in the input
// We append a space if the first separator is not a space
var joiner=this.computedSeparator.charAt(0);
return joiner!==' '?"".concat(joiner," "):joiner;
},
computeIgnoreInputFocusSelector:function computeIgnoreInputFocusSelector(){
// Normalize to an single selector with selectors separated by `,`
return concat(this.ignoreInputFocusSelector).filter(identity).join(',').trim();
},
disableAddButton:function disableAddButton(){
var _this=this;

// If 'Add' button should be disabled
// If the input contains at least one tag that can
// be added, then the 'Add' button should be enabled
var newTag=trim(this.newTag);
return newTag===''||!this.splitTags(newTag).some(function(t){
return !arrayIncludes(_this.tags,t)&&_this.validateTag(t);
});
},
duplicateTags:function duplicateTags(){
return this.tagsState.duplicate;
},
hasDuplicateTags:function hasDuplicateTags(){
return this.duplicateTags.length>0;
},
invalidTags:function invalidTags(){
return this.tagsState.invalid;
},
hasInvalidTags:function hasInvalidTags(){
return this.invalidTags.length>0;
},
isLimitReached:function isLimitReached(){
var limit=this.limit;
return isNumber(limit)&&limit>=0&&this.tags.length>=limit;
}},

watch:(_watch$b={},_defineProperty(_watch$b,MODEL_PROP_NAME$b,function(newValue){
this.tags=cleanTags(newValue);
}),_defineProperty(_watch$b,"tags",function tags(newValue,oldValue){
// Update the `v-model` (if it differs from the value prop)
if(!looseEqual(newValue,this[MODEL_PROP_NAME$b])){
this.$emit(MODEL_EVENT_NAME$b,newValue);
}

if(!looseEqual(newValue,oldValue)){
newValue=concat(newValue).filter(identity);
oldValue=concat(oldValue).filter(identity);
this.removedTags=oldValue.filter(function(old){
return !arrayIncludes(newValue,old);
});
}
}),_defineProperty(_watch$b,"tagsState",function tagsState(newValue,oldValue){
// Emit a tag-state event when the `tagsState` object changes
if(!looseEqual(newValue,oldValue)){
this.$emit(EVENT_NAME_TAG_STATE,newValue.valid,newValue.invalid,newValue.duplicate);
}
}),_watch$b),
created:function created(){
// We do this in created to make sure an input event emits
// if the cleaned tags are not equal to the value prop
this.tags=cleanTags(this[MODEL_PROP_NAME$b]);
},
mounted:function mounted(){
var _this2=this;

// Listen for form reset events, to reset the tags input
var $form=closest('form',this.$el);

if($form){
eventOn($form,'reset',this.reset,EVENT_OPTIONS_PASSIVE);
this.$on(HOOK_EVENT_NAME_BEFORE_DESTROY,function(){
eventOff($form,'reset',_this2.reset,EVENT_OPTIONS_PASSIVE);
});
}
},
methods:{
addTag:function addTag(newTag){
newTag=isString(newTag)?newTag:this.newTag;
/* istanbul ignore next */

if(this.disabled||trim(newTag)===''||this.isLimitReached){
// Early exit
return;
}

var parsed=this.parseTags(newTag);// Add any new tags to the `tags` array, or if the
// array of `allTags` is empty, we clear the input

if(parsed.valid.length>0||parsed.all.length===0){
// Clear the user input element (and leave in any invalid/duplicate tag(s)

/* istanbul ignore if: full testing to be added later */
if(matches(this.getInput(),'select')){
// The following is needed to properly
// work with `<select>` elements
this.newTag='';
}else {
var invalidAndDuplicates=[].concat(_toConsumableArray(parsed.invalid),_toConsumableArray(parsed.duplicate));
this.newTag=parsed.all.filter(function(tag){
return arrayIncludes(invalidAndDuplicates,tag);
}).join(this.computedJoiner).concat(invalidAndDuplicates.length>0?this.computedJoiner.charAt(0):'');
}
}

if(parsed.valid.length>0){
// We add the new tags in one atomic operation
// to trigger reactivity once (instead of once per tag)
// We do this after we update the new tag input value
// `concat()` can be faster than array spread, when both args are arrays
this.tags=concat(this.tags,parsed.valid);
}

this.tagsState=parsed;// Attempt to re-focus the input (specifically for when using the Add
// button, as the button disappears after successfully adding a tag

this.focus();
},
removeTag:function removeTag(tag){
var _this3=this;

/* istanbul ignore next */
if(this.disabled){
return;
}// TODO:
//   Add `onRemoveTag(tag)` user method, which if returns `false`
//   will prevent the tag from being removed (i.e. confirmation)
//   Or emit cancelable `BvEvent`


this.tags=this.tags.filter(function(t){
return t!==tag;
});// Return focus to the input (if possible)

this.$nextTick(function(){
_this3.focus();
});
},
reset:function reset(){
var _this4=this;

this.newTag='';
this.tags=[];
this.$nextTick(function(){
_this4.removedTags=[];
_this4.tagsState=cleanTagsState();
});
},
// --- Input element event handlers ---
onInputInput:function onInputInput(event){
/* istanbul ignore next: hard to test composition events */
if(this.disabled||isEvent(event)&&event.target.composing){
// `event.target.composing` is set by Vue (`v-model` directive)
// https://github.com/vuejs/vue/blob/dev/src/platforms/web/runtime/directives/model.js
return;
}

var newTag=processEventValue(event);
var separatorRe=this.computedSeparatorRegExp;

if(this.newTag!==newTag){
this.newTag=newTag;
}// We ignore leading whitespace for the following


newTag=trimLeft(newTag);

if(separatorRe&&separatorRe.test(newTag.slice(-1))){
// A trailing separator character was entered, so add the tag(s)
// Note: More than one tag on input event is possible via copy/paste
this.addTag();
}else {
// Validate (parse tags) on input event
this.tagsState=newTag===''?cleanTagsState():this.parseTags(newTag);
}
},
onInputChange:function onInputChange(event){
// Change is triggered on `<input>` blur, or `<select>` selected
// This event is opt-in
if(!this.disabled&&this.addOnChange){
var newTag=processEventValue(event);
/* istanbul ignore next */

if(this.newTag!==newTag){
this.newTag=newTag;
}

this.addTag();
}
},
onInputKeydown:function onInputKeydown(event){
// Early exit

/* istanbul ignore next */
if(this.disabled||!isEvent(event)){
return;
}

var keyCode=event.keyCode;
var value=event.target.value||'';
/* istanbul ignore else: testing to be added later */

if(!this.noAddOnEnter&&keyCode===CODE_ENTER){
// Attempt to add the tag when user presses enter
stopEvent(event,{
propagation:false});

this.addTag();
}else if(this.removeOnDelete&&(keyCode===CODE_BACKSPACE||keyCode===CODE_DELETE)&&value===''){
// Remove the last tag if the user pressed backspace/delete and the input is empty
stopEvent(event,{
propagation:false});

this.tags=this.tags.slice(0,-1);
}
},
// --- Wrapper event handlers ---
onClick:function onClick(event){
var _this5=this;

var ignoreFocusSelector=this.computeIgnoreInputFocusSelector;
var target=event.target;

if(!this.disabled&&!isActiveElement(target)&&(!ignoreFocusSelector||!closest(ignoreFocusSelector,target,true))){
this.$nextTick(function(){
_this5.focus();
});
}
},
onFocusin:function onFocusin(){
this.hasFocus=true;
},
onFocusout:function onFocusout(){
this.hasFocus=false;
},
handleAutofocus:function handleAutofocus(){
var _this6=this;

this.$nextTick(function(){
requestAF(function(){
if(_this6.autofocus&&!_this6.disabled){
_this6.focus();
}
});
});
},
// --- Public methods ---
focus:function focus(){
if(!this.disabled){
attemptFocus(this.getInput());
}
},
blur:function blur(){
if(!this.disabled){
attemptBlur(this.getInput());
}
},
// --- Private methods ---
splitTags:function splitTags(newTag){
// Split the input into an array of raw tags
newTag=toString$1(newTag);
var separatorRe=this.computedSeparatorRegExp;// Split the tag(s) via the optional separator
// Normally only a single tag is provided, but copy/paste
// can enter multiple tags in a single operation

return (separatorRe?newTag.split(separatorRe):[newTag]).map(trim).filter(identity);
},
parseTags:function parseTags(newTag){
var _this7=this;

// Takes `newTag` value and parses it into `validTags`,
// `invalidTags`, and duplicate tags as an object
// Split the input into raw tags
var tags=this.splitTags(newTag);// Base results

var parsed={
all:tags,
valid:[],
invalid:[],
duplicate:[]};
// Parse the unique tags

tags.forEach(function(tag){
if(arrayIncludes(_this7.tags,tag)||arrayIncludes(parsed.valid,tag)){
// Unique duplicate tags
if(!arrayIncludes(parsed.duplicate,tag)){
parsed.duplicate.push(tag);
}
}else if(_this7.validateTag(tag)){
// We only add unique/valid tags
parsed.valid.push(tag);
}else {
// Unique invalid tags
if(!arrayIncludes(parsed.invalid,tag)){
parsed.invalid.push(tag);
}
}
});
return parsed;
},
validateTag:function validateTag(tag){
var tagValidator=this.tagValidator;
return hasPropFunction(tagValidator)?tagValidator(tag):true;
},
getInput:function getInput(){
// Returns the input element reference (or null if not found)
// We need to escape `computedInputId` since it can be user-provided
return select("#".concat(cssEscape(this.computedInputId)),this.$el);
},
// Default User Interface render
defaultRender:function defaultRender(_ref){
var addButtonText=_ref.addButtonText,
addButtonVariant=_ref.addButtonVariant,
addTag=_ref.addTag,
disableAddButton=_ref.disableAddButton,
disabled=_ref.disabled,
duplicateTagText=_ref.duplicateTagText,
inputAttrs=_ref.inputAttrs,
inputClass=_ref.inputClass,
inputHandlers=_ref.inputHandlers,
inputType=_ref.inputType,
invalidTagText=_ref.invalidTagText,
isDuplicate=_ref.isDuplicate,
isInvalid=_ref.isInvalid,
isLimitReached=_ref.isLimitReached,
limitTagsText=_ref.limitTagsText,
noTagRemove=_ref.noTagRemove,
placeholder=_ref.placeholder,
removeTag=_ref.removeTag,
tagClass=_ref.tagClass,
tagPills=_ref.tagPills,
tagRemoveLabel=_ref.tagRemoveLabel,
tagVariant=_ref.tagVariant,
tags=_ref.tags;
var h=this.$createElement;// Make the list of tags

var $tags=tags.map(function(tag){
tag=toString$1(tag);
return h(BFormTag,{
class:tagClass,
// `BFormTag` will auto generate an ID
// so we do not need to set the ID prop
props:{
disabled:disabled,
noRemove:noTagRemove,
pill:tagPills,
removeLabel:tagRemoveLabel,
tag:'li',
title:tag,
variant:tagVariant},

on:{
remove:function remove(){
return removeTag(tag);
}},

key:"tags_".concat(tag)},
tag);
});// Feedback IDs if needed

var invalidFeedbackId=invalidTagText&&isInvalid?this.safeId('__invalid_feedback__'):null;
var duplicateFeedbackId=duplicateTagText&&isDuplicate?this.safeId('__duplicate_feedback__'):null;
var limitFeedbackId=limitTagsText&&isLimitReached?this.safeId('__limit_feedback__'):null;// Compute the `aria-describedby` attribute value

var ariaDescribedby=[inputAttrs['aria-describedby'],invalidFeedbackId,duplicateFeedbackId,limitFeedbackId].filter(identity).join(' ');// Input

var $input=h('input',{
staticClass:'b-form-tags-input w-100 flex-grow-1 p-0 m-0 bg-transparent border-0',
class:inputClass,
style:{
outline:0,
minWidth:'5rem'},

attrs:_objectSpread2(_objectSpread2({},inputAttrs),{},{
'aria-describedby':ariaDescribedby||null,
type:inputType,
placeholder:placeholder||null}),

domProps:{
value:inputAttrs.value},

on:inputHandlers,
// Directive needed to get `event.target.composing` set (if needed)
directives:[{
name:'model',
value:inputAttrs.value}],

ref:'input'});
// Add button

var $button=h(BButton,{
staticClass:'b-form-tags-button py-0',
class:{
// Only show the button if the tag can be added
// We use the `invisible` class instead of not rendering
// the button, so that we maintain layout to prevent
// the user input from jumping around
invisible:disableAddButton},

style:{
fontSize:'90%'},

props:{
disabled:disableAddButton||isLimitReached,
variant:addButtonVariant},

on:{
click:function click(){
return addTag();
}},

ref:'button'},
[this.normalizeSlot(SLOT_NAME_ADD_BUTTON_TEXT)||addButtonText]);// ID of the tags + input `<ul>` list
// Note we could concatenate `inputAttrs.id` with '__tag_list__'
// but `inputId` may be `null` until after mount
// `safeId()` returns `null`, if no user provided ID,
// until after mount when a unique ID is generated

var tagListId=this.safeId('__tag_list__');
var $field=h('li',{
staticClass:'b-from-tags-field flex-grow-1',
attrs:{
role:'none',
'aria-live':'off',
'aria-controls':tagListId},

key:'tags_field'},
[h('div',{
staticClass:'d-flex',
attrs:{
role:'group'}},

[$input,$button])]);// Wrap in an unordered list element (we use a list for accessibility)

var $ul=h('ul',{
staticClass:'b-form-tags-list list-unstyled mb-0 d-flex flex-wrap align-items-center',
attrs:{
id:tagListId},

key:'tags_list'},
[$tags,$field]);// Assemble the feedback

var $feedback=h();

if(invalidTagText||duplicateTagText||limitTagsText){
// Add an aria live region for the invalid/duplicate tag
// messages if the user has not disabled the messages
var joiner=this.computedJoiner;// Invalid tag feedback if needed (error)

var $invalid=h();

if(invalidFeedbackId){
$invalid=h(BFormInvalidFeedback,{
props:{
id:invalidFeedbackId,
forceShow:true},

key:'tags_invalid_feedback'},
[this.invalidTagText,': ',this.invalidTags.join(joiner)]);
}// Duplicate tag feedback if needed (warning, not error)


var $duplicate=h();

if(duplicateFeedbackId){
$duplicate=h(BFormText,{
props:{
id:duplicateFeedbackId},

key:'tags_duplicate_feedback'},
[this.duplicateTagText,': ',this.duplicateTags.join(joiner)]);
}// Limit tags feedback if needed (warning, not error)


var $limit=h();

if(limitFeedbackId){
$limit=h(BFormText,{
props:{
id:limitFeedbackId},

key:'tags_limit_feedback'},
[limitTagsText]);
}

$feedback=h('div',{
attrs:{
'aria-live':'polite',
'aria-atomic':'true'},

key:'tags_feedback'},
[$invalid,$duplicate,$limit]);
}// Return the content


return [$ul,$feedback];
}},

render:function render(h){
var name=this.name,
disabled=this.disabled,
required=this.required,
form=this.form,
tags=this.tags,
computedInputId=this.computedInputId,
hasFocus=this.hasFocus,
noOuterFocus=this.noOuterFocus;// Scoped slot properties

var scope=_objectSpread2({
// Array of tags (shallow copy to prevent mutations)
tags:tags.slice(),
// <input> v-bind:inputAttrs
inputAttrs:this.computedInputAttrs,
// We don't include this in the attrs, as users may want to override this
inputType:this.computedInputType,
// <input> v-on:inputHandlers
inputHandlers:this.computedInputHandlers,
// Methods
removeTag:this.removeTag,
addTag:this.addTag,
reset:this.reset,
// <input> :id="inputId"
inputId:computedInputId,
// Invalid/Duplicate state information
isInvalid:this.hasInvalidTags,
invalidTags:this.invalidTags.slice(),
isDuplicate:this.hasDuplicateTags,
duplicateTags:this.duplicateTags.slice(),
isLimitReached:this.isLimitReached,
// If the 'Add' button should be disabled
disableAddButton:this.disableAddButton},
pick(this.$props,['addButtonText','addButtonVariant','disabled','duplicateTagText','form','inputClass','invalidTagText','limit','limitTagsText','noTagRemove','placeholder','required','separator','size','state','tagClass','tagPills','tagRemoveLabel','tagVariant']));// Generate the user interface


var $content=this.normalizeSlot(SLOT_NAME_DEFAULT,scope)||this.defaultRender(scope);// Generate the `aria-live` region for the current value(s)

var $output=h('output',{
staticClass:'sr-only',
attrs:{
id:this.safeId('__selected_tags__'),
role:'status',
for:computedInputId,
'aria-live':hasFocus?'polite':'off',
'aria-atomic':'true',
'aria-relevant':'additions text'}},

this.tags.join(', '));// Removed tag live region

var $removed=h('div',{
staticClass:'sr-only',
attrs:{
id:this.safeId('__removed_tags__'),
role:'status',
'aria-live':hasFocus?'assertive':'off',
'aria-atomic':'true'}},

this.removedTags.length>0?"(".concat(this.tagRemovedLabel,") ").concat(this.removedTags.join(', ')):'');// Add hidden inputs for form submission

var $hidden=h();

if(name&&!disabled){
// We add hidden inputs for each tag if a name is provided
// When there are currently no tags, a visually hidden input
// with empty value is rendered for proper required handling
var hasTags=tags.length>0;
$hidden=(hasTags?tags:['']).map(function(tag){
return h('input',{
class:{
'sr-only':!hasTags},

attrs:{
type:hasTags?'hidden':'text',
value:tag,
required:required,
name:name,
form:form},

key:"tag_input_".concat(tag)});

});
}// Return the rendered output


return h('div',{
staticClass:'b-form-tags form-control h-auto',
class:[{
focus:hasFocus&&!noOuterFocus&&!disabled,
disabled:disabled},
this.sizeFormClass,this.stateClass],
attrs:{
id:this.safeId(),
role:'group',
tabindex:disabled||noOuterFocus?null:'-1',
'aria-describedby':this.safeId('__selected_tags__')},

on:{
click:this.onClick,
focusin:this.onFocusin,
focusout:this.onFocusout}},

[$output,$removed,$content,$hidden]);
}});


var FormTagsPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormTags:BFormTags,
BTags:BFormTags,
BFormTag:BFormTag,
BTag:BFormTag}});



var props$1c=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$Q),props$S),props$T),props$10),{},{
maxRows:makeProp(PROP_TYPE_NUMBER_STRING),
// When in auto resize mode, disable shrinking to content height
noAutoShrink:makeProp(PROP_TYPE_BOOLEAN,false),
// Disable the resize handle of textarea
noResize:makeProp(PROP_TYPE_BOOLEAN,false),
rows:makeProp(PROP_TYPE_NUMBER_STRING,2),
// 'soft', 'hard' or 'off'
// Browser default is 'soft'
wrap:makeProp(PROP_TYPE_STRING,'soft')})),
NAME_FORM_TEXTAREA);// --- Main component ---
// @vue/component

var BFormTextarea=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_TEXTAREA,
directives:{
'b-visible':VBVisible},

// Mixin order is important!
mixins:[listenersMixin,idMixin,listenOnRootMixin,formControlMixin,formSizeMixin,formStateMixin,formTextMixin,formSelectionMixin,formValidityMixin],
props:props$1c,
data:function data(){
return {
heightInPx:null};

},
computed:{
computedStyle:function computedStyle(){
var styles={
// Setting `noResize` to true will disable the ability for the user to
// manually resize the textarea. We also disable when in auto height mode
resize:!this.computedRows||this.noResize?'none':null};


if(!this.computedRows){
// Conditionally set the computed CSS height when auto rows/height is enabled
// We avoid setting the style to `null`, which can override user manual resize handle
styles.height=this.heightInPx;// We always add a vertical scrollbar to the textarea when auto-height is
// enabled so that the computed height calculation returns a stable value

styles.overflowY='scroll';
}

return styles;
},
computedMinRows:function computedMinRows(){
// Ensure rows is at least 2 and positive (2 is the native textarea value)
// A value of 1 can cause issues in some browsers, and most browsers
// only support 2 as the smallest value
return mathMax(toInteger(this.rows,2),2);
},
computedMaxRows:function computedMaxRows(){
return mathMax(this.computedMinRows,toInteger(this.maxRows,0));
},
computedRows:function computedRows(){
// This is used to set the attribute 'rows' on the textarea
// If auto-height is enabled, then we return `null` as we use CSS to control height
return this.computedMinRows===this.computedMaxRows?this.computedMinRows:null;
},
computedAttrs:function computedAttrs(){
var disabled=this.disabled,
required=this.required;
return {
id:this.safeId(),
name:this.name||null,
form:this.form||null,
disabled:disabled,
placeholder:this.placeholder||null,
required:required,
autocomplete:this.autocomplete||null,
readonly:this.readonly||this.plaintext,
rows:this.computedRows,
wrap:this.wrap||null,
'aria-required':this.required?'true':null,
'aria-invalid':this.computedAriaInvalid};

},
computedListeners:function computedListeners(){
return _objectSpread2(_objectSpread2({},this.bvListeners),{},{
input:this.onInput,
change:this.onChange,
blur:this.onBlur});

}},

watch:{
localValue:function localValue(){
this.setHeight();
}},

mounted:function mounted(){
this.setHeight();
},
methods:{
// Called by intersection observer directive

/* istanbul ignore next */
visibleCallback:function visibleCallback(visible){
if(visible){
// We use a `$nextTick()` here just to make sure any
// transitions or portalling have completed
this.$nextTick(this.setHeight);
}
},
setHeight:function setHeight(){
var _this=this;

this.$nextTick(function(){
requestAF(function(){
_this.heightInPx=_this.computeHeight();
});
});
},

/* istanbul ignore next: can't test getComputedStyle in JSDOM */
computeHeight:function computeHeight(){
if(this.$isServer||!isNull(this.computedRows)){
return null;
}

var el=this.$el;// Element must be visible (not hidden) and in document
// Must be checked after above checks

if(!isVisible(el)){
return null;
}// Get current computed styles


var computedStyle=getCS(el);// Height of one line of text in px

var lineHeight=toFloat(computedStyle.lineHeight,1);// Calculate height of border and padding

var border=toFloat(computedStyle.borderTopWidth,0)+toFloat(computedStyle.borderBottomWidth,0);
var padding=toFloat(computedStyle.paddingTop,0)+toFloat(computedStyle.paddingBottom,0);// Calculate offset

var offset=border+padding;// Minimum height for min rows (which must be 2 rows or greater for cross-browser support)

var minHeight=lineHeight*this.computedMinRows+offset;// Get the current style height (with `px` units)

var oldHeight=getStyle(el,'height')||computedStyle.height;// Probe scrollHeight by temporarily changing the height to `auto`

setStyle(el,'height','auto');
var scrollHeight=el.scrollHeight;// Place the original old height back on the element, just in case `computedProp`
// returns the same value as before

setStyle(el,'height',oldHeight);// Calculate content height in 'rows' (scrollHeight includes padding but not border)

var contentRows=mathMax((scrollHeight-padding)/lineHeight,2);// Calculate number of rows to display (limited within min/max rows)

var rows=mathMin(mathMax(contentRows,this.computedMinRows),this.computedMaxRows);// Calculate the required height of the textarea including border and padding (in pixels)

var height=mathMax(mathCeil(rows*lineHeight+offset),minHeight);// Computed height remains the larger of `oldHeight` and new `height`,
// when height is in `sticky` mode (prop `no-auto-shrink` is true)

if(this.noAutoShrink&&toFloat(oldHeight,0)>height){
return oldHeight;
}// Return the new computed CSS height in px units


return "".concat(height,"px");
}},

render:function render(h){
return h('textarea',{
class:this.computedClass,
style:this.computedStyle,
directives:[{
name:'b-visible',
value:this.visibleCallback,
// If textarea is within 640px of viewport, consider it visible
modifiers:{
'640':true}}],


attrs:this.computedAttrs,
domProps:{
value:this.localValue},

on:this.computedListeners,
ref:'input'});

}});


var FormTextareaPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormTextarea:BFormTextarea,
BTextarea:BFormTextarea}});



var _watch$c;

var _makeModelMixin$d=makeModelMixin('value',{
type:PROP_TYPE_STRING,
defaultValue:''}),

modelMixin$c=_makeModelMixin$d.mixin,
modelProps$c=_makeModelMixin$d.props,
MODEL_PROP_NAME$c=_makeModelMixin$d.prop,
MODEL_EVENT_NAME$c=_makeModelMixin$d.event;

var NUMERIC='numeric';// --- Helper methods ---

var padLeftZeros=function padLeftZeros(value){
return "00".concat(value||'').slice(-2);
};

var parseHMS=function parseHMS(value){
value=toString$1(value);
var hh=null,
mm=null,
ss=null;

if(RX_TIME.test(value)){

var _value$split$map=value.split(':').map(function(v){
return toInteger(v,null);
});

var _value$split$map2=_slicedToArray(_value$split$map,3);

hh=_value$split$map2[0];
mm=_value$split$map2[1];
ss=_value$split$map2[2];
}

return {
hours:isUndefinedOrNull(hh)?null:hh,
minutes:isUndefinedOrNull(mm)?null:mm,
seconds:isUndefinedOrNull(ss)?null:ss,
ampm:isUndefinedOrNull(hh)||hh<12?0:1};

};

var formatHMS=function formatHMS(_ref){
var hours=_ref.hours,
minutes=_ref.minutes,
seconds=_ref.seconds;
var requireSeconds=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;

if(isNull(hours)||isNull(minutes)||requireSeconds&&isNull(seconds)){
return '';
}

var hms=[hours,minutes,requireSeconds?seconds:0];
return hms.map(padLeftZeros).join(':');
};// --- Props ---


var props$1d=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$c),pick(props$19,['labelIncrement','labelDecrement'])),{},{
// ID of label element
ariaLabelledby:makeProp(PROP_TYPE_STRING),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
hidden:makeProp(PROP_TYPE_BOOLEAN,false),
hideHeader:makeProp(PROP_TYPE_BOOLEAN,false),
// Explicitly force 12 or 24 hour time
// Default is to use resolved locale for 12/24 hour display
// Tri-state: `true` = 12, `false` = 24, `null` = auto
hour12:makeProp(PROP_TYPE_BOOLEAN,null),
labelAm:makeProp(PROP_TYPE_STRING,'AM'),
labelAmpm:makeProp(PROP_TYPE_STRING,'AM/PM'),
labelHours:makeProp(PROP_TYPE_STRING,'Hours'),
labelMinutes:makeProp(PROP_TYPE_STRING,'Minutes'),
labelNoTimeSelected:makeProp(PROP_TYPE_STRING,'No time selected'),
labelPm:makeProp(PROP_TYPE_STRING,'PM'),
labelSeconds:makeProp(PROP_TYPE_STRING,'Seconds'),
labelSelected:makeProp(PROP_TYPE_STRING,'Selected time'),
locale:makeProp(PROP_TYPE_ARRAY_STRING),
minutesStep:makeProp(PROP_TYPE_NUMBER_STRING,1),
readonly:makeProp(PROP_TYPE_BOOLEAN,false),
secondsStep:makeProp(PROP_TYPE_NUMBER_STRING,1),
// If `true`, show the second spinbutton
showSeconds:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_TIME);// --- Main component ---
// @vue/component

var BTime=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TIME,
mixins:[idMixin,modelMixin$c,normalizeSlotMixin],
props:props$1d,
data:function data(){
var parsed=parseHMS(this[MODEL_PROP_NAME$c]||'');
return {
// Spin button models
modelHours:parsed.hours,
modelMinutes:parsed.minutes,
modelSeconds:parsed.seconds,
modelAmpm:parsed.ampm,
// Internal flag to enable aria-live regions
isLive:false};

},
computed:{
computedHMS:function computedHMS(){
var hours=this.modelHours;
var minutes=this.modelMinutes;
var seconds=this.modelSeconds;
return formatHMS({
hours:hours,
minutes:minutes,
seconds:seconds},
this.showSeconds);
},
resolvedOptions:function resolvedOptions(){
// Resolved locale options
var locale=concat(this.locale).filter(identity);
var options={
hour:NUMERIC,
minute:NUMERIC,
second:NUMERIC};


if(!isUndefinedOrNull(this.hour12)){
// Force 12 or 24 hour clock
options.hour12=!!this.hour12;
}

var dtf=new Intl.DateTimeFormat(locale,options);
var resolved=dtf.resolvedOptions();
var hour12=resolved.hour12||false;// IE 11 doesn't resolve the hourCycle, so we make
// an assumption and fall back to common values

var hourCycle=resolved.hourCycle||(hour12?'h12':'h23');
return {
locale:resolved.locale,
hour12:hour12,
hourCycle:hourCycle};

},
computedLocale:function computedLocale(){
return this.resolvedOptions.locale;
},
computedLang:function computedLang(){
return (this.computedLocale||'').replace(/-u-.*$/,'');
},
computedRTL:function computedRTL(){
return isLocaleRTL(this.computedLang);
},
computedHourCycle:function computedHourCycle(){
// h11, h12, h23, or h24
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Locale/hourCycle
// h12 - Hour system using 1–12. Corresponds to 'h' in patterns. The 12 hour clock, with midnight starting at 12:00 am
// h23 - Hour system using 0–23. Corresponds to 'H' in patterns. The 24 hour clock, with midnight starting at 0:00
// h11 - Hour system using 0–11. Corresponds to 'K' in patterns. The 12 hour clock, with midnight starting at 0:00 am
// h24 - Hour system using 1–24. Corresponds to 'k' in pattern. The 24 hour clock, with midnight starting at 24:00
// For h12 or h24, we visually format 00 hours as 12
return this.resolvedOptions.hourCycle;
},
is12Hour:function is12Hour(){
return !!this.resolvedOptions.hour12;
},
context:function context(){
return {
locale:this.computedLocale,
isRTL:this.computedRTL,
hourCycle:this.computedHourCycle,
hour12:this.is12Hour,
hours:this.modelHours,
minutes:this.modelMinutes,
seconds:this.showSeconds?this.modelSeconds:0,
value:this.computedHMS,
formatted:this.formattedTimeString};

},
valueId:function valueId(){
return this.safeId()||null;
},
computedAriaLabelledby:function computedAriaLabelledby(){
return [this.ariaLabelledby,this.valueId].filter(identity).join(' ')||null;
},
timeFormatter:function timeFormatter(){
// Returns a formatter function reference
// The formatter converts the time to a localized string
var options={
hour12:this.is12Hour,
hourCycle:this.computedHourCycle,
hour:NUMERIC,
minute:NUMERIC,
timeZone:'UTC'};


if(this.showSeconds){
options.second=NUMERIC;
}// Formats the time as a localized string


return createDateFormatter(this.computedLocale,options);
},
numberFormatter:function numberFormatter(){
// Returns a formatter function reference
// The formatter always formats as 2 digits and is localized
var nf=new Intl.NumberFormat(this.computedLocale,{
style:'decimal',
minimumIntegerDigits:2,
minimumFractionDigits:0,
maximumFractionDigits:0,
notation:'standard'});

return nf.format;
},
formattedTimeString:function formattedTimeString(){
var hours=this.modelHours;
var minutes=this.modelMinutes;
var seconds=this.showSeconds?this.modelSeconds||0:0;

if(this.computedHMS){
return this.timeFormatter(createDate(Date.UTC(0,0,1,hours,minutes,seconds)));
}

return this.labelNoTimeSelected||' ';
},
spinScopedSlots:function spinScopedSlots(){
var h=this.$createElement;
return {
increment:function increment(_ref2){
var hasFocus=_ref2.hasFocus;
return h(BIconChevronUp,{
props:{
scale:hasFocus?1.5:1.25},

attrs:{
'aria-hidden':'true'}});


},
decrement:function decrement(_ref3){
var hasFocus=_ref3.hasFocus;
return h(BIconChevronUp,{
props:{
flipV:true,
scale:hasFocus?1.5:1.25},

attrs:{
'aria-hidden':'true'}});


}};

}},

watch:(_watch$c={},_defineProperty(_watch$c,MODEL_PROP_NAME$c,function(newValue,oldValue){
if(newValue!==oldValue&&!looseEqual(parseHMS(newValue),parseHMS(this.computedHMS))){
var _parseHMS=parseHMS(newValue),
hours=_parseHMS.hours,
minutes=_parseHMS.minutes,
seconds=_parseHMS.seconds,
ampm=_parseHMS.ampm;

this.modelHours=hours;
this.modelMinutes=minutes;
this.modelSeconds=seconds;
this.modelAmpm=ampm;
}
}),_defineProperty(_watch$c,"computedHMS",function computedHMS(newValue,oldValue){
if(newValue!==oldValue){
this.$emit(MODEL_EVENT_NAME$c,newValue);
}
}),_defineProperty(_watch$c,"context",function context(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.$emit(EVENT_NAME_CONTEXT,newValue);
}
}),_defineProperty(_watch$c,"modelAmpm",function modelAmpm(newValue,oldValue){
var _this=this;

if(newValue!==oldValue){
var hours=isNull(this.modelHours)?0:this.modelHours;
this.$nextTick(function(){
if(newValue===0&&hours>11){
// Switched to AM
_this.modelHours=hours-12;
}else if(newValue===1&&hours<12){
// Switched to PM
_this.modelHours=hours+12;
}
});
}
}),_defineProperty(_watch$c,"modelHours",function modelHours(newHours,oldHours){
if(newHours!==oldHours){
this.modelAmpm=newHours>11?1:0;
}
}),_watch$c),
created:function created(){
var _this2=this;

this.$nextTick(function(){
_this2.$emit(EVENT_NAME_CONTEXT,_this2.context);
});
},
mounted:function mounted(){
this.setLive(true);
},

/* istanbul ignore next */
activated:function activated(){
this.setLive(true);
},

/* istanbul ignore next */
deactivated:function deactivated(){
this.setLive(false);
},
beforeDestroy:function beforeDestroy(){
this.setLive(false);
},
methods:{
// Public methods
focus:function focus(){
if(!this.disabled){
// We focus the first spin button
attemptFocus(this.$refs.spinners[0]);
}
},
blur:function blur(){
if(!this.disabled){
var activeElement=getActiveElement();

if(contains(this.$el,activeElement)){
attemptBlur(activeElement);
}
}
},
// Formatters for the spin buttons
formatHours:function formatHours(hh){
var hourCycle=this.computedHourCycle;// We always store 0-23, but format based on h11/h12/h23/h24 formats

hh=this.is12Hour&&hh>12?hh-12:hh;// Determine how 00:00 and 12:00 are shown

hh=hh===0&&hourCycle==='h12'?12:hh===0&&hourCycle==='h24'?
/* istanbul ignore next */
24:hh===12&&hourCycle==='h11'?
/* istanbul ignore next */
0:hh;
return this.numberFormatter(hh);
},
formatMinutes:function formatMinutes(mm){
return this.numberFormatter(mm);
},
formatSeconds:function formatSeconds(ss){
return this.numberFormatter(ss);
},
formatAmpm:function formatAmpm(ampm){
// These should come from label props???
// `ampm` should always be a value of `0` or `1`
return ampm===0?this.labelAm:ampm===1?this.labelPm:'';
},
// Spinbutton on change handlers
setHours:function setHours(value){
this.modelHours=value;
},
setMinutes:function setMinutes(value){
this.modelMinutes=value;
},
setSeconds:function setSeconds(value){
this.modelSeconds=value;
},
setAmpm:function setAmpm(value){
this.modelAmpm=value;
},
onSpinLeftRight:function onSpinLeftRight(){
var event=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{};
var type=event.type,
keyCode=event.keyCode;

if(!this.disabled&&type==='keydown'&&(keyCode===CODE_LEFT||keyCode===CODE_RIGHT)){
stopEvent(event);
var spinners=this.$refs.spinners||[];
var index=spinners.map(function(cmp){
return !!cmp.hasFocus;
}).indexOf(true);
index=index+(keyCode===CODE_LEFT?-1:1);
index=index>=spinners.length?0:index<0?spinners.length-1:index;
attemptFocus(spinners[index]);
}
},
setLive:function setLive(on){
var _this3=this;

if(on){
this.$nextTick(function(){
requestAF(function(){
_this3.isLive=true;
});
});
}else {
this.isLive=false;
}
}},

render:function render(h){
var _this4=this;

/* istanbul ignore if */
if(this.hidden){
// If hidden, we just render a placeholder comment
return h();
}

var valueId=this.valueId;
var computedAriaLabelledby=this.computedAriaLabelledby;
var spinIds=[];// Helper method to render a spinbutton

var makeSpinbutton=function makeSpinbutton(handler,key,classes){
var spinbuttonProps=arguments.length>3&&arguments[3]!==undefined?arguments[3]:{};
var id=_this4.safeId("_spinbutton_".concat(key,"_"))||null;
spinIds.push(id);
return h(BFormSpinbutton,{
class:classes,
props:_objectSpread2({
id:id,
placeholder:'--',
vertical:true,
required:true,
disabled:_this4.disabled,
readonly:_this4.readonly,
locale:_this4.computedLocale,
labelIncrement:_this4.labelIncrement,
labelDecrement:_this4.labelDecrement,
wrap:true,
ariaControls:valueId,
min:0},
spinbuttonProps),
scopedSlots:_this4.spinScopedSlots,
on:{
// We use `change` event to minimize SR verbosity
// As the spinbutton will announce each value change
// and we don't want the formatted time to be announced
// on each value input if repeat is happening
change:handler},

key:key,
ref:'spinners',
refInFor:true});

};// Helper method to return a "colon" separator


var makeColon=function makeColon(){
return h('div',{
staticClass:'d-flex flex-column',
class:{
'text-muted':_this4.disabled||_this4.readonly},

attrs:{
'aria-hidden':'true'}},

[h(BIconCircleFill,{
props:{
shiftV:4,
scale:0.5}}),

h(BIconCircleFill,{
props:{
shiftV:-4,
scale:0.5}})]);


};

var $spinners=[];// Hours

$spinners.push(makeSpinbutton(this.setHours,'hours','b-time-hours',{
value:this.modelHours,
max:23,
step:1,
formatterFn:this.formatHours,
ariaLabel:this.labelHours}));
// Spacer

$spinners.push(makeColon());// Minutes

$spinners.push(makeSpinbutton(this.setMinutes,'minutes','b-time-minutes',{
value:this.modelMinutes,
max:59,
step:this.minutesStep||1,
formatterFn:this.formatMinutes,
ariaLabel:this.labelMinutes}));


if(this.showSeconds){
// Spacer
$spinners.push(makeColon());// Seconds

$spinners.push(makeSpinbutton(this.setSeconds,'seconds','b-time-seconds',{
value:this.modelSeconds,
max:59,
step:this.secondsStep||1,
formatterFn:this.formatSeconds,
ariaLabel:this.labelSeconds}));

}// AM/PM ?


if(this.is12Hour){
// TODO:
//   If locale is RTL, unshift this instead of push?
//   And switch class `ml-2` to `mr-2`
//   Note some LTR locales (i.e. zh) also place AM/PM to the left
$spinners.push(makeSpinbutton(this.setAmpm,'ampm','b-time-ampm',{
value:this.modelAmpm,
max:1,
formatterFn:this.formatAmpm,
ariaLabel:this.labelAmpm,
// We set `required` as `false`, since this always has a value
required:false}));

}// Assemble spinners


$spinners=h('div',{
staticClass:'d-flex align-items-center justify-content-center mx-auto',
attrs:{
role:'group',
tabindex:this.disabled||this.readonly?null:'-1',
'aria-labelledby':computedAriaLabelledby},

on:{
keydown:this.onSpinLeftRight,
click:
/* istanbul ignore next */
function click(event){
if(event.target===event.currentTarget){
_this4.focus();
}
}}},

$spinners);// Selected type display

var $value=h('output',{
staticClass:'form-control form-control-sm text-center',
class:{
disabled:this.disabled||this.readonly},

attrs:{
id:valueId,
role:'status',
for:spinIds.filter(identity).join(' ')||null,
tabindex:this.disabled?null:'-1',
'aria-live':this.isLive?'polite':'off',
'aria-atomic':'true'},

on:{
// Transfer focus/click to focus hours spinner
click:this.focus,
focus:this.focus}},

[h('bdi',this.formattedTimeString),this.computedHMS?h('span',{
staticClass:'sr-only'},
" (".concat(this.labelSelected,") ")):'']);
var $header=h('header',{
staticClass:'b-time-header',
class:{
'sr-only':this.hideHeader}},

[$value]);// Optional bottom slot

var $slot=this.normalizeSlot();
$slot=$slot?h('footer',{
staticClass:'b-time-footer'},
$slot):h();
return h('div',{
staticClass:'b-time d-inline-flex flex-column text-center',
attrs:{
role:'group',
lang:this.computedLang||null,
'aria-labelledby':computedAriaLabelledby||null,
'aria-disabled':this.disabled?'true':null,
'aria-readonly':this.readonly&&!this.disabled?'true':null}},

[$header,$spinners,$slot]);
}});


var _watch$d;

var _makeModelMixin$e=makeModelMixin('value',{
type:PROP_TYPE_STRING,
defaultValue:''}),

modelMixin$d=_makeModelMixin$e.mixin,
modelProps$d=_makeModelMixin$e.props,
MODEL_PROP_NAME$d=_makeModelMixin$e.prop,
MODEL_EVENT_NAME$d=_makeModelMixin$e.event;// --- Props ---


var timeProps=omit(props$1d,['hidden','id','value']);
var formBtnLabelControlProps$1=omit(props$Z,['formattedValue','id','lang','rtl','value']);
var props$1e=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$d),timeProps),formBtnLabelControlProps$1),{},{
closeButtonVariant:makeProp(PROP_TYPE_STRING,'outline-secondary'),
labelCloseButton:makeProp(PROP_TYPE_STRING,'Close'),
labelNowButton:makeProp(PROP_TYPE_STRING,'Select now'),
labelResetButton:makeProp(PROP_TYPE_STRING,'Reset'),
noCloseButton:makeProp(PROP_TYPE_BOOLEAN,false),
nowButton:makeProp(PROP_TYPE_BOOLEAN,false),
nowButtonVariant:makeProp(PROP_TYPE_STRING,'outline-primary'),
resetButton:makeProp(PROP_TYPE_BOOLEAN,false),
resetButtonVariant:makeProp(PROP_TYPE_STRING,'outline-danger'),
resetValue:makeProp(PROP_TYPE_DATE_STRING)})),
NAME_FORM_TIMEPICKER);// --- Main component ---
// @vue/component

var BFormTimepicker=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_FORM_TIMEPICKER,
mixins:[idMixin,modelMixin$d],
props:props$1e,
data:function data(){
return {
// We always use `HH:mm:ss` value internally
localHMS:this[MODEL_PROP_NAME$d]||'',
// Context data from BTime
localLocale:null,
isRTL:false,
formattedValue:'',
// If the menu is opened
isVisible:false};

},
computed:{
computedLang:function computedLang(){
return (this.localLocale||'').replace(/-u-.*$/i,'')||null;
}},

watch:(_watch$d={},_defineProperty(_watch$d,MODEL_PROP_NAME$d,function(newValue){
this.localHMS=newValue||'';
}),_defineProperty(_watch$d,"localHMS",function localHMS(newValue){
// We only update the v-model value when the timepicker
// is open, to prevent cursor jumps when bound to a
// text input in button only mode
if(this.isVisible){
this.$emit(MODEL_EVENT_NAME$d,newValue||'');
}
}),_watch$d),
methods:{
// Public methods
focus:function focus(){
if(!this.disabled){
attemptFocus(this.$refs.control);
}
},
blur:function blur(){
if(!this.disabled){
attemptBlur(this.$refs.control);
}
},
// Private methods
setAndClose:function setAndClose(value){
var _this=this;

this.localHMS=value;
this.$nextTick(function(){
_this.$refs.control.hide(true);
});
},
onInput:function onInput(hms){
if(this.localHMS!==hms){
this.localHMS=hms;
}
},
onContext:function onContext(ctx){
var isRTL=ctx.isRTL,
locale=ctx.locale,
value=ctx.value,
formatted=ctx.formatted;
this.isRTL=isRTL;
this.localLocale=locale;
this.formattedValue=formatted;
this.localHMS=value||'';// Re-emit the context event

this.$emit(EVENT_NAME_CONTEXT,ctx);
},
onNowButton:function onNowButton(){
var now=new Date();
var hours=now.getHours();
var minutes=now.getMinutes();
var seconds=this.showSeconds?now.getSeconds():0;
var value=[hours,minutes,seconds].map(function(v){
return "00".concat(v||'').slice(-2);
}).join(':');
this.setAndClose(value);
},
onResetButton:function onResetButton(){
this.setAndClose(this.resetValue);
},
onCloseButton:function onCloseButton(){
this.$refs.control.hide(true);
},
onShow:function onShow(){
this.isVisible=true;
},
onShown:function onShown(){
var _this2=this;

this.$nextTick(function(){
attemptFocus(_this2.$refs.time);

_this2.$emit(EVENT_NAME_SHOWN);
});
},
onHidden:function onHidden(){
this.isVisible=false;
this.$emit(EVENT_NAME_HIDDEN);
},
// Render function helpers
defaultButtonFn:function defaultButtonFn(_ref){
var isHovered=_ref.isHovered,
hasFocus=_ref.hasFocus;
return this.$createElement(isHovered||hasFocus?BIconClockFill:BIconClock,{
attrs:{
'aria-hidden':'true'}});


}},

render:function render(h){
var localHMS=this.localHMS,
disabled=this.disabled,
readonly=this.readonly,
$props=this.$props;
var placeholder=isUndefinedOrNull(this.placeholder)?this.labelNoTimeSelected:this.placeholder;// Footer buttons

var $footer=[];

if(this.nowButton){
var label=this.labelNowButton;
$footer.push(h(BButton,{
props:{
size:'sm',
disabled:disabled||readonly,
variant:this.nowButtonVariant},

attrs:{
'aria-label':label||null},

on:{
click:this.onNowButton},

key:'now-btn'},
label));
}

if(this.resetButton){
if($footer.length>0){
// Add a "spacer" between buttons ('&nbsp;')
$footer.push(h('span',"\xA0"));
}

var _label=this.labelResetButton;
$footer.push(h(BButton,{
props:{
size:'sm',
disabled:disabled||readonly,
variant:this.resetButtonVariant},

attrs:{
'aria-label':_label||null},

on:{
click:this.onResetButton},

key:'reset-btn'},
_label));
}

if(!this.noCloseButton){
// Add a "spacer" between buttons ('&nbsp;')
if($footer.length>0){
$footer.push(h('span',"\xA0"));
}

var _label2=this.labelCloseButton;
$footer.push(h(BButton,{
props:{
size:'sm',
disabled:disabled,
variant:this.closeButtonVariant},

attrs:{
'aria-label':_label2||null},

on:{
click:this.onCloseButton},

key:'close-btn'},
_label2));
}

if($footer.length>0){
$footer=[h('div',{
staticClass:'b-form-date-controls d-flex flex-wrap',
class:{
'justify-content-between':$footer.length>1,
'justify-content-end':$footer.length<2}},

$footer)];
}

var $time=h(BTime,{
staticClass:'b-form-time-control',
props:_objectSpread2(_objectSpread2({},pluckProps(timeProps,$props)),{},{
value:localHMS,
hidden:!this.isVisible}),

on:{
input:this.onInput,
context:this.onContext},

ref:'time'},
$footer);
return h(BVFormBtnLabelControl,{
staticClass:'b-form-timepicker',
props:_objectSpread2(_objectSpread2({},pluckProps(formBtnLabelControlProps$1,$props)),{},{
id:this.safeId(),
value:localHMS,
formattedValue:localHMS?this.formattedValue:'',
placeholder:placeholder,
rtl:this.isRTL,
lang:this.computedLang}),

on:{
show:this.onShow,
shown:this.onShown,
hidden:this.onHidden},

scopedSlots:_defineProperty({},SLOT_NAME_BUTTON_CONTENT,this.$scopedSlots[SLOT_NAME_BUTTON_CONTENT]||this.defaultButtonFn),
ref:'control'},
[$time]);
}});


var FormTimepickerPlugin=/*#__PURE__*/pluginFactory({
components:{
BFormTimepicker:BFormTimepicker,
BTimepicker:BFormTimepicker}});



var ImagePlugin=/*#__PURE__*/pluginFactory({
components:{
BImg:BImg,
BImgLazy:BImgLazy}});



var props$1f=makePropsConfigurable({
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_INPUT_GROUP_TEXT);// --- Main component ---
// @vue/component

var BInputGroupText=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_INPUT_GROUP_TEXT,
functional:true,
props:props$1f,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'input-group-text'}),
children);
}});


var props$1g=makePropsConfigurable({
append:makeProp(PROP_TYPE_BOOLEAN,false),
id:makeProp(PROP_TYPE_STRING),
isText:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_INPUT_GROUP_ADDON);// --- Main component ---
// @vue/component

var BInputGroupAddon=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_INPUT_GROUP_ADDON,
functional:true,
props:props$1g,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var append=props.append;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:{
'input-group-append':append,
'input-group-prepend':!append},

attrs:{
id:props.id}}),

props.isText?[h(BInputGroupText,children)]:children);
}});


var props$1h=makePropsConfigurable(omit(props$1g,['append']),NAME_INPUT_GROUP_APPEND);// --- Main component ---
// @vue/component

var BInputGroupAppend=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_INPUT_GROUP_APPEND,
functional:true,
props:props$1h,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
// Pass all our data down to child, and set `append` to `true`
return h(BInputGroupAddon,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
props:_objectSpread2(_objectSpread2({},props),{},{
append:true})}),

children);
}});


var props$1i=makePropsConfigurable(omit(props$1g,['append']),NAME_INPUT_GROUP_PREPEND);// --- Main component ---
// @vue/component

var BInputGroupPrepend=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_INPUT_GROUP_PREPEND,
functional:true,
props:props$1i,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
// Pass all our data down to child, and set `append` to `true`
return h(BInputGroupAddon,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
props:_objectSpread2(_objectSpread2({},props),{},{
append:false})}),

children);
}});


var props$1j=makePropsConfigurable({
append:makeProp(PROP_TYPE_STRING),
appendHtml:makeProp(PROP_TYPE_STRING),
id:makeProp(PROP_TYPE_STRING),
prepend:makeProp(PROP_TYPE_STRING),
prependHtml:makeProp(PROP_TYPE_STRING),
size:makeProp(PROP_TYPE_STRING),
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_INPUT_GROUP);// --- Main component ---
// @vue/component

var BInputGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_INPUT_GROUP,
functional:true,
props:props$1j,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots;
var prepend=props.prepend,
prependHtml=props.prependHtml,
append=props.append,
appendHtml=props.appendHtml,
size=props.size;
var $scopedSlots=scopedSlots||{};
var $slots=slots();
var slotScope={};
var $prepend=h();
var hasPrependSlot=hasNormalizedSlot(SLOT_NAME_PREPEND,$scopedSlots,$slots);

if(hasPrependSlot||prepend||prependHtml){
$prepend=h(BInputGroupPrepend,[hasPrependSlot?normalizeSlot(SLOT_NAME_PREPEND,slotScope,$scopedSlots,$slots):h(BInputGroupText,{
domProps:htmlOrText(prependHtml,prepend)})]);

}

var $append=h();
var hasAppendSlot=hasNormalizedSlot(SLOT_NAME_APPEND,$scopedSlots,$slots);

if(hasAppendSlot||append||appendHtml){
$append=h(BInputGroupAppend,[hasAppendSlot?normalizeSlot(SLOT_NAME_APPEND,slotScope,$scopedSlots,$slots):h(BInputGroupText,{
domProps:htmlOrText(appendHtml,append)})]);

}

return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'input-group',
class:_defineProperty({},"input-group-".concat(size),size),
attrs:{
id:props.id||null,
role:'group'}}),

[$prepend,normalizeSlot(SLOT_NAME_DEFAULT,slotScope,$scopedSlots,$slots),$append]);
}});


var InputGroupPlugin=/*#__PURE__*/pluginFactory({
components:{
BInputGroup:BInputGroup,
BInputGroupAddon:BInputGroupAddon,
BInputGroupPrepend:BInputGroupPrepend,
BInputGroupAppend:BInputGroupAppend,
BInputGroupText:BInputGroupText}});



var props$1k=makePropsConfigurable({
// String breakpoint name new in Bootstrap v4.4.x
fluid:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_CONTAINER);// --- Main component ---
// @vue/component

var BContainer=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_CONTAINER,
functional:true,
props:props$1k,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var fluid=props.fluid;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
class:_defineProperty({
container:!(fluid||fluid===''),
'container-fluid':fluid===true||fluid===''},
"container-".concat(fluid),fluid&&fluid!==true)}),
children);
}});


var props$1l=makePropsConfigurable({
bgVariant:makeProp(PROP_TYPE_STRING),
borderVariant:makeProp(PROP_TYPE_STRING),
containerFluid:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
fluid:makeProp(PROP_TYPE_BOOLEAN,false),
header:makeProp(PROP_TYPE_STRING),
headerHtml:makeProp(PROP_TYPE_STRING),
headerLevel:makeProp(PROP_TYPE_NUMBER_STRING,3),
headerTag:makeProp(PROP_TYPE_STRING,'h1'),
lead:makeProp(PROP_TYPE_STRING),
leadHtml:makeProp(PROP_TYPE_STRING),
leadTag:makeProp(PROP_TYPE_STRING,'p'),
tag:makeProp(PROP_TYPE_STRING,'div'),
textVariant:makeProp(PROP_TYPE_STRING)},
NAME_JUMBOTRON);// --- Main component ---
// @vue/component

var BJumbotron=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_JUMBOTRON,
functional:true,
props:props$1l,
render:function render(h,_ref){
var _class2;

var props=_ref.props,
data=_ref.data,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots;
var header=props.header,
headerHtml=props.headerHtml,
lead=props.lead,
leadHtml=props.leadHtml,
textVariant=props.textVariant,
bgVariant=props.bgVariant,
borderVariant=props.borderVariant;
var $scopedSlots=scopedSlots||{};
var $slots=slots();
var slotScope={};
var $header=h();
var hasHeaderSlot=hasNormalizedSlot(SLOT_NAME_HEADER,$scopedSlots,$slots);

if(hasHeaderSlot||header||headerHtml){
var headerLevel=props.headerLevel;
$header=h(props.headerTag,{
class:_defineProperty({},"display-".concat(headerLevel),headerLevel),
domProps:hasHeaderSlot?{}:htmlOrText(headerHtml,header)},
normalizeSlot(SLOT_NAME_HEADER,slotScope,$scopedSlots,$slots));
}

var $lead=h();
var hasLeadSlot=hasNormalizedSlot(SLOT_NAME_LEAD,$scopedSlots,$slots);

if(hasLeadSlot||lead||leadHtml){
$lead=h(props.leadTag,{
staticClass:'lead',
domProps:hasLeadSlot?{}:htmlOrText(leadHtml,lead)},
normalizeSlot(SLOT_NAME_LEAD,slotScope,$scopedSlots,$slots));
}

var $children=[$header,$lead,normalizeSlot(SLOT_NAME_DEFAULT,slotScope,$scopedSlots,$slots)];// If fluid, wrap content in a container

if(props.fluid){
$children=[h(BContainer,{
props:{
fluid:props.containerFluid}},

$children)];
}

return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'jumbotron',
class:(_class2={
'jumbotron-fluid':props.fluid},
_defineProperty(_class2,"text-".concat(textVariant),textVariant),_defineProperty(_class2,"bg-".concat(bgVariant),bgVariant),_defineProperty(_class2,"border-".concat(borderVariant),borderVariant),_defineProperty(_class2,"border",borderVariant),_class2)}),
$children);
}});


var JumbotronPlugin=/*#__PURE__*/pluginFactory({
components:{
BJumbotron:BJumbotron}});



var COMMON_ALIGNMENT=['start','end','center'];// --- Helper methods ---
// Compute a `row-cols-{breakpoint}-{cols}` class name
// Memoized function for better performance on generating class names

var computeRowColsClass=memoize(function(breakpoint,cols){
cols=trim(toString$1(cols));
return cols?lowerCase(['row-cols',breakpoint,cols].filter(identity).join('-')):null;
});// Get the breakpoint name from the `rowCols` prop name
// Memoized function for better performance on extracting breakpoint names

var computeRowColsBreakpoint=memoize(function(prop){
return lowerCase(prop.replace('cols',''));
});// Cached copy of the `row-cols` breakpoint prop names
// Will be populated when the props are generated

var rowColsPropList=[];// --- Props ---
// Prop generator for lazy generation of props

var generateProps$2=function generateProps(){
// i.e. 'row-cols-2', 'row-cols-md-4', 'row-cols-xl-6', ...
var rowColsProps=getBreakpointsUpCached().reduce(function(props,breakpoint){
props[suffixPropName(breakpoint,'cols')]=makeProp(PROP_TYPE_NUMBER_STRING);
return props;
},create(null));// Cache the row-cols prop names

rowColsPropList=keys(rowColsProps);// Return the generated props

return makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},rowColsProps),{},{
alignContent:makeProp(PROP_TYPE_STRING,null,function(value){
return arrayIncludes(concat(COMMON_ALIGNMENT,'between','around','stretch'),value);
}),
alignH:makeProp(PROP_TYPE_STRING,null,function(value){
return arrayIncludes(concat(COMMON_ALIGNMENT,'between','around'),value);
}),
alignV:makeProp(PROP_TYPE_STRING,null,function(value){
return arrayIncludes(concat(COMMON_ALIGNMENT,'baseline','stretch'),value);
}),
noGutters:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div')})),
NAME_ROW);
};// --- Main component ---
// We do not use `Vue.extend()` here as that would evaluate the props
// immediately, which we do not want to happen
// @vue/component

var BRow={
name:NAME_ROW,
functional:true,

get props(){
// Allow props to be lazy evaled on first access and
// then they become a non-getter afterwards
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Functions/get#Smart_self-overwriting_lazy_getters
delete this.props;
this.props=generateProps$2();
return this.props;
},

render:function render(h,_ref){
var _classList$push;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var alignV=props.alignV,
alignH=props.alignH,
alignContent=props.alignContent;// Loop through row-cols breakpoint props and generate the classes

var classList=[];
rowColsPropList.forEach(function(prop){
var c=computeRowColsClass(computeRowColsBreakpoint(prop),props[prop]);// If a class is returned, push it onto the array

if(c){
classList.push(c);
}
});
classList.push((_classList$push={
'no-gutters':props.noGutters},
_defineProperty(_classList$push,"align-items-".concat(alignV),alignV),_defineProperty(_classList$push,"justify-content-".concat(alignH),alignH),_defineProperty(_classList$push,"align-content-".concat(alignContent),alignContent),_classList$push));
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'row',
class:classList}),
children);
}};


var LayoutPlugin=/*#__PURE__*/pluginFactory({
components:{
BContainer:BContainer,
BRow:BRow,
BCol:BCol,
BFormRow:BFormRow}});



var LinkPlugin=/*#__PURE__*/pluginFactory({
components:{
BLink:BLink}});



var props$1m=makePropsConfigurable({
flush:makeProp(PROP_TYPE_BOOLEAN,false),
horizontal:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_LIST_GROUP);// --- Main component ---
// @vue/component

var BListGroup=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_LIST_GROUP,
functional:true,
props:props$1m,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var horizontal=props.horizontal===''?true:props.horizontal;
horizontal=props.flush?false:horizontal;
var componentData={
staticClass:'list-group',
class:_defineProperty({
'list-group-flush':props.flush,
'list-group-horizontal':horizontal===true},
"list-group-horizontal-".concat(horizontal),isString(horizontal))};

return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,componentData),children);
}});


var actionTags=['a','router-link','button','b-link'];// --- Props ---

var linkProps$4=omit(props$6,['event','routerTag']);
delete linkProps$4.href.default;
delete linkProps$4.to.default;
var props$1n=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},linkProps$4),{},{
action:makeProp(PROP_TYPE_BOOLEAN,false),
button:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div'),
variant:makeProp(PROP_TYPE_STRING)})),
NAME_LIST_GROUP_ITEM);// --- Main component ---
// @vue/component

var BListGroupItem=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_LIST_GROUP_ITEM,
functional:true,
props:props$1n,
render:function render(h,_ref){
var _class;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var button=props.button,
variant=props.variant,
active=props.active,
disabled=props.disabled;
var link=isLink(props);
var tag=button?'button':!link?props.tag:BLink;
var action=!!(props.action||link||button||arrayIncludes(actionTags,props.tag));
var attrs={};
var itemProps={};

if(isTag(tag,'button')){
if(!data.attrs||!data.attrs.type){
// Add a type for button is one not provided in passed attributes
attrs.type='button';
}

if(props.disabled){
// Set disabled attribute if button and disabled
attrs.disabled=true;
}
}else {
itemProps=pluckProps(linkProps$4,props);
}

return h(tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
attrs:attrs,
props:itemProps,
staticClass:'list-group-item',
class:(_class={},_defineProperty(_class,"list-group-item-".concat(variant),variant),_defineProperty(_class,'list-group-item-action',action),_defineProperty(_class,"active",active),_defineProperty(_class,"disabled",disabled),_class)}),
children);
}});


var ListGroupPlugin=/*#__PURE__*/pluginFactory({
components:{
BListGroup:BListGroup,
BListGroupItem:BListGroupItem}});



var props$1o=makePropsConfigurable({
right:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div'),
verticalAlign:makeProp(PROP_TYPE_STRING,'top')},
NAME_MEDIA_ASIDE);// --- Main component ---
// @vue/component

var BMediaAside=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_MEDIA_ASIDE,
functional:true,
props:props$1o,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var verticalAlign=props.verticalAlign;
var align=verticalAlign==='top'?'start':verticalAlign==='bottom'?'end':
/* istanbul ignore next */
verticalAlign;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'media-aside',
class:_defineProperty({
'media-aside-right':props.right},
"align-self-".concat(align),align)}),
children);
}});


var props$1p=makePropsConfigurable({
tag:makeProp(PROP_TYPE_STRING,'div')},
NAME_MEDIA_BODY);// --- Main component ---
// @vue/component

var BMediaBody=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_MEDIA_BODY,
functional:true,
props:props$1p,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'media-body'}),
children);
}});


var props$1q=makePropsConfigurable({
noBody:makeProp(PROP_TYPE_BOOLEAN,false),
rightAlign:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div'),
verticalAlign:makeProp(PROP_TYPE_STRING,'top')},
NAME_MEDIA);// --- Main component ---
// @vue/component

var BMedia=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_MEDIA,
functional:true,
props:props$1q,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots,
children=_ref.children;
var noBody=props.noBody,
rightAlign=props.rightAlign,
verticalAlign=props.verticalAlign;
var $children=noBody?children:[];

if(!noBody){
var slotScope={};
var $slots=slots();
var $scopedSlots=scopedSlots||{};
$children.push(h(BMediaBody,normalizeSlot(SLOT_NAME_DEFAULT,slotScope,$scopedSlots,$slots)));
var $aside=normalizeSlot(SLOT_NAME_ASIDE,slotScope,$scopedSlots,$slots);

if($aside){
$children[rightAlign?'push':'unshift'](h(BMediaAside,{
props:{
right:rightAlign,
verticalAlign:verticalAlign}},

$aside));
}
}

return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'media'}),
$children);
}});


var MediaPlugin=/*#__PURE__*/pluginFactory({
components:{
BMedia:BMedia,
BMediaAside:BMediaAside,
BMediaBody:BMediaBody}});



var PROP$1='$_bv_documentHandlers_';// --- Mixin ---
// @vue/component

var listenOnDocumentMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
created:function created(){
var _this=this;

/* istanbul ignore next */
if(!IS_BROWSER){
return;
}// Declare non-reactive property
// Object of arrays, keyed by event name,
// where value is an array of handlers
// Prop will be defined on client only


this[PROP$1]={};// Set up our beforeDestroy handler (client only)

this.$once(HOOK_EVENT_NAME_BEFORE_DESTROY,function(){
var items=_this[PROP$1]||{};// Immediately delete this[PROP] to prevent the
// listenOn/Off methods from running (which may occur
// due to requestAnimationFrame/transition delays)

delete _this[PROP$1];// Remove all registered event handlers

keys(items).forEach(function(eventName){
var handlers=items[eventName]||[];
handlers.forEach(function(handler){
return eventOff(document,eventName,handler,EVENT_OPTIONS_NO_CAPTURE);
});
});
});
},
methods:{
listenDocument:function listenDocument(on,eventName,handler){
on?this.listenOnDocument(eventName,handler):this.listenOffDocument(eventName,handler);
},
listenOnDocument:function listenOnDocument(eventName,handler){
if(this[PROP$1]&&isString(eventName)&&isFunction(handler)){
this[PROP$1][eventName]=this[PROP$1][eventName]||[];

if(!arrayIncludes(this[PROP$1][eventName],handler)){
this[PROP$1][eventName].push(handler);
eventOn(document,eventName,handler,EVENT_OPTIONS_NO_CAPTURE);
}
}
},
listenOffDocument:function listenOffDocument(eventName,handler){
if(this[PROP$1]&&isString(eventName)&&isFunction(handler)){
eventOff(document,eventName,handler,EVENT_OPTIONS_NO_CAPTURE);
this[PROP$1][eventName]=(this[PROP$1][eventName]||[]).filter(function(h){
return h!==handler;
});
}
}}});



var PROP$2='$_bv_windowHandlers_';// --- Mixin ---
// @vue/component

var listenOnWindowMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
beforeCreate:function beforeCreate(){
// Declare non-reactive property
// Object of arrays, keyed by event name,
// where value is an array of handlers
this[PROP$2]={};
},
beforeDestroy:function beforeDestroy(){
if(IS_BROWSER){
var items=this[PROP$2];// Immediately delete this[PROP] to prevent the
// listenOn/Off methods from running (which may occur
// due to requestAnimationFrame delays)

delete this[PROP$2];// Remove all registered event handlers

keys(items).forEach(function(eventName){
var handlers=items[eventName]||[];
handlers.forEach(function(handler){
return eventOff(window,eventName,handler,EVENT_OPTIONS_NO_CAPTURE);
});
});
}
},
methods:{
listenWindow:function listenWindow(on,eventName,handler){
on?this.listenOnWindow(eventName,handler):this.listenOffWindow(eventName,handler);
},
listenOnWindow:function listenOnWindow(eventName,handler){
if(IS_BROWSER&&this[PROP$2]&&isString(eventName)&&isFunction(handler)){
this[PROP$2][eventName]=this[PROP$2][eventName]||[];

if(!arrayIncludes(this[PROP$2][eventName],handler)){
this[PROP$2][eventName].push(handler);
eventOn(window,eventName,handler,EVENT_OPTIONS_NO_CAPTURE);
}
}
},
listenOffWindow:function listenOffWindow(eventName,handler){
if(IS_BROWSER&&this[PROP$2]&&isString(eventName)&&isFunction(handler)){
eventOff(window,eventName,handler,EVENT_OPTIONS_NO_CAPTURE);
this[PROP$2][eventName]=(this[PROP$2][eventName]||[]).filter(function(h){
return h!==handler;
});
}
}}});



// This method returns a component's scoped style attribute name: `data-v-xxxxxxx`
// The `_scopeId` options property is added by vue-loader when using scoped styles
// and will be `undefined` if no scoped styles are in use
var getScopeId=function getScopeId(vm){
var defaultValue=arguments.length>1&&arguments[1]!==undefined?arguments[1]:null;
return vm?vm.$options._scopeId||defaultValue:defaultValue;
};

var scopedStyleMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
computed:{
scopedStyleAttrs:function scopedStyleAttrs(){
var scopeId=getScopeId(this.$parent);
return scopeId?_defineProperty({},scopeId,''):{};
}}});



// BVTransporter/BVTransporterTarget:
//
// Single root node portaling of content, which retains parent/child hierarchy
// Unlike Portal-Vue where portaled content is no longer a descendent of its
// intended parent components
//
// Private components for use by Tooltips, Popovers and Modals
//
// Based on vue-simple-portal
// https://github.com/LinusBorg/vue-simple-portal
// Transporter target used by BVTransporter
// Supports only a single root element
// @vue/component

var BVTransporterTarget=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
// As an abstract component, it doesn't appear in the $parent chain of
// components, which means the next parent of any component rendered inside
// of this one will be the parent from which is was portal'd
abstract:true,
name:NAME_TRANSPORTER_TARGET,
props:{
// Even though we only support a single root element,
// VNodes are always passed as an array
nodes:makeProp(PROP_TYPE_ARRAY_FUNCTION)},

data:function data(vm){
return {
updatedNodes:vm.nodes};

},
destroyed:function destroyed(){
removeNode(this.$el);
},
render:function render(h){
var updatedNodes=this.updatedNodes;
var $nodes=isFunction(updatedNodes)?updatedNodes({}):updatedNodes;
$nodes=concat($nodes).filter(identity);

if($nodes&&$nodes.length>0&&!$nodes[0].text){
return $nodes[0];
}
/* istanbul ignore next */


return h();
}});
// --- Props ---

var props$1r={
// String: CSS selector,
// HTMLElement: Element reference
// Mainly needed for tooltips/popovers inside modals
container:makeProp([HTMLElement,PROP_TYPE_STRING],'body'),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
// This should be set to match the root element type
tag:makeProp(PROP_TYPE_STRING,'div')};
// --- Main component ---
// @vue/component

var BVTransporter=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TRANSPORTER,
mixins:[normalizeSlotMixin],
props:props$1r,
watch:{
disabled:{
immediate:true,
handler:function handler(disabled){
disabled?this.unmountTarget():this.$nextTick(this.mountTarget);
}}},


created:function created(){
// Create private non-reactive props
this.$_defaultFn=null;
this.$_target=null;
},
beforeMount:function beforeMount(){
this.mountTarget();
},
updated:function updated(){
// We need to make sure that all children have completed updating
// before rendering in the target
// `vue-simple-portal` has the this in a `$nextTick()`,
// while `portal-vue` doesn't
// Just trying to see if the `$nextTick()` delay is required or not
// Since all slots in Vue 2.6.x are always functions
this.updateTarget();
},
beforeDestroy:function beforeDestroy(){
this.unmountTarget();
this.$_defaultFn=null;
},
methods:{
// Get the element which the target should be appended to
getContainer:function getContainer(){
/* istanbul ignore else */
if(IS_BROWSER){
var container=this.container;
return isString(container)?select(container):container;
}else {
return null;
}
},
// Mount the target
mountTarget:function mountTarget(){
if(!this.$_target){
var $container=this.getContainer();

if($container){
var $el=document.createElement('div');
$container.appendChild($el);
this.$_target=new BVTransporterTarget({
el:$el,
parent:this,
propsData:{
// Initial nodes to be rendered
nodes:concat(this.normalizeSlot())}});


}
}
},
// Update the content of the target
updateTarget:function updateTarget(){
if(IS_BROWSER&&this.$_target){
var defaultFn=this.$scopedSlots.default;

if(!this.disabled){
/* istanbul ignore else: only applicable in Vue 2.5.x */
if(defaultFn&&this.$_defaultFn!==defaultFn){
// We only update the target component if the scoped slot
// function is a fresh one. The new slot syntax (since Vue 2.6)
// can cache unchanged slot functions and we want to respect that here
this.$_target.updatedNodes=defaultFn;
}else if(!defaultFn){
// We also need to be back compatible with non-scoped default slot (i.e. 2.5.x)
this.$_target.updatedNodes=this.$slots.default;
}
}// Update the scoped slot function cache


this.$_defaultFn=defaultFn;
}
},
// Unmount the target
unmountTarget:function unmountTarget(){
this.$_target&&this.$_target.$destroy();
this.$_target=null;
}},

render:function render(h){
// This component has no root element, so only a single VNode is allowed
if(this.disabled){
var $nodes=concat(this.normalizeSlot()).filter(identity);

if($nodes.length>0&&!$nodes[0].text){
return $nodes[0];
}
}

return h();
}});


var BvModalEvent=/*#__PURE__*/function(_BvEvent){
_inherits(BvModalEvent,_BvEvent);

var _super=_createSuper(BvModalEvent);

function BvModalEvent(type){
var _this;

var eventInit=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

_classCallCheck(this,BvModalEvent);

_this=_super.call(this,type,eventInit);// Freeze our new props as readonly, but leave them enumerable

defineProperties(_assertThisInitialized(_this),{
trigger:readonlyDescriptor()});

return _this;
}

_createClass(BvModalEvent,null,[{
key:"Defaults",
get:function get(){
return _objectSpread2(_objectSpread2({},_get(_getPrototypeOf(BvModalEvent),"Defaults",this)),{},{
trigger:null});

}}]);


return BvModalEvent;
}(BvEvent);// Named exports

/**
 * Private ModalManager helper
 * Handles controlling modal stacking zIndexes and body adjustments/classes
 */
// Default modal backdrop z-index

var DEFAULT_ZINDEX=1040;// Selectors for padding/margin adjustments

var SELECTOR_FIXED_CONTENT='.fixed-top, .fixed-bottom, .is-fixed, .sticky-top';
var SELECTOR_STICKY_CONTENT='.sticky-top';
var SELECTOR_NAVBAR_TOGGLER='.navbar-toggler';// --- Main component ---
// @vue/component

var ModalManager=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
data:function data(){
return {
modals:[],
baseZIndex:null,
scrollbarWidth:null,
isBodyOverflowing:false};

},
computed:{
modalCount:function modalCount(){
return this.modals.length;
},
modalsAreOpen:function modalsAreOpen(){
return this.modalCount>0;
}},

watch:{
modalCount:function modalCount(newCount,oldCount){
if(IS_BROWSER){
this.getScrollbarWidth();

if(newCount>0&&oldCount===0){
// Transitioning to modal(s) open
this.checkScrollbar();
this.setScrollbar();
addClass(document.body,'modal-open');
}else if(newCount===0&&oldCount>0){
// Transitioning to modal(s) closed
this.resetScrollbar();
removeClass(document.body,'modal-open');
}

setAttr(document.body,'data-modal-open-count',String(newCount));
}
},
modals:function modals(newValue){
var _this=this;

this.checkScrollbar();
requestAF(function(){
_this.updateModals(newValue||[]);
});
}},

methods:{
// Public methods
registerModal:function registerModal(modal){
var _this2=this;

// Register the modal if not already registered
if(modal&&this.modals.indexOf(modal)===-1){
// Add modal to modals array
this.modals.push(modal);
modal.$once(HOOK_EVENT_NAME_BEFORE_DESTROY,function(){
_this2.unregisterModal(modal);
});
}
},
unregisterModal:function unregisterModal(modal){
var index=this.modals.indexOf(modal);

if(index>-1){
// Remove modal from modals array
this.modals.splice(index,1);// Reset the modal's data

if(!(modal._isBeingDestroyed||modal._isDestroyed)){
this.resetModal(modal);
}
}
},
getBaseZIndex:function getBaseZIndex(){
if(isNull(this.baseZIndex)&&IS_BROWSER){
// Create a temporary `div.modal-backdrop` to get computed z-index
var div=document.createElement('div');
addClass(div,'modal-backdrop');
addClass(div,'d-none');
setStyle(div,'display','none');
document.body.appendChild(div);
this.baseZIndex=toInteger(getCS(div).zIndex,DEFAULT_ZINDEX);
document.body.removeChild(div);
}

return this.baseZIndex||DEFAULT_ZINDEX;
},
getScrollbarWidth:function getScrollbarWidth(){
if(isNull(this.scrollbarWidth)&&IS_BROWSER){
// Create a temporary `div.measure-scrollbar` to get computed z-index
var div=document.createElement('div');
addClass(div,'modal-scrollbar-measure');
document.body.appendChild(div);
this.scrollbarWidth=getBCR(div).width-div.clientWidth;
document.body.removeChild(div);
}

return this.scrollbarWidth||0;
},
// Private methods
updateModals:function updateModals(modals){
var _this3=this;

var baseZIndex=this.getBaseZIndex();
var scrollbarWidth=this.getScrollbarWidth();
modals.forEach(function(modal,index){
// We update data values on each modal
modal.zIndex=baseZIndex+index;
modal.scrollbarWidth=scrollbarWidth;
modal.isTop=index===_this3.modals.length-1;
modal.isBodyOverflowing=_this3.isBodyOverflowing;
});
},
resetModal:function resetModal(modal){
if(modal){
modal.zIndex=this.getBaseZIndex();
modal.isTop=true;
modal.isBodyOverflowing=false;
}
},
checkScrollbar:function checkScrollbar(){
// Determine if the body element is overflowing
var _getBCR=getBCR(document.body),
left=_getBCR.left,
right=_getBCR.right;

this.isBodyOverflowing=left+right<window.innerWidth;
},
setScrollbar:function setScrollbar(){
var body=document.body;// Storage place to cache changes to margins and padding
// Note: This assumes the following element types are not added to the
// document after the modal has opened.

body._paddingChangedForModal=body._paddingChangedForModal||[];
body._marginChangedForModal=body._marginChangedForModal||[];

if(this.isBodyOverflowing){
var scrollbarWidth=this.scrollbarWidth;// Adjust fixed content padding

/* istanbul ignore next: difficult to test in JSDOM */

selectAll(SELECTOR_FIXED_CONTENT).forEach(function(el){
var actualPadding=getStyle(el,'paddingRight')||'';
setAttr(el,'data-padding-right',actualPadding);
setStyle(el,'paddingRight',"".concat(toFloat(getCS(el).paddingRight,0)+scrollbarWidth,"px"));

body._paddingChangedForModal.push(el);
});// Adjust sticky content margin

/* istanbul ignore next: difficult to test in JSDOM */

selectAll(SELECTOR_STICKY_CONTENT).forEach(function(el)
/* istanbul ignore next */
{
var actualMargin=getStyle(el,'marginRight')||'';
setAttr(el,'data-margin-right',actualMargin);
setStyle(el,'marginRight',"".concat(toFloat(getCS(el).marginRight,0)-scrollbarWidth,"px"));

body._marginChangedForModal.push(el);
});// Adjust <b-navbar-toggler> margin

/* istanbul ignore next: difficult to test in JSDOM */

selectAll(SELECTOR_NAVBAR_TOGGLER).forEach(function(el)
/* istanbul ignore next */
{
var actualMargin=getStyle(el,'marginRight')||'';
setAttr(el,'data-margin-right',actualMargin);
setStyle(el,'marginRight',"".concat(toFloat(getCS(el).marginRight,0)+scrollbarWidth,"px"));

body._marginChangedForModal.push(el);
});// Adjust body padding

var actualPadding=getStyle(body,'paddingRight')||'';
setAttr(body,'data-padding-right',actualPadding);
setStyle(body,'paddingRight',"".concat(toFloat(getCS(body).paddingRight,0)+scrollbarWidth,"px"));
}
},
resetScrollbar:function resetScrollbar(){
var body=document.body;

if(body._paddingChangedForModal){
// Restore fixed content padding
body._paddingChangedForModal.forEach(function(el){
/* istanbul ignore next: difficult to test in JSDOM */
if(hasAttr(el,'data-padding-right')){
setStyle(el,'paddingRight',getAttr(el,'data-padding-right')||'');
removeAttr(el,'data-padding-right');
}
});
}

if(body._marginChangedForModal){
// Restore sticky content and navbar-toggler margin
body._marginChangedForModal.forEach(function(el){
/* istanbul ignore next: difficult to test in JSDOM */
if(hasAttr(el,'data-margin-right')){
setStyle(el,'marginRight',getAttr(el,'data-margin-right')||'');
removeAttr(el,'data-margin-right');
}
});
}

body._paddingChangedForModal=null;
body._marginChangedForModal=null;// Restore body padding

if(hasAttr(body,'data-padding-right')){
setStyle(body,'paddingRight',getAttr(body,'data-padding-right')||'');
removeAttr(body,'data-padding-right');
}
}}});

// Create and export our modal manager instance

var modalManager=new ModalManager();

var _makeModelMixin$f=makeModelMixin('visible',{
type:PROP_TYPE_BOOLEAN,
defaultValue:false,
event:EVENT_NAME_CHANGE}),

modelMixin$e=_makeModelMixin$f.mixin,
modelProps$e=_makeModelMixin$f.props,
MODEL_PROP_NAME$e=_makeModelMixin$f.prop,
MODEL_EVENT_NAME$e=_makeModelMixin$f.event;

var TRIGGER_BACKDROP='backdrop';
var TRIGGER_ESC='esc';
var TRIGGER_FORCE='FORCE';
var TRIGGER_TOGGLE='toggle';
var BUTTON_CANCEL='cancel';// TODO: This should be renamed to 'close'

var BUTTON_CLOSE='headerclose';
var BUTTON_OK='ok';
var BUTTONS=[BUTTON_CANCEL,BUTTON_CLOSE,BUTTON_OK];// `ObserveDom` config to detect changes in modal content
// so that we can adjust the modal padding if needed

var OBSERVER_CONFIG={
subtree:true,
childList:true,
characterData:true,
attributes:true,
attributeFilter:['style','class']};
// --- Props ---

var props$1s=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$e),{},{
ariaLabel:makeProp(PROP_TYPE_STRING),
autoFocusButton:makeProp(PROP_TYPE_STRING,null,
/* istanbul ignore next */
function(value){
return isUndefinedOrNull(value)||arrayIncludes(BUTTONS,value);
}),
bodyBgVariant:makeProp(PROP_TYPE_STRING),
bodyClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
bodyTextVariant:makeProp(PROP_TYPE_STRING),
busy:makeProp(PROP_TYPE_BOOLEAN,false),
buttonSize:makeProp(PROP_TYPE_STRING),
cancelDisabled:makeProp(PROP_TYPE_BOOLEAN,false),
cancelTitle:makeProp(PROP_TYPE_STRING,'Cancel'),
cancelTitleHtml:makeProp(PROP_TYPE_STRING),
cancelVariant:makeProp(PROP_TYPE_STRING,'secondary'),
centered:makeProp(PROP_TYPE_BOOLEAN,false),
contentClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
dialogClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
footerBgVariant:makeProp(PROP_TYPE_STRING),
footerBorderVariant:makeProp(PROP_TYPE_STRING),
footerClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
footerTextVariant:makeProp(PROP_TYPE_STRING),
headerBgVariant:makeProp(PROP_TYPE_STRING),
headerBorderVariant:makeProp(PROP_TYPE_STRING),
headerClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
headerCloseContent:makeProp(PROP_TYPE_STRING,'&times;'),
headerCloseLabel:makeProp(PROP_TYPE_STRING,'Close'),
headerCloseVariant:makeProp(PROP_TYPE_STRING),
headerTextVariant:makeProp(PROP_TYPE_STRING),
// TODO: Rename to `noBackdrop` and deprecate `hideBackdrop`
hideBackdrop:makeProp(PROP_TYPE_BOOLEAN,false),
// TODO: Rename to `noFooter` and deprecate `hideFooter`
hideFooter:makeProp(PROP_TYPE_BOOLEAN,false),
// TODO: Rename to `noHeader` and deprecate `hideHeader`
hideHeader:makeProp(PROP_TYPE_BOOLEAN,false),
// TODO: Rename to `noHeaderClose` and deprecate `hideHeaderClose`
hideHeaderClose:makeProp(PROP_TYPE_BOOLEAN,false),
ignoreEnforceFocusSelector:makeProp(PROP_TYPE_ARRAY_STRING),
lazy:makeProp(PROP_TYPE_BOOLEAN,false),
modalClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
noCloseOnBackdrop:makeProp(PROP_TYPE_BOOLEAN,false),
noCloseOnEsc:makeProp(PROP_TYPE_BOOLEAN,false),
noEnforceFocus:makeProp(PROP_TYPE_BOOLEAN,false),
noFade:makeProp(PROP_TYPE_BOOLEAN,false),
noStacking:makeProp(PROP_TYPE_BOOLEAN,false),
okDisabled:makeProp(PROP_TYPE_BOOLEAN,false),
okOnly:makeProp(PROP_TYPE_BOOLEAN,false),
okTitle:makeProp(PROP_TYPE_STRING,'OK'),
okTitleHtml:makeProp(PROP_TYPE_STRING),
okVariant:makeProp(PROP_TYPE_STRING,'primary'),
// HTML Element, CSS selector string or Vue component instance
returnFocus:makeProp([HTMLElement,PROP_TYPE_OBJECT,PROP_TYPE_STRING]),
scrollable:makeProp(PROP_TYPE_BOOLEAN,false),
size:makeProp(PROP_TYPE_STRING,'md'),
static:makeProp(PROP_TYPE_BOOLEAN,false),
title:makeProp(PROP_TYPE_STRING),
titleClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
titleHtml:makeProp(PROP_TYPE_STRING),
titleSrOnly:makeProp(PROP_TYPE_BOOLEAN,false),
titleTag:makeProp(PROP_TYPE_STRING,'h5')})),
NAME_MODAL);// --- Main component ---
// @vue/component

var BModal=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_MODAL,
mixins:[attrsMixin,idMixin,modelMixin$e,listenOnDocumentMixin,listenOnRootMixin,listenOnWindowMixin,normalizeSlotMixin,scopedStyleMixin],
inheritAttrs:false,
props:props$1s,
data:function data(){
return {
isHidden:true,
// If modal should not be in document
isVisible:false,
// Controls modal visible state
isTransitioning:false,
// Used for style control
isShow:false,
// Used for style control
isBlock:false,
// Used for style control
isOpening:false,
// To signal that the modal is in the process of opening
isClosing:false,
// To signal that the modal is in the process of closing
ignoreBackdropClick:false,
// Used to signify if click out listener should ignore the click
isModalOverflowing:false,
// The following items are controlled by the modalManager instance
scrollbarWidth:0,
zIndex:modalManager.getBaseZIndex(),
isTop:true,
isBodyOverflowing:false};

},
computed:{
modalId:function modalId(){
return this.safeId();
},
modalOuterId:function modalOuterId(){
return this.safeId('__BV_modal_outer_');
},
modalHeaderId:function modalHeaderId(){
return this.safeId('__BV_modal_header_');
},
modalBodyId:function modalBodyId(){
return this.safeId('__BV_modal_body_');
},
modalTitleId:function modalTitleId(){
return this.safeId('__BV_modal_title_');
},
modalContentId:function modalContentId(){
return this.safeId('__BV_modal_content_');
},
modalFooterId:function modalFooterId(){
return this.safeId('__BV_modal_footer_');
},
modalBackdropId:function modalBackdropId(){
return this.safeId('__BV_modal_backdrop_');
},
modalClasses:function modalClasses(){
return [{
fade:!this.noFade,
show:this.isShow},
this.modalClass];
},
modalStyles:function modalStyles(){
var sbWidth="".concat(this.scrollbarWidth,"px");
return {
paddingLeft:!this.isBodyOverflowing&&this.isModalOverflowing?sbWidth:'',
paddingRight:this.isBodyOverflowing&&!this.isModalOverflowing?sbWidth:'',
// Needed to fix issue https://github.com/bootstrap-vue/bootstrap-vue/issues/3457
// Even though we are using v-show, we must ensure 'none' is restored in the styles
display:this.isBlock?'block':'none'};

},
dialogClasses:function dialogClasses(){
var _ref;

return [(_ref={},_defineProperty(_ref,"modal-".concat(this.size),this.size),_defineProperty(_ref,'modal-dialog-centered',this.centered),_defineProperty(_ref,'modal-dialog-scrollable',this.scrollable),_ref),this.dialogClass];
},
headerClasses:function headerClasses(){
var _ref2;

return [(_ref2={},_defineProperty(_ref2,"bg-".concat(this.headerBgVariant),this.headerBgVariant),_defineProperty(_ref2,"text-".concat(this.headerTextVariant),this.headerTextVariant),_defineProperty(_ref2,"border-".concat(this.headerBorderVariant),this.headerBorderVariant),_ref2),this.headerClass];
},
titleClasses:function titleClasses(){
return [{
'sr-only':this.titleSrOnly},
this.titleClass];
},
bodyClasses:function bodyClasses(){
var _ref3;

return [(_ref3={},_defineProperty(_ref3,"bg-".concat(this.bodyBgVariant),this.bodyBgVariant),_defineProperty(_ref3,"text-".concat(this.bodyTextVariant),this.bodyTextVariant),_ref3),this.bodyClass];
},
footerClasses:function footerClasses(){
var _ref4;

return [(_ref4={},_defineProperty(_ref4,"bg-".concat(this.footerBgVariant),this.footerBgVariant),_defineProperty(_ref4,"text-".concat(this.footerTextVariant),this.footerTextVariant),_defineProperty(_ref4,"border-".concat(this.footerBorderVariant),this.footerBorderVariant),_ref4),this.footerClass];
},
modalOuterStyle:function modalOuterStyle(){
// Styles needed for proper stacking of modals
return {
position:'absolute',
zIndex:this.zIndex};

},
slotScope:function slotScope(){
return {
cancel:this.onCancel,
close:this.onClose,
hide:this.hide,
ok:this.onOk,
visible:this.isVisible};

},
computeIgnoreEnforceFocusSelector:function computeIgnoreEnforceFocusSelector(){
// Normalize to an single selector with selectors separated by `,`
return concat(this.ignoreEnforceFocusSelector).filter(identity).join(',').trim();
},
computedAttrs:function computedAttrs(){
// If the parent has a scoped style attribute, and the modal
// is portalled, add the scoped attribute to the modal wrapper
var scopedStyleAttrs=!this.static?this.scopedStyleAttrs:{};
return _objectSpread2(_objectSpread2(_objectSpread2({},scopedStyleAttrs),this.bvAttrs),{},{
id:this.modalOuterId});

},
computedModalAttrs:function computedModalAttrs(){
var isVisible=this.isVisible,
ariaLabel=this.ariaLabel;
return {
id:this.modalId,
role:'dialog',
'aria-hidden':isVisible?null:'true',
'aria-modal':isVisible?'true':null,
'aria-label':ariaLabel,
'aria-labelledby':this.hideHeader||ariaLabel||// TODO: Rename slot to `title` and deprecate `modal-title`
!(this.hasNormalizedSlot(SLOT_NAME_MODAL_TITLE)||this.titleHtml||this.title)?null:this.modalTitleId,
'aria-describedby':this.modalBodyId};

}},

watch:_defineProperty({},MODEL_PROP_NAME$e,function(newValue,oldValue){
if(newValue!==oldValue){
this[newValue?'show':'hide']();
}
}),
created:function created(){
// Define non-reactive properties
this.$_observer=null;
this.$_returnFocus=this.returnFocus||null;
},
mounted:function mounted(){
// Set initial z-index as queried from the DOM
this.zIndex=modalManager.getBaseZIndex();// Listen for events from others to either open or close ourselves
// and listen to all modals to enable/disable enforce focus

this.listenOnRoot(getRootActionEventName(NAME_MODAL,EVENT_NAME_SHOW),this.showHandler);
this.listenOnRoot(getRootActionEventName(NAME_MODAL,EVENT_NAME_HIDE),this.hideHandler);
this.listenOnRoot(getRootActionEventName(NAME_MODAL,EVENT_NAME_TOGGLE),this.toggleHandler);// Listen for `bv:modal::show events`, and close ourselves if the
// opening modal not us

this.listenOnRoot(getRootEventName(NAME_MODAL,EVENT_NAME_SHOW),this.modalListener);// Initially show modal?

if(this[MODEL_PROP_NAME$e]===true){
this.$nextTick(this.show);
}
},
beforeDestroy:function beforeDestroy(){
// Ensure everything is back to normal
this.setObserver(false);

if(this.isVisible){
this.isVisible=false;
this.isShow=false;
this.isTransitioning=false;
}
},
methods:{
setObserver:function setObserver(){
var on=arguments.length>0&&arguments[0]!==undefined?arguments[0]:false;
this.$_observer&&this.$_observer.disconnect();
this.$_observer=null;

if(on){
this.$_observer=observeDom(this.$refs.content,this.checkModalOverflow.bind(this),OBSERVER_CONFIG);
}
},
// Private method to update the v-model
updateModel:function updateModel(value){
if(value!==this[MODEL_PROP_NAME$e]){
this.$emit(MODEL_EVENT_NAME$e,value);
}
},
// Private method to create a BvModalEvent object
buildEvent:function buildEvent(type){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
return new BvModalEvent(type,_objectSpread2(_objectSpread2({
// Default options
cancelable:false,
target:this.$refs.modal||this.$el||null,
relatedTarget:null,
trigger:null},
options),{},{
// Options that can't be overridden
vueTarget:this,
componentId:this.modalId}));

},
// Public method to show modal
show:function show(){
if(this.isVisible||this.isOpening){
// If already open, or in the process of opening, do nothing

/* istanbul ignore next */
return;
}
/* istanbul ignore next */


if(this.isClosing){
// If we are in the process of closing, wait until hidden before re-opening

/* istanbul ignore next */
this.$once(EVENT_NAME_HIDDEN,this.show);
/* istanbul ignore next */

return;
}

this.isOpening=true;// Set the element to return focus to when closed

this.$_returnFocus=this.$_returnFocus||this.getActiveElement();
var showEvt=this.buildEvent(EVENT_NAME_SHOW,{
cancelable:true});

this.emitEvent(showEvt);// Don't show if canceled

if(showEvt.defaultPrevented||this.isVisible){
this.isOpening=false;// Ensure the v-model reflects the current state

this.updateModel(false);
return;
}// Show the modal


this.doShow();
},
// Public method to hide modal
hide:function hide(){
var trigger=arguments.length>0&&arguments[0]!==undefined?arguments[0]:'';

if(!this.isVisible||this.isClosing){
/* istanbul ignore next */
return;
}

this.isClosing=true;
var hideEvt=this.buildEvent(EVENT_NAME_HIDE,{
cancelable:trigger!==TRIGGER_FORCE,
trigger:trigger||null});
// We emit specific event for one of the three built-in buttons

if(trigger===BUTTON_OK){
this.$emit(EVENT_NAME_OK,hideEvt);
}else if(trigger===BUTTON_CANCEL){
this.$emit(EVENT_NAME_CANCEL,hideEvt);
}else if(trigger===BUTTON_CLOSE){
this.$emit(EVENT_NAME_CLOSE,hideEvt);
}

this.emitEvent(hideEvt);// Hide if not canceled

if(hideEvt.defaultPrevented||!this.isVisible){
this.isClosing=false;// Ensure v-model reflects current state

this.updateModel(true);
return;
}// Stop observing for content changes


this.setObserver(false);// Trigger the hide transition

this.isVisible=false;// Update the v-model

this.updateModel(false);
},
// Public method to toggle modal visibility
toggle:function toggle(triggerEl){
if(triggerEl){
this.$_returnFocus=triggerEl;
}

if(this.isVisible){
this.hide(TRIGGER_TOGGLE);
}else {
this.show();
}
},
// Private method to get the current document active element
getActiveElement:function getActiveElement$1(){
// Returning focus to `document.body` may cause unwanted scrolls,
// so we exclude setting focus on body
var activeElement=getActiveElement(IS_BROWSER?[document.body]:[]);// Preset the fallback return focus value if it is not set
// `document.activeElement` should be the trigger element that was clicked or
// in the case of using the v-model, which ever element has current focus
// Will be overridden by some commands such as toggle, etc.
// Note: On IE 11, `document.activeElement` may be `null`
// So we test it for truthiness first
// https://github.com/bootstrap-vue/bootstrap-vue/issues/3206


return activeElement&&activeElement.focus?activeElement:null;
},
// Private method to finish showing modal
doShow:function doShow(){
var _this=this;

/* istanbul ignore next: commenting out for now until we can test stacking */
if(modalManager.modalsAreOpen&&this.noStacking){
// If another modal(s) is already open, wait for it(them) to close
this.listenOnRootOnce(getRootEventName(NAME_MODAL,EVENT_NAME_HIDDEN),this.doShow);
return;
}

modalManager.registerModal(this);// Place modal in DOM

this.isHidden=false;
this.$nextTick(function(){
// We do this in `$nextTick()` to ensure the modal is in DOM first
// before we show it
_this.isVisible=true;
_this.isOpening=false;// Update the v-model

_this.updateModel(true);

_this.$nextTick(function(){
// Observe changes in modal content and adjust if necessary
// In a `$nextTick()` in case modal content is lazy
_this.setObserver(true);
});
});
},
// Transition handlers
onBeforeEnter:function onBeforeEnter(){
this.isTransitioning=true;
this.setResizeEvent(true);
},
onEnter:function onEnter(){
var _this2=this;

this.isBlock=true;// We add the `show` class 1 frame later
// `requestAF()` runs the callback before the next repaint, so we need
// two calls to guarantee the next frame has been rendered

requestAF(function(){
requestAF(function(){
_this2.isShow=true;
});
});
},
onAfterEnter:function onAfterEnter(){
var _this3=this;

this.checkModalOverflow();
this.isTransitioning=false;// We use `requestAF()` to allow transition hooks to complete
// before passing control over to the other handlers
// This will allow users to not have to use `$nextTick()` or `requestAF()`
// when trying to pre-focus an element

requestAF(function(){
_this3.emitEvent(_this3.buildEvent(EVENT_NAME_SHOWN));

_this3.setEnforceFocus(true);

_this3.$nextTick(function(){
// Delayed in a `$nextTick()` to allow users time to pre-focus
// an element if the wish
_this3.focusFirst();
});
});
},
onBeforeLeave:function onBeforeLeave(){
this.isTransitioning=true;
this.setResizeEvent(false);
this.setEnforceFocus(false);
},
onLeave:function onLeave(){
// Remove the 'show' class
this.isShow=false;
},
onAfterLeave:function onAfterLeave(){
var _this4=this;

this.isBlock=false;
this.isTransitioning=false;
this.isModalOverflowing=false;
this.isHidden=true;
this.$nextTick(function(){
_this4.isClosing=false;
modalManager.unregisterModal(_this4);

_this4.returnFocusTo();// TODO: Need to find a way to pass the `trigger` property
//       to the `hidden` event, not just only the `hide` event


_this4.emitEvent(_this4.buildEvent(EVENT_NAME_HIDDEN));
});
},
emitEvent:function emitEvent(bvEvent){
var type=bvEvent.type;// We emit on `$root` first in case a global listener wants to cancel
// the event first before the instance emits its event

this.emitOnRoot(getRootEventName(NAME_MODAL,type),bvEvent,bvEvent.componentId);
this.$emit(type,bvEvent);
},
// UI event handlers
onDialogMousedown:function onDialogMousedown(){
var _this5=this;

// Watch to see if the matching mouseup event occurs outside the dialog
// And if it does, cancel the clickOut handler
var modal=this.$refs.modal;

var onceModalMouseup=function onceModalMouseup(event){
eventOff(modal,'mouseup',onceModalMouseup,EVENT_OPTIONS_NO_CAPTURE);

if(event.target===modal){
_this5.ignoreBackdropClick=true;
}
};

eventOn(modal,'mouseup',onceModalMouseup,EVENT_OPTIONS_NO_CAPTURE);
},
onClickOut:function onClickOut(event){
if(this.ignoreBackdropClick){
// Click was initiated inside the modal content, but finished outside.
// Set by the above onDialogMousedown handler
this.ignoreBackdropClick=false;
return;
}// Do nothing if not visible, backdrop click disabled, or element
// that generated click event is no longer in document body


if(!this.isVisible||this.noCloseOnBackdrop||!contains(document.body,event.target)){
return;
}// If backdrop clicked, hide modal


if(!contains(this.$refs.content,event.target)){
this.hide(TRIGGER_BACKDROP);
}
},
onOk:function onOk(){
this.hide(BUTTON_OK);
},
onCancel:function onCancel(){
this.hide(BUTTON_CANCEL);
},
onClose:function onClose(){
this.hide(BUTTON_CLOSE);
},
onEsc:function onEsc(event){
// If ESC pressed, hide modal
if(event.keyCode===CODE_ESC&&this.isVisible&&!this.noCloseOnEsc){
this.hide(TRIGGER_ESC);
}
},
// Document focusin listener
focusHandler:function focusHandler(event){
// If focus leaves modal content, bring it back
var content=this.$refs.content;
var target=event.target;

if(this.noEnforceFocus||!this.isTop||!this.isVisible||!content||document===target||contains(content,target)||this.computeIgnoreEnforceFocusSelector&&closest(this.computeIgnoreEnforceFocusSelector,target,true)){
return;
}

var tabables=getTabables(this.$refs.content);
var bottomTrap=this.$refs['bottom-trap'];
var topTrap=this.$refs['top-trap'];

if(bottomTrap&&target===bottomTrap){
// If user pressed TAB out of modal into our bottom trab trap element
// Find the first tabable element in the modal content and focus it
if(attemptFocus(tabables[0])){
// Focus was successful
return;
}
}else if(topTrap&&target===topTrap){
// If user pressed CTRL-TAB out of modal and into our top tab trap element
// Find the last tabable element in the modal content and focus it
if(attemptFocus(tabables[tabables.length-1])){
// Focus was successful
return;
}
}// Otherwise focus the modal content container


attemptFocus(content,{
preventScroll:true});

},
// Turn on/off focusin listener
setEnforceFocus:function setEnforceFocus(on){
this.listenDocument(on,'focusin',this.focusHandler);
},
// Resize listener
setResizeEvent:function setResizeEvent(on){
this.listenWindow(on,'resize',this.checkModalOverflow);
this.listenWindow(on,'orientationchange',this.checkModalOverflow);
},
// Root listener handlers
showHandler:function showHandler(id,triggerEl){
if(id===this.modalId){
this.$_returnFocus=triggerEl||this.getActiveElement();
this.show();
}
},
hideHandler:function hideHandler(id){
if(id===this.modalId){
this.hide('event');
}
},
toggleHandler:function toggleHandler(id,triggerEl){
if(id===this.modalId){
this.toggle(triggerEl);
}
},
modalListener:function modalListener(bvEvent){
// If another modal opens, close this one if stacking not permitted
if(this.noStacking&&bvEvent.vueTarget!==this){
this.hide();
}
},
// Focus control handlers
focusFirst:function focusFirst(){
var _this6=this;

// Don't try and focus if we are SSR
if(IS_BROWSER){
requestAF(function(){
var modal=_this6.$refs.modal;
var content=_this6.$refs.content;

var activeElement=_this6.getActiveElement();// If the modal contains the activeElement, we don't do anything


if(modal&&content&&!(activeElement&&contains(content,activeElement))){
var ok=_this6.$refs['ok-button'];
var cancel=_this6.$refs['cancel-button'];
var close=_this6.$refs['close-button'];// Focus the appropriate button or modal content wrapper

var autoFocus=_this6.autoFocusButton;
/* istanbul ignore next */

var el=autoFocus===BUTTON_OK&&ok?ok.$el||ok:autoFocus===BUTTON_CANCEL&&cancel?cancel.$el||cancel:autoFocus===BUTTON_CLOSE&&close?close.$el||close:content;// Focus the element

attemptFocus(el);

if(el===content){
// Make sure top of modal is showing (if longer than the viewport)
_this6.$nextTick(function(){
modal.scrollTop=0;
});
}
}
});
}
},
returnFocusTo:function returnFocusTo(){
// Prefer `returnFocus` prop over event specified
// `return_focus` value
var el=this.returnFocus||this.$_returnFocus||null;
this.$_returnFocus=null;
this.$nextTick(function(){
// Is el a string CSS selector?
el=isString(el)?select(el):el;

if(el){
// Possibly could be a component reference
el=el.$el||el;
attemptFocus(el);
}
});
},
checkModalOverflow:function checkModalOverflow(){
if(this.isVisible){
var modal=this.$refs.modal;
this.isModalOverflowing=modal.scrollHeight>document.documentElement.clientHeight;
}
},
makeModal:function makeModal(h){
// Modal header
var $header=h();

if(!this.hideHeader){
// TODO: Rename slot to `header` and deprecate `modal-header`
var $modalHeader=this.normalizeSlot(SLOT_NAME_MODAL_HEADER,this.slotScope);

if(!$modalHeader){
var $closeButton=h();

if(!this.hideHeaderClose){
$closeButton=h(BButtonClose,{
props:{
content:this.headerCloseContent,
disabled:this.isTransitioning,
ariaLabel:this.headerCloseLabel,
textVariant:this.headerCloseVariant||this.headerTextVariant},

on:{
click:this.onClose},

ref:'close-button'},
// TODO: Rename slot to `header-close` and deprecate `modal-header-close`
[this.normalizeSlot(SLOT_NAME_MODAL_HEADER_CLOSE)]);
}

$modalHeader=[h(this.titleTag,{
staticClass:'modal-title',
class:this.titleClasses,
attrs:{
id:this.modalTitleId},

// TODO: Rename slot to `title` and deprecate `modal-title`
domProps:this.hasNormalizedSlot(SLOT_NAME_MODAL_TITLE)?{}:htmlOrText(this.titleHtml,this.title)},
// TODO: Rename slot to `title` and deprecate `modal-title`
this.normalizeSlot(SLOT_NAME_MODAL_TITLE,this.slotScope)),$closeButton];
}

$header=h('header',{
staticClass:'modal-header',
class:this.headerClasses,
attrs:{
id:this.modalHeaderId},

ref:'header'},
[$modalHeader]);
}// Modal body


var $body=h('div',{
staticClass:'modal-body',
class:this.bodyClasses,
attrs:{
id:this.modalBodyId},

ref:'body'},
this.normalizeSlot(SLOT_NAME_DEFAULT,this.slotScope));// Modal footer

var $footer=h();

if(!this.hideFooter){
// TODO: Rename slot to `footer` and deprecate `modal-footer`
var $modalFooter=this.normalizeSlot(SLOT_NAME_MODAL_FOOTER,this.slotScope);

if(!$modalFooter){
var $cancelButton=h();

if(!this.okOnly){
$cancelButton=h(BButton,{
props:{
variant:this.cancelVariant,
size:this.buttonSize,
disabled:this.cancelDisabled||this.busy||this.isTransitioning},

// TODO: Rename slot to `cancel-button` and deprecate `modal-cancel`
domProps:this.hasNormalizedSlot(SLOT_NAME_MODAL_CANCEL)?{}:htmlOrText(this.cancelTitleHtml,this.cancelTitle),
on:{
click:this.onCancel},

ref:'cancel-button'},
// TODO: Rename slot to `cancel-button` and deprecate `modal-cancel`
this.normalizeSlot(SLOT_NAME_MODAL_CANCEL));
}

var $okButton=h(BButton,{
props:{
variant:this.okVariant,
size:this.buttonSize,
disabled:this.okDisabled||this.busy||this.isTransitioning},

// TODO: Rename slot to `ok-button` and deprecate `modal-ok`
domProps:this.hasNormalizedSlot(SLOT_NAME_MODAL_OK)?{}:htmlOrText(this.okTitleHtml,this.okTitle),
on:{
click:this.onOk},

ref:'ok-button'},
// TODO: Rename slot to `ok-button` and deprecate `modal-ok`
this.normalizeSlot(SLOT_NAME_MODAL_OK));
$modalFooter=[$cancelButton,$okButton];
}

$footer=h('footer',{
staticClass:'modal-footer',
class:this.footerClasses,
attrs:{
id:this.modalFooterId},

ref:'footer'},
[$modalFooter]);
}// Assemble modal content


var $modalContent=h('div',{
staticClass:'modal-content',
class:this.contentClass,
attrs:{
id:this.modalContentId,
tabindex:'-1'},

ref:'content'},
[$header,$body,$footer]);// Tab traps to prevent page from scrolling to next element in
// tab index during enforce-focus tab cycle

var $tabTrapTop=h();
var $tabTrapBottom=h();

if(this.isVisible&&!this.noEnforceFocus){
$tabTrapTop=h('span',{
attrs:{
tabindex:'0'},

ref:'top-trap'});

$tabTrapBottom=h('span',{
attrs:{
tabindex:'0'},

ref:'bottom-trap'});

}// Modal dialog wrapper


var $modalDialog=h('div',{
staticClass:'modal-dialog',
class:this.dialogClasses,
on:{
mousedown:this.onDialogMousedown},

ref:'dialog'},
[$tabTrapTop,$modalContent,$tabTrapBottom]);// Modal

var $modal=h('div',{
staticClass:'modal',
class:this.modalClasses,
style:this.modalStyles,
attrs:this.computedModalAttrs,
on:{
keydown:this.onEsc,
click:this.onClickOut},

directives:[{
name:'show',
value:this.isVisible}],

ref:'modal'},
[$modalDialog]);// Wrap modal in transition
// Sadly, we can't use `BVTransition` here due to the differences in
// transition durations for `.modal` and `.modal-dialog`
// At least until https://github.com/vuejs/vue/issues/9986 is resolved

$modal=h('transition',{
props:{
enterClass:'',
enterToClass:'',
enterActiveClass:'',
leaveClass:'',
leaveActiveClass:'',
leaveToClass:''},

on:{
beforeEnter:this.onBeforeEnter,
enter:this.onEnter,
afterEnter:this.onAfterEnter,
beforeLeave:this.onBeforeLeave,
leave:this.onLeave,
afterLeave:this.onAfterLeave}},

[$modal]);// Modal backdrop

var $backdrop=h();

if(!this.hideBackdrop&&this.isVisible){
$backdrop=h('div',{
staticClass:'modal-backdrop',
attrs:{
id:this.modalBackdropId}},

// TODO: Rename slot to `backdrop` and deprecate `modal-backdrop`
this.normalizeSlot(SLOT_NAME_MODAL_BACKDROP));
}

$backdrop=h(BVTransition,{
props:{
noFade:this.noFade}},

[$backdrop]);// Assemble modal and backdrop in an outer <div>

return h('div',{
style:this.modalOuterStyle,
attrs:this.computedAttrs,
key:"modal-outer-".concat(this[COMPONENT_UID_KEY])},
[$modal,$backdrop]);
}},

render:function render(h){
if(this.static){
return this.lazy&&this.isHidden?h():this.makeModal(h);
}else {
return this.isHidden?h():h(BVTransporter,[this.makeModal(h)]);
}
}});


var ROOT_ACTION_EVENT_NAME_SHOW=getRootActionEventName(NAME_MODAL,EVENT_NAME_SHOW);// Prop name we use to store info on root element

var PROPERTY='__bv_modal_directive__';

var getTarget=function getTarget(_ref){
var _ref$modifiers=_ref.modifiers,
modifiers=_ref$modifiers===void 0?{}:_ref$modifiers,
arg=_ref.arg,
value=_ref.value;
// Try value, then arg, otherwise pick last modifier
return isString(value)?value:isString(arg)?arg:keys(modifiers).reverse()[0];
};

var getTriggerElement=function getTriggerElement(el){
// If root element is a dropdown-item or nav-item, we
// need to target the inner link or button instead
return el&&matches(el,'.dropdown-menu > li, li.nav-item')?select('a, button',el)||el:el;
};

var setRole=function setRole(trigger){
// Ensure accessibility on non button elements
if(trigger&&trigger.tagName!=='BUTTON'){
// Only set a role if the trigger element doesn't have one
if(!hasAttr(trigger,'role')){
setAttr(trigger,'role','button');
}// Add a tabindex is not a button or link, and tabindex is not provided


if(trigger.tagName!=='A'&&!hasAttr(trigger,'tabindex')){
setAttr(trigger,'tabindex','0');
}
}
};

var bind$1=function bind(el,binding,vnode){
var target=getTarget(binding);
var trigger=getTriggerElement(el);

if(target&&trigger){
var handler=function handler(event){
// `currentTarget` is the element with the listener on it
var currentTarget=event.currentTarget;

if(!isDisabled(currentTarget)){
var type=event.type;
var key=event.keyCode;// Open modal only if trigger is not disabled

if(type==='click'||type==='keydown'&&(key===CODE_ENTER||key===CODE_SPACE)){
vnode.context.$root.$emit(ROOT_ACTION_EVENT_NAME_SHOW,target,currentTarget);
}
}
};

el[PROPERTY]={
handler:handler,
target:target,
trigger:trigger};
// If element is not a button, we add `role="button"` for accessibility

setRole(trigger);// Listen for click events

eventOn(trigger,'click',handler,EVENT_OPTIONS_PASSIVE);

if(trigger.tagName!=='BUTTON'&&getAttr(trigger,'role')==='button'){
// If trigger isn't a button but has role button,
// we also listen for `keydown.space` && `keydown.enter`
eventOn(trigger,'keydown',handler,EVENT_OPTIONS_PASSIVE);
}
}
};

var unbind$1=function unbind(el){
var oldProp=el[PROPERTY]||{};
var trigger=oldProp.trigger;
var handler=oldProp.handler;

if(trigger&&handler){
eventOff(trigger,'click',handler,EVENT_OPTIONS_PASSIVE);
eventOff(trigger,'keydown',handler,EVENT_OPTIONS_PASSIVE);
eventOff(el,'click',handler,EVENT_OPTIONS_PASSIVE);
eventOff(el,'keydown',handler,EVENT_OPTIONS_PASSIVE);
}

delete el[PROPERTY];
};

var componentUpdated$1=function componentUpdated(el,binding,vnode){
var oldProp=el[PROPERTY]||{};
var target=getTarget(binding);
var trigger=getTriggerElement(el);

if(target!==oldProp.target||trigger!==oldProp.trigger){
// We bind and rebind if the target or trigger changes
unbind$1(el);
bind$1(el,binding,vnode);
}// If trigger element is not a button, ensure `role="button"`
// is still set for accessibility


setRole(trigger);
};

var updated=function updated(){};
/*
 * Export our directive
 */


var VBModal={
inserted:componentUpdated$1,
updated:updated,
componentUpdated:componentUpdated$1,
unbind:unbind$1};


var PROP_NAME$1='$bvModal';
var PROP_NAME_PRIV='_bv__modal';// Base modal props that are allowed
// Some may be ignored or overridden on some message boxes
// Prop ID is allowed, but really only should be used for testing
// We need to add it in explicitly as it comes from the `idMixin`

var BASE_PROPS=['id'].concat(_toConsumableArray(keys(omit(props$1s,['busy','lazy','noStacking','static','visible']))));// Fallback event resolver (returns undefined)

var defaultResolver=function defaultResolver(){};// Map prop names to modal slot names


var propsToSlots={
msgBoxContent:'default',
title:'modal-title',
okTitle:'modal-ok',
cancelTitle:'modal-cancel'};
// --- Helper methods ---
// Method to filter only recognized props that are not undefined

var filterOptions=function filterOptions(options){
return BASE_PROPS.reduce(function(memo,key){
if(!isUndefined(options[key])){
memo[key]=options[key];
}

return memo;
},{});
};// Method to install `$bvModal` VM injection


var plugin=function plugin(Vue){
// Create a private sub-component that extends BModal
// which self-destructs after hidden
// @vue/component
var BMsgBox=Vue.extend({
name:NAME_MSG_BOX,
extends:BModal,
destroyed:function destroyed(){
// Make sure we not in document any more
if(this.$el&&this.$el.parentNode){
this.$el.parentNode.removeChild(this.$el);
}
},
mounted:function mounted(){
var _this=this;

// Self destruct handler
var handleDestroy=function handleDestroy(){
_this.$nextTick(function(){
// In a `requestAF()` to release control back to application
requestAF(function(){
_this.$destroy();
});
});
};// Self destruct if parent destroyed


this.$parent.$once(HOOK_EVENT_NAME_DESTROYED,handleDestroy);// Self destruct after hidden

this.$once(EVENT_NAME_HIDDEN,handleDestroy);// Self destruct on route change

/* istanbul ignore if */

if(this.$router&&this.$route){
// Destroy ourselves if route changes

/* istanbul ignore next */
this.$once(HOOK_EVENT_NAME_BEFORE_DESTROY,this.$watch('$router',handleDestroy));
}// Show the `BMsgBox`


this.show();
}});
// Method to generate the on-demand modal message box
// Returns a promise that resolves to a value returned by the resolve

var asyncMsgBox=function asyncMsgBox($parent,props){
var resolver=arguments.length>2&&arguments[2]!==undefined?arguments[2]:defaultResolver;

if(warnNotClient(PROP_NAME$1)||warnNoPromiseSupport(PROP_NAME$1)){
/* istanbul ignore next */
return;
}// Create an instance of `BMsgBox` component


var msgBox=new BMsgBox({
// We set parent as the local VM so these modals can emit events on
// the app `$root`, as needed by things like tooltips and popovers
// And it helps to ensure `BMsgBox` is destroyed when parent is destroyed
parent:$parent,
// Preset the prop values
propsData:_objectSpread2(_objectSpread2(_objectSpread2({},filterOptions(getComponentConfig(NAME_MODAL))),{},{
// Defaults that user can override
hideHeaderClose:true,
hideHeader:!(props.title||props.titleHtml)},
omit(props,keys(propsToSlots))),{},{
// Props that can't be overridden
lazy:false,
busy:false,
visible:false,
noStacking:false,
noEnforceFocus:false})});

// Convert certain props to scoped slots

keys(propsToSlots).forEach(function(prop){
if(!isUndefined(props[prop])){
// Can be a string, or array of VNodes.
// Alternatively, user can use HTML version of prop to pass an HTML string.
msgBox.$slots[propsToSlots[prop]]=concat(props[prop]);
}
});// Return a promise that resolves when hidden, or rejects on destroyed

return new Promise(function(resolve,reject){
var resolved=false;
msgBox.$once(HOOK_EVENT_NAME_DESTROYED,function(){
if(!resolved){
/* istanbul ignore next */
reject(new Error('BootstrapVue MsgBox destroyed before resolve'));
}
});
msgBox.$on(EVENT_NAME_HIDE,function(bvModalEvt){
if(!bvModalEvt.defaultPrevented){
var result=resolver(bvModalEvt);// If resolver didn't cancel hide, we resolve

if(!bvModalEvt.defaultPrevented){
resolved=true;
resolve(result);
}
}
});// Create a mount point (a DIV) and mount the msgBo which will trigger it to show

var div=document.createElement('div');
document.body.appendChild(div);
msgBox.$mount(div);
});
};// Private utility method to open a user defined message box and returns a promise.
// Not to be used directly by consumers, as this method may change calling syntax


var makeMsgBox=function makeMsgBox($parent,content){
var options=arguments.length>2&&arguments[2]!==undefined?arguments[2]:{};
var resolver=arguments.length>3&&arguments[3]!==undefined?arguments[3]:null;

if(!content||warnNoPromiseSupport(PROP_NAME$1)||warnNotClient(PROP_NAME$1)||!isFunction(resolver)){
/* istanbul ignore next */
return;
}

return asyncMsgBox($parent,_objectSpread2(_objectSpread2({},filterOptions(options)),{},{
msgBoxContent:content}),
resolver);
};// BvModal instance class


var BvModal=/*#__PURE__*/function(){
function BvModal(vm){
_classCallCheck(this,BvModal);

// Assign the new properties to this instance
assign(this,{
_vm:vm,
_root:vm.$root});
// Set these properties as read-only and non-enumerable

defineProperties(this,{
_vm:readonlyDescriptor(),
_root:readonlyDescriptor()});

}// --- Instance methods ---
// Show modal with the specified ID args are for future use


_createClass(BvModal,[{
key:"show",
value:function show(id){
if(id&&this._root){
var _this$_root;

for(var _len=arguments.length,args=new Array(_len>1?_len-1:0),_key=1;_key<_len;_key++){
args[_key-1]=arguments[_key];
}

(_this$_root=this._root).$emit.apply(_this$_root,[getRootActionEventName(NAME_MODAL,'show'),id].concat(args));
}
}// Hide modal with the specified ID args are for future use
},
{
key:"hide",
value:function hide(id){
if(id&&this._root){
var _this$_root2;

for(var _len2=arguments.length,args=new Array(_len2>1?_len2-1:0),_key2=1;_key2<_len2;_key2++){
args[_key2-1]=arguments[_key2];
}

(_this$_root2=this._root).$emit.apply(_this$_root2,[getRootActionEventName(NAME_MODAL,'hide'),id].concat(args));
}
}// The following methods require Promise support!
// IE 11 and others do not support Promise natively, so users
// should have a Polyfill loaded (which they need anyways for IE 11 support)
// Open a message box with OK button only and returns a promise
},
{
key:"msgBoxOk",
value:function msgBoxOk(message){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

// Pick the modal props we support from options
var props=_objectSpread2(_objectSpread2({},options),{},{
// Add in overrides and our content prop
okOnly:true,
okDisabled:false,
hideFooter:false,
msgBoxContent:message});


return makeMsgBox(this._vm,message,props,function(){
// Always resolve to true for OK
return true;
});
}// Open a message box modal with OK and CANCEL buttons
// and returns a promise
},
{
key:"msgBoxConfirm",
value:function msgBoxConfirm(message){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

// Set the modal props we support from options
var props=_objectSpread2(_objectSpread2({},options),{},{
// Add in overrides and our content prop
okOnly:false,
okDisabled:false,
cancelDisabled:false,
hideFooter:false});


return makeMsgBox(this._vm,message,props,function(bvModalEvt){
var trigger=bvModalEvt.trigger;
return trigger==='ok'?true:trigger==='cancel'?false:null;
});
}}]);


return BvModal;
}();// Add our instance mixin


Vue.mixin({
beforeCreate:function beforeCreate(){
// Because we need access to `$root` for `$emits`, and VM for parenting,
// we have to create a fresh instance of `BvModal` for each VM
this[PROP_NAME_PRIV]=new BvModal(this);
}});
// Define our read-only `$bvModal` instance property
// Placed in an if just in case in HMR mode

if(!hasOwnProperty(Vue.prototype,PROP_NAME$1)){
defineProperty(Vue.prototype,PROP_NAME$1,{
get:function get(){
/* istanbul ignore next */
if(!this||!this[PROP_NAME_PRIV]){
warn("\"".concat(PROP_NAME$1,"\" must be accessed from a Vue instance \"this\" context."),NAME_MODAL);
}

return this[PROP_NAME_PRIV];
}});

}
};

var BVModalPlugin=/*#__PURE__*/pluginFactory({
plugins:{
plugin:plugin}});



var ModalPlugin=/*#__PURE__*/pluginFactory({
components:{
BModal:BModal},

directives:{
VBModal:VBModal},

// $bvModal injection
plugins:{
BVModalPlugin:BVModalPlugin}});



var computeJustifyContent=function computeJustifyContent(value){
value=value==='left'?'start':value==='right'?'end':value;
return "justify-content-".concat(value);
};// --- Props ---


var props$1t=makePropsConfigurable({
align:makeProp(PROP_TYPE_STRING),
// Set to `true` if placing in a card header
cardHeader:makeProp(PROP_TYPE_BOOLEAN,false),
fill:makeProp(PROP_TYPE_BOOLEAN,false),
justified:makeProp(PROP_TYPE_BOOLEAN,false),
pills:makeProp(PROP_TYPE_BOOLEAN,false),
small:makeProp(PROP_TYPE_BOOLEAN,false),
tabs:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'ul'),
vertical:makeProp(PROP_TYPE_BOOLEAN,false)},
NAME_NAV);// --- Main component ---
// @vue/component

var BNav=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAV,
functional:true,
props:props$1t,
render:function render(h,_ref){
var _class;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var tabs=props.tabs,
pills=props.pills,
vertical=props.vertical,
align=props.align,
cardHeader=props.cardHeader;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'nav',
class:(_class={
'nav-tabs':tabs,
'nav-pills':pills&&!tabs,
'card-header-tabs':!vertical&&cardHeader&&tabs,
'card-header-pills':!vertical&&cardHeader&&pills&&!tabs,
'flex-column':vertical,
'nav-fill':!vertical&&props.fill,
'nav-justified':!vertical&&props.justified},
_defineProperty(_class,computeJustifyContent(align),!vertical&&align),_defineProperty(_class,"small",props.small),_class)}),
children);
}});


var linkProps$5=omit(props$6,['event','routerTag']);
var props$1u=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},linkProps$5),{},{
linkAttrs:makeProp(PROP_TYPE_OBJECT,{}),
linkClasses:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)})),
NAME_NAV_ITEM);// --- Main component ---
// @vue/component

var BNavItem=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAV_ITEM,
functional:true,
props:props$1u,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
listeners=_ref.listeners,
children=_ref.children;
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['on']),{
staticClass:'nav-item'}),
[h(BLink,{
staticClass:'nav-link',
class:props.linkClasses,
attrs:props.linkAttrs,
props:pluckProps(linkProps$5,props),
on:listeners},
children)]);
}});


var props$1v={};// --- Main component ---
// @vue/component

var BNavText=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAV_TEXT,
functional:true,
props:props$1v,
render:function render(h,_ref){
var data=_ref.data,
children=_ref.children;
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'navbar-text'}),
children);
}});


var formProps=omit(props$F,['inline']);
var props$1w=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},formProps),{},{
formClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)})),
NAME_NAV_FORM);// --- Main component ---
// @vue/component

var BNavForm=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAV_FORM,
functional:true,
props:props$1w,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children,
listeners=_ref.listeners;
var $form=h(BForm,{
class:props.formClass,
props:_objectSpread2(_objectSpread2({},pluckProps(formProps,props)),{},{
inline:true}),

attrs:data.attrs,
on:listeners},
children);
return h('li',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(omit(data,['attrs','on']),{
staticClass:'form-inline'}),
[$form]);
}});


var props$1x=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$g),pick(props$A,[].concat(_toConsumableArray(keys(props$z)),['html','lazy','menuClass','noCaret','role','text','toggleClass'])))),NAME_NAV_ITEM_DROPDOWN);// --- Main component ---
// @vue/component

var BNavItemDropdown=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAV_ITEM_DROPDOWN,
mixins:[idMixin,dropdownMixin,normalizeSlotMixin],
props:props$1x,
computed:{
toggleId:function toggleId(){
return this.safeId('_BV_toggle_');
},
dropdownClasses:function dropdownClasses(){
return [this.directionClass,this.boundaryClass,{
show:this.visible}];

},
menuClasses:function menuClasses(){
return [this.menuClass,{
'dropdown-menu-right':this.right,
show:this.visible}];

},
toggleClasses:function toggleClasses(){
return [this.toggleClass,{
'dropdown-toggle-no-caret':this.noCaret}];

}},

render:function render(h){
var toggleId=this.toggleId,
visible=this.visible,
hide=this.hide;
var $toggle=h(BLink,{
staticClass:'nav-link dropdown-toggle',
class:this.toggleClasses,
props:{
href:"#".concat(this.id||''),
disabled:this.disabled},

attrs:{
id:toggleId,
role:'button',
'aria-haspopup':'true',
'aria-expanded':visible?'true':'false'},

on:{
mousedown:this.onMousedown,
click:this.toggle,
keydown:this.toggle// Handle ENTER, SPACE and DOWN
},

ref:'toggle'},
[// TODO: The `text` slot is deprecated in favor of the `button-content` slot
this.normalizeSlot([SLOT_NAME_BUTTON_CONTENT,SLOT_NAME_TEXT])||h('span',{
domProps:htmlOrText(this.html,this.text)})]);

var $menu=h('ul',{
staticClass:'dropdown-menu',
class:this.menuClasses,
attrs:{
tabindex:'-1',
'aria-labelledby':toggleId},

on:{
keydown:this.onKeydown// Handle UP, DOWN and ESC
},

ref:'menu'},
!this.lazy||visible?this.normalizeSlot(SLOT_NAME_DEFAULT,{
hide:hide}):
[h()]);
return h('li',{
staticClass:'nav-item b-nav-dropdown dropdown',
class:this.dropdownClasses,
attrs:{
id:this.safeId()}},

[$toggle,$menu]);
}});


var NavPlugin=/*#__PURE__*/pluginFactory({
components:{
BNav:BNav,
BNavItem:BNavItem,
BNavText:BNavText,
BNavForm:BNavForm,
BNavItemDropdown:BNavItemDropdown,
BNavItemDd:BNavItemDropdown,
BNavDropdown:BNavItemDropdown,
BNavDd:BNavItemDropdown},

plugins:{
DropdownPlugin:DropdownPlugin}});



var props$1y=makePropsConfigurable({
fixed:makeProp(PROP_TYPE_STRING),
print:makeProp(PROP_TYPE_BOOLEAN,false),
sticky:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'nav'),
toggleable:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
type:makeProp(PROP_TYPE_STRING,'light'),
variant:makeProp(PROP_TYPE_STRING)},
NAME_NAVBAR);// --- Main component ---
// @vue/component

var BNavbar=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAVBAR,
mixins:[normalizeSlotMixin],
provide:function provide(){
return {
bvNavbar:this};

},
props:props$1y,
computed:{
breakpointClass:function breakpointClass(){
var toggleable=this.toggleable;
var xs=getBreakpoints()[0];
var breakpoint=null;

if(toggleable&&isString(toggleable)&&toggleable!==xs){
breakpoint="navbar-expand-".concat(toggleable);
}else if(toggleable===false){
breakpoint='navbar-expand';
}

return breakpoint;
}},

render:function render(h){
var _ref;

var tag=this.tag,
type=this.type,
variant=this.variant,
fixed=this.fixed;
return h(tag,{
staticClass:'navbar',
class:[(_ref={
'd-print':this.print,
'sticky-top':this.sticky},
_defineProperty(_ref,"navbar-".concat(type),type),_defineProperty(_ref,"bg-".concat(variant),variant),_defineProperty(_ref,"fixed-".concat(fixed),fixed),_ref),this.breakpointClass],
attrs:{
role:isTag(tag,'nav')?null:'navigation'}},

[this.normalizeSlot()]);
}});


var computeJustifyContent$1=function computeJustifyContent(value){
value=value==='left'?'start':value==='right'?'end':value;
return "justify-content-".concat(value);
};// --- Props ---


var props$1z=makePropsConfigurable(pick(props$1t,['tag','fill','justified','align','small']),NAME_NAVBAR_NAV);// --- Main component ---
// @vue/component

var BNavbarNav=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAVBAR_NAV,
functional:true,
props:props$1z,
render:function render(h,_ref){
var _class;

var props=_ref.props,
data=_ref.data,
children=_ref.children;
var align=props.align;
return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'navbar-nav',
class:(_class={
'nav-fill':props.fill,
'nav-justified':props.justified},
_defineProperty(_class,computeJustifyContent$1(align),align),_defineProperty(_class,"small",props.small),_class)}),
children);
}});


var linkProps$6=omit(props$6,['event','routerTag']);
linkProps$6.href.default=undefined;
linkProps$6.to.default=undefined;
var props$1A=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},linkProps$6),{},{
tag:makeProp(PROP_TYPE_STRING,'div')})),
NAME_NAVBAR_BRAND);// --- Main component ---
// @vue/component

var BNavbarBrand=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAVBAR_BRAND,
functional:true,
props:props$1A,
render:function render(h,_ref){
var props=_ref.props,
data=_ref.data,
children=_ref.children;
var isLink=props.to||props.href;
var tag=isLink?BLink:props.tag;
return h(tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'navbar-brand',
props:isLink?pluckProps(linkProps$6,props):{}}),
children);
}});


var CLASS_NAME$2='navbar-toggler';
var ROOT_EVENT_NAME_STATE$2=getRootEventName(NAME_COLLAPSE,'state');
var ROOT_EVENT_NAME_SYNC_STATE$2=getRootEventName(NAME_COLLAPSE,'sync-state');// --- Props ---

var props$1B=makePropsConfigurable({
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
label:makeProp(PROP_TYPE_STRING,'Toggle navigation'),
target:makeProp(PROP_TYPE_ARRAY_STRING,undefined,true)// Required
},
NAME_NAVBAR_TOGGLE);// --- Main component ---
// @vue/component

var BNavbarToggle=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_NAVBAR_TOGGLE,
directives:{
VBToggle:VBToggle},

mixins:[listenOnRootMixin,normalizeSlotMixin],
props:props$1B,
data:function data(){
return {
toggleState:false};

},
created:function created(){
this.listenOnRoot(ROOT_EVENT_NAME_STATE$2,this.handleStateEvt);
this.listenOnRoot(ROOT_EVENT_NAME_SYNC_STATE$2,this.handleStateEvt);
},
methods:{
onClick:function onClick(event){
if(!this.disabled){
// Emit courtesy `click` event
this.$emit(EVENT_NAME_CLICK,event);
}
},
handleStateEvt:function handleStateEvt(id,state){
// We listen for state events so that we can pass the
// boolean expanded state to the default scoped slot
if(id===this.target){
this.toggleState=state;
}
}},

render:function render(h){
var disabled=this.disabled;
return h('button',{
staticClass:CLASS_NAME$2,
class:{
disabled:disabled},

directives:[{
name:'VBToggle',
value:this.target}],

attrs:{
type:'button',
disabled:disabled,
'aria-label':this.label},

on:{
click:this.onClick}},

[this.normalizeSlot(SLOT_NAME_DEFAULT,{
expanded:this.toggleState})||
h('span',{
staticClass:"".concat(CLASS_NAME$2,"-icon")})]);

}});


var NavbarPlugin=/*#__PURE__*/pluginFactory({
components:{
BNavbar:BNavbar,
BNavbarNav:BNavbarNav,
BNavbarBrand:BNavbarBrand,
BNavbarToggle:BNavbarToggle,
BNavToggle:BNavbarToggle},

plugins:{
NavPlugin:NavPlugin,
CollapsePlugin:CollapsePlugin,
DropdownPlugin:DropdownPlugin}});



var props$1C=makePropsConfigurable({
label:makeProp(PROP_TYPE_STRING),
role:makeProp(PROP_TYPE_STRING,'status'),
small:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'span'),
type:makeProp(PROP_TYPE_STRING,'border'),
variant:makeProp(PROP_TYPE_STRING)},
NAME_SPINNER);// --- Main component ---
// @vue/component

var BSpinner=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_SPINNER,
functional:true,
props:props$1C,
render:function render(h,_ref){
var _class;

var props=_ref.props,
data=_ref.data,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots;
var $slots=slots();
var $scopedSlots=scopedSlots||{};
var $label=normalizeSlot(SLOT_NAME_LABEL,{},$scopedSlots,$slots)||props.label;

if($label){
$label=h('span',{
staticClass:'sr-only'},
$label);
}

return h(props.tag,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
attrs:{
role:$label?props.role||'status':null,
'aria-hidden':$label?null:'true'},

class:(_class={},_defineProperty(_class,"spinner-".concat(props.type),props.type),_defineProperty(_class,"spinner-".concat(props.type,"-sm"),props.small),_defineProperty(_class,"text-".concat(props.variant),props.variant),_class)}),
[$label||h()]);
}});


var POSITION_COVER={
top:0,
left:0,
bottom:0,
right:0};
// --- Props ---

var props$1D=makePropsConfigurable({
// Alternative to variant, allowing a specific
// CSS color to be applied to the overlay
bgColor:makeProp(PROP_TYPE_STRING),
blur:makeProp(PROP_TYPE_STRING,'2px'),
fixed:makeProp(PROP_TYPE_BOOLEAN,false),
noCenter:makeProp(PROP_TYPE_BOOLEAN,false),
noFade:makeProp(PROP_TYPE_BOOLEAN,false),
// If `true, does not render the default slot
// and switches to absolute positioning
noWrap:makeProp(PROP_TYPE_BOOLEAN,false),
opacity:makeProp(PROP_TYPE_NUMBER_STRING,0.85,function(value){
var number=toFloat(value,0);
return number>=0&&number<=1;
}),
overlayTag:makeProp(PROP_TYPE_STRING,'div'),
rounded:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
show:makeProp(PROP_TYPE_BOOLEAN,false),
spinnerSmall:makeProp(PROP_TYPE_BOOLEAN,false),
spinnerType:makeProp(PROP_TYPE_STRING,'border'),
spinnerVariant:makeProp(PROP_TYPE_STRING),
variant:makeProp(PROP_TYPE_STRING,'light'),
wrapTag:makeProp(PROP_TYPE_STRING,'div'),
zIndex:makeProp(PROP_TYPE_NUMBER_STRING,10)},
NAME_OVERLAY);// --- Main component ---
// @vue/component

var BOverlay=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_OVERLAY,
mixins:[normalizeSlotMixin],
props:props$1D,
computed:{
computedRounded:function computedRounded(){
var rounded=this.rounded;
return rounded===true||rounded===''?'rounded':!rounded?'':"rounded-".concat(rounded);
},
computedVariant:function computedVariant(){
var variant=this.variant;
return variant&&!this.bgColor?"bg-".concat(variant):'';
},
slotScope:function slotScope(){
return {
spinnerType:this.spinnerType||null,
spinnerVariant:this.spinnerVariant||null,
spinnerSmall:this.spinnerSmall};

}},

methods:{
defaultOverlayFn:function defaultOverlayFn(_ref){
var spinnerType=_ref.spinnerType,
spinnerVariant=_ref.spinnerVariant,
spinnerSmall=_ref.spinnerSmall;
return this.$createElement(BSpinner,{
props:{
type:spinnerType,
variant:spinnerVariant,
small:spinnerSmall}});


}},

render:function render(h){
var _this=this;

var show=this.show,
fixed=this.fixed,
noFade=this.noFade,
noWrap=this.noWrap,
slotScope=this.slotScope;
var $overlay=h();

if(show){
var $background=h('div',{
staticClass:'position-absolute',
class:[this.computedVariant,this.computedRounded],
style:_objectSpread2(_objectSpread2({},POSITION_COVER),{},{
opacity:this.opacity,
backgroundColor:this.bgColor||null,
backdropFilter:this.blur?"blur(".concat(this.blur,")"):null})});


var $content=h('div',{
staticClass:'position-absolute',
style:this.noCenter?
/* istanbul ignore next */
_objectSpread2({},POSITION_COVER):{
top:'50%',
left:'50%',
transform:'translateX(-50%) translateY(-50%)'}},

[this.normalizeSlot(SLOT_NAME_OVERLAY,slotScope)||this.defaultOverlayFn(slotScope)]);
$overlay=h(this.overlayTag,{
staticClass:'b-overlay',
class:{
'position-absolute':!noWrap||noWrap&&!fixed,
'position-fixed':noWrap&&fixed},

style:_objectSpread2(_objectSpread2({},POSITION_COVER),{},{
zIndex:this.zIndex||10}),

on:{
click:function click(event){
return _this.$emit(EVENT_NAME_CLICK,event);
}},

key:'overlay'},
[$background,$content]);
}// Wrap in a fade transition


$overlay=h(BVTransition,{
props:{
noFade:noFade,
appear:true},

on:{
'after-enter':function afterEnter(){
return _this.$emit(EVENT_NAME_SHOWN);
},
'after-leave':function afterLeave(){
return _this.$emit(EVENT_NAME_HIDDEN);
}}},

[$overlay]);

if(noWrap){
return $overlay;
}

return h(this.wrapTag,{
staticClass:'b-overlay-wrap position-relative',
attrs:{
'aria-busy':show?'true':null}},

noWrap?[$overlay]:[this.normalizeSlot(),$overlay]);
}});


var OverlayPlugin=/*#__PURE__*/pluginFactory({
components:{
BOverlay:BOverlay}});



var _watch$e;
// for `<b-pagination>` and `<b-pagination-nav>`
// --- Constants ---

var _makeModelMixin$g=makeModelMixin('value',{
type:PROP_TYPE_BOOLEAN_NUMBER_STRING,
defaultValue:null,

/* istanbul ignore next */
validator:function validator(value){
if(!isNull(value)&&toInteger(value,0)<1){
warn('"v-model" value must be a number greater than "0"',NAME_PAGINATION);
return false;
}

return true;
}}),

modelMixin$f=_makeModelMixin$g.mixin,
modelProps$f=_makeModelMixin$g.props,
MODEL_PROP_NAME$f=_makeModelMixin$g.prop,
MODEL_EVENT_NAME$f=_makeModelMixin$g.event;

var ELLIPSIS_THRESHOLD=3;// Default # of buttons limit

var DEFAULT_LIMIT=5;// --- Helper methods ---
// Make an array of N to N+X

var makePageArray=function makePageArray(startNumber,numberOfPages){
return createArray(numberOfPages,function(_,i){
return {
number:startNumber+i,
classes:null};

});
};// Sanitize the provided limit value (converting to a number)


var sanitizeLimit=function sanitizeLimit(value){
var limit=toInteger(value)||1;
return limit<1?DEFAULT_LIMIT:limit;
};// Sanitize the provided current page number (converting to a number)


var sanitizeCurrentPage=function sanitizeCurrentPage(val,numberOfPages){
var page=toInteger(val)||1;
return page>numberOfPages?numberOfPages:page<1?1:page;
};// Links don't normally respond to SPACE, so we add that
// functionality via this handler


var onSpaceKey=function onSpaceKey(event){
if(event.keyCode===CODE_SPACE){
// Stop page from scrolling
stopEvent(event,{
immediatePropagation:true});
// Trigger the click event on the link

event.currentTarget.click();
return false;
}
};// --- Props ---


var props$1E=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},modelProps$f),{},{
align:makeProp(PROP_TYPE_STRING,'left'),
ariaLabel:makeProp(PROP_TYPE_STRING,'Pagination'),
disabled:makeProp(PROP_TYPE_BOOLEAN,false),
ellipsisClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
ellipsisText:makeProp(PROP_TYPE_STRING,"\u2026"),
// '…'
firstClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
firstNumber:makeProp(PROP_TYPE_BOOLEAN,false),
firstText:makeProp(PROP_TYPE_STRING,"\xAB"),
// '«'
hideEllipsis:makeProp(PROP_TYPE_BOOLEAN,false),
hideGotoEndButtons:makeProp(PROP_TYPE_BOOLEAN,false),
labelFirstPage:makeProp(PROP_TYPE_STRING,'Go to first page'),
labelLastPage:makeProp(PROP_TYPE_STRING,'Go to last page'),
labelNextPage:makeProp(PROP_TYPE_STRING,'Go to next page'),
labelPage:makeProp(PROP_TYPE_FUNCTION_STRING,'Go to page'),
labelPrevPage:makeProp(PROP_TYPE_STRING,'Go to previous page'),
lastClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
lastNumber:makeProp(PROP_TYPE_BOOLEAN,false),
lastText:makeProp(PROP_TYPE_STRING,"\xBB"),
// '»'
limit:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_LIMIT,
/* istanbul ignore next */
function(value){
if(toInteger(value,0)<1){
warn('Prop "limit" must be a number greater than "0"',NAME_PAGINATION);
return false;
}

return true;
}),
nextClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
nextText:makeProp(PROP_TYPE_STRING,"\u203A"),
// '›'
pageClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
pills:makeProp(PROP_TYPE_BOOLEAN,false),
prevClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
prevText:makeProp(PROP_TYPE_STRING,"\u2039"),
// '‹'
size:makeProp(PROP_TYPE_STRING)})),
'pagination');// --- Mixin ---
// @vue/component

var paginationMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[modelMixin$f,normalizeSlotMixin],
props:props$1E,
data:function data(){
// `-1` signifies no page initially selected
var currentPage=toInteger(this[MODEL_PROP_NAME$f],0);
currentPage=currentPage>0?currentPage:-1;
return {
currentPage:currentPage,
localNumberOfPages:1,
localLimit:DEFAULT_LIMIT};

},
computed:{
btnSize:function btnSize(){
var size=this.size;
return size?"pagination-".concat(size):'';
},
alignment:function alignment(){
var align=this.align;

if(align==='center'){
return 'justify-content-center';
}else if(align==='end'||align==='right'){
return 'justify-content-end';
}else if(align==='fill'){
// The page-items will also have 'flex-fill' added
// We add text centering to make the button appearance better in fill mode
return 'text-center';
}

return '';
},
styleClass:function styleClass(){
return this.pills?'b-pagination-pills':'';
},
computedCurrentPage:function computedCurrentPage(){
return sanitizeCurrentPage(this.currentPage,this.localNumberOfPages);
},
paginationParams:function paginationParams(){
// Determine if we should show the the ellipsis
var limit=this.localLimit,
numberOfPages=this.localNumberOfPages,
currentPage=this.computedCurrentPage,
hideEllipsis=this.hideEllipsis,
firstNumber=this.firstNumber,
lastNumber=this.lastNumber;
var showFirstDots=false;
var showLastDots=false;
var numberOfLinks=limit;
var startNumber=1;

if(numberOfPages<=limit){
// Special case: Less pages available than the limit of displayed pages
numberOfLinks=numberOfPages;
}else if(currentPage<limit-1&&limit>ELLIPSIS_THRESHOLD){
if(!hideEllipsis||lastNumber){
showLastDots=true;
numberOfLinks=limit-(firstNumber?0:1);
}

numberOfLinks=mathMin(numberOfLinks,limit);
}else if(numberOfPages-currentPage+2<limit&&limit>ELLIPSIS_THRESHOLD){
if(!hideEllipsis||firstNumber){
showFirstDots=true;
numberOfLinks=limit-(lastNumber?0:1);
}

startNumber=numberOfPages-numberOfLinks+1;
}else {
// We are somewhere in the middle of the page list
if(limit>ELLIPSIS_THRESHOLD){
numberOfLinks=limit-(hideEllipsis?0:2);
showFirstDots=!!(!hideEllipsis||firstNumber);
showLastDots=!!(!hideEllipsis||lastNumber);
}

startNumber=currentPage-mathFloor(numberOfLinks/2);
}// Sanity checks

/* istanbul ignore if */


if(startNumber<1){
startNumber=1;
showFirstDots=false;
}else if(startNumber>numberOfPages-numberOfLinks){
startNumber=numberOfPages-numberOfLinks+1;
showLastDots=false;
}

if(showFirstDots&&firstNumber&&startNumber<4){
numberOfLinks=numberOfLinks+2;
startNumber=1;
showFirstDots=false;
}

var lastPageNumber=startNumber+numberOfLinks-1;

if(showLastDots&&lastNumber&&lastPageNumber>numberOfPages-3){
numberOfLinks=numberOfLinks+(lastPageNumber===numberOfPages-2?2:3);
showLastDots=false;
}// Special handling for lower limits (where ellipsis are never shown)


if(limit<=ELLIPSIS_THRESHOLD){
if(firstNumber&&startNumber===1){
numberOfLinks=mathMin(numberOfLinks+1,numberOfPages,limit+1);
}else if(lastNumber&&numberOfPages===startNumber+numberOfLinks-1){
startNumber=mathMax(startNumber-1,1);
numberOfLinks=mathMin(numberOfPages-startNumber+1,numberOfPages,limit+1);
}
}

numberOfLinks=mathMin(numberOfLinks,numberOfPages-startNumber+1);
return {
showFirstDots:showFirstDots,
showLastDots:showLastDots,
numberOfLinks:numberOfLinks,
startNumber:startNumber};

},
pageList:function pageList(){
// Generates the pageList array
var _this$paginationParam=this.paginationParams,
numberOfLinks=_this$paginationParam.numberOfLinks,
startNumber=_this$paginationParam.startNumber;
var currentPage=this.computedCurrentPage;// Generate list of page numbers

var pages=makePageArray(startNumber,numberOfLinks);// We limit to a total of 3 page buttons on XS screens
// So add classes to page links to hide them for XS breakpoint
// Note: Ellipsis will also be hidden on XS screens
// TODO: Make this visual limit configurable based on breakpoint(s)

if(pages.length>3){
var idx=currentPage-startNumber;// THe following is a bootstrap-vue custom utility class

var classes='bv-d-xs-down-none';

if(idx===0){
// Keep leftmost 3 buttons visible when current page is first page
for(var i=3;i<pages.length;i++){
pages[i].classes=classes;
}
}else if(idx===pages.length-1){
// Keep rightmost 3 buttons visible when current page is last page
for(var _i=0;_i<pages.length-3;_i++){
pages[_i].classes=classes;
}
}else {
// Hide all except current page, current page - 1 and current page + 1
for(var _i2=0;_i2<idx-1;_i2++){
// hide some left button(s)
pages[_i2].classes=classes;
}

for(var _i3=pages.length-1;_i3>idx+1;_i3--){
// hide some right button(s)
pages[_i3].classes=classes;
}
}
}

return pages;
}},

watch:(_watch$e={},_defineProperty(_watch$e,MODEL_PROP_NAME$f,function(newValue,oldValue){
if(newValue!==oldValue){
this.currentPage=sanitizeCurrentPage(newValue,this.localNumberOfPages);
}
}),_defineProperty(_watch$e,"currentPage",function currentPage(newValue,oldValue){
if(newValue!==oldValue){
// Emit `null` if no page selected
this.$emit(MODEL_EVENT_NAME$f,newValue>0?newValue:null);
}
}),_defineProperty(_watch$e,"limit",function limit(newValue,oldValue){
if(newValue!==oldValue){
this.localLimit=sanitizeLimit(newValue);
}
}),_watch$e),
created:function created(){
var _this=this;

// Set our default values in data
this.localLimit=sanitizeLimit(this.limit);
this.$nextTick(function(){
// Sanity check
_this.currentPage=_this.currentPage>_this.localNumberOfPages?_this.localNumberOfPages:_this.currentPage;
});
},
methods:{
handleKeyNav:function handleKeyNav(event){
var keyCode=event.keyCode,
shiftKey=event.shiftKey;
/* istanbul ignore if */

if(this.isNav){
// We disable left/right keyboard navigation in `<b-pagination-nav>`
return;
}

if(keyCode===CODE_LEFT||keyCode===CODE_UP){
stopEvent(event,{
propagation:false});

shiftKey?this.focusFirst():this.focusPrev();
}else if(keyCode===CODE_RIGHT||keyCode===CODE_DOWN){
stopEvent(event,{
propagation:false});

shiftKey?this.focusLast():this.focusNext();
}
},
getButtons:function getButtons(){
// Return only buttons that are visible
return selectAll('button.page-link, a.page-link',this.$el).filter(function(btn){
return isVisible(btn);
});
},
focusCurrent:function focusCurrent(){
var _this2=this;

// We do this in `$nextTick()` to ensure buttons have finished rendering
this.$nextTick(function(){
var btn=_this2.getButtons().find(function(el){
return toInteger(getAttr(el,'aria-posinset'),0)===_this2.computedCurrentPage;
});

if(!attemptFocus(btn)){
// Fallback if current page is not in button list
_this2.focusFirst();
}
});
},
focusFirst:function focusFirst(){
var _this3=this;

// We do this in `$nextTick()` to ensure buttons have finished rendering
this.$nextTick(function(){
var btn=_this3.getButtons().find(function(el){
return !isDisabled(el);
});

attemptFocus(btn);
});
},
focusLast:function focusLast(){
var _this4=this;

// We do this in `$nextTick()` to ensure buttons have finished rendering
this.$nextTick(function(){
var btn=_this4.getButtons().reverse().find(function(el){
return !isDisabled(el);
});

attemptFocus(btn);
});
},
focusPrev:function focusPrev(){
var _this5=this;

// We do this in `$nextTick()` to ensure buttons have finished rendering
this.$nextTick(function(){
var buttons=_this5.getButtons();

var index=buttons.indexOf(getActiveElement());

if(index>0&&!isDisabled(buttons[index-1])){
attemptFocus(buttons[index-1]);
}
});
},
focusNext:function focusNext(){
var _this6=this;

// We do this in `$nextTick()` to ensure buttons have finished rendering
this.$nextTick(function(){
var buttons=_this6.getButtons();

var index=buttons.indexOf(getActiveElement());

if(index<buttons.length-1&&!isDisabled(buttons[index+1])){
attemptFocus(buttons[index+1]);
}
});
}},

render:function render(h){
var _this7=this;

var disabled=this.disabled,
labelPage=this.labelPage,
ariaLabel=this.ariaLabel,
isNav=this.isNav,
numberOfPages=this.localNumberOfPages,
currentPage=this.computedCurrentPage;
var pageNumbers=this.pageList.map(function(p){
return p.number;
});
var _this$paginationParam2=this.paginationParams,
showFirstDots=_this$paginationParam2.showFirstDots,
showLastDots=_this$paginationParam2.showLastDots;
var fill=this.align==='fill';
var $buttons=[];// Helper function and flag

var isActivePage=function isActivePage(pageNumber){
return pageNumber===currentPage;
};

var noCurrentPage=this.currentPage<1;// Factory function for prev/next/first/last buttons

var makeEndBtn=function makeEndBtn(linkTo,ariaLabel,btnSlot,btnText,btnClass,pageTest,key){
var isDisabled=disabled||isActivePage(pageTest)||noCurrentPage||linkTo<1||linkTo>numberOfPages;
var pageNumber=linkTo<1?1:linkTo>numberOfPages?numberOfPages:linkTo;
var scope={
disabled:isDisabled,
page:pageNumber,
index:pageNumber-1};

var $btnContent=_this7.normalizeSlot(btnSlot,scope)||toString$1(btnText)||h();
var $inner=h(isDisabled?'span':isNav?BLink:'button',{
staticClass:'page-link',
class:{
'flex-grow-1':!isNav&&!isDisabled&&fill},

props:isDisabled||!isNav?{}:_this7.linkProps(linkTo),
attrs:{
role:isNav?null:'menuitem',
type:isNav||isDisabled?null:'button',
tabindex:isDisabled||isNav?null:'-1',
'aria-label':ariaLabel,
'aria-controls':_this7.ariaControls||null,
'aria-disabled':isDisabled?'true':null},

on:isDisabled?{}:{
'!click':function click(event){
_this7.onClick(event,linkTo);
},
keydown:onSpaceKey}},

[$btnContent]);
return h('li',{
key:key,
staticClass:'page-item',
class:[{
disabled:isDisabled,
'flex-fill':fill,
'd-flex':fill&&!isNav&&!isDisabled},
btnClass],
attrs:{
role:isNav?null:'presentation',
'aria-hidden':isDisabled?'true':null}},

[$inner]);
};// Ellipsis factory


var makeEllipsis=function makeEllipsis(isLast){
return h('li',{
staticClass:'page-item',
class:['disabled','bv-d-xs-down-none',fill?'flex-fill':'',_this7.ellipsisClass],
attrs:{
role:'separator'},

key:"ellipsis-".concat(isLast?'last':'first')},
[h('span',{
staticClass:'page-link'},
[_this7.normalizeSlot(SLOT_NAME_ELLIPSIS_TEXT)||toString$1(_this7.ellipsisText)||h()])]);
};// Page button factory


var makePageButton=function makePageButton(page,idx){
var pageNumber=page.number;
var active=isActivePage(pageNumber)&&!noCurrentPage;// Active page will have tabindex of 0, or if no current page and first page button

var tabIndex=disabled?null:active||noCurrentPage&&idx===0?'0':'-1';
var attrs={
role:isNav?null:'menuitemradio',
type:isNav||disabled?null:'button',
'aria-disabled':disabled?'true':null,
'aria-controls':_this7.ariaControls||null,
'aria-label':hasPropFunction(labelPage)?
/* istanbul ignore next */
labelPage(pageNumber):"".concat(isFunction(labelPage)?labelPage():labelPage," ").concat(pageNumber),
'aria-checked':isNav?null:active?'true':'false',
'aria-current':isNav&&active?'page':null,
'aria-posinset':isNav?null:pageNumber,
'aria-setsize':isNav?null:numberOfPages,
// ARIA "roving tabindex" method (except in `isNav` mode)
tabindex:isNav?null:tabIndex};

var btnContent=toString$1(_this7.makePage(pageNumber));
var scope={
page:pageNumber,
index:pageNumber-1,
content:btnContent,
active:active,
disabled:disabled};

var $inner=h(disabled?'span':isNav?BLink:'button',{
props:disabled||!isNav?{}:_this7.linkProps(pageNumber),
staticClass:'page-link',
class:{
'flex-grow-1':!isNav&&!disabled&&fill},

attrs:attrs,
on:disabled?{}:{
'!click':function click(event){
_this7.onClick(event,pageNumber);
},
keydown:onSpaceKey}},

[_this7.normalizeSlot(SLOT_NAME_PAGE,scope)||btnContent]);
return h('li',{
staticClass:'page-item',
class:[{
disabled:disabled,
active:active,
'flex-fill':fill,
'd-flex':fill&&!isNav&&!disabled},
page.classes,_this7.pageClass],
attrs:{
role:isNav?null:'presentation'},

key:"page-".concat(pageNumber)},
[$inner]);
};// Goto first page button
// Don't render button when `hideGotoEndButtons` or `firstNumber` is set


var $firstPageBtn=h();

if(!this.firstNumber&&!this.hideGotoEndButtons){
$firstPageBtn=makeEndBtn(1,this.labelFirstPage,SLOT_NAME_FIRST_TEXT,this.firstText,this.firstClass,1,'pagination-goto-first');
}

$buttons.push($firstPageBtn);// Goto previous page button

$buttons.push(makeEndBtn(currentPage-1,this.labelPrevPage,SLOT_NAME_PREV_TEXT,this.prevText,this.prevClass,1,'pagination-goto-prev'));// Show first (1) button?

$buttons.push(this.firstNumber&&pageNumbers[0]!==1?makePageButton({
number:1},
0):h());// First ellipsis

$buttons.push(showFirstDots?makeEllipsis(false):h());// Individual page links

this.pageList.forEach(function(page,idx){
var offset=showFirstDots&&_this7.firstNumber&&pageNumbers[0]!==1?1:0;
$buttons.push(makePageButton(page,idx+offset));
});// Last ellipsis

$buttons.push(showLastDots?makeEllipsis(true):h());// Show last page button?

$buttons.push(this.lastNumber&&pageNumbers[pageNumbers.length-1]!==numberOfPages?makePageButton({
number:numberOfPages},
-1):h());// Goto next page button

$buttons.push(makeEndBtn(currentPage+1,this.labelNextPage,SLOT_NAME_NEXT_TEXT,this.nextText,this.nextClass,numberOfPages,'pagination-goto-next'));// Goto last page button
// Don't render button when `hideGotoEndButtons` or `lastNumber` is set

var $lastPageBtn=h();

if(!this.lastNumber&&!this.hideGotoEndButtons){
$lastPageBtn=makeEndBtn(numberOfPages,this.labelLastPage,SLOT_NAME_LAST_TEXT,this.lastText,this.lastClass,numberOfPages,'pagination-goto-last');
}

$buttons.push($lastPageBtn);// Assemble the pagination buttons

var $pagination=h('ul',{
staticClass:'pagination',
class:['b-pagination',this.btnSize,this.alignment,this.styleClass],
attrs:{
role:isNav?null:'menubar',
'aria-disabled':disabled?'true':'false',
'aria-label':isNav?null:ariaLabel||null},

// We disable keyboard left/right nav when `<b-pagination-nav>`
on:isNav?{}:{
keydown:this.handleKeyNav},

ref:'ul'},
$buttons);// If we are `<b-pagination-nav>`, wrap in `<nav>` wrapper

if(isNav){
return h('nav',{
attrs:{
'aria-disabled':disabled?'true':null,
'aria-hidden':disabled?'true':'false',
'aria-label':isNav?ariaLabel||null:null}},

[$pagination]);
}

return $pagination;
}});


var DEFAULT_PER_PAGE=20;
var DEFAULT_TOTAL_ROWS=0;// --- Helper methods ---
// Sanitize the provided per page number (converting to a number)

var sanitizePerPage=function sanitizePerPage(value){
return mathMax(toInteger(value)||DEFAULT_PER_PAGE,1);
};// Sanitize the provided total rows number (converting to a number)


var sanitizeTotalRows=function sanitizeTotalRows(value){
return mathMax(toInteger(value)||DEFAULT_TOTAL_ROWS,0);
};// --- Props ---


var props$1F=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$1E),{},{
ariaControls:makeProp(PROP_TYPE_STRING),
perPage:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_PER_PAGE),
totalRows:makeProp(PROP_TYPE_NUMBER_STRING,DEFAULT_TOTAL_ROWS)})),
NAME_PAGINATION);// --- Main component ---
// @vue/component

var BPagination=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_PAGINATION,
// The render function is brought in via the `paginationMixin`
mixins:[paginationMixin],
props:props$1F,
computed:{
numberOfPages:function numberOfPages(){
var result=mathCeil(sanitizeTotalRows(this.totalRows)/sanitizePerPage(this.perPage));
return result<1?1:result;
},
// Used for watching changes to `perPage` and `numberOfPages`
pageSizeNumberOfPages:function pageSizeNumberOfPages(){
return {
perPage:sanitizePerPage(this.perPage),
totalRows:sanitizeTotalRows(this.totalRows),
numberOfPages:this.numberOfPages};

}},

watch:{
pageSizeNumberOfPages:function pageSizeNumberOfPages(newValue,oldValue){
if(!isUndefinedOrNull(oldValue)){
if(newValue.perPage!==oldValue.perPage&&newValue.totalRows===oldValue.totalRows){
// If the page size changes, reset to page 1
this.currentPage=1;
}else if(newValue.numberOfPages!==oldValue.numberOfPages&&this.currentPage>newValue.numberOfPages){
// If `numberOfPages` changes and is less than
// the `currentPage` number, reset to page 1
this.currentPage=1;
}
}

this.localNumberOfPages=newValue.numberOfPages;
}},

created:function created(){
var _this=this;

// Set the initial page count
this.localNumberOfPages=this.numberOfPages;// Set the initial page value

var currentPage=toInteger(this[MODEL_PROP_NAME$f],0);

if(currentPage>0){
this.currentPage=currentPage;
}else {
this.$nextTick(function(){
// If this value parses to `NaN` or a value less than `1`
// trigger an initial emit of `null` if no page specified
_this.currentPage=0;
});
}
},
methods:{
// These methods are used by the render function
onClick:function onClick(event,pageNumber){
var _this2=this;

// Dont do anything if clicking the current active page
if(pageNumber===this.currentPage){
return;
}

var target=event.target;// Emit a user-cancelable `page-click` event

var clickEvt=new BvEvent(EVENT_NAME_PAGE_CLICK,{
cancelable:true,
vueTarget:this,
target:target});

this.$emit(clickEvt.type,clickEvt,pageNumber);

if(clickEvt.defaultPrevented){
return;
}// Update the `v-model`


this.currentPage=pageNumber;// Emit event triggered by user interaction

this.$emit(EVENT_NAME_CHANGE,this.currentPage);// Keep the current button focused if possible

this.$nextTick(function(){
if(isVisible(target)&&_this2.$el.contains(target)){
attemptFocus(target);
}else {
_this2.focusCurrent();
}
});
},
makePage:function makePage(pageNum){
return pageNum;
},

/* istanbul ignore next */
linkProps:function linkProps(){
// No props, since we render a plain button
return {};
}}});



var PaginationPlugin=/*#__PURE__*/pluginFactory({
components:{
BPagination:BPagination}});



// Sanitize the provided number of pages (converting to a number)

var sanitizeNumberOfPages=function sanitizeNumberOfPages(value){
return mathMax(toInteger(value,0),1);
};// --- Props ---

var _linkProps=omit(props$6,['event','routerTag']);

var props$1G=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$1E),_linkProps),{},{
baseUrl:makeProp(PROP_TYPE_STRING,'/'),
linkGen:makeProp(PROP_TYPE_FUNCTION),
// Disable auto page number detection if `true`
noPageDetect:makeProp(PROP_TYPE_BOOLEAN,false),
numberOfPages:makeProp(PROP_TYPE_NUMBER_STRING,1,
/* istanbul ignore next */
function(value){
var number=toInteger(value,0);

if(number<1){
warn('Prop "number-of-pages" must be a number greater than "0"',NAME_PAGINATION_NAV);
return false;
}

return true;
}),
pageGen:makeProp(PROP_TYPE_FUNCTION),
// Optional array of page links
pages:makeProp(PROP_TYPE_ARRAY),
useRouter:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_PAGINATION_NAV);// --- Main component ---
// @vue/component

var BPaginationNav=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_PAGINATION_NAV,
// The render function is brought in via the pagination mixin
mixins:[paginationMixin],
props:props$1G,
computed:{
// Used by render function to trigger wrapping in '<nav>' element
isNav:function isNav(){
return true;
},
computedValue:function computedValue(){
// Returns the value prop as a number or `null` if undefined or < 1
var value=toInteger(this.value,0);
return value<1?null:value;
}},

watch:{
numberOfPages:function numberOfPages(){
var _this=this;

this.$nextTick(function(){
_this.setNumberOfPages();
});
},
pages:function pages(){
var _this2=this;

this.$nextTick(function(){
_this2.setNumberOfPages();
});
}},

created:function created(){
this.setNumberOfPages();
},
mounted:function mounted(){
var _this3=this;

if(this.$router){
// We only add the watcher if vue router is detected
this.$watch('$route',function(){
_this3.$nextTick(function(){
requestAF(function(){
_this3.guessCurrentPage();
});
});
});
}
},
methods:{
setNumberOfPages:function setNumberOfPages(){
var _this4=this;

if(isArray(this.pages)&&this.pages.length>0){
this.localNumberOfPages=this.pages.length;
}else {
this.localNumberOfPages=sanitizeNumberOfPages(this.numberOfPages);
}

this.$nextTick(function(){
_this4.guessCurrentPage();
});
},
onClick:function onClick(event,pageNumber){
var _this5=this;

// Dont do anything if clicking the current active page
if(pageNumber===this.currentPage){
return;
}

var target=event.currentTarget||event.target;// Emit a user-cancelable `page-click` event

var clickEvt=new BvEvent(EVENT_NAME_PAGE_CLICK,{
cancelable:true,
vueTarget:this,
target:target});

this.$emit(clickEvt.type,clickEvt,pageNumber);

if(clickEvt.defaultPrevented){
return;
}// Update the `v-model`
// Done in in requestAF() to allow browser to complete the
// native browser click handling of a link


requestAF(function(){
_this5.currentPage=pageNumber;

_this5.$emit(EVENT_NAME_CHANGE,pageNumber);
});// Emulate native link click page reloading behaviour by blurring the
// paginator and returning focus to the document
// Done in a `nextTick()` to ensure rendering complete

this.$nextTick(function(){
attemptBlur(target);
});
},
getPageInfo:function getPageInfo(pageNumber){
if(!isArray(this.pages)||this.pages.length===0||isUndefined(this.pages[pageNumber-1])){
var link="".concat(this.baseUrl).concat(pageNumber);
return {
link:this.useRouter?{
path:link}:
link,
text:toString$1(pageNumber)};

}

var info=this.pages[pageNumber-1];

if(isObject(info)){
var _link=info.link;
return {
// Normalize link for router use
link:isObject(_link)?_link:this.useRouter?{
path:_link}:
_link,
// Make sure text has a value
text:toString$1(info.text||pageNumber)};

}else {
return {
link:toString$1(info),
text:toString$1(pageNumber)};

}
},
makePage:function makePage(pageNumber){
var pageGen=this.pageGen;
var info=this.getPageInfo(pageNumber);

if(hasPropFunction(pageGen)){
return pageGen(pageNumber,info);
}

return info.text;
},
makeLink:function makeLink(pageNumber){
var linkGen=this.linkGen;
var info=this.getPageInfo(pageNumber);

if(hasPropFunction(linkGen)){
return linkGen(pageNumber,info);
}

return info.link;
},
linkProps:function linkProps(pageNumber){
var props=pluckProps(_linkProps,this);
var link=this.makeLink(pageNumber);

if(this.useRouter||isObject(link)){
props.to=link;
}else {
props.href=link;
}

return props;
},
resolveLink:function resolveLink(){
var to=arguments.length>0&&arguments[0]!==undefined?arguments[0]:'';
// Given a to (or href string), convert to normalized route-like structure
// Works only client side!
var link;

try{
// Convert the `to` to a HREF via a temporary `a` tag
link=document.createElement('a');
link.href=computeHref({
to:to},
'a','/','/');// We need to add the anchor to the document to make sure the
// `pathname` is correctly detected in any browser (i.e. IE)

document.body.appendChild(link);// Once href is assigned, the link will be normalized to the full URL bits

var _link2=link,
pathname=_link2.pathname,
hash=_link2.hash,
search=_link2.search;// Remove link from document

document.body.removeChild(link);// Return the location in a route-like object

return {
path:pathname,
hash:hash,
query:parseQuery(search)};

}catch(e){
/* istanbul ignore next */
try{
link&&link.parentNode&&link.parentNode.removeChild(link);
}catch(_unused){}
/* istanbul ignore next */


return {};
}
},
resolveRoute:function resolveRoute(){
var to=arguments.length>0&&arguments[0]!==undefined?arguments[0]:'';

// Given a to (or href string), convert to normalized route location structure
// Works only when router available!
try{
var route=this.$router.resolve(to,this.$route).route;
return {
path:route.path,
hash:route.hash,
query:route.query};

}catch(e){
/* istanbul ignore next */
return {};
}
},
guessCurrentPage:function guessCurrentPage(){
var $router=this.$router,
$route=this.$route;
var guess=this.computedValue;// This section only occurs if we are client side, or server-side with `$router`

if(!this.noPageDetect&&!guess&&(IS_BROWSER||!IS_BROWSER&&$router)){
// Current route (if router available)
var currentRoute=$router&&$route?{
path:$route.path,
hash:$route.hash,
query:$route.query}:
{};// Current page full HREF (if client side)
// Can't be done as a computed prop!

var loc=IS_BROWSER?window.location||document.location:null;
var currentLink=loc?{
path:loc.pathname,
hash:loc.hash,
query:parseQuery(loc.search)}:

/* istanbul ignore next */
{};// Loop through the possible pages looking for a match until found

for(var pageNumber=1;!guess&&pageNumber<=this.localNumberOfPages;pageNumber++){
var to=this.makeLink(pageNumber);

if($router&&(isObject(to)||this.useRouter)){
// Resolve the page via the `$router`
guess=looseEqual(this.resolveRoute(to),currentRoute)?pageNumber:null;
}else if(IS_BROWSER){
// If no `$router` available (or `!this.useRouter` when `to` is a string)
// we compare using parsed URIs
guess=looseEqual(this.resolveLink(to),currentLink)?pageNumber:null;
}else {
// Probably SSR, but no `$router` so we can't guess,
// so lets break out of the loop early

/* istanbul ignore next */
guess=-1;
}
}
}// We set `currentPage` to `0` to trigger an `$emit('input', null)`
// As the default for `currentPage` is `-1` when no value is specified
// Valid page numbers are greater than `0`


this.currentPage=guess>0?guess:0;
}}});



var PaginationNavPlugin=/*#__PURE__*/pluginFactory({
components:{
BPaginationNav:BPaginationNav}});



// Base on-demand component for tooltip / popover templates

var AttachmentMap={
AUTO:'auto',
TOP:'top',
RIGHT:'right',
BOTTOM:'bottom',
LEFT:'left',
TOPLEFT:'top',
TOPRIGHT:'top',
RIGHTTOP:'right',
RIGHTBOTTOM:'right',
BOTTOMLEFT:'bottom',
BOTTOMRIGHT:'bottom',
LEFTTOP:'left',
LEFTBOTTOM:'left'};

var OffsetMap={
AUTO:0,
TOPLEFT:-1,
TOP:0,
TOPRIGHT:+1,
RIGHTTOP:-1,
RIGHT:0,
RIGHTBOTTOM:+1,
BOTTOMLEFT:-1,
BOTTOM:0,
BOTTOMRIGHT:+1,
LEFTTOP:-1,
LEFT:0,
LEFTBOTTOM:+1};
// --- Props ---

var props$1H={
// The minimum distance (in `px`) from the edge of the
// tooltip/popover that the arrow can be positioned
arrowPadding:makeProp(PROP_TYPE_NUMBER_STRING,6),
// 'scrollParent', 'viewport', 'window', or `Element`
boundary:makeProp([HTMLElement,PROP_TYPE_STRING],'scrollParent'),
// Tooltip/popover will try and stay away from
// boundary edge by this many pixels
boundaryPadding:makeProp(PROP_TYPE_NUMBER_STRING,5),
fallbackPlacement:makeProp(PROP_TYPE_ARRAY_STRING,'flip'),
offset:makeProp(PROP_TYPE_NUMBER_STRING,0),
placement:makeProp(PROP_TYPE_STRING,'top'),
// Element that the tooltip/popover is positioned relative to
target:makeProp([HTMLElement,SVGElement])};
// --- Main component ---
// @vue/component

var BVPopper=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_POPPER,
props:props$1H,
data:function data(){
return {
// reactive props set by parent
noFade:false,
// State related data
localShow:true,
attachment:this.getAttachment(this.placement)};

},
computed:{
/* istanbul ignore next */
templateType:function templateType(){
// Overridden by template component
return 'unknown';
},
popperConfig:function popperConfig(){
var _this=this;

var placement=this.placement;
return {
placement:this.getAttachment(placement),
modifiers:{
offset:{
offset:this.getOffset(placement)},

flip:{
behavior:this.fallbackPlacement},

// `arrow.element` can also be a reference to an HTML Element
// maybe we should make this a `$ref` in the templates?
arrow:{
element:'.arrow'},

preventOverflow:{
padding:this.boundaryPadding,
boundariesElement:this.boundary}},


onCreate:function onCreate(data){
// Handle flipping arrow classes
if(data.originalPlacement!==data.placement){
/* istanbul ignore next: can't test in JSDOM */
_this.popperPlacementChange(data);
}
},
onUpdate:function onUpdate(data){
// Handle flipping arrow classes
_this.popperPlacementChange(data);
}};

}},

created:function created(){
var _this2=this;

// Note: We are created on-demand, and should be guaranteed that
// DOM is rendered/ready by the time the created hook runs
this.$_popper=null;// Ensure we show as we mount

this.localShow=true;// Create popper instance before shown

this.$on(EVENT_NAME_SHOW,function(el){
_this2.popperCreate(el);
});// Self destruct handler

var handleDestroy=function handleDestroy(){
_this2.$nextTick(function(){
// In a `requestAF()` to release control back to application
requestAF(function(){
_this2.$destroy();
});
});
};// Self destruct if parent destroyed


this.$parent.$once(HOOK_EVENT_NAME_DESTROYED,handleDestroy);// Self destruct after hidden

this.$once(EVENT_NAME_HIDDEN,handleDestroy);
},
beforeMount:function beforeMount(){
// Ensure that the attachment position is correct before mounting
// as our propsData is added after `new Template({...})`
this.attachment=this.getAttachment(this.placement);
},
updated:function updated(){
// Update popper if needed
// TODO: Should this be a watcher on `this.popperConfig` instead?
this.updatePopper();
},
beforeDestroy:function beforeDestroy(){
this.destroyPopper();
},
destroyed:function destroyed(){
// Make sure template is removed from DOM
var el=this.$el;
el&&el.parentNode&&el.parentNode.removeChild(el);
},
methods:{
// "Public" method to trigger hide template
hide:function hide(){
this.localShow=false;
},
// Private
getAttachment:function getAttachment(placement){
return AttachmentMap[String(placement).toUpperCase()]||'auto';
},
getOffset:function getOffset(placement){
if(!this.offset){
// Could set a ref for the arrow element
var arrow=this.$refs.arrow||select('.arrow',this.$el);
var arrowOffset=toFloat(getCS(arrow).width,0)+toFloat(this.arrowPadding,0);

switch(OffsetMap[String(placement).toUpperCase()]||0){
/* istanbul ignore next: can't test in JSDOM */
case+1:
/* istanbul ignore next: can't test in JSDOM */
return "+50%p - ".concat(arrowOffset,"px");

/* istanbul ignore next: can't test in JSDOM */

case-1:
/* istanbul ignore next: can't test in JSDOM */
return "-50%p + ".concat(arrowOffset,"px");

default:
return 0;}

}
/* istanbul ignore next */


return this.offset;
},
popperCreate:function popperCreate(el){
this.destroyPopper();// We use `el` rather than `this.$el` just in case the original
// mountpoint root element type was changed by the template

this.$_popper=new popper_js__WEBPACK_IMPORTED_MODULE_2__["default"](this.target,el,this.popperConfig);
},
destroyPopper:function destroyPopper(){
this.$_popper&&this.$_popper.destroy();
this.$_popper=null;
},
updatePopper:function updatePopper(){
this.$_popper&&this.$_popper.scheduleUpdate();
},
popperPlacementChange:function popperPlacementChange(data){
// Callback used by popper to adjust the arrow placement
this.attachment=this.getAttachment(data.placement);
},

/* istanbul ignore next */
renderTemplate:function renderTemplate(h){
// Will be overridden by templates
return h('div');
}},

render:function render(h){
var _this3=this;

var noFade=this.noFade;// Note: 'show' and 'fade' classes are only appled during transition

return h(BVTransition,{
// Transitions as soon as mounted
props:{
appear:true,
noFade:noFade},

on:{
// Events used by parent component/instance
beforeEnter:function beforeEnter(el){
return _this3.$emit(EVENT_NAME_SHOW,el);
},
afterEnter:function afterEnter(el){
return _this3.$emit(EVENT_NAME_SHOWN,el);
},
beforeLeave:function beforeLeave(el){
return _this3.$emit(EVENT_NAME_HIDE,el);
},
afterLeave:function afterLeave(el){
return _this3.$emit(EVENT_NAME_HIDDEN,el);
}}},

[this.localShow?this.renderTemplate(h):h()]);
}});


var props$1I={
// Used only by the directive versions
html:makeProp(PROP_TYPE_BOOLEAN,false),
// Other non-reactive (while open) props are pulled in from BVPopper
id:makeProp(PROP_TYPE_STRING)};
// --- Main component ---
// @vue/component

var BVTooltipTemplate=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TOOLTIP_TEMPLATE,
extends:BVPopper,
mixins:[scopedStyleMixin],
props:props$1I,
data:function data(){
// We use data, rather than props to ensure reactivity
// Parent component will directly set this data
return {
title:'',
content:'',
variant:null,
customClass:null,
interactive:true};

},
computed:{
templateType:function templateType(){
return 'tooltip';
},
templateClasses:function templateClasses(){
var _ref;

var variant=this.variant,
attachment=this.attachment,
templateType=this.templateType;
return [(_ref={
// Disables pointer events to hide the tooltip when the user
// hovers over its content
noninteractive:!this.interactive},
_defineProperty(_ref,"b-".concat(templateType,"-").concat(variant),variant),_defineProperty(_ref,"bs-".concat(templateType,"-").concat(attachment),attachment),_ref),this.customClass];
},
templateAttributes:function templateAttributes(){
var id=this.id;
return _objectSpread2(_objectSpread2({},this.$parent.$parent.$attrs),{},{
id:id,
role:'tooltip',
tabindex:'-1'},
this.scopedStyleAttrs);
},
templateListeners:function templateListeners(){
var _this=this;

// Used for hover/focus trigger listeners
return {
mouseenter:
/* istanbul ignore next */
function mouseenter(event){
_this.$emit(EVENT_NAME_MOUSEENTER,event);
},
mouseleave:
/* istanbul ignore next */
function mouseleave(event){
_this.$emit(EVENT_NAME_MOUSELEAVE,event);
},
focusin:
/* istanbul ignore next */
function focusin(event){
_this.$emit(EVENT_NAME_FOCUSIN,event);
},
focusout:
/* istanbul ignore next */
function focusout(event){
_this.$emit(EVENT_NAME_FOCUSOUT,event);
}};

}},

methods:{
renderTemplate:function renderTemplate(h){
var title=this.title;// Title can be a scoped slot function

var $title=isFunction(title)?title({}):title;// Directive versions only

var domProps=this.html&&!isFunction(title)?{
innerHTML:title}:
{};
return h('div',{
staticClass:'tooltip b-tooltip',
class:this.templateClasses,
attrs:this.templateAttributes,
on:this.templateListeners},
[h('div',{
staticClass:'arrow',
ref:'arrow'}),
h('div',{
staticClass:'tooltip-inner',
domProps:domProps},
[$title])]);
}}});



// Modal container selector for appending tooltip/popover

var MODAL_SELECTOR='.modal-content';// Modal `$root` hidden event

var ROOT_EVENT_NAME_MODAL_HIDDEN=getRootEventName(NAME_MODAL,EVENT_NAME_HIDDEN);// Sidebar container selector for appending tooltip/popover

var SIDEBAR_SELECTOR='.b-sidebar';// For finding the container to append to

var CONTAINER_SELECTOR=[MODAL_SELECTOR,SIDEBAR_SELECTOR].join(', ');// For dropdown sniffing

var DROPDOWN_CLASS='dropdown';
var DROPDOWN_OPEN_SELECTOR='.dropdown-menu.show';// Data attribute to temporary store the `title` attribute's value

var DATA_TITLE_ATTR='data-original-title';// Data specific to popper and template
// We don't use props, as we need reactivity (we can't pass reactive props)

var templateData={
// Text string or Scoped slot function
title:'',
// Text string or Scoped slot function
content:'',
// String
variant:null,
// String, Array, Object
customClass:null,
// String or array of Strings (overwritten by BVPopper)
triggers:'',
// String (overwritten by BVPopper)
placement:'auto',
// String or array of strings
fallbackPlacement:'flip',
// Element or Component reference (or function that returns element) of
// the element that will have the trigger events bound, and is also
// default element for positioning
target:null,
// HTML ID, Element or Component reference
container:null,
// 'body'
// Boolean
noFade:false,
// 'scrollParent', 'viewport', 'window', Element, or Component reference
boundary:'scrollParent',
// Tooltip/popover will try and stay away from
// boundary edge by this many pixels (Number)
boundaryPadding:5,
// Arrow offset (Number)
offset:0,
// Hover/focus delay (Number or Object)
delay:0,
// Arrow of Tooltip/popover will try and stay away from
// the edge of tooltip/popover edge by this many pixels
arrowPadding:6,
// Interactive state (Boolean)
interactive:true,
// Disabled state (Boolean)
disabled:false,
// ID to use for tooltip/popover
id:null,
// Flag used by directives only, for HTML content
html:false};
// --- Main component ---
// @vue/component

var BVTooltip=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TOOLTIP_HELPER,
mixins:[listenOnRootMixin],
data:function data(){
return _objectSpread2(_objectSpread2({},templateData),{},{
// State management data
activeTrigger:{
// manual: false,
hover:false,
click:false,
focus:false},

localShow:false});

},
computed:{
templateType:function templateType(){
// Overwritten by BVPopover
return 'tooltip';
},
computedId:function computedId(){
return this.id||"__bv_".concat(this.templateType,"_").concat(this[COMPONENT_UID_KEY],"__");
},
computedDelay:function computedDelay(){
// Normalizes delay into object form
var delay={
show:0,
hide:0};


if(isPlainObject(this.delay)){
delay.show=mathMax(toInteger(this.delay.show,0),0);
delay.hide=mathMax(toInteger(this.delay.hide,0),0);
}else if(isNumber(this.delay)||isString(this.delay)){
delay.show=delay.hide=mathMax(toInteger(this.delay,0),0);
}

return delay;
},
computedTriggers:function computedTriggers(){
// Returns the triggers in sorted array form
// TODO: Switch this to object form for easier lookup
return concat(this.triggers).filter(identity).join(' ').trim().toLowerCase().split(/\s+/).sort();
},
isWithActiveTrigger:function isWithActiveTrigger(){
for(var trigger in this.activeTrigger){
if(this.activeTrigger[trigger]){
return true;
}
}

return false;
},
computedTemplateData:function computedTemplateData(){
var title=this.title,
content=this.content,
variant=this.variant,
customClass=this.customClass,
noFade=this.noFade,
interactive=this.interactive;
return {
title:title,
content:content,
variant:variant,
customClass:customClass,
noFade:noFade,
interactive:interactive};

}},

watch:{
computedTriggers:function computedTriggers(newTriggers,oldTriggers){
var _this=this;

// Triggers have changed, so re-register them

/* istanbul ignore next */
if(!looseEqual(newTriggers,oldTriggers)){
this.$nextTick(function(){
// Disable trigger listeners
_this.unListen();// Clear any active triggers that are no longer in the list of triggers


oldTriggers.forEach(function(trigger){
if(!arrayIncludes(newTriggers,trigger)){
if(_this.activeTrigger[trigger]){
_this.activeTrigger[trigger]=false;
}
}
});// Re-enable the trigger listeners

_this.listen();
});
}
},
computedTemplateData:function computedTemplateData(){
// If any of the while open reactive "props" change,
// ensure that the template updates accordingly
this.handleTemplateUpdate();
},
title:function title(newValue,oldValue){
// Make sure to hide the tooltip when the title is set empty
if(newValue!==oldValue&&!newValue){
this.hide();
}
},
disabled:function disabled(newValue){
if(newValue){
this.disable();
}else {
this.enable();
}
}},

created:function created(){
var _this2=this;

// Create non-reactive properties
this.$_tip=null;
this.$_hoverTimeout=null;
this.$_hoverState='';
this.$_visibleInterval=null;
this.$_enabled=!this.disabled;
this.$_noop=noop.bind(this);// Destroy ourselves when the parent is destroyed

if(this.$parent){
this.$parent.$once(HOOK_EVENT_NAME_BEFORE_DESTROY,function(){
_this2.$nextTick(function(){
// In a `requestAF()` to release control back to application
requestAF(function(){
_this2.$destroy();
});
});
});
}

this.$nextTick(function(){
var target=_this2.getTarget();

if(target&&contains(document.body,target)){
// Copy the parent's scoped style attribute
_this2.scopeId=getScopeId(_this2.$parent);// Set up all trigger handlers and listeners

_this2.listen();
}else {
/* istanbul ignore next */
warn(isString(_this2.target)?"Unable to find target element by ID \"#".concat(_this2.target,"\" in document."):'The provided target is no valid HTML element.',_this2.templateType);
}
});
},

/* istanbul ignore next */
updated:function updated(){
// Usually called when the slots/data changes
this.$nextTick(this.handleTemplateUpdate);
},

/* istanbul ignore next */
deactivated:function deactivated(){
// In a keepalive that has been deactivated, so hide
// the tooltip/popover if it is showing
this.forceHide();
},
beforeDestroy:function beforeDestroy(){
// Remove all handler/listeners
this.unListen();
this.setWhileOpenListeners(false);// Clear any timeouts/intervals

this.clearHoverTimeout();
this.clearVisibilityInterval();// Destroy the template

this.destroyTemplate();// Remove any other private properties created during create

this.$_noop=null;
},
methods:{
// --- Methods for creating and destroying the template ---
getTemplate:function getTemplate(){
// Overridden by BVPopover
return BVTooltipTemplate;
},
updateData:function updateData(){
var _this3=this;

var data=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{};
// Method for updating popper/template data
// We only update data if it exists, and has not changed
var titleUpdated=false;
keys(templateData).forEach(function(prop){
if(!isUndefined(data[prop])&&_this3[prop]!==data[prop]){
_this3[prop]=data[prop];

if(prop==='title'){
titleUpdated=true;
}
}
});// If the title has updated, we may need to handle the `title`
// attribute on the trigger target
// We only do this while the template is open

if(titleUpdated&&this.localShow){
this.fixTitle();
}
},
createTemplateAndShow:function createTemplateAndShow(){
// Creates the template instance and show it
var container=this.getContainer();
var Template=this.getTemplate();
var $tip=this.$_tip=new Template({
parent:this,
// The following is not reactive to changes in the props data
propsData:{
// These values cannot be changed while template is showing
id:this.computedId,
html:this.html,
placement:this.placement,
fallbackPlacement:this.fallbackPlacement,
target:this.getPlacementTarget(),
boundary:this.getBoundary(),
// Ensure the following are integers
offset:toInteger(this.offset,0),
arrowPadding:toInteger(this.arrowPadding,0),
boundaryPadding:toInteger(this.boundaryPadding,0)}});

// We set the initial reactive data (values that can be changed while open)

this.handleTemplateUpdate();// Template transition phase events (handled once only)
// When the template has mounted, but not visibly shown yet

$tip.$once(EVENT_NAME_SHOW,this.onTemplateShow);// When the template has completed showing

$tip.$once(EVENT_NAME_SHOWN,this.onTemplateShown);// When the template has started to hide

$tip.$once(EVENT_NAME_HIDE,this.onTemplateHide);// When the template has completed hiding

$tip.$once(EVENT_NAME_HIDDEN,this.onTemplateHidden);// When the template gets destroyed for any reason

$tip.$once(HOOK_EVENT_NAME_DESTROYED,this.destroyTemplate);// Convenience events from template
// To save us from manually adding/removing DOM
// listeners to tip element when it is open

$tip.$on(EVENT_NAME_FOCUSIN,this.handleEvent);
$tip.$on(EVENT_NAME_FOCUSOUT,this.handleEvent);
$tip.$on(EVENT_NAME_MOUSEENTER,this.handleEvent);
$tip.$on(EVENT_NAME_MOUSELEAVE,this.handleEvent);// Mount (which triggers the `show`)

$tip.$mount(container.appendChild(document.createElement('div')));// Template will automatically remove its markup from DOM when hidden
},
hideTemplate:function hideTemplate(){
// Trigger the template to start hiding
// The template will emit the `hide` event after this and
// then emit the `hidden` event once it is fully hidden
// The `hook:destroyed` will also be called (safety measure)
this.$_tip&&this.$_tip.hide();// Clear out any stragging active triggers

this.clearActiveTriggers();// Reset the hover state

this.$_hoverState='';
},
// Destroy the template instance and reset state
destroyTemplate:function destroyTemplate(){
this.setWhileOpenListeners(false);
this.clearHoverTimeout();
this.$_hoverState='';
this.clearActiveTriggers();
this.localPlacementTarget=null;

try{
this.$_tip.$destroy();
}catch(_unused){}

this.$_tip=null;
this.removeAriaDescribedby();
this.restoreTitle();
this.localShow=false;
},
getTemplateElement:function getTemplateElement(){
return this.$_tip?this.$_tip.$el:null;
},
handleTemplateUpdate:function handleTemplateUpdate(){
var _this4=this;

// Update our template title/content "props"
// So that the template updates accordingly
var $tip=this.$_tip;

if($tip){
var props=['title','content','variant','customClass','noFade','interactive'];// Only update the values if they have changed

props.forEach(function(prop){
if($tip[prop]!==_this4[prop]){
$tip[prop]=_this4[prop];
}
});
}
},
// --- Show/Hide handlers ---
// Show the tooltip
show:function show(){
var target=this.getTarget();

if(!target||!contains(document.body,target)||!isVisible(target)||this.dropdownOpen()||(isUndefinedOrNull(this.title)||this.title==='')&&(isUndefinedOrNull(this.content)||this.content==='')){
// If trigger element isn't in the DOM or is not visible, or
// is on an open dropdown toggle, or has no content, then
// we exit without showing
return;
}// If tip already exists, exit early


if(this.$_tip||this.localShow){
/* istanbul ignore next */
return;
}// In the process of showing


this.localShow=true;// Create a cancelable BvEvent

var showEvt=this.buildEvent(EVENT_NAME_SHOW,{
cancelable:true});

this.emitEvent(showEvt);// Don't show if event cancelled

/* istanbul ignore if */

if(showEvt.defaultPrevented){
// Destroy the template (if for some reason it was created)
this.destroyTemplate();
return;
}// Fix the title attribute on target


this.fixTitle();// Set aria-describedby on target

this.addAriaDescribedby();// Create and show the tooltip

this.createTemplateAndShow();
},
hide:function hide(){
var force=arguments.length>0&&arguments[0]!==undefined?arguments[0]:false;
// Hide the tooltip
var tip=this.getTemplateElement();
/* istanbul ignore if */

if(!tip||!this.localShow){
this.restoreTitle();
return;
}// Emit cancelable BvEvent 'hide'
// We disable cancelling if `force` is true


var hideEvt=this.buildEvent(EVENT_NAME_HIDE,{
cancelable:!force});

this.emitEvent(hideEvt);
/* istanbul ignore if: ignore for now */

if(hideEvt.defaultPrevented){
// Don't hide if event cancelled
return;
}// Tell the template to hide


this.hideTemplate();
},
forceHide:function forceHide(){
// Forcefully hides/destroys the template, regardless of any active triggers
var tip=this.getTemplateElement();

if(!tip||!this.localShow){
/* istanbul ignore next */
return;
}// Disable while open listeners/watchers
// This is also done in the template `hide` event handler


this.setWhileOpenListeners(false);// Clear any hover enter/leave event

this.clearHoverTimeout();
this.$_hoverState='';
this.clearActiveTriggers();// Disable the fade animation on the template

if(this.$_tip){
this.$_tip.noFade=true;
}// Hide the tip (with force = true)


this.hide(true);
},
enable:function enable(){
this.$_enabled=true;// Create a non-cancelable BvEvent

this.emitEvent(this.buildEvent(EVENT_NAME_ENABLED));
},
disable:function disable(){
this.$_enabled=false;// Create a non-cancelable BvEvent

this.emitEvent(this.buildEvent(EVENT_NAME_DISABLED));
},
// --- Handlers for template events ---
// When template is inserted into DOM, but not yet shown
onTemplateShow:function onTemplateShow(){
// Enable while open listeners/watchers
this.setWhileOpenListeners(true);
},
// When template show transition completes
onTemplateShown:function onTemplateShown(){
var prevHoverState=this.$_hoverState;
this.$_hoverState='';
/* istanbul ignore next: occasional Node 10 coverage error */

if(prevHoverState==='out'){
this.leave(null);
}// Emit a non-cancelable BvEvent 'shown'


this.emitEvent(this.buildEvent(EVENT_NAME_SHOWN));
},
// When template is starting to hide
onTemplateHide:function onTemplateHide(){
// Disable while open listeners/watchers
this.setWhileOpenListeners(false);
},
// When template has completed closing (just before it self destructs)
onTemplateHidden:function onTemplateHidden(){
// Destroy the template
this.destroyTemplate();// Emit a non-cancelable BvEvent 'shown'

this.emitEvent(this.buildEvent(EVENT_NAME_HIDDEN));
},
// --- Helper methods ---
getTarget:function getTarget(){
var target=this.target;

if(isString(target)){
target=getById(target.replace(/^#/,''));
}else if(isFunction(target)){
target=target();
}else if(target){
target=target.$el||target;
}

return isElement(target)?target:null;
},
getPlacementTarget:function getPlacementTarget(){
// This is the target that the tooltip will be placed on, which may not
// necessarily be the same element that has the trigger event listeners
// For now, this is the same as target
// TODO:
//   Add in child selector support
//   Add in visibility checks for this element
//   Fallback to target if not found
return this.getTarget();
},
getTargetId:function getTargetId(){
// Returns the ID of the trigger element
var target=this.getTarget();
return target&&target.id?target.id:null;
},
getContainer:function getContainer(){
// Handle case where container may be a component ref
var container=this.container?this.container.$el||this.container:false;
var body=document.body;
var target=this.getTarget();// If we are in a modal, we append to the modal, If we
// are in a sidebar, we append to the sidebar, else append
// to body, unless a container is specified
// TODO:
//   Template should periodically check to see if it is in dom
//   And if not, self destruct (if container got v-if'ed out of DOM)
//   Or this could possibly be part of the visibility check

return container===false?closest(CONTAINER_SELECTOR,target)||body:
/*istanbul ignore next */
isString(container)?
/*istanbul ignore next */
getById(container.replace(/^#/,''))||body:
/*istanbul ignore next */
body;
},
getBoundary:function getBoundary(){
return this.boundary?this.boundary.$el||this.boundary:'scrollParent';
},
isInModal:function isInModal(){
var target=this.getTarget();
return target&&closest(MODAL_SELECTOR,target);
},
isDropdown:function isDropdown(){
// Returns true if trigger is a dropdown
var target=this.getTarget();
return target&&hasClass(target,DROPDOWN_CLASS);
},
dropdownOpen:function dropdownOpen(){
// Returns true if trigger is a dropdown and the dropdown menu is open
var target=this.getTarget();
return this.isDropdown()&&target&&select(DROPDOWN_OPEN_SELECTOR,target);
},
clearHoverTimeout:function clearHoverTimeout(){
clearTimeout(this.$_hoverTimeout);
this.$_hoverTimeout=null;
},
clearVisibilityInterval:function clearVisibilityInterval(){
clearInterval(this.$_visibleInterval);
this.$_visibleInterval=null;
},
clearActiveTriggers:function clearActiveTriggers(){
for(var trigger in this.activeTrigger){
this.activeTrigger[trigger]=false;
}
},
addAriaDescribedby:function addAriaDescribedby(){
// Add aria-describedby on trigger element, without removing any other IDs
var target=this.getTarget();
var desc=getAttr(target,'aria-describedby')||'';
desc=desc.split(/\s+/).concat(this.computedId).join(' ').trim();// Update/add aria-described by

setAttr(target,'aria-describedby',desc);
},
removeAriaDescribedby:function removeAriaDescribedby(){
var _this5=this;

// Remove aria-describedby on trigger element, without removing any other IDs
var target=this.getTarget();
var desc=getAttr(target,'aria-describedby')||'';
desc=desc.split(/\s+/).filter(function(d){
return d!==_this5.computedId;
}).join(' ').trim();// Update or remove aria-describedby

if(desc){
/* istanbul ignore next */
setAttr(target,'aria-describedby',desc);
}else {
removeAttr(target,'aria-describedby');
}
},
fixTitle:function fixTitle(){
// If the target has a `title` attribute,
// remove it and store it on a data attribute
var target=this.getTarget();

if(hasAttr(target,'title')){
// Get `title` attribute value and remove it from target
var title=getAttr(target,'title');
setAttr(target,'title','');// Only set the data attribute when the value is truthy

if(title){
setAttr(target,DATA_TITLE_ATTR,title);
}
}
},
restoreTitle:function restoreTitle(){
// If the target had a `title` attribute,
// restore it and remove the data attribute
var target=this.getTarget();

if(hasAttr(target,DATA_TITLE_ATTR)){
// Get data attribute value and remove it from target
var title=getAttr(target,DATA_TITLE_ATTR);
removeAttr(target,DATA_TITLE_ATTR);// Only restore the `title` attribute when the value is truthy

if(title){
setAttr(target,'title',title);
}
}
},
// --- BvEvent helpers ---
buildEvent:function buildEvent(type){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
// Defaults to a non-cancellable event
return new BvEvent(type,_objectSpread2({
cancelable:false,
target:this.getTarget(),
relatedTarget:this.getTemplateElement()||null,
componentId:this.computedId,
vueTarget:this},
options));
},
emitEvent:function emitEvent(bvEvent){
var type=bvEvent.type;
this.emitOnRoot(getRootEventName(this.templateType,type),bvEvent);
this.$emit(type,bvEvent);
},
// --- Event handler setup methods ---
listen:function listen(){
var _this6=this;

// Enable trigger event handlers
var el=this.getTarget();

if(!el){
/* istanbul ignore next */
return;
}// Listen for global show/hide events


this.setRootListener(true);// Set up our listeners on the target trigger element

this.computedTriggers.forEach(function(trigger){
if(trigger==='click'){
eventOn(el,'click',_this6.handleEvent,EVENT_OPTIONS_NO_CAPTURE);
}else if(trigger==='focus'){
eventOn(el,'focusin',_this6.handleEvent,EVENT_OPTIONS_NO_CAPTURE);
eventOn(el,'focusout',_this6.handleEvent,EVENT_OPTIONS_NO_CAPTURE);
}else if(trigger==='blur'){
// Used to close $tip when element looses focus

/* istanbul ignore next */
eventOn(el,'focusout',_this6.handleEvent,EVENT_OPTIONS_NO_CAPTURE);
}else if(trigger==='hover'){
eventOn(el,'mouseenter',_this6.handleEvent,EVENT_OPTIONS_NO_CAPTURE);
eventOn(el,'mouseleave',_this6.handleEvent,EVENT_OPTIONS_NO_CAPTURE);
}
},this);
},

/* istanbul ignore next */
unListen:function unListen(){
var _this7=this;

// Remove trigger event handlers
var events=['click','focusin','focusout','mouseenter','mouseleave'];
var target=this.getTarget();// Stop listening for global show/hide/enable/disable events

this.setRootListener(false);// Clear out any active target listeners

events.forEach(function(event){
target&&eventOff(target,event,_this7.handleEvent,EVENT_OPTIONS_NO_CAPTURE);
},this);
},
setRootListener:function setRootListener(on){
// Listen for global `bv::{hide|show}::{tooltip|popover}` hide request event
var $root=this.$root;

if($root){
var method=on?'$on':'$off';
var type=this.templateType;
$root[method](getRootActionEventName(type,EVENT_NAME_HIDE),this.doHide);
$root[method](getRootActionEventName(type,EVENT_NAME_SHOW),this.doShow);
$root[method](getRootActionEventName(type,EVENT_NAME_DISABLE),this.doDisable);
$root[method](getRootActionEventName(type,EVENT_NAME_ENABLE),this.doEnable);
}
},
setWhileOpenListeners:function setWhileOpenListeners(on){
// Events that are only registered when the template is showing
// Modal close events
this.setModalListener(on);// Dropdown open events (if we are attached to a dropdown)

this.setDropdownListener(on);// Periodic $element visibility check
// For handling when tip target is in <keepalive>, tabs, carousel, etc

this.visibleCheck(on);// On-touch start listeners

this.setOnTouchStartListener(on);
},
// Handler for periodic visibility check
visibleCheck:function visibleCheck(on){
var _this8=this;

this.clearVisibilityInterval();
var target=this.getTarget();
var tip=this.getTemplateElement();

if(on){
this.$_visibleInterval=setInterval(function(){
if(tip&&_this8.localShow&&(!target.parentNode||!isVisible(target))){
// Target element is no longer visible or not in DOM, so force-hide the tooltip
_this8.forceHide();
}
},100);
}
},
setModalListener:function setModalListener(on){
// Handle case where tooltip/target is in a modal
if(this.isInModal()){
// We can listen for modal hidden events on `$root`
this.$root[on?'$on':'$off'](ROOT_EVENT_NAME_MODAL_HIDDEN,this.forceHide);
}
},

/* istanbul ignore next: JSDOM doesn't support `ontouchstart` */
setOnTouchStartListener:function setOnTouchStartListener(on){
var _this9=this;

// If this is a touch-enabled device we add extra empty
// `mouseover` listeners to the body's immediate children
// Only needed because of broken event delegation on iOS
// https://www.quirksmode.org/blog/archives/2014/02/mouse_event_bub.html
if('ontouchstart'in document.documentElement){
from(document.body.children).forEach(function(el){
eventOnOff(on,el,'mouseover',_this9.$_noop);
});
}
},
setDropdownListener:function setDropdownListener(on){
var target=this.getTarget();

if(!target||!this.$root||!this.isDropdown){
return;
}// We can listen for dropdown shown events on its instance
// TODO:
//   We could grab the ID from the dropdown, and listen for
//   $root events for that particular dropdown id
//   Dropdown shown and hidden events will need to emit
//   Note: Dropdown auto-ID happens in a `$nextTick()` after mount
//         So the ID lookup would need to be done in a `$nextTick()`


if(target.__vue__){
target.__vue__[on?'$on':'$off'](EVENT_NAME_SHOWN,this.forceHide);
}
},
// --- Event handlers ---
handleEvent:function handleEvent(event){
// General trigger event handler
// target is the trigger element
var target=this.getTarget();

if(!target||isDisabled(target)||!this.$_enabled||this.dropdownOpen()){
// If disabled or not enabled, or if a dropdown that is open, don't do anything
// If tip is shown before element gets disabled, then tip will not
// close until no longer disabled or forcefully closed
return;
}

var type=event.type;
var triggers=this.computedTriggers;

if(type==='click'&&arrayIncludes(triggers,'click')){
this.click(event);
}else if(type==='mouseenter'&&arrayIncludes(triggers,'hover')){
// `mouseenter` is a non-bubbling event
this.enter(event);
}else if(type==='focusin'&&arrayIncludes(triggers,'focus')){
// `focusin` is a bubbling event
// `event` includes `relatedTarget` (element losing focus)
this.enter(event);
}else if(type==='focusout'&&(arrayIncludes(triggers,'focus')||arrayIncludes(triggers,'blur'))||type==='mouseleave'&&arrayIncludes(triggers,'hover')){
// `focusout` is a bubbling event
// `mouseleave` is a non-bubbling event
// `tip` is the template (will be null if not open)
var tip=this.getTemplateElement();// `eventTarget` is the element which is losing focus/hover and

var eventTarget=event.target;// `relatedTarget` is the element gaining focus/hover

var relatedTarget=event.relatedTarget;
/* istanbul ignore next */

if(// From tip to target
tip&&contains(tip,eventTarget)&&contains(target,relatedTarget)||// From target to tip
tip&&contains(target,eventTarget)&&contains(tip,relatedTarget)||// Within tip
tip&&contains(tip,eventTarget)&&contains(tip,relatedTarget)||// Within target
contains(target,eventTarget)&&contains(target,relatedTarget)){
// If focus/hover moves within `tip` and `target`, don't trigger a leave
return;
}// Otherwise trigger a leave


this.leave(event);
}
},
doHide:function doHide(id){
// Programmatically hide tooltip or popover
if(!id||this.getTargetId()===id||this.computedId===id){
// Close all tooltips or popovers, or this specific tip (with ID)
this.forceHide();
}
},
doShow:function doShow(id){
// Programmatically show tooltip or popover
if(!id||this.getTargetId()===id||this.computedId===id){
// Open all tooltips or popovers, or this specific tip (with ID)
this.show();
}
},

/*istanbul ignore next: ignore for now */
doDisable:function doDisable(id)
/*istanbul ignore next: ignore for now */
{
// Programmatically disable tooltip or popover
if(!id||this.getTargetId()===id||this.computedId===id){
// Disable all tooltips or popovers (no ID), or this specific tip (with ID)
this.disable();
}
},

/*istanbul ignore next: ignore for now */
doEnable:function doEnable(id)
/*istanbul ignore next: ignore for now */
{
// Programmatically enable tooltip or popover
if(!id||this.getTargetId()===id||this.computedId===id){
// Enable all tooltips or popovers (no ID), or this specific tip (with ID)
this.enable();
}
},
click:function click(event){
if(!this.$_enabled||this.dropdownOpen()){
/* istanbul ignore next */
return;
}// Get around a WebKit bug where `click` does not trigger focus events
// On most browsers, `click` triggers a `focusin`/`focus` event first
// Needed so that trigger 'click blur' works on iOS
// https://github.com/bootstrap-vue/bootstrap-vue/issues/5099
// We use `currentTarget` rather than `target` to trigger on the
// element, not the inner content


attemptFocus(event.currentTarget);
this.activeTrigger.click=!this.activeTrigger.click;

if(this.isWithActiveTrigger){
this.enter(null);
}else {
/* istanbul ignore next */
this.leave(null);
}
},

/* istanbul ignore next */
toggle:function toggle(){
// Manual toggle handler
if(!this.$_enabled||this.dropdownOpen()){
/* istanbul ignore next */
return;
}// Should we register as an active trigger?
// this.activeTrigger.manual = !this.activeTrigger.manual


if(this.localShow){
this.leave(null);
}else {
this.enter(null);
}
},
enter:function enter(){
var _this10=this;

var event=arguments.length>0&&arguments[0]!==undefined?arguments[0]:null;

// Opening trigger handler
// Note: Click events are sent with event === null
if(event){
this.activeTrigger[event.type==='focusin'?'focus':'hover']=true;
}
/* istanbul ignore next */


if(this.localShow||this.$_hoverState==='in'){
this.$_hoverState='in';
return;
}

this.clearHoverTimeout();
this.$_hoverState='in';

if(!this.computedDelay.show){
this.show();
}else {
// Hide any title attribute while enter delay is active
this.fixTitle();
this.$_hoverTimeout=setTimeout(function(){
/* istanbul ignore else */
if(_this10.$_hoverState==='in'){
_this10.show();
}else if(!_this10.localShow){
_this10.restoreTitle();
}
},this.computedDelay.show);
}
},
leave:function leave(){
var _this11=this;

var event=arguments.length>0&&arguments[0]!==undefined?arguments[0]:null;

// Closing trigger handler
// Note: Click events are sent with event === null
if(event){
this.activeTrigger[event.type==='focusout'?'focus':'hover']=false;
/* istanbul ignore next */

if(event.type==='focusout'&&arrayIncludes(this.computedTriggers,'blur')){
// Special case for `blur`: we clear out the other triggers
this.activeTrigger.click=false;
this.activeTrigger.hover=false;
}
}
/* istanbul ignore next: ignore for now */


if(this.isWithActiveTrigger){
return;
}

this.clearHoverTimeout();
this.$_hoverState='out';

if(!this.computedDelay.hide){
this.hide();
}else {
this.$_hoverTimeout=setTimeout(function(){
if(_this11.$_hoverState==='out'){
_this11.hide();
}
},this.computedDelay.hide);
}
}}});



var _makePropsConfigurabl,_watch$f;

var MODEL_PROP_NAME_ENABLED='disabled';
var MODEL_EVENT_NAME_ENABLED=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_ENABLED;
var MODEL_PROP_NAME_SHOW$1='show';
var MODEL_EVENT_NAME_SHOW$1=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_SHOW$1;// --- Props ---

var props$1J=makePropsConfigurable((_makePropsConfigurabl={
// String: scrollParent, window, or viewport
// Element: element reference
// Object: Vue component
boundary:makeProp([HTMLElement,PROP_TYPE_OBJECT,PROP_TYPE_STRING],'scrollParent'),
boundaryPadding:makeProp(PROP_TYPE_NUMBER_STRING,50),
// String: HTML ID of container, if null body is used (default)
// HTMLElement: element reference reference
// Object: Vue Component
container:makeProp([HTMLElement,PROP_TYPE_OBJECT,PROP_TYPE_STRING]),
customClass:makeProp(PROP_TYPE_STRING),
delay:makeProp(PROP_TYPE_NUMBER_OBJECT_STRING,50)},
_defineProperty(_makePropsConfigurabl,MODEL_PROP_NAME_ENABLED,makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_makePropsConfigurabl,"fallbackPlacement",makeProp(PROP_TYPE_ARRAY_STRING,'flip')),_defineProperty(_makePropsConfigurabl,"id",makeProp(PROP_TYPE_STRING)),_defineProperty(_makePropsConfigurabl,"noFade",makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_makePropsConfigurabl,"noninteractive",makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_makePropsConfigurabl,"offset",makeProp(PROP_TYPE_NUMBER_STRING,0)),_defineProperty(_makePropsConfigurabl,"placement",makeProp(PROP_TYPE_STRING,'top')),_defineProperty(_makePropsConfigurabl,MODEL_PROP_NAME_SHOW$1,makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_makePropsConfigurabl,"target",makeProp([HTMLElement,SVGElement,PROP_TYPE_FUNCTION,PROP_TYPE_OBJECT,PROP_TYPE_STRING],undefined,true)),_defineProperty(_makePropsConfigurabl,"title",makeProp(PROP_TYPE_STRING)),_defineProperty(_makePropsConfigurabl,"triggers",makeProp(PROP_TYPE_ARRAY_STRING,'hover focus')),_defineProperty(_makePropsConfigurabl,"variant",makeProp(PROP_TYPE_STRING)),_makePropsConfigurabl),NAME_TOOLTIP);// --- Main component ---
// @vue/component

var BTooltip=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TOOLTIP,
mixins:[normalizeSlotMixin],
inheritAttrs:false,
props:props$1J,
data:function data(){
return {
localShow:this[MODEL_PROP_NAME_SHOW$1],
localTitle:'',
localContent:''};

},
computed:{
// Data that will be passed to the template and popper
templateData:function templateData(){
return _objectSpread2({
title:this.localTitle,
content:this.localContent,
interactive:!this.noninteractive},
pick(this.$props,['boundary','boundaryPadding','container','customClass','delay','fallbackPlacement','id','noFade','offset','placement','target','target','triggers','variant',MODEL_PROP_NAME_ENABLED]));
},
// Used to watch for changes to the title and content props
templateTitleContent:function templateTitleContent(){
var title=this.title,
content=this.content;
return {
title:title,
content:content};

}},

watch:(_watch$f={},_defineProperty(_watch$f,MODEL_PROP_NAME_SHOW$1,function(newValue,oldValue){
if(newValue!==oldValue&&newValue!==this.localShow&&this.$_toolpop){
if(newValue){
this.$_toolpop.show();
}else {
// We use `forceHide()` to override any active triggers
this.$_toolpop.forceHide();
}
}
}),_defineProperty(_watch$f,MODEL_PROP_NAME_ENABLED,function(newValue){
if(newValue){
this.doDisable();
}else {
this.doEnable();
}
}),_defineProperty(_watch$f,"localShow",function localShow(newValue){
// TODO: May need to be done in a `$nextTick()`
this.$emit(MODEL_EVENT_NAME_SHOW$1,newValue);
}),_defineProperty(_watch$f,"templateData",function templateData(){
var _this=this;

this.$nextTick(function(){
if(_this.$_toolpop){
_this.$_toolpop.updateData(_this.templateData);
}
});
}),_defineProperty(_watch$f,"templateTitleContent",function templateTitleContent(){
this.$nextTick(this.updateContent);
}),_watch$f),
created:function created(){
// Create private non-reactive props
this.$_toolpop=null;
},
updated:function updated(){
// Update the `propData` object
// Done in a `$nextTick()` to ensure slot(s) have updated
this.$nextTick(this.updateContent);
},
beforeDestroy:function beforeDestroy(){
// Shutdown our local event listeners
this.$off(EVENT_NAME_OPEN,this.doOpen);
this.$off(EVENT_NAME_CLOSE,this.doClose);
this.$off(EVENT_NAME_DISABLE,this.doDisable);
this.$off(EVENT_NAME_ENABLE,this.doEnable);// Destroy the tip instance

if(this.$_toolpop){
this.$_toolpop.$destroy();
this.$_toolpop=null;
}
},
mounted:function mounted(){
var _this2=this;

// Instantiate a new BVTooltip instance
// Done in a `$nextTick()` to ensure DOM has completed rendering
// so that target can be found
this.$nextTick(function(){
// Load the on demand child instance
var Component=_this2.getComponent();// Ensure we have initial content


_this2.updateContent();// Pass down the scoped style attribute if available


var scopeId=getScopeId(_this2)||getScopeId(_this2.$parent);// Create the instance

var $toolpop=_this2.$_toolpop=new Component({
parent:_this2,
// Pass down the scoped style ID
_scopeId:scopeId||undefined});
// Set the initial data

$toolpop.updateData(_this2.templateData);// Set listeners

$toolpop.$on(EVENT_NAME_SHOW,_this2.onShow);
$toolpop.$on(EVENT_NAME_SHOWN,_this2.onShown);
$toolpop.$on(EVENT_NAME_HIDE,_this2.onHide);
$toolpop.$on(EVENT_NAME_HIDDEN,_this2.onHidden);
$toolpop.$on(EVENT_NAME_DISABLED,_this2.onDisabled);
$toolpop.$on(EVENT_NAME_ENABLED,_this2.onEnabled);// Initially disabled?

if(_this2[MODEL_PROP_NAME_ENABLED]){
// Initially disabled
_this2.doDisable();
}// Listen to open signals from others


_this2.$on(EVENT_NAME_OPEN,_this2.doOpen);// Listen to close signals from others


_this2.$on(EVENT_NAME_CLOSE,_this2.doClose);// Listen to disable signals from others


_this2.$on(EVENT_NAME_DISABLE,_this2.doDisable);// Listen to enable signals from others


_this2.$on(EVENT_NAME_ENABLE,_this2.doEnable);// Initially show tooltip?


if(_this2.localShow){
$toolpop.show();
}
});
},
methods:{
getComponent:function getComponent(){
// Overridden by BPopover
return BVTooltip;
},
updateContent:function updateContent(){
// Overridden by BPopover
// Tooltip: Default slot is `title`
// Popover: Default slot is `content`, `title` slot is title
// We pass a scoped slot function reference by default (Vue v2.6x)
// And pass the title prop as a fallback
this.setTitle(this.normalizeSlot()||this.title);
},
// Helper methods for `updateContent()`
setTitle:function setTitle(value){
value=isUndefinedOrNull(value)?'':value;// We only update the value if it has changed

if(this.localTitle!==value){
this.localTitle=value;
}
},
setContent:function setContent(value){
value=isUndefinedOrNull(value)?'':value;// We only update the value if it has changed

if(this.localContent!==value){
this.localContent=value;
}
},
// --- Template event handlers ---
onShow:function onShow(bvEvent){
// Placeholder
this.$emit(EVENT_NAME_SHOW,bvEvent);

if(bvEvent){
this.localShow=!bvEvent.defaultPrevented;
}
},
onShown:function onShown(bvEvent){
// Tip is now showing
this.localShow=true;
this.$emit(EVENT_NAME_SHOWN,bvEvent);
},
onHide:function onHide(bvEvent){
this.$emit(EVENT_NAME_HIDE,bvEvent);
},
onHidden:function onHidden(bvEvent){
// Tip is no longer showing
this.$emit(EVENT_NAME_HIDDEN,bvEvent);
this.localShow=false;
},
onDisabled:function onDisabled(bvEvent){
// Prevent possible endless loop if user mistakenly
// fires `disabled` instead of `disable`
if(bvEvent&&bvEvent.type===EVENT_NAME_DISABLED){
this.$emit(MODEL_EVENT_NAME_ENABLED,true);
this.$emit(EVENT_NAME_DISABLED,bvEvent);
}
},
onEnabled:function onEnabled(bvEvent){
// Prevent possible endless loop if user mistakenly
// fires `enabled` instead of `enable`
if(bvEvent&&bvEvent.type===EVENT_NAME_ENABLED){
this.$emit(MODEL_EVENT_NAME_ENABLED,false);
this.$emit(EVENT_NAME_ENABLED,bvEvent);
}
},
// --- Local event listeners ---
doOpen:function doOpen(){
!this.localShow&&this.$_toolpop&&this.$_toolpop.show();
},
doClose:function doClose(){
this.localShow&&this.$_toolpop&&this.$_toolpop.hide();
},
doDisable:function doDisable(){
this.$_toolpop&&this.$_toolpop.disable();
},
doEnable:function doEnable(){
this.$_toolpop&&this.$_toolpop.enable();
}},

render:function render(h){
// Always renders a comment node
// TODO:
//   Future: Possibly render a target slot (single root element)
//   which we can apply the listeners to (pass `this.$el` to BVTooltip)
return h();
}});


var BVPopoverTemplate=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_POPOVER_TEMPLATE,
extends:BVTooltipTemplate,
computed:{
templateType:function templateType(){
return 'popover';
}},

methods:{
renderTemplate:function renderTemplate(h){
var title=this.title,
content=this.content;// Title and content could be a scoped slot function

var $title=isFunction(title)?title({}):title;
var $content=isFunction(content)?content({}):content;// Directive usage only

var titleDomProps=this.html&&!isFunction(title)?{
innerHTML:title}:
{};
var contentDomProps=this.html&&!isFunction(content)?{
innerHTML:content}:
{};
return h('div',{
staticClass:'popover b-popover',
class:this.templateClasses,
attrs:this.templateAttributes,
on:this.templateListeners},
[h('div',{
staticClass:'arrow',
ref:'arrow'}),
isUndefinedOrNull($title)||$title===''?
/* istanbul ignore next */
h():h('h3',{
staticClass:'popover-header',
domProps:titleDomProps},
[$title]),isUndefinedOrNull($content)||$content===''?
/* istanbul ignore next */
h():h('div',{
staticClass:'popover-body',
domProps:contentDomProps},
[$content])]);
}}});



// Popover "Class" (Built as a renderless Vue instance)

var BVPopover=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_POPOVER_HELPER,
extends:BVTooltip,
computed:{
// Overwrites BVTooltip
templateType:function templateType(){
return 'popover';
}},

methods:{
getTemplate:function getTemplate(){
// Overwrites BVTooltip
return BVPopoverTemplate;
}}});



var props$1K=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$1J),{},{
content:makeProp(PROP_TYPE_STRING),
placement:makeProp(PROP_TYPE_STRING,'right'),
triggers:makeProp(PROP_TYPE_ARRAY_STRING,EVENT_NAME_CLICK)})),
NAME_POPOVER);// --- Main component ---
// @vue/component

var BPopover=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_POPOVER,
extends:BTooltip,
inheritAttrs:false,
props:props$1K,
methods:{
getComponent:function getComponent(){
// Overridden by BPopover
return BVPopover;
},
updateContent:function updateContent(){
// Tooltip: Default slot is `title`
// Popover: Default slot is `content`, `title` slot is title
// We pass a scoped slot function references by default (Vue v2.6x)
// And pass the title prop as a fallback
this.setContent(this.normalizeSlot()||this.content);
this.setTitle(this.normalizeSlot(SLOT_NAME_TITLE)||this.title);
}}
// Render function provided by BTooltip
});


var BV_POPOVER='__BV_Popover__';// Default trigger

var DefaultTrigger='click';// Valid event triggers

var validTriggers={
focus:true,
hover:true,
click:true,
blur:true,
manual:true};
// Directive modifier test regular expressions. Pre-compile for performance

var htmlRE=/^html$/i;
var noFadeRE=/^nofade$/i;
var placementRE=/^(auto|top(left|right)?|bottom(left|right)?|left(top|bottom)?|right(top|bottom)?)$/i;
var boundaryRE=/^(window|viewport|scrollParent)$/i;
var delayRE=/^d\d+$/i;
var delayShowRE=/^ds\d+$/i;
var delayHideRE=/^dh\d+$/i;
var offsetRE=/^o-?\d+$/i;
var variantRE=/^v-.+$/i;
var spacesRE=/\s+/;// Build a Popover config based on bindings (if any)
// Arguments and modifiers take precedence over passed value config object

var parseBindings=function parseBindings(bindings,vnode)
/* istanbul ignore next: not easy to test */
{
// We start out with a basic config
var config={
title:undefined,
content:undefined,
trigger:'',
// Default set below if needed
placement:'right',
fallbackPlacement:'flip',
container:false,
// Default of body
animation:true,
offset:0,
disabled:false,
id:null,
html:false,
delay:getComponentConfig(NAME_POPOVER,'delay',50),
boundary:String(getComponentConfig(NAME_POPOVER,'boundary','scrollParent')),
boundaryPadding:toInteger(getComponentConfig(NAME_POPOVER,'boundaryPadding',5),0),
variant:getComponentConfig(NAME_POPOVER,'variant'),
customClass:getComponentConfig(NAME_POPOVER,'customClass')};
// Process `bindings.value`

if(isString(bindings.value)||isNumber(bindings.value)){
// Value is popover content (html optionally supported)
config.content=bindings.value;
}else if(isFunction(bindings.value)){
// Content generator function
config.content=bindings.value;
}else if(isPlainObject(bindings.value)){
// Value is config object, so merge
config=_objectSpread2(_objectSpread2({},config),bindings.value);
}// If argument, assume element ID of container element


if(bindings.arg){
// Element ID specified as arg
// We must prepend '#' to become a CSS selector
config.container="#".concat(bindings.arg);
}// If title is not provided, try title attribute


if(isUndefined(config.title)){
// Try attribute
var data=vnode.data||{};
config.title=data.attrs&&!isUndefinedOrNull(data.attrs.title)?data.attrs.title:undefined;
}// Normalize delay


if(!isPlainObject(config.delay)){
config.delay={
show:toInteger(config.delay,0),
hide:toInteger(config.delay,0)};

}// Process modifiers


keys(bindings.modifiers).forEach(function(mod){
if(htmlRE.test(mod)){
// Title/content allows HTML
config.html=true;
}else if(noFadeRE.test(mod)){
// No animation
config.animation=false;
}else if(placementRE.test(mod)){
// Placement of popover
config.placement=mod;
}else if(boundaryRE.test(mod)){
// Boundary of popover
mod=mod==='scrollparent'?'scrollParent':mod;
config.boundary=mod;
}else if(delayRE.test(mod)){
// Delay value
var delay=toInteger(mod.slice(1),0);
config.delay.show=delay;
config.delay.hide=delay;
}else if(delayShowRE.test(mod)){
// Delay show value
config.delay.show=toInteger(mod.slice(2),0);
}else if(delayHideRE.test(mod)){
// Delay hide value
config.delay.hide=toInteger(mod.slice(2),0);
}else if(offsetRE.test(mod)){
// Offset value, negative allowed
config.offset=toInteger(mod.slice(1),0);
}else if(variantRE.test(mod)){
// Variant
config.variant=mod.slice(2)||null;
}
});// Special handling of event trigger modifiers trigger is
// a space separated list

var selectedTriggers={};// Parse current config object trigger

concat(config.trigger||'').filter(identity).join(' ').trim().toLowerCase().split(spacesRE).forEach(function(trigger){
if(validTriggers[trigger]){
selectedTriggers[trigger]=true;
}
});// Parse modifiers for triggers

keys(bindings.modifiers).forEach(function(mod){
mod=mod.toLowerCase();

if(validTriggers[mod]){
// If modifier is a valid trigger
selectedTriggers[mod]=true;
}
});// Sanitize triggers

config.trigger=keys(selectedTriggers).join(' ');

if(config.trigger==='blur'){
// Blur by itself is useless, so convert it to 'focus'
config.trigger='focus';
}

if(!config.trigger){
// Use default trigger
config.trigger=DefaultTrigger;
}

return config;
};// Add or update Popover on our element


var applyPopover=function applyPopover(el,bindings,vnode){
if(!IS_BROWSER){
/* istanbul ignore next */
return;
}

var config=parseBindings(bindings,vnode);

if(!el[BV_POPOVER]){
var $parent=vnode.context;
el[BV_POPOVER]=new BVPopover({
parent:$parent,
// Add the parent's scoped style attribute data
_scopeId:getScopeId($parent,undefined)});

el[BV_POPOVER].__bv_prev_data__={};
el[BV_POPOVER].$on(EVENT_NAME_SHOW,function()
/* istanbul ignore next: for now */
{
// Before showing the popover, we update the title
// and content if they are functions
var data={};

if(isFunction(config.title)){
data.title=config.title(el);
}

if(isFunction(config.content)){
data.content=config.content(el);
}

if(keys(data).length>0){
el[BV_POPOVER].updateData(data);
}
});
}

var data={
title:config.title,
content:config.content,
triggers:config.trigger,
placement:config.placement,
fallbackPlacement:config.fallbackPlacement,
variant:config.variant,
customClass:config.customClass,
container:config.container,
boundary:config.boundary,
delay:config.delay,
offset:config.offset,
noFade:!config.animation,
id:config.id,
disabled:config.disabled,
html:config.html};

var oldData=el[BV_POPOVER].__bv_prev_data__;
el[BV_POPOVER].__bv_prev_data__=data;

if(!looseEqual(data,oldData)){
// We only update the instance if data has changed
var newData={
target:el};

keys(data).forEach(function(prop){
// We only pass data properties that have changed
if(data[prop]!==oldData[prop]){
// If title/content is a function, we execute it here
newData[prop]=(prop==='title'||prop==='content')&&isFunction(data[prop])?
/* istanbul ignore next */
data[prop](el):data[prop];
}
});
el[BV_POPOVER].updateData(newData);
}
};// Remove Popover from our element


var removePopover=function removePopover(el){
if(el[BV_POPOVER]){
el[BV_POPOVER].$destroy();
el[BV_POPOVER]=null;
}

delete el[BV_POPOVER];
};// Export our directive


var VBPopover={
bind:function bind(el,bindings,vnode){
applyPopover(el,bindings,vnode);
},
// We use `componentUpdated` here instead of `update`, as the former
// waits until the containing component and children have finished updating
componentUpdated:function componentUpdated(el,bindings,vnode){
// Performed in a `$nextTick()` to prevent endless render/update loops
vnode.context.$nextTick(function(){
applyPopover(el,bindings,vnode);
});
},
unbind:function unbind(el){
removePopover(el);
}};


var VBPopoverPlugin=/*#__PURE__*/pluginFactory({
directives:{
VBPopover:VBPopover}});



var PopoverPlugin=/*#__PURE__*/pluginFactory({
components:{
BPopover:BPopover},

plugins:{
VBPopoverPlugin:VBPopoverPlugin}});



var props$1L=makePropsConfigurable({
animated:makeProp(PROP_TYPE_BOOLEAN,null),
label:makeProp(PROP_TYPE_STRING),
labelHtml:makeProp(PROP_TYPE_STRING),
max:makeProp(PROP_TYPE_NUMBER_STRING,null),
precision:makeProp(PROP_TYPE_NUMBER_STRING,null),
showProgress:makeProp(PROP_TYPE_BOOLEAN,null),
showValue:makeProp(PROP_TYPE_BOOLEAN,null),
striped:makeProp(PROP_TYPE_BOOLEAN,null),
value:makeProp(PROP_TYPE_NUMBER_STRING,0),
variant:makeProp(PROP_TYPE_STRING)},
NAME_PROGRESS_BAR);// --- Main component ---
// @vue/component

var BProgressBar=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_PROGRESS_BAR,
mixins:[normalizeSlotMixin],
inject:{
bvProgress:{
default:
/* istanbul ignore next */
function _default(){
return {};
}}},


props:props$1L,
computed:{
progressBarClasses:function progressBarClasses(){
var computedAnimated=this.computedAnimated,
computedVariant=this.computedVariant;
return [computedVariant?"bg-".concat(computedVariant):'',this.computedStriped||computedAnimated?'progress-bar-striped':'',computedAnimated?'progress-bar-animated':''];
},
progressBarStyles:function progressBarStyles(){
return {
width:100*(this.computedValue/this.computedMax)+'%'};

},
computedValue:function computedValue(){
return toFloat(this.value,0);
},
computedMax:function computedMax(){
// Prefer our max over parent setting
// Default to `100` for invalid values (`-x`, `0`, `NaN`)
var max=toFloat(this.max)||toFloat(this.bvProgress.max,0);
return max>0?max:100;
},
computedPrecision:function computedPrecision(){
// Prefer our precision over parent setting
// Default to `0` for invalid values (`-x`, `NaN`)
return mathMax(toInteger(this.precision,toInteger(this.bvProgress.precision,0)),0);
},
computedProgress:function computedProgress(){
var precision=this.computedPrecision;
var p=mathPow(10,precision);
return toFixed(100*p*this.computedValue/this.computedMax/p,precision);
},
computedVariant:function computedVariant(){
// Prefer our variant over parent setting
return this.variant||this.bvProgress.variant;
},
computedStriped:function computedStriped(){
// Prefer our striped over parent setting
return isBoolean(this.striped)?this.striped:this.bvProgress.striped||false;
},
computedAnimated:function computedAnimated(){
// Prefer our animated over parent setting
return isBoolean(this.animated)?this.animated:this.bvProgress.animated||false;
},
computedShowProgress:function computedShowProgress(){
// Prefer our showProgress over parent setting
return isBoolean(this.showProgress)?this.showProgress:this.bvProgress.showProgress||false;
},
computedShowValue:function computedShowValue(){
// Prefer our showValue over parent setting
return isBoolean(this.showValue)?this.showValue:this.bvProgress.showValue||false;
}},

render:function render(h){
var label=this.label,
labelHtml=this.labelHtml,
computedValue=this.computedValue,
computedPrecision=this.computedPrecision;
var $children;
var domProps={};

if(this.hasNormalizedSlot()){
$children=this.normalizeSlot();
}else if(label||labelHtml){
domProps=htmlOrText(labelHtml,label);
}else if(this.computedShowProgress){
$children=this.computedProgress;
}else if(this.computedShowValue){
$children=toFixed(computedValue,computedPrecision);
}

return h('div',{
staticClass:'progress-bar',
class:this.progressBarClasses,
style:this.progressBarStyles,
attrs:{
role:'progressbar',
'aria-valuemin':'0',
'aria-valuemax':toString$1(this.computedMax),
'aria-valuenow':toFixed(computedValue,computedPrecision)},

domProps:domProps},
$children);
}});


var progressBarProps=omit(props$1L,['label','labelHtml']);
var props$1M=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},progressBarProps),{},{
animated:makeProp(PROP_TYPE_BOOLEAN,false),
height:makeProp(PROP_TYPE_STRING),
max:makeProp(PROP_TYPE_NUMBER_STRING,100),
precision:makeProp(PROP_TYPE_NUMBER_STRING,0),
showProgress:makeProp(PROP_TYPE_BOOLEAN,false),
showValue:makeProp(PROP_TYPE_BOOLEAN,false),
striped:makeProp(PROP_TYPE_BOOLEAN,false)})),
NAME_PROGRESS);// --- Main component ---
// @vue/component

var BProgress=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_PROGRESS,
mixins:[normalizeSlotMixin],
provide:function provide(){
return {
bvProgress:this};

},
props:props$1M,
computed:{
progressHeight:function progressHeight(){
return {
height:this.height||null};

}},

render:function render(h){
var $childNodes=this.normalizeSlot();

if(!$childNodes){
$childNodes=h(BProgressBar,{
props:pluckProps(progressBarProps,this.$props)});

}

return h('div',{
staticClass:'progress',
style:this.progressHeight},
[$childNodes]);
}});


var ProgressPlugin=/*#__PURE__*/pluginFactory({
components:{
BProgress:BProgress,
BProgressBar:BProgressBar}});



var _watch$g;

var CLASS_NAME$3='b-sidebar';
var ROOT_ACTION_EVENT_NAME_REQUEST_STATE$2=getRootActionEventName(NAME_COLLAPSE,'request-state');
var ROOT_ACTION_EVENT_NAME_TOGGLE$2=getRootActionEventName(NAME_COLLAPSE,'toggle');
var ROOT_EVENT_NAME_STATE$3=getRootEventName(NAME_COLLAPSE,'state');
var ROOT_EVENT_NAME_SYNC_STATE$3=getRootEventName(NAME_COLLAPSE,'sync-state');

var _makeModelMixin$h=makeModelMixin('visible',{
type:PROP_TYPE_BOOLEAN,
defaultValue:false,
event:EVENT_NAME_CHANGE}),

modelMixin$g=_makeModelMixin$h.mixin,
modelProps$g=_makeModelMixin$h.props,
MODEL_PROP_NAME$g=_makeModelMixin$h.prop,
MODEL_EVENT_NAME$g=_makeModelMixin$h.event;// --- Props ---


var props$1N=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$g),{},{
ariaLabel:makeProp(PROP_TYPE_STRING),
ariaLabelledby:makeProp(PROP_TYPE_STRING),
// If `true`, shows a basic backdrop
backdrop:makeProp(PROP_TYPE_BOOLEAN,false),
backdropVariant:makeProp(PROP_TYPE_STRING,'dark'),
bgVariant:makeProp(PROP_TYPE_STRING,'light'),
bodyClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
// `aria-label` for close button
closeLabel:makeProp(PROP_TYPE_STRING),
footerClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
headerClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
lazy:makeProp(PROP_TYPE_BOOLEAN,false),
noCloseOnBackdrop:makeProp(PROP_TYPE_BOOLEAN,false),
noCloseOnEsc:makeProp(PROP_TYPE_BOOLEAN,false),
noCloseOnRouteChange:makeProp(PROP_TYPE_BOOLEAN,false),
noEnforceFocus:makeProp(PROP_TYPE_BOOLEAN,false),
noHeader:makeProp(PROP_TYPE_BOOLEAN,false),
noHeaderClose:makeProp(PROP_TYPE_BOOLEAN,false),
noSlide:makeProp(PROP_TYPE_BOOLEAN,false),
right:makeProp(PROP_TYPE_BOOLEAN,false),
shadow:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
sidebarClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
tag:makeProp(PROP_TYPE_STRING,'div'),
textVariant:makeProp(PROP_TYPE_STRING,'dark'),
title:makeProp(PROP_TYPE_STRING),
width:makeProp(PROP_TYPE_STRING),
zIndex:makeProp(PROP_TYPE_NUMBER_STRING)})),
NAME_SIDEBAR);// --- Render methods ---

var renderHeaderTitle=function renderHeaderTitle(h,ctx){
// Render a empty `<span>` when to title was provided
var title=ctx.normalizeSlot(SLOT_NAME_TITLE,ctx.slotScope)||ctx.title;

if(!title){
return h('span');
}

return h('strong',{
attrs:{
id:ctx.safeId('__title__')}},

[title]);
};

var renderHeaderClose=function renderHeaderClose(h,ctx){
if(ctx.noHeaderClose){
return h();
}

var closeLabel=ctx.closeLabel,
textVariant=ctx.textVariant,
hide=ctx.hide;
return h(BButtonClose,{
props:{
ariaLabel:closeLabel,
textVariant:textVariant},

on:{
click:hide},

ref:'close-button'},
[ctx.normalizeSlot(SLOT_NAME_HEADER_CLOSE)||h(BIconX)]);
};

var renderHeader=function renderHeader(h,ctx){
if(ctx.noHeader){
return h();
}

var $content=ctx.normalizeSlot(SLOT_NAME_HEADER,ctx.slotScope);

if(!$content){
var $title=renderHeaderTitle(h,ctx);
var $close=renderHeaderClose(h,ctx);
$content=ctx.right?[$close,$title]:[$title,$close];
}

return h('header',{
staticClass:"".concat(CLASS_NAME$3,"-header"),
class:ctx.headerClass,
key:'header'},
$content);
};

var renderBody=function renderBody(h,ctx){
return h('div',{
staticClass:"".concat(CLASS_NAME$3,"-body"),
class:ctx.bodyClass,
key:'body'},
[ctx.normalizeSlot(SLOT_NAME_DEFAULT,ctx.slotScope)]);
};

var renderFooter=function renderFooter(h,ctx){
var $footer=ctx.normalizeSlot(SLOT_NAME_FOOTER,ctx.slotScope);

if(!$footer){
return h();
}

return h('footer',{
staticClass:"".concat(CLASS_NAME$3,"-footer"),
class:ctx.footerClass,
key:'footer'},
[$footer]);
};

var renderContent=function renderContent(h,ctx){
// We render the header even if `lazy` is enabled as it
// acts as the accessible label for the sidebar
var $header=renderHeader(h,ctx);

if(ctx.lazy&&!ctx.isOpen){
return $header;
}

return [$header,renderBody(h,ctx),renderFooter(h,ctx)];
};

var renderBackdrop=function renderBackdrop(h,ctx){
if(!ctx.backdrop){
return h();
}

var backdropVariant=ctx.backdropVariant;
return h('div',{
directives:[{
name:'show',
value:ctx.localShow}],

staticClass:'b-sidebar-backdrop',
class:_defineProperty({},"bg-".concat(backdropVariant),backdropVariant),
on:{
click:ctx.onBackdropClick}});


};// --- Main component ---
// @vue/component


var BSidebar=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_SIDEBAR,
mixins:[attrsMixin,idMixin,modelMixin$g,listenOnRootMixin,normalizeSlotMixin],
inheritAttrs:false,
props:props$1N,
data:function data(){
var visible=!!this[MODEL_PROP_NAME$g];
return {
// Internal `v-model` state
localShow:visible,
// For lazy render triggering
isOpen:visible};

},
computed:{
transitionProps:function transitionProps(){
return this.noSlide?
/* istanbul ignore next */
{
css:true}:
{
css:true,
enterClass:'',
enterActiveClass:'slide',
enterToClass:'show',
leaveClass:'show',
leaveActiveClass:'slide',
leaveToClass:''};

},
slotScope:function slotScope(){
var hide=this.hide,
right=this.right,
visible=this.localShow;
return {
hide:hide,
right:right,
visible:visible};

},
hasTitle:function hasTitle(){
var $scopedSlots=this.$scopedSlots,
$slots=this.$slots;
return !this.noHeader&&!this.hasNormalizedSlot(SLOT_NAME_HEADER)&&!!(this.normalizeSlot(SLOT_NAME_TITLE,this.slotScope,$scopedSlots,$slots)||this.title);
},
titleId:function titleId(){
return this.hasTitle?this.safeId('__title__'):null;
},
computedAttrs:function computedAttrs(){
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
id:this.safeId(),
tabindex:'-1',
role:'dialog',
'aria-modal':this.backdrop?'true':'false',
'aria-hidden':this.localShow?null:'true',
'aria-label':this.ariaLabel||null,
'aria-labelledby':this.ariaLabelledby||this.titleId||null});

}},

watch:(_watch$g={},_defineProperty(_watch$g,MODEL_PROP_NAME$g,function(newValue,oldValue){
if(newValue!==oldValue){
this.localShow=newValue;
}
}),_defineProperty(_watch$g,"localShow",function localShow(newValue,oldValue){
if(newValue!==oldValue){
this.emitState(newValue);
this.$emit(MODEL_EVENT_NAME$g,newValue);
}
}),_defineProperty(_watch$g,"$route",function $route(){
var newValue=arguments.length>0&&arguments[0]!==undefined?arguments[0]:{};
var oldValue=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

if(!this.noCloseOnRouteChange&&newValue.fullPath!==oldValue.fullPath){
this.hide();
}
}),_watch$g),
created:function created(){
// Define non-reactive properties
this.$_returnFocusEl=null;
},
mounted:function mounted(){
var _this=this;

// Add `$root` listeners
this.listenOnRoot(ROOT_ACTION_EVENT_NAME_TOGGLE$2,this.handleToggle);
this.listenOnRoot(ROOT_ACTION_EVENT_NAME_REQUEST_STATE$2,this.handleSync);// Send out a gratuitous state event to ensure toggle button is synced

this.$nextTick(function(){
_this.emitState(_this.localShow);
});
},

/* istanbul ignore next */
activated:function activated(){
this.emitSync();
},
beforeDestroy:function beforeDestroy(){
this.localShow=false;
this.$_returnFocusEl=null;
},
methods:{
hide:function hide(){
this.localShow=false;
},
emitState:function emitState(){
var state=arguments.length>0&&arguments[0]!==undefined?arguments[0]:this.localShow;
this.emitOnRoot(ROOT_EVENT_NAME_STATE$3,this.safeId(),state);
},
emitSync:function emitSync(){
var state=arguments.length>0&&arguments[0]!==undefined?arguments[0]:this.localShow;
this.emitOnRoot(ROOT_EVENT_NAME_SYNC_STATE$3,this.safeId(),state);
},
handleToggle:function handleToggle(id){
// Note `safeId()` can be null until after mount
if(id&&id===this.safeId()){
this.localShow=!this.localShow;
}
},
handleSync:function handleSync(id){
var _this2=this;

// Note `safeId()` can be null until after mount
if(id&&id===this.safeId()){
this.$nextTick(function(){
_this2.emitSync(_this2.localShow);
});
}
},
onKeydown:function onKeydown(event){
var keyCode=event.keyCode;

if(!this.noCloseOnEsc&&keyCode===CODE_ESC&&this.localShow){
this.hide();
}
},
onBackdropClick:function onBackdropClick(){
if(this.localShow&&!this.noCloseOnBackdrop){
this.hide();
}
},

/* istanbul ignore next */
onTopTrapFocus:function onTopTrapFocus(){
var tabables=getTabables(this.$refs.content);
this.enforceFocus(tabables.reverse()[0]);
},

/* istanbul ignore next */
onBottomTrapFocus:function onBottomTrapFocus(){
var tabables=getTabables(this.$refs.content);
this.enforceFocus(tabables[0]);
},
onBeforeEnter:function onBeforeEnter(){
// Returning focus to `document.body` may cause unwanted scrolls,
// so we exclude setting focus on body
this.$_returnFocusEl=getActiveElement(IS_BROWSER?[document.body]:[]);// Trigger lazy render

this.isOpen=true;
},
onAfterEnter:function onAfterEnter(el){
if(!contains(el,getActiveElement())){
this.enforceFocus(el);
}

this.$emit(EVENT_NAME_SHOWN);
},
onAfterLeave:function onAfterLeave(){
this.enforceFocus(this.$_returnFocusEl);
this.$_returnFocusEl=null;// Trigger lazy render

this.isOpen=false;
this.$emit(EVENT_NAME_HIDDEN);
},
enforceFocus:function enforceFocus(el){
if(!this.noEnforceFocus){
attemptFocus(el);
}
}},

render:function render(h){
var _ref;

var bgVariant=this.bgVariant,
width=this.width,
textVariant=this.textVariant,
localShow=this.localShow;
var shadow=this.shadow===''?true:this.shadow;
var $sidebar=h(this.tag,{
staticClass:CLASS_NAME$3,
class:[(_ref={
shadow:shadow===true},
_defineProperty(_ref,"shadow-".concat(shadow),shadow&&shadow!==true),_defineProperty(_ref,"".concat(CLASS_NAME$3,"-right"),this.right),_defineProperty(_ref,"bg-".concat(bgVariant),bgVariant),_defineProperty(_ref,"text-".concat(textVariant),textVariant),_ref),this.sidebarClass],
style:{
width:width},

attrs:this.computedAttrs,
directives:[{
name:'show',
value:localShow}],

ref:'content'},
[renderContent(h,this)]);
$sidebar=h('transition',{
props:this.transitionProps,
on:{
beforeEnter:this.onBeforeEnter,
afterEnter:this.onAfterEnter,
afterLeave:this.onAfterLeave}},

[$sidebar]);
var $backdrop=h(BVTransition,{
props:{
noFade:this.noSlide}},

[renderBackdrop(h,this)]);
var $tabTrapTop=h();
var $tabTrapBottom=h();

if(this.backdrop&&localShow){
$tabTrapTop=h('div',{
attrs:{
tabindex:'0'},

on:{
focus:this.onTopTrapFocus}});


$tabTrapBottom=h('div',{
attrs:{
tabindex:'0'},

on:{
focus:this.onBottomTrapFocus}});


}

return h('div',{
staticClass:'b-sidebar-outer',
style:{
zIndex:this.zIndex},

attrs:{
tabindex:'-1'},

on:{
keydown:this.onKeydown}},

[$tabTrapTop,$sidebar,$tabTrapBottom,$backdrop]);
}});


var SidebarPlugin=/*#__PURE__*/pluginFactory({
components:{
BSidebar:BSidebar},

plugins:{
VBTogglePlugin:VBTogglePlugin}});



var props$1O=makePropsConfigurable({
animation:makeProp(PROP_TYPE_STRING,'wave'),
height:makeProp(PROP_TYPE_STRING),
size:makeProp(PROP_TYPE_STRING),
type:makeProp(PROP_TYPE_STRING,'text'),
variant:makeProp(PROP_TYPE_STRING),
width:makeProp(PROP_TYPE_STRING)},
NAME_SKELETON);// --- Main component ---
// @vue/component

var BSkeleton=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_SKELETON,
functional:true,
props:props$1O,
render:function render(h,_ref){
var _class;

var data=_ref.data,
props=_ref.props;
var size=props.size,
animation=props.animation,
variant=props.variant;
return h('div',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'b-skeleton',
style:{
width:size||props.width,
height:size||props.height},

class:(_class={},_defineProperty(_class,"b-skeleton-".concat(props.type),true),_defineProperty(_class,"b-skeleton-animate-".concat(animation),animation),_defineProperty(_class,"bg-".concat(variant),variant),_class)}));

}});


var props$1P=makePropsConfigurable(omit(props$4,['content','stacked']),NAME_ICONSTACK);// --- Main component ---
// @vue/component

var BIconstack=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_ICONSTACK,
functional:true,
props:props$1P,
render:function render(h,_ref){
var data=_ref.data,
props=_ref.props,
children=_ref.children;
return h(BVIconBase,Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
staticClass:'b-iconstack',
props:props}),
children);
}});


// --- BEGIN AUTO-GENERATED FILE ---

var IconsPlugin=/*#__PURE__*/pluginFactoryNoConfig({
components:{
// Icon helper component
BIcon:BIcon,
// Icon stacking component
BIconstack:BIconstack,
// BootstrapVue custom icon components
BIconBlank:BIconBlank,
// Bootstrap icon components
BIconAlarm:BIconAlarm,
BIconAlarmFill:BIconAlarmFill,
BIconAlignBottom:BIconAlignBottom,
BIconAlignCenter:BIconAlignCenter,
BIconAlignEnd:BIconAlignEnd,
BIconAlignMiddle:BIconAlignMiddle,
BIconAlignStart:BIconAlignStart,
BIconAlignTop:BIconAlignTop,
BIconAlt:BIconAlt,
BIconApp:BIconApp,
BIconAppIndicator:BIconAppIndicator,
BIconArchive:BIconArchive,
BIconArchiveFill:BIconArchiveFill,
BIconArrow90degDown:BIconArrow90degDown,
BIconArrow90degLeft:BIconArrow90degLeft,
BIconArrow90degRight:BIconArrow90degRight,
BIconArrow90degUp:BIconArrow90degUp,
BIconArrowBarDown:BIconArrowBarDown,
BIconArrowBarLeft:BIconArrowBarLeft,
BIconArrowBarRight:BIconArrowBarRight,
BIconArrowBarUp:BIconArrowBarUp,
BIconArrowClockwise:BIconArrowClockwise,
BIconArrowCounterclockwise:BIconArrowCounterclockwise,
BIconArrowDown:BIconArrowDown,
BIconArrowDownCircle:BIconArrowDownCircle,
BIconArrowDownCircleFill:BIconArrowDownCircleFill,
BIconArrowDownLeft:BIconArrowDownLeft,
BIconArrowDownLeftCircle:BIconArrowDownLeftCircle,
BIconArrowDownLeftCircleFill:BIconArrowDownLeftCircleFill,
BIconArrowDownLeftSquare:BIconArrowDownLeftSquare,
BIconArrowDownLeftSquareFill:BIconArrowDownLeftSquareFill,
BIconArrowDownRight:BIconArrowDownRight,
BIconArrowDownRightCircle:BIconArrowDownRightCircle,
BIconArrowDownRightCircleFill:BIconArrowDownRightCircleFill,
BIconArrowDownRightSquare:BIconArrowDownRightSquare,
BIconArrowDownRightSquareFill:BIconArrowDownRightSquareFill,
BIconArrowDownShort:BIconArrowDownShort,
BIconArrowDownSquare:BIconArrowDownSquare,
BIconArrowDownSquareFill:BIconArrowDownSquareFill,
BIconArrowDownUp:BIconArrowDownUp,
BIconArrowLeft:BIconArrowLeft,
BIconArrowLeftCircle:BIconArrowLeftCircle,
BIconArrowLeftCircleFill:BIconArrowLeftCircleFill,
BIconArrowLeftRight:BIconArrowLeftRight,
BIconArrowLeftShort:BIconArrowLeftShort,
BIconArrowLeftSquare:BIconArrowLeftSquare,
BIconArrowLeftSquareFill:BIconArrowLeftSquareFill,
BIconArrowRepeat:BIconArrowRepeat,
BIconArrowReturnLeft:BIconArrowReturnLeft,
BIconArrowReturnRight:BIconArrowReturnRight,
BIconArrowRight:BIconArrowRight,
BIconArrowRightCircle:BIconArrowRightCircle,
BIconArrowRightCircleFill:BIconArrowRightCircleFill,
BIconArrowRightShort:BIconArrowRightShort,
BIconArrowRightSquare:BIconArrowRightSquare,
BIconArrowRightSquareFill:BIconArrowRightSquareFill,
BIconArrowUp:BIconArrowUp,
BIconArrowUpCircle:BIconArrowUpCircle,
BIconArrowUpCircleFill:BIconArrowUpCircleFill,
BIconArrowUpLeft:BIconArrowUpLeft,
BIconArrowUpLeftCircle:BIconArrowUpLeftCircle,
BIconArrowUpLeftCircleFill:BIconArrowUpLeftCircleFill,
BIconArrowUpLeftSquare:BIconArrowUpLeftSquare,
BIconArrowUpLeftSquareFill:BIconArrowUpLeftSquareFill,
BIconArrowUpRight:BIconArrowUpRight,
BIconArrowUpRightCircle:BIconArrowUpRightCircle,
BIconArrowUpRightCircleFill:BIconArrowUpRightCircleFill,
BIconArrowUpRightSquare:BIconArrowUpRightSquare,
BIconArrowUpRightSquareFill:BIconArrowUpRightSquareFill,
BIconArrowUpShort:BIconArrowUpShort,
BIconArrowUpSquare:BIconArrowUpSquare,
BIconArrowUpSquareFill:BIconArrowUpSquareFill,
BIconArrowsAngleContract:BIconArrowsAngleContract,
BIconArrowsAngleExpand:BIconArrowsAngleExpand,
BIconArrowsCollapse:BIconArrowsCollapse,
BIconArrowsExpand:BIconArrowsExpand,
BIconArrowsFullscreen:BIconArrowsFullscreen,
BIconArrowsMove:BIconArrowsMove,
BIconAspectRatio:BIconAspectRatio,
BIconAspectRatioFill:BIconAspectRatioFill,
BIconAsterisk:BIconAsterisk,
BIconAt:BIconAt,
BIconAward:BIconAward,
BIconAwardFill:BIconAwardFill,
BIconBack:BIconBack,
BIconBackspace:BIconBackspace,
BIconBackspaceFill:BIconBackspaceFill,
BIconBackspaceReverse:BIconBackspaceReverse,
BIconBackspaceReverseFill:BIconBackspaceReverseFill,
BIconBadge4k:BIconBadge4k,
BIconBadge4kFill:BIconBadge4kFill,
BIconBadge8k:BIconBadge8k,
BIconBadge8kFill:BIconBadge8kFill,
BIconBadgeAd:BIconBadgeAd,
BIconBadgeAdFill:BIconBadgeAdFill,
BIconBadgeCc:BIconBadgeCc,
BIconBadgeCcFill:BIconBadgeCcFill,
BIconBadgeHd:BIconBadgeHd,
BIconBadgeHdFill:BIconBadgeHdFill,
BIconBadgeTm:BIconBadgeTm,
BIconBadgeTmFill:BIconBadgeTmFill,
BIconBadgeVo:BIconBadgeVo,
BIconBadgeVoFill:BIconBadgeVoFill,
BIconBag:BIconBag,
BIconBagCheck:BIconBagCheck,
BIconBagCheckFill:BIconBagCheckFill,
BIconBagDash:BIconBagDash,
BIconBagDashFill:BIconBagDashFill,
BIconBagFill:BIconBagFill,
BIconBagPlus:BIconBagPlus,
BIconBagPlusFill:BIconBagPlusFill,
BIconBagX:BIconBagX,
BIconBagXFill:BIconBagXFill,
BIconBarChart:BIconBarChart,
BIconBarChartFill:BIconBarChartFill,
BIconBarChartLine:BIconBarChartLine,
BIconBarChartLineFill:BIconBarChartLineFill,
BIconBarChartSteps:BIconBarChartSteps,
BIconBasket:BIconBasket,
BIconBasket2:BIconBasket2,
BIconBasket2Fill:BIconBasket2Fill,
BIconBasket3:BIconBasket3,
BIconBasket3Fill:BIconBasket3Fill,
BIconBasketFill:BIconBasketFill,
BIconBattery:BIconBattery,
BIconBatteryCharging:BIconBatteryCharging,
BIconBatteryFull:BIconBatteryFull,
BIconBatteryHalf:BIconBatteryHalf,
BIconBell:BIconBell,
BIconBellFill:BIconBellFill,
BIconBezier:BIconBezier,
BIconBezier2:BIconBezier2,
BIconBicycle:BIconBicycle,
BIconBinoculars:BIconBinoculars,
BIconBinocularsFill:BIconBinocularsFill,
BIconBlockquoteLeft:BIconBlockquoteLeft,
BIconBlockquoteRight:BIconBlockquoteRight,
BIconBook:BIconBook,
BIconBookFill:BIconBookFill,
BIconBookHalf:BIconBookHalf,
BIconBookmark:BIconBookmark,
BIconBookmarkCheck:BIconBookmarkCheck,
BIconBookmarkCheckFill:BIconBookmarkCheckFill,
BIconBookmarkDash:BIconBookmarkDash,
BIconBookmarkDashFill:BIconBookmarkDashFill,
BIconBookmarkFill:BIconBookmarkFill,
BIconBookmarkHeart:BIconBookmarkHeart,
BIconBookmarkHeartFill:BIconBookmarkHeartFill,
BIconBookmarkPlus:BIconBookmarkPlus,
BIconBookmarkPlusFill:BIconBookmarkPlusFill,
BIconBookmarkStar:BIconBookmarkStar,
BIconBookmarkStarFill:BIconBookmarkStarFill,
BIconBookmarkX:BIconBookmarkX,
BIconBookmarkXFill:BIconBookmarkXFill,
BIconBookmarks:BIconBookmarks,
BIconBookmarksFill:BIconBookmarksFill,
BIconBookshelf:BIconBookshelf,
BIconBootstrap:BIconBootstrap,
BIconBootstrapFill:BIconBootstrapFill,
BIconBootstrapReboot:BIconBootstrapReboot,
BIconBorderStyle:BIconBorderStyle,
BIconBorderWidth:BIconBorderWidth,
BIconBoundingBox:BIconBoundingBox,
BIconBoundingBoxCircles:BIconBoundingBoxCircles,
BIconBox:BIconBox,
BIconBoxArrowDown:BIconBoxArrowDown,
BIconBoxArrowDownLeft:BIconBoxArrowDownLeft,
BIconBoxArrowDownRight:BIconBoxArrowDownRight,
BIconBoxArrowInDown:BIconBoxArrowInDown,
BIconBoxArrowInDownLeft:BIconBoxArrowInDownLeft,
BIconBoxArrowInDownRight:BIconBoxArrowInDownRight,
BIconBoxArrowInLeft:BIconBoxArrowInLeft,
BIconBoxArrowInRight:BIconBoxArrowInRight,
BIconBoxArrowInUp:BIconBoxArrowInUp,
BIconBoxArrowInUpLeft:BIconBoxArrowInUpLeft,
BIconBoxArrowInUpRight:BIconBoxArrowInUpRight,
BIconBoxArrowLeft:BIconBoxArrowLeft,
BIconBoxArrowRight:BIconBoxArrowRight,
BIconBoxArrowUp:BIconBoxArrowUp,
BIconBoxArrowUpLeft:BIconBoxArrowUpLeft,
BIconBoxArrowUpRight:BIconBoxArrowUpRight,
BIconBoxSeam:BIconBoxSeam,
BIconBraces:BIconBraces,
BIconBricks:BIconBricks,
BIconBriefcase:BIconBriefcase,
BIconBriefcaseFill:BIconBriefcaseFill,
BIconBrightnessAltHigh:BIconBrightnessAltHigh,
BIconBrightnessAltHighFill:BIconBrightnessAltHighFill,
BIconBrightnessAltLow:BIconBrightnessAltLow,
BIconBrightnessAltLowFill:BIconBrightnessAltLowFill,
BIconBrightnessHigh:BIconBrightnessHigh,
BIconBrightnessHighFill:BIconBrightnessHighFill,
BIconBrightnessLow:BIconBrightnessLow,
BIconBrightnessLowFill:BIconBrightnessLowFill,
BIconBroadcast:BIconBroadcast,
BIconBroadcastPin:BIconBroadcastPin,
BIconBrush:BIconBrush,
BIconBrushFill:BIconBrushFill,
BIconBucket:BIconBucket,
BIconBucketFill:BIconBucketFill,
BIconBug:BIconBug,
BIconBugFill:BIconBugFill,
BIconBuilding:BIconBuilding,
BIconBullseye:BIconBullseye,
BIconCalculator:BIconCalculator,
BIconCalculatorFill:BIconCalculatorFill,
BIconCalendar:BIconCalendar,
BIconCalendar2:BIconCalendar2,
BIconCalendar2Check:BIconCalendar2Check,
BIconCalendar2CheckFill:BIconCalendar2CheckFill,
BIconCalendar2Date:BIconCalendar2Date,
BIconCalendar2DateFill:BIconCalendar2DateFill,
BIconCalendar2Day:BIconCalendar2Day,
BIconCalendar2DayFill:BIconCalendar2DayFill,
BIconCalendar2Event:BIconCalendar2Event,
BIconCalendar2EventFill:BIconCalendar2EventFill,
BIconCalendar2Fill:BIconCalendar2Fill,
BIconCalendar2Minus:BIconCalendar2Minus,
BIconCalendar2MinusFill:BIconCalendar2MinusFill,
BIconCalendar2Month:BIconCalendar2Month,
BIconCalendar2MonthFill:BIconCalendar2MonthFill,
BIconCalendar2Plus:BIconCalendar2Plus,
BIconCalendar2PlusFill:BIconCalendar2PlusFill,
BIconCalendar2Range:BIconCalendar2Range,
BIconCalendar2RangeFill:BIconCalendar2RangeFill,
BIconCalendar2Week:BIconCalendar2Week,
BIconCalendar2WeekFill:BIconCalendar2WeekFill,
BIconCalendar2X:BIconCalendar2X,
BIconCalendar2XFill:BIconCalendar2XFill,
BIconCalendar3:BIconCalendar3,
BIconCalendar3Event:BIconCalendar3Event,
BIconCalendar3EventFill:BIconCalendar3EventFill,
BIconCalendar3Fill:BIconCalendar3Fill,
BIconCalendar3Range:BIconCalendar3Range,
BIconCalendar3RangeFill:BIconCalendar3RangeFill,
BIconCalendar3Week:BIconCalendar3Week,
BIconCalendar3WeekFill:BIconCalendar3WeekFill,
BIconCalendar4:BIconCalendar4,
BIconCalendar4Event:BIconCalendar4Event,
BIconCalendar4Range:BIconCalendar4Range,
BIconCalendar4Week:BIconCalendar4Week,
BIconCalendarCheck:BIconCalendarCheck,
BIconCalendarCheckFill:BIconCalendarCheckFill,
BIconCalendarDate:BIconCalendarDate,
BIconCalendarDateFill:BIconCalendarDateFill,
BIconCalendarDay:BIconCalendarDay,
BIconCalendarDayFill:BIconCalendarDayFill,
BIconCalendarEvent:BIconCalendarEvent,
BIconCalendarEventFill:BIconCalendarEventFill,
BIconCalendarFill:BIconCalendarFill,
BIconCalendarMinus:BIconCalendarMinus,
BIconCalendarMinusFill:BIconCalendarMinusFill,
BIconCalendarMonth:BIconCalendarMonth,
BIconCalendarMonthFill:BIconCalendarMonthFill,
BIconCalendarPlus:BIconCalendarPlus,
BIconCalendarPlusFill:BIconCalendarPlusFill,
BIconCalendarRange:BIconCalendarRange,
BIconCalendarRangeFill:BIconCalendarRangeFill,
BIconCalendarWeek:BIconCalendarWeek,
BIconCalendarWeekFill:BIconCalendarWeekFill,
BIconCalendarX:BIconCalendarX,
BIconCalendarXFill:BIconCalendarXFill,
BIconCamera:BIconCamera,
BIconCamera2:BIconCamera2,
BIconCameraFill:BIconCameraFill,
BIconCameraReels:BIconCameraReels,
BIconCameraReelsFill:BIconCameraReelsFill,
BIconCameraVideo:BIconCameraVideo,
BIconCameraVideoFill:BIconCameraVideoFill,
BIconCameraVideoOff:BIconCameraVideoOff,
BIconCameraVideoOffFill:BIconCameraVideoOffFill,
BIconCapslock:BIconCapslock,
BIconCapslockFill:BIconCapslockFill,
BIconCardChecklist:BIconCardChecklist,
BIconCardHeading:BIconCardHeading,
BIconCardImage:BIconCardImage,
BIconCardList:BIconCardList,
BIconCardText:BIconCardText,
BIconCaretDown:BIconCaretDown,
BIconCaretDownFill:BIconCaretDownFill,
BIconCaretDownSquare:BIconCaretDownSquare,
BIconCaretDownSquareFill:BIconCaretDownSquareFill,
BIconCaretLeft:BIconCaretLeft,
BIconCaretLeftFill:BIconCaretLeftFill,
BIconCaretLeftSquare:BIconCaretLeftSquare,
BIconCaretLeftSquareFill:BIconCaretLeftSquareFill,
BIconCaretRight:BIconCaretRight,
BIconCaretRightFill:BIconCaretRightFill,
BIconCaretRightSquare:BIconCaretRightSquare,
BIconCaretRightSquareFill:BIconCaretRightSquareFill,
BIconCaretUp:BIconCaretUp,
BIconCaretUpFill:BIconCaretUpFill,
BIconCaretUpSquare:BIconCaretUpSquare,
BIconCaretUpSquareFill:BIconCaretUpSquareFill,
BIconCart:BIconCart,
BIconCart2:BIconCart2,
BIconCart3:BIconCart3,
BIconCart4:BIconCart4,
BIconCartCheck:BIconCartCheck,
BIconCartCheckFill:BIconCartCheckFill,
BIconCartDash:BIconCartDash,
BIconCartDashFill:BIconCartDashFill,
BIconCartFill:BIconCartFill,
BIconCartPlus:BIconCartPlus,
BIconCartPlusFill:BIconCartPlusFill,
BIconCartX:BIconCartX,
BIconCartXFill:BIconCartXFill,
BIconCash:BIconCash,
BIconCashStack:BIconCashStack,
BIconCast:BIconCast,
BIconChat:BIconChat,
BIconChatDots:BIconChatDots,
BIconChatDotsFill:BIconChatDotsFill,
BIconChatFill:BIconChatFill,
BIconChatLeft:BIconChatLeft,
BIconChatLeftDots:BIconChatLeftDots,
BIconChatLeftDotsFill:BIconChatLeftDotsFill,
BIconChatLeftFill:BIconChatLeftFill,
BIconChatLeftQuote:BIconChatLeftQuote,
BIconChatLeftQuoteFill:BIconChatLeftQuoteFill,
BIconChatLeftText:BIconChatLeftText,
BIconChatLeftTextFill:BIconChatLeftTextFill,
BIconChatQuote:BIconChatQuote,
BIconChatQuoteFill:BIconChatQuoteFill,
BIconChatRight:BIconChatRight,
BIconChatRightDots:BIconChatRightDots,
BIconChatRightDotsFill:BIconChatRightDotsFill,
BIconChatRightFill:BIconChatRightFill,
BIconChatRightQuote:BIconChatRightQuote,
BIconChatRightQuoteFill:BIconChatRightQuoteFill,
BIconChatRightText:BIconChatRightText,
BIconChatRightTextFill:BIconChatRightTextFill,
BIconChatSquare:BIconChatSquare,
BIconChatSquareDots:BIconChatSquareDots,
BIconChatSquareDotsFill:BIconChatSquareDotsFill,
BIconChatSquareFill:BIconChatSquareFill,
BIconChatSquareQuote:BIconChatSquareQuote,
BIconChatSquareQuoteFill:BIconChatSquareQuoteFill,
BIconChatSquareText:BIconChatSquareText,
BIconChatSquareTextFill:BIconChatSquareTextFill,
BIconChatText:BIconChatText,
BIconChatTextFill:BIconChatTextFill,
BIconCheck:BIconCheck,
BIconCheck2:BIconCheck2,
BIconCheck2All:BIconCheck2All,
BIconCheck2Circle:BIconCheck2Circle,
BIconCheck2Square:BIconCheck2Square,
BIconCheckAll:BIconCheckAll,
BIconCheckCircle:BIconCheckCircle,
BIconCheckCircleFill:BIconCheckCircleFill,
BIconCheckSquare:BIconCheckSquare,
BIconCheckSquareFill:BIconCheckSquareFill,
BIconChevronBarContract:BIconChevronBarContract,
BIconChevronBarDown:BIconChevronBarDown,
BIconChevronBarExpand:BIconChevronBarExpand,
BIconChevronBarLeft:BIconChevronBarLeft,
BIconChevronBarRight:BIconChevronBarRight,
BIconChevronBarUp:BIconChevronBarUp,
BIconChevronCompactDown:BIconChevronCompactDown,
BIconChevronCompactLeft:BIconChevronCompactLeft,
BIconChevronCompactRight:BIconChevronCompactRight,
BIconChevronCompactUp:BIconChevronCompactUp,
BIconChevronContract:BIconChevronContract,
BIconChevronDoubleDown:BIconChevronDoubleDown,
BIconChevronDoubleLeft:BIconChevronDoubleLeft,
BIconChevronDoubleRight:BIconChevronDoubleRight,
BIconChevronDoubleUp:BIconChevronDoubleUp,
BIconChevronDown:BIconChevronDown,
BIconChevronExpand:BIconChevronExpand,
BIconChevronLeft:BIconChevronLeft,
BIconChevronRight:BIconChevronRight,
BIconChevronUp:BIconChevronUp,
BIconCircle:BIconCircle,
BIconCircleFill:BIconCircleFill,
BIconCircleHalf:BIconCircleHalf,
BIconCircleSquare:BIconCircleSquare,
BIconClipboard:BIconClipboard,
BIconClipboardCheck:BIconClipboardCheck,
BIconClipboardData:BIconClipboardData,
BIconClipboardMinus:BIconClipboardMinus,
BIconClipboardPlus:BIconClipboardPlus,
BIconClipboardX:BIconClipboardX,
BIconClock:BIconClock,
BIconClockFill:BIconClockFill,
BIconClockHistory:BIconClockHistory,
BIconCloud:BIconCloud,
BIconCloudArrowDown:BIconCloudArrowDown,
BIconCloudArrowDownFill:BIconCloudArrowDownFill,
BIconCloudArrowUp:BIconCloudArrowUp,
BIconCloudArrowUpFill:BIconCloudArrowUpFill,
BIconCloudCheck:BIconCloudCheck,
BIconCloudCheckFill:BIconCloudCheckFill,
BIconCloudDownload:BIconCloudDownload,
BIconCloudDownloadFill:BIconCloudDownloadFill,
BIconCloudFill:BIconCloudFill,
BIconCloudMinus:BIconCloudMinus,
BIconCloudMinusFill:BIconCloudMinusFill,
BIconCloudPlus:BIconCloudPlus,
BIconCloudPlusFill:BIconCloudPlusFill,
BIconCloudSlash:BIconCloudSlash,
BIconCloudSlashFill:BIconCloudSlashFill,
BIconCloudUpload:BIconCloudUpload,
BIconCloudUploadFill:BIconCloudUploadFill,
BIconCode:BIconCode,
BIconCodeSlash:BIconCodeSlash,
BIconCodeSquare:BIconCodeSquare,
BIconCollection:BIconCollection,
BIconCollectionFill:BIconCollectionFill,
BIconCollectionPlay:BIconCollectionPlay,
BIconCollectionPlayFill:BIconCollectionPlayFill,
BIconColumns:BIconColumns,
BIconColumnsGap:BIconColumnsGap,
BIconCommand:BIconCommand,
BIconCompass:BIconCompass,
BIconCompassFill:BIconCompassFill,
BIconCone:BIconCone,
BIconConeStriped:BIconConeStriped,
BIconController:BIconController,
BIconCpu:BIconCpu,
BIconCpuFill:BIconCpuFill,
BIconCreditCard:BIconCreditCard,
BIconCreditCard2Back:BIconCreditCard2Back,
BIconCreditCard2BackFill:BIconCreditCard2BackFill,
BIconCreditCard2Front:BIconCreditCard2Front,
BIconCreditCard2FrontFill:BIconCreditCard2FrontFill,
BIconCreditCardFill:BIconCreditCardFill,
BIconCrop:BIconCrop,
BIconCup:BIconCup,
BIconCupFill:BIconCupFill,
BIconCupStraw:BIconCupStraw,
BIconCursor:BIconCursor,
BIconCursorFill:BIconCursorFill,
BIconCursorText:BIconCursorText,
BIconDash:BIconDash,
BIconDashCircle:BIconDashCircle,
BIconDashCircleFill:BIconDashCircleFill,
BIconDashSquare:BIconDashSquare,
BIconDashSquareFill:BIconDashSquareFill,
BIconDiagram2:BIconDiagram2,
BIconDiagram2Fill:BIconDiagram2Fill,
BIconDiagram3:BIconDiagram3,
BIconDiagram3Fill:BIconDiagram3Fill,
BIconDiamond:BIconDiamond,
BIconDiamondFill:BIconDiamondFill,
BIconDiamondHalf:BIconDiamondHalf,
BIconDice1:BIconDice1,
BIconDice1Fill:BIconDice1Fill,
BIconDice2:BIconDice2,
BIconDice2Fill:BIconDice2Fill,
BIconDice3:BIconDice3,
BIconDice3Fill:BIconDice3Fill,
BIconDice4:BIconDice4,
BIconDice4Fill:BIconDice4Fill,
BIconDice5:BIconDice5,
BIconDice5Fill:BIconDice5Fill,
BIconDice6:BIconDice6,
BIconDice6Fill:BIconDice6Fill,
BIconDisc:BIconDisc,
BIconDiscFill:BIconDiscFill,
BIconDiscord:BIconDiscord,
BIconDisplay:BIconDisplay,
BIconDisplayFill:BIconDisplayFill,
BIconDistributeHorizontal:BIconDistributeHorizontal,
BIconDistributeVertical:BIconDistributeVertical,
BIconDoorClosed:BIconDoorClosed,
BIconDoorClosedFill:BIconDoorClosedFill,
BIconDoorOpen:BIconDoorOpen,
BIconDoorOpenFill:BIconDoorOpenFill,
BIconDot:BIconDot,
BIconDownload:BIconDownload,
BIconDroplet:BIconDroplet,
BIconDropletFill:BIconDropletFill,
BIconDropletHalf:BIconDropletHalf,
BIconEarbuds:BIconEarbuds,
BIconEasel:BIconEasel,
BIconEaselFill:BIconEaselFill,
BIconEgg:BIconEgg,
BIconEggFill:BIconEggFill,
BIconEggFried:BIconEggFried,
BIconEject:BIconEject,
BIconEjectFill:BIconEjectFill,
BIconEmojiAngry:BIconEmojiAngry,
BIconEmojiAngryFill:BIconEmojiAngryFill,
BIconEmojiDizzy:BIconEmojiDizzy,
BIconEmojiDizzyFill:BIconEmojiDizzyFill,
BIconEmojiExpressionless:BIconEmojiExpressionless,
BIconEmojiExpressionlessFill:BIconEmojiExpressionlessFill,
BIconEmojiFrown:BIconEmojiFrown,
BIconEmojiFrownFill:BIconEmojiFrownFill,
BIconEmojiHeartEyes:BIconEmojiHeartEyes,
BIconEmojiHeartEyesFill:BIconEmojiHeartEyesFill,
BIconEmojiLaughing:BIconEmojiLaughing,
BIconEmojiLaughingFill:BIconEmojiLaughingFill,
BIconEmojiNeutral:BIconEmojiNeutral,
BIconEmojiNeutralFill:BIconEmojiNeutralFill,
BIconEmojiSmile:BIconEmojiSmile,
BIconEmojiSmileFill:BIconEmojiSmileFill,
BIconEmojiSmileUpsideDown:BIconEmojiSmileUpsideDown,
BIconEmojiSmileUpsideDownFill:BIconEmojiSmileUpsideDownFill,
BIconEmojiSunglasses:BIconEmojiSunglasses,
BIconEmojiSunglassesFill:BIconEmojiSunglassesFill,
BIconEmojiWink:BIconEmojiWink,
BIconEmojiWinkFill:BIconEmojiWinkFill,
BIconEnvelope:BIconEnvelope,
BIconEnvelopeFill:BIconEnvelopeFill,
BIconEnvelopeOpen:BIconEnvelopeOpen,
BIconEnvelopeOpenFill:BIconEnvelopeOpenFill,
BIconExclamation:BIconExclamation,
BIconExclamationCircle:BIconExclamationCircle,
BIconExclamationCircleFill:BIconExclamationCircleFill,
BIconExclamationDiamond:BIconExclamationDiamond,
BIconExclamationDiamondFill:BIconExclamationDiamondFill,
BIconExclamationOctagon:BIconExclamationOctagon,
BIconExclamationOctagonFill:BIconExclamationOctagonFill,
BIconExclamationSquare:BIconExclamationSquare,
BIconExclamationSquareFill:BIconExclamationSquareFill,
BIconExclamationTriangle:BIconExclamationTriangle,
BIconExclamationTriangleFill:BIconExclamationTriangleFill,
BIconExclude:BIconExclude,
BIconEye:BIconEye,
BIconEyeFill:BIconEyeFill,
BIconEyeSlash:BIconEyeSlash,
BIconEyeSlashFill:BIconEyeSlashFill,
BIconEyeglasses:BIconEyeglasses,
BIconFacebook:BIconFacebook,
BIconFile:BIconFile,
BIconFileArrowDown:BIconFileArrowDown,
BIconFileArrowDownFill:BIconFileArrowDownFill,
BIconFileArrowUp:BIconFileArrowUp,
BIconFileArrowUpFill:BIconFileArrowUpFill,
BIconFileBarGraph:BIconFileBarGraph,
BIconFileBarGraphFill:BIconFileBarGraphFill,
BIconFileBinary:BIconFileBinary,
BIconFileBinaryFill:BIconFileBinaryFill,
BIconFileBreak:BIconFileBreak,
BIconFileBreakFill:BIconFileBreakFill,
BIconFileCheck:BIconFileCheck,
BIconFileCheckFill:BIconFileCheckFill,
BIconFileCode:BIconFileCode,
BIconFileCodeFill:BIconFileCodeFill,
BIconFileDiff:BIconFileDiff,
BIconFileDiffFill:BIconFileDiffFill,
BIconFileEarmark:BIconFileEarmark,
BIconFileEarmarkArrowDown:BIconFileEarmarkArrowDown,
BIconFileEarmarkArrowDownFill:BIconFileEarmarkArrowDownFill,
BIconFileEarmarkArrowUp:BIconFileEarmarkArrowUp,
BIconFileEarmarkArrowUpFill:BIconFileEarmarkArrowUpFill,
BIconFileEarmarkBarGraph:BIconFileEarmarkBarGraph,
BIconFileEarmarkBarGraphFill:BIconFileEarmarkBarGraphFill,
BIconFileEarmarkBinary:BIconFileEarmarkBinary,
BIconFileEarmarkBinaryFill:BIconFileEarmarkBinaryFill,
BIconFileEarmarkBreak:BIconFileEarmarkBreak,
BIconFileEarmarkBreakFill:BIconFileEarmarkBreakFill,
BIconFileEarmarkCheck:BIconFileEarmarkCheck,
BIconFileEarmarkCheckFill:BIconFileEarmarkCheckFill,
BIconFileEarmarkCode:BIconFileEarmarkCode,
BIconFileEarmarkCodeFill:BIconFileEarmarkCodeFill,
BIconFileEarmarkDiff:BIconFileEarmarkDiff,
BIconFileEarmarkDiffFill:BIconFileEarmarkDiffFill,
BIconFileEarmarkEasel:BIconFileEarmarkEasel,
BIconFileEarmarkEaselFill:BIconFileEarmarkEaselFill,
BIconFileEarmarkExcel:BIconFileEarmarkExcel,
BIconFileEarmarkExcelFill:BIconFileEarmarkExcelFill,
BIconFileEarmarkFill:BIconFileEarmarkFill,
BIconFileEarmarkFont:BIconFileEarmarkFont,
BIconFileEarmarkFontFill:BIconFileEarmarkFontFill,
BIconFileEarmarkImage:BIconFileEarmarkImage,
BIconFileEarmarkImageFill:BIconFileEarmarkImageFill,
BIconFileEarmarkLock:BIconFileEarmarkLock,
BIconFileEarmarkLock2:BIconFileEarmarkLock2,
BIconFileEarmarkLock2Fill:BIconFileEarmarkLock2Fill,
BIconFileEarmarkLockFill:BIconFileEarmarkLockFill,
BIconFileEarmarkMedical:BIconFileEarmarkMedical,
BIconFileEarmarkMedicalFill:BIconFileEarmarkMedicalFill,
BIconFileEarmarkMinus:BIconFileEarmarkMinus,
BIconFileEarmarkMinusFill:BIconFileEarmarkMinusFill,
BIconFileEarmarkMusic:BIconFileEarmarkMusic,
BIconFileEarmarkMusicFill:BIconFileEarmarkMusicFill,
BIconFileEarmarkPerson:BIconFileEarmarkPerson,
BIconFileEarmarkPersonFill:BIconFileEarmarkPersonFill,
BIconFileEarmarkPlay:BIconFileEarmarkPlay,
BIconFileEarmarkPlayFill:BIconFileEarmarkPlayFill,
BIconFileEarmarkPlus:BIconFileEarmarkPlus,
BIconFileEarmarkPlusFill:BIconFileEarmarkPlusFill,
BIconFileEarmarkPost:BIconFileEarmarkPost,
BIconFileEarmarkPostFill:BIconFileEarmarkPostFill,
BIconFileEarmarkPpt:BIconFileEarmarkPpt,
BIconFileEarmarkPptFill:BIconFileEarmarkPptFill,
BIconFileEarmarkRichtext:BIconFileEarmarkRichtext,
BIconFileEarmarkRichtextFill:BIconFileEarmarkRichtextFill,
BIconFileEarmarkRuled:BIconFileEarmarkRuled,
BIconFileEarmarkRuledFill:BIconFileEarmarkRuledFill,
BIconFileEarmarkSlides:BIconFileEarmarkSlides,
BIconFileEarmarkSlidesFill:BIconFileEarmarkSlidesFill,
BIconFileEarmarkSpreadsheet:BIconFileEarmarkSpreadsheet,
BIconFileEarmarkSpreadsheetFill:BIconFileEarmarkSpreadsheetFill,
BIconFileEarmarkText:BIconFileEarmarkText,
BIconFileEarmarkTextFill:BIconFileEarmarkTextFill,
BIconFileEarmarkWord:BIconFileEarmarkWord,
BIconFileEarmarkWordFill:BIconFileEarmarkWordFill,
BIconFileEarmarkX:BIconFileEarmarkX,
BIconFileEarmarkXFill:BIconFileEarmarkXFill,
BIconFileEarmarkZip:BIconFileEarmarkZip,
BIconFileEarmarkZipFill:BIconFileEarmarkZipFill,
BIconFileEasel:BIconFileEasel,
BIconFileEaselFill:BIconFileEaselFill,
BIconFileExcel:BIconFileExcel,
BIconFileExcelFill:BIconFileExcelFill,
BIconFileFill:BIconFileFill,
BIconFileFont:BIconFileFont,
BIconFileFontFill:BIconFileFontFill,
BIconFileImage:BIconFileImage,
BIconFileImageFill:BIconFileImageFill,
BIconFileLock:BIconFileLock,
BIconFileLock2:BIconFileLock2,
BIconFileLock2Fill:BIconFileLock2Fill,
BIconFileLockFill:BIconFileLockFill,
BIconFileMedical:BIconFileMedical,
BIconFileMedicalFill:BIconFileMedicalFill,
BIconFileMinus:BIconFileMinus,
BIconFileMinusFill:BIconFileMinusFill,
BIconFileMusic:BIconFileMusic,
BIconFileMusicFill:BIconFileMusicFill,
BIconFilePerson:BIconFilePerson,
BIconFilePersonFill:BIconFilePersonFill,
BIconFilePlay:BIconFilePlay,
BIconFilePlayFill:BIconFilePlayFill,
BIconFilePlus:BIconFilePlus,
BIconFilePlusFill:BIconFilePlusFill,
BIconFilePost:BIconFilePost,
BIconFilePostFill:BIconFilePostFill,
BIconFilePpt:BIconFilePpt,
BIconFilePptFill:BIconFilePptFill,
BIconFileRichtext:BIconFileRichtext,
BIconFileRichtextFill:BIconFileRichtextFill,
BIconFileRuled:BIconFileRuled,
BIconFileRuledFill:BIconFileRuledFill,
BIconFileSlides:BIconFileSlides,
BIconFileSlidesFill:BIconFileSlidesFill,
BIconFileSpreadsheet:BIconFileSpreadsheet,
BIconFileSpreadsheetFill:BIconFileSpreadsheetFill,
BIconFileText:BIconFileText,
BIconFileTextFill:BIconFileTextFill,
BIconFileWord:BIconFileWord,
BIconFileWordFill:BIconFileWordFill,
BIconFileX:BIconFileX,
BIconFileXFill:BIconFileXFill,
BIconFileZip:BIconFileZip,
BIconFileZipFill:BIconFileZipFill,
BIconFiles:BIconFiles,
BIconFilesAlt:BIconFilesAlt,
BIconFilm:BIconFilm,
BIconFilter:BIconFilter,
BIconFilterCircle:BIconFilterCircle,
BIconFilterCircleFill:BIconFilterCircleFill,
BIconFilterLeft:BIconFilterLeft,
BIconFilterRight:BIconFilterRight,
BIconFilterSquare:BIconFilterSquare,
BIconFilterSquareFill:BIconFilterSquareFill,
BIconFlag:BIconFlag,
BIconFlagFill:BIconFlagFill,
BIconFlower1:BIconFlower1,
BIconFlower2:BIconFlower2,
BIconFlower3:BIconFlower3,
BIconFolder:BIconFolder,
BIconFolder2:BIconFolder2,
BIconFolder2Open:BIconFolder2Open,
BIconFolderCheck:BIconFolderCheck,
BIconFolderFill:BIconFolderFill,
BIconFolderMinus:BIconFolderMinus,
BIconFolderPlus:BIconFolderPlus,
BIconFolderSymlink:BIconFolderSymlink,
BIconFolderSymlinkFill:BIconFolderSymlinkFill,
BIconFolderX:BIconFolderX,
BIconFonts:BIconFonts,
BIconForward:BIconForward,
BIconForwardFill:BIconForwardFill,
BIconFront:BIconFront,
BIconFullscreen:BIconFullscreen,
BIconFullscreenExit:BIconFullscreenExit,
BIconFunnel:BIconFunnel,
BIconFunnelFill:BIconFunnelFill,
BIconGear:BIconGear,
BIconGearFill:BIconGearFill,
BIconGearWide:BIconGearWide,
BIconGearWideConnected:BIconGearWideConnected,
BIconGem:BIconGem,
BIconGeo:BIconGeo,
BIconGeoAlt:BIconGeoAlt,
BIconGeoAltFill:BIconGeoAltFill,
BIconGeoFill:BIconGeoFill,
BIconGift:BIconGift,
BIconGiftFill:BIconGiftFill,
BIconGithub:BIconGithub,
BIconGlobe:BIconGlobe,
BIconGlobe2:BIconGlobe2,
BIconGoogle:BIconGoogle,
BIconGraphDown:BIconGraphDown,
BIconGraphUp:BIconGraphUp,
BIconGrid:BIconGrid,
BIconGrid1x2:BIconGrid1x2,
BIconGrid1x2Fill:BIconGrid1x2Fill,
BIconGrid3x2:BIconGrid3x2,
BIconGrid3x2Gap:BIconGrid3x2Gap,
BIconGrid3x2GapFill:BIconGrid3x2GapFill,
BIconGrid3x3:BIconGrid3x3,
BIconGrid3x3Gap:BIconGrid3x3Gap,
BIconGrid3x3GapFill:BIconGrid3x3GapFill,
BIconGridFill:BIconGridFill,
BIconGripHorizontal:BIconGripHorizontal,
BIconGripVertical:BIconGripVertical,
BIconHammer:BIconHammer,
BIconHandIndex:BIconHandIndex,
BIconHandIndexThumb:BIconHandIndexThumb,
BIconHandThumbsDown:BIconHandThumbsDown,
BIconHandThumbsUp:BIconHandThumbsUp,
BIconHandbag:BIconHandbag,
BIconHandbagFill:BIconHandbagFill,
BIconHash:BIconHash,
BIconHdd:BIconHdd,
BIconHddFill:BIconHddFill,
BIconHddNetwork:BIconHddNetwork,
BIconHddNetworkFill:BIconHddNetworkFill,
BIconHddRack:BIconHddRack,
BIconHddRackFill:BIconHddRackFill,
BIconHddStack:BIconHddStack,
BIconHddStackFill:BIconHddStackFill,
BIconHeadphones:BIconHeadphones,
BIconHeadset:BIconHeadset,
BIconHeart:BIconHeart,
BIconHeartFill:BIconHeartFill,
BIconHeartHalf:BIconHeartHalf,
BIconHeptagon:BIconHeptagon,
BIconHeptagonFill:BIconHeptagonFill,
BIconHeptagonHalf:BIconHeptagonHalf,
BIconHexagon:BIconHexagon,
BIconHexagonFill:BIconHexagonFill,
BIconHexagonHalf:BIconHexagonHalf,
BIconHourglass:BIconHourglass,
BIconHourglassBottom:BIconHourglassBottom,
BIconHourglassSplit:BIconHourglassSplit,
BIconHourglassTop:BIconHourglassTop,
BIconHouse:BIconHouse,
BIconHouseDoor:BIconHouseDoor,
BIconHouseDoorFill:BIconHouseDoorFill,
BIconHouseFill:BIconHouseFill,
BIconHr:BIconHr,
BIconImage:BIconImage,
BIconImageAlt:BIconImageAlt,
BIconImageFill:BIconImageFill,
BIconImages:BIconImages,
BIconInbox:BIconInbox,
BIconInboxFill:BIconInboxFill,
BIconInboxes:BIconInboxes,
BIconInboxesFill:BIconInboxesFill,
BIconInfo:BIconInfo,
BIconInfoCircle:BIconInfoCircle,
BIconInfoCircleFill:BIconInfoCircleFill,
BIconInfoSquare:BIconInfoSquare,
BIconInfoSquareFill:BIconInfoSquareFill,
BIconInputCursor:BIconInputCursor,
BIconInputCursorText:BIconInputCursorText,
BIconInstagram:BIconInstagram,
BIconIntersect:BIconIntersect,
BIconJournal:BIconJournal,
BIconJournalAlbum:BIconJournalAlbum,
BIconJournalArrowDown:BIconJournalArrowDown,
BIconJournalArrowUp:BIconJournalArrowUp,
BIconJournalBookmark:BIconJournalBookmark,
BIconJournalBookmarkFill:BIconJournalBookmarkFill,
BIconJournalCheck:BIconJournalCheck,
BIconJournalCode:BIconJournalCode,
BIconJournalMedical:BIconJournalMedical,
BIconJournalMinus:BIconJournalMinus,
BIconJournalPlus:BIconJournalPlus,
BIconJournalRichtext:BIconJournalRichtext,
BIconJournalText:BIconJournalText,
BIconJournalX:BIconJournalX,
BIconJournals:BIconJournals,
BIconJoystick:BIconJoystick,
BIconJustify:BIconJustify,
BIconJustifyLeft:BIconJustifyLeft,
BIconJustifyRight:BIconJustifyRight,
BIconKanban:BIconKanban,
BIconKanbanFill:BIconKanbanFill,
BIconKey:BIconKey,
BIconKeyFill:BIconKeyFill,
BIconKeyboard:BIconKeyboard,
BIconKeyboardFill:BIconKeyboardFill,
BIconLadder:BIconLadder,
BIconLamp:BIconLamp,
BIconLampFill:BIconLampFill,
BIconLaptop:BIconLaptop,
BIconLaptopFill:BIconLaptopFill,
BIconLayers:BIconLayers,
BIconLayersFill:BIconLayersFill,
BIconLayersHalf:BIconLayersHalf,
BIconLayoutSidebar:BIconLayoutSidebar,
BIconLayoutSidebarInset:BIconLayoutSidebarInset,
BIconLayoutSidebarInsetReverse:BIconLayoutSidebarInsetReverse,
BIconLayoutSidebarReverse:BIconLayoutSidebarReverse,
BIconLayoutSplit:BIconLayoutSplit,
BIconLayoutTextSidebar:BIconLayoutTextSidebar,
BIconLayoutTextSidebarReverse:BIconLayoutTextSidebarReverse,
BIconLayoutTextWindow:BIconLayoutTextWindow,
BIconLayoutTextWindowReverse:BIconLayoutTextWindowReverse,
BIconLayoutThreeColumns:BIconLayoutThreeColumns,
BIconLayoutWtf:BIconLayoutWtf,
BIconLifePreserver:BIconLifePreserver,
BIconLightning:BIconLightning,
BIconLightningFill:BIconLightningFill,
BIconLink:BIconLink,
BIconLink45deg:BIconLink45deg,
BIconLinkedin:BIconLinkedin,
BIconList:BIconList,
BIconListCheck:BIconListCheck,
BIconListNested:BIconListNested,
BIconListOl:BIconListOl,
BIconListStars:BIconListStars,
BIconListTask:BIconListTask,
BIconListUl:BIconListUl,
BIconLock:BIconLock,
BIconLockFill:BIconLockFill,
BIconMailbox:BIconMailbox,
BIconMailbox2:BIconMailbox2,
BIconMap:BIconMap,
BIconMapFill:BIconMapFill,
BIconMarkdown:BIconMarkdown,
BIconMarkdownFill:BIconMarkdownFill,
BIconMenuApp:BIconMenuApp,
BIconMenuAppFill:BIconMenuAppFill,
BIconMenuButton:BIconMenuButton,
BIconMenuButtonFill:BIconMenuButtonFill,
BIconMenuButtonWide:BIconMenuButtonWide,
BIconMenuButtonWideFill:BIconMenuButtonWideFill,
BIconMenuDown:BIconMenuDown,
BIconMenuUp:BIconMenuUp,
BIconMic:BIconMic,
BIconMicFill:BIconMicFill,
BIconMicMute:BIconMicMute,
BIconMicMuteFill:BIconMicMuteFill,
BIconMinecart:BIconMinecart,
BIconMinecartLoaded:BIconMinecartLoaded,
BIconMoon:BIconMoon,
BIconMouse:BIconMouse,
BIconMouse2:BIconMouse2,
BIconMouse3:BIconMouse3,
BIconMusicNote:BIconMusicNote,
BIconMusicNoteBeamed:BIconMusicNoteBeamed,
BIconMusicNoteList:BIconMusicNoteList,
BIconMusicPlayer:BIconMusicPlayer,
BIconMusicPlayerFill:BIconMusicPlayerFill,
BIconNewspaper:BIconNewspaper,
BIconNodeMinus:BIconNodeMinus,
BIconNodeMinusFill:BIconNodeMinusFill,
BIconNodePlus:BIconNodePlus,
BIconNodePlusFill:BIconNodePlusFill,
BIconNut:BIconNut,
BIconNutFill:BIconNutFill,
BIconOctagon:BIconOctagon,
BIconOctagonFill:BIconOctagonFill,
BIconOctagonHalf:BIconOctagonHalf,
BIconOption:BIconOption,
BIconOutlet:BIconOutlet,
BIconPaperclip:BIconPaperclip,
BIconParagraph:BIconParagraph,
BIconPatchCheck:BIconPatchCheck,
BIconPatchCheckFill:BIconPatchCheckFill,
BIconPatchExclamation:BIconPatchExclamation,
BIconPatchExclamationFill:BIconPatchExclamationFill,
BIconPatchMinus:BIconPatchMinus,
BIconPatchMinusFill:BIconPatchMinusFill,
BIconPatchPlus:BIconPatchPlus,
BIconPatchPlusFill:BIconPatchPlusFill,
BIconPatchQuestion:BIconPatchQuestion,
BIconPatchQuestionFill:BIconPatchQuestionFill,
BIconPause:BIconPause,
BIconPauseBtn:BIconPauseBtn,
BIconPauseBtnFill:BIconPauseBtnFill,
BIconPauseCircle:BIconPauseCircle,
BIconPauseCircleFill:BIconPauseCircleFill,
BIconPauseFill:BIconPauseFill,
BIconPeace:BIconPeace,
BIconPeaceFill:BIconPeaceFill,
BIconPen:BIconPen,
BIconPenFill:BIconPenFill,
BIconPencil:BIconPencil,
BIconPencilFill:BIconPencilFill,
BIconPencilSquare:BIconPencilSquare,
BIconPentagon:BIconPentagon,
BIconPentagonFill:BIconPentagonFill,
BIconPentagonHalf:BIconPentagonHalf,
BIconPeople:BIconPeople,
BIconPeopleFill:BIconPeopleFill,
BIconPercent:BIconPercent,
BIconPerson:BIconPerson,
BIconPersonBadge:BIconPersonBadge,
BIconPersonBadgeFill:BIconPersonBadgeFill,
BIconPersonBoundingBox:BIconPersonBoundingBox,
BIconPersonCheck:BIconPersonCheck,
BIconPersonCheckFill:BIconPersonCheckFill,
BIconPersonCircle:BIconPersonCircle,
BIconPersonDash:BIconPersonDash,
BIconPersonDashFill:BIconPersonDashFill,
BIconPersonFill:BIconPersonFill,
BIconPersonLinesFill:BIconPersonLinesFill,
BIconPersonPlus:BIconPersonPlus,
BIconPersonPlusFill:BIconPersonPlusFill,
BIconPersonSquare:BIconPersonSquare,
BIconPersonX:BIconPersonX,
BIconPersonXFill:BIconPersonXFill,
BIconPhone:BIconPhone,
BIconPhoneFill:BIconPhoneFill,
BIconPhoneLandscape:BIconPhoneLandscape,
BIconPhoneLandscapeFill:BIconPhoneLandscapeFill,
BIconPhoneVibrate:BIconPhoneVibrate,
BIconPieChart:BIconPieChart,
BIconPieChartFill:BIconPieChartFill,
BIconPip:BIconPip,
BIconPipFill:BIconPipFill,
BIconPlay:BIconPlay,
BIconPlayBtn:BIconPlayBtn,
BIconPlayBtnFill:BIconPlayBtnFill,
BIconPlayCircle:BIconPlayCircle,
BIconPlayCircleFill:BIconPlayCircleFill,
BIconPlayFill:BIconPlayFill,
BIconPlug:BIconPlug,
BIconPlugFill:BIconPlugFill,
BIconPlus:BIconPlus,
BIconPlusCircle:BIconPlusCircle,
BIconPlusCircleFill:BIconPlusCircleFill,
BIconPlusSquare:BIconPlusSquare,
BIconPlusSquareFill:BIconPlusSquareFill,
BIconPower:BIconPower,
BIconPrinter:BIconPrinter,
BIconPrinterFill:BIconPrinterFill,
BIconPuzzle:BIconPuzzle,
BIconPuzzleFill:BIconPuzzleFill,
BIconQuestion:BIconQuestion,
BIconQuestionCircle:BIconQuestionCircle,
BIconQuestionCircleFill:BIconQuestionCircleFill,
BIconQuestionDiamond:BIconQuestionDiamond,
BIconQuestionDiamondFill:BIconQuestionDiamondFill,
BIconQuestionOctagon:BIconQuestionOctagon,
BIconQuestionOctagonFill:BIconQuestionOctagonFill,
BIconQuestionSquare:BIconQuestionSquare,
BIconQuestionSquareFill:BIconQuestionSquareFill,
BIconReceipt:BIconReceipt,
BIconReceiptCutoff:BIconReceiptCutoff,
BIconReception0:BIconReception0,
BIconReception1:BIconReception1,
BIconReception2:BIconReception2,
BIconReception3:BIconReception3,
BIconReception4:BIconReception4,
BIconRecord:BIconRecord,
BIconRecord2:BIconRecord2,
BIconRecord2Fill:BIconRecord2Fill,
BIconRecordBtn:BIconRecordBtn,
BIconRecordBtnFill:BIconRecordBtnFill,
BIconRecordCircle:BIconRecordCircle,
BIconRecordCircleFill:BIconRecordCircleFill,
BIconRecordFill:BIconRecordFill,
BIconReply:BIconReply,
BIconReplyAll:BIconReplyAll,
BIconReplyAllFill:BIconReplyAllFill,
BIconReplyFill:BIconReplyFill,
BIconRss:BIconRss,
BIconRssFill:BIconRssFill,
BIconScissors:BIconScissors,
BIconScrewdriver:BIconScrewdriver,
BIconSearch:BIconSearch,
BIconSegmentedNav:BIconSegmentedNav,
BIconServer:BIconServer,
BIconShare:BIconShare,
BIconShareFill:BIconShareFill,
BIconShield:BIconShield,
BIconShieldCheck:BIconShieldCheck,
BIconShieldExclamation:BIconShieldExclamation,
BIconShieldFill:BIconShieldFill,
BIconShieldFillCheck:BIconShieldFillCheck,
BIconShieldFillExclamation:BIconShieldFillExclamation,
BIconShieldFillMinus:BIconShieldFillMinus,
BIconShieldFillPlus:BIconShieldFillPlus,
BIconShieldFillX:BIconShieldFillX,
BIconShieldLock:BIconShieldLock,
BIconShieldLockFill:BIconShieldLockFill,
BIconShieldMinus:BIconShieldMinus,
BIconShieldPlus:BIconShieldPlus,
BIconShieldShaded:BIconShieldShaded,
BIconShieldSlash:BIconShieldSlash,
BIconShieldSlashFill:BIconShieldSlashFill,
BIconShieldX:BIconShieldX,
BIconShift:BIconShift,
BIconShiftFill:BIconShiftFill,
BIconShop:BIconShop,
BIconShopWindow:BIconShopWindow,
BIconShuffle:BIconShuffle,
BIconSignpost:BIconSignpost,
BIconSignpost2:BIconSignpost2,
BIconSignpost2Fill:BIconSignpost2Fill,
BIconSignpostFill:BIconSignpostFill,
BIconSignpostSplit:BIconSignpostSplit,
BIconSignpostSplitFill:BIconSignpostSplitFill,
BIconSim:BIconSim,
BIconSimFill:BIconSimFill,
BIconSkipBackward:BIconSkipBackward,
BIconSkipBackwardBtn:BIconSkipBackwardBtn,
BIconSkipBackwardBtnFill:BIconSkipBackwardBtnFill,
BIconSkipBackwardCircle:BIconSkipBackwardCircle,
BIconSkipBackwardCircleFill:BIconSkipBackwardCircleFill,
BIconSkipBackwardFill:BIconSkipBackwardFill,
BIconSkipEnd:BIconSkipEnd,
BIconSkipEndBtn:BIconSkipEndBtn,
BIconSkipEndBtnFill:BIconSkipEndBtnFill,
BIconSkipEndCircle:BIconSkipEndCircle,
BIconSkipEndCircleFill:BIconSkipEndCircleFill,
BIconSkipEndFill:BIconSkipEndFill,
BIconSkipForward:BIconSkipForward,
BIconSkipForwardBtn:BIconSkipForwardBtn,
BIconSkipForwardBtnFill:BIconSkipForwardBtnFill,
BIconSkipForwardCircle:BIconSkipForwardCircle,
BIconSkipForwardCircleFill:BIconSkipForwardCircleFill,
BIconSkipForwardFill:BIconSkipForwardFill,
BIconSkipStart:BIconSkipStart,
BIconSkipStartBtn:BIconSkipStartBtn,
BIconSkipStartBtnFill:BIconSkipStartBtnFill,
BIconSkipStartCircle:BIconSkipStartCircle,
BIconSkipStartCircleFill:BIconSkipStartCircleFill,
BIconSkipStartFill:BIconSkipStartFill,
BIconSlack:BIconSlack,
BIconSlash:BIconSlash,
BIconSlashCircle:BIconSlashCircle,
BIconSlashCircleFill:BIconSlashCircleFill,
BIconSlashSquare:BIconSlashSquare,
BIconSlashSquareFill:BIconSlashSquareFill,
BIconSliders:BIconSliders,
BIconSmartwatch:BIconSmartwatch,
BIconSortAlphaDown:BIconSortAlphaDown,
BIconSortAlphaDownAlt:BIconSortAlphaDownAlt,
BIconSortAlphaUp:BIconSortAlphaUp,
BIconSortAlphaUpAlt:BIconSortAlphaUpAlt,
BIconSortDown:BIconSortDown,
BIconSortDownAlt:BIconSortDownAlt,
BIconSortNumericDown:BIconSortNumericDown,
BIconSortNumericDownAlt:BIconSortNumericDownAlt,
BIconSortNumericUp:BIconSortNumericUp,
BIconSortNumericUpAlt:BIconSortNumericUpAlt,
BIconSortUp:BIconSortUp,
BIconSortUpAlt:BIconSortUpAlt,
BIconSoundwave:BIconSoundwave,
BIconSpeaker:BIconSpeaker,
BIconSpeakerFill:BIconSpeakerFill,
BIconSpellcheck:BIconSpellcheck,
BIconSquare:BIconSquare,
BIconSquareFill:BIconSquareFill,
BIconSquareHalf:BIconSquareHalf,
BIconStar:BIconStar,
BIconStarFill:BIconStarFill,
BIconStarHalf:BIconStarHalf,
BIconStickies:BIconStickies,
BIconStickiesFill:BIconStickiesFill,
BIconSticky:BIconSticky,
BIconStickyFill:BIconStickyFill,
BIconStop:BIconStop,
BIconStopBtn:BIconStopBtn,
BIconStopBtnFill:BIconStopBtnFill,
BIconStopCircle:BIconStopCircle,
BIconStopCircleFill:BIconStopCircleFill,
BIconStopFill:BIconStopFill,
BIconStoplights:BIconStoplights,
BIconStoplightsFill:BIconStoplightsFill,
BIconStopwatch:BIconStopwatch,
BIconStopwatchFill:BIconStopwatchFill,
BIconSubtract:BIconSubtract,
BIconSuitClub:BIconSuitClub,
BIconSuitClubFill:BIconSuitClubFill,
BIconSuitDiamond:BIconSuitDiamond,
BIconSuitDiamondFill:BIconSuitDiamondFill,
BIconSuitHeart:BIconSuitHeart,
BIconSuitHeartFill:BIconSuitHeartFill,
BIconSuitSpade:BIconSuitSpade,
BIconSuitSpadeFill:BIconSuitSpadeFill,
BIconSun:BIconSun,
BIconSunglasses:BIconSunglasses,
BIconTable:BIconTable,
BIconTablet:BIconTablet,
BIconTabletFill:BIconTabletFill,
BIconTabletLandscape:BIconTabletLandscape,
BIconTabletLandscapeFill:BIconTabletLandscapeFill,
BIconTag:BIconTag,
BIconTagFill:BIconTagFill,
BIconTags:BIconTags,
BIconTagsFill:BIconTagsFill,
BIconTelephone:BIconTelephone,
BIconTelephoneFill:BIconTelephoneFill,
BIconTelephoneForward:BIconTelephoneForward,
BIconTelephoneForwardFill:BIconTelephoneForwardFill,
BIconTelephoneInbound:BIconTelephoneInbound,
BIconTelephoneInboundFill:BIconTelephoneInboundFill,
BIconTelephoneMinus:BIconTelephoneMinus,
BIconTelephoneMinusFill:BIconTelephoneMinusFill,
BIconTelephoneOutbound:BIconTelephoneOutbound,
BIconTelephoneOutboundFill:BIconTelephoneOutboundFill,
BIconTelephonePlus:BIconTelephonePlus,
BIconTelephonePlusFill:BIconTelephonePlusFill,
BIconTelephoneX:BIconTelephoneX,
BIconTelephoneXFill:BIconTelephoneXFill,
BIconTerminal:BIconTerminal,
BIconTerminalFill:BIconTerminalFill,
BIconTextCenter:BIconTextCenter,
BIconTextIndentLeft:BIconTextIndentLeft,
BIconTextIndentRight:BIconTextIndentRight,
BIconTextLeft:BIconTextLeft,
BIconTextParagraph:BIconTextParagraph,
BIconTextRight:BIconTextRight,
BIconTextarea:BIconTextarea,
BIconTextareaResize:BIconTextareaResize,
BIconTextareaT:BIconTextareaT,
BIconThermometer:BIconThermometer,
BIconThermometerHalf:BIconThermometerHalf,
BIconThreeDots:BIconThreeDots,
BIconThreeDotsVertical:BIconThreeDotsVertical,
BIconToggle2Off:BIconToggle2Off,
BIconToggle2On:BIconToggle2On,
BIconToggleOff:BIconToggleOff,
BIconToggleOn:BIconToggleOn,
BIconToggles:BIconToggles,
BIconToggles2:BIconToggles2,
BIconTools:BIconTools,
BIconTrash:BIconTrash,
BIconTrash2:BIconTrash2,
BIconTrash2Fill:BIconTrash2Fill,
BIconTrashFill:BIconTrashFill,
BIconTree:BIconTree,
BIconTreeFill:BIconTreeFill,
BIconTriangle:BIconTriangle,
BIconTriangleFill:BIconTriangleFill,
BIconTriangleHalf:BIconTriangleHalf,
BIconTrophy:BIconTrophy,
BIconTrophyFill:BIconTrophyFill,
BIconTruck:BIconTruck,
BIconTruckFlatbed:BIconTruckFlatbed,
BIconTv:BIconTv,
BIconTvFill:BIconTvFill,
BIconTwitch:BIconTwitch,
BIconTwitter:BIconTwitter,
BIconType:BIconType,
BIconTypeBold:BIconTypeBold,
BIconTypeH1:BIconTypeH1,
BIconTypeH2:BIconTypeH2,
BIconTypeH3:BIconTypeH3,
BIconTypeItalic:BIconTypeItalic,
BIconTypeStrikethrough:BIconTypeStrikethrough,
BIconTypeUnderline:BIconTypeUnderline,
BIconUiChecks:BIconUiChecks,
BIconUiChecksGrid:BIconUiChecksGrid,
BIconUiRadios:BIconUiRadios,
BIconUiRadiosGrid:BIconUiRadiosGrid,
BIconUnion:BIconUnion,
BIconUnlock:BIconUnlock,
BIconUnlockFill:BIconUnlockFill,
BIconUpc:BIconUpc,
BIconUpcScan:BIconUpcScan,
BIconUpload:BIconUpload,
BIconVectorPen:BIconVectorPen,
BIconViewList:BIconViewList,
BIconViewStacked:BIconViewStacked,
BIconVinyl:BIconVinyl,
BIconVinylFill:BIconVinylFill,
BIconVoicemail:BIconVoicemail,
BIconVolumeDown:BIconVolumeDown,
BIconVolumeDownFill:BIconVolumeDownFill,
BIconVolumeMute:BIconVolumeMute,
BIconVolumeMuteFill:BIconVolumeMuteFill,
BIconVolumeOff:BIconVolumeOff,
BIconVolumeOffFill:BIconVolumeOffFill,
BIconVolumeUp:BIconVolumeUp,
BIconVolumeUpFill:BIconVolumeUpFill,
BIconVr:BIconVr,
BIconWallet:BIconWallet,
BIconWallet2:BIconWallet2,
BIconWalletFill:BIconWalletFill,
BIconWatch:BIconWatch,
BIconWifi:BIconWifi,
BIconWifi1:BIconWifi1,
BIconWifi2:BIconWifi2,
BIconWifiOff:BIconWifiOff,
BIconWindow:BIconWindow,
BIconWrench:BIconWrench,
BIconX:BIconX,
BIconXCircle:BIconXCircle,
BIconXCircleFill:BIconXCircleFill,
BIconXDiamond:BIconXDiamond,
BIconXDiamondFill:BIconXDiamondFill,
BIconXOctagon:BIconXOctagon,
BIconXOctagonFill:BIconXOctagonFill,
BIconXSquare:BIconXSquare,
BIconXSquareFill:BIconXSquareFill,
BIconYoutube:BIconYoutube,
BIconZoomIn:BIconZoomIn,
BIconZoomOut:BIconZoomOut}});

// Export the BootstrapVueIcons plugin installer
// Mainly for the stand-alone bootstrap-vue-icons.xxx.js builds

var BootstrapVueIcons=/*#__PURE__*/pluginFactoryNoConfig({
plugins:{
IconsPlugin:IconsPlugin}},

{
NAME:'BootstrapVueIcons'});
// --- END AUTO-GENERATED FILE ---

var props$1Q=makePropsConfigurable({
animation:makeProp(PROP_TYPE_STRING,'wave'),
icon:makeProp(PROP_TYPE_STRING),
iconProps:makeProp(PROP_TYPE_OBJECT,{})},
NAME_SKELETON_ICON);// --- Main component ---
// @vue/component

var BSkeletonIcon=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_SKELETON_ICON,
functional:true,
props:props$1Q,
render:function render(h,_ref){
var props=_ref.props;
var icon=props.icon,
animation=props.animation;
var $icon=h(BIcon,{
staticClass:'b-skeleton-icon',
props:_objectSpread2(_objectSpread2({},props.iconProps),{},{
icon:icon})});


return h('div',{
staticClass:'b-skeleton-icon-wrapper position-relative d-inline-block overflow-hidden',
class:_defineProperty({},"b-skeleton-animate-".concat(animation),animation)},
[$icon]);
}});


var props$1R=makePropsConfigurable({
animation:makeProp(PROP_TYPE_STRING),
aspect:makeProp(PROP_TYPE_STRING,'16:9'),
cardImg:makeProp(PROP_TYPE_STRING),
height:makeProp(PROP_TYPE_STRING),
noAspect:makeProp(PROP_TYPE_BOOLEAN,false),
variant:makeProp(PROP_TYPE_STRING),
width:makeProp(PROP_TYPE_STRING)},
NAME_SKELETON_IMG);// --- Main component ---
// @vue/component

var BSkeletonImg=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_SKELETON_IMG,
functional:true,
props:props$1R,
render:function render(h,_ref){
var props=_ref.props;
var aspect=props.aspect,
width=props.width,
height=props.height,
animation=props.animation,
variant=props.variant,
cardImg=props.cardImg;
var $img=h(BSkeleton,{
props:{
type:'img',
width:width,
height:height,
animation:animation,
variant:variant},

class:_defineProperty({},"card-img-".concat(cardImg),cardImg)});

return props.noAspect?$img:h(BAspect,{
props:{
aspect:aspect}},

[$img]);
}});


// Mixin to determine if an event listener has been registered

var hasListenerMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
methods:{
hasListener:function hasListener(name){
// Only includes listeners registered via `v-on:name`
var $listeners=this.$listeners||{};// Includes `v-on:name` and `this.$on('name')` registered listeners
// Note this property is not part of the public Vue API, but it is
// the only way to determine if a listener was added via `vm.$on`

var $events=this._events||{};// Registered listeners in `this._events` are always an array,
// but might be zero length

return !isUndefined($listeners[name])||isArray($events[name])&&$events[name].length>0;
}}});



var LIGHT='light';
var DARK='dark';// --- Props ---

var props$1S=makePropsConfigurable({
variant:makeProp(PROP_TYPE_STRING)},
NAME_TR);// --- Main component ---
// TODO:
//   In Bootstrap v5, we won't need "sniffing" as table element variants properly inherit
//   to the child elements, so this can be converted to a functional component
// @vue/component

var BTr=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TR,
mixins:[attrsMixin,listenersMixin,normalizeSlotMixin],
provide:function provide(){
return {
bvTableTr:this};

},
inject:{
bvTableRowGroup:{
default:
/* istanbul ignore next */
function _default(){
return {};
}}},


inheritAttrs:false,
props:props$1S,
computed:{
// Sniffed by `<b-td>` / `<b-th>`
inTbody:function inTbody(){
return this.bvTableRowGroup.isTbody;
},
// Sniffed by `<b-td>` / `<b-th>`
inThead:function inThead(){
return this.bvTableRowGroup.isThead;
},
// Sniffed by `<b-td>` / `<b-th>`
inTfoot:function inTfoot(){
return this.bvTableRowGroup.isTfoot;
},
// Sniffed by `<b-td>` / `<b-th>`
isDark:function isDark(){
return this.bvTableRowGroup.isDark;
},
// Sniffed by `<b-td>` / `<b-th>`
isStacked:function isStacked(){
return this.bvTableRowGroup.isStacked;
},
// Sniffed by `<b-td>` / `<b-th>`
isResponsive:function isResponsive(){
return this.bvTableRowGroup.isResponsive;
},
// Sniffed by `<b-td>` / `<b-th>`
// Sticky headers are only supported in thead
isStickyHeader:function isStickyHeader(){
return this.bvTableRowGroup.isStickyHeader;
},
// Sniffed by <b-tr> / `<b-td>` / `<b-th>`
// Needed to handle header background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
hasStickyHeader:function hasStickyHeader(){
return !this.isStacked&&this.bvTableRowGroup.hasStickyHeader;
},
// Sniffed by `<b-td>` / `<b-th>`
tableVariant:function tableVariant(){
return this.bvTableRowGroup.tableVariant;
},
// Sniffed by `<b-td>` / `<b-th>`
headVariant:function headVariant(){
return this.inThead?this.bvTableRowGroup.headVariant:null;
},
// Sniffed by `<b-td>` / `<b-th>`
footVariant:function footVariant(){
return this.inTfoot?this.bvTableRowGroup.footVariant:null;
},
isRowDark:function isRowDark(){
return this.headVariant===LIGHT||this.footVariant===LIGHT?
/* istanbul ignore next */
false:this.headVariant===DARK||this.footVariant===DARK?
/* istanbul ignore next */
true:this.isDark;
},
trClasses:function trClasses(){
var variant=this.variant;
return [variant?"".concat(this.isRowDark?'bg':'table',"-").concat(variant):null];
},
trAttrs:function trAttrs(){
return _objectSpread2({
role:'row'},
this.bvAttrs);
}},

render:function render(h){
return h('tr',{
class:this.trClasses,
attrs:this.trAttrs,
// Pass native listeners to child
on:this.bvListeners},
this.normalizeSlot());
}});


var props$1T={};// --- Mixin ---
// @vue/component

var bottomRowMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$1T,
methods:{
renderBottomRow:function renderBottomRow(){
var fields=this.computedFields,
stacked=this.stacked,
tbodyTrClass=this.tbodyTrClass,
tbodyTrAttr=this.tbodyTrAttr;
var h=this.$createElement;// Static bottom row slot (hidden in visibly stacked mode as we can't control the data-label)
// If in *always* stacked mode, we don't bother rendering the row

if(!this.hasNormalizedSlot(SLOT_NAME_BOTTOM_ROW)||stacked===true||stacked===''){
return h();
}

return h(BTr,{
staticClass:'b-table-bottom-row',
class:[isFunction(tbodyTrClass)?
/* istanbul ignore next */
tbodyTrClass(null,'row-bottom'):tbodyTrClass],
attrs:isFunction(tbodyTrAttr)?
/* istanbul ignore next */
tbodyTrAttr(null,'row-bottom'):tbodyTrAttr,
key:'b-bottom-row'},
this.normalizeSlot(SLOT_NAME_BOTTOM_ROW,{
columns:fields.length,
fields:fields}));

}}});



// Parse a rowspan or colspan into a digit (or `null` if < `1` )

var parseSpan=function parseSpan(value){
value=toInteger(value,0);
return value>0?value:null;
};
/* istanbul ignore next */


var spanValidator=function spanValidator(value){
return isUndefinedOrNull(value)||parseSpan(value)>0;
};// --- Props ---


var props$1U=makePropsConfigurable({
colspan:makeProp(PROP_TYPE_NUMBER_STRING,null,spanValidator),
rowspan:makeProp(PROP_TYPE_NUMBER_STRING,null,spanValidator),
stackedHeading:makeProp(PROP_TYPE_STRING),
stickyColumn:makeProp(PROP_TYPE_BOOLEAN,false),
variant:makeProp(PROP_TYPE_STRING)},
NAME_TABLE_CELL);// --- Main component ---
// TODO:
//   In Bootstrap v5, we won't need "sniffing" as table element variants properly inherit
//   to the child elements, so this can be converted to a functional component
// @vue/component

var BTd=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TABLE_CELL,
// Mixin order is important!
mixins:[attrsMixin,listenersMixin,normalizeSlotMixin],
inject:{
bvTableTr:{
default:
/* istanbul ignore next */
function _default(){
return {};
}}},


inheritAttrs:false,
props:props$1U,
computed:{
// Overridden by `<b-th>`
tag:function tag(){
return 'td';
},
inTbody:function inTbody(){
return this.bvTableTr.inTbody;
},
inThead:function inThead(){
return this.bvTableTr.inThead;
},
inTfoot:function inTfoot(){
return this.bvTableTr.inTfoot;
},
isDark:function isDark(){
return this.bvTableTr.isDark;
},
isStacked:function isStacked(){
return this.bvTableTr.isStacked;
},
// We only support stacked-heading in tbody in stacked mode
isStackedCell:function isStackedCell(){
return this.inTbody&&this.isStacked;
},
isResponsive:function isResponsive(){
return this.bvTableTr.isResponsive;
},
// Needed to handle header background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
// Sticky headers only apply to cells in table `thead`
isStickyHeader:function isStickyHeader(){
return this.bvTableTr.isStickyHeader;
},
// Needed to handle header background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
hasStickyHeader:function hasStickyHeader(){
return this.bvTableTr.hasStickyHeader;
},
// Needed to handle background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
// Sticky column cells are only available in responsive
// mode (horizontal scrolling) or when sticky header mode
// Applies to cells in `thead`, `tbody` and `tfoot`
isStickyColumn:function isStickyColumn(){
return !this.isStacked&&(this.isResponsive||this.hasStickyHeader)&&this.stickyColumn;
},
rowVariant:function rowVariant(){
return this.bvTableTr.variant;
},
headVariant:function headVariant(){
return this.bvTableTr.headVariant;
},
footVariant:function footVariant(){
return this.bvTableTr.footVariant;
},
tableVariant:function tableVariant(){
return this.bvTableTr.tableVariant;
},
computedColspan:function computedColspan(){
return parseSpan(this.colspan);
},
computedRowspan:function computedRowspan(){
return parseSpan(this.rowspan);
},
// We use computed props here for improved performance by caching
// the results of the string interpolation
cellClasses:function cellClasses(){
var variant=this.variant,
headVariant=this.headVariant,
isStickyColumn=this.isStickyColumn;

if(!variant&&this.isStickyHeader&&!headVariant||!variant&&isStickyColumn&&this.inTfoot&&!this.footVariant||!variant&&isStickyColumn&&this.inThead&&!headVariant||!variant&&isStickyColumn&&this.inTbody){
// Needed for sticky-header mode as Bootstrap v4 table cells do
// not inherit parent's `background-color`
variant=this.rowVariant||this.tableVariant||'b-table-default';
}

return [variant?"".concat(this.isDark?'bg':'table',"-").concat(variant):null,isStickyColumn?'b-table-sticky-column':null];
},
cellAttrs:function cellAttrs(){
var stackedHeading=this.stackedHeading;// We use computed props here for improved performance by caching
// the results of the object spread (Object.assign)

var headOrFoot=this.inThead||this.inTfoot;// Make sure col/rowspan's are > 0 or null

var colspan=this.computedColspan;
var rowspan=this.computedRowspan;// Default role and scope

var role='cell';
var scope=null;// Compute role and scope
// We only add scopes with an explicit span of 1 or greater

if(headOrFoot){
// Header or footer cells
role='columnheader';
scope=colspan>0?'colspan':'col';
}else if(isTag(this.tag,'th')){
// th's in tbody
role='rowheader';
scope=rowspan>0?'rowgroup':'row';
}

return _objectSpread2(_objectSpread2({
colspan:colspan,
rowspan:rowspan,
role:role,
scope:scope},
this.bvAttrs),{},{
// Add in the stacked cell label data-attribute if in
// stacked mode (if a stacked heading label is provided)
'data-label':this.isStackedCell&&!isUndefinedOrNull(stackedHeading)?
/* istanbul ignore next */
toString$1(stackedHeading):null});

}},

render:function render(h){
var $content=[this.normalizeSlot()];
return h(this.tag,{
class:this.cellClasses,
attrs:this.cellAttrs,
// Transfer any native listeners
on:this.bvListeners},
[this.isStackedCell?h('div',[$content]):$content]);
}});


var MODEL_PROP_NAME_BUSY='busy';
var MODEL_EVENT_NAME_BUSY=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_BUSY;// --- Props ---

var props$1V=_defineProperty({},MODEL_PROP_NAME_BUSY,makeProp(PROP_TYPE_BOOLEAN,false));// --- Mixin ---
// @vue/component

var busyMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$1V,
data:function data(){
return {
localBusy:false};

},
computed:{
computedBusy:function computedBusy(){
return this[MODEL_PROP_NAME_BUSY]||this.localBusy;
}},

watch:{
localBusy:function localBusy(newValue,oldValue){
if(newValue!==oldValue){
this.$emit(MODEL_EVENT_NAME_BUSY,newValue);
}
}},

methods:{
// Event handler helper
stopIfBusy:function stopIfBusy(event){
// If table is busy (via provider) then don't propagate
if(this.computedBusy){
stopEvent(event);
return true;
}

return false;
},
// Render the busy indicator or return `null` if not busy
renderBusy:function renderBusy(){
var tbodyTrClass=this.tbodyTrClass,
tbodyTrAttr=this.tbodyTrAttr;
var h=this.$createElement;// Return a busy indicator row, or `null` if not busy

if(this.computedBusy&&this.hasNormalizedSlot(SLOT_NAME_TABLE_BUSY)){
return h(BTr,{
staticClass:'b-table-busy-slot',
class:[isFunction(tbodyTrClass)?
/* istanbul ignore next */
tbodyTrClass(null,SLOT_NAME_TABLE_BUSY):tbodyTrClass],
attrs:isFunction(tbodyTrAttr)?
/* istanbul ignore next */
tbodyTrAttr(null,SLOT_NAME_TABLE_BUSY):tbodyTrAttr,
key:'table-busy-slot'},
[h(BTd,{
props:{
colspan:this.computedFields.length||null}},

[this.normalizeSlot(SLOT_NAME_TABLE_BUSY)])]);
}// We return `null` here so that we can determine if we need to
// render the table items rows or not


return null;
}}});



var props$1W={
caption:makeProp(PROP_TYPE_STRING),
captionHtml:makeProp(PROP_TYPE_STRING)// `caption-top` is part of table-render mixin (styling)
// captionTop: makeProp(PROP_TYPE_BOOLEAN, false)
};
// --- Mixin ---
// @vue/component

var captionMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$1W,
computed:{
captionId:function captionId(){
return this.isStacked?this.safeId('_caption_'):null;
}},

methods:{
renderCaption:function renderCaption(){
var caption=this.caption,
captionHtml=this.captionHtml;
var h=this.$createElement;
var $caption=h();
var hasCaptionSlot=this.hasNormalizedSlot(SLOT_NAME_TABLE_CAPTION);

if(hasCaptionSlot||caption||captionHtml){
$caption=h('caption',{
attrs:{
id:this.captionId},

domProps:hasCaptionSlot?{}:htmlOrText(captionHtml,caption),
key:'caption',
ref:'caption'},
this.normalizeSlot(SLOT_NAME_TABLE_CAPTION));
}

return $caption;
}}});



var props$1X={};// --- Mixin ---
// @vue/component

var colgroupMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
methods:{
renderColgroup:function renderColgroup(){
var fields=this.computedFields;
var h=this.$createElement;
var $colgroup=h();

if(this.hasNormalizedSlot(SLOT_NAME_TABLE_COLGROUP)){
$colgroup=h('colgroup',{
key:'colgroup'},
[this.normalizeSlot(SLOT_NAME_TABLE_COLGROUP,{
columns:fields.length,
fields:fields})]);

}

return $colgroup;
}}});



var props$1Y={
emptyFilteredHtml:makeProp(PROP_TYPE_STRING),
emptyFilteredText:makeProp(PROP_TYPE_STRING,'There are no records matching your request'),
emptyHtml:makeProp(PROP_TYPE_STRING),
emptyText:makeProp(PROP_TYPE_STRING,'There are no records to show'),
showEmpty:makeProp(PROP_TYPE_BOOLEAN,false)};
// --- Mixin ---
// @vue/component

var emptyMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$1Y,
methods:{
renderEmpty:function renderEmpty(){
var items=this.computedItems;
var h=this.$createElement;
var $empty=h();

if(this.showEmpty&&(!items||items.length===0)&&!(this.computedBusy&&this.hasNormalizedSlot(SLOT_NAME_TABLE_BUSY))){
var fields=this.computedFields,
isFiltered=this.isFiltered,
emptyText=this.emptyText,
emptyHtml=this.emptyHtml,
emptyFilteredText=this.emptyFilteredText,
emptyFilteredHtml=this.emptyFilteredHtml,
tbodyTrClass=this.tbodyTrClass,
tbodyTrAttr=this.tbodyTrAttr;
$empty=this.normalizeSlot(isFiltered?SLOT_NAME_EMPTYFILTERED:SLOT_NAME_EMPTY,{
emptyFilteredHtml:emptyFilteredHtml,
emptyFilteredText:emptyFilteredText,
emptyHtml:emptyHtml,
emptyText:emptyText,
fields:fields,
// Not sure why this is included, as it will always be an empty array
items:items});


if(!$empty){
$empty=h('div',{
class:['text-center','my-2'],
domProps:isFiltered?htmlOrText(emptyFilteredHtml,emptyFilteredText):htmlOrText(emptyHtml,emptyText)});

}

$empty=h(BTd,{
props:{
colspan:fields.length||null}},

[h('div',{
attrs:{
role:'alert',
'aria-live':'polite'}},

[$empty])]);
$empty=h(BTr,{
staticClass:'b-table-empty-row',
class:[isFunction(tbodyTrClass)?
/* istanbul ignore next */
tbodyTrClass(null,'row-empty'):tbodyTrClass],
attrs:isFunction(tbodyTrAttr)?
/* istanbul ignore next */
tbodyTrAttr(null,'row-empty'):tbodyTrAttr,
key:isFiltered?'b-empty-filtered-row':'b-empty-row'},
[$empty]);
}

return $empty;
}}});



// SSR safe deterministic way (keys are sorted before stringification)
//
//   ex:
//     { b: 3, c: { z: 'zzz', d: null, e: 2 }, d: [10, 12, 11], a: 'one' }
//   becomes
//     'one 3 2 zzz 10 12 11'
//
// Strings are returned as-is
// Numbers get converted to string
// `null` and `undefined` values are filtered out
// Dates are converted to their native string format

var stringifyObjectValues=function stringifyObjectValues(value){
if(isUndefinedOrNull(value)){
return '';
}// Arrays are also object, and keys just returns the array indexes
// Date objects we convert to strings


if(isObject(value)&&!isDate(value)){
return keys(value).sort()// Sort to prevent SSR issues on pre-rendered sorted tables
.map(function(k){
return stringifyObjectValues(value[k]);
}).filter(function(v){
return !!v;
})// Ignore empty strings
.join(' ');
}

return toString$1(value);
};

// Constants used by table helpers
var FIELD_KEY_CELL_VARIANT='_cellVariants';
var FIELD_KEY_ROW_VARIANT='_rowVariant';
var FIELD_KEY_SHOW_DETAILS='_showDetails';// Object of item keys that should be ignored for headers and
// stringification and filter events

var IGNORED_FIELD_KEYS=[FIELD_KEY_CELL_VARIANT,FIELD_KEY_ROW_VARIANT,FIELD_KEY_SHOW_DETAILS].reduce(function(result,key){
return _objectSpread2(_objectSpread2({},result),{},_defineProperty({},key,true));
},{});// Filter CSS selector for click/dblclick/etc. events
// If any of these selectors match the clicked element, we ignore the event

var EVENT_FILTER=['a','a *',// Include content inside links
'button','button *',// Include content inside buttons
'input:not(.disabled):not([disabled])','select:not(.disabled):not([disabled])','textarea:not(.disabled):not([disabled])','[role="link"]','[role="link"] *','[role="button"]','[role="button"] *','[tabindex]:not(.disabled):not([disabled])'].join(',');

var sanitizeRow=function sanitizeRow(row,ignoreFields,includeFields){
var fieldsObj=arguments.length>3&&arguments[3]!==undefined?arguments[3]:{};
// We first need to format the row based on the field configurations
// This ensures that we add formatted values for keys that may not
// exist in the row itself
var formattedRow=keys(fieldsObj).reduce(function(result,key){
var field=fieldsObj[key];
var filterByFormatted=field.filterByFormatted;
var formatter=isFunction(filterByFormatted)?
/* istanbul ignore next */
filterByFormatted:filterByFormatted?
/* istanbul ignore next */
field.formatter:null;

if(isFunction(formatter)){
result[key]=formatter(row[key],key,row);
}

return result;
},clone(row));// Determine the allowed keys:
//   - Ignore special fields that start with `_`
//   - Ignore fields in the `ignoreFields` array
//   - Include only fields in the `includeFields` array

var allowedKeys=keys(formattedRow).filter(function(key){
return !IGNORED_FIELD_KEYS[key]&&!(isArray(ignoreFields)&&ignoreFields.length>0&&arrayIncludes(ignoreFields,key))&&!(isArray(includeFields)&&includeFields.length>0&&!arrayIncludes(includeFields,key));
});
return pick(formattedRow,allowedKeys);
};

// TODO: Add option to stringify `scopedSlot` items

var stringifyRecordValues=function stringifyRecordValues(row,ignoreFields,includeFields,fieldsObj){
return isObject(row)?stringifyObjectValues(sanitizeRow(row,ignoreFields,includeFields,fieldsObj)):
/* istanbul ignore next */
'';
};

var DEBOUNCE_DEPRECATED_MSG='Prop "filter-debounce" is deprecated. Use the debounce feature of "<b-form-input>" instead.';// --- Props ---

var props$1Z={
filter:makeProp([].concat(_toConsumableArray(PROP_TYPE_ARRAY_OBJECT_STRING),[PROP_TYPE_REG_EXP])),
filterDebounce:makeProp(PROP_TYPE_NUMBER_STRING,0,function(value){
return RX_DIGITS.test(String(value));
}),
filterFunction:makeProp(PROP_TYPE_FUNCTION),
filterIgnoredFields:makeProp(PROP_TYPE_ARRAY,[]),
filterIncludedFields:makeProp(PROP_TYPE_ARRAY,[])};
// --- Mixin ---
// @vue/component

var filteringMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$1Z,
data:function data(){
return {
// Flag for displaying which empty slot to show and some event triggering
isFiltered:false,
// Where we store the copy of the filter criteria after debouncing
// We pre-set it with the sanitized filter value
localFilter:this.filterSanitize(this.filter)};

},
computed:{
computedFilterIgnored:function computedFilterIgnored(){
return concat(this.filterIgnoredFields||[]).filter(identity);
},
computedFilterIncluded:function computedFilterIncluded(){
return concat(this.filterIncludedFields||[]).filter(identity);
},
computedFilterDebounce:function computedFilterDebounce(){
var ms=toInteger(this.filterDebounce,0);
/* istanbul ignore next */

if(ms>0){
warn(DEBOUNCE_DEPRECATED_MSG,NAME_TABLE);
}

return ms;
},
localFiltering:function localFiltering(){
return this.hasProvider?!!this.noProviderFiltering:true;
},
// For watching changes to `filteredItems` vs `localItems`
filteredCheck:function filteredCheck(){
var filteredItems=this.filteredItems,
localItems=this.localItems,
localFilter=this.localFilter;
return {
filteredItems:filteredItems,
localItems:localItems,
localFilter:localFilter};

},
// Sanitized/normalize filter-function prop
localFilterFn:function localFilterFn(){
// Return `null` to signal to use internal filter function
var filterFunction=this.filterFunction;
return hasPropFunction(filterFunction)?filterFunction:null;
},
// Returns the records in `localItems` that match the filter criteria
// Returns the original `localItems` array if not sorting
filteredItems:function filteredItems(){
// Note the criteria is debounced and sanitized
var items=this.localItems,
criteria=this.localFilter;// Resolve the filtering function, when requested
// We prefer the provided filtering function and fallback to the internal one
// When no filtering criteria is specified the filtering factories will return `null`

var filterFn=this.localFiltering?this.filterFnFactory(this.localFilterFn,criteria)||this.defaultFilterFnFactory(criteria):null;// We only do local filtering when requested and there are records to filter

return filterFn&&items.length>0?items.filter(filterFn):items;
}},

watch:{
// Watch for debounce being set to 0
computedFilterDebounce:function computedFilterDebounce(newValue){
if(!newValue&&this.$_filterTimer){
this.clearFilterTimer();
this.localFilter=this.filterSanitize(this.filter);
}
},
// Watch for changes to the filter criteria, and debounce if necessary
filter:{
// We need a deep watcher in case the user passes
// an object when using `filter-function`
deep:true,
handler:function handler(newCriteria){
var _this=this;

var timeout=this.computedFilterDebounce;
this.clearFilterTimer();

if(timeout&&timeout>0){
// If we have a debounce time, delay the update of `localFilter`
this.$_filterTimer=setTimeout(function(){
_this.localFilter=_this.filterSanitize(newCriteria);
},timeout);
}else {
// Otherwise, immediately update `localFilter` with `newFilter` value
this.localFilter=this.filterSanitize(newCriteria);
}
}},

// Watch for changes to the filter criteria and filtered items vs `localItems`
// Set visual state and emit events as required
filteredCheck:function filteredCheck(_ref){
var filteredItems=_ref.filteredItems,
localFilter=_ref.localFilter;
// Determine if the dataset is filtered or not
var isFiltered=false;

if(!localFilter){
// If filter criteria is falsey
isFiltered=false;
}else if(looseEqual(localFilter,[])||looseEqual(localFilter,{})){
// If filter criteria is an empty array or object
isFiltered=false;
}else if(localFilter){
// If filter criteria is truthy
isFiltered=true;
}

if(isFiltered){
this.$emit(EVENT_NAME_FILTERED,filteredItems,filteredItems.length);
}

this.isFiltered=isFiltered;
},
isFiltered:function isFiltered(newValue,oldValue){
if(newValue===false&&oldValue===true){
// We need to emit a filtered event if `isFiltered` transitions from `true` to
// `false` so that users can update their pagination controls
var localItems=this.localItems;
this.$emit(EVENT_NAME_FILTERED,localItems,localItems.length);
}
}},

created:function created(){
var _this2=this;

// Create private non-reactive props
this.$_filterTimer=null;// If filter is "pre-set", set the criteria
// This will trigger any watchers/dependents
// this.localFilter = this.filterSanitize(this.filter)
// Set the initial filtered state in a `$nextTick()` so that
// we trigger a filtered event if needed

this.$nextTick(function(){
_this2.isFiltered=Boolean(_this2.localFilter);
});
},
beforeDestroy:function beforeDestroy(){
this.clearFilterTimer();
},
methods:{
clearFilterTimer:function clearFilterTimer(){
clearTimeout(this.$_filterTimer);
this.$_filterTimer=null;
},
filterSanitize:function filterSanitize(criteria){
// Sanitizes filter criteria based on internal or external filtering
if(this.localFiltering&&!this.localFilterFn&&!(isString(criteria)||isRegExp(criteria))){
// If using internal filter function, which only accepts string or RegExp,
// return '' to signify no filter
return '';
}// Could be a string, object or array, as needed by external filter function
// We use `cloneDeep` to ensure we have a new copy of an object or array
// without Vue's reactive observers


return cloneDeep(criteria);
},
// Filter Function factories
filterFnFactory:function filterFnFactory(filterFn,criteria){
// Wrapper factory for external filter functions
// Wrap the provided filter-function and return a new function
// Returns `null` if no filter-function defined or if criteria is falsey
// Rather than directly grabbing `this.computedLocalFilterFn` or `this.filterFunction`
// we have it passed, so that the caller computed prop will be reactive to changes
// in the original filter-function (as this routine is a method)
if(!filterFn||!isFunction(filterFn)||!criteria||looseEqual(criteria,[])||looseEqual(criteria,{})){
return null;
}// Build the wrapped filter test function, passing the criteria to the provided function


var fn=function fn(item){
// Generated function returns true if the criteria matches part
// of the serialized data, otherwise false
return filterFn(item,criteria);
};// Return the wrapped function


return fn;
},
defaultFilterFnFactory:function defaultFilterFnFactory(criteria){
var _this3=this;

// Generates the default filter function, using the given filter criteria
// Returns `null` if no criteria or criteria format not supported
if(!criteria||!(isString(criteria)||isRegExp(criteria))){
// Built in filter can only support strings or RegExp criteria (at the moment)
return null;
}// Build the RegExp needed for filtering


var regExp=criteria;

if(isString(regExp)){
// Escape special RegExp characters in the string and convert contiguous
// whitespace to \s+ matches
var pattern=escapeRegExp(criteria).replace(RX_SPACES,'\\s+');// Build the RegExp (no need for global flag, as we only need
// to find the value once in the string)

regExp=new RegExp(".*".concat(pattern,".*"),'i');
}// Generate the wrapped filter test function to use


var fn=function fn(item){
// This searches all row values (and sub property values) in the entire (excluding
// special `_` prefixed keys), because we convert the record to a space-separated
// string containing all the value properties (recursively), even ones that are
// not visible (not specified in this.fields)
// Users can ignore filtering on specific fields, or on only certain fields,
// and can optionall specify searching results of fields with formatter
//
// TODO: Enable searching on scoped slots (optional, as it will be SLOW)
//
// Generated function returns true if the criteria matches part of
// the serialized data, otherwise false
//
// We set `lastIndex = 0` on the `RegExp` in case someone specifies the `/g` global flag
regExp.lastIndex=0;
return regExp.test(stringifyRecordValues(item,_this3.computedFilterIgnored,_this3.computedFilterIncluded,_this3.computedFieldsObj));
};// Return the generated function


return fn;
}}});



var processField=function processField(key,value){
var field=null;

if(isString(value)){
// Label shortcut
field={
key:key,
label:value};

}else if(isFunction(value)){
// Formatter shortcut
field={
key:key,
formatter:value};

}else if(isObject(value)){
field=clone(value);
field.key=field.key||key;
}else if(value!==false){
// Fallback to just key

/* istanbul ignore next */
field={
key:key};

}

return field;
};// We normalize fields into an array of objects
// [ { key:..., label:..., ...}, {...}, ..., {..}]


var normalizeFields=function normalizeFields(origFields,items){
var fields=[];

if(isArray(origFields)){
// Normalize array Form
origFields.filter(identity).forEach(function(f){
if(isString(f)){
fields.push({
key:f,
label:startCase(f)});

}else if(isObject(f)&&f.key&&isString(f.key)){
// Full object definition. We use assign so that we don't mutate the original
fields.push(clone(f));
}else if(isObject(f)&&keys(f).length===1){
// Shortcut object (i.e. { 'foo_bar': 'This is Foo Bar' }
var key=keys(f)[0];
var field=processField(key,f[key]);

if(field){
fields.push(field);
}
}
});
}// If no field provided, take a sample from first record (if exits)


if(fields.length===0&&isArray(items)&&items.length>0){
var sample=items[0];
keys(sample).forEach(function(k){
if(!IGNORED_FIELD_KEYS[k]){
fields.push({
key:k,
label:startCase(k)});

}
});
}// Ensure we have a unique array of fields and that they have String labels


var memo={};
return fields.filter(function(f){
if(!memo[f.key]){
memo[f.key]=true;
f.label=isString(f.label)?f.label:startCase(f.key);
return true;
}

return false;
});
};

var _makeModelMixin$i=makeModelMixin('value',{
type:PROP_TYPE_ARRAY,
defaultValue:[]}),

modelMixin$h=_makeModelMixin$i.mixin,
modelProps$h=_makeModelMixin$i.props,
MODEL_PROP_NAME$h=_makeModelMixin$i.prop,
MODEL_EVENT_NAME$h=_makeModelMixin$i.event;

var props$1_=sortKeys(_objectSpread2(_objectSpread2({},modelProps$h),{},_defineProperty({
fields:makeProp(PROP_TYPE_ARRAY,null),
// Provider mixin adds in `Function` type
items:makeProp(PROP_TYPE_ARRAY,[]),
// Primary key for record
// If provided the value in each row must be unique!
primaryKey:makeProp(PROP_TYPE_STRING)},
MODEL_PROP_NAME$h,makeProp(PROP_TYPE_ARRAY,[]))));// --- Mixin ---
// @vue/component

var itemsMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[modelMixin$h],
props:props$1_,
data:function data(){
var items=this.items;
return {
// Our local copy of the items
// Must be an array
localItems:isArray(items)?items.slice():[]};

},
computed:{
computedFields:function computedFields(){
// We normalize fields into an array of objects
// `[ { key:..., label:..., ...}, {...}, ..., {..}]`
return normalizeFields(this.fields,this.localItems);
},
computedFieldsObj:function computedFieldsObj(){
// Fields as a simple lookup hash object
// Mainly for formatter lookup and use in `scopedSlots` for convenience
// If the field has a formatter, it normalizes formatter to a
// function ref or `undefined` if no formatter
var $parent=this.$parent;
return this.computedFields.reduce(function(obj,f){
// We use object spread here so we don't mutate the original field object
obj[f.key]=clone(f);

if(f.formatter){
// Normalize formatter to a function ref or `undefined`
var formatter=f.formatter;

if(isString(formatter)&&isFunction($parent[formatter])){
formatter=$parent[formatter];
}else if(!isFunction(formatter)){
/* istanbul ignore next */
formatter=undefined;
}// Return formatter function or `undefined` if none


obj[f.key].formatter=formatter;
}

return obj;
},{});
},
computedItems:function computedItems(){
// Fallback if various mixins not provided
return (this.paginatedItems||this.sortedItems||this.filteredItems||this.localItems||
/* istanbul ignore next */
[]).slice();
},
context:function context(){
// Current state of sorting, filtering and pagination props/values
return {
filter:this.localFilter,
sortBy:this.localSortBy,
sortDesc:this.localSortDesc,
perPage:mathMax(toInteger(this.perPage,0),0),
currentPage:mathMax(toInteger(this.currentPage,0),1),
apiUrl:this.apiUrl};

}},

watch:{
items:function items(newValue){
// Set `localItems`/`filteredItems` to a copy of the provided array
this.localItems=isArray(newValue)?newValue.slice():[];
},
// Watch for changes on `computedItems` and update the `v-model`
computedItems:function computedItems(newValue,oldValue){
if(!looseEqual(newValue,oldValue)){
this.$emit(MODEL_EVENT_NAME$h,newValue);
}
},
// Watch for context changes
context:function context(newValue,oldValue){
// Emit context information for external paging/filtering/sorting handling
if(!looseEqual(newValue,oldValue)){
this.$emit(EVENT_NAME_CONTEXT_CHANGED,newValue);
}
}},

mounted:function mounted(){
// Initially update the `v-model` of displayed items
this.$emit(MODEL_EVENT_NAME$h,this.computedItems);
},
methods:{
// Method to get the formatter method for a given field key
getFieldFormatter:function getFieldFormatter(key){
var field=this.computedFieldsObj[key];// `this.computedFieldsObj` has pre-normalized the formatter to a
// function ref if present, otherwise `undefined`

return field?field.formatter:undefined;
}}});



var props$1$={
currentPage:makeProp(PROP_TYPE_NUMBER_STRING,1),
perPage:makeProp(PROP_TYPE_NUMBER_STRING,0)};
// --- Mixin ---
// @vue/component

var paginationMixin$1=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$1$,
computed:{
localPaging:function localPaging(){
return this.hasProvider?!!this.noProviderPaging:true;
},
paginatedItems:function paginatedItems(){
var items=this.sortedItems||this.filteredItems||this.localItems||[];
var currentPage=mathMax(toInteger(this.currentPage,1),1);
var perPage=mathMax(toInteger(this.perPage,0),0);// Apply local pagination

if(this.localPaging&&perPage){
// Grab the current page of data (which may be past filtered items limit)
items=items.slice((currentPage-1)*perPage,currentPage*perPage);
}// Return the items to display in the table


return items;
}}});



var ROOT_EVENT_NAME_REFRESHED=getRootEventName(NAME_TABLE,EVENT_NAME_REFRESHED);
var ROOT_ACTION_EVENT_NAME_REFRESH=getRootActionEventName(NAME_TABLE,EVENT_NAME_REFRESH);// --- Props ---

var props$20={
// Passed to the context object
// Not used by `<b-table>` directly
apiUrl:makeProp(PROP_TYPE_STRING),
// Adds in 'Function' support
items:makeProp(PROP_TYPE_ARRAY_FUNCTION,[]),
noProviderFiltering:makeProp(PROP_TYPE_BOOLEAN,false),
noProviderPaging:makeProp(PROP_TYPE_BOOLEAN,false),
noProviderSorting:makeProp(PROP_TYPE_BOOLEAN,false)};
// --- Mixin ---
// @vue/component

var providerMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[listenOnRootMixin],
props:props$20,
computed:{
hasProvider:function hasProvider(){
return isFunction(this.items);
},
providerTriggerContext:function providerTriggerContext(){
// Used to trigger the provider function via a watcher. Only the fields that
// are needed for triggering a provider update are included. Note that the
// regular this.context is sent to the provider during fetches though, as they
// may need all the prop info.
var ctx={
apiUrl:this.apiUrl,
filter:null,
sortBy:null,
sortDesc:null,
perPage:null,
currentPage:null};


if(!this.noProviderFiltering){
// Either a string, or could be an object or array.
ctx.filter=this.localFilter;
}

if(!this.noProviderSorting){
ctx.sortBy=this.localSortBy;
ctx.sortDesc=this.localSortDesc;
}

if(!this.noProviderPaging){
ctx.perPage=this.perPage;
ctx.currentPage=this.currentPage;
}

return clone(ctx);
}},

watch:{
// Provider update triggering
items:function items(newValue){
// If a new provider has been specified, trigger an update
if(this.hasProvider||isFunction(newValue)){
this.$nextTick(this._providerUpdate);
}
},
providerTriggerContext:function providerTriggerContext(newValue,oldValue){
// Trigger the provider to update as the relevant context values have changed.
if(!looseEqual(newValue,oldValue)){
this.$nextTick(this._providerUpdate);
}
}},

mounted:function mounted(){
var _this=this;

// Call the items provider if necessary
if(this.hasProvider&&(!this.localItems||this.localItems.length===0)){
// Fetch on mount if localItems is empty
this._providerUpdate();
}// Listen for global messages to tell us to force refresh the table


this.listenOnRoot(ROOT_ACTION_EVENT_NAME_REFRESH,function(id){
if(id===_this.id||id===_this){
_this.refresh();
}
});
},
methods:{
refresh:function refresh(){
var items=this.items,
refresh=this.refresh;// Public Method: Force a refresh of the provider function

this.$off(EVENT_NAME_REFRESHED,refresh);

if(this.computedBusy){
// Can't force an update when forced busy by user (busy prop === true)
if(this.localBusy&&this.hasProvider){
// But if provider running (localBusy), re-schedule refresh once `refreshed` emitted
this.$on(EVENT_NAME_REFRESHED,refresh);
}
}else {
this.clearSelected();

if(this.hasProvider){
this.$nextTick(this._providerUpdate);
}else {
/* istanbul ignore next */
this.localItems=isArray(items)?items.slice():[];
}
}
},
// Provider related methods
_providerSetLocal:function _providerSetLocal(items){
this.localItems=isArray(items)?items.slice():[];
this.localBusy=false;
this.$emit(EVENT_NAME_REFRESHED);// New root emit

if(this.id){
this.emitOnRoot(ROOT_EVENT_NAME_REFRESHED,this.id);
}
},
_providerUpdate:function _providerUpdate(){
var _this2=this;

// Refresh the provider function items.
if(!this.hasProvider){
// Do nothing if no provider
return;
}// If table is busy, wait until refreshed before calling again


if(this.computedBusy){
// Schedule a new refresh once `refreshed` is emitted
this.$nextTick(this.refresh);
return;
}// Set internal busy state


this.localBusy=true;// Call provider function with context and optional callback after DOM is fully updated

this.$nextTick(function(){
try{
// Call provider function passing it the context and optional callback
var data=_this2.items(_this2.context,_this2._providerSetLocal);

if(isPromise(data)){
// Provider returned Promise
data.then(function(items){
// Provider resolved with items
_this2._providerSetLocal(items);
});
}else if(isArray(data)){
// Provider returned Array data
_this2._providerSetLocal(data);
}else {
/* istanbul ignore if */
if(_this2.items.length!==2){
// Check number of arguments provider function requested
// Provider not using callback (didn't request second argument), so we clear
// busy state as most likely there was an error in the provider function

/* istanbul ignore next */
warn("Provider function didn't request callback and did not return a promise or data.",NAME_TABLE);
_this2.localBusy=false;
}
}
}catch(e)
/* istanbul ignore next */
{
// Provider function borked on us, so we spew out a warning
// and clear the busy state
warn("Provider function error [".concat(e.name,"] ").concat(e.message,"."),NAME_TABLE);
_this2.localBusy=false;

_this2.$off(EVENT_NAME_REFRESHED,_this2.refresh);
}
});
}}});



var SELECT_MODES=['range','multi','single'];// --- Props ---

var props$21={
// Disable use of click handlers for row selection
noSelectOnClick:makeProp(PROP_TYPE_BOOLEAN,false),
selectMode:makeProp(PROP_TYPE_STRING,'multi',function(value){
return arrayIncludes(SELECT_MODES,value);
}),
selectable:makeProp(PROP_TYPE_BOOLEAN,false),
selectedVariant:makeProp(PROP_TYPE_STRING,'active')};
// --- Mixin ---
// @vue/component

var selectableMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$21,
data:function data(){
return {
selectedRows:[],
selectedLastRow:-1};

},
computed:{
isSelectable:function isSelectable(){
return this.selectable&&this.selectMode;
},
hasSelectableRowClick:function hasSelectableRowClick(){
return this.isSelectable&&!this.noSelectOnClick;
},
supportsSelectableRows:function supportsSelectableRows(){
return true;
},
selectableHasSelection:function selectableHasSelection(){
var selectedRows=this.selectedRows;
return this.isSelectable&&selectedRows&&selectedRows.length>0&&selectedRows.some(identity);
},
selectableIsMultiSelect:function selectableIsMultiSelect(){
return this.isSelectable&&arrayIncludes(['range','multi'],this.selectMode);
},
selectableTableClasses:function selectableTableClasses(){
var _ref;

var isSelectable=this.isSelectable;
return _ref={
'b-table-selectable':isSelectable},
_defineProperty(_ref,"b-table-select-".concat(this.selectMode),isSelectable),_defineProperty(_ref,'b-table-selecting',this.selectableHasSelection),_defineProperty(_ref,'b-table-selectable-no-click',isSelectable&&!this.hasSelectableRowClick),_ref;
},
selectableTableAttrs:function selectableTableAttrs(){
return {
// TODO:
//   Should this attribute not be included when no-select-on-click is set
//   since this attribute implies keyboard navigation?
'aria-multiselectable':!this.isSelectable?null:this.selectableIsMultiSelect?'true':'false'};

}},

watch:{
computedItems:function computedItems(newValue,oldValue){
// Reset for selectable
var equal=false;

if(this.isSelectable&&this.selectedRows.length>0){
// Quick check against array length
equal=isArray(newValue)&&isArray(oldValue)&&newValue.length===oldValue.length;

for(var i=0;equal&&i<newValue.length;i++){
// Look for the first non-loosely equal row, after ignoring reserved fields
equal=looseEqual(sanitizeRow(newValue[i]),sanitizeRow(oldValue[i]));
}
}

if(!equal){
this.clearSelected();
}
},
selectable:function selectable(newValue){
this.clearSelected();
this.setSelectionHandlers(newValue);
},
selectMode:function selectMode(){
this.clearSelected();
},
hasSelectableRowClick:function hasSelectableRowClick(newValue){
this.clearSelected();
this.setSelectionHandlers(!newValue);
},
selectedRows:function selectedRows(_selectedRows,oldValue){
var _this=this;

if(this.isSelectable&&!looseEqual(_selectedRows,oldValue)){
var items=[];// `.forEach()` skips over non-existent indices (on sparse arrays)

_selectedRows.forEach(function(v,idx){
if(v){
items.push(_this.computedItems[idx]);
}
});

this.$emit(EVENT_NAME_ROW_SELECTED,items);
}
}},

beforeMount:function beforeMount(){
// Set up handlers if needed
if(this.isSelectable){
this.setSelectionHandlers(true);
}
},
methods:{
// Public methods
selectRow:function selectRow(index){
// Select a particular row (indexed based on computedItems)
if(this.isSelectable&&isNumber(index)&&index>=0&&index<this.computedItems.length&&!this.isRowSelected(index)){
var selectedRows=this.selectableIsMultiSelect?this.selectedRows.slice():[];
selectedRows[index]=true;
this.selectedLastClicked=-1;
this.selectedRows=selectedRows;
}
},
unselectRow:function unselectRow(index){
// Un-select a particular row (indexed based on `computedItems`)
if(this.isSelectable&&isNumber(index)&&this.isRowSelected(index)){
var selectedRows=this.selectedRows.slice();
selectedRows[index]=false;
this.selectedLastClicked=-1;
this.selectedRows=selectedRows;
}
},
selectAllRows:function selectAllRows(){
var length=this.computedItems.length;

if(this.isSelectable&&length>0){
this.selectedLastClicked=-1;
this.selectedRows=this.selectableIsMultiSelect?createArray(length,true):[true];
}
},
isRowSelected:function isRowSelected(index){
// Determine if a row is selected (indexed based on `computedItems`)
return !!(isNumber(index)&&this.selectedRows[index]);
},
clearSelected:function clearSelected(){
// Clear any active selected row(s)
this.selectedLastClicked=-1;
this.selectedRows=[];
},
// Internal private methods
selectableRowClasses:function selectableRowClasses(index){
if(this.isSelectable&&this.isRowSelected(index)){
var variant=this.selectedVariant;
return _defineProperty({
'b-table-row-selected':true},
"".concat(this.dark?'bg':'table',"-").concat(variant),variant);
}

return {};
},
selectableRowAttrs:function selectableRowAttrs(index){
return {
'aria-selected':!this.isSelectable?null:this.isRowSelected(index)?'true':'false'};

},
setSelectionHandlers:function setSelectionHandlers(on){
var method=on&&!this.noSelectOnClick?'$on':'$off';// Handle row-clicked event

this[method](EVENT_NAME_ROW_CLICKED,this.selectionHandler);// Clear selection on filter, pagination, and sort changes

this[method](EVENT_NAME_FILTERED,this.clearSelected);
this[method](EVENT_NAME_CONTEXT_CHANGED,this.clearSelected);
},
selectionHandler:function selectionHandler(item,index,event){
/* istanbul ignore if: should never happen */
if(!this.isSelectable||this.noSelectOnClick){
// Don't do anything if table is not in selectable mode
this.clearSelected();
return;
}

var selectMode=this.selectMode,
selectedLastRow=this.selectedLastRow;
var selectedRows=this.selectedRows.slice();
var selected=!selectedRows[index];// Note 'multi' mode needs no special event handling

if(selectMode==='single'){
selectedRows=[];
}else if(selectMode==='range'){
if(selectedLastRow>-1&&event.shiftKey){
// range
for(var idx=mathMin(selectedLastRow,index);idx<=mathMax(selectedLastRow,index);idx++){
selectedRows[idx]=true;
}

selected=true;
}else {
if(!(event.ctrlKey||event.metaKey)){
// Clear range selection if any
selectedRows=[];
selected=true;
}

this.selectedLastRow=selected?index:-1;
}
}

selectedRows[index]=selected;
this.selectedRows=selectedRows;
}}});



/*
 * Consistent and stable sort function across JavaScript platforms
 *
 * Inconsistent sorts can cause SSR problems between client and server
 * such as in <b-table> if sortBy is applied to the data on server side render.
 * Chrome and V8 native sorts are inconsistent/unstable
 *
 * This function uses native sort with fallback to index compare when the a and b
 * compare returns 0
 *
 * Algorithm based on:
 * https://stackoverflow.com/questions/1427608/fast-stable-sorting-algorithm-implementation-in-javascript/45422645#45422645
 *
 * @param {array} array to sort
 * @param {function} sort compare function
 * @return {array}
 */
var stableSort=function stableSort(array,compareFn){
// Using `.bind(compareFn)` on the wrapped anonymous function improves
// performance by avoiding the function call setup. We don't use an arrow
// function here as it binds `this` to the `stableSort` context rather than
// the `compareFn` context, which wouldn't give us the performance increase.
return array.map(function(a,index){
return [index,a];
}).sort(function(a,b){
return this(a[1],b[1])||a[0]-b[0];
}.bind(compareFn)).map(function(e){
return e[1];
});
};

var normalizeValue=function normalizeValue(value){
if(isUndefinedOrNull(value)){
return '';
}

if(isNumeric(value)){
return toFloat(value,value);
}

return value;
};// Default sort compare routine
//
// TODO:
//   Add option to sort by multiple columns (tri-state per column,
//   plus order of columns in sort) where `sortBy` could be an array
//   of objects `[ {key: 'foo', sortDir: 'asc'}, {key:'bar', sortDir: 'desc'} ...]`
//   or an array of arrays `[ ['foo','asc'], ['bar','desc'] ]`
//   Multisort will most likely be handled in `mixin-sort.js` by
//   calling this method for each sortBy


var defaultSortCompare=function defaultSortCompare(a,b){
var _ref=arguments.length>2&&arguments[2]!==undefined?arguments[2]:{},
_ref$sortBy=_ref.sortBy,
sortBy=_ref$sortBy===void 0?null:_ref$sortBy,
_ref$formatter=_ref.formatter,
formatter=_ref$formatter===void 0?null:_ref$formatter,
_ref$locale=_ref.locale,
locale=_ref$locale===void 0?undefined:_ref$locale,
_ref$localeOptions=_ref.localeOptions,
localeOptions=_ref$localeOptions===void 0?{}:_ref$localeOptions,
_ref$nullLast=_ref.nullLast,
nullLast=_ref$nullLast===void 0?false:_ref$nullLast;

// Get the value by `sortBy`
var aa=get(a,sortBy,null);
var bb=get(b,sortBy,null);// Apply user-provided formatter

if(isFunction(formatter)){
aa=formatter(aa,sortBy,a);
bb=formatter(bb,sortBy,b);
}// Internally normalize value
// `null` / `undefined` => ''
// `'0'` => `0`


aa=normalizeValue(aa);
bb=normalizeValue(bb);

if(isDate(aa)&&isDate(bb)||isNumber(aa)&&isNumber(bb)){
// Special case for comparing dates and numbers
// Internally dates are compared via their epoch number values
return aa<bb?-1:aa>bb?1:0;
}else if(nullLast&&aa===''&&bb!==''){
// Special case when sorting `null` / `undefined` / '' last
return 1;
}else if(nullLast&&aa!==''&&bb===''){
// Special case when sorting `null` / `undefined` / '' last
return -1;
}// Do localized string comparison


return stringifyObjectValues(aa).localeCompare(stringifyObjectValues(bb),locale,localeOptions);
};

var _props,_watch$h;

var MODEL_PROP_NAME_SORT_BY='sortBy';
var MODEL_EVENT_NAME_SORT_BY=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_SORT_BY;
var MODEL_PROP_NAME_SORT_DESC='sortDesc';
var MODEL_EVENT_NAME_SORT_DESC=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_SORT_DESC;
var SORT_DIRECTION_ASC='asc';
var SORT_DIRECTION_DESC='desc';
var SORT_DIRECTION_LAST='last';
var SORT_DIRECTIONS=[SORT_DIRECTION_ASC,SORT_DIRECTION_DESC,SORT_DIRECTION_LAST];// --- Props ---

var props$22=(_props={
labelSortAsc:makeProp(PROP_TYPE_STRING,'Click to sort Ascending'),
labelSortClear:makeProp(PROP_TYPE_STRING,'Click to clear sorting'),
labelSortDesc:makeProp(PROP_TYPE_STRING,'Click to sort Descending'),
noFooterSorting:makeProp(PROP_TYPE_BOOLEAN,false),
noLocalSorting:makeProp(PROP_TYPE_BOOLEAN,false),
// Another prop that should have had a better name
// It should be `noSortClear` (on non-sortable headers)
// We will need to make sure the documentation is clear on what
// this prop does (as well as in the code for future reference)
noSortReset:makeProp(PROP_TYPE_BOOLEAN,false)},
_defineProperty(_props,MODEL_PROP_NAME_SORT_BY,makeProp(PROP_TYPE_STRING)),_defineProperty(_props,"sortCompare",makeProp(PROP_TYPE_FUNCTION)),_defineProperty(_props,"sortCompareLocale",makeProp(PROP_TYPE_ARRAY_STRING)),_defineProperty(_props,"sortCompareOptions",makeProp(PROP_TYPE_OBJECT,{
numeric:true})),
_defineProperty(_props,MODEL_PROP_NAME_SORT_DESC,makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_props,"sortDirection",makeProp(PROP_TYPE_STRING,SORT_DIRECTION_ASC,function(value){
return arrayIncludes(SORT_DIRECTIONS,value);
})),_defineProperty(_props,"sortIconLeft",makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_props,"sortNullLast",makeProp(PROP_TYPE_BOOLEAN,false)),_props);// --- Mixin ---
// @vue/component

var sortingMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$22,
data:function data(){
return {
localSortBy:this[MODEL_PROP_NAME_SORT_BY]||'',
localSortDesc:this[MODEL_PROP_NAME_SORT_DESC]||false};

},
computed:{
localSorting:function localSorting(){
return this.hasProvider?!!this.noProviderSorting:!this.noLocalSorting;
},
isSortable:function isSortable(){
return this.computedFields.some(function(f){
return f.sortable;
});
},
// Sorts the filtered items and returns a new array of the sorted items
// When not sorted, the original items array will be returned
sortedItems:function sortedItems(){
var sortBy=this.localSortBy,
sortDesc=this.localSortDesc,
locale=this.sortCompareLocale,
nullLast=this.sortNullLast,
sortCompare=this.sortCompare,
localSorting=this.localSorting;
var items=(this.filteredItems||this.localItems||[]).slice();

var localeOptions=_objectSpread2(_objectSpread2({},this.sortCompareOptions),{},{
usage:'sort'});


if(sortBy&&localSorting){
var field=this.computedFieldsObj[sortBy]||{};
var sortByFormatted=field.sortByFormatted;
var formatter=isFunction(sortByFormatted)?
/* istanbul ignore next */
sortByFormatted:sortByFormatted?this.getFieldFormatter(sortBy):undefined;// `stableSort` returns a new array, and leaves the original array intact

return stableSort(items,function(a,b){
var result=null;// Call user provided `sortCompare` routine first

if(isFunction(sortCompare)){
// TODO:
//   Change the `sortCompare` signature to the one of `defaultSortCompare`
//   with the next major version bump
result=sortCompare(a,b,sortBy,sortDesc,formatter,localeOptions,locale);
}// Fallback to built-in `defaultSortCompare` if `sortCompare`
// is not defined or returns `null`/`false`


if(isUndefinedOrNull(result)||result===false){
result=defaultSortCompare(a,b,{
sortBy:sortBy,
formatter:formatter,
locale:locale,
localeOptions:localeOptions,
nullLast:nullLast});

}// Negate result if sorting in descending order


return (result||0)*(sortDesc?-1:1);
});
}

return items;
}},

watch:(_watch$h={
/* istanbul ignore next: pain in the butt to test */
isSortable:function isSortable(newValue){
if(newValue){
if(this.isSortable){
this.$on(EVENT_NAME_HEAD_CLICKED,this.handleSort);
}
}else {
this.$off(EVENT_NAME_HEAD_CLICKED,this.handleSort);
}
}},
_defineProperty(_watch$h,MODEL_PROP_NAME_SORT_DESC,function(newValue){
/* istanbul ignore next */
if(newValue===this.localSortDesc){
return;
}

this.localSortDesc=newValue||false;
}),_defineProperty(_watch$h,MODEL_PROP_NAME_SORT_BY,function(newValue){
/* istanbul ignore next */
if(newValue===this.localSortBy){
return;
}

this.localSortBy=newValue||'';
}),_defineProperty(_watch$h,"localSortDesc",function localSortDesc(newValue,oldValue){
// Emit update to sort-desc.sync
if(newValue!==oldValue){
this.$emit(MODEL_EVENT_NAME_SORT_DESC,newValue);
}
}),_defineProperty(_watch$h,"localSortBy",function localSortBy(newValue,oldValue){
if(newValue!==oldValue){
this.$emit(MODEL_EVENT_NAME_SORT_BY,newValue);
}
}),_watch$h),
created:function created(){
if(this.isSortable){
this.$on(EVENT_NAME_HEAD_CLICKED,this.handleSort);
}
},
methods:{
// Handlers
// Need to move from thead-mixin
handleSort:function handleSort(key,field,event,isFoot){
var _this=this;

if(!this.isSortable){
/* istanbul ignore next */
return;
}

if(isFoot&&this.noFooterSorting){
return;
}// TODO: make this tri-state sorting
// cycle desc => asc => none => desc => ...


var sortChanged=false;

var toggleLocalSortDesc=function toggleLocalSortDesc(){
var sortDirection=field.sortDirection||_this.sortDirection;

if(sortDirection===SORT_DIRECTION_ASC){
_this.localSortDesc=false;
}else if(sortDirection===SORT_DIRECTION_DESC){
_this.localSortDesc=true;
}
};

if(field.sortable){
var sortKey=!this.localSorting&&field.sortKey?field.sortKey:key;

if(this.localSortBy===sortKey){
// Change sorting direction on current column
this.localSortDesc=!this.localSortDesc;
}else {
// Start sorting this column ascending
this.localSortBy=sortKey;// this.localSortDesc = false

toggleLocalSortDesc();
}

sortChanged=true;
}else if(this.localSortBy&&!this.noSortReset){
this.localSortBy='';
toggleLocalSortDesc();
sortChanged=true;
}

if(sortChanged){
// Sorting parameters changed
this.$emit(EVENT_NAME_SORT_CHANGED,this.context);
}
},
// methods to compute classes and attrs for thead>th cells
sortTheadThClasses:function sortTheadThClasses(key,field,isFoot){
return {
// If sortable and sortIconLeft are true, then place sort icon on the left
'b-table-sort-icon-left':field.sortable&&this.sortIconLeft&&!(isFoot&&this.noFooterSorting)};

},
sortTheadThAttrs:function sortTheadThAttrs(key,field,isFoot){
if(!this.isSortable||isFoot&&this.noFooterSorting){
// No attributes if not a sortable table
return {};
}

var sortable=field.sortable;// Assemble the aria-sort attribute value

var ariaSort=sortable&&this.localSortBy===key?this.localSortDesc?'descending':'ascending':sortable?'none':null;// Return the attribute

return {
'aria-sort':ariaSort};

},
sortTheadThLabel:function sortTheadThLabel(key,field,isFoot){
// A label to be placed in an `.sr-only` element in the header cell
if(!this.isSortable||isFoot&&this.noFooterSorting){
// No label if not a sortable table
return null;
}

var sortable=field.sortable;// The correctness of these labels is very important for screen-reader users.

var labelSorting='';

if(sortable){
if(this.localSortBy===key){
// currently sorted sortable column.
labelSorting=this.localSortDesc?this.labelSortAsc:this.labelSortDesc;
}else {
// Not currently sorted sortable column.
// Not using nested ternary's here for clarity/readability
// Default for ariaLabel
labelSorting=this.localSortDesc?this.labelSortDesc:this.labelSortAsc;// Handle sortDirection setting

var sortDirection=this.sortDirection||field.sortDirection;

if(sortDirection===SORT_DIRECTION_ASC){
labelSorting=this.labelSortAsc;
}else if(sortDirection===SORT_DIRECTION_DESC){
labelSorting=this.labelSortDesc;
}
}
}else if(!this.noSortReset){
// Non sortable column
labelSorting=this.localSortBy?this.labelSortClear:'';
}// Return the sr-only sort label or null if no label


return trim(labelSorting)||null;
}}});



var props$23={
stacked:makeProp(PROP_TYPE_BOOLEAN_STRING,false)};
// --- Mixin ---
// @vue/component

var stackedMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$23,
computed:{
isStacked:function isStacked(){
var stacked=this.stacked;// `true` when always stacked, or returns breakpoint specified

return stacked===''?true:stacked;
},
isStackedAlways:function isStackedAlways(){
return this.isStacked===true;
},
stackedTableClasses:function stackedTableClasses(){
var isStackedAlways=this.isStackedAlways;
return _defineProperty({
'b-table-stacked':isStackedAlways},
"b-table-stacked-".concat(this.stacked),!isStackedAlways&&this.isStacked);
}}});



// Includes all main table styling options
// --- Props ---

var props$24={
bordered:makeProp(PROP_TYPE_BOOLEAN,false),
borderless:makeProp(PROP_TYPE_BOOLEAN,false),
captionTop:makeProp(PROP_TYPE_BOOLEAN,false),
dark:makeProp(PROP_TYPE_BOOLEAN,false),
fixed:makeProp(PROP_TYPE_BOOLEAN,false),
hover:makeProp(PROP_TYPE_BOOLEAN,false),
noBorderCollapse:makeProp(PROP_TYPE_BOOLEAN,false),
outlined:makeProp(PROP_TYPE_BOOLEAN,false),
responsive:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
small:makeProp(PROP_TYPE_BOOLEAN,false),
// If a string, it is assumed to be the table `max-height` value
stickyHeader:makeProp(PROP_TYPE_BOOLEAN_STRING,false),
striped:makeProp(PROP_TYPE_BOOLEAN,false),
tableClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
tableVariant:makeProp(PROP_TYPE_STRING)};
// --- Mixin ---
// @vue/component

var tableRendererMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[attrsMixin],
provide:function provide(){
return {
bvTable:this};

},
// Don't place attributes on root element automatically,
// as table could be wrapped in responsive `<div>`
inheritAttrs:false,
props:props$24,
computed:{
// Layout related computed props
isResponsive:function isResponsive(){
var responsive=this.responsive;
return responsive===''?true:responsive;
},
isStickyHeader:function isStickyHeader(){
var stickyHeader=this.stickyHeader;
stickyHeader=stickyHeader===''?true:stickyHeader;
return this.isStacked?false:stickyHeader;
},
wrapperClasses:function wrapperClasses(){
var isResponsive=this.isResponsive;
return [this.isStickyHeader?'b-table-sticky-header':'',isResponsive===true?'table-responsive':isResponsive?"table-responsive-".concat(this.responsive):''].filter(identity);
},
wrapperStyles:function wrapperStyles(){
var isStickyHeader=this.isStickyHeader;
return isStickyHeader&&!isBoolean(isStickyHeader)?{
maxHeight:isStickyHeader}:
{};
},
tableClasses:function tableClasses(){
var hover=this.hover,
tableVariant=this.tableVariant;
hover=this.isTableSimple?hover:hover&&this.computedItems.length>0&&!this.computedBusy;
return [// User supplied classes
this.tableClass,// Styling classes
{
'table-striped':this.striped,
'table-hover':hover,
'table-dark':this.dark,
'table-bordered':this.bordered,
'table-borderless':this.borderless,
'table-sm':this.small,
// The following are b-table custom styles
border:this.outlined,
'b-table-fixed':this.fixed,
'b-table-caption-top':this.captionTop,
'b-table-no-border-collapse':this.noBorderCollapse},
tableVariant?"".concat(this.dark?'bg':'table',"-").concat(tableVariant):'',// Stacked table classes
this.stackedTableClasses,// Selectable classes
this.selectableTableClasses];
},
tableAttrs:function tableAttrs(){
var items=this.computedItems,
filteredItems=this.filteredItems,
fields=this.computedFields,
selectableTableAttrs=this.selectableTableAttrs;
var ariaAttrs=this.isTableSimple?{}:{
'aria-busy':this.computedBusy?'true':'false',
'aria-colcount':toString$1(fields.length),
// Preserve user supplied `aria-describedby`, if provided
'aria-describedby':this.bvAttrs['aria-describedby']||this.$refs.caption?this.captionId:null};

var rowCount=items&&filteredItems&&filteredItems.length>items.length?toString$1(filteredItems.length):null;
return _objectSpread2(_objectSpread2(_objectSpread2({
// We set `aria-rowcount` before merging in `$attrs`,
// in case user has supplied their own
'aria-rowcount':rowCount},
this.bvAttrs),{},{
// Now we can override any `$attrs` here
id:this.safeId(),
role:'table'},
ariaAttrs),selectableTableAttrs);
}},

render:function render(h){
var wrapperClasses=this.wrapperClasses,
renderCaption=this.renderCaption,
renderColgroup=this.renderColgroup,
renderThead=this.renderThead,
renderTbody=this.renderTbody,
renderTfoot=this.renderTfoot;
var $content=[];

if(this.isTableSimple){
$content.push(this.normalizeSlot());
}else {
// Build the `<caption>` (from caption mixin)
$content.push(renderCaption?renderCaption():null);// Build the `<colgroup>`

$content.push(renderColgroup?renderColgroup():null);// Build the `<thead>`

$content.push(renderThead?renderThead():null);// Build the `<tbody>`

$content.push(renderTbody?renderTbody():null);// Build the `<tfoot>`

$content.push(renderTfoot?renderTfoot():null);
}// Assemble `<table>`


var $table=h('table',{
staticClass:'table b-table',
class:this.tableClasses,
attrs:this.tableAttrs,
key:'b-table'},
$content.filter(identity));// Add responsive/sticky wrapper if needed and return table

return wrapperClasses.length>0?h('div',{
class:wrapperClasses,
style:this.wrapperStyles,
key:'wrap'},
[$table]):$table;
}});


var props$25=makePropsConfigurable({
tbodyTransitionHandlers:makeProp(PROP_TYPE_OBJECT),
tbodyTransitionProps:makeProp(PROP_TYPE_OBJECT)},
NAME_TBODY);// --- Main component ---
// TODO:
//   In Bootstrap v5, we won't need "sniffing" as table element variants properly inherit
//   to the child elements, so this can be converted to a functional component
// @vue/component

var BTbody=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TBODY,
mixins:[attrsMixin,listenersMixin,normalizeSlotMixin],
provide:function provide(){
return {
bvTableRowGroup:this};

},
inject:{
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
bvTable:{
default:
/* istanbul ignore next */
function _default(){
return {};
}}},


inheritAttrs:false,
props:props$25,
computed:{
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isTbody:function isTbody(){
return true;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isDark:function isDark(){
return this.bvTable.dark;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isStacked:function isStacked(){
return this.bvTable.isStacked;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isResponsive:function isResponsive(){
return this.bvTable.isResponsive;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
// Sticky headers are only supported in thead
isStickyHeader:function isStickyHeader(){
return false;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
// Needed to handle header background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
hasStickyHeader:function hasStickyHeader(){
return !this.isStacked&&this.bvTable.stickyHeader;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
tableVariant:function tableVariant(){
return this.bvTable.tableVariant;
},
isTransitionGroup:function isTransitionGroup(){
return this.tbodyTransitionProps||this.tbodyTransitionHandlers;
},
tbodyAttrs:function tbodyAttrs(){
return _objectSpread2({
role:'rowgroup'},
this.bvAttrs);
},
tbodyProps:function tbodyProps(){
var tbodyTransitionProps=this.tbodyTransitionProps;
return tbodyTransitionProps?_objectSpread2(_objectSpread2({},tbodyTransitionProps),{},{
tag:'tbody'}):
{};
}},

render:function render(h){
var data={
props:this.tbodyProps,
attrs:this.tbodyAttrs};


if(this.isTransitionGroup){
// We use native listeners if a transition group for any delegated events
data.on=this.tbodyTransitionHandlers||{};
data.nativeOn=this.bvListeners;
}else {
// Otherwise we place any listeners on the tbody element
data.on=this.bvListeners;
}

return h(this.isTransitionGroup?'transition-group':'tbody',data,this.normalizeSlot());
}});


var TABLE_TAG_NAMES=['TD','TH','TR'];// Returns `true` if we should ignore the click/double-click/keypress event
// Avoids having the user need to use `@click.stop` on the form control

var filterEvent=function filterEvent(event){
// Exit early when we don't have a target element
if(!event||!event.target){
/* istanbul ignore next */
return false;
}

var el=event.target;// Exit early when element is disabled or a table element

if(el.disabled||TABLE_TAG_NAMES.indexOf(el.tagName)!==-1){
return false;
}// Ignore the click when it was inside a dropdown menu


if(closest('.dropdown-menu',el)){
return true;
}

var label=el.tagName==='LABEL'?el:closest('label',el);// If the label's form control is not disabled then we don't propagate event
// Modern browsers have `label.control` that references the associated input, but IE 11
// does not have this property on the label element, so we resort to DOM lookups

if(label){
var labelFor=getAttr(label,'for');
var input=labelFor?getById(labelFor):select('input, select, textarea',label);

if(input&&!input.disabled){
return true;
}
}// Otherwise check if the event target matches one of the selectors in the
// event filter (i.e. anchors, non disabled inputs, etc.)
// Return `true` if we should ignore the event


return matches(el,EVENT_FILTER);
};

// Used to filter out click events caused by the mouse up at end of selection
//
// Accepts an element as only argument to test to see if selection overlaps or is
// contained within the element

var textSelectionActive=function textSelectionActive(){
var el=arguments.length>0&&arguments[0]!==undefined?arguments[0]:document;
var sel=getSel();
return sel&&sel.toString().trim()!==''&&sel.containsNode&&isElement(el)?
/* istanbul ignore next */
sel.containsNode(el,true):false;
};

var props$26=makePropsConfigurable(props$1U,NAME_TH);// --- Main component ---
// TODO:
//   In Bootstrap v5, we won't need "sniffing" as table element variants properly inherit
//   to the child elements, so this can be converted to a functional component
// @vue/component

var BTh=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TH,
extends:BTd,
props:props$26,
computed:{
tag:function tag(){
return 'th';
}}});



var props$27={
detailsTdClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
tbodyTrAttr:makeProp(PROP_TYPE_OBJECT_FUNCTION),
tbodyTrClass:makeProp([].concat(_toConsumableArray(PROP_TYPE_ARRAY_OBJECT_STRING),[PROP_TYPE_FUNCTION]))};
// --- Mixin ---
// @vue/component

var tbodyRowMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$27,
methods:{
// Methods for computing classes, attributes and styles for table cells
getTdValues:function getTdValues(item,key,tdValue,defaultValue){
var $parent=this.$parent;

if(tdValue){
var value=get(item,key,'');

if(isFunction(tdValue)){
return tdValue(value,key,item);
}else if(isString(tdValue)&&isFunction($parent[tdValue])){
return $parent[tdValue](value,key,item);
}

return tdValue;
}

return defaultValue;
},
getThValues:function getThValues(item,key,thValue,type,defaultValue){
var $parent=this.$parent;

if(thValue){
var value=get(item,key,'');

if(isFunction(thValue)){
return thValue(value,key,item,type);
}else if(isString(thValue)&&isFunction($parent[thValue])){
return $parent[thValue](value,key,item,type);
}

return thValue;
}

return defaultValue;
},
// Method to get the value for a field
getFormattedValue:function getFormattedValue(item,field){
var key=field.key;
var formatter=this.getFieldFormatter(key);
var value=get(item,key,null);

if(isFunction(formatter)){
value=formatter(value,key,item);
}

return isUndefinedOrNull(value)?'':value;
},
// Factory function methods
toggleDetailsFactory:function toggleDetailsFactory(hasDetailsSlot,item){
var _this=this;

// Returns a function to toggle a row's details slot
return function(){
if(hasDetailsSlot){
_this.$set(item,FIELD_KEY_SHOW_DETAILS,!item[FIELD_KEY_SHOW_DETAILS]);
}
};
},
// Row event handlers
rowHovered:function rowHovered(event){
// `mouseenter` handler (non-bubbling)
// `this.tbodyRowEvtStopped` from tbody mixin
if(!this.tbodyRowEvtStopped(event)){
// `this.emitTbodyRowEvent` from tbody mixin
this.emitTbodyRowEvent(EVENT_NAME_ROW_HOVERED,event);
}
},
rowUnhovered:function rowUnhovered(event){
// `mouseleave` handler (non-bubbling)
// `this.tbodyRowEvtStopped` from tbody mixin
if(!this.tbodyRowEvtStopped(event)){
// `this.emitTbodyRowEvent` from tbody mixin
this.emitTbodyRowEvent(EVENT_NAME_ROW_UNHOVERED,event);
}
},
// Renders a TD or TH for a row's field
renderTbodyRowCell:function renderTbodyRowCell(field,colIndex,item,rowIndex){
var _this2=this;

var isStacked=this.isStacked;
var key=field.key,
label=field.label,
isRowHeader=field.isRowHeader;
var h=this.$createElement;
var hasDetailsSlot=this.hasNormalizedSlot(SLOT_NAME_ROW_DETAILS);
var formatted=this.getFormattedValue(item,field);
var stickyColumn=!isStacked&&(this.isResponsive||this.stickyHeader)&&field.stickyColumn;// We only uses the helper components for sticky columns to
// improve performance of BTable/BTableLite by reducing the
// total number of vue instances created during render

var cellTag=stickyColumn?isRowHeader?BTh:BTd:isRowHeader?'th':'td';
var cellVariant=item[FIELD_KEY_CELL_VARIANT]&&item[FIELD_KEY_CELL_VARIANT][key]?item[FIELD_KEY_CELL_VARIANT][key]:field.variant||null;
var data={
// For the Vue key, we concatenate the column index and
// field key (as field keys could be duplicated)
// TODO: Although we do prevent duplicate field keys...
//   So we could change this to: `row-${rowIndex}-cell-${key}`
class:[field.class?field.class:'',this.getTdValues(item,key,field.tdClass,'')],
props:{},
attrs:_objectSpread2({
'aria-colindex':String(colIndex+1)},
isRowHeader?this.getThValues(item,key,field.thAttr,'row',{}):this.getTdValues(item,key,field.tdAttr,{})),
key:"row-".concat(rowIndex,"-cell-").concat(colIndex,"-").concat(key)};


if(stickyColumn){
// We are using the helper BTd or BTh
data.props={
stackedHeading:isStacked?label:null,
stickyColumn:true,
variant:cellVariant};

}else {
// Using native TD or TH element, so we need to
// add in the attributes and variant class
data.attrs['data-label']=isStacked&&!isUndefinedOrNull(label)?toString$1(label):null;
data.attrs.role=isRowHeader?'rowheader':'cell';
data.attrs.scope=isRowHeader?'row':null;// Add in the variant class

if(cellVariant){
data.class.push("".concat(this.dark?'bg':'table',"-").concat(cellVariant));
}
}

var slotScope={
item:item,
index:rowIndex,
field:field,
unformatted:get(item,key,''),
value:formatted,
toggleDetails:this.toggleDetailsFactory(hasDetailsSlot,item),
detailsShowing:Boolean(item[FIELD_KEY_SHOW_DETAILS])};
// If table supports selectable mode, then add in the following scope
// this.supportsSelectableRows will be undefined if mixin isn't loaded

if(this.supportsSelectableRows){
slotScope.rowSelected=this.isRowSelected(rowIndex);

slotScope.selectRow=function(){
return _this2.selectRow(rowIndex);
};

slotScope.unselectRow=function(){
return _this2.unselectRow(rowIndex);
};
}// The new `v-slot` syntax doesn't like a slot name starting with
// a square bracket and if using in-document HTML templates, the
// v-slot attributes are lower-cased by the browser.
// Switched to round bracket syntax to prevent confusion with
// dynamic slot name syntax.
// We look for slots in this order: `cell(${key})`, `cell(${key.toLowerCase()})`, 'cell()'
// Slot names are now cached by mixin tbody in `this.$_bodyFieldSlotNameCache`
// Will be `null` if no slot (or fallback slot) exists


var slotName=this.$_bodyFieldSlotNameCache[key];
var $childNodes=slotName?this.normalizeSlot(slotName,slotScope):toString$1(formatted);

if(this.isStacked){
// We wrap in a DIV to ensure rendered as a single cell when visually stacked!
$childNodes=[h('div',[$childNodes])];
}// Render either a td or th cell


return h(cellTag,data,[$childNodes]);
},
// Renders an item's row (or rows if details supported)
renderTbodyRow:function renderTbodyRow(item,rowIndex){
var _this3=this;

var fields=this.computedFields,
striped=this.striped,
primaryKey=this.primaryKey,
currentPage=this.currentPage,
perPage=this.perPage,
tbodyTrClass=this.tbodyTrClass,
tbodyTrAttr=this.tbodyTrAttr;
var h=this.$createElement;
var hasDetailsSlot=this.hasNormalizedSlot(SLOT_NAME_ROW_DETAILS);
var rowShowDetails=item[FIELD_KEY_SHOW_DETAILS]&&hasDetailsSlot;
var hasRowClickHandler=this.$listeners[EVENT_NAME_ROW_CLICKED]||this.hasSelectableRowClick;// We can return more than one TR if rowDetails enabled

var $rows=[];// Details ID needed for `aria-details` when details showing
// We set it to `null` when not showing so that attribute
// does not appear on the element

var detailsId=rowShowDetails?this.safeId("_details_".concat(rowIndex,"_")):null;// For each item data field in row

var $tds=fields.map(function(field,colIndex){
return _this3.renderTbodyRowCell(field,colIndex,item,rowIndex);
});// Calculate the row number in the dataset (indexed from 1)

var ariaRowIndex=null;

if(currentPage&&perPage&&perPage>0){
ariaRowIndex=String((currentPage-1)*perPage+rowIndex+1);
}// Create a unique :key to help ensure that sub components are re-rendered rather than
// re-used, which can cause issues. If a primary key is not provided we use the rendered
// rows index within the tbody.
// See: https://github.com/bootstrap-vue/bootstrap-vue/issues/2410


var primaryKeyValue=toString$1(get(item,primaryKey))||null;
var rowKey=primaryKeyValue||toString$1(rowIndex);// If primary key is provided, use it to generate a unique ID on each tbody > tr
// In the format of '{tableId}__row_{primaryKeyValue}'

var rowId=primaryKeyValue?this.safeId("_row_".concat(primaryKeyValue)):null;// Selectable classes and attributes

var selectableClasses=this.selectableRowClasses?this.selectableRowClasses(rowIndex):{};
var selectableAttrs=this.selectableRowAttrs?this.selectableRowAttrs(rowIndex):{};// Additional classes and attributes

var userTrClasses=isFunction(tbodyTrClass)?tbodyTrClass(item,'row'):tbodyTrClass;
var userTrAttrs=isFunction(tbodyTrAttr)?
/* istanbul ignore next */
tbodyTrAttr(item,'row'):tbodyTrAttr;// Add the item row

$rows.push(h(BTr,{
class:[userTrClasses,selectableClasses,rowShowDetails?'b-table-has-details':''],
props:{
variant:item[FIELD_KEY_ROW_VARIANT]||null},

attrs:_objectSpread2(_objectSpread2({
id:rowId},
userTrAttrs),{},{
// Users cannot override the following attributes
tabindex:hasRowClickHandler?'0':null,
'data-pk':primaryKeyValue||null,
'aria-details':detailsId,
'aria-owns':detailsId,
'aria-rowindex':ariaRowIndex},
selectableAttrs),
on:{
// Note: These events are not A11Y friendly!
mouseenter:this.rowHovered,
mouseleave:this.rowUnhovered},

key:"__b-table-row-".concat(rowKey,"__"),
ref:'item-rows',
refInFor:true},
$tds));// Row Details slot

if(rowShowDetails){
var detailsScope={
item:item,
index:rowIndex,
fields:fields,
toggleDetails:this.toggleDetailsFactory(hasDetailsSlot,item)};
// If table supports selectable mode, then add in the following scope
// this.supportsSelectableRows will be undefined if mixin isn't loaded

if(this.supportsSelectableRows){
detailsScope.rowSelected=this.isRowSelected(rowIndex);

detailsScope.selectRow=function(){
return _this3.selectRow(rowIndex);
};

detailsScope.unselectRow=function(){
return _this3.unselectRow(rowIndex);
};
}// Render the details slot in a TD


var $details=h(BTd,{
props:{
colspan:fields.length},

class:this.detailsTdClass},
[this.normalizeSlot(SLOT_NAME_ROW_DETAILS,detailsScope)]);// Add a hidden row to keep table row striping consistent when details showing
// Only added if the table is striped

if(striped){
$rows.push(// We don't use `BTr` here as we don't need the extra functionality
h('tr',{
staticClass:'d-none',
attrs:{
'aria-hidden':'true',
role:'presentation'},

key:"__b-table-details-stripe__".concat(rowKey)}));

}// Add the actual details row


var userDetailsTrClasses=isFunction(this.tbodyTrClass)?
/* istanbul ignore next */
this.tbodyTrClass(item,SLOT_NAME_ROW_DETAILS):this.tbodyTrClass;
var userDetailsTrAttrs=isFunction(this.tbodyTrAttr)?
/* istanbul ignore next */
this.tbodyTrAttr(item,SLOT_NAME_ROW_DETAILS):this.tbodyTrAttr;
$rows.push(h(BTr,{
staticClass:'b-table-details',
class:[userDetailsTrClasses],
props:{
variant:item[FIELD_KEY_ROW_VARIANT]||null},

attrs:_objectSpread2(_objectSpread2({},userDetailsTrAttrs),{},{
// Users cannot override the following attributes
id:detailsId,
tabindex:'-1'}),

key:"__b-table-details__".concat(rowKey)},
[$details]));
}else if(hasDetailsSlot){
// Only add the placeholder if a the table has a row-details slot defined (but not shown)
$rows.push(h());

if(striped){
// Add extra placeholder if table is striped
$rows.push(h());
}
}// Return the row(s)


return $rows;
}}});



var getCellSlotName=function getCellSlotName(value){
return "cell(".concat(value||'',")");
};// --- Props ---


var props$28=sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$25),props$27),{},{
tbodyClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)}));
// --- Mixin ---
// @vue/component

var tbodyMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[tbodyRowMixin],
props:props$28,
beforeDestroy:function beforeDestroy(){
this.$_bodyFieldSlotNameCache=null;
},
methods:{
// Returns all the item TR elements (excludes detail and spacer rows)
// `this.$refs['item-rows']` is an array of item TR components/elements
// Rows should all be `<b-tr>` components, but we map to TR elements
// Also note that `this.$refs['item-rows']` may not always be in document order
getTbodyTrs:function getTbodyTrs(){
var $refs=this.$refs;
var tbody=$refs.tbody?$refs.tbody.$el||$refs.tbody:null;
var trs=($refs['item-rows']||[]).map(function(tr){
return tr.$el||tr;
});
return tbody&&tbody.children&&tbody.children.length>0&&trs&&trs.length>0?from(tbody.children).filter(function(tr){
return arrayIncludes(trs,tr);
}):
/* istanbul ignore next */
[];
},
// Returns index of a particular TBODY item TR
// We set `true` on closest to include self in result
getTbodyTrIndex:function getTbodyTrIndex(el){
/* istanbul ignore next: should not normally happen */
if(!isElement(el)){
return -1;
}

var tr=el.tagName==='TR'?el:closest('tr',el,true);
return tr?this.getTbodyTrs().indexOf(tr):-1;
},
// Emits a row event, with the item object, row index and original event
emitTbodyRowEvent:function emitTbodyRowEvent(type,event){
if(type&&this.hasListener(type)&&event&&event.target){
var rowIndex=this.getTbodyTrIndex(event.target);

if(rowIndex>-1){
// The array of TRs correlate to the `computedItems` array
var item=this.computedItems[rowIndex];
this.$emit(type,item,rowIndex,event);
}
}
},
tbodyRowEvtStopped:function tbodyRowEvtStopped(event){
return this.stopIfBusy&&this.stopIfBusy(event);
},
// Delegated row event handlers
onTbodyRowKeydown:function onTbodyRowKeydown(event){
// Keyboard navigation and row click emulation
var target=event.target,
keyCode=event.keyCode;

if(this.tbodyRowEvtStopped(event)||target.tagName!=='TR'||!isActiveElement(target)||target.tabIndex!==0){
// Early exit if not an item row TR
return;
}

if(arrayIncludes([CODE_ENTER,CODE_SPACE],keyCode)){
// Emulated click for keyboard users, transfer to click handler
stopEvent(event);
this.onTBodyRowClicked(event);
}else if(arrayIncludes([CODE_UP,CODE_DOWN,CODE_HOME,CODE_END],keyCode)){
// Keyboard navigation
var rowIndex=this.getTbodyTrIndex(target);

if(rowIndex>-1){
stopEvent(event);
var trs=this.getTbodyTrs();
var shift=event.shiftKey;

if(keyCode===CODE_HOME||shift&&keyCode===CODE_UP){
// Focus first row
attemptFocus(trs[0]);
}else if(keyCode===CODE_END||shift&&keyCode===CODE_DOWN){
// Focus last row
attemptFocus(trs[trs.length-1]);
}else if(keyCode===CODE_UP&&rowIndex>0){
// Focus previous row
attemptFocus(trs[rowIndex-1]);
}else if(keyCode===CODE_DOWN&&rowIndex<trs.length-1){
// Focus next row
attemptFocus(trs[rowIndex+1]);
}
}
}
},
onTBodyRowClicked:function onTBodyRowClicked(event){
// Don't emit event when the table is busy, the user clicked
// on a non-disabled control or is selecting text
if(this.tbodyRowEvtStopped(event)||filterEvent(event)||textSelectionActive(this.$el)){
return;
}

this.emitTbodyRowEvent(EVENT_NAME_ROW_CLICKED,event);
},
onTbodyRowMiddleMouseRowClicked:function onTbodyRowMiddleMouseRowClicked(event){
if(!this.tbodyRowEvtStopped(event)&&event.which===2){
this.emitTbodyRowEvent(EVENT_NAME_ROW_MIDDLE_CLICKED,event);
}
},
onTbodyRowContextmenu:function onTbodyRowContextmenu(event){
if(!this.tbodyRowEvtStopped(event)){
this.emitTbodyRowEvent(EVENT_NAME_ROW_CONTEXTMENU,event);
}
},
onTbodyRowDblClicked:function onTbodyRowDblClicked(event){
if(!this.tbodyRowEvtStopped(event)&&!filterEvent(event)){
this.emitTbodyRowEvent(EVENT_NAME_ROW_DBLCLICKED,event);
}
},
// Render the tbody element and children
// Note:
//   Row hover handlers are handled by the tbody-row mixin
//   As mouseenter/mouseleave events do not bubble
renderTbody:function renderTbody(){
var _this=this;

var items=this.computedItems,
renderBusy=this.renderBusy,
renderTopRow=this.renderTopRow,
renderEmpty=this.renderEmpty,
renderBottomRow=this.renderBottomRow;
var h=this.$createElement;
var hasRowClickHandler=this.hasListener(EVENT_NAME_ROW_CLICKED)||this.hasSelectableRowClick;// Prepare the tbody rows

var $rows=[];// Add the item data rows or the busy slot

var $busy=renderBusy?renderBusy():null;

if($busy){
// If table is busy and a busy slot, then return only the busy "row" indicator
$rows.push($busy);
}else {
// Table isn't busy, or we don't have a busy slot
// Create a slot cache for improved performance when looking up cell slot names
// Values will be keyed by the field's `key` and will store the slot's name
// Slots could be dynamic (i.e. `v-if`), so we must compute on each render
// Used by tbody-row mixin render helper
var cache={};
var defaultSlotName=getCellSlotName();
defaultSlotName=this.hasNormalizedSlot(defaultSlotName)?defaultSlotName:null;
this.computedFields.forEach(function(field){
var key=field.key;
var slotName=getCellSlotName(key);
var lowercaseSlotName=getCellSlotName(key.toLowerCase());
cache[key]=_this.hasNormalizedSlot(slotName)?slotName:_this.hasNormalizedSlot(lowercaseSlotName)?
/* istanbul ignore next */
lowercaseSlotName:defaultSlotName;
});// Created as a non-reactive property so to not trigger component updates
// Must be a fresh object each render

this.$_bodyFieldSlotNameCache=cache;// Add static top row slot (hidden in visibly stacked mode
// as we can't control `data-label` attr)

$rows.push(renderTopRow?renderTopRow():h());// Render the rows

items.forEach(function(item,rowIndex){
// Render the individual item row (rows if details slot)
$rows.push(_this.renderTbodyRow(item,rowIndex));
});// Empty items / empty filtered row slot (only shows if `items.length < 1`)

$rows.push(renderEmpty?renderEmpty():h());// Static bottom row slot (hidden in visibly stacked mode
// as we can't control `data-label` attr)

$rows.push(renderBottomRow?renderBottomRow():h());
}// Note: these events will only emit if a listener is registered


var handlers={
auxclick:this.onTbodyRowMiddleMouseRowClicked,
// TODO:
//   Perhaps we do want to automatically prevent the
//   default context menu from showing if there is a
//   `row-contextmenu` listener registered
contextmenu:this.onTbodyRowContextmenu,
// The following event(s) is not considered A11Y friendly
dblclick:this.onTbodyRowDblClicked// Hover events (`mouseenter`/`mouseleave`) are handled by `tbody-row` mixin
};
// Add in click/keydown listeners if needed

if(hasRowClickHandler){
handlers.click=this.onTBodyRowClicked;
handlers.keydown=this.onTbodyRowKeydown;
}// Assemble rows into the tbody


var $tbody=h(BTbody,{
class:this.tbodyClass||null,
props:pluckProps(props$25,this.$props),
// BTbody transfers all native event listeners to the root element
// TODO: Only set the handlers if the table is not busy
on:handlers,
ref:'tbody'},
$rows);// Return the assembled tbody

return $tbody;
}}});



var props$29=makePropsConfigurable({
// Supported values: 'lite', 'dark', or null
footVariant:makeProp(PROP_TYPE_STRING)},
NAME_TFOOT);// --- Main component ---
// TODO:
//   In Bootstrap v5, we won't need "sniffing" as table element variants properly inherit
//   to the child elements, so this can be converted to a functional component
// @vue/component

var BTfoot=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TFOOT,
mixins:[attrsMixin,listenersMixin,normalizeSlotMixin],
provide:function provide(){
return {
bvTableRowGroup:this};

},
inject:{
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
bvTable:{
default:
/* istanbul ignore next */
function _default(){
return {};
}}},


inheritAttrs:false,
props:props$29,
computed:{
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isTfoot:function isTfoot(){
return true;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isDark:function isDark(){
return this.bvTable.dark;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isStacked:function isStacked(){
return this.bvTable.isStacked;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isResponsive:function isResponsive(){
return this.bvTable.isResponsive;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
// Sticky headers are only supported in thead
isStickyHeader:function isStickyHeader(){
return false;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
// Needed to handle header background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
hasStickyHeader:function hasStickyHeader(){
return !this.isStacked&&this.bvTable.stickyHeader;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
tableVariant:function tableVariant(){
return this.bvTable.tableVariant;
},
tfootClasses:function tfootClasses(){
return [this.footVariant?"thead-".concat(this.footVariant):null];
},
tfootAttrs:function tfootAttrs(){
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
role:'rowgroup'});

}},

render:function render(h){
return h('tfoot',{
class:this.tfootClasses,
attrs:this.tfootAttrs,
// Pass down any native listeners
on:this.bvListeners},
this.normalizeSlot());
}});


var props$2a={
footClone:makeProp(PROP_TYPE_BOOLEAN,false),
// Any Bootstrap theme variant (or custom)
// Falls back to `headRowVariant`
footRowVariant:makeProp(PROP_TYPE_STRING),
// 'dark', 'light', or `null` (or custom)
footVariant:makeProp(PROP_TYPE_STRING),
tfootClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
tfootTrClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)};
// --- Mixin ---
// @vue/component

var tfootMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$2a,
methods:{
renderTFootCustom:function renderTFootCustom(){
var h=this.$createElement;

if(this.hasNormalizedSlot(SLOT_NAME_CUSTOM_FOOT)){
return h(BTfoot,{
class:this.tfootClass||null,
props:{
footVariant:this.footVariant||this.headVariant||null},

key:'bv-tfoot-custom'},
this.normalizeSlot(SLOT_NAME_CUSTOM_FOOT,{
items:this.computedItems.slice(),
fields:this.computedFields.slice(),
columns:this.computedFields.length}));

}

return h();
},
renderTfoot:function renderTfoot(){
// Passing true to renderThead will make it render a tfoot
return this.footClone?this.renderThead(true):this.renderTFootCustom();
}}});



var props$2b=makePropsConfigurable({
// Also sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
// Supported values: 'lite', 'dark', or `null`
headVariant:makeProp(PROP_TYPE_STRING)},
NAME_THEAD);// --- Main component ---
// TODO:
//   In Bootstrap v5, we won't need "sniffing" as table element variants properly inherit
//   to the child elements, so this can be converted to a functional component
// @vue/component

var BThead=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_THEAD,
mixins:[attrsMixin,listenersMixin,normalizeSlotMixin],
provide:function provide(){
return {
bvTableRowGroup:this};

},
inject:{
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
bvTable:{
default:
/* istanbul ignore next */
function _default(){
return {};
}}},


inheritAttrs:false,
props:props$2b,
computed:{
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isThead:function isThead(){
return true;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isDark:function isDark(){
return this.bvTable.dark;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isStacked:function isStacked(){
return this.bvTable.isStacked;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
isResponsive:function isResponsive(){
return this.bvTable.isResponsive;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
// Needed to handle header background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
// Sticky headers only apply to cells in table `thead`
isStickyHeader:function isStickyHeader(){
return !this.isStacked&&this.bvTable.stickyHeader;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
// Needed to handle header background classes, due to lack of
// background color inheritance with Bootstrap v4 table CSS
hasStickyHeader:function hasStickyHeader(){
return !this.isStacked&&this.bvTable.stickyHeader;
},
// Sniffed by `<b-tr>` / `<b-td>` / `<b-th>`
tableVariant:function tableVariant(){
return this.bvTable.tableVariant;
},
theadClasses:function theadClasses(){
return [this.headVariant?"thead-".concat(this.headVariant):null];
},
theadAttrs:function theadAttrs(){
return _objectSpread2({
role:'rowgroup'},
this.bvAttrs);
}},

render:function render(h){
return h('thead',{
class:this.theadClasses,
attrs:this.theadAttrs,
// Pass down any native listeners
on:this.bvListeners},
this.normalizeSlot());
}});


var getHeadSlotName=function getHeadSlotName(value){
return "head(".concat(value||'',")");
};

var getFootSlotName=function getFootSlotName(value){
return "foot(".concat(value||'',")");
};// --- Props ---


var props$2c={
// Any Bootstrap theme variant (or custom)
headRowVariant:makeProp(PROP_TYPE_STRING),
// 'light', 'dark' or `null` (or custom)
headVariant:makeProp(PROP_TYPE_STRING),
theadClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
theadTrClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)};
// --- Mixin ---
// @vue/component

var theadMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
props:props$2c,
methods:{
fieldClasses:function fieldClasses(field){
// Header field (<th>) classes
return [field.class?field.class:'',field.thClass?field.thClass:''];
},
headClicked:function headClicked(event,field,isFoot){
if(this.stopIfBusy&&this.stopIfBusy(event)){
// If table is busy (via provider) then don't propagate
return;
}else if(filterEvent(event)){
// Clicked on a non-disabled control so ignore
return;
}else if(textSelectionActive(this.$el)){
// User is selecting text, so ignore

/* istanbul ignore next: JSDOM doesn't support getSelection() */
return;
}

stopEvent(event);
this.$emit(EVENT_NAME_HEAD_CLICKED,field.key,field,event,isFoot);
},
renderThead:function renderThead(){
var _this=this;

var isFoot=arguments.length>0&&arguments[0]!==undefined?arguments[0]:false;
var fields=this.computedFields,
isSortable=this.isSortable,
isSelectable=this.isSelectable,
headVariant=this.headVariant,
footVariant=this.footVariant,
headRowVariant=this.headRowVariant,
footRowVariant=this.footRowVariant;
var h=this.$createElement;// In always stacked mode, we don't bother rendering the head/foot
// Or if no field headings (empty table)

if(this.isStackedAlways||fields.length===0){
return h();
}

var hasHeadClickListener=isSortable||this.hasListener(EVENT_NAME_HEAD_CLICKED);// Reference to `selectAllRows` and `clearSelected()`, if table is selectable

var selectAllRows=isSelectable?this.selectAllRows:noop;
var clearSelected=isSelectable?this.clearSelected:noop;// Helper function to generate a field <th> cell

var makeCell=function makeCell(field,colIndex){
var label=field.label,
labelHtml=field.labelHtml,
variant=field.variant,
stickyColumn=field.stickyColumn,
key=field.key;
var ariaLabel=null;

if(!field.label.trim()&&!field.headerTitle){
// In case field's label and title are empty/blank
// We need to add a hint about what the column is about for non-sighted users

/* istanbul ignore next */
ariaLabel=startCase(field.key);
}

var on={};

if(hasHeadClickListener){
on.click=function(event){
_this.headClicked(event,field,isFoot);
};

on.keydown=function(event){
var keyCode=event.keyCode;

if(keyCode===CODE_ENTER||keyCode===CODE_SPACE){
_this.headClicked(event,field,isFoot);
}
};
}

var sortAttrs=isSortable?_this.sortTheadThAttrs(key,field,isFoot):{};
var sortClass=isSortable?_this.sortTheadThClasses(key,field,isFoot):null;
var sortLabel=isSortable?_this.sortTheadThLabel(key,field,isFoot):null;
var data={
class:[_this.fieldClasses(field),sortClass],
props:{
variant:variant,
stickyColumn:stickyColumn},

style:field.thStyle||{},
attrs:_objectSpread2(_objectSpread2({
// We only add a `tabindex` of `0` if there is a head-clicked listener
// and the current field is sortable
tabindex:hasHeadClickListener&&field.sortable?'0':null,
abbr:field.headerAbbr||null,
title:field.headerTitle||null,
'aria-colindex':colIndex+1,
'aria-label':ariaLabel},
_this.getThValues(null,key,field.thAttr,isFoot?'foot':'head',{})),sortAttrs),
on:on,
key:key};
// Handle edge case where in-document templates are used with new
// `v-slot:name` syntax where the browser lower-cases the v-slot's
// name (attributes become lower cased when parsed by the browser)
// We have replaced the square bracket syntax with round brackets
// to prevent confusion with dynamic slot names

var slotNames=[getHeadSlotName(key),getHeadSlotName(key.toLowerCase()),getHeadSlotName()];// Footer will fallback to header slot names

if(isFoot){
slotNames=[getFootSlotName(key),getFootSlotName(key.toLowerCase()),getFootSlotName()].concat(_toConsumableArray(slotNames));
}

var scope={
label:label,
column:key,
field:field,
isFoot:isFoot,
// Add in row select methods
selectAllRows:selectAllRows,
clearSelected:clearSelected};

var $content=_this.normalizeSlot(slotNames,scope)||h('div',{
domProps:htmlOrText(labelHtml,label)});

var $srLabel=sortLabel?h('span',{
staticClass:'sr-only'},
" (".concat(sortLabel,")")):null;// Return the header cell

return h(BTh,data,[$content,$srLabel].filter(identity));
};// Generate the array of <th> cells


var $cells=fields.map(makeCell).filter(identity);// Generate the row(s)

var $trs=[];

if(isFoot){
$trs.push(h(BTr,{
class:this.tfootTrClass,
props:{
variant:isUndefinedOrNull(footRowVariant)?headRowVariant:
/* istanbul ignore next */
footRowVariant}},

$cells));
}else {
var scope={
columns:fields.length,
fields:fields,
// Add in row select methods
selectAllRows:selectAllRows,
clearSelected:clearSelected};

$trs.push(this.normalizeSlot(SLOT_NAME_THEAD_TOP,scope)||h());
$trs.push(h(BTr,{
class:this.theadTrClass,
props:{
variant:headRowVariant}},

$cells));
}

return h(isFoot?BTfoot:BThead,{
class:(isFoot?this.tfootClass:this.theadClass)||null,
props:isFoot?{
footVariant:footVariant||headVariant||null}:
{
headVariant:headVariant||null},

key:isFoot?'bv-tfoot':'bv-thead'},
$trs);
}}});



var props$2d={};// --- Mixin ---
// @vue/component

var topRowMixin=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
methods:{
renderTopRow:function renderTopRow(){
var fields=this.computedFields,
stacked=this.stacked,
tbodyTrClass=this.tbodyTrClass,
tbodyTrAttr=this.tbodyTrAttr;
var h=this.$createElement;// Add static Top Row slot (hidden in visibly stacked mode as we can't control the data-label)
// If in *always* stacked mode, we don't bother rendering the row

if(!this.hasNormalizedSlot(SLOT_NAME_TOP_ROW)||stacked===true||stacked===''){
return h();
}

return h(BTr,{
staticClass:'b-table-top-row',
class:[isFunction(tbodyTrClass)?tbodyTrClass(null,'row-top'):tbodyTrClass],
attrs:isFunction(tbodyTrAttr)?tbodyTrAttr(null,'row-top'):tbodyTrAttr,
key:'b-top-row'},
[this.normalizeSlot(SLOT_NAME_TOP_ROW,{
columns:fields.length,
fields:fields})]);

}}});



var props$2e=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$1T),props$1V),props$1W),props$1X),props$1Y),props$1Z),props$1_),props$1$),props$20),props$21),props$22),props$23),props$24),props$28),props$2a),props$2c),props$2d)),NAME_TABLE);// --- Main component ---
// @vue/component

var BTable=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TABLE,
// Order of mixins is important!
// They are merged from first to last, followed by this component
mixins:[// General mixins
attrsMixin,hasListenerMixin,idMixin,normalizeSlotMixin,// Required table mixins
itemsMixin,tableRendererMixin,stackedMixin,theadMixin,tfootMixin,tbodyMixin,// Table features mixins
stackedMixin,filteringMixin,sortingMixin,paginationMixin$1,captionMixin,colgroupMixin,selectableMixin,emptyMixin,topRowMixin,bottomRowMixin,busyMixin,providerMixin],
props:props$2e// Render function is provided by `tableRendererMixin`
});


var props$2f=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$1W),props$1X),props$1_),props$23),props$24),props$28),props$2a),props$2c)),NAME_TABLE_LITE);// --- Main component ---
// @vue/component

var BTableLite=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TABLE_LITE,
// Order of mixins is important!
// They are merged from first to last, followed by this component
mixins:[// General mixins
attrsMixin,hasListenerMixin,idMixin,normalizeSlotMixin,// Required table mixins
itemsMixin,tableRendererMixin,stackedMixin,theadMixin,tfootMixin,tbodyMixin,// Table features mixins
// These are pretty lightweight, and are useful for lightweight tables
captionMixin,colgroupMixin],
props:props$2f// Render function is provided by `tableRendererMixin`
});


var props$2g=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),props$23),props$24)),NAME_TABLE_SIMPLE);// --- Main component ---
// @vue/component

var BTableSimple=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TABLE_SIMPLE,
// Order of mixins is important!
// They are merged from first to last, followed by this component
mixins:[// General mixins
attrsMixin,hasListenerMixin,idMixin,normalizeSlotMixin,// Required table mixins
tableRendererMixin,// Table features mixins
// Stacked requires extra handling by users via
// the table cell `stacked-heading` prop
stackedMixin],
props:props$2g,
computed:{
isTableSimple:function isTableSimple(){
return true;
}}
// Render function is provided by `tableRendererMixin`
});


var TableLitePlugin=/*#__PURE__*/pluginFactory({
components:{
BTableLite:BTableLite}});


var TableSimplePlugin=/*#__PURE__*/pluginFactory({
components:{
BTableSimple:BTableSimple,
BTbody:BTbody,
BThead:BThead,
BTfoot:BTfoot,
BTr:BTr,
BTd:BTd,
BTh:BTh}});


var TablePlugin=/*#__PURE__*/pluginFactory({
components:{
BTable:BTable},

plugins:{
TableLitePlugin:TableLitePlugin,
TableSimplePlugin:TableSimplePlugin}});



var isPositiveNumber=function isPositiveNumber(value){
return value>0;
};// --- Props ---


var props$2h=makePropsConfigurable({
animation:makeProp(PROP_TYPE_STRING),
columns:makeProp(PROP_TYPE_NUMBER,5,isPositiveNumber),
hideHeader:makeProp(PROP_TYPE_BOOLEAN,false),
rows:makeProp(PROP_TYPE_NUMBER,3,isPositiveNumber),
showFooter:makeProp(PROP_TYPE_BOOLEAN,false),
tableProps:makeProp(PROP_TYPE_OBJECT,{})},
NAME_SKELETON_TABLE);// --- Main component ---
// @vue/component

var BSkeletonTable=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_SKELETON_TABLE,
functional:true,
props:props$2h,
render:function render(h,_ref){
var props=_ref.props;
var animation=props.animation,
columns=props.columns;
var $th=h('th',[h(BSkeleton,{
props:{
animation:animation}})]);


var $thTr=h('tr',createArray(columns,$th));
var $td=h('td',[h(BSkeleton,{
props:{
width:'75%',
animation:animation}})]);


var $tdTr=h('tr',createArray(columns,$td));
var $tbody=h('tbody',createArray(props.rows,$tdTr));
var $thead=!props.hideHeader?h('thead',[$thTr]):h();
var $tfoot=props.showFooter?h('tfoot',[$thTr]):h();
return h(BTableSimple,{
props:_objectSpread2({},props.tableProps)},
[$thead,$tbody,$tfoot]);
}});


var props$2i=makePropsConfigurable({
loading:makeProp(PROP_TYPE_BOOLEAN,false)},
NAME_SKELETON_WRAPPER);// --- Main component ---
// @vue/component

var BSkeletonWrapper=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_SKELETON_WRAPPER,
functional:true,
props:props$2i,
render:function render(h,_ref){
var data=_ref.data,
props=_ref.props,
slots=_ref.slots,
scopedSlots=_ref.scopedSlots;
var $slots=slots();
var $scopedSlots=scopedSlots||{};
var slotScope={};

if(props.loading){
return h('div',Object(vue_functional_data_merge__WEBPACK_IMPORTED_MODULE_1__["mergeData"])(data,{
attrs:{
role:'alert',
'aria-live':'polite',
'aria-busy':true},

staticClass:'b-skeleton-wrapper',
key:'loading'}),
normalizeSlot(SLOT_NAME_LOADING,slotScope,$scopedSlots,$slots));
}

return normalizeSlot(SLOT_NAME_DEFAULT,slotScope,$scopedSlots,$slots);
}});


var SkeletonPlugin=/*#__PURE__*/pluginFactory({
components:{
BSkeleton:BSkeleton,
BSkeletonIcon:BSkeletonIcon,
BSkeletonImg:BSkeletonImg,
BSkeletonTable:BSkeletonTable,
BSkeletonWrapper:BSkeletonWrapper}});



var SpinnerPlugin=/*#__PURE__*/pluginFactory({
components:{
BSpinner:BSpinner}});



var _watch$i;

var _makeModelMixin$j=makeModelMixin('value',{
type:PROP_TYPE_NUMBER}),

modelMixin$i=_makeModelMixin$j.mixin,
modelProps$i=_makeModelMixin$j.props,
MODEL_PROP_NAME$i=_makeModelMixin$j.prop,
MODEL_EVENT_NAME$i=_makeModelMixin$j.event;// --- Helper methods ---
// Filter function to filter out disabled tabs


var notDisabled=function notDisabled(tab){
return !tab.disabled;
};// --- Helper components ---
// @vue/component


var BVTabButton=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TAB_BUTTON_HELPER,
inject:{
bvTabs:{
default:
/* istanbul ignore next */
function _default(){
return {};
}}},


props:{
controls:makeProp(PROP_TYPE_STRING),
id:makeProp(PROP_TYPE_STRING),
noKeyNav:makeProp(PROP_TYPE_BOOLEAN,false),
posInSet:makeProp(PROP_TYPE_NUMBER),
setSize:makeProp(PROP_TYPE_NUMBER),
// Reference to the child <b-tab> instance
tab:makeProp(),
tabIndex:makeProp(PROP_TYPE_NUMBER)},

methods:{
focus:function focus(){
attemptFocus(this.$refs.link);
},
handleEvt:function handleEvt(event){
/* istanbul ignore next */
if(this.tab.disabled){
return;
}

var type=event.type,
keyCode=event.keyCode,
shiftKey=event.shiftKey;

if(type==='click'){
stopEvent(event);
this.$emit(EVENT_NAME_CLICK,event);
}else if(type==='keydown'&&keyCode===CODE_SPACE){
// For ARIA tabs the SPACE key will also trigger a click/select
// Even with keyboard navigation disabled, SPACE should "click" the button
// See: https://github.com/bootstrap-vue/bootstrap-vue/issues/4323
stopEvent(event);
this.$emit(EVENT_NAME_CLICK,event);
}else if(type==='keydown'&&!this.noKeyNav){
// For keyboard navigation
if([CODE_UP,CODE_LEFT,CODE_HOME].indexOf(keyCode)!==-1){
stopEvent(event);

if(shiftKey||keyCode===CODE_HOME){
this.$emit(EVENT_NAME_FIRST,event);
}else {
this.$emit(EVENT_NAME_PREV,event);
}
}else if([CODE_DOWN,CODE_RIGHT,CODE_END].indexOf(keyCode)!==-1){
stopEvent(event);

if(shiftKey||keyCode===CODE_END){
this.$emit(EVENT_NAME_LAST,event);
}else {
this.$emit(EVENT_NAME_NEXT,event);
}
}
}
}},

render:function render(h){
var id=this.id,
tabIndex=this.tabIndex,
setSize=this.setSize,
posInSet=this.posInSet,
controls=this.controls,
handleEvt=this.handleEvt;
var _this$tab=this.tab,
title=_this$tab.title,
localActive=_this$tab.localActive,
disabled=_this$tab.disabled,
titleItemClass=_this$tab.titleItemClass,
titleLinkClass=_this$tab.titleLinkClass,
titleLinkAttributes=_this$tab.titleLinkAttributes;
var $link=h(BLink,{
staticClass:'nav-link',
class:[{
active:localActive&&!disabled,
disabled:disabled},
titleLinkClass,// Apply <b-tabs> `activeNavItemClass` styles when the tab is active
localActive?this.bvTabs.activeNavItemClass:null],
props:{
disabled:disabled},

attrs:_objectSpread2(_objectSpread2({},titleLinkAttributes),{},{
id:id,
role:'tab',
// Roving tab index when keynav enabled
tabindex:tabIndex,
'aria-selected':localActive&&!disabled?'true':'false',
'aria-setsize':setSize,
'aria-posinset':posInSet,
'aria-controls':controls}),

on:{
click:handleEvt,
keydown:handleEvt},

ref:'link'},
[this.tab.normalizeSlot(SLOT_NAME_TITLE)||title]);
return h('li',{
staticClass:'nav-item',
class:[titleItemClass],
attrs:{
role:'presentation'}},

[$link]);
}});
// --- Props ---

var navProps=omit(props$1t,['tabs','isNavBar','cardHeader']);
var props$2j=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$i),navProps),{},{
// Only applied to the currently active `<b-nav-item>`
activeNavItemClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
// Only applied to the currently active `<b-tab>`
// This prop is sniffed by the `<b-tab>` child
activeTabClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
card:makeProp(PROP_TYPE_BOOLEAN,false),
contentClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
// Synonym for 'bottom'
end:makeProp(PROP_TYPE_BOOLEAN,false),
// This prop is sniffed by the `<b-tab>` child
lazy:makeProp(PROP_TYPE_BOOLEAN,false),
navClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
navWrapperClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
noFade:makeProp(PROP_TYPE_BOOLEAN,false),
noKeyNav:makeProp(PROP_TYPE_BOOLEAN,false),
noNavStyle:makeProp(PROP_TYPE_BOOLEAN,false),
tag:makeProp(PROP_TYPE_STRING,'div')})),
NAME_TABS);// --- Main component ---
// @vue/component

var BTabs=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TABS,
mixins:[idMixin,modelMixin$i,normalizeSlotMixin],
provide:function provide(){
return {
bvTabs:this};

},
props:props$2j,
data:function data(){
return {
// Index of current tab
currentTab:toInteger(this[MODEL_PROP_NAME$i],-1),
// Array of direct child `<b-tab>` instances, in DOM order
tabs:[],
// Array of child instances registered (for triggering reactive updates)
registeredTabs:[]};

},
computed:{
fade:function fade(){
// This computed prop is sniffed by the tab child
return !this.noFade;
},
localNavClass:function localNavClass(){
var classes=[];

if(this.card&&this.vertical){
classes.push('card-header','h-100','border-bottom-0','rounded-0');
}

return [].concat(classes,[this.navClass]);
}},

watch:(_watch$i={},_defineProperty(_watch$i,MODEL_PROP_NAME$i,function(newValue,oldValue){
if(newValue!==oldValue){
newValue=toInteger(newValue,-1);
oldValue=toInteger(oldValue,0);
var $tab=this.tabs[newValue];

if($tab&&!$tab.disabled){
this.activateTab($tab);
}else {
// Try next or prev tabs
if(newValue<oldValue){
this.previousTab();
}else {
this.nextTab();
}
}
}
}),_defineProperty(_watch$i,"currentTab",function currentTab(newValue){
var index=-1;// Ensure only one tab is active at most

this.tabs.forEach(function($tab,i){
if(i===newValue&&!$tab.disabled){
$tab.localActive=true;
index=i;
}else {
$tab.localActive=false;
}
});// Update the v-model

this.$emit(MODEL_EVENT_NAME$i,index);
}),_defineProperty(_watch$i,"tabs",function tabs(newValue,oldValue){
var _this=this;

// We use `_uid` instead of `safeId()`, as the later is changed in a `$nextTick()`
// if no explicit ID is provided, causing duplicate emits
if(!looseEqual(newValue.map(function($tab){
return $tab[COMPONENT_UID_KEY];
}),oldValue.map(function($tab){
return $tab[COMPONENT_UID_KEY];
}))){
// In a `$nextTick()` to ensure `currentTab` has been set first
this.$nextTick(function(){
// We emit shallow copies of the new and old arrays of tabs,
// to prevent users from potentially mutating the internal arrays
_this.$emit(EVENT_NAME_CHANGED,newValue.slice(),oldValue.slice());
});
}
}),_defineProperty(_watch$i,"registeredTabs",function registeredTabs(){
this.updateTabs();
}),_watch$i),
created:function created(){
// Create private non-reactive props
this.$_observer=null;
},
mounted:function mounted(){
this.setObserver(true);
},
beforeDestroy:function beforeDestroy(){
this.setObserver(false);// Ensure no references to child instances exist

this.tabs=[];
},
methods:{
registerTab:function registerTab($tab){
if(!arrayIncludes(this.registeredTabs,$tab)){
this.registeredTabs.push($tab);
}
},
unregisterTab:function unregisterTab($tab){
this.registeredTabs=this.registeredTabs.slice().filter(function($t){
return $t!==$tab;
});
},
// DOM observer is needed to detect changes in order of tabs
setObserver:function setObserver(){
var _this2=this;

var on=arguments.length>0&&arguments[0]!==undefined?arguments[0]:true;
this.$_observer&&this.$_observer.disconnect();
this.$_observer=null;

if(on){
/* istanbul ignore next: difficult to test mutation observer in JSDOM */
var handler=function handler(){
_this2.$nextTick(function(){
requestAF(function(){
_this2.updateTabs();
});
});
};// Watch for changes to `<b-tab>` sub components


this.$_observer=observeDom(this.$refs.content,handler,{
childList:true,
subtree:false,
attributes:true,
attributeFilter:['id']});

}
},
getTabs:function getTabs(){
var $tabs=this.registeredTabs.filter(function($tab){
return $tab.$children.filter(function($t){
return $t._isTab;
}).length===0;
});// DOM Order of Tabs

var order=[];
/* istanbul ignore next: too difficult to test */

if(IS_BROWSER&&$tabs.length>0){
// We rely on the DOM when mounted to get the "true" order of the `<b-tab>` children
// `querySelectorAll()` always returns elements in document order, regardless of
// order specified in the selector
var selector=$tabs.map(function($tab){
return "#".concat($tab.safeId());
}).join(', ');
order=selectAll(selector,this.$el).map(function($el){
return $el.id;
}).filter(identity);
}// Stable sort keeps the original order if not found in the `order` array,
// which will be an empty array before mount


return stableSort($tabs,function(a,b){
return order.indexOf(a.safeId())-order.indexOf(b.safeId());
});
},
updateTabs:function updateTabs(){
var $tabs=this.getTabs();// Find last active non-disabled tab in current tabs
// We trust tab state over `currentTab`, in case tabs were added/removed/re-ordered

var tabIndex=$tabs.indexOf($tabs.slice().reverse().find(function($tab){
return $tab.localActive&&!$tab.disabled;
}));// Else try setting to `currentTab`

if(tabIndex<0){
var currentTab=this.currentTab;

if(currentTab>=$tabs.length){
// Handle last tab being removed, so find the last non-disabled tab
tabIndex=$tabs.indexOf($tabs.slice().reverse().find(notDisabled));
}else if($tabs[currentTab]&&!$tabs[currentTab].disabled){
// Current tab is not disabled
tabIndex=currentTab;
}
}// Else find first non-disabled tab in current tabs


if(tabIndex<0){
tabIndex=$tabs.indexOf($tabs.find(notDisabled));
}// Ensure only one tab is active at a time


$tabs.forEach(function($tab,index){
$tab.localActive=index===tabIndex;
});
this.tabs=$tabs;
this.currentTab=tabIndex;
},
// Find a button that controls a tab, given the tab reference
// Returns the button vm instance
getButtonForTab:function getButtonForTab($tab){
return (this.$refs.buttons||[]).find(function($btn){
return $btn.tab===$tab;
});
},
// Force a button to re-render its content, given a `<b-tab>` instance
// Called by `<b-tab>` on `update()`
updateButton:function updateButton($tab){
var $button=this.getButtonForTab($tab);

if($button&&$button.$forceUpdate){
$button.$forceUpdate();
}
},
// Activate a tab given a `<b-tab>` instance
// Also accessed by `<b-tab>`
activateTab:function activateTab($tab){
var currentTab=this.currentTab,
$tabs=this.tabs;
var result=false;

if($tab){
var index=$tabs.indexOf($tab);

if(index!==currentTab&&index>-1&&!$tab.disabled){
var tabEvent=new BvEvent(EVENT_NAME_ACTIVATE_TAB,{
cancelable:true,
vueTarget:this,
componentId:this.safeId()});

this.$emit(tabEvent.type,index,currentTab,tabEvent);

if(!tabEvent.defaultPrevented){
this.currentTab=index;
result=true;
}
}
}// Couldn't set tab, so ensure v-model is up to date

/* istanbul ignore next: should rarely happen */


if(!result&&this[MODEL_PROP_NAME$i]!==currentTab){
this.$emit(MODEL_EVENT_NAME$i,currentTab);
}

return result;
},
// Deactivate a tab given a `<b-tab>` instance
// Accessed by `<b-tab>`
deactivateTab:function deactivateTab($tab){
if($tab){
// Find first non-disabled tab that isn't the one being deactivated
// If no tabs are available, then don't deactivate current tab
return this.activateTab(this.tabs.filter(function($t){
return $t!==$tab;
}).find(notDisabled));
}
/* istanbul ignore next: should never/rarely happen */


return false;
},
// Focus a tab button given its `<b-tab>` instance
focusButton:function focusButton($tab){
var _this3=this;

// Wrap in `$nextTick()` to ensure DOM has completed rendering
this.$nextTick(function(){
attemptFocus(_this3.getButtonForTab($tab));
});
},
// Emit a click event on a specified `<b-tab>` component instance
emitTabClick:function emitTabClick(tab,event){
if(isEvent(event)&&tab&&tab.$emit&&!tab.disabled){
tab.$emit(EVENT_NAME_CLICK,event);
}
},
// Click handler
clickTab:function clickTab($tab,event){
this.activateTab($tab);
this.emitTabClick($tab,event);
},
// Move to first non-disabled tab
firstTab:function firstTab(focus){
var $tab=this.tabs.find(notDisabled);

if(this.activateTab($tab)&&focus){
this.focusButton($tab);
this.emitTabClick($tab,focus);
}
},
// Move to previous non-disabled tab
previousTab:function previousTab(focus){
var currentIndex=mathMax(this.currentTab,0);
var $tab=this.tabs.slice(0,currentIndex).reverse().find(notDisabled);

if(this.activateTab($tab)&&focus){
this.focusButton($tab);
this.emitTabClick($tab,focus);
}
},
// Move to next non-disabled tab
nextTab:function nextTab(focus){
var currentIndex=mathMax(this.currentTab,-1);
var $tab=this.tabs.slice(currentIndex+1).find(notDisabled);

if(this.activateTab($tab)&&focus){
this.focusButton($tab);
this.emitTabClick($tab,focus);
}
},
// Move to last non-disabled tab
lastTab:function lastTab(focus){
var $tab=this.tabs.slice().reverse().find(notDisabled);

if(this.activateTab($tab)&&focus){
this.focusButton($tab);
this.emitTabClick($tab,focus);
}
}},

render:function render(h){
var _this4=this;

var align=this.align,
card=this.card,
end=this.end,
fill=this.fill,
firstTab=this.firstTab,
justified=this.justified,
lastTab=this.lastTab,
nextTab=this.nextTab,
noKeyNav=this.noKeyNav,
noNavStyle=this.noNavStyle,
pills=this.pills,
previousTab=this.previousTab,
small=this.small,
$tabs=this.tabs,
vertical=this.vertical;// Currently active tab

var $activeTab=$tabs.find(function($tab){
return $tab.localActive&&!$tab.disabled;
});// Tab button to allow focusing when no active tab found (keynav only)

var $fallbackTab=$tabs.find(function($tab){
return !$tab.disabled;
});// For each `<b-tab>` found create the tab buttons

var $buttons=$tabs.map(function($tab,index){
var _on;

var safeId=$tab.safeId;// Ensure at least one tab button is focusable when keynav enabled (if possible)

var tabIndex=null;

if(!noKeyNav){
// Buttons are not in tab index unless active, or a fallback tab
tabIndex=-1;

if($tab===$activeTab||!$activeTab&&$tab===$fallbackTab){
// Place tab button in tab sequence
tabIndex=null;
}
}

return h(BVTabButton,{
props:{
controls:safeId?safeId():null,
id:$tab.controlledBy||(safeId?safeId("_BV_tab_button_"):null),
noKeyNav:noKeyNav,
posInSet:index+1,
setSize:$tabs.length,
tab:$tab,
tabIndex:tabIndex},

on:(_on={},_defineProperty(_on,EVENT_NAME_CLICK,function(event){
_this4.clickTab($tab,event);
}),_defineProperty(_on,EVENT_NAME_FIRST,firstTab),_defineProperty(_on,EVENT_NAME_PREV,previousTab),_defineProperty(_on,EVENT_NAME_NEXT,nextTab),_defineProperty(_on,EVENT_NAME_LAST,lastTab),_on),
key:$tab[COMPONENT_UID_KEY]||index,
ref:'buttons',
// Needed to make `this.$refs.buttons` an array
refInFor:true});

});
var $nav=h(BNav,{
class:this.localNavClass,
attrs:{
role:'tablist',
id:this.safeId('_BV_tab_controls_')},

props:{
fill:fill,
justified:justified,
align:align,
tabs:!noNavStyle&&!pills,
pills:!noNavStyle&&pills,
vertical:vertical,
small:small,
cardHeader:card&&!vertical},

ref:'nav'},
[this.normalizeSlot(SLOT_NAME_TABS_START)||h(),$buttons,this.normalizeSlot(SLOT_NAME_TABS_END)||h()]);
$nav=h('div',{
class:[{
'card-header':card&&!vertical&&!end,
'card-footer':card&&!vertical&&end,
'col-auto':vertical},
this.navWrapperClass],
key:'bv-tabs-nav'},
[$nav]);
var $children=this.normalizeSlot()||[];
var $empty=h();

if($children.length===0){
$empty=h('div',{
class:['tab-pane','active',{
'card-body':card}],

key:'bv-empty-tab'},
this.normalizeSlot(SLOT_NAME_EMPTY));
}

var $content=h('div',{
staticClass:'tab-content',
class:[{
col:vertical},
this.contentClass],
attrs:{
id:this.safeId('_BV_tab_container_')},

key:'bv-content',
ref:'content'},
[$children,$empty]);// Render final output

return h(this.tag,{
staticClass:'tabs',
class:{
row:vertical,
'no-gutters':vertical&&card},

attrs:{
id:this.safeId()}},

[end?$content:h(),$nav,end?h():$content]);
}});


var _objectSpread2$3,_watch$j;

var MODEL_PROP_NAME_ACTIVE='active';
var MODEL_EVENT_NAME_ACTIVE=MODEL_EVENT_NAME_PREFIX+MODEL_PROP_NAME_ACTIVE;// --- Props ---

var props$2k=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2({},props$g),{},(_objectSpread2$3={},_defineProperty(_objectSpread2$3,MODEL_PROP_NAME_ACTIVE,makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_objectSpread2$3,"buttonId",makeProp(PROP_TYPE_STRING)),_defineProperty(_objectSpread2$3,"disabled",makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_objectSpread2$3,"lazy",makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_objectSpread2$3,"noBody",makeProp(PROP_TYPE_BOOLEAN,false)),_defineProperty(_objectSpread2$3,"tag",makeProp(PROP_TYPE_STRING,'div')),_defineProperty(_objectSpread2$3,"title",makeProp(PROP_TYPE_STRING)),_defineProperty(_objectSpread2$3,"titleItemClass",makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)),_defineProperty(_objectSpread2$3,"titleLinkAttributes",makeProp(PROP_TYPE_OBJECT)),_defineProperty(_objectSpread2$3,"titleLinkClass",makeProp(PROP_TYPE_ARRAY_OBJECT_STRING)),_objectSpread2$3))),NAME_TAB);// --- Main component ---
// @vue/component

var BTab=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TAB,
mixins:[idMixin,normalizeSlotMixin],
inject:{
bvTabs:{
default:function _default(){
return {};
}}},


props:props$2k,
data:function data(){
return {
localActive:this[MODEL_PROP_NAME_ACTIVE]&&!this.disabled};

},
computed:{
// For parent sniffing of child
_isTab:function _isTab(){
return true;
},
tabClasses:function tabClasses(){
var active=this.localActive,
disabled=this.disabled;
return [{
active:active,
disabled:disabled,
'card-body':this.bvTabs.card&&!this.noBody},
// Apply <b-tabs> `activeTabClass` styles when this tab is active
active?this.bvTabs.activeTabClass:null];
},
controlledBy:function controlledBy(){
return this.buttonId||this.safeId('__BV_tab_button__');
},
computedNoFade:function computedNoFade(){
return !(this.bvTabs.fade||false);
},
computedLazy:function computedLazy(){
return this.bvTabs.lazy||this.lazy;
}},

watch:(_watch$j={},_defineProperty(_watch$j,MODEL_PROP_NAME_ACTIVE,function(newValue,oldValue){
if(newValue!==oldValue){
if(newValue){
// If activated post mount
this.activate();
}else {
/* istanbul ignore next */
if(!this.deactivate()){
// Tab couldn't be deactivated, so we reset the synced active prop
// Deactivation will fail if no other tabs to activate
this.$emit(MODEL_EVENT_NAME_ACTIVE,this.localActive);
}
}
}
}),_defineProperty(_watch$j,"disabled",function disabled(newValue,oldValue){
if(newValue!==oldValue){
var firstTab=this.bvTabs.firstTab;

if(newValue&&this.localActive&&firstTab){
this.localActive=false;
firstTab();
}
}
}),_defineProperty(_watch$j,"localActive",function localActive(newValue){
// Make `active` prop work with `.sync` modifier
this.$emit(MODEL_EVENT_NAME_ACTIVE,newValue);
}),_watch$j),
mounted:function mounted(){
// Inform `<b-tabs>` of our presence
this.registerTab();
},
updated:function updated(){
// Force the tab button content to update (since slots are not reactive)
// Only done if we have a title slot, as the title prop is reactive
var updateButton=this.bvTabs.updateButton;

if(updateButton&&this.hasNormalizedSlot(SLOT_NAME_TITLE)){
updateButton(this);
}
},
beforeDestroy:function beforeDestroy(){
// Inform `<b-tabs>` of our departure
this.unregisterTab();
},
methods:{
// Private methods
registerTab:function registerTab(){
// Inform `<b-tabs>` of our presence
var registerTab=this.bvTabs.registerTab;

if(registerTab){
registerTab(this);
}
},
unregisterTab:function unregisterTab(){
// Inform `<b-tabs>` of our departure
var unregisterTab=this.bvTabs.unregisterTab;

if(unregisterTab){
unregisterTab(this);
}
},
// Public methods
activate:function activate(){
// Not inside a `<b-tabs>` component or tab is disabled
var activateTab=this.bvTabs.activateTab;
return activateTab&&!this.disabled?activateTab(this):false;
},
deactivate:function deactivate(){
// Not inside a `<b-tabs>` component or not active to begin with
var deactivateTab=this.bvTabs.deactivateTab;
return deactivateTab&&this.localActive?deactivateTab(this):false;
}},

render:function render(h){
var localActive=this.localActive;
var $content=h(this.tag,{
staticClass:'tab-pane',
class:this.tabClasses,
directives:[{
name:'show',
value:localActive}],

attrs:{
role:'tabpanel',
id:this.safeId(),
'aria-hidden':localActive?'false':'true',
'aria-labelledby':this.controlledBy||null},

ref:'panel'},
// Render content lazily if requested
[localActive||!this.computedLazy?this.normalizeSlot():h()]);
return h(BVTransition,{
props:{
mode:'out-in',
noFade:this.computedNoFade}},

[$content]);
}});


var TabsPlugin=/*#__PURE__*/pluginFactory({
components:{
BTabs:BTabs,
BTab:BTab}});



var TimePlugin=/*#__PURE__*/pluginFactory({
components:{
BTime:BTime}});



// @vue/component

var DefaultTransition=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
mixins:[normalizeSlotMixin],
data:function data(){
return {
// Transition classes base name
name:'b-toaster'};

},
methods:{
onAfterEnter:function onAfterEnter(el){
var _this=this;

// Work around a Vue.js bug where `*-enter-to` class is not removed
// See: https://github.com/vuejs/vue/pull/7901
// The `*-move` class is also stuck on elements that moved,
// but there are no JavaScript hooks to handle after move
// See: https://github.com/vuejs/vue/pull/7906
requestAF(function(){
removeClass(el,"".concat(_this.name,"-enter-to"));
});
}},

render:function render(h){
return h('transition-group',{
props:{
tag:'div',
name:this.name},

on:{
afterEnter:this.onAfterEnter}},

this.normalizeSlot());
}});
// --- Props ---

var props$2l=makePropsConfigurable({
// Allowed: 'true' or 'false' or `null`
ariaAtomic:makeProp(PROP_TYPE_STRING),
ariaLive:makeProp(PROP_TYPE_STRING),
name:makeProp(PROP_TYPE_STRING,undefined,true),
// Required
// Aria role
role:makeProp(PROP_TYPE_STRING)},
NAME_TOASTER);// --- Main component ---
// @vue/component

var BToaster=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TOASTER,
mixins:[listenOnRootMixin],
props:props$2l,
data:function data(){
return {
// We don't render on SSR or if a an existing target found
doRender:false,
dead:false,
// Toaster names cannot change once created
staticName:this.name};

},
beforeMount:function beforeMount(){
var _this2=this;

var name=this.name;
this.staticName=name;
/* istanbul ignore if */

if(portal_vue__WEBPACK_IMPORTED_MODULE_3__["Wormhole"].hasTarget(name)){
warn("A \"<portal-target>\" with name \"".concat(name,"\" already exists in the document."),NAME_TOASTER);
this.dead=true;
}else {
this.doRender=true;
this.$once(HOOK_EVENT_NAME_BEFORE_DESTROY,function(){
// Let toasts made with `this.$bvToast.toast()` know that this toaster
// is being destroyed and should should also destroy/hide themselves
_this2.emitOnRoot(getRootEventName(NAME_TOASTER,EVENT_NAME_DESTROYED),name);
});
}
},
destroyed:function destroyed(){
// Remove from DOM if needed
var $el=this.$el;
/* istanbul ignore next: difficult to test */

if($el&&$el.parentNode){
$el.parentNode.removeChild($el);
}
},
render:function render(h){
var $toaster=h('div',{
class:['d-none',{
'b-dead-toaster':this.dead}]});



if(this.doRender){
var $target=h(portal_vue__WEBPACK_IMPORTED_MODULE_3__["PortalTarget"],{
staticClass:'b-toaster-slot',
props:{
name:this.staticName,
multiple:true,
tag:'div',
slim:false,
// transition: this.transition || DefaultTransition
transition:DefaultTransition}});


$toaster=h('div',{
staticClass:'b-toaster',
class:[this.staticName],
attrs:{
id:this.staticName,
// Fallback to null to make sure attribute doesn't exist
role:this.role||null,
'aria-live':this.ariaLive,
'aria-atomic':this.ariaAtomic}},

[$target]);
}

return $toaster;
}});


var _watch$k;

var _makeModelMixin$k=makeModelMixin('visible',{
type:PROP_TYPE_BOOLEAN,
defaultValue:false,
event:EVENT_NAME_CHANGE}),

modelMixin$j=_makeModelMixin$k.mixin,
modelProps$j=_makeModelMixin$k.props,
MODEL_PROP_NAME$j=_makeModelMixin$k.prop,
MODEL_EVENT_NAME$j=_makeModelMixin$k.event;

var MIN_DURATION=1000;// --- Props ---

var linkProps$7=pick(props$6,['href','to']);
var props$2m=makePropsConfigurable(sortKeys(_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},props$g),modelProps$j),linkProps$7),{},{
appendToast:makeProp(PROP_TYPE_BOOLEAN,false),
autoHideDelay:makeProp(PROP_TYPE_NUMBER_STRING,5000),
bodyClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
headerClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
// Switches role to 'status' and aria-live to 'polite'
isStatus:makeProp(PROP_TYPE_BOOLEAN,false),
noAutoHide:makeProp(PROP_TYPE_BOOLEAN,false),
noCloseButton:makeProp(PROP_TYPE_BOOLEAN,false),
noFade:makeProp(PROP_TYPE_BOOLEAN,false),
noHoverPause:makeProp(PROP_TYPE_BOOLEAN,false),
solid:makeProp(PROP_TYPE_BOOLEAN,false),
// Render the toast in place, rather than in a portal-target
static:makeProp(PROP_TYPE_BOOLEAN,false),
title:makeProp(PROP_TYPE_STRING),
toastClass:makeProp(PROP_TYPE_ARRAY_OBJECT_STRING),
toaster:makeProp(PROP_TYPE_STRING,'b-toaster-top-right'),
variant:makeProp(PROP_TYPE_STRING)})),
NAME_TOAST);// --- Main component ---
// @vue/component

var BToast=/*#__PURE__*/vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:NAME_TOAST,
mixins:[attrsMixin,idMixin,modelMixin$j,listenOnRootMixin,normalizeSlotMixin,scopedStyleMixin],
inheritAttrs:false,
props:props$2m,
data:function data(){
return {
isMounted:false,
doRender:false,
localShow:false,
isTransitioning:false,
isHiding:false,
order:0,
dismissStarted:0,
resumeDismiss:0};

},
computed:{
toastClasses:function toastClasses(){
var appendToast=this.appendToast,
variant=this.variant;
return _defineProperty({
'b-toast-solid':this.solid,
'b-toast-append':appendToast,
'b-toast-prepend':!appendToast},
"b-toast-".concat(variant),variant);
},
slotScope:function slotScope(){
var hide=this.hide;
return {
hide:hide};

},
computedDuration:function computedDuration(){
// Minimum supported duration is 1 second
return mathMax(toInteger(this.autoHideDelay,0),MIN_DURATION);
},
computedToaster:function computedToaster(){
return String(this.toaster);
},
transitionHandlers:function transitionHandlers(){
return {
beforeEnter:this.onBeforeEnter,
afterEnter:this.onAfterEnter,
beforeLeave:this.onBeforeLeave,
afterLeave:this.onAfterLeave};

},
computedAttrs:function computedAttrs(){
return _objectSpread2(_objectSpread2({},this.bvAttrs),{},{
id:this.safeId(),
tabindex:'0'});

}},

watch:(_watch$k={},_defineProperty(_watch$k,MODEL_PROP_NAME$j,function(newValue){
this[newValue?'show':'hide']();
}),_defineProperty(_watch$k,"localShow",function localShow(newValue){
if(newValue!==this[MODEL_PROP_NAME$j]){
this.$emit(MODEL_EVENT_NAME$j,newValue);
}
}),_defineProperty(_watch$k,"toaster",function toaster(){
// If toaster target changed, make sure toaster exists
this.$nextTick(this.ensureToaster);
}),_defineProperty(_watch$k,"static",function _static(newValue){
// If static changes to true, and the toast is showing,
// ensure the toaster target exists
if(newValue&&this.localShow){
this.ensureToaster();
}
}),_watch$k),
created:function created(){
// Create private non-reactive props
this.$_dismissTimer=null;
},
mounted:function mounted(){
var _this=this;

this.isMounted=true;
this.$nextTick(function(){
if(_this[MODEL_PROP_NAME$j]){
requestAF(function(){
_this.show();
});
}
});// Listen for global $root show events

this.listenOnRoot(getRootActionEventName(NAME_TOAST,EVENT_NAME_SHOW),function(id){
if(id===_this.safeId()){
_this.show();
}
});// Listen for global $root hide events

this.listenOnRoot(getRootActionEventName(NAME_TOAST,EVENT_NAME_HIDE),function(id){
if(!id||id===_this.safeId()){
_this.hide();
}
});// Make sure we hide when toaster is destroyed

/* istanbul ignore next: difficult to test */

this.listenOnRoot(getRootEventName(NAME_TOASTER,EVENT_NAME_DESTROYED),function(toaster){
/* istanbul ignore next */
if(toaster===_this.computedToaster){
_this.hide();
}
});
},
beforeDestroy:function beforeDestroy(){
this.clearDismissTimer();
},
methods:{
show:function show(){
var _this2=this;

if(!this.localShow){
this.ensureToaster();
var showEvt=this.buildEvent(EVENT_NAME_SHOW);
this.emitEvent(showEvt);
this.dismissStarted=this.resumeDismiss=0;
this.order=Date.now()*(this.appendToast?1:-1);
this.isHiding=false;
this.doRender=true;
this.$nextTick(function(){
// We show the toast after we have rendered the portal and b-toast wrapper
// so that screen readers will properly announce the toast
requestAF(function(){
_this2.localShow=true;
});
});
}
},
hide:function hide(){
var _this3=this;

if(this.localShow){
var hideEvt=this.buildEvent(EVENT_NAME_HIDE);
this.emitEvent(hideEvt);
this.setHoverHandler(false);
this.dismissStarted=this.resumeDismiss=0;
this.clearDismissTimer();
this.isHiding=true;
requestAF(function(){
_this3.localShow=false;
});
}
},
buildEvent:function buildEvent(type){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
return new BvEvent(type,_objectSpread2(_objectSpread2({
cancelable:false,
target:this.$el||null,
relatedTarget:null},
options),{},{
vueTarget:this,
componentId:this.safeId()}));

},
emitEvent:function emitEvent(bvEvent){
var type=bvEvent.type;
this.emitOnRoot(getRootEventName(NAME_TOAST,type),bvEvent);
this.$emit(type,bvEvent);
},
ensureToaster:function ensureToaster(){
if(this.static){
return;
}

var computedToaster=this.computedToaster;

if(!portal_vue__WEBPACK_IMPORTED_MODULE_3__["Wormhole"].hasTarget(computedToaster)){
var div=document.createElement('div');
document.body.appendChild(div);
var toaster=new BToaster({
parent:this.$root,
propsData:{
name:computedToaster}});


toaster.$mount(div);
}
},
startDismissTimer:function startDismissTimer(){
this.clearDismissTimer();

if(!this.noAutoHide){
this.$_dismissTimer=setTimeout(this.hide,this.resumeDismiss||this.computedDuration);
this.dismissStarted=Date.now();
this.resumeDismiss=0;
}
},
clearDismissTimer:function clearDismissTimer(){
clearTimeout(this.$_dismissTimer);
this.$_dismissTimer=null;
},
setHoverHandler:function setHoverHandler(on){
var el=this.$refs['b-toast'];
eventOnOff(on,el,'mouseenter',this.onPause,EVENT_OPTIONS_NO_CAPTURE);
eventOnOff(on,el,'mouseleave',this.onUnPause,EVENT_OPTIONS_NO_CAPTURE);
},
onPause:function onPause(){
// Determine time remaining, and then pause timer
if(this.noAutoHide||this.noHoverPause||!this.$_dismissTimer||this.resumeDismiss){
return;
}

var passed=Date.now()-this.dismissStarted;

if(passed>0){
this.clearDismissTimer();
this.resumeDismiss=mathMax(this.computedDuration-passed,MIN_DURATION);
}
},
onUnPause:function onUnPause(){
// Restart timer with max of time remaining or 1 second
if(this.noAutoHide||this.noHoverPause||!this.resumeDismiss){
this.resumeDismiss=this.dismissStarted=0;
return;
}

this.startDismissTimer();
},
onLinkClick:function onLinkClick(){
var _this4=this;

// We delay the close to allow time for the
// browser to process the link click
this.$nextTick(function(){
requestAF(function(){
_this4.hide();
});
});
},
onBeforeEnter:function onBeforeEnter(){
this.isTransitioning=true;
},
onAfterEnter:function onAfterEnter(){
this.isTransitioning=false;
var hiddenEvt=this.buildEvent(EVENT_NAME_SHOWN);
this.emitEvent(hiddenEvt);
this.startDismissTimer();
this.setHoverHandler(true);
},
onBeforeLeave:function onBeforeLeave(){
this.isTransitioning=true;
},
onAfterLeave:function onAfterLeave(){
this.isTransitioning=false;
this.order=0;
this.resumeDismiss=this.dismissStarted=0;
var hiddenEvt=this.buildEvent(EVENT_NAME_HIDDEN);
this.emitEvent(hiddenEvt);
this.doRender=false;
},
// Render helper for generating the toast
makeToast:function makeToast(h){
var _this5=this;

var title=this.title,
slotScope=this.slotScope;
var link=isLink(this);
var $headerContent=[];
var $title=this.normalizeSlot(SLOT_NAME_TOAST_TITLE,slotScope);

if($title){
$headerContent.push($title);
}else if(title){
$headerContent.push(h('strong',{
staticClass:'mr-2'},
title));
}

if(!this.noCloseButton){
$headerContent.push(h(BButtonClose,{
staticClass:'ml-auto mb-1',
on:{
click:function click(){
_this5.hide();
}}}));


}

var $header=h();

if($headerContent.length>0){
$header=h('header',{
staticClass:'toast-header',
class:this.headerClass},
$headerContent);
}

var $body=h(link?BLink:'div',{
staticClass:'toast-body',
class:this.bodyClass,
props:link?pluckProps(linkProps$7,this):{},
on:link?{
click:this.onLinkClick}:
{}},
this.normalizeSlot(SLOT_NAME_DEFAULT,slotScope));
return h('div',{
staticClass:'toast',
class:this.toastClass,
attrs:this.computedAttrs,
key:"toast-".concat(this[COMPONENT_UID_KEY]),
ref:'toast'},
[$header,$body]);
}},

render:function render(h){
if(!this.doRender||!this.isMounted){
return h();
}

var order=this.order,
isStatic=this.static,
isHiding=this.isHiding,
isStatus=this.isStatus;
var name="b-toast-".concat(this[COMPONENT_UID_KEY]);
var $toast=h('div',{
staticClass:'b-toast',
class:this.toastClasses,
attrs:_objectSpread2(_objectSpread2({},isStatic?{}:this.scopedStyleAttrs),{},{
id:this.safeId('_toast_outer'),
role:isHiding?null:isStatus?'status':'alert',
'aria-live':isHiding?null:isStatus?'polite':'assertive',
'aria-atomic':isHiding?null:'true'}),

key:name,
ref:'b-toast'},
[h(BVTransition,{
props:{
noFade:this.noFade},

on:this.transitionHandlers},
[this.localShow?this.makeToast(h):h()])]);
return h(portal_vue__WEBPACK_IMPORTED_MODULE_3__["Portal"],{
props:{
name:name,
to:this.computedToaster,
order:order,
slim:true,
disabled:isStatic}},

[$toast]);
}});


var PROP_NAME$2='$bvToast';
var PROP_NAME_PRIV$1='_bv__toast';// Base toast props that are allowed
// Some may be ignored or overridden on some message boxes
// Prop ID is allowed, but really only should be used for testing
// We need to add it in explicitly as it comes from the `idMixin`

var BASE_PROPS$1=['id'].concat(_toConsumableArray(keys(omit(props$2m,['static','visible']))));// Map prop names to toast slot names

var propsToSlots$1={
toastContent:'default',
title:'toast-title'};
// --- Helper methods ---
// Method to filter only recognized props that are not undefined

var filterOptions$1=function filterOptions(options){
return BASE_PROPS$1.reduce(function(memo,key){
if(!isUndefined(options[key])){
memo[key]=options[key];
}

return memo;
},{});
};// Method to install `$bvToast` VM injection


var plugin$1=function plugin(Vue){
// Create a private sub-component constructor that
// extends BToast and self-destructs after hidden
// @vue/component
var BVToastPop=Vue.extend({
name:NAME_TOAST_POP,
extends:BToast,
destroyed:function destroyed(){
// Make sure we not in document any more
var $el=this.$el;

if($el&&$el.parentNode){
$el.parentNode.removeChild($el);
}
},
mounted:function mounted(){
var _this=this;

// Self destruct handler
var handleDestroy=function handleDestroy(){
// Ensure the toast has been force hidden
_this.localShow=false;
_this.doRender=false;

_this.$nextTick(function(){
_this.$nextTick(function(){
// In a `requestAF()` to release control back to application
// and to allow the portal-target time to remove the content
requestAF(function(){
_this.$destroy();
});
});
});
};// Self destruct if parent destroyed


this.$parent.$once(HOOK_EVENT_NAME_DESTROYED,handleDestroy);// Self destruct after hidden

this.$once(EVENT_NAME_HIDDEN,handleDestroy);// Self destruct when toaster is destroyed

this.listenOnRoot(getRootEventName(NAME_TOASTER,EVENT_NAME_DESTROYED),function(toaster){
/* istanbul ignore next: hard to test */
if(toaster===_this.toaster){
handleDestroy();
}
});
}});
// Private method to generate the on-demand toast

var makeToast=function makeToast(props,$parent){
if(warnNotClient(PROP_NAME$2)){
/* istanbul ignore next */
return;
}// Create an instance of `BVToastPop` component


var toast=new BVToastPop({
// We set parent as the local VM so these toasts can emit events on the
// app `$root`, and it ensures `BToast` is destroyed when parent is destroyed
parent:$parent,
propsData:_objectSpread2(_objectSpread2(_objectSpread2({},filterOptions$1(getComponentConfig(NAME_TOAST))),omit(props,keys(propsToSlots$1))),{},{
// Props that can't be overridden
static:false,
visible:true})});

// Convert certain props to slots

keys(propsToSlots$1).forEach(function(prop){
var value=props[prop];

if(!isUndefined(value)){
// Can be a string, or array of VNodes
if(prop==='title'&&isString(value)){
// Special case for title if it is a string, we wrap in a <strong>
value=[$parent.$createElement('strong',{
class:'mr-2'},
value)];
}

toast.$slots[propsToSlots$1[prop]]=concat(value);
}
});// Create a mount point (a DIV) and mount it (which triggers the show)

var div=document.createElement('div');
document.body.appendChild(div);
toast.$mount(div);
};// Declare BvToast instance property class


var BvToast=/*#__PURE__*/function(){
function BvToast(vm){
_classCallCheck(this,BvToast);

// Assign the new properties to this instance
assign(this,{
_vm:vm,
_root:vm.$root});
// Set these properties as read-only and non-enumerable

defineProperties(this,{
_vm:readonlyDescriptor(),
_root:readonlyDescriptor()});

}// --- Public Instance methods ---
// Opens a user defined toast and returns immediately


_createClass(BvToast,[{
key:"toast",
value:function toast(content){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};

if(!content||warnNotClient(PROP_NAME$2)){
/* istanbul ignore next */
return;
}

makeToast(_objectSpread2(_objectSpread2({},filterOptions$1(options)),{},{
toastContent:content}),
this._vm);
}// shows a `<b-toast>` component with the specified ID
},
{
key:"show",
value:function show(id){
if(id){
this._root.$emit(getRootActionEventName(NAME_TOAST,EVENT_NAME_SHOW),id);
}
}// Hide a toast with specified ID, or if not ID all toasts
},
{
key:"hide",
value:function hide(){
var id=arguments.length>0&&arguments[0]!==undefined?arguments[0]:null;

this._root.$emit(getRootActionEventName(NAME_TOAST,EVENT_NAME_HIDE),id);
}}]);


return BvToast;
}();// Add our instance mixin


Vue.mixin({
beforeCreate:function beforeCreate(){
// Because we need access to `$root` for `$emits`, and VM for parenting,
// we have to create a fresh instance of `BvToast` for each VM
this[PROP_NAME_PRIV$1]=new BvToast(this);
}});
// Define our read-only `$bvToast` instance property
// Placed in an if just in case in HMR mode

if(!hasOwnProperty(Vue.prototype,PROP_NAME$2)){
defineProperty(Vue.prototype,PROP_NAME$2,{
get:function get(){
/* istanbul ignore next */
if(!this||!this[PROP_NAME_PRIV$1]){
warn("\"".concat(PROP_NAME$2,"\" must be accessed from a Vue instance \"this\" context."),NAME_TOAST);
}

return this[PROP_NAME_PRIV$1];
}});

}
};

var BVToastPlugin=/*#__PURE__*/pluginFactory({
plugins:{
plugin:plugin$1}});



var ToastPlugin=/*#__PURE__*/pluginFactory({
components:{
BToast:BToast,
BToaster:BToaster},

// $bvToast injection
plugins:{
BVToastPlugin:BVToastPlugin}});



var BV_TOOLTIP='__BV_Tooltip__';// Default trigger

var DefaultTrigger$1='hover focus';// Valid event triggers

var validTriggers$1={
focus:true,
hover:true,
click:true,
blur:true,
manual:true};
// Directive modifier test regular expressions. Pre-compile for performance

var htmlRE$1=/^html$/i;
var noninteractiveRE=/^noninteractive$/i;
var noFadeRE$1=/^nofade$/i;
var placementRE$1=/^(auto|top(left|right)?|bottom(left|right)?|left(top|bottom)?|right(top|bottom)?)$/i;
var boundaryRE$1=/^(window|viewport|scrollParent)$/i;
var delayRE$1=/^d\d+$/i;
var delayShowRE$1=/^ds\d+$/i;
var delayHideRE$1=/^dh\d+$/i;
var offsetRE$1=/^o-?\d+$/i;
var variantRE$1=/^v-.+$/i;
var spacesRE$1=/\s+/;// Build a Tooltip config based on bindings (if any)
// Arguments and modifiers take precedence over passed value config object

var parseBindings$1=function parseBindings(bindings,vnode)
/* istanbul ignore next: not easy to test */
{
// We start out with a basic config
var config={
title:undefined,
trigger:'',
// Default set below if needed
placement:'top',
fallbackPlacement:'flip',
container:false,
// Default of body
animation:true,
offset:0,
id:null,
html:false,
interactive:true,
disabled:false,
delay:getComponentConfig(NAME_TOOLTIP,'delay',50),
boundary:String(getComponentConfig(NAME_TOOLTIP,'boundary','scrollParent')),
boundaryPadding:toInteger(getComponentConfig(NAME_TOOLTIP,'boundaryPadding',5),0),
variant:getComponentConfig(NAME_TOOLTIP,'variant'),
customClass:getComponentConfig(NAME_TOOLTIP,'customClass')};
// Process `bindings.value`

if(isString(bindings.value)||isNumber(bindings.value)){
// Value is tooltip content (HTML optionally supported)
config.title=bindings.value;
}else if(isFunction(bindings.value)){
// Title generator function
config.title=bindings.value;
}else if(isPlainObject(bindings.value)){
// Value is config object, so merge
config=_objectSpread2(_objectSpread2({},config),bindings.value);
}// If title is not provided, try title attribute


if(isUndefined(config.title)){
// Try attribute
var data=vnode.data||{};
config.title=data.attrs&&!isUndefinedOrNull(data.attrs.title)?data.attrs.title:undefined;
}// Normalize delay


if(!isPlainObject(config.delay)){
config.delay={
show:toInteger(config.delay,0),
hide:toInteger(config.delay,0)};

}// If argument, assume element ID of container element


if(bindings.arg){
// Element ID specified as arg
// We must prepend '#' to become a CSS selector
config.container="#".concat(bindings.arg);
}// Process modifiers


keys(bindings.modifiers).forEach(function(mod){
if(htmlRE$1.test(mod)){
// Title allows HTML
config.html=true;
}else if(noninteractiveRE.test(mod)){
// Noninteractive
config.interactive=false;
}else if(noFadeRE$1.test(mod)){
// No animation
config.animation=false;
}else if(placementRE$1.test(mod)){
// Placement of tooltip
config.placement=mod;
}else if(boundaryRE$1.test(mod)){
// Boundary of tooltip
mod=mod==='scrollparent'?'scrollParent':mod;
config.boundary=mod;
}else if(delayRE$1.test(mod)){
// Delay value
var delay=toInteger(mod.slice(1),0);
config.delay.show=delay;
config.delay.hide=delay;
}else if(delayShowRE$1.test(mod)){
// Delay show value
config.delay.show=toInteger(mod.slice(2),0);
}else if(delayHideRE$1.test(mod)){
// Delay hide value
config.delay.hide=toInteger(mod.slice(2),0);
}else if(offsetRE$1.test(mod)){
// Offset value, negative allowed
config.offset=toInteger(mod.slice(1),0);
}else if(variantRE$1.test(mod)){
// Variant
config.variant=mod.slice(2)||null;
}
});// Special handling of event trigger modifiers trigger is
// a space separated list

var selectedTriggers={};// Parse current config object trigger

concat(config.trigger||'').filter(identity).join(' ').trim().toLowerCase().split(spacesRE$1).forEach(function(trigger){
if(validTriggers$1[trigger]){
selectedTriggers[trigger]=true;
}
});// Parse modifiers for triggers

keys(bindings.modifiers).forEach(function(mod){
mod=mod.toLowerCase();

if(validTriggers$1[mod]){
// If modifier is a valid trigger
selectedTriggers[mod]=true;
}
});// Sanitize triggers

config.trigger=keys(selectedTriggers).join(' ');

if(config.trigger==='blur'){
// Blur by itself is useless, so convert it to 'focus'
config.trigger='focus';
}

if(!config.trigger){
// Use default trigger
config.trigger=DefaultTrigger$1;
}// Return the config


return config;
};// Add/update Tooltip on our element


var applyTooltip=function applyTooltip(el,bindings,vnode){
if(!IS_BROWSER){
/* istanbul ignore next */
return;
}

var config=parseBindings$1(bindings,vnode);

if(!el[BV_TOOLTIP]){
var $parent=vnode.context;
el[BV_TOOLTIP]=new BVTooltip({
parent:$parent,
// Add the parent's scoped style attribute data
_scopeId:getScopeId($parent,undefined)});

el[BV_TOOLTIP].__bv_prev_data__={};
el[BV_TOOLTIP].$on(EVENT_NAME_SHOW,function()
/* istanbul ignore next: for now */
{
// Before showing the tooltip, we update the title if it is a function
if(isFunction(config.title)){
el[BV_TOOLTIP].updateData({
title:config.title(el)});

}
});
}

var data={
title:config.title,
triggers:config.trigger,
placement:config.placement,
fallbackPlacement:config.fallbackPlacement,
variant:config.variant,
customClass:config.customClass,
container:config.container,
boundary:config.boundary,
delay:config.delay,
offset:config.offset,
noFade:!config.animation,
id:config.id,
interactive:config.interactive,
disabled:config.disabled,
html:config.html};

var oldData=el[BV_TOOLTIP].__bv_prev_data__;
el[BV_TOOLTIP].__bv_prev_data__=data;

if(!looseEqual(data,oldData)){
// We only update the instance if data has changed
var newData={
target:el};

keys(data).forEach(function(prop){
// We only pass data properties that have changed
if(data[prop]!==oldData[prop]){
// if title is a function, we execute it here
newData[prop]=prop==='title'&&isFunction(data[prop])?data[prop](el):data[prop];
}
});
el[BV_TOOLTIP].updateData(newData);
}
};// Remove Tooltip on our element


var removeTooltip=function removeTooltip(el){
if(el[BV_TOOLTIP]){
el[BV_TOOLTIP].$destroy();
el[BV_TOOLTIP]=null;
}

delete el[BV_TOOLTIP];
};// Export our directive


var VBTooltip={
bind:function bind(el,bindings,vnode){
applyTooltip(el,bindings,vnode);
},
// We use `componentUpdated` here instead of `update`, as the former
// waits until the containing component and children have finished updating
componentUpdated:function componentUpdated(el,bindings,vnode){
// Performed in a `$nextTick()` to prevent render update loops
vnode.context.$nextTick(function(){
applyTooltip(el,bindings,vnode);
});
},
unbind:function unbind(el){
removeTooltip(el);
}};


var VBTooltipPlugin=/*#__PURE__*/pluginFactory({
directives:{
VBTooltip:VBTooltip}});



var TooltipPlugin=/*#__PURE__*/pluginFactory({
components:{
BTooltip:BTooltip},

plugins:{
VBTooltipPlugin:VBTooltipPlugin}});



var componentsPlugin=/*#__PURE__*/pluginFactory({
plugins:{
AlertPlugin:AlertPlugin,
AspectPlugin:AspectPlugin,
AvatarPlugin:AvatarPlugin,
BadgePlugin:BadgePlugin,
BreadcrumbPlugin:BreadcrumbPlugin,
ButtonPlugin:ButtonPlugin,
ButtonGroupPlugin:ButtonGroupPlugin,
ButtonToolbarPlugin:ButtonToolbarPlugin,
CalendarPlugin:CalendarPlugin,
CardPlugin:CardPlugin,
CarouselPlugin:CarouselPlugin,
CollapsePlugin:CollapsePlugin,
DropdownPlugin:DropdownPlugin,
EmbedPlugin:EmbedPlugin,
FormPlugin:FormPlugin,
FormCheckboxPlugin:FormCheckboxPlugin,
FormDatepickerPlugin:FormDatepickerPlugin,
FormFilePlugin:FormFilePlugin,
FormGroupPlugin:FormGroupPlugin,
FormInputPlugin:FormInputPlugin,
FormRadioPlugin:FormRadioPlugin,
FormRatingPlugin:FormRatingPlugin,
FormSelectPlugin:FormSelectPlugin,
FormSpinbuttonPlugin:FormSpinbuttonPlugin,
FormTagsPlugin:FormTagsPlugin,
FormTextareaPlugin:FormTextareaPlugin,
FormTimepickerPlugin:FormTimepickerPlugin,
ImagePlugin:ImagePlugin,
InputGroupPlugin:InputGroupPlugin,
JumbotronPlugin:JumbotronPlugin,
LayoutPlugin:LayoutPlugin,
LinkPlugin:LinkPlugin,
ListGroupPlugin:ListGroupPlugin,
MediaPlugin:MediaPlugin,
ModalPlugin:ModalPlugin,
NavPlugin:NavPlugin,
NavbarPlugin:NavbarPlugin,
OverlayPlugin:OverlayPlugin,
PaginationPlugin:PaginationPlugin,
PaginationNavPlugin:PaginationNavPlugin,
PopoverPlugin:PopoverPlugin,
ProgressPlugin:ProgressPlugin,
SidebarPlugin:SidebarPlugin,
SkeletonPlugin:SkeletonPlugin,
SpinnerPlugin:SpinnerPlugin,
TablePlugin:TablePlugin,
TabsPlugin:TabsPlugin,
TimePlugin:TimePlugin,
ToastPlugin:ToastPlugin,
TooltipPlugin:TooltipPlugin}});



var VBHoverPlugin=/*#__PURE__*/pluginFactory({
directives:{
VBHover:VBHover}});



var VBModalPlugin=/*#__PURE__*/pluginFactory({
directives:{
VBModal:VBModal}});



/*
 * Constants / Defaults
 */

var NAME$1='v-b-scrollspy';
var CLASS_NAME_DROPDOWN_ITEM='dropdown-item';
var CLASS_NAME_ACTIVE='active';
var SELECTOR_NAV_LIST_GROUP='.nav, .list-group';
var SELECTOR_NAV_LINKS='.nav-link';
var SELECTOR_NAV_ITEMS='.nav-item';
var SELECTOR_LIST_ITEMS='.list-group-item';
var SELECTOR_DROPDOWN='.dropdown, .dropup';
var SELECTOR_DROPDOWN_ITEMS='.dropdown-item';
var SELECTOR_DROPDOWN_TOGGLE='.dropdown-toggle';
var ROOT_EVENT_NAME_ACTIVATE=getRootEventName('BVScrollspy','activate');
var METHOD_OFFSET='offset';
var METHOD_POSITION='position';
var Default={
element:'body',
offset:10,
method:'auto',
throttle:75};

var DefaultType={
element:'(string|element|component)',
offset:'number',
method:'string',
throttle:'number'};
// Transition Events

var TransitionEndEvents$1=['webkitTransitionEnd','transitionend','otransitionend','oTransitionEnd'];
/*
 * Utility Methods
 */
// Better var type detection

var toType$1=function toType(obj)
/* istanbul ignore next: not easy to test */
{
return toString(obj).match(/\s([a-zA-Z]+)/)[1].toLowerCase();
};// Check config properties for expected types

/* istanbul ignore next */


var typeCheckConfig=function typeCheckConfig(componentName,config,configTypes)
/* istanbul ignore next: not easy to test */
{
for(var property in configTypes){
if(hasOwnProperty(configTypes,property)){
var expectedTypes=configTypes[property];
var value=config[property];
var valueType=value&&isElement(value)?'element':toType$1(value);// handle Vue instances

valueType=value&&value._isVue?'component':valueType;

if(!new RegExp(expectedTypes).test(valueType)){
/* istanbul ignore next */
warn("".concat(componentName,": Option \"").concat(property,"\" provided type \"").concat(valueType,"\" but expected type \"").concat(expectedTypes,"\""));
}
}
}
};
/*
 * ------------------------------------------------------------------------
 * Class Definition
 * ------------------------------------------------------------------------
 */

/* istanbul ignore next: not easy to test */


var BVScrollSpy
/* istanbul ignore next: not easy to test */=
/*#__PURE__*/function(){
function BVScrollSpy(element,config,$root){
_classCallCheck(this,BVScrollSpy);

// The element we activate links in
this.$el=element;
this.$scroller=null;
this.$selector=[SELECTOR_NAV_LINKS,SELECTOR_LIST_ITEMS,SELECTOR_DROPDOWN_ITEMS].join(',');
this.$offsets=[];
this.$targets=[];
this.$activeTarget=null;
this.$scrollHeight=0;
this.$resizeTimeout=null;
this.$scrollerObserver=null;
this.$targetsObserver=null;
this.$root=$root||null;
this.$config=null;
this.updateConfig(config);
}

_createClass(BVScrollSpy,[{
key:"updateConfig",
value:function updateConfig(config,$root){
if(this.$scroller){
// Just in case out scroll element has changed
this.unlisten();
this.$scroller=null;
}

var cfg=_objectSpread2(_objectSpread2({},this.constructor.Default),config);

if($root){
this.$root=$root;
}

typeCheckConfig(this.constructor.Name,cfg,this.constructor.DefaultType);
this.$config=cfg;

if(this.$root){
var self=this;
this.$root.$nextTick(function(){
self.listen();
});
}else {
this.listen();
}
}},
{
key:"dispose",
value:function dispose(){
this.unlisten();
clearTimeout(this.$resizeTimeout);
this.$resizeTimeout=null;
this.$el=null;
this.$config=null;
this.$scroller=null;
this.$selector=null;
this.$offsets=null;
this.$targets=null;
this.$activeTarget=null;
this.$scrollHeight=null;
}},
{
key:"listen",
value:function listen(){
var _this=this;

var scroller=this.getScroller();

if(scroller&&scroller.tagName!=='BODY'){
eventOn(scroller,'scroll',this,EVENT_OPTIONS_NO_CAPTURE);
}

eventOn(window,'scroll',this,EVENT_OPTIONS_NO_CAPTURE);
eventOn(window,'resize',this,EVENT_OPTIONS_NO_CAPTURE);
eventOn(window,'orientationchange',this,EVENT_OPTIONS_NO_CAPTURE);
TransitionEndEvents$1.forEach(function(eventName){
eventOn(window,eventName,_this,EVENT_OPTIONS_NO_CAPTURE);
});
this.setObservers(true);// Schedule a refresh

this.handleEvent('refresh');
}},
{
key:"unlisten",
value:function unlisten(){
var _this2=this;

var scroller=this.getScroller();
this.setObservers(false);

if(scroller&&scroller.tagName!=='BODY'){
eventOff(scroller,'scroll',this,EVENT_OPTIONS_NO_CAPTURE);
}

eventOff(window,'scroll',this,EVENT_OPTIONS_NO_CAPTURE);
eventOff(window,'resize',this,EVENT_OPTIONS_NO_CAPTURE);
eventOff(window,'orientationchange',this,EVENT_OPTIONS_NO_CAPTURE);
TransitionEndEvents$1.forEach(function(eventName){
eventOff(window,eventName,_this2,EVENT_OPTIONS_NO_CAPTURE);
});
}},
{
key:"setObservers",
value:function setObservers(on){
var _this3=this;

// We observe both the scroller for content changes, and the target links
this.$scrollerObserver&&this.$scrollerObserver.disconnect();
this.$targetsObserver&&this.$targetsObserver.disconnect();
this.$scrollerObserver=null;
this.$targetsObserver=null;

if(on){
this.$targetsObserver=observeDom(this.$el,function(){
_this3.handleEvent('mutation');
},{
subtree:true,
childList:true,
attributes:true,
attributeFilter:['href']});

this.$scrollerObserver=observeDom(this.getScroller(),function(){
_this3.handleEvent('mutation');
},{
subtree:true,
childList:true,
characterData:true,
attributes:true,
attributeFilter:['id','style','class']});

}
}// General event handler
},
{
key:"handleEvent",
value:function handleEvent(event){
var type=isString(event)?event:event.type;
var self=this;

var resizeThrottle=function resizeThrottle(){
if(!self.$resizeTimeout){
self.$resizeTimeout=setTimeout(function(){
self.refresh();
self.process();
self.$resizeTimeout=null;
},self.$config.throttle);
}
};

if(type==='scroll'){
if(!this.$scrollerObserver){
// Just in case we are added to the DOM before the scroll target is
// We re-instantiate our listeners, just in case
this.listen();
}

this.process();
}else if(/(resize|orientationchange|mutation|refresh)/.test(type)){
// Postpone these events by throttle time
resizeThrottle();
}
}// Refresh the list of target links on the element we are applied to
},
{
key:"refresh",
value:function refresh(){
var _this4=this;

var scroller=this.getScroller();

if(!scroller){
return;
}

var autoMethod=scroller!==scroller.window?METHOD_POSITION:METHOD_OFFSET;
var method=this.$config.method==='auto'?autoMethod:this.$config.method;
var methodFn=method===METHOD_POSITION?position:offset;
var offsetBase=method===METHOD_POSITION?this.getScrollTop():0;
this.$offsets=[];
this.$targets=[];
this.$scrollHeight=this.getScrollHeight();// Find all the unique link HREFs that we will control

selectAll(this.$selector,this.$el)// Get HREF value
.map(function(link){
return getAttr(link,'href');
})// Filter out HREFs that do not match our RegExp
.filter(function(href){
return href&&RX_HREF.test(href||'');
})// Find all elements with ID that match HREF hash
.map(function(href){
// Convert HREF into an ID (including # at beginning)
var id=href.replace(RX_HREF,'$1').trim();

if(!id){
return null;
}// Find the element with the ID specified by id


var el=select(id,scroller);

if(el&&isVisible(el)){
return {
offset:toInteger(methodFn(el).top,0)+offsetBase,
target:id};

}

return null;
}).filter(identity)// Sort them by their offsets (smallest first)
.sort(function(a,b){
return a.offset-b.offset;
})// record only unique targets/offsets
.reduce(function(memo,item){
if(!memo[item.target]){
_this4.$offsets.push(item.offset);

_this4.$targets.push(item.target);

memo[item.target]=true;
}

return memo;
},{});// Return this for easy chaining

return this;
}// Handle activating/clearing
},
{
key:"process",
value:function process(){
var scrollTop=this.getScrollTop()+this.$config.offset;
var scrollHeight=this.getScrollHeight();
var maxScroll=this.$config.offset+scrollHeight-this.getOffsetHeight();

if(this.$scrollHeight!==scrollHeight){
this.refresh();
}

if(scrollTop>=maxScroll){
var target=this.$targets[this.$targets.length-1];

if(this.$activeTarget!==target){
this.activate(target);
}

return;
}

if(this.$activeTarget&&scrollTop<this.$offsets[0]&&this.$offsets[0]>0){
this.$activeTarget=null;
this.clear();
return;
}

for(var i=this.$offsets.length;i--;){
var isActiveTarget=this.$activeTarget!==this.$targets[i]&&scrollTop>=this.$offsets[i]&&(isUndefined(this.$offsets[i+1])||scrollTop<this.$offsets[i+1]);

if(isActiveTarget){
this.activate(this.$targets[i]);
}
}
}},
{
key:"getScroller",
value:function getScroller(){
if(this.$scroller){
return this.$scroller;
}

var scroller=this.$config.element;

if(!scroller){
return null;
}else if(isElement(scroller.$el)){
scroller=scroller.$el;
}else if(isString(scroller)){
scroller=select(scroller);
}

if(!scroller){
return null;
}

this.$scroller=scroller.tagName==='BODY'?window:scroller;
return this.$scroller;
}},
{
key:"getScrollTop",
value:function getScrollTop(){
var scroller=this.getScroller();
return scroller===window?scroller.pageYOffset:scroller.scrollTop;
}},
{
key:"getScrollHeight",
value:function getScrollHeight(){
return this.getScroller().scrollHeight||mathMax(document.body.scrollHeight,document.documentElement.scrollHeight);
}},
{
key:"getOffsetHeight",
value:function getOffsetHeight(){
var scroller=this.getScroller();
return scroller===window?window.innerHeight:getBCR(scroller).height;
}},
{
key:"activate",
value:function activate(target){
var _this5=this;

this.$activeTarget=target;
this.clear();// Grab the list of target links (<a href="{$target}">)

var links=selectAll(this.$selector// Split out the base selectors
.split(',')// Map to a selector that matches links with HREF ending in the ID (including '#')
.map(function(selector){
return "".concat(selector,"[href$=\"").concat(target,"\"]");
})// Join back into a single selector string
.join(','),this.$el);
links.forEach(function(link){
if(hasClass(link,CLASS_NAME_DROPDOWN_ITEM)){
// This is a dropdown item, so find the .dropdown-toggle and set its state
var dropdown=closest(SELECTOR_DROPDOWN,link);

if(dropdown){
_this5.setActiveState(select(SELECTOR_DROPDOWN_TOGGLE,dropdown),true);
}// Also set this link's state


_this5.setActiveState(link,true);
}else {
// Set triggered link as active
_this5.setActiveState(link,true);

if(matches(link.parentElement,SELECTOR_NAV_ITEMS)){
// Handle nav-link inside nav-item, and set nav-item active
_this5.setActiveState(link.parentElement,true);
}// Set triggered links parents as active
// With both <ul> and <nav> markup a parent is the previous sibling of any nav ancestor


var el=link;

while(el){
el=closest(SELECTOR_NAV_LIST_GROUP,el);
var sibling=el?el.previousElementSibling:null;

if(sibling&&matches(sibling,"".concat(SELECTOR_NAV_LINKS,", ").concat(SELECTOR_LIST_ITEMS))){
_this5.setActiveState(sibling,true);
}// Handle special case where nav-link is inside a nav-item


if(sibling&&matches(sibling,SELECTOR_NAV_ITEMS)){
_this5.setActiveState(select(SELECTOR_NAV_LINKS,sibling),true);// Add active state to nav-item as well


_this5.setActiveState(sibling,true);
}
}
}
});// Signal event to via $root, passing ID of activated target and reference to array of links

if(links&&links.length>0&&this.$root){
this.$root.$emit(ROOT_EVENT_NAME_ACTIVATE,target,links);
}
}},
{
key:"clear",
value:function clear(){
var _this6=this;

selectAll("".concat(this.$selector,", ").concat(SELECTOR_NAV_ITEMS),this.$el).filter(function(el){
return hasClass(el,CLASS_NAME_ACTIVE);
}).forEach(function(el){
return _this6.setActiveState(el,false);
});
}},
{
key:"setActiveState",
value:function setActiveState(el,active){
if(!el){
return;
}

if(active){
addClass(el,CLASS_NAME_ACTIVE);
}else {
removeClass(el,CLASS_NAME_ACTIVE);
}
}}],
[{
key:"Name",
get:function get(){
return NAME$1;
}},
{
key:"Default",
get:function get(){
return Default;
}},
{
key:"DefaultType",
get:function get(){
return DefaultType;
}}]);


return BVScrollSpy;
}();

var BV_SCROLLSPY='__BV_ScrollSpy__';// Pre-compiled regular expressions

var onlyDigitsRE=/^\d+$/;
var offsetRE$2=/^(auto|position|offset)$/;// Build a ScrollSpy config based on bindings (if any)
// Arguments and modifiers take precedence over passed value config object

/* istanbul ignore next: not easy to test */

var parseBindings$2=function parseBindings(bindings)
/* istanbul ignore next: not easy to test */
{
var config={};// If argument, assume element ID

if(bindings.arg){
// Element ID specified as arg
// We must prepend '#' to become a CSS selector
config.element="#".concat(bindings.arg);
}// Process modifiers


keys(bindings.modifiers).forEach(function(mod){
if(onlyDigitsRE.test(mod)){
// Offset value
config.offset=toInteger(mod,0);
}else if(offsetRE$2.test(mod)){
// Offset method
config.method=mod;
}
});// Process value

if(isString(bindings.value)){
// Value is a CSS ID or selector
config.element=bindings.value;
}else if(isNumber(bindings.value)){
// Value is offset
config.offset=mathRound(bindings.value);
}else if(isObject(bindings.value)){
// Value is config object
// Filter the object based on our supported config options
keys(bindings.value).filter(function(k){
return !!BVScrollSpy.DefaultType[k];
}).forEach(function(k){
config[k]=bindings.value[k];
});
}

return config;
};// Add or update ScrollSpy on our element


var applyScrollspy=function applyScrollspy(el,bindings,vnode)
/* istanbul ignore next: not easy to test */
{
if(!IS_BROWSER){
/* istanbul ignore next */
return;
}

var config=parseBindings$2(bindings);

if(el[BV_SCROLLSPY]){
el[BV_SCROLLSPY].updateConfig(config,vnode.context.$root);
}else {
el[BV_SCROLLSPY]=new BVScrollSpy(el,config,vnode.context.$root);
}
};// Remove ScrollSpy on our element

/* istanbul ignore next: not easy to test */


var removeScrollspy=function removeScrollspy(el)
/* istanbul ignore next: not easy to test */
{
if(el[BV_SCROLLSPY]){
el[BV_SCROLLSPY].dispose();
el[BV_SCROLLSPY]=null;
delete el[BV_SCROLLSPY];
}
};
/*
 * Export our directive
 */


var VBScrollspy={
/* istanbul ignore next: not easy to test */
bind:function bind(el,bindings,vnode){
applyScrollspy(el,bindings,vnode);
},

/* istanbul ignore next: not easy to test */
inserted:function inserted(el,bindings,vnode){
applyScrollspy(el,bindings,vnode);
},

/* istanbul ignore next: not easy to test */
update:function update(el,bindings,vnode){
if(bindings.value!==bindings.oldValue){
applyScrollspy(el,bindings,vnode);
}
},

/* istanbul ignore next: not easy to test */
componentUpdated:function componentUpdated(el,bindings,vnode){
if(bindings.value!==bindings.oldValue){
applyScrollspy(el,bindings,vnode);
}
},

/* istanbul ignore next: not easy to test */
unbind:function unbind(el){
removeScrollspy(el);
}};


var VBScrollspyPlugin=/*#__PURE__*/pluginFactory({
directives:{
VBScrollspy:VBScrollspy}});



var VBVisiblePlugin=/*#__PURE__*/pluginFactory({
directives:{
VBVisible:VBVisible}});



var directivesPlugin=/*#__PURE__*/pluginFactory({
plugins:{
VBHoverPlugin:VBHoverPlugin,
VBModalPlugin:VBModalPlugin,
VBPopoverPlugin:VBPopoverPlugin,
VBScrollspyPlugin:VBScrollspyPlugin,
VBTogglePlugin:VBTogglePlugin,
VBTooltipPlugin:VBTooltipPlugin,
VBVisiblePlugin:VBVisiblePlugin}});



//
var BVConfigPlugin=/*#__PURE__*/pluginFactory();

var NAME$2='BootstrapVue';// --- BootstrapVue installer ---

var install=/*#__PURE__*/installFactory({
plugins:{
componentsPlugin:componentsPlugin,
directivesPlugin:directivesPlugin}});

// --- BootstrapVue plugin ---

var BootstrapVue=/*#__PURE__*/{
install:install,
NAME:NAME$2};
// --- Named exports for BvConfigPlugin ---

/* harmony default export */__webpack_exports__["default"]=BootstrapVue;



/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../process/browser.js */"./node_modules/process/browser.js"));

/***/},

/***/"./node_modules/css-loader/index.js!./node_modules/bootstrap-vue/dist/bootstrap-vue.css":
/*!*************************************************************************************!*\
  !*** ./node_modules/css-loader!./node_modules/bootstrap-vue/dist/bootstrap-vue.css ***!
  \*************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesBootstrapVueDistBootstrapVueCss(module,exports,__webpack_require__){

exports=module.exports=__webpack_require__(/*! ../../css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,"@charset \"UTF-8\";\n/*!\n * BootstrapVue Custom CSS (https://bootstrap-vue.org)\n */\n.bv-no-focus-ring:focus {\n  outline: none;\n}\n\n@media (max-width: 575.98px) {\n  .bv-d-xs-down-none {\n    display: none !important;\n  }\n}\n@media (max-width: 767.98px) {\n  .bv-d-sm-down-none {\n    display: none !important;\n  }\n}\n@media (max-width: 991.98px) {\n  .bv-d-md-down-none {\n    display: none !important;\n  }\n}\n@media (max-width: 1199.98px) {\n  .bv-d-lg-down-none {\n    display: none !important;\n  }\n}\n.bv-d-xl-down-none {\n  display: none !important;\n}\n\n.form-control.focus {\n  color: #495057;\n  background-color: #fff;\n  border-color: #80bdff;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);\n}\n.form-control.focus.is-valid {\n  border-color: #28a745;\n  box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25);\n}\n.form-control.focus.is-invalid {\n  border-color: #dc3545;\n  box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25);\n}\n\n.b-avatar {\n  display: inline-flex;\n  align-items: center;\n  justify-content: center;\n  vertical-align: middle;\n  flex-shrink: 0;\n  width: 2.5rem;\n  height: 2.5rem;\n  font-size: inherit;\n  font-weight: 400;\n  line-height: 1;\n  max-width: 100%;\n  max-height: auto;\n  text-align: center;\n  overflow: visible;\n  position: relative;\n  transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n.b-avatar:focus {\n  outline: 0;\n}\n.b-avatar.btn, .b-avatar[href] {\n  padding: 0;\n  border: 0;\n}\n.b-avatar.btn .b-avatar-img img, .b-avatar[href] .b-avatar-img img {\n  transition: -webkit-transform 0.15s ease-in-out;\n  transition: transform 0.15s ease-in-out;\n  transition: transform 0.15s ease-in-out, -webkit-transform 0.15s ease-in-out;\n}\n.b-avatar.btn:not(:disabled):not(.disabled), .b-avatar[href]:not(:disabled):not(.disabled) {\n  cursor: pointer;\n}\n.b-avatar.btn:not(:disabled):not(.disabled):hover .b-avatar-img img, .b-avatar[href]:not(:disabled):not(.disabled):hover .b-avatar-img img {\n  -webkit-transform: scale(1.15);\n  transform: scale(1.15);\n}\n.b-avatar.disabled, .b-avatar:disabled, .b-avatar[disabled] {\n  opacity: 0.65;\n  pointer-events: none;\n}\n.b-avatar .b-avatar-custom,\n.b-avatar .b-avatar-text,\n.b-avatar .b-avatar-img {\n  border-radius: inherit;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  -webkit-mask-image: radial-gradient(white, black);\n  mask-image: radial-gradient(white, black);\n}\n.b-avatar .b-avatar-text {\n  text-transform: uppercase;\n  white-space: nowrap;\n}\n.b-avatar[href] {\n  text-decoration: none;\n}\n.b-avatar > .b-icon {\n  width: 60%;\n  height: auto;\n  max-width: 100%;\n}\n.b-avatar .b-avatar-img img {\n  width: 100%;\n  height: 100%;\n  max-height: auto;\n  border-radius: inherit;\n  -o-object-fit: cover;\n  object-fit: cover;\n}\n.b-avatar .b-avatar-badge {\n  position: absolute;\n  min-height: 1.5em;\n  min-width: 1.5em;\n  padding: 0.25em;\n  line-height: 1;\n  border-radius: 10em;\n  font-size: 70%;\n  font-weight: 700;\n  z-index: 1;\n}\n\n.b-avatar-sm {\n  width: 1.5rem;\n  height: 1.5rem;\n}\n.b-avatar-sm .b-avatar-text {\n  font-size: calc(0.6rem);\n}\n.b-avatar-sm .b-avatar-badge {\n  font-size: calc(0.42rem);\n}\n\n.b-avatar-lg {\n  width: 3.5rem;\n  height: 3.5rem;\n}\n.b-avatar-lg .b-avatar-text {\n  font-size: calc(1.4rem);\n}\n.b-avatar-lg .b-avatar-badge {\n  font-size: calc(0.98rem);\n}\n\n.b-avatar-group .b-avatar-group-inner {\n  display: flex;\n  flex-wrap: wrap;\n}\n.b-avatar-group .b-avatar {\n  border: 1px solid #dee2e6;\n}\n.b-avatar-group a.b-avatar:hover:not(.disabled):not(disabled),\n.b-avatar-group .btn.b-avatar:hover:not(.disabled):not(disabled) {\n  z-index: 1;\n}\n\n.b-calendar {\n  display: inline-flex;\n}\n.b-calendar .b-calendar-inner {\n  min-width: 250px;\n}\n.b-calendar .b-calendar-header,\n.b-calendar .b-calendar-nav {\n  margin-bottom: 0.25rem;\n}\n.b-calendar .b-calendar-nav .btn {\n  padding: 0.25rem;\n}\n.b-calendar output {\n  padding: 0.25rem;\n  font-size: 80%;\n}\n.b-calendar output.readonly {\n  background-color: #e9ecef;\n  opacity: 1;\n}\n.b-calendar .b-calendar-footer {\n  margin-top: 0.5rem;\n}\n.b-calendar .b-calendar-grid {\n  padding: 0;\n  margin: 0;\n  overflow: hidden;\n}\n.b-calendar .b-calendar-grid .row {\n  flex-wrap: nowrap;\n}\n.b-calendar .b-calendar-grid-caption {\n  padding: 0.25rem;\n}\n.b-calendar .b-calendar-grid-body .col[data-date] .btn {\n  width: 32px;\n  height: 32px;\n  font-size: 14px;\n  line-height: 1;\n  margin: 3px auto;\n  padding: 9px 0;\n}\n.b-calendar .btn:disabled, .b-calendar .btn.disabled, .b-calendar .btn[aria-disabled=true] {\n  cursor: default;\n  pointer-events: none;\n}\n\n.card-img-left {\n  border-top-left-radius: calc(0.25rem - 1px);\n  border-bottom-left-radius: calc(0.25rem - 1px);\n}\n\n.card-img-right {\n  border-top-right-radius: calc(0.25rem - 1px);\n  border-bottom-right-radius: calc(0.25rem - 1px);\n}\n\n.dropdown:not(.dropleft) .dropdown-toggle.dropdown-toggle-no-caret::after {\n  display: none !important;\n}\n.dropdown.dropleft .dropdown-toggle.dropdown-toggle-no-caret::before {\n  display: none !important;\n}\n.dropdown .dropdown-menu:focus {\n  outline: none;\n}\n\n.b-dropdown-form {\n  display: inline-block;\n  padding: 0.25rem 1.5rem;\n  width: 100%;\n  clear: both;\n  font-weight: 400;\n}\n.b-dropdown-form:focus {\n  outline: 1px dotted !important;\n  outline: 5px auto -webkit-focus-ring-color !important;\n}\n.b-dropdown-form.disabled, .b-dropdown-form:disabled {\n  outline: 0 !important;\n  color: #6c757d;\n  pointer-events: none;\n}\n\n.b-dropdown-text {\n  display: inline-block;\n  padding: 0.25rem 1.5rem;\n  margin-bottom: 0;\n  width: 100%;\n  clear: both;\n  font-weight: lighter;\n}\n\n.custom-checkbox.b-custom-control-lg,\n.input-group-lg .custom-checkbox {\n  font-size: 1.25rem;\n  line-height: 1.5;\n  padding-left: 1.875rem;\n}\n.custom-checkbox.b-custom-control-lg .custom-control-label::before,\n.input-group-lg .custom-checkbox .custom-control-label::before {\n  top: 0.3125rem;\n  left: -1.875rem;\n  width: 1.25rem;\n  height: 1.25rem;\n  border-radius: 0.3rem;\n}\n.custom-checkbox.b-custom-control-lg .custom-control-label::after,\n.input-group-lg .custom-checkbox .custom-control-label::after {\n  top: 0.3125rem;\n  left: -1.875rem;\n  width: 1.25rem;\n  height: 1.25rem;\n  background-size: 50% 50%;\n}\n\n.custom-checkbox.b-custom-control-sm,\n.input-group-sm .custom-checkbox {\n  font-size: 0.875rem;\n  line-height: 1.5;\n  padding-left: 1.3125rem;\n}\n.custom-checkbox.b-custom-control-sm .custom-control-label::before,\n.input-group-sm .custom-checkbox .custom-control-label::before {\n  top: 0.21875rem;\n  left: -1.3125rem;\n  width: 0.875rem;\n  height: 0.875rem;\n  border-radius: 0.2rem;\n}\n.custom-checkbox.b-custom-control-sm .custom-control-label::after,\n.input-group-sm .custom-checkbox .custom-control-label::after {\n  top: 0.21875rem;\n  left: -1.3125rem;\n  width: 0.875rem;\n  height: 0.875rem;\n  background-size: 50% 50%;\n}\n\n.custom-switch.b-custom-control-lg,\n.input-group-lg .custom-switch {\n  padding-left: 2.8125rem;\n}\n.custom-switch.b-custom-control-lg .custom-control-label,\n.input-group-lg .custom-switch .custom-control-label {\n  font-size: 1.25rem;\n  line-height: 1.5;\n}\n.custom-switch.b-custom-control-lg .custom-control-label::before,\n.input-group-lg .custom-switch .custom-control-label::before {\n  top: 0.3125rem;\n  height: 1.25rem;\n  left: -2.8125rem;\n  width: 2.1875rem;\n  border-radius: 0.625rem;\n}\n.custom-switch.b-custom-control-lg .custom-control-label::after,\n.input-group-lg .custom-switch .custom-control-label::after {\n  top: calc( 0.3125rem + 2px );\n  left: calc( -2.8125rem + 2px );\n  width: calc( 1.25rem - 4px );\n  height: calc( 1.25rem - 4px );\n  border-radius: 0.625rem;\n  background-size: 50% 50%;\n}\n.custom-switch.b-custom-control-lg .custom-control-input:checked ~ .custom-control-label::after,\n.input-group-lg .custom-switch .custom-control-input:checked ~ .custom-control-label::after {\n  -webkit-transform: translateX(0.9375rem);\n  transform: translateX(0.9375rem);\n}\n\n.custom-switch.b-custom-control-sm,\n.input-group-sm .custom-switch {\n  padding-left: 1.96875rem;\n}\n.custom-switch.b-custom-control-sm .custom-control-label,\n.input-group-sm .custom-switch .custom-control-label {\n  font-size: 0.875rem;\n  line-height: 1.5;\n}\n.custom-switch.b-custom-control-sm .custom-control-label::before,\n.input-group-sm .custom-switch .custom-control-label::before {\n  top: 0.21875rem;\n  left: -1.96875rem;\n  width: 1.53125rem;\n  height: 0.875rem;\n  border-radius: 0.4375rem;\n}\n.custom-switch.b-custom-control-sm .custom-control-label::after,\n.input-group-sm .custom-switch .custom-control-label::after {\n  top: calc( 0.21875rem + 2px );\n  left: calc( -1.96875rem + 2px );\n  width: calc( 0.875rem - 4px );\n  height: calc( 0.875rem - 4px );\n  border-radius: 0.4375rem;\n  background-size: 50% 50%;\n}\n.custom-switch.b-custom-control-sm .custom-control-input:checked ~ .custom-control-label::after,\n.input-group-sm .custom-switch .custom-control-input:checked ~ .custom-control-label::after {\n  -webkit-transform: translateX(0.65625rem);\n  transform: translateX(0.65625rem);\n}\n\n.input-group > .input-group-prepend > .btn-group > .btn,\n.input-group > .input-group-append:not(:last-child) > .btn-group > .btn,\n.input-group > .input-group-append:last-child > .btn-group:not(:last-child):not(.dropdown-toggle) > .btn {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n.input-group > .input-group-append > .btn-group > .btn,\n.input-group > .input-group-prepend:not(:first-child) > .btn-group > .btn,\n.input-group > .input-group-prepend:first-child > .btn-group:not(:first-child) > .btn {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.b-form-btn-label-control.form-control {\n  display: flex;\n  align-items: stretch;\n  height: auto;\n  padding: 0;\n  background-image: none;\n}\n.input-group .b-form-btn-label-control.form-control {\n  padding: 0;\n}\n\n[dir=rtl] .b-form-btn-label-control.form-control, .b-form-btn-label-control.form-control[dir=rtl] {\n  flex-direction: row-reverse;\n}\n[dir=rtl] .b-form-btn-label-control.form-control > label, .b-form-btn-label-control.form-control[dir=rtl] > label {\n  text-align: right;\n}\n\n.b-form-btn-label-control.form-control > .btn {\n  line-height: 1;\n  font-size: inherit;\n  box-shadow: none !important;\n  border: 0;\n}\n.b-form-btn-label-control.form-control > .btn:disabled {\n  pointer-events: none;\n}\n.b-form-btn-label-control.form-control.is-valid > .btn {\n  color: #28a745;\n}\n.b-form-btn-label-control.form-control.is-invalid > .btn {\n  color: #dc3545;\n}\n.b-form-btn-label-control.form-control > .dropdown-menu {\n  padding: 0.5rem;\n}\n.b-form-btn-label-control.form-control > .form-control {\n  height: auto;\n  min-height: calc(calc(1.5em + 0.75rem + 2px) - 2px);\n  padding-left: 0.25rem;\n  margin: 0;\n  border: 0;\n  outline: 0;\n  background: transparent;\n  word-break: break-word;\n  font-size: inherit;\n  white-space: normal;\n  cursor: pointer;\n}\n.b-form-btn-label-control.form-control > .form-control.form-control-sm {\n  min-height: calc(calc(1.5em + 0.5rem + 2px) - 2px);\n}\n.b-form-btn-label-control.form-control > .form-control.form-control-lg {\n  min-height: calc(calc(1.5em + 1rem + 2px) - 2px);\n}\n.input-group.input-group-sm .b-form-btn-label-control.form-control > .form-control {\n  min-height: calc(calc(1.5em + 0.5rem + 2px) - 2px);\n  padding-top: 0.25rem;\n  padding-bottom: 0.25rem;\n}\n\n.input-group.input-group-lg .b-form-btn-label-control.form-control > .form-control {\n  min-height: calc(calc(1.5em + 1rem + 2px) - 2px);\n  padding-top: 0.5rem;\n  padding-bottom: 0.5rem;\n}\n\n.b-form-btn-label-control.form-control[aria-disabled=true], .b-form-btn-label-control.form-control[aria-readonly=true] {\n  background-color: #e9ecef;\n  opacity: 1;\n}\n.b-form-btn-label-control.form-control[aria-disabled=true] {\n  pointer-events: none;\n}\n.b-form-btn-label-control.form-control[aria-disabled=true] > label {\n  cursor: default;\n}\n\n.b-form-btn-label-control.btn-group > .dropdown-menu {\n  padding: 0.5rem;\n}\n\n.custom-file-label {\n  white-space: nowrap;\n  overflow-x: hidden;\n}\n\n.b-custom-control-lg.custom-file,\n.b-custom-control-lg .custom-file-input,\n.b-custom-control-lg .custom-file-label,\n.input-group-lg.custom-file,\n.input-group-lg .custom-file-input,\n.input-group-lg .custom-file-label {\n  font-size: 1.25rem;\n  height: calc(1.5em + 1rem + 2px);\n}\n.b-custom-control-lg .custom-file-label,\n.b-custom-control-lg .custom-file-label:after,\n.input-group-lg .custom-file-label,\n.input-group-lg .custom-file-label:after {\n  padding: 0.5rem 1rem;\n  line-height: 1.5;\n}\n.b-custom-control-lg .custom-file-label,\n.input-group-lg .custom-file-label {\n  border-radius: 0.3rem;\n}\n.b-custom-control-lg .custom-file-label::after,\n.input-group-lg .custom-file-label::after {\n  font-size: inherit;\n  height: calc( 1.5em + 1rem );\n  border-radius: 0 0.3rem 0.3rem 0;\n}\n\n.b-custom-control-sm.custom-file,\n.b-custom-control-sm .custom-file-input,\n.b-custom-control-sm .custom-file-label,\n.input-group-sm.custom-file,\n.input-group-sm .custom-file-input,\n.input-group-sm .custom-file-label {\n  font-size: 0.875rem;\n  height: calc(1.5em + 0.5rem + 2px);\n}\n.b-custom-control-sm .custom-file-label,\n.b-custom-control-sm .custom-file-label:after,\n.input-group-sm .custom-file-label,\n.input-group-sm .custom-file-label:after {\n  padding: 0.25rem 0.5rem;\n  line-height: 1.5;\n}\n.b-custom-control-sm .custom-file-label,\n.input-group-sm .custom-file-label {\n  border-radius: 0.2rem;\n}\n.b-custom-control-sm .custom-file-label::after,\n.input-group-sm .custom-file-label::after {\n  font-size: inherit;\n  height: calc( 1.5em + 0.5rem );\n  border-radius: 0 0.2rem 0.2rem 0;\n}\n\n.was-validated .form-control:invalid, .was-validated .form-control:valid, .form-control.is-invalid, .form-control.is-valid {\n  background-position: right calc(0.375em + 0.1875rem) center;\n}\n\ninput[type=color].form-control {\n  height: calc(1.5em + 0.75rem + 2px);\n  padding: 0.125rem 0.25rem;\n}\n\ninput[type=color].form-control.form-control-sm,\n.input-group-sm input[type=color].form-control {\n  height: calc(1.5em + 0.5rem + 2px);\n  padding: 0.125rem 0.25rem;\n}\n\ninput[type=color].form-control.form-control-lg,\n.input-group-lg input[type=color].form-control {\n  height: calc(1.5em + 1rem + 2px);\n  padding: 0.125rem 0.25rem;\n}\n\ninput[type=color].form-control:disabled {\n  background-color: #adb5bd;\n  opacity: 0.65;\n}\n\n.input-group > .custom-range {\n  position: relative;\n  flex: 1 1 auto;\n  width: 1%;\n  margin-bottom: 0;\n}\n.input-group > .custom-range + .form-control,\n.input-group > .custom-range + .form-control-plaintext,\n.input-group > .custom-range + .custom-select,\n.input-group > .custom-range + .custom-range,\n.input-group > .custom-range + .custom-file {\n  margin-left: -1px;\n}\n.input-group > .form-control + .custom-range,\n.input-group > .form-control-plaintext + .custom-range,\n.input-group > .custom-select + .custom-range,\n.input-group > .custom-range + .custom-range,\n.input-group > .custom-file + .custom-range {\n  margin-left: -1px;\n}\n.input-group > .custom-range:focus {\n  z-index: 3;\n}\n.input-group > .custom-range:not(:last-child) {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n.input-group > .custom-range:not(:first-child) {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n.input-group > .custom-range {\n  height: calc(1.5em + 0.75rem + 2px);\n  padding: 0 0.75rem;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #ced4da;\n  height: calc(1.5em + 0.75rem + 2px);\n  border-radius: 0.25rem;\n  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n@media (prefers-reduced-motion: reduce) {\n  .input-group > .custom-range {\n    transition: none;\n  }\n}\n.input-group > .custom-range:focus {\n  color: #495057;\n  background-color: #fff;\n  border-color: #80bdff;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);\n}\n.input-group > .custom-range:disabled, .input-group > .custom-range[readonly] {\n  background-color: #e9ecef;\n}\n\n.input-group-lg > .custom-range {\n  height: calc(1.5em + 1rem + 2px);\n  padding: 0 1rem;\n  border-radius: 0.3rem;\n}\n\n.input-group-sm > .custom-range {\n  height: calc(1.5em + 0.5rem + 2px);\n  padding: 0 0.5rem;\n  border-radius: 0.2rem;\n}\n\n.was-validated .input-group .custom-range:valid, .input-group .custom-range.is-valid {\n  border-color: #28a745;\n}\n.was-validated .input-group .custom-range:valid:focus, .input-group .custom-range.is-valid:focus {\n  border-color: #28a745;\n  box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25);\n}\n\n.was-validated .custom-range:valid:focus::-webkit-slider-thumb, .custom-range.is-valid:focus::-webkit-slider-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem #9be7ac;\n}\n.was-validated .custom-range:valid:focus::-moz-range-thumb, .custom-range.is-valid:focus::-moz-range-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem #9be7ac;\n}\n.was-validated .custom-range:valid:focus::-ms-thumb, .custom-range.is-valid:focus::-ms-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem #9be7ac;\n}\n.was-validated .custom-range:valid::-webkit-slider-thumb, .custom-range.is-valid::-webkit-slider-thumb {\n  background-color: #28a745;\n  background-image: none;\n}\n.was-validated .custom-range:valid::-webkit-slider-thumb:active, .custom-range.is-valid::-webkit-slider-thumb:active {\n  background-color: #9be7ac;\n  background-image: none;\n}\n.was-validated .custom-range:valid::-webkit-slider-runnable-track, .custom-range.is-valid::-webkit-slider-runnable-track {\n  background-color: rgba(40, 167, 69, 0.35);\n}\n.was-validated .custom-range:valid::-moz-range-thumb, .custom-range.is-valid::-moz-range-thumb {\n  background-color: #28a745;\n  background-image: none;\n}\n.was-validated .custom-range:valid::-moz-range-thumb:active, .custom-range.is-valid::-moz-range-thumb:active {\n  background-color: #9be7ac;\n  background-image: none;\n}\n.was-validated .custom-range:valid::-moz-range-track, .custom-range.is-valid::-moz-range-track {\n  background: rgba(40, 167, 69, 0.35);\n}\n.was-validated .custom-range:valid ~ .valid-feedback,\n.was-validated .custom-range:valid ~ .valid-tooltip, .custom-range.is-valid ~ .valid-feedback,\n.custom-range.is-valid ~ .valid-tooltip {\n  display: block;\n}\n.was-validated .custom-range:valid::-ms-thumb, .custom-range.is-valid::-ms-thumb {\n  background-color: #28a745;\n  background-image: none;\n}\n.was-validated .custom-range:valid::-ms-thumb:active, .custom-range.is-valid::-ms-thumb:active {\n  background-color: #9be7ac;\n  background-image: none;\n}\n.was-validated .custom-range:valid::-ms-track-lower, .custom-range.is-valid::-ms-track-lower {\n  background: rgba(40, 167, 69, 0.35);\n}\n.was-validated .custom-range:valid::-ms-track-upper, .custom-range.is-valid::-ms-track-upper {\n  background: rgba(40, 167, 69, 0.35);\n}\n\n.was-validated .input-group .custom-range:invalid, .input-group .custom-range.is-invalid {\n  border-color: #dc3545;\n}\n.was-validated .input-group .custom-range:invalid:focus, .input-group .custom-range.is-invalid:focus {\n  border-color: #dc3545;\n  box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25);\n}\n\n.was-validated .custom-range:invalid:focus::-webkit-slider-thumb, .custom-range.is-invalid:focus::-webkit-slider-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem #f6cdd1;\n}\n.was-validated .custom-range:invalid:focus::-moz-range-thumb, .custom-range.is-invalid:focus::-moz-range-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem #f6cdd1;\n}\n.was-validated .custom-range:invalid:focus::-ms-thumb, .custom-range.is-invalid:focus::-ms-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem #f6cdd1;\n}\n.was-validated .custom-range:invalid::-webkit-slider-thumb, .custom-range.is-invalid::-webkit-slider-thumb {\n  background-color: #dc3545;\n  background-image: none;\n}\n.was-validated .custom-range:invalid::-webkit-slider-thumb:active, .custom-range.is-invalid::-webkit-slider-thumb:active {\n  background-color: #f6cdd1;\n  background-image: none;\n}\n.was-validated .custom-range:invalid::-webkit-slider-runnable-track, .custom-range.is-invalid::-webkit-slider-runnable-track {\n  background-color: rgba(220, 53, 69, 0.35);\n}\n.was-validated .custom-range:invalid::-moz-range-thumb, .custom-range.is-invalid::-moz-range-thumb {\n  background-color: #dc3545;\n  background-image: none;\n}\n.was-validated .custom-range:invalid::-moz-range-thumb:active, .custom-range.is-invalid::-moz-range-thumb:active {\n  background-color: #f6cdd1;\n  background-image: none;\n}\n.was-validated .custom-range:invalid::-moz-range-track, .custom-range.is-invalid::-moz-range-track {\n  background: rgba(220, 53, 69, 0.35);\n}\n.was-validated .custom-range:invalid ~ .invalid-feedback,\n.was-validated .custom-range:invalid ~ .invalid-tooltip, .custom-range.is-invalid ~ .invalid-feedback,\n.custom-range.is-invalid ~ .invalid-tooltip {\n  display: block;\n}\n.was-validated .custom-range:invalid::-ms-thumb, .custom-range.is-invalid::-ms-thumb {\n  background-color: #dc3545;\n  background-image: none;\n}\n.was-validated .custom-range:invalid::-ms-thumb:active, .custom-range.is-invalid::-ms-thumb:active {\n  background-color: #f6cdd1;\n  background-image: none;\n}\n.was-validated .custom-range:invalid::-ms-track-lower, .custom-range.is-invalid::-ms-track-lower {\n  background: rgba(220, 53, 69, 0.35);\n}\n.was-validated .custom-range:invalid::-ms-track-upper, .custom-range.is-invalid::-ms-track-upper {\n  background: rgba(220, 53, 69, 0.35);\n}\n\n.custom-radio.b-custom-control-lg,\n.input-group-lg .custom-radio {\n  font-size: 1.25rem;\n  line-height: 1.5;\n  padding-left: 1.875rem;\n}\n.custom-radio.b-custom-control-lg .custom-control-label::before,\n.input-group-lg .custom-radio .custom-control-label::before {\n  top: 0.3125rem;\n  left: -1.875rem;\n  width: 1.25rem;\n  height: 1.25rem;\n  border-radius: 50%;\n}\n.custom-radio.b-custom-control-lg .custom-control-label::after,\n.input-group-lg .custom-radio .custom-control-label::after {\n  top: 0.3125rem;\n  left: -1.875rem;\n  width: 1.25rem;\n  height: 1.25rem;\n  background: no-repeat 50%/50% 50%;\n}\n\n.custom-radio.b-custom-control-sm,\n.input-group-sm .custom-radio {\n  font-size: 0.875rem;\n  line-height: 1.5;\n  padding-left: 1.3125rem;\n}\n.custom-radio.b-custom-control-sm .custom-control-label::before,\n.input-group-sm .custom-radio .custom-control-label::before {\n  top: 0.21875rem;\n  left: -1.3125rem;\n  width: 0.875rem;\n  height: 0.875rem;\n  border-radius: 50%;\n}\n.custom-radio.b-custom-control-sm .custom-control-label::after,\n.input-group-sm .custom-radio .custom-control-label::after {\n  top: 0.21875rem;\n  left: -1.3125rem;\n  width: 0.875rem;\n  height: 0.875rem;\n  background: no-repeat 50%/50% 50%;\n}\n\n.b-rating {\n  text-align: center;\n}\n.b-rating.d-inline-flex {\n  width: auto;\n}\n.b-rating .b-rating-star,\n.b-rating .b-rating-value {\n  padding: 0 0.25em;\n}\n.b-rating .b-rating-value {\n  min-width: 2.5em;\n}\n.b-rating .b-rating-star {\n  display: inline-flex;\n  justify-content: center;\n  outline: 0;\n}\n.b-rating .b-rating-star .b-rating-icon {\n  display: inline-flex;\n  transition: all 0.15s ease-in-out;\n}\n.b-rating.disabled, .b-rating:disabled {\n  background-color: #e9ecef;\n  color: #6c757d;\n}\n.b-rating:not(.disabled):not(.readonly) .b-rating-star {\n  cursor: pointer;\n}\n.b-rating:not(.disabled):not(.readonly):focus:not(:hover) .b-rating-star.focused .b-rating-icon,\n.b-rating:not(.disabled):not(.readonly) .b-rating-star:hover .b-rating-icon {\n  -webkit-transform: scale(1.5);\n  transform: scale(1.5);\n}\n.b-rating[dir=rtl] .b-rating-star-half {\n  -webkit-transform: scale(-1, 1);\n  transform: scale(-1, 1);\n}\n\n.b-form-spinbutton {\n  text-align: center;\n  overflow: hidden;\n  background-image: none;\n  padding: 0;\n}\n[dir=rtl] .b-form-spinbutton:not(.flex-column), .b-form-spinbutton[dir=rtl]:not(.flex-column) {\n  flex-direction: row-reverse;\n}\n\n.b-form-spinbutton output {\n  font-size: inherit;\n  outline: 0;\n  border: 0;\n  background-color: transparent;\n  width: auto;\n  margin: 0;\n  padding: 0 0.25rem;\n}\n.b-form-spinbutton output > div,\n.b-form-spinbutton output > bdi {\n  display: block;\n  min-width: 2.25em;\n  height: 1.5em;\n}\n.b-form-spinbutton.flex-column {\n  height: auto;\n  width: auto;\n}\n.b-form-spinbutton.flex-column output {\n  margin: 0 0.25rem;\n  padding: 0.25rem 0;\n}\n.b-form-spinbutton:not(.d-inline-flex):not(.flex-column) {\n  output-width: 100%;\n}\n.b-form-spinbutton.d-inline-flex:not(.flex-column) {\n  width: auto;\n}\n.b-form-spinbutton .btn {\n  line-height: 1;\n  box-shadow: none !important;\n}\n.b-form-spinbutton .btn:disabled {\n  pointer-events: none;\n}\n.b-form-spinbutton .btn:hover:not(:disabled) > div > .b-icon {\n  -webkit-transform: scale(1.25);\n  transform: scale(1.25);\n}\n.b-form-spinbutton.disabled, .b-form-spinbutton.readonly {\n  background-color: #e9ecef;\n}\n.b-form-spinbutton.disabled {\n  pointer-events: none;\n}\n\n.b-form-tags .b-form-tags-list {\n  margin-top: -0.25rem;\n}\n.b-form-tags .b-form-tags-list .b-from-tags-field,\n.b-form-tags .b-form-tags-list .b-form-tag {\n  margin-top: 0.25rem;\n}\n.b-form-tags.focus {\n  color: #495057;\n  background-color: #fff;\n  border-color: #80bdff;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);\n}\n.b-form-tags.focus.is-valid {\n  border-color: #28a745;\n  box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25);\n}\n.b-form-tags.focus.is-invalid {\n  border-color: #dc3545;\n  box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25);\n}\n.b-form-tags.disabled {\n  background-color: #e9ecef;\n}\n\n.b-form-tag {\n  font-size: 75%;\n  font-weight: normal;\n  line-height: 1.5;\n  margin-right: 0.25rem;\n}\n.b-form-tag.disabled {\n  opacity: 0.75;\n}\n.b-form-tag > button.b-form-tag-remove {\n  color: inherit;\n  font-size: 125%;\n  line-height: 1;\n  float: none;\n  margin-left: 0.25rem;\n}\n\n.form-control-sm .b-form-tag {\n  line-height: 1.5;\n}\n\n.form-control-lg .b-form-tag {\n  line-height: 1.5;\n}\n\n.media-aside {\n  display: flex;\n  margin-right: 1rem;\n}\n\n.media-aside-right {\n  margin-right: 0;\n  margin-left: 1rem;\n}\n\n.modal-backdrop {\n  opacity: 0.5;\n}\n\n.b-pagination-pills .page-item .page-link {\n  border-radius: 50rem !important;\n  margin-left: 0.25rem;\n  line-height: 1;\n}\n.b-pagination-pills .page-item:first-child .page-link {\n  margin-left: 0;\n}\n\n.popover.b-popover {\n  display: block;\n  opacity: 1;\n  outline: 0;\n}\n.popover.b-popover.fade:not(.show) {\n  opacity: 0;\n}\n.popover.b-popover.show {\n  opacity: 1;\n}\n\n.b-popover-primary.popover {\n  background-color: #cce5ff;\n  border-color: #b8daff;\n}\n.b-popover-primary.bs-popover-top > .arrow::before, .b-popover-primary.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #b8daff;\n}\n.b-popover-primary.bs-popover-top > .arrow::after, .b-popover-primary.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #cce5ff;\n}\n.b-popover-primary.bs-popover-right > .arrow::before, .b-popover-primary.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #b8daff;\n}\n.b-popover-primary.bs-popover-right > .arrow::after, .b-popover-primary.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #cce5ff;\n}\n.b-popover-primary.bs-popover-bottom > .arrow::before, .b-popover-primary.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #b8daff;\n}\n.b-popover-primary.bs-popover-bottom > .arrow::after, .b-popover-primary.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #bdddff;\n}\n.b-popover-primary.bs-popover-bottom .popover-header::before, .b-popover-primary.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #bdddff;\n}\n.b-popover-primary.bs-popover-left > .arrow::before, .b-popover-primary.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #b8daff;\n}\n.b-popover-primary.bs-popover-left > .arrow::after, .b-popover-primary.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #cce5ff;\n}\n.b-popover-primary .popover-header {\n  color: #212529;\n  background-color: #bdddff;\n  border-bottom-color: #a3d0ff;\n}\n.b-popover-primary .popover-body {\n  color: #004085;\n}\n\n.b-popover-secondary.popover {\n  background-color: #e2e3e5;\n  border-color: #d6d8db;\n}\n.b-popover-secondary.bs-popover-top > .arrow::before, .b-popover-secondary.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #d6d8db;\n}\n.b-popover-secondary.bs-popover-top > .arrow::after, .b-popover-secondary.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #e2e3e5;\n}\n.b-popover-secondary.bs-popover-right > .arrow::before, .b-popover-secondary.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #d6d8db;\n}\n.b-popover-secondary.bs-popover-right > .arrow::after, .b-popover-secondary.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #e2e3e5;\n}\n.b-popover-secondary.bs-popover-bottom > .arrow::before, .b-popover-secondary.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #d6d8db;\n}\n.b-popover-secondary.bs-popover-bottom > .arrow::after, .b-popover-secondary.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #dadbde;\n}\n.b-popover-secondary.bs-popover-bottom .popover-header::before, .b-popover-secondary.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #dadbde;\n}\n.b-popover-secondary.bs-popover-left > .arrow::before, .b-popover-secondary.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #d6d8db;\n}\n.b-popover-secondary.bs-popover-left > .arrow::after, .b-popover-secondary.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #e2e3e5;\n}\n.b-popover-secondary .popover-header {\n  color: #212529;\n  background-color: #dadbde;\n  border-bottom-color: #ccced2;\n}\n.b-popover-secondary .popover-body {\n  color: #383d41;\n}\n\n.b-popover-success.popover {\n  background-color: #d4edda;\n  border-color: #c3e6cb;\n}\n.b-popover-success.bs-popover-top > .arrow::before, .b-popover-success.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #c3e6cb;\n}\n.b-popover-success.bs-popover-top > .arrow::after, .b-popover-success.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #d4edda;\n}\n.b-popover-success.bs-popover-right > .arrow::before, .b-popover-success.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #c3e6cb;\n}\n.b-popover-success.bs-popover-right > .arrow::after, .b-popover-success.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #d4edda;\n}\n.b-popover-success.bs-popover-bottom > .arrow::before, .b-popover-success.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #c3e6cb;\n}\n.b-popover-success.bs-popover-bottom > .arrow::after, .b-popover-success.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #c9e8d1;\n}\n.b-popover-success.bs-popover-bottom .popover-header::before, .b-popover-success.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #c9e8d1;\n}\n.b-popover-success.bs-popover-left > .arrow::before, .b-popover-success.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #c3e6cb;\n}\n.b-popover-success.bs-popover-left > .arrow::after, .b-popover-success.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #d4edda;\n}\n.b-popover-success .popover-header {\n  color: #212529;\n  background-color: #c9e8d1;\n  border-bottom-color: #b7e1c1;\n}\n.b-popover-success .popover-body {\n  color: #155724;\n}\n\n.b-popover-info.popover {\n  background-color: #d1ecf1;\n  border-color: #bee5eb;\n}\n.b-popover-info.bs-popover-top > .arrow::before, .b-popover-info.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #bee5eb;\n}\n.b-popover-info.bs-popover-top > .arrow::after, .b-popover-info.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #d1ecf1;\n}\n.b-popover-info.bs-popover-right > .arrow::before, .b-popover-info.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #bee5eb;\n}\n.b-popover-info.bs-popover-right > .arrow::after, .b-popover-info.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #d1ecf1;\n}\n.b-popover-info.bs-popover-bottom > .arrow::before, .b-popover-info.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #bee5eb;\n}\n.b-popover-info.bs-popover-bottom > .arrow::after, .b-popover-info.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #c5e7ed;\n}\n.b-popover-info.bs-popover-bottom .popover-header::before, .b-popover-info.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #c5e7ed;\n}\n.b-popover-info.bs-popover-left > .arrow::before, .b-popover-info.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #bee5eb;\n}\n.b-popover-info.bs-popover-left > .arrow::after, .b-popover-info.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #d1ecf1;\n}\n.b-popover-info .popover-header {\n  color: #212529;\n  background-color: #c5e7ed;\n  border-bottom-color: #b2dfe7;\n}\n.b-popover-info .popover-body {\n  color: #0c5460;\n}\n\n.b-popover-warning.popover {\n  background-color: #fff3cd;\n  border-color: #ffeeba;\n}\n.b-popover-warning.bs-popover-top > .arrow::before, .b-popover-warning.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #ffeeba;\n}\n.b-popover-warning.bs-popover-top > .arrow::after, .b-popover-warning.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #fff3cd;\n}\n.b-popover-warning.bs-popover-right > .arrow::before, .b-popover-warning.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #ffeeba;\n}\n.b-popover-warning.bs-popover-right > .arrow::after, .b-popover-warning.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #fff3cd;\n}\n.b-popover-warning.bs-popover-bottom > .arrow::before, .b-popover-warning.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #ffeeba;\n}\n.b-popover-warning.bs-popover-bottom > .arrow::after, .b-popover-warning.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #ffefbe;\n}\n.b-popover-warning.bs-popover-bottom .popover-header::before, .b-popover-warning.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #ffefbe;\n}\n.b-popover-warning.bs-popover-left > .arrow::before, .b-popover-warning.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #ffeeba;\n}\n.b-popover-warning.bs-popover-left > .arrow::after, .b-popover-warning.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #fff3cd;\n}\n.b-popover-warning .popover-header {\n  color: #212529;\n  background-color: #ffefbe;\n  border-bottom-color: #ffe9a4;\n}\n.b-popover-warning .popover-body {\n  color: #856404;\n}\n\n.b-popover-danger.popover {\n  background-color: #f8d7da;\n  border-color: #f5c6cb;\n}\n.b-popover-danger.bs-popover-top > .arrow::before, .b-popover-danger.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #f5c6cb;\n}\n.b-popover-danger.bs-popover-top > .arrow::after, .b-popover-danger.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #f8d7da;\n}\n.b-popover-danger.bs-popover-right > .arrow::before, .b-popover-danger.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #f5c6cb;\n}\n.b-popover-danger.bs-popover-right > .arrow::after, .b-popover-danger.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #f8d7da;\n}\n.b-popover-danger.bs-popover-bottom > .arrow::before, .b-popover-danger.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #f5c6cb;\n}\n.b-popover-danger.bs-popover-bottom > .arrow::after, .b-popover-danger.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #f6cace;\n}\n.b-popover-danger.bs-popover-bottom .popover-header::before, .b-popover-danger.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #f6cace;\n}\n.b-popover-danger.bs-popover-left > .arrow::before, .b-popover-danger.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #f5c6cb;\n}\n.b-popover-danger.bs-popover-left > .arrow::after, .b-popover-danger.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #f8d7da;\n}\n.b-popover-danger .popover-header {\n  color: #212529;\n  background-color: #f6cace;\n  border-bottom-color: #f2b4ba;\n}\n.b-popover-danger .popover-body {\n  color: #721c24;\n}\n\n.b-popover-light.popover {\n  background-color: #fefefe;\n  border-color: #fdfdfe;\n}\n.b-popover-light.bs-popover-top > .arrow::before, .b-popover-light.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #fdfdfe;\n}\n.b-popover-light.bs-popover-top > .arrow::after, .b-popover-light.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #fefefe;\n}\n.b-popover-light.bs-popover-right > .arrow::before, .b-popover-light.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #fdfdfe;\n}\n.b-popover-light.bs-popover-right > .arrow::after, .b-popover-light.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #fefefe;\n}\n.b-popover-light.bs-popover-bottom > .arrow::before, .b-popover-light.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #fdfdfe;\n}\n.b-popover-light.bs-popover-bottom > .arrow::after, .b-popover-light.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #f6f6f6;\n}\n.b-popover-light.bs-popover-bottom .popover-header::before, .b-popover-light.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #f6f6f6;\n}\n.b-popover-light.bs-popover-left > .arrow::before, .b-popover-light.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #fdfdfe;\n}\n.b-popover-light.bs-popover-left > .arrow::after, .b-popover-light.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #fefefe;\n}\n.b-popover-light .popover-header {\n  color: #212529;\n  background-color: #f6f6f6;\n  border-bottom-color: #eaeaea;\n}\n.b-popover-light .popover-body {\n  color: #818182;\n}\n\n.b-popover-dark.popover {\n  background-color: #d6d8d9;\n  border-color: #c6c8ca;\n}\n.b-popover-dark.bs-popover-top > .arrow::before, .b-popover-dark.bs-popover-auto[x-placement^=top] > .arrow::before {\n  border-top-color: #c6c8ca;\n}\n.b-popover-dark.bs-popover-top > .arrow::after, .b-popover-dark.bs-popover-auto[x-placement^=top] > .arrow::after {\n  border-top-color: #d6d8d9;\n}\n.b-popover-dark.bs-popover-right > .arrow::before, .b-popover-dark.bs-popover-auto[x-placement^=right] > .arrow::before {\n  border-right-color: #c6c8ca;\n}\n.b-popover-dark.bs-popover-right > .arrow::after, .b-popover-dark.bs-popover-auto[x-placement^=right] > .arrow::after {\n  border-right-color: #d6d8d9;\n}\n.b-popover-dark.bs-popover-bottom > .arrow::before, .b-popover-dark.bs-popover-auto[x-placement^=bottom] > .arrow::before {\n  border-bottom-color: #c6c8ca;\n}\n.b-popover-dark.bs-popover-bottom > .arrow::after, .b-popover-dark.bs-popover-auto[x-placement^=bottom] > .arrow::after {\n  border-bottom-color: #ced0d2;\n}\n.b-popover-dark.bs-popover-bottom .popover-header::before, .b-popover-dark.bs-popover-auto[x-placement^=bottom] .popover-header::before {\n  border-bottom-color: #ced0d2;\n}\n.b-popover-dark.bs-popover-left > .arrow::before, .b-popover-dark.bs-popover-auto[x-placement^=left] > .arrow::before {\n  border-left-color: #c6c8ca;\n}\n.b-popover-dark.bs-popover-left > .arrow::after, .b-popover-dark.bs-popover-auto[x-placement^=left] > .arrow::after {\n  border-left-color: #d6d8d9;\n}\n.b-popover-dark .popover-header {\n  color: #212529;\n  background-color: #ced0d2;\n  border-bottom-color: #c1c4c5;\n}\n.b-popover-dark .popover-body {\n  color: #1b1e21;\n}\n\n.b-sidebar-outer {\n  position: fixed;\n  top: 0;\n  left: 0;\n  right: 0;\n  height: 0;\n  overflow: visible;\n  z-index: calc(1030 + 5);\n}\n\n.b-sidebar-backdrop {\n  position: fixed;\n  top: 0;\n  left: 0;\n  z-index: -1;\n  width: 100vw;\n  height: 100vh;\n  opacity: 0.6;\n}\n\n.b-sidebar {\n  display: flex;\n  flex-direction: column;\n  position: fixed;\n  top: 0;\n  width: 320px;\n  max-width: 100%;\n  height: 100vh;\n  max-height: 100%;\n  margin: 0;\n  outline: 0;\n  -webkit-transform: translateX(0);\n  transform: translateX(0);\n}\n.b-sidebar.slide {\n  transition: -webkit-transform 0.3s ease-in-out;\n  transition: transform 0.3s ease-in-out;\n  transition: transform 0.3s ease-in-out, -webkit-transform 0.3s ease-in-out;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-sidebar.slide {\n    transition: none;\n  }\n}\n.b-sidebar:not(.b-sidebar-right) {\n  left: 0;\n  right: auto;\n}\n.b-sidebar:not(.b-sidebar-right).slide:not(.show) {\n  -webkit-transform: translateX(-100%);\n  transform: translateX(-100%);\n}\n.b-sidebar:not(.b-sidebar-right) > .b-sidebar-header .close {\n  margin-left: auto;\n}\n.b-sidebar.b-sidebar-right {\n  left: auto;\n  right: 0;\n}\n.b-sidebar.b-sidebar-right.slide:not(.show) {\n  -webkit-transform: translateX(100%);\n  transform: translateX(100%);\n}\n.b-sidebar.b-sidebar-right > .b-sidebar-header .close {\n  margin-right: auto;\n}\n.b-sidebar > .b-sidebar-header {\n  font-size: 1.5rem;\n  padding: 0.5rem 1rem;\n  display: flex;\n  flex-direction: row;\n  flex-grow: 0;\n  align-items: center;\n}\n[dir=rtl] .b-sidebar > .b-sidebar-header {\n  flex-direction: row-reverse;\n}\n\n.b-sidebar > .b-sidebar-header .close {\n  float: none;\n  font-size: 1.5rem;\n}\n.b-sidebar > .b-sidebar-body {\n  flex-grow: 1;\n  height: 100%;\n  overflow-y: auto;\n}\n.b-sidebar > .b-sidebar-footer {\n  flex-grow: 0;\n}\n\n.b-skeleton-wrapper {\n  cursor: wait;\n}\n\n.b-skeleton {\n  position: relative;\n  overflow: hidden;\n  background-color: rgba(0, 0, 0, 0.12);\n  cursor: wait;\n  -webkit-mask-image: radial-gradient(white, black);\n  mask-image: radial-gradient(white, black);\n}\n.b-skeleton::before {\n  content: \"\\A0\";\n}\n\n.b-skeleton-text {\n  height: 1rem;\n  margin-bottom: 0.25rem;\n  border-radius: 0.25rem;\n}\n\n.b-skeleton-button {\n  width: 75px;\n  padding: 0.375rem 0.75rem;\n  font-size: 1rem;\n  line-height: 1.5;\n  border-radius: 0.25rem;\n}\n\n.b-skeleton-avatar {\n  width: 2.5em;\n  height: 2.5em;\n  border-radius: 50%;\n}\n\n.b-skeleton-input {\n  height: calc(1.5em + 0.75rem + 2px);\n  padding: 0.375rem 0.75rem;\n  line-height: 1.5;\n  border: #ced4da solid 1px;\n  border-radius: 0.25rem;\n}\n\n.b-skeleton-icon-wrapper svg {\n  color: rgba(0, 0, 0, 0.12);\n}\n\n.b-skeleton-img {\n  height: 100%;\n  width: 100%;\n}\n\n.b-skeleton-animate-wave::after {\n  content: \"\";\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  z-index: 0;\n  background: linear-gradient(90deg, transparent, rgba(255, 255, 255, 0.4), transparent);\n  -webkit-animation: b-skeleton-animate-wave 1.75s linear infinite;\n  animation: b-skeleton-animate-wave 1.75s linear infinite;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-skeleton-animate-wave::after {\n    background: none;\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n\n@-webkit-keyframes b-skeleton-animate-wave {\n  from {\n    -webkit-transform: translateX(-100%);\n    transform: translateX(-100%);\n  }\n  to {\n    -webkit-transform: translateX(100%);\n    transform: translateX(100%);\n  }\n}\n\n@keyframes b-skeleton-animate-wave {\n  from {\n    -webkit-transform: translateX(-100%);\n    transform: translateX(-100%);\n  }\n  to {\n    -webkit-transform: translateX(100%);\n    transform: translateX(100%);\n  }\n}\n.b-skeleton-animate-fade {\n  -webkit-animation: b-skeleton-animate-fade 0.875s ease-in-out alternate infinite;\n  animation: b-skeleton-animate-fade 0.875s ease-in-out alternate infinite;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-skeleton-animate-fade {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n\n@-webkit-keyframes b-skeleton-animate-fade {\n  0% {\n    opacity: 1;\n  }\n  100% {\n    opacity: 0.4;\n  }\n}\n\n@keyframes b-skeleton-animate-fade {\n  0% {\n    opacity: 1;\n  }\n  100% {\n    opacity: 0.4;\n  }\n}\n.b-skeleton-animate-throb {\n  -webkit-animation: b-skeleton-animate-throb 0.875s ease-in alternate infinite;\n  animation: b-skeleton-animate-throb 0.875s ease-in alternate infinite;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-skeleton-animate-throb {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n\n@-webkit-keyframes b-skeleton-animate-throb {\n  0% {\n    -webkit-transform: scale(1);\n    transform: scale(1);\n  }\n  100% {\n    -webkit-transform: scale(0.975);\n    transform: scale(0.975);\n  }\n}\n\n@keyframes b-skeleton-animate-throb {\n  0% {\n    -webkit-transform: scale(1);\n    transform: scale(1);\n  }\n  100% {\n    -webkit-transform: scale(0.975);\n    transform: scale(0.975);\n  }\n}\n.table.b-table.b-table-fixed {\n  table-layout: fixed;\n}\n.table.b-table.b-table-no-border-collapse {\n  border-collapse: separate;\n  border-spacing: 0;\n}\n.table.b-table[aria-busy=true] {\n  opacity: 0.55;\n}\n.table.b-table > tbody > tr.b-table-details > td {\n  border-top: none !important;\n}\n.table.b-table > caption {\n  caption-side: bottom;\n}\n.table.b-table.b-table-caption-top > caption {\n  caption-side: top !important;\n}\n.table.b-table > tbody > .table-active,\n.table.b-table > tbody > .table-active > th,\n.table.b-table > tbody > .table-active > td {\n  background-color: rgba(0, 0, 0, 0.075);\n}\n.table.b-table.table-hover > tbody > tr.table-active:hover td,\n.table.b-table.table-hover > tbody > tr.table-active:hover th {\n  color: #212529;\n  background-image: linear-gradient(rgba(0, 0, 0, 0.075), rgba(0, 0, 0, 0.075));\n  background-repeat: no-repeat;\n}\n.table.b-table > tbody > .bg-active,\n.table.b-table > tbody > .bg-active > th,\n.table.b-table > tbody > .bg-active > td {\n  background-color: rgba(255, 255, 255, 0.075) !important;\n}\n.table.b-table.table-hover.table-dark > tbody > tr.bg-active:hover td,\n.table.b-table.table-hover.table-dark > tbody > tr.bg-active:hover th {\n  color: #fff;\n  background-image: linear-gradient(rgba(255, 255, 255, 0.075), rgba(255, 255, 255, 0.075));\n  background-repeat: no-repeat;\n}\n\n.b-table-sticky-header,\n.table-responsive,\n[class*=table-responsive-] {\n  margin-bottom: 1rem;\n}\n.b-table-sticky-header > .table,\n.table-responsive > .table,\n[class*=table-responsive-] > .table {\n  margin-bottom: 0;\n}\n\n.b-table-sticky-header {\n  overflow-y: auto;\n  max-height: 300px;\n}\n\n@media print {\n  .b-table-sticky-header {\n    overflow-y: visible !important;\n    max-height: none !important;\n  }\n}\n@supports ((position: -webkit-sticky) or (position: sticky)) {\n  .b-table-sticky-header > .table.b-table > thead > tr > th {\n    position: -webkit-sticky;\n    position: sticky;\n    top: 0;\n    z-index: 2;\n  }\n\n  .b-table-sticky-header > .table.b-table > thead > tr > .b-table-sticky-column,\n.b-table-sticky-header > .table.b-table > tbody > tr > .b-table-sticky-column,\n.b-table-sticky-header > .table.b-table > tfoot > tr > .b-table-sticky-column,\n.table-responsive > .table.b-table > thead > tr > .b-table-sticky-column,\n.table-responsive > .table.b-table > tbody > tr > .b-table-sticky-column,\n.table-responsive > .table.b-table > tfoot > tr > .b-table-sticky-column,\n[class*=table-responsive-] > .table.b-table > thead > tr > .b-table-sticky-column,\n[class*=table-responsive-] > .table.b-table > tbody > tr > .b-table-sticky-column,\n[class*=table-responsive-] > .table.b-table > tfoot > tr > .b-table-sticky-column {\n    position: -webkit-sticky;\n    position: sticky;\n    left: 0;\n  }\n  .b-table-sticky-header > .table.b-table > thead > tr > .b-table-sticky-column,\n.table-responsive > .table.b-table > thead > tr > .b-table-sticky-column,\n[class*=table-responsive-] > .table.b-table > thead > tr > .b-table-sticky-column {\n    z-index: 5;\n  }\n  .b-table-sticky-header > .table.b-table > tbody > tr > .b-table-sticky-column,\n.b-table-sticky-header > .table.b-table > tfoot > tr > .b-table-sticky-column,\n.table-responsive > .table.b-table > tbody > tr > .b-table-sticky-column,\n.table-responsive > .table.b-table > tfoot > tr > .b-table-sticky-column,\n[class*=table-responsive-] > .table.b-table > tbody > tr > .b-table-sticky-column,\n[class*=table-responsive-] > .table.b-table > tfoot > tr > .b-table-sticky-column {\n    z-index: 2;\n  }\n\n  .table.b-table > thead > tr > .table-b-table-default,\n.table.b-table > tbody > tr > .table-b-table-default,\n.table.b-table > tfoot > tr > .table-b-table-default {\n    color: #212529;\n    background-color: #fff;\n  }\n  .table.b-table.table-dark > thead > tr > .bg-b-table-default,\n.table.b-table.table-dark > tbody > tr > .bg-b-table-default,\n.table.b-table.table-dark > tfoot > tr > .bg-b-table-default {\n    color: #fff;\n    background-color: #343a40;\n  }\n  .table.b-table.table-striped > tbody > tr:nth-of-type(odd) > .table-b-table-default {\n    background-image: linear-gradient(rgba(0, 0, 0, 0.05), rgba(0, 0, 0, 0.05));\n    background-repeat: no-repeat;\n  }\n  .table.b-table.table-striped.table-dark > tbody > tr:nth-of-type(odd) > .bg-b-table-default {\n    background-image: linear-gradient(rgba(255, 255, 255, 0.05), rgba(255, 255, 255, 0.05));\n    background-repeat: no-repeat;\n  }\n  .table.b-table.table-hover > tbody > tr:hover > .table-b-table-default {\n    color: #212529;\n    background-image: linear-gradient(rgba(0, 0, 0, 0.075), rgba(0, 0, 0, 0.075));\n    background-repeat: no-repeat;\n  }\n  .table.b-table.table-hover.table-dark > tbody > tr:hover > .bg-b-table-default {\n    color: #fff;\n    background-image: linear-gradient(rgba(255, 255, 255, 0.075), rgba(255, 255, 255, 0.075));\n    background-repeat: no-repeat;\n  }\n}\n.table.b-table > thead > tr > [aria-sort],\n.table.b-table > tfoot > tr > [aria-sort] {\n  cursor: pointer;\n  background-image: none;\n  background-repeat: no-repeat;\n  background-size: 0.65em 1em;\n}\n.table.b-table > thead > tr > [aria-sort]:not(.b-table-sort-icon-left),\n.table.b-table > tfoot > tr > [aria-sort]:not(.b-table-sort-icon-left) {\n  background-position: right calc(0.75rem / 2) center;\n  padding-right: calc(0.75rem + 0.65em);\n}\n.table.b-table > thead > tr > [aria-sort].b-table-sort-icon-left,\n.table.b-table > tfoot > tr > [aria-sort].b-table-sort-icon-left {\n  background-position: left calc(0.75rem / 2) center;\n  padding-left: calc(0.75rem + 0.65em);\n}\n.table.b-table > thead > tr > [aria-sort=none],\n.table.b-table > tfoot > tr > [aria-sort=none] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='black' opacity='.3' d='M51 1l25 23 24 22H1l25-22zM51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table > thead > tr > [aria-sort=ascending],\n.table.b-table > tfoot > tr > [aria-sort=ascending] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='black' d='M51 1l25 23 24 22H1l25-22z'/%3e%3cpath fill='black' opacity='.3' d='M51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table > thead > tr > [aria-sort=descending],\n.table.b-table > tfoot > tr > [aria-sort=descending] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='black' opacity='.3' d='M51 1l25 23 24 22H1l25-22z'/%3e%3cpath fill='black' d='M51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table.table-dark > thead > tr > [aria-sort=none], .table.b-table.table-dark > tfoot > tr > [aria-sort=none],\n.table.b-table > .thead-dark > tr > [aria-sort=none] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='white' opacity='.3' d='M51 1l25 23 24 22H1l25-22zM51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table.table-dark > thead > tr > [aria-sort=ascending], .table.b-table.table-dark > tfoot > tr > [aria-sort=ascending],\n.table.b-table > .thead-dark > tr > [aria-sort=ascending] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='white' d='M51 1l25 23 24 22H1l25-22z'/%3e%3cpath fill='white' opacity='.3' d='M51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table.table-dark > thead > tr > [aria-sort=descending], .table.b-table.table-dark > tfoot > tr > [aria-sort=descending],\n.table.b-table > .thead-dark > tr > [aria-sort=descending] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='white' opacity='.3' d='M51 1l25 23 24 22H1l25-22z'/%3e%3cpath fill='white' d='M51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table > thead > tr > .table-dark[aria-sort=none],\n.table.b-table > tfoot > tr > .table-dark[aria-sort=none] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='white' opacity='.3' d='M51 1l25 23 24 22H1l25-22zM51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table > thead > tr > .table-dark[aria-sort=ascending],\n.table.b-table > tfoot > tr > .table-dark[aria-sort=ascending] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='white' d='M51 1l25 23 24 22H1l25-22z'/%3e%3cpath fill='white' opacity='.3' d='M51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table > thead > tr > .table-dark[aria-sort=descending],\n.table.b-table > tfoot > tr > .table-dark[aria-sort=descending] {\n  background-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='101' height='101' view-box='0 0 101 101' preserveAspectRatio='none'%3e%3cpath fill='white' opacity='.3' d='M51 1l25 23 24 22H1l25-22z'/%3e%3cpath fill='white' d='M51 101l25-23 24-22H1l25 22z'/%3e%3c/svg%3e\");\n}\n.table.b-table.table-sm > thead > tr > [aria-sort]:not(.b-table-sort-icon-left),\n.table.b-table.table-sm > tfoot > tr > [aria-sort]:not(.b-table-sort-icon-left) {\n  background-position: right calc(0.3rem / 2) center;\n  padding-right: calc(0.3rem + 0.65em);\n}\n.table.b-table.table-sm > thead > tr > [aria-sort].b-table-sort-icon-left,\n.table.b-table.table-sm > tfoot > tr > [aria-sort].b-table-sort-icon-left {\n  background-position: left calc(0.3rem / 2) center;\n  padding-left: calc(0.3rem + 0.65em);\n}\n\n.table.b-table.b-table-selectable:not(.b-table-selectable-no-click) > tbody > tr {\n  cursor: pointer;\n}\n.table.b-table.b-table-selectable:not(.b-table-selectable-no-click).b-table-selecting.b-table-select-range > tbody > tr {\n  -webkit-user-select: none;\n  -moz-user-select: none;\n  -ms-user-select: none;\n  user-select: none;\n}\n\n@media (max-width: 575.98px) {\n  .table.b-table.b-table-stacked-sm {\n    display: block;\n    width: 100%;\n  }\n  .table.b-table.b-table-stacked-sm > caption,\n.table.b-table.b-table-stacked-sm > tbody,\n.table.b-table.b-table-stacked-sm > tbody > tr,\n.table.b-table.b-table-stacked-sm > tbody > tr > td,\n.table.b-table.b-table-stacked-sm > tbody > tr > th {\n    display: block;\n  }\n  .table.b-table.b-table-stacked-sm > thead,\n.table.b-table.b-table-stacked-sm > tfoot {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-sm > thead > tr.b-table-top-row,\n.table.b-table.b-table-stacked-sm > thead > tr.b-table-bottom-row,\n.table.b-table.b-table-stacked-sm > tfoot > tr.b-table-top-row,\n.table.b-table.b-table-stacked-sm > tfoot > tr.b-table-bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-sm > caption {\n    caption-side: top !important;\n  }\n  .table.b-table.b-table-stacked-sm > tbody > tr > [data-label]::before {\n    content: attr(data-label);\n    width: 40%;\n    float: left;\n    text-align: right;\n    overflow-wrap: break-word;\n    font-weight: bold;\n    font-style: normal;\n    padding: 0 calc(1rem / 2) 0 0;\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-sm > tbody > tr > [data-label]::after {\n    display: block;\n    clear: both;\n    content: \"\";\n  }\n  .table.b-table.b-table-stacked-sm > tbody > tr > [data-label] > div {\n    display: inline-block;\n    width: calc(100% - 40%);\n    padding: 0 0 0 calc(1rem / 2);\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-sm > tbody > tr.top-row, .table.b-table.b-table-stacked-sm > tbody > tr.bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-sm > tbody > tr > :first-child {\n    border-top-width: 3px;\n  }\n  .table.b-table.b-table-stacked-sm > tbody > tr > [rowspan] + td,\n.table.b-table.b-table-stacked-sm > tbody > tr > [rowspan] + th {\n    border-top-width: 3px;\n  }\n}\n@media (max-width: 767.98px) {\n  .table.b-table.b-table-stacked-md {\n    display: block;\n    width: 100%;\n  }\n  .table.b-table.b-table-stacked-md > caption,\n.table.b-table.b-table-stacked-md > tbody,\n.table.b-table.b-table-stacked-md > tbody > tr,\n.table.b-table.b-table-stacked-md > tbody > tr > td,\n.table.b-table.b-table-stacked-md > tbody > tr > th {\n    display: block;\n  }\n  .table.b-table.b-table-stacked-md > thead,\n.table.b-table.b-table-stacked-md > tfoot {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-md > thead > tr.b-table-top-row,\n.table.b-table.b-table-stacked-md > thead > tr.b-table-bottom-row,\n.table.b-table.b-table-stacked-md > tfoot > tr.b-table-top-row,\n.table.b-table.b-table-stacked-md > tfoot > tr.b-table-bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-md > caption {\n    caption-side: top !important;\n  }\n  .table.b-table.b-table-stacked-md > tbody > tr > [data-label]::before {\n    content: attr(data-label);\n    width: 40%;\n    float: left;\n    text-align: right;\n    overflow-wrap: break-word;\n    font-weight: bold;\n    font-style: normal;\n    padding: 0 calc(1rem / 2) 0 0;\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-md > tbody > tr > [data-label]::after {\n    display: block;\n    clear: both;\n    content: \"\";\n  }\n  .table.b-table.b-table-stacked-md > tbody > tr > [data-label] > div {\n    display: inline-block;\n    width: calc(100% - 40%);\n    padding: 0 0 0 calc(1rem / 2);\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-md > tbody > tr.top-row, .table.b-table.b-table-stacked-md > tbody > tr.bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-md > tbody > tr > :first-child {\n    border-top-width: 3px;\n  }\n  .table.b-table.b-table-stacked-md > tbody > tr > [rowspan] + td,\n.table.b-table.b-table-stacked-md > tbody > tr > [rowspan] + th {\n    border-top-width: 3px;\n  }\n}\n@media (max-width: 991.98px) {\n  .table.b-table.b-table-stacked-lg {\n    display: block;\n    width: 100%;\n  }\n  .table.b-table.b-table-stacked-lg > caption,\n.table.b-table.b-table-stacked-lg > tbody,\n.table.b-table.b-table-stacked-lg > tbody > tr,\n.table.b-table.b-table-stacked-lg > tbody > tr > td,\n.table.b-table.b-table-stacked-lg > tbody > tr > th {\n    display: block;\n  }\n  .table.b-table.b-table-stacked-lg > thead,\n.table.b-table.b-table-stacked-lg > tfoot {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-lg > thead > tr.b-table-top-row,\n.table.b-table.b-table-stacked-lg > thead > tr.b-table-bottom-row,\n.table.b-table.b-table-stacked-lg > tfoot > tr.b-table-top-row,\n.table.b-table.b-table-stacked-lg > tfoot > tr.b-table-bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-lg > caption {\n    caption-side: top !important;\n  }\n  .table.b-table.b-table-stacked-lg > tbody > tr > [data-label]::before {\n    content: attr(data-label);\n    width: 40%;\n    float: left;\n    text-align: right;\n    overflow-wrap: break-word;\n    font-weight: bold;\n    font-style: normal;\n    padding: 0 calc(1rem / 2) 0 0;\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-lg > tbody > tr > [data-label]::after {\n    display: block;\n    clear: both;\n    content: \"\";\n  }\n  .table.b-table.b-table-stacked-lg > tbody > tr > [data-label] > div {\n    display: inline-block;\n    width: calc(100% - 40%);\n    padding: 0 0 0 calc(1rem / 2);\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-lg > tbody > tr.top-row, .table.b-table.b-table-stacked-lg > tbody > tr.bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-lg > tbody > tr > :first-child {\n    border-top-width: 3px;\n  }\n  .table.b-table.b-table-stacked-lg > tbody > tr > [rowspan] + td,\n.table.b-table.b-table-stacked-lg > tbody > tr > [rowspan] + th {\n    border-top-width: 3px;\n  }\n}\n@media (max-width: 1199.98px) {\n  .table.b-table.b-table-stacked-xl {\n    display: block;\n    width: 100%;\n  }\n  .table.b-table.b-table-stacked-xl > caption,\n.table.b-table.b-table-stacked-xl > tbody,\n.table.b-table.b-table-stacked-xl > tbody > tr,\n.table.b-table.b-table-stacked-xl > tbody > tr > td,\n.table.b-table.b-table-stacked-xl > tbody > tr > th {\n    display: block;\n  }\n  .table.b-table.b-table-stacked-xl > thead,\n.table.b-table.b-table-stacked-xl > tfoot {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-xl > thead > tr.b-table-top-row,\n.table.b-table.b-table-stacked-xl > thead > tr.b-table-bottom-row,\n.table.b-table.b-table-stacked-xl > tfoot > tr.b-table-top-row,\n.table.b-table.b-table-stacked-xl > tfoot > tr.b-table-bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-xl > caption {\n    caption-side: top !important;\n  }\n  .table.b-table.b-table-stacked-xl > tbody > tr > [data-label]::before {\n    content: attr(data-label);\n    width: 40%;\n    float: left;\n    text-align: right;\n    overflow-wrap: break-word;\n    font-weight: bold;\n    font-style: normal;\n    padding: 0 calc(1rem / 2) 0 0;\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-xl > tbody > tr > [data-label]::after {\n    display: block;\n    clear: both;\n    content: \"\";\n  }\n  .table.b-table.b-table-stacked-xl > tbody > tr > [data-label] > div {\n    display: inline-block;\n    width: calc(100% - 40%);\n    padding: 0 0 0 calc(1rem / 2);\n    margin: 0;\n  }\n  .table.b-table.b-table-stacked-xl > tbody > tr.top-row, .table.b-table.b-table-stacked-xl > tbody > tr.bottom-row {\n    display: none;\n  }\n  .table.b-table.b-table-stacked-xl > tbody > tr > :first-child {\n    border-top-width: 3px;\n  }\n  .table.b-table.b-table-stacked-xl > tbody > tr > [rowspan] + td,\n.table.b-table.b-table-stacked-xl > tbody > tr > [rowspan] + th {\n    border-top-width: 3px;\n  }\n}\n.table.b-table.b-table-stacked {\n  display: block;\n  width: 100%;\n}\n.table.b-table.b-table-stacked > caption,\n.table.b-table.b-table-stacked > tbody,\n.table.b-table.b-table-stacked > tbody > tr,\n.table.b-table.b-table-stacked > tbody > tr > td,\n.table.b-table.b-table-stacked > tbody > tr > th {\n  display: block;\n}\n.table.b-table.b-table-stacked > thead,\n.table.b-table.b-table-stacked > tfoot {\n  display: none;\n}\n.table.b-table.b-table-stacked > thead > tr.b-table-top-row,\n.table.b-table.b-table-stacked > thead > tr.b-table-bottom-row,\n.table.b-table.b-table-stacked > tfoot > tr.b-table-top-row,\n.table.b-table.b-table-stacked > tfoot > tr.b-table-bottom-row {\n  display: none;\n}\n.table.b-table.b-table-stacked > caption {\n  caption-side: top !important;\n}\n.table.b-table.b-table-stacked > tbody > tr > [data-label]::before {\n  content: attr(data-label);\n  width: 40%;\n  float: left;\n  text-align: right;\n  overflow-wrap: break-word;\n  font-weight: bold;\n  font-style: normal;\n  padding: 0 calc(1rem / 2) 0 0;\n  margin: 0;\n}\n.table.b-table.b-table-stacked > tbody > tr > [data-label]::after {\n  display: block;\n  clear: both;\n  content: \"\";\n}\n.table.b-table.b-table-stacked > tbody > tr > [data-label] > div {\n  display: inline-block;\n  width: calc(100% - 40%);\n  padding: 0 0 0 calc(1rem / 2);\n  margin: 0;\n}\n.table.b-table.b-table-stacked > tbody > tr.top-row, .table.b-table.b-table-stacked > tbody > tr.bottom-row {\n  display: none;\n}\n.table.b-table.b-table-stacked > tbody > tr > :first-child {\n  border-top-width: 3px;\n}\n.table.b-table.b-table-stacked > tbody > tr > [rowspan] + td,\n.table.b-table.b-table-stacked > tbody > tr > [rowspan] + th {\n  border-top-width: 3px;\n}\n\n.b-time {\n  min-width: 150px;\n}\n.b-time[aria-disabled=true] output, .b-time[aria-readonly=true] output,\n.b-time output.disabled {\n  background-color: #e9ecef;\n  opacity: 1;\n}\n.b-time[aria-disabled=true] output {\n  pointer-events: none;\n}\n[dir=rtl] .b-time > .d-flex:not(.flex-column) {\n  flex-direction: row-reverse;\n}\n\n.b-time .b-time-header {\n  margin-bottom: 0.5rem;\n}\n.b-time .b-time-header output {\n  padding: 0.25rem;\n  font-size: 80%;\n}\n.b-time .b-time-footer {\n  margin-top: 0.5rem;\n}\n.b-time .b-time-ampm {\n  margin-left: 0.5rem;\n}\n\n.b-toast {\n  display: block;\n  position: relative;\n  max-width: 350px;\n  -webkit-backface-visibility: hidden;\n  backface-visibility: hidden;\n  background-clip: padding-box;\n  z-index: 1;\n  border-radius: 0.25rem;\n}\n.b-toast .toast {\n  background-color: rgba(255, 255, 255, 0.85);\n}\n.b-toast:not(:last-child) {\n  margin-bottom: 0.75rem;\n}\n.b-toast.b-toast-solid .toast {\n  background-color: white;\n}\n.b-toast .toast {\n  opacity: 1;\n}\n.b-toast .toast.fade:not(.show) {\n  opacity: 0;\n}\n.b-toast .toast .toast-body {\n  display: block;\n}\n\n.b-toast-primary .toast {\n  background-color: rgba(230, 242, 255, 0.85);\n  border-color: rgba(184, 218, 255, 0.85);\n  color: #004085;\n}\n.b-toast-primary .toast .toast-header {\n  color: #004085;\n  background-color: rgba(204, 229, 255, 0.85);\n  border-bottom-color: rgba(184, 218, 255, 0.85);\n}\n.b-toast-primary.b-toast-solid .toast {\n  background-color: #e6f2ff;\n}\n\n.b-toast-secondary .toast {\n  background-color: rgba(239, 240, 241, 0.85);\n  border-color: rgba(214, 216, 219, 0.85);\n  color: #383d41;\n}\n.b-toast-secondary .toast .toast-header {\n  color: #383d41;\n  background-color: rgba(226, 227, 229, 0.85);\n  border-bottom-color: rgba(214, 216, 219, 0.85);\n}\n.b-toast-secondary.b-toast-solid .toast {\n  background-color: #eff0f1;\n}\n\n.b-toast-success .toast {\n  background-color: rgba(230, 245, 233, 0.85);\n  border-color: rgba(195, 230, 203, 0.85);\n  color: #155724;\n}\n.b-toast-success .toast .toast-header {\n  color: #155724;\n  background-color: rgba(212, 237, 218, 0.85);\n  border-bottom-color: rgba(195, 230, 203, 0.85);\n}\n.b-toast-success.b-toast-solid .toast {\n  background-color: #e6f5e9;\n}\n\n.b-toast-info .toast {\n  background-color: rgba(229, 244, 247, 0.85);\n  border-color: rgba(190, 229, 235, 0.85);\n  color: #0c5460;\n}\n.b-toast-info .toast .toast-header {\n  color: #0c5460;\n  background-color: rgba(209, 236, 241, 0.85);\n  border-bottom-color: rgba(190, 229, 235, 0.85);\n}\n.b-toast-info.b-toast-solid .toast {\n  background-color: #e5f4f7;\n}\n\n.b-toast-warning .toast {\n  background-color: rgba(255, 249, 231, 0.85);\n  border-color: rgba(255, 238, 186, 0.85);\n  color: #856404;\n}\n.b-toast-warning .toast .toast-header {\n  color: #856404;\n  background-color: rgba(255, 243, 205, 0.85);\n  border-bottom-color: rgba(255, 238, 186, 0.85);\n}\n.b-toast-warning.b-toast-solid .toast {\n  background-color: #fff9e7;\n}\n\n.b-toast-danger .toast {\n  background-color: rgba(252, 237, 238, 0.85);\n  border-color: rgba(245, 198, 203, 0.85);\n  color: #721c24;\n}\n.b-toast-danger .toast .toast-header {\n  color: #721c24;\n  background-color: rgba(248, 215, 218, 0.85);\n  border-bottom-color: rgba(245, 198, 203, 0.85);\n}\n.b-toast-danger.b-toast-solid .toast {\n  background-color: #fcedee;\n}\n\n.b-toast-light .toast {\n  background-color: rgba(255, 255, 255, 0.85);\n  border-color: rgba(253, 253, 254, 0.85);\n  color: #818182;\n}\n.b-toast-light .toast .toast-header {\n  color: #818182;\n  background-color: rgba(254, 254, 254, 0.85);\n  border-bottom-color: rgba(253, 253, 254, 0.85);\n}\n.b-toast-light.b-toast-solid .toast {\n  background-color: white;\n}\n\n.b-toast-dark .toast {\n  background-color: rgba(227, 229, 229, 0.85);\n  border-color: rgba(198, 200, 202, 0.85);\n  color: #1b1e21;\n}\n.b-toast-dark .toast .toast-header {\n  color: #1b1e21;\n  background-color: rgba(214, 216, 217, 0.85);\n  border-bottom-color: rgba(198, 200, 202, 0.85);\n}\n.b-toast-dark.b-toast-solid .toast {\n  background-color: #e3e5e5;\n}\n\n.b-toaster {\n  z-index: 1100;\n}\n.b-toaster .b-toaster-slot {\n  position: relative;\n  display: block;\n}\n.b-toaster .b-toaster-slot:empty {\n  display: none !important;\n}\n\n.b-toaster.b-toaster-top-right, .b-toaster.b-toaster-top-left, .b-toaster.b-toaster-top-center, .b-toaster.b-toaster-top-full, .b-toaster.b-toaster-bottom-right, .b-toaster.b-toaster-bottom-left, .b-toaster.b-toaster-bottom-center, .b-toaster.b-toaster-bottom-full {\n  position: fixed;\n  left: 0.5rem;\n  right: 0.5rem;\n  margin: 0;\n  padding: 0;\n  height: 0;\n  overflow: visible;\n}\n.b-toaster.b-toaster-top-right .b-toaster-slot, .b-toaster.b-toaster-top-left .b-toaster-slot, .b-toaster.b-toaster-top-center .b-toaster-slot, .b-toaster.b-toaster-top-full .b-toaster-slot, .b-toaster.b-toaster-bottom-right .b-toaster-slot, .b-toaster.b-toaster-bottom-left .b-toaster-slot, .b-toaster.b-toaster-bottom-center .b-toaster-slot, .b-toaster.b-toaster-bottom-full .b-toaster-slot {\n  position: absolute;\n  max-width: 350px;\n  width: 100%;\n  /* IE 11 fix */\n  left: 0;\n  right: 0;\n  padding: 0;\n  margin: 0;\n}\n.b-toaster.b-toaster-top-full .b-toaster-slot, .b-toaster.b-toaster-bottom-full .b-toaster-slot {\n  width: 100%;\n  max-width: 100%;\n}\n.b-toaster.b-toaster-top-full .b-toaster-slot .b-toast,\n.b-toaster.b-toaster-top-full .b-toaster-slot .toast, .b-toaster.b-toaster-bottom-full .b-toaster-slot .b-toast,\n.b-toaster.b-toaster-bottom-full .b-toaster-slot .toast {\n  width: 100%;\n  max-width: 100%;\n}\n.b-toaster.b-toaster-top-right, .b-toaster.b-toaster-top-left, .b-toaster.b-toaster-top-center, .b-toaster.b-toaster-top-full {\n  top: 0;\n}\n.b-toaster.b-toaster-top-right .b-toaster-slot, .b-toaster.b-toaster-top-left .b-toaster-slot, .b-toaster.b-toaster-top-center .b-toaster-slot, .b-toaster.b-toaster-top-full .b-toaster-slot {\n  top: 0.5rem;\n}\n.b-toaster.b-toaster-bottom-right, .b-toaster.b-toaster-bottom-left, .b-toaster.b-toaster-bottom-center, .b-toaster.b-toaster-bottom-full {\n  bottom: 0;\n}\n.b-toaster.b-toaster-bottom-right .b-toaster-slot, .b-toaster.b-toaster-bottom-left .b-toaster-slot, .b-toaster.b-toaster-bottom-center .b-toaster-slot, .b-toaster.b-toaster-bottom-full .b-toaster-slot {\n  bottom: 0.5rem;\n}\n.b-toaster.b-toaster-top-right .b-toaster-slot, .b-toaster.b-toaster-bottom-right .b-toaster-slot, .b-toaster.b-toaster-top-center .b-toaster-slot, .b-toaster.b-toaster-bottom-center .b-toaster-slot {\n  margin-left: auto;\n}\n.b-toaster.b-toaster-top-left .b-toaster-slot, .b-toaster.b-toaster-bottom-left .b-toaster-slot, .b-toaster.b-toaster-top-center .b-toaster-slot, .b-toaster.b-toaster-bottom-center .b-toaster-slot {\n  margin-right: auto;\n}\n\n.b-toaster.b-toaster-top-right .b-toast.b-toaster-enter-active, .b-toaster.b-toaster-top-right .b-toast.b-toaster-leave-active, .b-toaster.b-toaster-top-right .b-toast.b-toaster-move, .b-toaster.b-toaster-top-left .b-toast.b-toaster-enter-active, .b-toaster.b-toaster-top-left .b-toast.b-toaster-leave-active, .b-toaster.b-toaster-top-left .b-toast.b-toaster-move, .b-toaster.b-toaster-bottom-right .b-toast.b-toaster-enter-active, .b-toaster.b-toaster-bottom-right .b-toast.b-toaster-leave-active, .b-toaster.b-toaster-bottom-right .b-toast.b-toaster-move, .b-toaster.b-toaster-bottom-left .b-toast.b-toaster-enter-active, .b-toaster.b-toaster-bottom-left .b-toast.b-toaster-leave-active, .b-toaster.b-toaster-bottom-left .b-toast.b-toaster-move {\n  transition: -webkit-transform 0.175s;\n  transition: transform 0.175s;\n  transition: transform 0.175s, -webkit-transform 0.175s;\n}\n.b-toaster.b-toaster-top-right .b-toast.b-toaster-enter-to .toast.fade, .b-toaster.b-toaster-top-right .b-toast.b-toaster-enter-active .toast.fade, .b-toaster.b-toaster-top-left .b-toast.b-toaster-enter-to .toast.fade, .b-toaster.b-toaster-top-left .b-toast.b-toaster-enter-active .toast.fade, .b-toaster.b-toaster-bottom-right .b-toast.b-toaster-enter-to .toast.fade, .b-toaster.b-toaster-bottom-right .b-toast.b-toaster-enter-active .toast.fade, .b-toaster.b-toaster-bottom-left .b-toast.b-toaster-enter-to .toast.fade, .b-toaster.b-toaster-bottom-left .b-toast.b-toaster-enter-active .toast.fade {\n  transition-delay: 0.175s;\n}\n.b-toaster.b-toaster-top-right .b-toast.b-toaster-leave-active, .b-toaster.b-toaster-top-left .b-toast.b-toaster-leave-active, .b-toaster.b-toaster-bottom-right .b-toast.b-toaster-leave-active, .b-toaster.b-toaster-bottom-left .b-toast.b-toaster-leave-active {\n  position: absolute;\n  transition-delay: 0.175s;\n}\n.b-toaster.b-toaster-top-right .b-toast.b-toaster-leave-active .toast.fade, .b-toaster.b-toaster-top-left .b-toast.b-toaster-leave-active .toast.fade, .b-toaster.b-toaster-bottom-right .b-toast.b-toaster-leave-active .toast.fade, .b-toaster.b-toaster-bottom-left .b-toast.b-toaster-leave-active .toast.fade {\n  transition-delay: 0s;\n}\n.tooltip.b-tooltip {\n  display: block;\n  opacity: 0.9;\n  outline: 0;\n}\n.tooltip.b-tooltip.fade:not(.show) {\n  opacity: 0;\n}\n.tooltip.b-tooltip.show {\n  opacity: 0.9;\n}\n.tooltip.b-tooltip.noninteractive {\n  pointer-events: none;\n}\n.tooltip.b-tooltip .arrow {\n  margin: 0 0.25rem;\n}\n.tooltip.b-tooltip.bs-tooltip-right .arrow, .tooltip.b-tooltip.b-tooltip-dark.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.b-tooltip-light.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.b-tooltip-danger.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.b-tooltip-warning.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.b-tooltip-info.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.b-tooltip-success.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.b-tooltip-secondary.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.b-tooltip-primary.bs-tooltip-auto[x-placement^=right] .arrow, .tooltip.b-tooltip.bs-tooltip-left .arrow, .tooltip.b-tooltip.b-tooltip-dark.bs-tooltip-auto[x-placement^=left] .arrow, .tooltip.b-tooltip.b-tooltip-light.bs-tooltip-auto[x-placement^=left] .arrow, .tooltip.b-tooltip.b-tooltip-danger.bs-tooltip-auto[x-placement^=left] .arrow, .tooltip.b-tooltip.b-tooltip-warning.bs-tooltip-auto[x-placement^=left] .arrow, .tooltip.b-tooltip.b-tooltip-info.bs-tooltip-auto[x-placement^=left] .arrow, .tooltip.b-tooltip.b-tooltip-success.bs-tooltip-auto[x-placement^=left] .arrow, .tooltip.b-tooltip.b-tooltip-secondary.bs-tooltip-auto[x-placement^=left] .arrow, .tooltip.b-tooltip.b-tooltip-primary.bs-tooltip-auto[x-placement^=left] .arrow {\n  margin: 0.25rem 0;\n}\n\n.tooltip.b-tooltip-primary.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-primary.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #007bff;\n}\n.tooltip.b-tooltip-primary.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-primary.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #007bff;\n}\n.tooltip.b-tooltip-primary.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-primary.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #007bff;\n}\n.tooltip.b-tooltip-primary.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-primary.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #007bff;\n}\n.tooltip.b-tooltip-primary .tooltip-inner {\n  color: #fff;\n  background-color: #007bff;\n}\n\n.tooltip.b-tooltip-secondary.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-secondary.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #6c757d;\n}\n.tooltip.b-tooltip-secondary.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-secondary.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #6c757d;\n}\n.tooltip.b-tooltip-secondary.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-secondary.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #6c757d;\n}\n.tooltip.b-tooltip-secondary.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-secondary.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #6c757d;\n}\n.tooltip.b-tooltip-secondary .tooltip-inner {\n  color: #fff;\n  background-color: #6c757d;\n}\n\n.tooltip.b-tooltip-success.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-success.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #28a745;\n}\n.tooltip.b-tooltip-success.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-success.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #28a745;\n}\n.tooltip.b-tooltip-success.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-success.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #28a745;\n}\n.tooltip.b-tooltip-success.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-success.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #28a745;\n}\n.tooltip.b-tooltip-success .tooltip-inner {\n  color: #fff;\n  background-color: #28a745;\n}\n\n.tooltip.b-tooltip-info.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-info.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #17a2b8;\n}\n.tooltip.b-tooltip-info.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-info.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #17a2b8;\n}\n.tooltip.b-tooltip-info.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-info.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #17a2b8;\n}\n.tooltip.b-tooltip-info.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-info.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #17a2b8;\n}\n.tooltip.b-tooltip-info .tooltip-inner {\n  color: #fff;\n  background-color: #17a2b8;\n}\n\n.tooltip.b-tooltip-warning.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-warning.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #ffc107;\n}\n.tooltip.b-tooltip-warning.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-warning.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #ffc107;\n}\n.tooltip.b-tooltip-warning.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-warning.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #ffc107;\n}\n.tooltip.b-tooltip-warning.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-warning.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #ffc107;\n}\n.tooltip.b-tooltip-warning .tooltip-inner {\n  color: #212529;\n  background-color: #ffc107;\n}\n\n.tooltip.b-tooltip-danger.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-danger.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #dc3545;\n}\n.tooltip.b-tooltip-danger.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-danger.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #dc3545;\n}\n.tooltip.b-tooltip-danger.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-danger.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #dc3545;\n}\n.tooltip.b-tooltip-danger.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-danger.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #dc3545;\n}\n.tooltip.b-tooltip-danger .tooltip-inner {\n  color: #fff;\n  background-color: #dc3545;\n}\n\n.tooltip.b-tooltip-light.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-light.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #f8f9fa;\n}\n.tooltip.b-tooltip-light.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-light.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #f8f9fa;\n}\n.tooltip.b-tooltip-light.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-light.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #f8f9fa;\n}\n.tooltip.b-tooltip-light.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-light.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #f8f9fa;\n}\n.tooltip.b-tooltip-light .tooltip-inner {\n  color: #212529;\n  background-color: #f8f9fa;\n}\n\n.tooltip.b-tooltip-dark.bs-tooltip-top .arrow::before, .tooltip.b-tooltip-dark.bs-tooltip-auto[x-placement^=top] .arrow::before {\n  border-top-color: #343a40;\n}\n.tooltip.b-tooltip-dark.bs-tooltip-right .arrow::before, .tooltip.b-tooltip-dark.bs-tooltip-auto[x-placement^=right] .arrow::before {\n  border-right-color: #343a40;\n}\n.tooltip.b-tooltip-dark.bs-tooltip-bottom .arrow::before, .tooltip.b-tooltip-dark.bs-tooltip-auto[x-placement^=bottom] .arrow::before {\n  border-bottom-color: #343a40;\n}\n.tooltip.b-tooltip-dark.bs-tooltip-left .arrow::before, .tooltip.b-tooltip-dark.bs-tooltip-auto[x-placement^=left] .arrow::before {\n  border-left-color: #343a40;\n}\n.tooltip.b-tooltip-dark .tooltip-inner {\n  color: #fff;\n  background-color: #343a40;\n}\n\n.b-icon.bi {\n  display: inline-block;\n  overflow: visible;\n  vertical-align: -0.15em;\n}\n.b-icon.b-icon-animation-cylon, .b-icon.b-iconstack .b-icon-animation-cylon > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  -webkit-animation: 0.75s infinite ease-in-out alternate b-icon-animation-cylon;\n  animation: 0.75s infinite ease-in-out alternate b-icon-animation-cylon;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-cylon, .b-icon.b-iconstack .b-icon-animation-cylon > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n.b-icon.b-icon-animation-cylon-vertical, .b-icon.b-iconstack .b-icon-animation-cylon-vertical > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  -webkit-animation: 0.75s infinite ease-in-out alternate b-icon-animation-cylon-vertical;\n  animation: 0.75s infinite ease-in-out alternate b-icon-animation-cylon-vertical;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-cylon-vertical, .b-icon.b-iconstack .b-icon-animation-cylon-vertical > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n.b-icon.b-icon-animation-fade, .b-icon.b-iconstack .b-icon-animation-fade > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  -webkit-animation: 0.75s infinite ease-in-out alternate b-icon-animation-fade;\n  animation: 0.75s infinite ease-in-out alternate b-icon-animation-fade;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-fade, .b-icon.b-iconstack .b-icon-animation-fade > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n.b-icon.b-icon-animation-spin, .b-icon.b-iconstack .b-icon-animation-spin > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  -webkit-animation: 2s infinite linear normal b-icon-animation-spin;\n  animation: 2s infinite linear normal b-icon-animation-spin;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-spin, .b-icon.b-iconstack .b-icon-animation-spin > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n.b-icon.b-icon-animation-spin-reverse, .b-icon.b-iconstack .b-icon-animation-spin-reverse > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  animation: 2s infinite linear reverse b-icon-animation-spin;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-spin-reverse, .b-icon.b-iconstack .b-icon-animation-spin-reverse > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n.b-icon.b-icon-animation-spin-pulse, .b-icon.b-iconstack .b-icon-animation-spin-pulse > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  -webkit-animation: 1s infinite steps(8) normal b-icon-animation-spin;\n  animation: 1s infinite steps(8) normal b-icon-animation-spin;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-spin-pulse, .b-icon.b-iconstack .b-icon-animation-spin-pulse > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n.b-icon.b-icon-animation-spin-reverse-pulse, .b-icon.b-iconstack .b-icon-animation-spin-reverse-pulse > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  animation: 1s infinite steps(8) reverse b-icon-animation-spin;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-spin-reverse-pulse, .b-icon.b-iconstack .b-icon-animation-spin-reverse-pulse > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n.b-icon.b-icon-animation-throb, .b-icon.b-iconstack .b-icon-animation-throb > g {\n  -webkit-transform-origin: center;\n  transform-origin: center;\n  -webkit-animation: 0.75s infinite ease-in-out alternate b-icon-animation-throb;\n  animation: 0.75s infinite ease-in-out alternate b-icon-animation-throb;\n}\n@media (prefers-reduced-motion: reduce) {\n  .b-icon.b-icon-animation-throb, .b-icon.b-iconstack .b-icon-animation-throb > g {\n    -webkit-animation: none;\n    animation: none;\n  }\n}\n\n@-webkit-keyframes b-icon-animation-cylon {\n  0% {\n    -webkit-transform: translateX(-25%);\n    transform: translateX(-25%);\n  }\n  100% {\n    -webkit-transform: translateX(25%);\n    transform: translateX(25%);\n  }\n}\n\n@keyframes b-icon-animation-cylon {\n  0% {\n    -webkit-transform: translateX(-25%);\n    transform: translateX(-25%);\n  }\n  100% {\n    -webkit-transform: translateX(25%);\n    transform: translateX(25%);\n  }\n}\n@-webkit-keyframes b-icon-animation-cylon-vertical {\n  0% {\n    -webkit-transform: translateY(25%);\n    transform: translateY(25%);\n  }\n  100% {\n    -webkit-transform: translateY(-25%);\n    transform: translateY(-25%);\n  }\n}\n@keyframes b-icon-animation-cylon-vertical {\n  0% {\n    -webkit-transform: translateY(25%);\n    transform: translateY(25%);\n  }\n  100% {\n    -webkit-transform: translateY(-25%);\n    transform: translateY(-25%);\n  }\n}\n@-webkit-keyframes b-icon-animation-fade {\n  0% {\n    opacity: 0.1;\n  }\n  100% {\n    opacity: 1;\n  }\n}\n@keyframes b-icon-animation-fade {\n  0% {\n    opacity: 0.1;\n  }\n  100% {\n    opacity: 1;\n  }\n}\n@-webkit-keyframes b-icon-animation-spin {\n  0% {\n    -webkit-transform: rotate(0deg);\n    transform: rotate(0deg);\n  }\n  100% {\n    -webkit-transform: rotate(359deg);\n    transform: rotate(359deg);\n  }\n}\n@keyframes b-icon-animation-spin {\n  0% {\n    -webkit-transform: rotate(0deg);\n    transform: rotate(0deg);\n  }\n  100% {\n    -webkit-transform: rotate(359deg);\n    transform: rotate(359deg);\n  }\n}\n@-webkit-keyframes b-icon-animation-throb {\n  0% {\n    opacity: 0.5;\n    -webkit-transform: scale(0.5);\n    transform: scale(0.5);\n  }\n  100% {\n    opacity: 1;\n    -webkit-transform: scale(1);\n    transform: scale(1);\n  }\n}\n@keyframes b-icon-animation-throb {\n  0% {\n    opacity: 0.5;\n    -webkit-transform: scale(0.5);\n    transform: scale(0.5);\n  }\n  100% {\n    opacity: 1;\n    -webkit-transform: scale(1);\n    transform: scale(1);\n  }\n}\n.btn .b-icon.bi,\n.nav-link .b-icon.bi,\n.dropdown-toggle .b-icon.bi,\n.dropdown-item .b-icon.bi,\n.input-group-text .b-icon.bi {\n  font-size: 125%;\n  vertical-align: text-bottom;\n}",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js!./node_modules/nprogress/nprogress.css":
/*!************************************************************************!*\
  !*** ./node_modules/css-loader!./node_modules/nprogress/nprogress.css ***!
  \************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesNprogressNprogressCss(module,exports,__webpack_require__){

exports=module.exports=__webpack_require__(/*! ../css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,"/* Make clicks pass-through */\n#nprogress {\n  pointer-events: none;\n}\n\n#nprogress .bar {\n  background: #29d;\n\n  position: fixed;\n  z-index: 1031;\n  top: 0;\n  left: 0;\n\n  width: 100%;\n  height: 2px;\n}\n\n/* Fancy blur effect */\n#nprogress .peg {\n  display: block;\n  position: absolute;\n  right: 0px;\n  width: 100px;\n  height: 100%;\n  box-shadow: 0 0 10px #29d, 0 0 5px #29d;\n  opacity: 1.0;\n\n  -webkit-transform: rotate(3deg) translate(0px, -4px);\n      -ms-transform: rotate(3deg) translate(0px, -4px);\n          transform: rotate(3deg) translate(0px, -4px);\n}\n\n/* Remove these to get rid of the spinner */\n#nprogress .spinner {\n  display: block;\n  position: fixed;\n  z-index: 1031;\n  top: 15px;\n  right: 15px;\n}\n\n#nprogress .spinner-icon {\n  width: 18px;\n  height: 18px;\n  box-sizing: border-box;\n\n  border: solid 2px transparent;\n  border-top-color: #29d;\n  border-left-color: #29d;\n  border-radius: 50%;\n\n  -webkit-animation: nprogress-spinner 400ms linear infinite;\n          animation: nprogress-spinner 400ms linear infinite;\n}\n\n.nprogress-custom-parent {\n  overflow: hidden;\n  position: relative;\n}\n\n.nprogress-custom-parent #nprogress .spinner,\n.nprogress-custom-parent #nprogress .bar {\n  position: absolute;\n}\n\n@-webkit-keyframes nprogress-spinner {\n  0%   { -webkit-transform: rotate(0deg); }\n  100% { -webkit-transform: rotate(360deg); }\n}\n@keyframes nprogress-spinner {\n  0%   { transform: rotate(0deg); }\n  100% { transform: rotate(360deg); }\n}\n\n",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./resources/src/assets/styles/sass/themes/lite-purple.scss":
/*!*****************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader!./node_modules/postcss-loader/src??ref--7-2!./node_modules/sass-loader/dist/cjs.js??ref--7-3!./resources/src/assets/styles/sass/themes/lite-purple.scss ***!
  \*****************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesPostcssLoaderSrcIndexJsNode_modulesSassLoaderDistCjsJsResourcesSrcAssetsStylesSassThemesLitePurpleScss(module,exports,__webpack_require__){

var escape=__webpack_require__(/*! ../../../../../../node_modules/css-loader/lib/url/escape.js */"./node_modules/css-loader/lib/url/escape.js");
exports=module.exports=__webpack_require__(/*! ../../../../../../node_modules/css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports
exports.i(__webpack_require__(/*! -!../../../../../../node_modules/css-loader!bootstrap-vue/dist/bootstrap-vue.css */"./node_modules/css-loader/index.js!./node_modules/bootstrap-vue/dist/bootstrap-vue.css"),"");
exports.i(__webpack_require__(/*! -!../../../../../../node_modules/css-loader!vue-good-table/dist/vue-good-table.css */"./node_modules/css-loader/index.js!./node_modules/vue-good-table/dist/vue-good-table.css"),"");
exports.i(__webpack_require__(/*! -!../../../../../../node_modules/css-loader!nprogress/nprogress.css */"./node_modules/css-loader/index.js!./node_modules/nprogress/nprogress.css"),"");
exports.i(__webpack_require__(/*! -!../../../../../../node_modules/css-loader!../../../fonts/iconsmind/iconsmind.css */"./node_modules/css-loader/index.js!./resources/src/assets/fonts/iconsmind/iconsmind.css"),"");
exports.push([module.i,"@import url(https://fonts.googleapis.com/css?family=Nunito:300,400,400i,600,700,800,900);",""]);

// module
exports.push([module.i,"/*!\n * Bootstrap v4.1.3 (https://getbootstrap.com/)\n * Copyright 2011-2018 The Bootstrap Authors\n * Copyright 2011-2018 Twitter, Inc.\n * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)\n */\n:root {\n  --blue: #3b82f6;\n  --indigo: #6366f1;\n  --purple: #8b5cf6;\n  --pink: #ec4899;\n  --red: #ef4444;\n  --orange: #f97316;\n  --yellow: #f59e0b;\n  --green: #10b981;\n  --teal: #14b8a6;\n  --cyan: #06b6d4;\n  --white: #fff;\n  --gray: #4B5563;\n  --gray-dark: #1F2937;\n  --purple: #8b5cf6;\n  --pink: #ec4899;\n  --red: #ef4444;\n  --orange: #f97316;\n  --yellow: #f59e0b;\n  --green: #10b981;\n  --teal: #14b8a6;\n  --cyan: #06b6d4;\n  --white: #fff;\n  --gray: #4B5563;\n  --primary: #8b5cf6;\n  --secondary: #1F2937;\n  --success: #10b981;\n  --info: #3b82f6;\n  --warning: #f59e0b;\n  --danger: #ef4444;\n  --light: #6B7280;\n  --dark: #111827;\n  --gray-100: #F3F4F6;\n  --gray-200: #E5E7EB;\n  --gray-300: #D1D5DB;\n  --gray-400: #9CA3AF;\n  --gray-500: #6B7280;\n  --gray-600: #4B5563;\n  --gray-700: #374151;\n  --gray-800: #1F2937;\n  --gray-900: #111827;\n  --breakpoint-xs: 0;\n  --breakpoint-sm: 576px;\n  --breakpoint-md: 768px;\n  --breakpoint-lg: 992px;\n  --breakpoint-xl: 1200px;\n  --font-family-sans-serif: -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n  --font-family-monospace: SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n}\n\n*,\n*::before,\n*::after {\n  box-sizing: border-box;\n}\n\nhtml {\n  font-family: sans-serif;\n  line-height: 1.15;\n  -webkit-text-size-adjust: 100%;\n  -ms-text-size-adjust: 100%;\n  -ms-overflow-style: scrollbar;\n  -webkit-tap-highlight-color: rgba(10, 2, 30, 0);\n}\n\n@-ms-viewport {\n  width: device-width;\n}\n\narticle, aside, figcaption, figure, footer, header, hgroup, main, nav, section {\n  display: block;\n}\n\nbody {\n  margin: 0;\n  font-family: \"Nunito\", sans-serif;\n  font-size: 0.813rem;\n  font-weight: 400;\n  line-height: 1.5;\n  color: #111827;\n  text-align: left;\n  background-color: #fff;\n}\n\n[tabindex=\"-1\"]:focus {\n  outline: 0 !important;\n}\n\nhr {\n  box-sizing: content-box;\n  height: 0;\n  overflow: visible;\n}\n\nh1, h2, h3, h4, h5, h6 {\n  margin-top: 0;\n  margin-bottom: 0.5rem;\n}\n\np {\n  margin-top: 0;\n  margin-bottom: 1rem;\n}\n\nabbr[title],\nabbr[data-original-title] {\n  text-decoration: underline;\n  -webkit-text-decoration: underline dotted;\n          text-decoration: underline dotted;\n  cursor: help;\n  border-bottom: 0;\n}\n\naddress {\n  margin-bottom: 1rem;\n  font-style: normal;\n  line-height: inherit;\n}\n\nol,\nul,\ndl {\n  margin-top: 0;\n  margin-bottom: 1rem;\n}\n\nol ol,\nul ul,\nol ul,\nul ol {\n  margin-bottom: 0;\n}\n\ndt {\n  font-weight: 700;\n}\n\ndd {\n  margin-bottom: .5rem;\n  margin-left: 0;\n}\n\nblockquote {\n  margin: 0 0 1rem;\n}\n\ndfn {\n  font-style: italic;\n}\n\nb,\nstrong {\n  font-weight: bolder;\n}\n\nsmall {\n  font-size: 80%;\n}\n\nsub,\nsup {\n  position: relative;\n  font-size: 75%;\n  line-height: 0;\n  vertical-align: baseline;\n}\n\nsub {\n  bottom: -.25em;\n}\n\nsup {\n  top: -.5em;\n}\n\na {\n  color: #8b5cf6;\n  text-decoration: none;\n  background-color: transparent;\n  -webkit-text-decoration-skip: objects;\n}\n\na:hover {\n  color: #5714f2;\n  text-decoration: underline;\n}\n\na:not([href]):not([tabindex]) {\n  color: inherit;\n  text-decoration: none;\n}\n\na:not([href]):not([tabindex]):hover, a:not([href]):not([tabindex]):focus {\n  color: inherit;\n  text-decoration: none;\n}\n\na:not([href]):not([tabindex]):focus {\n  outline: 0;\n}\n\npre,\ncode,\nkbd,\nsamp {\n  font-family: SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n  font-size: 1em;\n}\n\npre {\n  margin-top: 0;\n  margin-bottom: 1rem;\n  overflow: auto;\n  -ms-overflow-style: scrollbar;\n}\n\nfigure {\n  margin: 0 0 1rem;\n}\n\nimg {\n  vertical-align: middle;\n  border-style: none;\n}\n\nsvg {\n  overflow: hidden;\n  vertical-align: middle;\n}\n\ntable {\n  border-collapse: collapse;\n}\n\ncaption {\n  padding-top: 0.75rem;\n  padding-bottom: 0.75rem;\n  color: #4B5563;\n  text-align: left;\n  caption-side: bottom;\n}\n\nth {\n  text-align: inherit;\n}\n\nlabel {\n  display: inline-block;\n  margin-bottom: 0.5rem;\n}\n\nbutton {\n  border-radius: 0;\n}\n\nbutton:focus {\n  outline: 1px dotted;\n  outline: 5px auto -webkit-focus-ring-color;\n}\n\ninput,\nbutton,\nselect,\noptgroup,\ntextarea {\n  margin: 0;\n  font-family: inherit;\n  font-size: inherit;\n  line-height: inherit;\n}\n\nbutton,\ninput {\n  overflow: visible;\n}\n\nbutton,\nselect {\n  text-transform: none;\n}\n\nbutton,\nhtml [type=\"button\"],\n[type=\"reset\"],\n[type=\"submit\"] {\n  -webkit-appearance: button;\n}\n\nbutton::-moz-focus-inner,\n[type=\"button\"]::-moz-focus-inner,\n[type=\"reset\"]::-moz-focus-inner,\n[type=\"submit\"]::-moz-focus-inner {\n  padding: 0;\n  border-style: none;\n}\n\ninput[type=\"radio\"],\ninput[type=\"checkbox\"] {\n  box-sizing: border-box;\n  padding: 0;\n}\n\ninput[type=\"date\"],\ninput[type=\"time\"],\ninput[type=\"datetime-local\"],\ninput[type=\"month\"] {\n  -webkit-appearance: listbox;\n}\n\ntextarea {\n  overflow: auto;\n  resize: vertical;\n}\n\nfieldset {\n  min-width: 0;\n  padding: 0;\n  margin: 0;\n  border: 0;\n}\n\nlegend {\n  display: block;\n  width: 100%;\n  max-width: 100%;\n  padding: 0;\n  margin-bottom: .5rem;\n  font-size: 1.5rem;\n  line-height: inherit;\n  color: inherit;\n  white-space: normal;\n}\n\nprogress {\n  vertical-align: baseline;\n}\n\n[type=\"number\"]::-webkit-inner-spin-button,\n[type=\"number\"]::-webkit-outer-spin-button {\n  height: auto;\n}\n\n[type=\"search\"] {\n  outline-offset: -2px;\n  -webkit-appearance: none;\n}\n\n[type=\"search\"]::-webkit-search-cancel-button,\n[type=\"search\"]::-webkit-search-decoration {\n  -webkit-appearance: none;\n}\n\n::-webkit-file-upload-button {\n  font: inherit;\n  -webkit-appearance: button;\n}\n\noutput {\n  display: inline-block;\n}\n\nsummary {\n  display: list-item;\n  cursor: pointer;\n}\n\ntemplate {\n  display: none;\n}\n\n[hidden] {\n  display: none !important;\n}\n\nh1, h2, h3, h4, h5, h6,\n.h1, .h2, .h3, .h4, .h5, .h6 {\n  margin-bottom: 0.5rem;\n  font-family: inherit;\n  font-weight: 500;\n  line-height: 1.2;\n  color: inherit;\n}\n\nh1, .h1 {\n  font-size: 2.0325rem;\n}\n\nh2, .h2 {\n  font-size: 1.626rem;\n}\n\nh3, .h3 {\n  font-size: 1.42275rem;\n}\n\nh4, .h4 {\n  font-size: 1.2195rem;\n}\n\nh5, .h5 {\n  font-size: 1.01625rem;\n}\n\nh6, .h6 {\n  font-size: 0.813rem;\n}\n\n.lead {\n  font-size: 1.01625rem;\n  font-weight: 300;\n}\n\n.display-1 {\n  font-size: 6rem;\n  font-weight: 300;\n  line-height: 1.2;\n}\n\n.display-2 {\n  font-size: 5.5rem;\n  font-weight: 300;\n  line-height: 1.2;\n}\n\n.display-3 {\n  font-size: 4.5rem;\n  font-weight: 300;\n  line-height: 1.2;\n}\n\n.display-4 {\n  font-size: 3.5rem;\n  font-weight: 300;\n  line-height: 1.2;\n}\n\nhr {\n  margin-top: 1rem;\n  margin-bottom: 1rem;\n  border: 0;\n  border-top: 1px solid rgba(10, 2, 30, 0.1);\n}\n\nsmall,\n.small {\n  font-size: 80%;\n  font-weight: 400;\n}\n\nmark,\n.mark {\n  padding: 0.2em;\n  background-color: #fcf8e3;\n}\n\n.list-unstyled {\n  padding-left: 0;\n  list-style: none;\n}\n\n.list-inline {\n  padding-left: 0;\n  list-style: none;\n}\n\n.list-inline-item {\n  display: inline-block;\n}\n\n.list-inline-item:not(:last-child) {\n  margin-right: 0.5rem;\n}\n\n.initialism {\n  font-size: 90%;\n  text-transform: uppercase;\n}\n\n.blockquote {\n  margin-bottom: 1rem;\n  font-size: 1.01625rem;\n}\n\n.blockquote-footer {\n  display: block;\n  font-size: 80%;\n  color: #4B5563;\n}\n\n.blockquote-footer::before {\n  content: \"\\2014   \\A0\";\n}\n\n.img-fluid {\n  max-width: 100%;\n  height: auto;\n}\n\n.img-thumbnail {\n  padding: 0.25rem;\n  background-color: #fff;\n  border: 1px solid #D1D5DB;\n  border-radius: 0.25rem;\n  max-width: 100%;\n  height: auto;\n}\n\n.figure {\n  display: inline-block;\n}\n\n.figure-img {\n  margin-bottom: 0.5rem;\n  line-height: 1;\n}\n\n.figure-caption {\n  font-size: 90%;\n  color: #4B5563;\n}\n\ncode {\n  font-size: 87.5%;\n  color: #ec4899;\n  word-break: break-word;\n}\n\na > code {\n  color: inherit;\n}\n\nkbd {\n  padding: 0.2rem 0.4rem;\n  font-size: 87.5%;\n  color: #fff;\n  background-color: #111827;\n  border-radius: 0.2rem;\n}\n\nkbd kbd {\n  padding: 0;\n  font-size: 100%;\n  font-weight: 700;\n}\n\npre {\n  display: block;\n  font-size: 87.5%;\n  color: #111827;\n}\n\npre code {\n  font-size: inherit;\n  color: inherit;\n  word-break: normal;\n}\n\n.pre-scrollable {\n  max-height: 340px;\n  overflow-y: scroll;\n}\n\n.container {\n  width: 100%;\n  padding-right: 15px;\n  padding-left: 15px;\n  margin-right: auto;\n  margin-left: auto;\n}\n\n@media (min-width: 576px) {\n  .container {\n    max-width: 540px;\n  }\n}\n\n@media (min-width: 768px) {\n  .container {\n    max-width: 720px;\n  }\n}\n\n@media (min-width: 992px) {\n  .container {\n    max-width: 960px;\n  }\n}\n\n@media (min-width: 1200px) {\n  .container {\n    max-width: 1140px;\n  }\n}\n\n.container-fluid {\n  width: 100%;\n  padding-right: 15px;\n  padding-left: 15px;\n  margin-right: auto;\n  margin-left: auto;\n}\n\n.row {\n  display: flex;\n  flex-wrap: wrap;\n  margin-right: -15px;\n  margin-left: -15px;\n}\n\n.no-gutters {\n  margin-right: 0;\n  margin-left: 0;\n}\n\n.no-gutters > .col,\n.no-gutters > [class*=\"col-\"] {\n  padding-right: 0;\n  padding-left: 0;\n}\n\n.col-1, .col-2, .col-3, .col-4, .col-5, .col-6, .col-7, .col-8, .col-9, .col-10, .col-11, .col-12, .col,\n.col-auto, .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm,\n.col-sm-auto, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-md,\n.col-md-auto, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg,\n.col-lg-auto, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12, .col-xl,\n.col-xl-auto {\n  position: relative;\n  width: 100%;\n  min-height: 1px;\n  padding-right: 15px;\n  padding-left: 15px;\n}\n\n.col {\n  flex-basis: 0;\n  flex-grow: 1;\n  max-width: 100%;\n}\n\n.col-auto {\n  flex: 0 0 auto;\n  width: auto;\n  max-width: none;\n}\n\n.col-1 {\n  flex: 0 0 8.33333333%;\n  max-width: 8.33333333%;\n}\n\n.col-2 {\n  flex: 0 0 16.66666667%;\n  max-width: 16.66666667%;\n}\n\n.col-3 {\n  flex: 0 0 25%;\n  max-width: 25%;\n}\n\n.col-4 {\n  flex: 0 0 33.33333333%;\n  max-width: 33.33333333%;\n}\n\n.col-5 {\n  flex: 0 0 41.66666667%;\n  max-width: 41.66666667%;\n}\n\n.col-6 {\n  flex: 0 0 50%;\n  max-width: 50%;\n}\n\n.col-7 {\n  flex: 0 0 58.33333333%;\n  max-width: 58.33333333%;\n}\n\n.col-8 {\n  flex: 0 0 66.66666667%;\n  max-width: 66.66666667%;\n}\n\n.col-9 {\n  flex: 0 0 75%;\n  max-width: 75%;\n}\n\n.col-10 {\n  flex: 0 0 83.33333333%;\n  max-width: 83.33333333%;\n}\n\n.col-11 {\n  flex: 0 0 91.66666667%;\n  max-width: 91.66666667%;\n}\n\n.col-12 {\n  flex: 0 0 100%;\n  max-width: 100%;\n}\n\n.order-first {\n  order: -1;\n}\n\n.order-last {\n  order: 13;\n}\n\n.order-0 {\n  order: 0;\n}\n\n.order-1 {\n  order: 1;\n}\n\n.order-2 {\n  order: 2;\n}\n\n.order-3 {\n  order: 3;\n}\n\n.order-4 {\n  order: 4;\n}\n\n.order-5 {\n  order: 5;\n}\n\n.order-6 {\n  order: 6;\n}\n\n.order-7 {\n  order: 7;\n}\n\n.order-8 {\n  order: 8;\n}\n\n.order-9 {\n  order: 9;\n}\n\n.order-10 {\n  order: 10;\n}\n\n.order-11 {\n  order: 11;\n}\n\n.order-12 {\n  order: 12;\n}\n\n.offset-1 {\n  margin-left: 8.33333333%;\n}\n\n.offset-2 {\n  margin-left: 16.66666667%;\n}\n\n.offset-3 {\n  margin-left: 25%;\n}\n\n.offset-4 {\n  margin-left: 33.33333333%;\n}\n\n.offset-5 {\n  margin-left: 41.66666667%;\n}\n\n.offset-6 {\n  margin-left: 50%;\n}\n\n.offset-7 {\n  margin-left: 58.33333333%;\n}\n\n.offset-8 {\n  margin-left: 66.66666667%;\n}\n\n.offset-9 {\n  margin-left: 75%;\n}\n\n.offset-10 {\n  margin-left: 83.33333333%;\n}\n\n.offset-11 {\n  margin-left: 91.66666667%;\n}\n\n@media (min-width: 576px) {\n  .col-sm {\n    flex-basis: 0;\n    flex-grow: 1;\n    max-width: 100%;\n  }\n  .col-sm-auto {\n    flex: 0 0 auto;\n    width: auto;\n    max-width: none;\n  }\n  .col-sm-1 {\n    flex: 0 0 8.33333333%;\n    max-width: 8.33333333%;\n  }\n  .col-sm-2 {\n    flex: 0 0 16.66666667%;\n    max-width: 16.66666667%;\n  }\n  .col-sm-3 {\n    flex: 0 0 25%;\n    max-width: 25%;\n  }\n  .col-sm-4 {\n    flex: 0 0 33.33333333%;\n    max-width: 33.33333333%;\n  }\n  .col-sm-5 {\n    flex: 0 0 41.66666667%;\n    max-width: 41.66666667%;\n  }\n  .col-sm-6 {\n    flex: 0 0 50%;\n    max-width: 50%;\n  }\n  .col-sm-7 {\n    flex: 0 0 58.33333333%;\n    max-width: 58.33333333%;\n  }\n  .col-sm-8 {\n    flex: 0 0 66.66666667%;\n    max-width: 66.66666667%;\n  }\n  .col-sm-9 {\n    flex: 0 0 75%;\n    max-width: 75%;\n  }\n  .col-sm-10 {\n    flex: 0 0 83.33333333%;\n    max-width: 83.33333333%;\n  }\n  .col-sm-11 {\n    flex: 0 0 91.66666667%;\n    max-width: 91.66666667%;\n  }\n  .col-sm-12 {\n    flex: 0 0 100%;\n    max-width: 100%;\n  }\n  .order-sm-first {\n    order: -1;\n  }\n  .order-sm-last {\n    order: 13;\n  }\n  .order-sm-0 {\n    order: 0;\n  }\n  .order-sm-1 {\n    order: 1;\n  }\n  .order-sm-2 {\n    order: 2;\n  }\n  .order-sm-3 {\n    order: 3;\n  }\n  .order-sm-4 {\n    order: 4;\n  }\n  .order-sm-5 {\n    order: 5;\n  }\n  .order-sm-6 {\n    order: 6;\n  }\n  .order-sm-7 {\n    order: 7;\n  }\n  .order-sm-8 {\n    order: 8;\n  }\n  .order-sm-9 {\n    order: 9;\n  }\n  .order-sm-10 {\n    order: 10;\n  }\n  .order-sm-11 {\n    order: 11;\n  }\n  .order-sm-12 {\n    order: 12;\n  }\n  .offset-sm-0 {\n    margin-left: 0;\n  }\n  .offset-sm-1 {\n    margin-left: 8.33333333%;\n  }\n  .offset-sm-2 {\n    margin-left: 16.66666667%;\n  }\n  .offset-sm-3 {\n    margin-left: 25%;\n  }\n  .offset-sm-4 {\n    margin-left: 33.33333333%;\n  }\n  .offset-sm-5 {\n    margin-left: 41.66666667%;\n  }\n  .offset-sm-6 {\n    margin-left: 50%;\n  }\n  .offset-sm-7 {\n    margin-left: 58.33333333%;\n  }\n  .offset-sm-8 {\n    margin-left: 66.66666667%;\n  }\n  .offset-sm-9 {\n    margin-left: 75%;\n  }\n  .offset-sm-10 {\n    margin-left: 83.33333333%;\n  }\n  .offset-sm-11 {\n    margin-left: 91.66666667%;\n  }\n}\n\n@media (min-width: 768px) {\n  .col-md {\n    flex-basis: 0;\n    flex-grow: 1;\n    max-width: 100%;\n  }\n  .col-md-auto {\n    flex: 0 0 auto;\n    width: auto;\n    max-width: none;\n  }\n  .col-md-1 {\n    flex: 0 0 8.33333333%;\n    max-width: 8.33333333%;\n  }\n  .col-md-2 {\n    flex: 0 0 16.66666667%;\n    max-width: 16.66666667%;\n  }\n  .col-md-3 {\n    flex: 0 0 25%;\n    max-width: 25%;\n  }\n  .col-md-4 {\n    flex: 0 0 33.33333333%;\n    max-width: 33.33333333%;\n  }\n  .col-md-5 {\n    flex: 0 0 41.66666667%;\n    max-width: 41.66666667%;\n  }\n  .col-md-6 {\n    flex: 0 0 50%;\n    max-width: 50%;\n  }\n  .col-md-7 {\n    flex: 0 0 58.33333333%;\n    max-width: 58.33333333%;\n  }\n  .col-md-8 {\n    flex: 0 0 66.66666667%;\n    max-width: 66.66666667%;\n  }\n  .col-md-9 {\n    flex: 0 0 75%;\n    max-width: 75%;\n  }\n  .col-md-10 {\n    flex: 0 0 83.33333333%;\n    max-width: 83.33333333%;\n  }\n  .col-md-11 {\n    flex: 0 0 91.66666667%;\n    max-width: 91.66666667%;\n  }\n  .col-md-12 {\n    flex: 0 0 100%;\n    max-width: 100%;\n  }\n  .order-md-first {\n    order: -1;\n  }\n  .order-md-last {\n    order: 13;\n  }\n  .order-md-0 {\n    order: 0;\n  }\n  .order-md-1 {\n    order: 1;\n  }\n  .order-md-2 {\n    order: 2;\n  }\n  .order-md-3 {\n    order: 3;\n  }\n  .order-md-4 {\n    order: 4;\n  }\n  .order-md-5 {\n    order: 5;\n  }\n  .order-md-6 {\n    order: 6;\n  }\n  .order-md-7 {\n    order: 7;\n  }\n  .order-md-8 {\n    order: 8;\n  }\n  .order-md-9 {\n    order: 9;\n  }\n  .order-md-10 {\n    order: 10;\n  }\n  .order-md-11 {\n    order: 11;\n  }\n  .order-md-12 {\n    order: 12;\n  }\n  .offset-md-0 {\n    margin-left: 0;\n  }\n  .offset-md-1 {\n    margin-left: 8.33333333%;\n  }\n  .offset-md-2 {\n    margin-left: 16.66666667%;\n  }\n  .offset-md-3 {\n    margin-left: 25%;\n  }\n  .offset-md-4 {\n    margin-left: 33.33333333%;\n  }\n  .offset-md-5 {\n    margin-left: 41.66666667%;\n  }\n  .offset-md-6 {\n    margin-left: 50%;\n  }\n  .offset-md-7 {\n    margin-left: 58.33333333%;\n  }\n  .offset-md-8 {\n    margin-left: 66.66666667%;\n  }\n  .offset-md-9 {\n    margin-left: 75%;\n  }\n  .offset-md-10 {\n    margin-left: 83.33333333%;\n  }\n  .offset-md-11 {\n    margin-left: 91.66666667%;\n  }\n}\n\n@media (min-width: 992px) {\n  .col-lg {\n    flex-basis: 0;\n    flex-grow: 1;\n    max-width: 100%;\n  }\n  .col-lg-auto {\n    flex: 0 0 auto;\n    width: auto;\n    max-width: none;\n  }\n  .col-lg-1 {\n    flex: 0 0 8.33333333%;\n    max-width: 8.33333333%;\n  }\n  .col-lg-2 {\n    flex: 0 0 16.66666667%;\n    max-width: 16.66666667%;\n  }\n  .col-lg-3 {\n    flex: 0 0 25%;\n    max-width: 25%;\n  }\n  .col-lg-4 {\n    flex: 0 0 33.33333333%;\n    max-width: 33.33333333%;\n  }\n  .col-lg-5 {\n    flex: 0 0 41.66666667%;\n    max-width: 41.66666667%;\n  }\n  .col-lg-6 {\n    flex: 0 0 50%;\n    max-width: 50%;\n  }\n  .col-lg-7 {\n    flex: 0 0 58.33333333%;\n    max-width: 58.33333333%;\n  }\n  .col-lg-8 {\n    flex: 0 0 66.66666667%;\n    max-width: 66.66666667%;\n  }\n  .col-lg-9 {\n    flex: 0 0 75%;\n    max-width: 75%;\n  }\n  .col-lg-10 {\n    flex: 0 0 83.33333333%;\n    max-width: 83.33333333%;\n  }\n  .col-lg-11 {\n    flex: 0 0 91.66666667%;\n    max-width: 91.66666667%;\n  }\n  .col-lg-12 {\n    flex: 0 0 100%;\n    max-width: 100%;\n  }\n  .order-lg-first {\n    order: -1;\n  }\n  .order-lg-last {\n    order: 13;\n  }\n  .order-lg-0 {\n    order: 0;\n  }\n  .order-lg-1 {\n    order: 1;\n  }\n  .order-lg-2 {\n    order: 2;\n  }\n  .order-lg-3 {\n    order: 3;\n  }\n  .order-lg-4 {\n    order: 4;\n  }\n  .order-lg-5 {\n    order: 5;\n  }\n  .order-lg-6 {\n    order: 6;\n  }\n  .order-lg-7 {\n    order: 7;\n  }\n  .order-lg-8 {\n    order: 8;\n  }\n  .order-lg-9 {\n    order: 9;\n  }\n  .order-lg-10 {\n    order: 10;\n  }\n  .order-lg-11 {\n    order: 11;\n  }\n  .order-lg-12 {\n    order: 12;\n  }\n  .offset-lg-0 {\n    margin-left: 0;\n  }\n  .offset-lg-1 {\n    margin-left: 8.33333333%;\n  }\n  .offset-lg-2 {\n    margin-left: 16.66666667%;\n  }\n  .offset-lg-3 {\n    margin-left: 25%;\n  }\n  .offset-lg-4 {\n    margin-left: 33.33333333%;\n  }\n  .offset-lg-5 {\n    margin-left: 41.66666667%;\n  }\n  .offset-lg-6 {\n    margin-left: 50%;\n  }\n  .offset-lg-7 {\n    margin-left: 58.33333333%;\n  }\n  .offset-lg-8 {\n    margin-left: 66.66666667%;\n  }\n  .offset-lg-9 {\n    margin-left: 75%;\n  }\n  .offset-lg-10 {\n    margin-left: 83.33333333%;\n  }\n  .offset-lg-11 {\n    margin-left: 91.66666667%;\n  }\n}\n\n@media (min-width: 1200px) {\n  .col-xl {\n    flex-basis: 0;\n    flex-grow: 1;\n    max-width: 100%;\n  }\n  .col-xl-auto {\n    flex: 0 0 auto;\n    width: auto;\n    max-width: none;\n  }\n  .col-xl-1 {\n    flex: 0 0 8.33333333%;\n    max-width: 8.33333333%;\n  }\n  .col-xl-2 {\n    flex: 0 0 16.66666667%;\n    max-width: 16.66666667%;\n  }\n  .col-xl-3 {\n    flex: 0 0 25%;\n    max-width: 25%;\n  }\n  .col-xl-4 {\n    flex: 0 0 33.33333333%;\n    max-width: 33.33333333%;\n  }\n  .col-xl-5 {\n    flex: 0 0 41.66666667%;\n    max-width: 41.66666667%;\n  }\n  .col-xl-6 {\n    flex: 0 0 50%;\n    max-width: 50%;\n  }\n  .col-xl-7 {\n    flex: 0 0 58.33333333%;\n    max-width: 58.33333333%;\n  }\n  .col-xl-8 {\n    flex: 0 0 66.66666667%;\n    max-width: 66.66666667%;\n  }\n  .col-xl-9 {\n    flex: 0 0 75%;\n    max-width: 75%;\n  }\n  .col-xl-10 {\n    flex: 0 0 83.33333333%;\n    max-width: 83.33333333%;\n  }\n  .col-xl-11 {\n    flex: 0 0 91.66666667%;\n    max-width: 91.66666667%;\n  }\n  .col-xl-12 {\n    flex: 0 0 100%;\n    max-width: 100%;\n  }\n  .order-xl-first {\n    order: -1;\n  }\n  .order-xl-last {\n    order: 13;\n  }\n  .order-xl-0 {\n    order: 0;\n  }\n  .order-xl-1 {\n    order: 1;\n  }\n  .order-xl-2 {\n    order: 2;\n  }\n  .order-xl-3 {\n    order: 3;\n  }\n  .order-xl-4 {\n    order: 4;\n  }\n  .order-xl-5 {\n    order: 5;\n  }\n  .order-xl-6 {\n    order: 6;\n  }\n  .order-xl-7 {\n    order: 7;\n  }\n  .order-xl-8 {\n    order: 8;\n  }\n  .order-xl-9 {\n    order: 9;\n  }\n  .order-xl-10 {\n    order: 10;\n  }\n  .order-xl-11 {\n    order: 11;\n  }\n  .order-xl-12 {\n    order: 12;\n  }\n  .offset-xl-0 {\n    margin-left: 0;\n  }\n  .offset-xl-1 {\n    margin-left: 8.33333333%;\n  }\n  .offset-xl-2 {\n    margin-left: 16.66666667%;\n  }\n  .offset-xl-3 {\n    margin-left: 25%;\n  }\n  .offset-xl-4 {\n    margin-left: 33.33333333%;\n  }\n  .offset-xl-5 {\n    margin-left: 41.66666667%;\n  }\n  .offset-xl-6 {\n    margin-left: 50%;\n  }\n  .offset-xl-7 {\n    margin-left: 58.33333333%;\n  }\n  .offset-xl-8 {\n    margin-left: 66.66666667%;\n  }\n  .offset-xl-9 {\n    margin-left: 75%;\n  }\n  .offset-xl-10 {\n    margin-left: 83.33333333%;\n  }\n  .offset-xl-11 {\n    margin-left: 91.66666667%;\n  }\n}\n\n.table {\n  width: 100%;\n  margin-bottom: 1rem;\n  background-color: transparent;\n}\n\n.table th,\n.table td {\n  padding: 0.75rem;\n  vertical-align: top;\n  border-top: 1px solid #D1D5DB;\n}\n\n.table thead th {\n  vertical-align: bottom;\n  border-bottom: 2px solid #D1D5DB;\n}\n\n.table tbody + tbody {\n  border-top: 2px solid #D1D5DB;\n}\n\n.table .table {\n  background-color: #fff;\n}\n\n.table-sm th,\n.table-sm td {\n  padding: 0.3rem;\n}\n\n.table-bordered {\n  border: 1px solid #D1D5DB;\n}\n\n.table-bordered th,\n.table-bordered td {\n  border: 1px solid #D1D5DB;\n}\n\n.table-bordered thead th,\n.table-bordered thead td {\n  border-bottom-width: 2px;\n}\n\n.table-borderless th,\n.table-borderless td,\n.table-borderless thead th,\n.table-borderless tbody + tbody {\n  border: 0;\n}\n\n.table-striped tbody tr:nth-of-type(odd) {\n  background-color: rgba(10, 2, 30, 0.05);\n}\n\n.table-hover tbody tr:hover {\n  background-color: rgba(10, 2, 30, 0.075);\n}\n\n.table-primary,\n.table-primary > th,\n.table-primary > td {\n  background-color: #dfd1fc;\n}\n\n.table-hover .table-primary:hover {\n  background-color: #ceb9fa;\n}\n\n.table-hover .table-primary:hover > td,\n.table-hover .table-primary:hover > th {\n  background-color: #ceb9fa;\n}\n\n.table-secondary,\n.table-secondary > th,\n.table-secondary > td {\n  background-color: #c0c3c7;\n}\n\n.table-hover .table-secondary:hover {\n  background-color: #b3b6bb;\n}\n\n.table-hover .table-secondary:hover > td,\n.table-hover .table-secondary:hover > th {\n  background-color: #b3b6bb;\n}\n\n.table-success,\n.table-success > th,\n.table-success > td {\n  background-color: #bcebdc;\n}\n\n.table-hover .table-success:hover {\n  background-color: #a8e5d2;\n}\n\n.table-hover .table-success:hover > td,\n.table-hover .table-success:hover > th {\n  background-color: #a8e5d2;\n}\n\n.table-info,\n.table-info > th,\n.table-info > td {\n  background-color: #c8dcfc;\n}\n\n.table-hover .table-info:hover {\n  background-color: #b0cdfb;\n}\n\n.table-hover .table-info:hover > td,\n.table-hover .table-info:hover > th {\n  background-color: #b0cdfb;\n}\n\n.table-warning,\n.table-warning > th,\n.table-warning > td {\n  background-color: #fce4bb;\n}\n\n.table-hover .table-warning:hover {\n  background-color: #fbdaa3;\n}\n\n.table-hover .table-warning:hover > td,\n.table-hover .table-warning:hover > th {\n  background-color: #fbdaa3;\n}\n\n.table-danger,\n.table-danger > th,\n.table-danger > td {\n  background-color: #fbcbcb;\n}\n\n.table-hover .table-danger:hover {\n  background-color: #f9b3b3;\n}\n\n.table-hover .table-danger:hover > td,\n.table-hover .table-danger:hover > th {\n  background-color: #f9b3b3;\n}\n\n.table-light,\n.table-light > th,\n.table-light > td {\n  background-color: #d6d8db;\n}\n\n.table-hover .table-light:hover {\n  background-color: #c8cbcf;\n}\n\n.table-hover .table-light:hover > td,\n.table-hover .table-light:hover > th {\n  background-color: #c8cbcf;\n}\n\n.table-dark,\n.table-dark > th,\n.table-dark > td {\n  background-color: #bcbec3;\n}\n\n.table-hover .table-dark:hover {\n  background-color: #afb1b7;\n}\n\n.table-hover .table-dark:hover > td,\n.table-hover .table-dark:hover > th {\n  background-color: #afb1b7;\n}\n\n.table-gray-100,\n.table-gray-100 > th,\n.table-gray-100 > td {\n  background-color: #fcfcfc;\n}\n\n.table-hover .table-gray-100:hover {\n  background-color: #efefef;\n}\n\n.table-hover .table-gray-100:hover > td,\n.table-hover .table-gray-100:hover > th {\n  background-color: #efefef;\n}\n\n.table-gray-200,\n.table-gray-200 > th,\n.table-gray-200 > td {\n  background-color: #f8f8f9;\n}\n\n.table-hover .table-gray-200:hover {\n  background-color: #eaeaed;\n}\n\n.table-hover .table-gray-200:hover > td,\n.table-hover .table-gray-200:hover > th {\n  background-color: #eaeaed;\n}\n\n.table-gray-300,\n.table-gray-300 > th,\n.table-gray-300 > td {\n  background-color: #f2f3f5;\n}\n\n.table-hover .table-gray-300:hover {\n  background-color: #e4e6ea;\n}\n\n.table-hover .table-gray-300:hover > td,\n.table-hover .table-gray-300:hover > th {\n  background-color: #e4e6ea;\n}\n\n.table-gray-400,\n.table-gray-400 > th,\n.table-gray-400 > td {\n  background-color: #e3e5e9;\n}\n\n.table-hover .table-gray-400:hover {\n  background-color: #d5d8de;\n}\n\n.table-hover .table-gray-400:hover > td,\n.table-hover .table-gray-400:hover > th {\n  background-color: #d5d8de;\n}\n\n.table-gray-500,\n.table-gray-500 > th,\n.table-gray-500 > td {\n  background-color: #d6d8db;\n}\n\n.table-hover .table-gray-500:hover {\n  background-color: #c8cbcf;\n}\n\n.table-hover .table-gray-500:hover > td,\n.table-hover .table-gray-500:hover > th {\n  background-color: #c8cbcf;\n}\n\n.table-gray-600,\n.table-gray-600 > th,\n.table-gray-600 > td {\n  background-color: #cdcfd3;\n}\n\n.table-hover .table-gray-600:hover {\n  background-color: #bfc2c7;\n}\n\n.table-hover .table-gray-600:hover > td,\n.table-hover .table-gray-600:hover > th {\n  background-color: #bfc2c7;\n}\n\n.table-gray-700,\n.table-gray-700 > th,\n.table-gray-700 > td {\n  background-color: #c7cace;\n}\n\n.table-hover .table-gray-700:hover {\n  background-color: #b9bdc2;\n}\n\n.table-hover .table-gray-700:hover > td,\n.table-hover .table-gray-700:hover > th {\n  background-color: #b9bdc2;\n}\n\n.table-gray-800,\n.table-gray-800 > th,\n.table-gray-800 > td {\n  background-color: #c0c3c7;\n}\n\n.table-hover .table-gray-800:hover {\n  background-color: #b3b6bb;\n}\n\n.table-hover .table-gray-800:hover > td,\n.table-hover .table-gray-800:hover > th {\n  background-color: #b3b6bb;\n}\n\n.table-gray-900,\n.table-gray-900 > th,\n.table-gray-900 > td {\n  background-color: #bcbec3;\n}\n\n.table-hover .table-gray-900:hover {\n  background-color: #afb1b7;\n}\n\n.table-hover .table-gray-900:hover > td,\n.table-hover .table-gray-900:hover > th {\n  background-color: #afb1b7;\n}\n\n.table-active,\n.table-active > th,\n.table-active > td {\n  background-color: rgba(10, 2, 30, 0.075);\n}\n\n.table-hover .table-active:hover {\n  background-color: rgba(2, 0, 6, 0.075);\n}\n\n.table-hover .table-active:hover > td,\n.table-hover .table-active:hover > th {\n  background-color: rgba(2, 0, 6, 0.075);\n}\n\n.table .thead-dark th {\n  color: #fff;\n  background-color: #111827;\n  border-color: #1d2842;\n}\n\n.table .thead-light th {\n  color: #374151;\n  background-color: #E5E7EB;\n  border-color: #D1D5DB;\n}\n\n.table-dark {\n  color: #fff;\n  background-color: #111827;\n}\n\n.table-dark th,\n.table-dark td,\n.table-dark thead th {\n  border-color: #1d2842;\n}\n\n.table-dark.table-bordered {\n  border: 0;\n}\n\n.table-dark.table-striped tbody tr:nth-of-type(odd) {\n  background-color: rgba(255, 255, 255, 0.05);\n}\n\n.table-dark.table-hover tbody tr:hover {\n  background-color: rgba(255, 255, 255, 0.075);\n}\n\n@media (max-width: 575.98px) {\n  .table-responsive-sm {\n    display: block;\n    width: 100%;\n    overflow-x: auto;\n    -webkit-overflow-scrolling: touch;\n    -ms-overflow-style: -ms-autohiding-scrollbar;\n  }\n  .table-responsive-sm > .table-bordered {\n    border: 0;\n  }\n}\n\n@media (max-width: 767.98px) {\n  .table-responsive-md {\n    display: block;\n    width: 100%;\n    overflow-x: auto;\n    -webkit-overflow-scrolling: touch;\n    -ms-overflow-style: -ms-autohiding-scrollbar;\n  }\n  .table-responsive-md > .table-bordered {\n    border: 0;\n  }\n}\n\n@media (max-width: 991.98px) {\n  .table-responsive-lg {\n    display: block;\n    width: 100%;\n    overflow-x: auto;\n    -webkit-overflow-scrolling: touch;\n    -ms-overflow-style: -ms-autohiding-scrollbar;\n  }\n  .table-responsive-lg > .table-bordered {\n    border: 0;\n  }\n}\n\n@media (max-width: 1199.98px) {\n  .table-responsive-xl {\n    display: block;\n    width: 100%;\n    overflow-x: auto;\n    -webkit-overflow-scrolling: touch;\n    -ms-overflow-style: -ms-autohiding-scrollbar;\n  }\n  .table-responsive-xl > .table-bordered {\n    border: 0;\n  }\n}\n\n.table-responsive {\n  display: block;\n  width: 100%;\n  overflow-x: auto;\n  -webkit-overflow-scrolling: touch;\n  -ms-overflow-style: -ms-autohiding-scrollbar;\n}\n\n.table-responsive > .table-bordered {\n  border: 0;\n}\n\n.form-control {\n  display: block;\n  width: 100%;\n  height: calc(1.9695rem + 2px);\n  padding: 0.375rem 0.75rem;\n  font-size: 0.813rem;\n  line-height: 1.5;\n  color: #374151;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #9CA3AF;\n  border-radius: 0.25rem;\n  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .form-control {\n    transition: none;\n  }\n}\n\n.form-control::-ms-expand {\n  background-color: transparent;\n  border: 0;\n}\n\n.form-control:focus {\n  color: #374151;\n  background-color: #fff;\n  border-color: #e1d5fd;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.form-control::-moz-placeholder {\n  color: #4B5563;\n  opacity: 1;\n}\n\n.form-control:-ms-input-placeholder {\n  color: #4B5563;\n  opacity: 1;\n}\n\n.form-control::placeholder {\n  color: #4B5563;\n  opacity: 1;\n}\n\n.form-control:disabled, .form-control[readonly] {\n  background-color: #E5E7EB;\n  opacity: 1;\n}\n\nselect.form-control:focus::-ms-value {\n  color: #374151;\n  background-color: #fff;\n}\n\n.form-control-file,\n.form-control-range {\n  display: block;\n  width: 100%;\n}\n\n.col-form-label {\n  padding-top: calc(0.375rem + 1px);\n  padding-bottom: calc(0.375rem + 1px);\n  margin-bottom: 0;\n  font-size: inherit;\n  line-height: 1.5;\n}\n\n.col-form-label-lg {\n  padding-top: calc(0.5rem + 1px);\n  padding-bottom: calc(0.5rem + 1px);\n  font-size: 1.01625rem;\n  line-height: 1.5;\n}\n\n.col-form-label-sm {\n  padding-top: calc(0.25rem + 1px);\n  padding-bottom: calc(0.25rem + 1px);\n  font-size: 0.711375rem;\n  line-height: 1.5;\n}\n\n.form-control-plaintext {\n  display: block;\n  width: 100%;\n  padding-top: 0.375rem;\n  padding-bottom: 0.375rem;\n  margin-bottom: 0;\n  line-height: 1.5;\n  color: #111827;\n  background-color: transparent;\n  border: solid transparent;\n  border-width: 1px 0;\n}\n\n.form-control-plaintext.form-control-sm, .form-control-plaintext.form-control-lg {\n  padding-right: 0;\n  padding-left: 0;\n}\n\n.form-control-sm {\n  height: calc( 1.5670625rem + 2px);\n  padding: 0.25rem 0.5rem;\n  font-size: 0.711375rem;\n  line-height: 1.5;\n  border-radius: 0.2rem;\n}\n\n.form-control-lg {\n  height: calc( 2.524375rem + 2px);\n  padding: 0.5rem 1rem;\n  font-size: 1.01625rem;\n  line-height: 1.5;\n  border-radius: 0.3rem;\n}\n\nselect.form-control[size], select.form-control[multiple] {\n  height: auto;\n}\n\ntextarea.form-control {\n  height: auto;\n}\n\n.form-group {\n  margin-bottom: 1rem;\n}\n\n.form-text {\n  display: block;\n  margin-top: 0.25rem;\n}\n\n.form-row {\n  display: flex;\n  flex-wrap: wrap;\n  margin-right: -5px;\n  margin-left: -5px;\n}\n\n.form-row > .col,\n.form-row > [class*=\"col-\"] {\n  padding-right: 5px;\n  padding-left: 5px;\n}\n\n.form-check {\n  position: relative;\n  display: block;\n  padding-left: 1.25rem;\n}\n\n.form-check-input {\n  position: absolute;\n  margin-top: 0.3rem;\n  margin-left: -1.25rem;\n}\n\n.form-check-input:disabled ~ .form-check-label {\n  color: #4B5563;\n}\n\n.form-check-label {\n  margin-bottom: 0;\n}\n\n.form-check-inline {\n  display: inline-flex;\n  align-items: center;\n  padding-left: 0;\n  margin-right: 0.75rem;\n}\n\n.form-check-inline .form-check-input {\n  position: static;\n  margin-top: 0;\n  margin-right: 0.3125rem;\n  margin-left: 0;\n}\n\n.valid-feedback {\n  display: none;\n  width: 100%;\n  margin-top: 0.25rem;\n  font-size: 80%;\n  color: #10b981;\n}\n\n.valid-tooltip {\n  position: absolute;\n  top: 100%;\n  z-index: 5;\n  display: none;\n  max-width: 100%;\n  padding: 0.25rem 0.5rem;\n  margin-top: .1rem;\n  font-size: 0.711375rem;\n  line-height: 1.5;\n  color: #fff;\n  background-color: rgba(16, 185, 129, 0.9);\n  border-radius: 0.25rem;\n}\n\n.was-validated .form-control:valid, .form-control.is-valid, .was-validated\n.custom-select:valid,\n.custom-select.is-valid {\n  border-color: #10b981;\n}\n\n.was-validated .form-control:valid:focus, .form-control.is-valid:focus, .was-validated\n.custom-select:valid:focus,\n.custom-select.is-valid:focus {\n  border-color: #10b981;\n  box-shadow: 0 0 0 0.2rem rgba(16, 185, 129, 0.25);\n}\n\n.was-validated .form-control:valid ~ .valid-feedback,\n.was-validated .form-control:valid ~ .valid-tooltip, .form-control.is-valid ~ .valid-feedback,\n.form-control.is-valid ~ .valid-tooltip, .was-validated\n.custom-select:valid ~ .valid-feedback,\n.was-validated\n.custom-select:valid ~ .valid-tooltip,\n.custom-select.is-valid ~ .valid-feedback,\n.custom-select.is-valid ~ .valid-tooltip {\n  display: block;\n}\n\n.was-validated .form-control-file:valid ~ .valid-feedback,\n.was-validated .form-control-file:valid ~ .valid-tooltip, .form-control-file.is-valid ~ .valid-feedback,\n.form-control-file.is-valid ~ .valid-tooltip {\n  display: block;\n}\n\n.was-validated .form-check-input:valid ~ .form-check-label, .form-check-input.is-valid ~ .form-check-label {\n  color: #10b981;\n}\n\n.was-validated .form-check-input:valid ~ .valid-feedback,\n.was-validated .form-check-input:valid ~ .valid-tooltip, .form-check-input.is-valid ~ .valid-feedback,\n.form-check-input.is-valid ~ .valid-tooltip {\n  display: block;\n}\n\n.was-validated .custom-control-input:valid ~ .custom-control-label, .custom-control-input.is-valid ~ .custom-control-label {\n  color: #10b981;\n}\n\n.was-validated .custom-control-input:valid ~ .custom-control-label::before, .custom-control-input.is-valid ~ .custom-control-label::before {\n  background-color: #58f1be;\n}\n\n.was-validated .custom-control-input:valid ~ .valid-feedback,\n.was-validated .custom-control-input:valid ~ .valid-tooltip, .custom-control-input.is-valid ~ .valid-feedback,\n.custom-control-input.is-valid ~ .valid-tooltip {\n  display: block;\n}\n\n.was-validated .custom-control-input:valid:checked ~ .custom-control-label::before, .custom-control-input.is-valid:checked ~ .custom-control-label::before {\n  background-color: #14e8a2;\n}\n\n.was-validated .custom-control-input:valid:focus ~ .custom-control-label::before, .custom-control-input.is-valid:focus ~ .custom-control-label::before {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(16, 185, 129, 0.25);\n}\n\n.was-validated .custom-file-input:valid ~ .custom-file-label, .custom-file-input.is-valid ~ .custom-file-label {\n  border-color: #10b981;\n}\n\n.was-validated .custom-file-input:valid ~ .custom-file-label::after, .custom-file-input.is-valid ~ .custom-file-label::after {\n  border-color: inherit;\n}\n\n.was-validated .custom-file-input:valid ~ .valid-feedback,\n.was-validated .custom-file-input:valid ~ .valid-tooltip, .custom-file-input.is-valid ~ .valid-feedback,\n.custom-file-input.is-valid ~ .valid-tooltip {\n  display: block;\n}\n\n.was-validated .custom-file-input:valid:focus ~ .custom-file-label, .custom-file-input.is-valid:focus ~ .custom-file-label {\n  box-shadow: 0 0 0 0.2rem rgba(16, 185, 129, 0.25);\n}\n\n.invalid-feedback {\n  display: none;\n  width: 100%;\n  margin-top: 0.25rem;\n  font-size: 80%;\n  color: #ef4444;\n}\n\n.invalid-tooltip {\n  position: absolute;\n  top: 100%;\n  z-index: 5;\n  display: none;\n  max-width: 100%;\n  padding: 0.25rem 0.5rem;\n  margin-top: .1rem;\n  font-size: 0.711375rem;\n  line-height: 1.5;\n  color: #fff;\n  background-color: rgba(239, 68, 68, 0.9);\n  border-radius: 0.25rem;\n}\n\n.was-validated .form-control:invalid, .form-control.is-invalid, .was-validated\n.custom-select:invalid,\n.custom-select.is-invalid {\n  border-color: #ef4444;\n}\n\n.was-validated .form-control:invalid:focus, .form-control.is-invalid:focus, .was-validated\n.custom-select:invalid:focus,\n.custom-select.is-invalid:focus {\n  border-color: #ef4444;\n  box-shadow: 0 0 0 0.2rem rgba(239, 68, 68, 0.25);\n}\n\n.was-validated .form-control:invalid ~ .invalid-feedback,\n.was-validated .form-control:invalid ~ .invalid-tooltip, .form-control.is-invalid ~ .invalid-feedback,\n.form-control.is-invalid ~ .invalid-tooltip, .was-validated\n.custom-select:invalid ~ .invalid-feedback,\n.was-validated\n.custom-select:invalid ~ .invalid-tooltip,\n.custom-select.is-invalid ~ .invalid-feedback,\n.custom-select.is-invalid ~ .invalid-tooltip {\n  display: block;\n}\n\n.was-validated .form-control-file:invalid ~ .invalid-feedback,\n.was-validated .form-control-file:invalid ~ .invalid-tooltip, .form-control-file.is-invalid ~ .invalid-feedback,\n.form-control-file.is-invalid ~ .invalid-tooltip {\n  display: block;\n}\n\n.was-validated .form-check-input:invalid ~ .form-check-label, .form-check-input.is-invalid ~ .form-check-label {\n  color: #ef4444;\n}\n\n.was-validated .form-check-input:invalid ~ .invalid-feedback,\n.was-validated .form-check-input:invalid ~ .invalid-tooltip, .form-check-input.is-invalid ~ .invalid-feedback,\n.form-check-input.is-invalid ~ .invalid-tooltip {\n  display: block;\n}\n\n.was-validated .custom-control-input:invalid ~ .custom-control-label, .custom-control-input.is-invalid ~ .custom-control-label {\n  color: #ef4444;\n}\n\n.was-validated .custom-control-input:invalid ~ .custom-control-label::before, .custom-control-input.is-invalid ~ .custom-control-label::before {\n  background-color: #f9b9b9;\n}\n\n.was-validated .custom-control-input:invalid ~ .invalid-feedback,\n.was-validated .custom-control-input:invalid ~ .invalid-tooltip, .custom-control-input.is-invalid ~ .invalid-feedback,\n.custom-control-input.is-invalid ~ .invalid-tooltip {\n  display: block;\n}\n\n.was-validated .custom-control-input:invalid:checked ~ .custom-control-label::before, .custom-control-input.is-invalid:checked ~ .custom-control-label::before {\n  background-color: #f37373;\n}\n\n.was-validated .custom-control-input:invalid:focus ~ .custom-control-label::before, .custom-control-input.is-invalid:focus ~ .custom-control-label::before {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(239, 68, 68, 0.25);\n}\n\n.was-validated .custom-file-input:invalid ~ .custom-file-label, .custom-file-input.is-invalid ~ .custom-file-label {\n  border-color: #ef4444;\n}\n\n.was-validated .custom-file-input:invalid ~ .custom-file-label::after, .custom-file-input.is-invalid ~ .custom-file-label::after {\n  border-color: inherit;\n}\n\n.was-validated .custom-file-input:invalid ~ .invalid-feedback,\n.was-validated .custom-file-input:invalid ~ .invalid-tooltip, .custom-file-input.is-invalid ~ .invalid-feedback,\n.custom-file-input.is-invalid ~ .invalid-tooltip {\n  display: block;\n}\n\n.was-validated .custom-file-input:invalid:focus ~ .custom-file-label, .custom-file-input.is-invalid:focus ~ .custom-file-label {\n  box-shadow: 0 0 0 0.2rem rgba(239, 68, 68, 0.25);\n}\n\n.form-inline {\n  display: flex;\n  flex-flow: row wrap;\n  align-items: center;\n}\n\n.form-inline .form-check {\n  width: 100%;\n}\n\n@media (min-width: 576px) {\n  .form-inline label {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    margin-bottom: 0;\n  }\n  .form-inline .form-group {\n    display: flex;\n    flex: 0 0 auto;\n    flex-flow: row wrap;\n    align-items: center;\n    margin-bottom: 0;\n  }\n  .form-inline .form-control {\n    display: inline-block;\n    width: auto;\n    vertical-align: middle;\n  }\n  .form-inline .form-control-plaintext {\n    display: inline-block;\n  }\n  .form-inline .input-group,\n  .form-inline .custom-select {\n    width: auto;\n  }\n  .form-inline .form-check {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    width: auto;\n    padding-left: 0;\n  }\n  .form-inline .form-check-input {\n    position: relative;\n    margin-top: 0;\n    margin-right: 0.25rem;\n    margin-left: 0;\n  }\n  .form-inline .custom-control {\n    align-items: center;\n    justify-content: center;\n  }\n  .form-inline .custom-control-label {\n    margin-bottom: 0;\n  }\n}\n\n.btn {\n  display: inline-block;\n  font-weight: 400;\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: middle;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n  border: 1px solid transparent;\n  padding: 0.375rem 0.75rem;\n  font-size: 0.813rem;\n  line-height: 1.5;\n  border-radius: 0.25rem;\n  transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .btn {\n    transition: none;\n  }\n}\n\n.btn:hover, .btn:focus {\n  text-decoration: none;\n}\n\n.btn:focus, .btn.focus {\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.btn.disabled, .btn:disabled {\n  opacity: 0.65;\n}\n\n.btn:not(:disabled):not(.disabled) {\n  cursor: pointer;\n}\n\na.btn.disabled,\nfieldset:disabled a.btn {\n  pointer-events: none;\n}\n\n.btn-primary {\n  color: #fff;\n  background-color: #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.btn-primary:hover {\n  color: #fff;\n  background-color: #7138f4;\n  border-color: #692cf3;\n}\n\n.btn-primary:focus, .btn-primary.focus {\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.5);\n}\n\n.btn-primary.disabled, .btn-primary:disabled {\n  color: #fff;\n  background-color: #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.btn-primary:not(:disabled):not(.disabled):active, .btn-primary:not(:disabled):not(.disabled).active,\n.show > .btn-primary.dropdown-toggle {\n  color: #fff;\n  background-color: #692cf3;\n  border-color: #6020f3;\n}\n\n.btn-primary:not(:disabled):not(.disabled):active:focus, .btn-primary:not(:disabled):not(.disabled).active:focus,\n.show > .btn-primary.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.5);\n}\n\n.btn-secondary {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-secondary:hover {\n  color: #fff;\n  background-color: #11171f;\n  border-color: #0d1116;\n}\n\n.btn-secondary:focus, .btn-secondary.focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-secondary.disabled, .btn-secondary:disabled {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-secondary:not(:disabled):not(.disabled):active, .btn-secondary:not(:disabled):not(.disabled).active,\n.show > .btn-secondary.dropdown-toggle {\n  color: #fff;\n  background-color: #0d1116;\n  border-color: #080b0e;\n}\n\n.btn-secondary:not(:disabled):not(.disabled):active:focus, .btn-secondary:not(:disabled):not(.disabled).active:focus,\n.show > .btn-secondary.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-success {\n  color: #fff;\n  background-color: #10b981;\n  border-color: #10b981;\n}\n\n.btn-success:hover {\n  color: #fff;\n  background-color: #0d9668;\n  border-color: #0c8a60;\n}\n\n.btn-success:focus, .btn-success.focus {\n  box-shadow: 0 0 0 0.2rem rgba(16, 185, 129, 0.5);\n}\n\n.btn-success.disabled, .btn-success:disabled {\n  color: #fff;\n  background-color: #10b981;\n  border-color: #10b981;\n}\n\n.btn-success:not(:disabled):not(.disabled):active, .btn-success:not(:disabled):not(.disabled).active,\n.show > .btn-success.dropdown-toggle {\n  color: #fff;\n  background-color: #0c8a60;\n  border-color: #0b7e58;\n}\n\n.btn-success:not(:disabled):not(.disabled):active:focus, .btn-success:not(:disabled):not(.disabled).active:focus,\n.show > .btn-success.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(16, 185, 129, 0.5);\n}\n\n.btn-info {\n  color: #fff;\n  background-color: #3b82f6;\n  border-color: #3b82f6;\n}\n\n.btn-info:hover {\n  color: #fff;\n  background-color: #166bf4;\n  border-color: #0b63f3;\n}\n\n.btn-info:focus, .btn-info.focus {\n  box-shadow: 0 0 0 0.2rem rgba(59, 130, 246, 0.5);\n}\n\n.btn-info.disabled, .btn-info:disabled {\n  color: #fff;\n  background-color: #3b82f6;\n  border-color: #3b82f6;\n}\n\n.btn-info:not(:disabled):not(.disabled):active, .btn-info:not(:disabled):not(.disabled).active,\n.show > .btn-info.dropdown-toggle {\n  color: #fff;\n  background-color: #0b63f3;\n  border-color: #0b5ee7;\n}\n\n.btn-info:not(:disabled):not(.disabled):active:focus, .btn-info:not(:disabled):not(.disabled).active:focus,\n.show > .btn-info.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(59, 130, 246, 0.5);\n}\n\n.btn-warning {\n  color: #111827;\n  background-color: #f59e0b;\n  border-color: #f59e0b;\n}\n\n.btn-warning:hover {\n  color: #fff;\n  background-color: #d18709;\n  border-color: #c57f08;\n}\n\n.btn-warning:focus, .btn-warning.focus {\n  box-shadow: 0 0 0 0.2rem rgba(245, 158, 11, 0.5);\n}\n\n.btn-warning.disabled, .btn-warning:disabled {\n  color: #111827;\n  background-color: #f59e0b;\n  border-color: #f59e0b;\n}\n\n.btn-warning:not(:disabled):not(.disabled):active, .btn-warning:not(:disabled):not(.disabled).active,\n.show > .btn-warning.dropdown-toggle {\n  color: #fff;\n  background-color: #c57f08;\n  border-color: #b97708;\n}\n\n.btn-warning:not(:disabled):not(.disabled):active:focus, .btn-warning:not(:disabled):not(.disabled).active:focus,\n.show > .btn-warning.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(245, 158, 11, 0.5);\n}\n\n.btn-danger {\n  color: #fff;\n  background-color: #ef4444;\n  border-color: #ef4444;\n}\n\n.btn-danger:hover {\n  color: #fff;\n  background-color: #ec2121;\n  border-color: #eb1515;\n}\n\n.btn-danger:focus, .btn-danger.focus {\n  box-shadow: 0 0 0 0.2rem rgba(239, 68, 68, 0.5);\n}\n\n.btn-danger.disabled, .btn-danger:disabled {\n  color: #fff;\n  background-color: #ef4444;\n  border-color: #ef4444;\n}\n\n.btn-danger:not(:disabled):not(.disabled):active, .btn-danger:not(:disabled):not(.disabled).active,\n.show > .btn-danger.dropdown-toggle {\n  color: #fff;\n  background-color: #eb1515;\n  border-color: #e01313;\n}\n\n.btn-danger:not(:disabled):not(.disabled):active:focus, .btn-danger:not(:disabled):not(.disabled).active:focus,\n.show > .btn-danger.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(239, 68, 68, 0.5);\n}\n\n.btn-light {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-light:hover {\n  color: #fff;\n  background-color: #5a5f6b;\n  border-color: #545964;\n}\n\n.btn-light:focus, .btn-light.focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-light.disabled, .btn-light:disabled {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-light:not(:disabled):not(.disabled):active, .btn-light:not(:disabled):not(.disabled).active,\n.show > .btn-light.dropdown-toggle {\n  color: #fff;\n  background-color: #545964;\n  border-color: #4e535d;\n}\n\n.btn-light:not(:disabled):not(.disabled):active:focus, .btn-light:not(:disabled):not(.disabled).active:focus,\n.show > .btn-light.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-dark {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-dark:hover {\n  color: #fff;\n  background-color: #05080c;\n  border-color: #020203;\n}\n\n.btn-dark:focus, .btn-dark.focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-dark.disabled, .btn-dark:disabled {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-dark:not(:disabled):not(.disabled):active, .btn-dark:not(:disabled):not(.disabled).active,\n.show > .btn-dark.dropdown-toggle {\n  color: #fff;\n  background-color: #020203;\n  border-color: black;\n}\n\n.btn-dark:not(:disabled):not(.disabled):active:focus, .btn-dark:not(:disabled):not(.disabled).active:focus,\n.show > .btn-dark.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-gray-100 {\n  color: #111827;\n  background-color: #F3F4F6;\n  border-color: #F3F4F6;\n}\n\n.btn-gray-100:hover {\n  color: #111827;\n  background-color: #dde0e6;\n  border-color: #d6d9e0;\n}\n\n.btn-gray-100:focus, .btn-gray-100.focus {\n  box-shadow: 0 0 0 0.2rem rgba(243, 244, 246, 0.5);\n}\n\n.btn-gray-100.disabled, .btn-gray-100:disabled {\n  color: #111827;\n  background-color: #F3F4F6;\n  border-color: #F3F4F6;\n}\n\n.btn-gray-100:not(:disabled):not(.disabled):active, .btn-gray-100:not(:disabled):not(.disabled).active,\n.show > .btn-gray-100.dropdown-toggle {\n  color: #111827;\n  background-color: #d6d9e0;\n  border-color: #cfd3db;\n}\n\n.btn-gray-100:not(:disabled):not(.disabled):active:focus, .btn-gray-100:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-100.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(243, 244, 246, 0.5);\n}\n\n.btn-gray-200 {\n  color: #111827;\n  background-color: #E5E7EB;\n  border-color: #E5E7EB;\n}\n\n.btn-gray-200:hover {\n  color: #111827;\n  background-color: #cfd3da;\n  border-color: #c8ccd5;\n}\n\n.btn-gray-200:focus, .btn-gray-200.focus {\n  box-shadow: 0 0 0 0.2rem rgba(229, 231, 235, 0.5);\n}\n\n.btn-gray-200.disabled, .btn-gray-200:disabled {\n  color: #111827;\n  background-color: #E5E7EB;\n  border-color: #E5E7EB;\n}\n\n.btn-gray-200:not(:disabled):not(.disabled):active, .btn-gray-200:not(:disabled):not(.disabled).active,\n.show > .btn-gray-200.dropdown-toggle {\n  color: #111827;\n  background-color: #c8ccd5;\n  border-color: #c1c6cf;\n}\n\n.btn-gray-200:not(:disabled):not(.disabled):active:focus, .btn-gray-200:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-200.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(229, 231, 235, 0.5);\n}\n\n.btn-gray-300 {\n  color: #111827;\n  background-color: #D1D5DB;\n  border-color: #D1D5DB;\n}\n\n.btn-gray-300:hover {\n  color: #111827;\n  background-color: #bcc1ca;\n  border-color: #b4bbc5;\n}\n\n.btn-gray-300:focus, .btn-gray-300.focus {\n  box-shadow: 0 0 0 0.2rem rgba(209, 213, 219, 0.5);\n}\n\n.btn-gray-300.disabled, .btn-gray-300:disabled {\n  color: #111827;\n  background-color: #D1D5DB;\n  border-color: #D1D5DB;\n}\n\n.btn-gray-300:not(:disabled):not(.disabled):active, .btn-gray-300:not(:disabled):not(.disabled).active,\n.show > .btn-gray-300.dropdown-toggle {\n  color: #111827;\n  background-color: #b4bbc5;\n  border-color: #adb4bf;\n}\n\n.btn-gray-300:not(:disabled):not(.disabled):active:focus, .btn-gray-300:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-300.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(209, 213, 219, 0.5);\n}\n\n.btn-gray-400 {\n  color: #111827;\n  background-color: #9CA3AF;\n  border-color: #9CA3AF;\n}\n\n.btn-gray-400:hover {\n  color: #fff;\n  background-color: #878f9e;\n  border-color: #808998;\n}\n\n.btn-gray-400:focus, .btn-gray-400.focus {\n  box-shadow: 0 0 0 0.2rem rgba(156, 163, 175, 0.5);\n}\n\n.btn-gray-400.disabled, .btn-gray-400:disabled {\n  color: #111827;\n  background-color: #9CA3AF;\n  border-color: #9CA3AF;\n}\n\n.btn-gray-400:not(:disabled):not(.disabled):active, .btn-gray-400:not(:disabled):not(.disabled).active,\n.show > .btn-gray-400.dropdown-toggle {\n  color: #fff;\n  background-color: #808998;\n  border-color: #798293;\n}\n\n.btn-gray-400:not(:disabled):not(.disabled):active:focus, .btn-gray-400:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-400.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(156, 163, 175, 0.5);\n}\n\n.btn-gray-500 {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-gray-500:hover {\n  color: #fff;\n  background-color: #5a5f6b;\n  border-color: #545964;\n}\n\n.btn-gray-500:focus, .btn-gray-500.focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-gray-500.disabled, .btn-gray-500:disabled {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-gray-500:not(:disabled):not(.disabled):active, .btn-gray-500:not(:disabled):not(.disabled).active,\n.show > .btn-gray-500.dropdown-toggle {\n  color: #fff;\n  background-color: #545964;\n  border-color: #4e535d;\n}\n\n.btn-gray-500:not(:disabled):not(.disabled):active:focus, .btn-gray-500:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-500.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-gray-600 {\n  color: #fff;\n  background-color: #4B5563;\n  border-color: #4B5563;\n}\n\n.btn-gray-600:hover {\n  color: #fff;\n  background-color: #3b424d;\n  border-color: #353c46;\n}\n\n.btn-gray-600:focus, .btn-gray-600.focus {\n  box-shadow: 0 0 0 0.2rem rgba(75, 85, 99, 0.5);\n}\n\n.btn-gray-600.disabled, .btn-gray-600:disabled {\n  color: #fff;\n  background-color: #4B5563;\n  border-color: #4B5563;\n}\n\n.btn-gray-600:not(:disabled):not(.disabled):active, .btn-gray-600:not(:disabled):not(.disabled).active,\n.show > .btn-gray-600.dropdown-toggle {\n  color: #fff;\n  background-color: #353c46;\n  border-color: #30363f;\n}\n\n.btn-gray-600:not(:disabled):not(.disabled):active:focus, .btn-gray-600:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-600.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(75, 85, 99, 0.5);\n}\n\n.btn-gray-700 {\n  color: #fff;\n  background-color: #374151;\n  border-color: #374151;\n}\n\n.btn-gray-700:hover {\n  color: #fff;\n  background-color: #282f3a;\n  border-color: #222933;\n}\n\n.btn-gray-700:focus, .btn-gray-700.focus {\n  box-shadow: 0 0 0 0.2rem rgba(55, 65, 81, 0.5);\n}\n\n.btn-gray-700.disabled, .btn-gray-700:disabled {\n  color: #fff;\n  background-color: #374151;\n  border-color: #374151;\n}\n\n.btn-gray-700:not(:disabled):not(.disabled):active, .btn-gray-700:not(:disabled):not(.disabled).active,\n.show > .btn-gray-700.dropdown-toggle {\n  color: #fff;\n  background-color: #222933;\n  border-color: #1d232b;\n}\n\n.btn-gray-700:not(:disabled):not(.disabled):active:focus, .btn-gray-700:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-700.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(55, 65, 81, 0.5);\n}\n\n.btn-gray-800 {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-gray-800:hover {\n  color: #fff;\n  background-color: #11171f;\n  border-color: #0d1116;\n}\n\n.btn-gray-800:focus, .btn-gray-800.focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-gray-800.disabled, .btn-gray-800:disabled {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-gray-800:not(:disabled):not(.disabled):active, .btn-gray-800:not(:disabled):not(.disabled).active,\n.show > .btn-gray-800.dropdown-toggle {\n  color: #fff;\n  background-color: #0d1116;\n  border-color: #080b0e;\n}\n\n.btn-gray-800:not(:disabled):not(.disabled):active:focus, .btn-gray-800:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-800.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-gray-900 {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-gray-900:hover {\n  color: #fff;\n  background-color: #05080c;\n  border-color: #020203;\n}\n\n.btn-gray-900:focus, .btn-gray-900.focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-gray-900.disabled, .btn-gray-900:disabled {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-gray-900:not(:disabled):not(.disabled):active, .btn-gray-900:not(:disabled):not(.disabled).active,\n.show > .btn-gray-900.dropdown-toggle {\n  color: #fff;\n  background-color: #020203;\n  border-color: black;\n}\n\n.btn-gray-900:not(:disabled):not(.disabled):active:focus, .btn-gray-900:not(:disabled):not(.disabled).active:focus,\n.show > .btn-gray-900.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-outline-primary {\n  color: #8b5cf6;\n  background-color: transparent;\n  background-image: none;\n  border-color: #8b5cf6;\n}\n\n.btn-outline-primary:hover {\n  color: #fff;\n  background-color: #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.btn-outline-primary:focus, .btn-outline-primary.focus {\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.5);\n}\n\n.btn-outline-primary.disabled, .btn-outline-primary:disabled {\n  color: #8b5cf6;\n  background-color: transparent;\n}\n\n.btn-outline-primary:not(:disabled):not(.disabled):active, .btn-outline-primary:not(:disabled):not(.disabled).active,\n.show > .btn-outline-primary.dropdown-toggle {\n  color: #fff;\n  background-color: #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.btn-outline-primary:not(:disabled):not(.disabled):active:focus, .btn-outline-primary:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-primary.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.5);\n}\n\n.btn-outline-secondary {\n  color: #1F2937;\n  background-color: transparent;\n  background-image: none;\n  border-color: #1F2937;\n}\n\n.btn-outline-secondary:hover {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-outline-secondary:focus, .btn-outline-secondary.focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-outline-secondary.disabled, .btn-outline-secondary:disabled {\n  color: #1F2937;\n  background-color: transparent;\n}\n\n.btn-outline-secondary:not(:disabled):not(.disabled):active, .btn-outline-secondary:not(:disabled):not(.disabled).active,\n.show > .btn-outline-secondary.dropdown-toggle {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-outline-secondary:not(:disabled):not(.disabled):active:focus, .btn-outline-secondary:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-secondary.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-outline-success {\n  color: #10b981;\n  background-color: transparent;\n  background-image: none;\n  border-color: #10b981;\n}\n\n.btn-outline-success:hover {\n  color: #fff;\n  background-color: #10b981;\n  border-color: #10b981;\n}\n\n.btn-outline-success:focus, .btn-outline-success.focus {\n  box-shadow: 0 0 0 0.2rem rgba(16, 185, 129, 0.5);\n}\n\n.btn-outline-success.disabled, .btn-outline-success:disabled {\n  color: #10b981;\n  background-color: transparent;\n}\n\n.btn-outline-success:not(:disabled):not(.disabled):active, .btn-outline-success:not(:disabled):not(.disabled).active,\n.show > .btn-outline-success.dropdown-toggle {\n  color: #fff;\n  background-color: #10b981;\n  border-color: #10b981;\n}\n\n.btn-outline-success:not(:disabled):not(.disabled):active:focus, .btn-outline-success:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-success.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(16, 185, 129, 0.5);\n}\n\n.btn-outline-info {\n  color: #3b82f6;\n  background-color: transparent;\n  background-image: none;\n  border-color: #3b82f6;\n}\n\n.btn-outline-info:hover {\n  color: #fff;\n  background-color: #3b82f6;\n  border-color: #3b82f6;\n}\n\n.btn-outline-info:focus, .btn-outline-info.focus {\n  box-shadow: 0 0 0 0.2rem rgba(59, 130, 246, 0.5);\n}\n\n.btn-outline-info.disabled, .btn-outline-info:disabled {\n  color: #3b82f6;\n  background-color: transparent;\n}\n\n.btn-outline-info:not(:disabled):not(.disabled):active, .btn-outline-info:not(:disabled):not(.disabled).active,\n.show > .btn-outline-info.dropdown-toggle {\n  color: #fff;\n  background-color: #3b82f6;\n  border-color: #3b82f6;\n}\n\n.btn-outline-info:not(:disabled):not(.disabled):active:focus, .btn-outline-info:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-info.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(59, 130, 246, 0.5);\n}\n\n.btn-outline-warning {\n  color: #f59e0b;\n  background-color: transparent;\n  background-image: none;\n  border-color: #f59e0b;\n}\n\n.btn-outline-warning:hover {\n  color: #111827;\n  background-color: #f59e0b;\n  border-color: #f59e0b;\n}\n\n.btn-outline-warning:focus, .btn-outline-warning.focus {\n  box-shadow: 0 0 0 0.2rem rgba(245, 158, 11, 0.5);\n}\n\n.btn-outline-warning.disabled, .btn-outline-warning:disabled {\n  color: #f59e0b;\n  background-color: transparent;\n}\n\n.btn-outline-warning:not(:disabled):not(.disabled):active, .btn-outline-warning:not(:disabled):not(.disabled).active,\n.show > .btn-outline-warning.dropdown-toggle {\n  color: #111827;\n  background-color: #f59e0b;\n  border-color: #f59e0b;\n}\n\n.btn-outline-warning:not(:disabled):not(.disabled):active:focus, .btn-outline-warning:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-warning.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(245, 158, 11, 0.5);\n}\n\n.btn-outline-danger {\n  color: #ef4444;\n  background-color: transparent;\n  background-image: none;\n  border-color: #ef4444;\n}\n\n.btn-outline-danger:hover {\n  color: #fff;\n  background-color: #ef4444;\n  border-color: #ef4444;\n}\n\n.btn-outline-danger:focus, .btn-outline-danger.focus {\n  box-shadow: 0 0 0 0.2rem rgba(239, 68, 68, 0.5);\n}\n\n.btn-outline-danger.disabled, .btn-outline-danger:disabled {\n  color: #ef4444;\n  background-color: transparent;\n}\n\n.btn-outline-danger:not(:disabled):not(.disabled):active, .btn-outline-danger:not(:disabled):not(.disabled).active,\n.show > .btn-outline-danger.dropdown-toggle {\n  color: #fff;\n  background-color: #ef4444;\n  border-color: #ef4444;\n}\n\n.btn-outline-danger:not(:disabled):not(.disabled):active:focus, .btn-outline-danger:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-danger.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(239, 68, 68, 0.5);\n}\n\n.btn-outline-light {\n  color: #6B7280;\n  background-color: transparent;\n  background-image: none;\n  border-color: #6B7280;\n}\n\n.btn-outline-light:hover {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-outline-light:focus, .btn-outline-light.focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-outline-light.disabled, .btn-outline-light:disabled {\n  color: #6B7280;\n  background-color: transparent;\n}\n\n.btn-outline-light:not(:disabled):not(.disabled):active, .btn-outline-light:not(:disabled):not(.disabled).active,\n.show > .btn-outline-light.dropdown-toggle {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-outline-light:not(:disabled):not(.disabled):active:focus, .btn-outline-light:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-light.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-outline-dark {\n  color: #111827;\n  background-color: transparent;\n  background-image: none;\n  border-color: #111827;\n}\n\n.btn-outline-dark:hover {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-outline-dark:focus, .btn-outline-dark.focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-outline-dark.disabled, .btn-outline-dark:disabled {\n  color: #111827;\n  background-color: transparent;\n}\n\n.btn-outline-dark:not(:disabled):not(.disabled):active, .btn-outline-dark:not(:disabled):not(.disabled).active,\n.show > .btn-outline-dark.dropdown-toggle {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-outline-dark:not(:disabled):not(.disabled):active:focus, .btn-outline-dark:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-dark.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-outline-gray-100 {\n  color: #F3F4F6;\n  background-color: transparent;\n  background-image: none;\n  border-color: #F3F4F6;\n}\n\n.btn-outline-gray-100:hover {\n  color: #111827;\n  background-color: #F3F4F6;\n  border-color: #F3F4F6;\n}\n\n.btn-outline-gray-100:focus, .btn-outline-gray-100.focus {\n  box-shadow: 0 0 0 0.2rem rgba(243, 244, 246, 0.5);\n}\n\n.btn-outline-gray-100.disabled, .btn-outline-gray-100:disabled {\n  color: #F3F4F6;\n  background-color: transparent;\n}\n\n.btn-outline-gray-100:not(:disabled):not(.disabled):active, .btn-outline-gray-100:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-100.dropdown-toggle {\n  color: #111827;\n  background-color: #F3F4F6;\n  border-color: #F3F4F6;\n}\n\n.btn-outline-gray-100:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-100:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-100.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(243, 244, 246, 0.5);\n}\n\n.btn-outline-gray-200 {\n  color: #E5E7EB;\n  background-color: transparent;\n  background-image: none;\n  border-color: #E5E7EB;\n}\n\n.btn-outline-gray-200:hover {\n  color: #111827;\n  background-color: #E5E7EB;\n  border-color: #E5E7EB;\n}\n\n.btn-outline-gray-200:focus, .btn-outline-gray-200.focus {\n  box-shadow: 0 0 0 0.2rem rgba(229, 231, 235, 0.5);\n}\n\n.btn-outline-gray-200.disabled, .btn-outline-gray-200:disabled {\n  color: #E5E7EB;\n  background-color: transparent;\n}\n\n.btn-outline-gray-200:not(:disabled):not(.disabled):active, .btn-outline-gray-200:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-200.dropdown-toggle {\n  color: #111827;\n  background-color: #E5E7EB;\n  border-color: #E5E7EB;\n}\n\n.btn-outline-gray-200:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-200:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-200.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(229, 231, 235, 0.5);\n}\n\n.btn-outline-gray-300 {\n  color: #D1D5DB;\n  background-color: transparent;\n  background-image: none;\n  border-color: #D1D5DB;\n}\n\n.btn-outline-gray-300:hover {\n  color: #111827;\n  background-color: #D1D5DB;\n  border-color: #D1D5DB;\n}\n\n.btn-outline-gray-300:focus, .btn-outline-gray-300.focus {\n  box-shadow: 0 0 0 0.2rem rgba(209, 213, 219, 0.5);\n}\n\n.btn-outline-gray-300.disabled, .btn-outline-gray-300:disabled {\n  color: #D1D5DB;\n  background-color: transparent;\n}\n\n.btn-outline-gray-300:not(:disabled):not(.disabled):active, .btn-outline-gray-300:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-300.dropdown-toggle {\n  color: #111827;\n  background-color: #D1D5DB;\n  border-color: #D1D5DB;\n}\n\n.btn-outline-gray-300:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-300:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-300.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(209, 213, 219, 0.5);\n}\n\n.btn-outline-gray-400 {\n  color: #9CA3AF;\n  background-color: transparent;\n  background-image: none;\n  border-color: #9CA3AF;\n}\n\n.btn-outline-gray-400:hover {\n  color: #111827;\n  background-color: #9CA3AF;\n  border-color: #9CA3AF;\n}\n\n.btn-outline-gray-400:focus, .btn-outline-gray-400.focus {\n  box-shadow: 0 0 0 0.2rem rgba(156, 163, 175, 0.5);\n}\n\n.btn-outline-gray-400.disabled, .btn-outline-gray-400:disabled {\n  color: #9CA3AF;\n  background-color: transparent;\n}\n\n.btn-outline-gray-400:not(:disabled):not(.disabled):active, .btn-outline-gray-400:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-400.dropdown-toggle {\n  color: #111827;\n  background-color: #9CA3AF;\n  border-color: #9CA3AF;\n}\n\n.btn-outline-gray-400:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-400:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-400.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(156, 163, 175, 0.5);\n}\n\n.btn-outline-gray-500 {\n  color: #6B7280;\n  background-color: transparent;\n  background-image: none;\n  border-color: #6B7280;\n}\n\n.btn-outline-gray-500:hover {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-outline-gray-500:focus, .btn-outline-gray-500.focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-outline-gray-500.disabled, .btn-outline-gray-500:disabled {\n  color: #6B7280;\n  background-color: transparent;\n}\n\n.btn-outline-gray-500:not(:disabled):not(.disabled):active, .btn-outline-gray-500:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-500.dropdown-toggle {\n  color: #fff;\n  background-color: #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-outline-gray-500:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-500:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-500.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(107, 114, 128, 0.5);\n}\n\n.btn-outline-gray-600 {\n  color: #4B5563;\n  background-color: transparent;\n  background-image: none;\n  border-color: #4B5563;\n}\n\n.btn-outline-gray-600:hover {\n  color: #fff;\n  background-color: #4B5563;\n  border-color: #4B5563;\n}\n\n.btn-outline-gray-600:focus, .btn-outline-gray-600.focus {\n  box-shadow: 0 0 0 0.2rem rgba(75, 85, 99, 0.5);\n}\n\n.btn-outline-gray-600.disabled, .btn-outline-gray-600:disabled {\n  color: #4B5563;\n  background-color: transparent;\n}\n\n.btn-outline-gray-600:not(:disabled):not(.disabled):active, .btn-outline-gray-600:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-600.dropdown-toggle {\n  color: #fff;\n  background-color: #4B5563;\n  border-color: #4B5563;\n}\n\n.btn-outline-gray-600:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-600:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-600.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(75, 85, 99, 0.5);\n}\n\n.btn-outline-gray-700 {\n  color: #374151;\n  background-color: transparent;\n  background-image: none;\n  border-color: #374151;\n}\n\n.btn-outline-gray-700:hover {\n  color: #fff;\n  background-color: #374151;\n  border-color: #374151;\n}\n\n.btn-outline-gray-700:focus, .btn-outline-gray-700.focus {\n  box-shadow: 0 0 0 0.2rem rgba(55, 65, 81, 0.5);\n}\n\n.btn-outline-gray-700.disabled, .btn-outline-gray-700:disabled {\n  color: #374151;\n  background-color: transparent;\n}\n\n.btn-outline-gray-700:not(:disabled):not(.disabled):active, .btn-outline-gray-700:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-700.dropdown-toggle {\n  color: #fff;\n  background-color: #374151;\n  border-color: #374151;\n}\n\n.btn-outline-gray-700:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-700:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-700.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(55, 65, 81, 0.5);\n}\n\n.btn-outline-gray-800 {\n  color: #1F2937;\n  background-color: transparent;\n  background-image: none;\n  border-color: #1F2937;\n}\n\n.btn-outline-gray-800:hover {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-outline-gray-800:focus, .btn-outline-gray-800.focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-outline-gray-800.disabled, .btn-outline-gray-800:disabled {\n  color: #1F2937;\n  background-color: transparent;\n}\n\n.btn-outline-gray-800:not(:disabled):not(.disabled):active, .btn-outline-gray-800:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-800.dropdown-toggle {\n  color: #fff;\n  background-color: #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-outline-gray-800:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-800:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-800.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(31, 41, 55, 0.5);\n}\n\n.btn-outline-gray-900 {\n  color: #111827;\n  background-color: transparent;\n  background-image: none;\n  border-color: #111827;\n}\n\n.btn-outline-gray-900:hover {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-outline-gray-900:focus, .btn-outline-gray-900.focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-outline-gray-900.disabled, .btn-outline-gray-900:disabled {\n  color: #111827;\n  background-color: transparent;\n}\n\n.btn-outline-gray-900:not(:disabled):not(.disabled):active, .btn-outline-gray-900:not(:disabled):not(.disabled).active,\n.show > .btn-outline-gray-900.dropdown-toggle {\n  color: #fff;\n  background-color: #111827;\n  border-color: #111827;\n}\n\n.btn-outline-gray-900:not(:disabled):not(.disabled):active:focus, .btn-outline-gray-900:not(:disabled):not(.disabled).active:focus,\n.show > .btn-outline-gray-900.dropdown-toggle:focus {\n  box-shadow: 0 0 0 0.2rem rgba(17, 24, 39, 0.5);\n}\n\n.btn-link {\n  font-weight: 400;\n  color: #8b5cf6;\n  background-color: transparent;\n}\n\n.btn-link:hover {\n  color: #5714f2;\n  text-decoration: underline;\n  background-color: transparent;\n  border-color: transparent;\n}\n\n.btn-link:focus, .btn-link.focus {\n  text-decoration: underline;\n  border-color: transparent;\n  box-shadow: none;\n}\n\n.btn-link:disabled, .btn-link.disabled {\n  color: #4B5563;\n  pointer-events: none;\n}\n\n.btn-lg, .btn-group-lg > .btn {\n  padding: 0.5rem 1rem;\n  font-size: 1.01625rem;\n  line-height: 1.5;\n  border-radius: 0.3rem;\n}\n\n.btn-sm, .btn-group-sm > .btn {\n  padding: 0.25rem 0.5rem;\n  font-size: 0.711375rem;\n  line-height: 1.5;\n  border-radius: 0.2rem;\n}\n\n.btn-block {\n  display: block;\n  width: 100%;\n}\n\n.btn-block + .btn-block {\n  margin-top: 0.5rem;\n}\n\ninput[type=\"submit\"].btn-block,\ninput[type=\"reset\"].btn-block,\ninput[type=\"button\"].btn-block {\n  width: 100%;\n}\n\n.fade {\n  transition: opacity 0.15s linear;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .fade {\n    transition: none;\n  }\n}\n\n.fade:not(.show) {\n  opacity: 0;\n}\n\n.collapse:not(.show) {\n  display: none;\n}\n\n.collapsing {\n  position: relative;\n  height: 0;\n  overflow: hidden;\n  transition: height 0.35s ease;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .collapsing {\n    transition: none;\n  }\n}\n\n.dropup,\n.dropright,\n.dropdown,\n.dropleft {\n  position: relative;\n}\n\n.dropdown-toggle::after {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  margin-left: 0.255em;\n  vertical-align: 0.255em;\n  content: \"\";\n  border-top: 0.3em solid;\n  border-right: 0.3em solid transparent;\n  border-bottom: 0;\n  border-left: 0.3em solid transparent;\n}\n\n.dropdown-toggle:empty::after {\n  margin-left: 0;\n}\n\n.dropdown-menu {\n  position: absolute;\n  top: 100%;\n  left: 0;\n  z-index: 1000;\n  display: none;\n  float: left;\n  min-width: 10rem;\n  padding: 0.5rem 0;\n  margin: 0.125rem 0 0;\n  font-size: 0.813rem;\n  color: #111827;\n  text-align: left;\n  list-style: none;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid rgba(10, 2, 30, 0.15);\n  border-radius: 0.25rem;\n}\n\n.dropdown-menu-right {\n  right: 0;\n  left: auto;\n}\n\n.dropup .dropdown-menu {\n  top: auto;\n  bottom: 100%;\n  margin-top: 0;\n  margin-bottom: 0.125rem;\n}\n\n.dropup .dropdown-toggle::after {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  margin-left: 0.255em;\n  vertical-align: 0.255em;\n  content: \"\";\n  border-top: 0;\n  border-right: 0.3em solid transparent;\n  border-bottom: 0.3em solid;\n  border-left: 0.3em solid transparent;\n}\n\n.dropup .dropdown-toggle:empty::after {\n  margin-left: 0;\n}\n\n.dropright .dropdown-menu {\n  top: 0;\n  right: auto;\n  left: 100%;\n  margin-top: 0;\n  margin-left: 0.125rem;\n}\n\n.dropright .dropdown-toggle::after {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  margin-left: 0.255em;\n  vertical-align: 0.255em;\n  content: \"\";\n  border-top: 0.3em solid transparent;\n  border-right: 0;\n  border-bottom: 0.3em solid transparent;\n  border-left: 0.3em solid;\n}\n\n.dropright .dropdown-toggle:empty::after {\n  margin-left: 0;\n}\n\n.dropright .dropdown-toggle::after {\n  vertical-align: 0;\n}\n\n.dropleft .dropdown-menu {\n  top: 0;\n  right: 100%;\n  left: auto;\n  margin-top: 0;\n  margin-right: 0.125rem;\n}\n\n.dropleft .dropdown-toggle::after {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  margin-left: 0.255em;\n  vertical-align: 0.255em;\n  content: \"\";\n}\n\n.dropleft .dropdown-toggle::after {\n  display: none;\n}\n\n.dropleft .dropdown-toggle::before {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  margin-right: 0.255em;\n  vertical-align: 0.255em;\n  content: \"\";\n  border-top: 0.3em solid transparent;\n  border-right: 0.3em solid;\n  border-bottom: 0.3em solid transparent;\n}\n\n.dropleft .dropdown-toggle:empty::after {\n  margin-left: 0;\n}\n\n.dropleft .dropdown-toggle::before {\n  vertical-align: 0;\n}\n\n.dropdown-menu[x-placement^=\"top\"], .dropdown-menu[x-placement^=\"right\"], .dropdown-menu[x-placement^=\"bottom\"], .dropdown-menu[x-placement^=\"left\"] {\n  right: auto;\n  bottom: auto;\n}\n\n.dropdown-divider {\n  height: 0;\n  margin: 0.5rem 0;\n  overflow: hidden;\n  border-top: 1px solid #E5E7EB;\n}\n\n.dropdown-item {\n  display: block;\n  width: 100%;\n  padding: 0.25rem 1.5rem;\n  clear: both;\n  font-weight: 400;\n  color: #111827;\n  text-align: inherit;\n  white-space: nowrap;\n  background-color: transparent;\n  border: 0;\n}\n\n.dropdown-item:hover, .dropdown-item:focus {\n  color: #090d15;\n  text-decoration: none;\n  background-color: #F3F4F6;\n}\n\n.dropdown-item.active, .dropdown-item:active {\n  color: #fff;\n  text-decoration: none;\n  background-color: #8b5cf6;\n}\n\n.dropdown-item.disabled, .dropdown-item:disabled {\n  color: #4B5563;\n  background-color: transparent;\n}\n\n.dropdown-menu.show {\n  display: block;\n}\n\n.dropdown-header {\n  display: block;\n  padding: 0.5rem 1.5rem;\n  margin-bottom: 0;\n  font-size: 0.711375rem;\n  color: #4B5563;\n  white-space: nowrap;\n}\n\n.dropdown-item-text {\n  display: block;\n  padding: 0.25rem 1.5rem;\n  color: #111827;\n}\n\n.btn-group,\n.btn-group-vertical {\n  position: relative;\n  display: inline-flex;\n  vertical-align: middle;\n}\n\n.btn-group > .btn,\n.btn-group-vertical > .btn {\n  position: relative;\n  flex: 0 1 auto;\n}\n\n.btn-group > .btn:hover,\n.btn-group-vertical > .btn:hover {\n  z-index: 1;\n}\n\n.btn-group > .btn:focus, .btn-group > .btn:active, .btn-group > .btn.active,\n.btn-group-vertical > .btn:focus,\n.btn-group-vertical > .btn:active,\n.btn-group-vertical > .btn.active {\n  z-index: 1;\n}\n\n.btn-group .btn + .btn,\n.btn-group .btn + .btn-group,\n.btn-group .btn-group + .btn,\n.btn-group .btn-group + .btn-group,\n.btn-group-vertical .btn + .btn,\n.btn-group-vertical .btn + .btn-group,\n.btn-group-vertical .btn-group + .btn,\n.btn-group-vertical .btn-group + .btn-group {\n  margin-left: -1px;\n}\n\n.btn-toolbar {\n  display: flex;\n  flex-wrap: wrap;\n  justify-content: flex-start;\n}\n\n.btn-toolbar .input-group {\n  width: auto;\n}\n\n.btn-group > .btn:first-child {\n  margin-left: 0;\n}\n\n.btn-group > .btn:not(:last-child):not(.dropdown-toggle),\n.btn-group > .btn-group:not(:last-child) > .btn {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.btn-group > .btn:not(:first-child),\n.btn-group > .btn-group:not(:first-child) > .btn {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.dropdown-toggle-split {\n  padding-right: 0.5625rem;\n  padding-left: 0.5625rem;\n}\n\n.dropdown-toggle-split::after,\n.dropup .dropdown-toggle-split::after,\n.dropright .dropdown-toggle-split::after {\n  margin-left: 0;\n}\n\n.dropleft .dropdown-toggle-split::before {\n  margin-right: 0;\n}\n\n.btn-sm + .dropdown-toggle-split, .btn-group-sm > .btn + .dropdown-toggle-split {\n  padding-right: 0.375rem;\n  padding-left: 0.375rem;\n}\n\n.btn-lg + .dropdown-toggle-split, .btn-group-lg > .btn + .dropdown-toggle-split {\n  padding-right: 0.75rem;\n  padding-left: 0.75rem;\n}\n\n.btn-group-vertical {\n  flex-direction: column;\n  align-items: flex-start;\n  justify-content: center;\n}\n\n.btn-group-vertical .btn,\n.btn-group-vertical .btn-group {\n  width: 100%;\n}\n\n.btn-group-vertical > .btn + .btn,\n.btn-group-vertical > .btn + .btn-group,\n.btn-group-vertical > .btn-group + .btn,\n.btn-group-vertical > .btn-group + .btn-group {\n  margin-top: -1px;\n  margin-left: 0;\n}\n\n.btn-group-vertical > .btn:not(:last-child):not(.dropdown-toggle),\n.btn-group-vertical > .btn-group:not(:last-child) > .btn {\n  border-bottom-right-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.btn-group-vertical > .btn:not(:first-child),\n.btn-group-vertical > .btn-group:not(:first-child) > .btn {\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n\n.btn-group-toggle > .btn,\n.btn-group-toggle > .btn-group > .btn {\n  margin-bottom: 0;\n}\n\n.btn-group-toggle > .btn input[type=\"radio\"],\n.btn-group-toggle > .btn input[type=\"checkbox\"],\n.btn-group-toggle > .btn-group > .btn input[type=\"radio\"],\n.btn-group-toggle > .btn-group > .btn input[type=\"checkbox\"] {\n  position: absolute;\n  clip: rect(0, 0, 0, 0);\n  pointer-events: none;\n}\n\n.input-group {\n  position: relative;\n  display: flex;\n  flex-wrap: wrap;\n  align-items: stretch;\n  width: 100%;\n}\n\n.input-group > .form-control,\n.input-group > .custom-select,\n.input-group > .custom-file {\n  position: relative;\n  flex: 1 1 auto;\n  width: 1%;\n  margin-bottom: 0;\n}\n\n.input-group > .form-control + .form-control,\n.input-group > .form-control + .custom-select,\n.input-group > .form-control + .custom-file,\n.input-group > .custom-select + .form-control,\n.input-group > .custom-select + .custom-select,\n.input-group > .custom-select + .custom-file,\n.input-group > .custom-file + .form-control,\n.input-group > .custom-file + .custom-select,\n.input-group > .custom-file + .custom-file {\n  margin-left: -1px;\n}\n\n.input-group > .form-control:focus,\n.input-group > .custom-select:focus,\n.input-group > .custom-file .custom-file-input:focus ~ .custom-file-label {\n  z-index: 3;\n}\n\n.input-group > .custom-file .custom-file-input:focus {\n  z-index: 4;\n}\n\n.input-group > .form-control:not(:last-child),\n.input-group > .custom-select:not(:last-child) {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.input-group > .form-control:not(:first-child),\n.input-group > .custom-select:not(:first-child) {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.input-group > .custom-file {\n  display: flex;\n  align-items: center;\n}\n\n.input-group > .custom-file:not(:last-child) .custom-file-label,\n.input-group > .custom-file:not(:last-child) .custom-file-label::after {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.input-group > .custom-file:not(:first-child) .custom-file-label {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.input-group-prepend,\n.input-group-append {\n  display: flex;\n}\n\n.input-group-prepend .btn,\n.input-group-append .btn {\n  position: relative;\n  z-index: 2;\n}\n\n.input-group-prepend .btn + .btn,\n.input-group-prepend .btn + .input-group-text,\n.input-group-prepend .input-group-text + .input-group-text,\n.input-group-prepend .input-group-text + .btn,\n.input-group-append .btn + .btn,\n.input-group-append .btn + .input-group-text,\n.input-group-append .input-group-text + .input-group-text,\n.input-group-append .input-group-text + .btn {\n  margin-left: -1px;\n}\n\n.input-group-prepend {\n  margin-right: -1px;\n}\n\n.input-group-append {\n  margin-left: -1px;\n}\n\n.input-group-text {\n  display: flex;\n  align-items: center;\n  padding: 0.375rem 0.75rem;\n  margin-bottom: 0;\n  font-size: 0.813rem;\n  font-weight: 400;\n  line-height: 1.5;\n  color: #374151;\n  text-align: center;\n  white-space: nowrap;\n  background-color: #E5E7EB;\n  border: 1px solid #9CA3AF;\n  border-radius: 0.25rem;\n}\n\n.input-group-text input[type=\"radio\"],\n.input-group-text input[type=\"checkbox\"] {\n  margin-top: 0;\n}\n\n.input-group-lg > .form-control,\n.input-group-lg > .input-group-prepend > .input-group-text,\n.input-group-lg > .input-group-append > .input-group-text,\n.input-group-lg > .input-group-prepend > .btn,\n.input-group-lg > .input-group-append > .btn {\n  height: calc( 2.524375rem + 2px);\n  padding: 0.5rem 1rem;\n  font-size: 1.01625rem;\n  line-height: 1.5;\n  border-radius: 0.3rem;\n}\n\n.input-group-sm > .form-control,\n.input-group-sm > .input-group-prepend > .input-group-text,\n.input-group-sm > .input-group-append > .input-group-text,\n.input-group-sm > .input-group-prepend > .btn,\n.input-group-sm > .input-group-append > .btn {\n  height: calc( 1.5670625rem + 2px);\n  padding: 0.25rem 0.5rem;\n  font-size: 0.711375rem;\n  line-height: 1.5;\n  border-radius: 0.2rem;\n}\n\n.input-group > .input-group-prepend > .btn,\n.input-group > .input-group-prepend > .input-group-text,\n.input-group > .input-group-append:not(:last-child) > .btn,\n.input-group > .input-group-append:not(:last-child) > .input-group-text,\n.input-group > .input-group-append:last-child > .btn:not(:last-child):not(.dropdown-toggle),\n.input-group > .input-group-append:last-child > .input-group-text:not(:last-child) {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.input-group > .input-group-append > .btn,\n.input-group > .input-group-append > .input-group-text,\n.input-group > .input-group-prepend:not(:first-child) > .btn,\n.input-group > .input-group-prepend:not(:first-child) > .input-group-text,\n.input-group > .input-group-prepend:first-child > .btn:not(:first-child),\n.input-group > .input-group-prepend:first-child > .input-group-text:not(:first-child) {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.custom-control {\n  position: relative;\n  display: block;\n  min-height: 1.2195rem;\n  padding-left: 1.5rem;\n}\n\n.custom-control-inline {\n  display: inline-flex;\n  margin-right: 1rem;\n}\n\n.custom-control-input {\n  position: absolute;\n  z-index: -1;\n  opacity: 0;\n}\n\n.custom-control-input:checked ~ .custom-control-label::before {\n  color: #fff;\n  background-color: #8b5cf6;\n}\n\n.custom-control-input:focus ~ .custom-control-label::before {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.custom-control-input:active ~ .custom-control-label::before {\n  color: #fff;\n  background-color: white;\n}\n\n.custom-control-input:disabled ~ .custom-control-label {\n  color: #4B5563;\n}\n\n.custom-control-input:disabled ~ .custom-control-label::before {\n  background-color: #E5E7EB;\n}\n\n.custom-control-label {\n  position: relative;\n  margin-bottom: 0;\n}\n\n.custom-control-label::before {\n  position: absolute;\n  top: 0.10975rem;\n  left: -1.5rem;\n  display: block;\n  width: 1rem;\n  height: 1rem;\n  pointer-events: none;\n  content: \"\";\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n  background-color: #D1D5DB;\n}\n\n.custom-control-label::after {\n  position: absolute;\n  top: 0.10975rem;\n  left: -1.5rem;\n  display: block;\n  width: 1rem;\n  height: 1rem;\n  content: \"\";\n  background-repeat: no-repeat;\n  background-position: center center;\n  background-size: 50% 50%;\n}\n\n.custom-checkbox .custom-control-label::before {\n  border-radius: 0.25rem;\n}\n\n.custom-checkbox .custom-control-input:checked ~ .custom-control-label::before {\n  background-color: #8b5cf6;\n}\n\n.custom-checkbox .custom-control-input:checked ~ .custom-control-label::after {\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='%23fff' d='M6.564.75l-3.59 3.612-1.538-1.55L0 4.26 2.974 7.25 8 2.193z'/%3E%3C/svg%3E\");\n}\n\n.custom-checkbox .custom-control-input:indeterminate ~ .custom-control-label::before {\n  background-color: #8b5cf6;\n}\n\n.custom-checkbox .custom-control-input:indeterminate ~ .custom-control-label::after {\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 4'%3E%3Cpath stroke='%23fff' d='M0 2h4'/%3E%3C/svg%3E\");\n}\n\n.custom-checkbox .custom-control-input:disabled:checked ~ .custom-control-label::before {\n  background-color: rgba(139, 92, 246, 0.5);\n}\n\n.custom-checkbox .custom-control-input:disabled:indeterminate ~ .custom-control-label::before {\n  background-color: rgba(139, 92, 246, 0.5);\n}\n\n.custom-radio .custom-control-label::before {\n  border-radius: 50%;\n}\n\n.custom-radio .custom-control-input:checked ~ .custom-control-label::before {\n  background-color: #8b5cf6;\n}\n\n.custom-radio .custom-control-input:checked ~ .custom-control-label::after {\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3E%3Ccircle r='3' fill='%23fff'/%3E%3C/svg%3E\");\n}\n\n.custom-radio .custom-control-input:disabled:checked ~ .custom-control-label::before {\n  background-color: rgba(139, 92, 246, 0.5);\n}\n\n.custom-select {\n  display: inline-block;\n  width: 100%;\n  height: calc(1.9695rem + 2px);\n  padding: 0.375rem 1.75rem 0.375rem 0.75rem;\n  line-height: 1.5;\n  color: #374151;\n  vertical-align: middle;\n  background: #fff url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 4 5'%3E%3Cpath fill='%231F2937' d='M2 0L0 2h4zm0 5L0 3h4z'/%3E%3C/svg%3E\") no-repeat right 0.75rem center;\n  background-size: 8px 10px;\n  border: 1px solid #9CA3AF;\n  border-radius: 0.25rem;\n  -webkit-appearance: none;\n     -moz-appearance: none;\n          appearance: none;\n}\n\n.custom-select:focus {\n  border-color: #e1d5fd;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(225, 213, 253, 0.5);\n}\n\n.custom-select:focus::-ms-value {\n  color: #374151;\n  background-color: #fff;\n}\n\n.custom-select[multiple], .custom-select[size]:not([size=\"1\"]) {\n  height: auto;\n  padding-right: 0.75rem;\n  background-image: none;\n}\n\n.custom-select:disabled {\n  color: #4B5563;\n  background-color: #E5E7EB;\n}\n\n.custom-select::-ms-expand {\n  opacity: 0;\n}\n\n.custom-select-sm {\n  height: calc( 1.5670625rem + 2px);\n  padding-top: 0.375rem;\n  padding-bottom: 0.375rem;\n  font-size: 75%;\n}\n\n.custom-select-lg {\n  height: calc( 2.524375rem + 2px);\n  padding-top: 0.375rem;\n  padding-bottom: 0.375rem;\n  font-size: 125%;\n}\n\n.custom-file {\n  position: relative;\n  display: inline-block;\n  width: 100%;\n  height: calc(1.9695rem + 2px);\n  margin-bottom: 0;\n}\n\n.custom-file-input {\n  position: relative;\n  z-index: 2;\n  width: 100%;\n  height: calc(1.9695rem + 2px);\n  margin: 0;\n  opacity: 0;\n}\n\n.custom-file-input:focus ~ .custom-file-label {\n  border-color: #e1d5fd;\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.custom-file-input:focus ~ .custom-file-label::after {\n  border-color: #e1d5fd;\n}\n\n.custom-file-input:disabled ~ .custom-file-label {\n  background-color: #E5E7EB;\n}\n\n.custom-file-input:lang(en) ~ .custom-file-label::after {\n  content: \"Browse\";\n}\n\n.custom-file-label {\n  position: absolute;\n  top: 0;\n  right: 0;\n  left: 0;\n  z-index: 1;\n  height: calc(1.9695rem + 2px);\n  padding: 0.375rem 0.75rem;\n  line-height: 1.5;\n  color: #374151;\n  background-color: #fff;\n  border: 1px solid #9CA3AF;\n  border-radius: 0.25rem;\n}\n\n.custom-file-label::after {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  z-index: 3;\n  display: block;\n  height: 1.9695rem;\n  padding: 0.375rem 0.75rem;\n  line-height: 1.5;\n  color: #374151;\n  content: \"Browse\";\n  background-color: #E5E7EB;\n  border-left: 1px solid #9CA3AF;\n  border-radius: 0 0.25rem 0.25rem 0;\n}\n\n.custom-range {\n  width: 100%;\n  padding-left: 0;\n  background-color: transparent;\n  -webkit-appearance: none;\n     -moz-appearance: none;\n          appearance: none;\n}\n\n.custom-range:focus {\n  outline: none;\n}\n\n.custom-range:focus::-webkit-slider-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.custom-range:focus::-moz-range-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.custom-range:focus::-ms-thumb {\n  box-shadow: 0 0 0 1px #fff, 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.custom-range::-moz-focus-outer {\n  border: 0;\n}\n\n.custom-range::-webkit-slider-thumb {\n  width: 1rem;\n  height: 1rem;\n  margin-top: -0.25rem;\n  background-color: #8b5cf6;\n  border: 0;\n  border-radius: 1rem;\n  -webkit-transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n  -webkit-appearance: none;\n          appearance: none;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .custom-range::-webkit-slider-thumb {\n    -webkit-transition: none;\n    transition: none;\n  }\n}\n\n.custom-range::-webkit-slider-thumb:active {\n  background-color: white;\n}\n\n.custom-range::-webkit-slider-runnable-track {\n  width: 100%;\n  height: 0.5rem;\n  color: transparent;\n  cursor: pointer;\n  background-color: #D1D5DB;\n  border-color: transparent;\n  border-radius: 1rem;\n}\n\n.custom-range::-moz-range-thumb {\n  width: 1rem;\n  height: 1rem;\n  background-color: #8b5cf6;\n  border: 0;\n  border-radius: 1rem;\n  -moz-transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n  -moz-appearance: none;\n       appearance: none;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .custom-range::-moz-range-thumb {\n    -moz-transition: none;\n    transition: none;\n  }\n}\n\n.custom-range::-moz-range-thumb:active {\n  background-color: white;\n}\n\n.custom-range::-moz-range-track {\n  width: 100%;\n  height: 0.5rem;\n  color: transparent;\n  cursor: pointer;\n  background-color: #D1D5DB;\n  border-color: transparent;\n  border-radius: 1rem;\n}\n\n.custom-range::-ms-thumb {\n  width: 1rem;\n  height: 1rem;\n  margin-top: 0;\n  margin-right: 0.2rem;\n  margin-left: 0.2rem;\n  background-color: #8b5cf6;\n  border: 0;\n  border-radius: 1rem;\n  -ms-transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n  appearance: none;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .custom-range::-ms-thumb {\n    -ms-transition: none;\n    transition: none;\n  }\n}\n\n.custom-range::-ms-thumb:active {\n  background-color: white;\n}\n\n.custom-range::-ms-track {\n  width: 100%;\n  height: 0.5rem;\n  color: transparent;\n  cursor: pointer;\n  background-color: transparent;\n  border-color: transparent;\n  border-width: 0.5rem;\n}\n\n.custom-range::-ms-fill-lower {\n  background-color: #D1D5DB;\n  border-radius: 1rem;\n}\n\n.custom-range::-ms-fill-upper {\n  margin-right: 15px;\n  background-color: #D1D5DB;\n  border-radius: 1rem;\n}\n\n.custom-control-label::before,\n.custom-file-label,\n.custom-select {\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .custom-control-label::before,\n  .custom-file-label,\n  .custom-select {\n    transition: none;\n  }\n}\n\n.nav {\n  display: flex;\n  flex-wrap: wrap;\n  padding-left: 0;\n  margin-bottom: 0;\n  list-style: none;\n}\n\n.nav-link {\n  display: block;\n  padding: 0.5rem 1rem;\n}\n\n.nav-link:hover, .nav-link:focus {\n  text-decoration: none;\n}\n\n.nav-link.disabled {\n  color: #4B5563;\n}\n\n.nav-tabs {\n  border-bottom: 1px solid #D1D5DB;\n}\n\n.nav-tabs .nav-item {\n  margin-bottom: -1px;\n}\n\n.nav-tabs .nav-link {\n  border: 1px solid transparent;\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n\n.nav-tabs .nav-link:hover, .nav-tabs .nav-link:focus {\n  border-color: #E5E7EB #E5E7EB #D1D5DB;\n}\n\n.nav-tabs .nav-link.disabled {\n  color: #4B5563;\n  background-color: transparent;\n  border-color: transparent;\n}\n\n.nav-tabs .nav-link.active,\n.nav-tabs .nav-item.show .nav-link {\n  color: #374151;\n  background-color: #fff;\n  border-color: #D1D5DB #D1D5DB #fff;\n}\n\n.nav-tabs .dropdown-menu {\n  margin-top: -1px;\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n\n.nav-pills .nav-link {\n  border-radius: 0.25rem;\n}\n\n.nav-pills .nav-link.active,\n.nav-pills .show > .nav-link {\n  color: #fff;\n  background-color: #8b5cf6;\n}\n\n.nav-fill .nav-item {\n  flex: 1 1 auto;\n  text-align: center;\n}\n\n.nav-justified .nav-item {\n  flex-basis: 0;\n  flex-grow: 1;\n  text-align: center;\n}\n\n.tab-content > .tab-pane {\n  display: none;\n}\n\n.tab-content > .active {\n  display: block;\n}\n\n.navbar {\n  position: relative;\n  display: flex;\n  flex-wrap: wrap;\n  align-items: center;\n  justify-content: space-between;\n  padding: 0.5rem 1rem;\n}\n\n.navbar > .container,\n.navbar > .container-fluid {\n  display: flex;\n  flex-wrap: wrap;\n  align-items: center;\n  justify-content: space-between;\n}\n\n.navbar-brand {\n  display: inline-block;\n  padding-top: 0.3475625rem;\n  padding-bottom: 0.3475625rem;\n  margin-right: 1rem;\n  font-size: 1.01625rem;\n  line-height: inherit;\n  white-space: nowrap;\n}\n\n.navbar-brand:hover, .navbar-brand:focus {\n  text-decoration: none;\n}\n\n.navbar-nav {\n  display: flex;\n  flex-direction: column;\n  padding-left: 0;\n  margin-bottom: 0;\n  list-style: none;\n}\n\n.navbar-nav .nav-link {\n  padding-right: 0;\n  padding-left: 0;\n}\n\n.navbar-nav .dropdown-menu {\n  position: static;\n  float: none;\n}\n\n.navbar-text {\n  display: inline-block;\n  padding-top: 0.5rem;\n  padding-bottom: 0.5rem;\n}\n\n.navbar-collapse {\n  flex-basis: 100%;\n  flex-grow: 1;\n  align-items: center;\n}\n\n.navbar-toggler {\n  padding: 0.25rem 0.75rem;\n  font-size: 1.01625rem;\n  line-height: 1;\n  background-color: transparent;\n  border: 1px solid transparent;\n  border-radius: 0.25rem;\n}\n\n.navbar-toggler:hover, .navbar-toggler:focus {\n  text-decoration: none;\n}\n\n.navbar-toggler:not(:disabled):not(.disabled) {\n  cursor: pointer;\n}\n\n.navbar-toggler-icon {\n  display: inline-block;\n  width: 1.5em;\n  height: 1.5em;\n  vertical-align: middle;\n  content: \"\";\n  background: no-repeat center center;\n  background-size: 100% 100%;\n}\n\n@media (max-width: 575.98px) {\n  .navbar-expand-sm > .container,\n  .navbar-expand-sm > .container-fluid {\n    padding-right: 0;\n    padding-left: 0;\n  }\n}\n\n@media (min-width: 576px) {\n  .navbar-expand-sm {\n    flex-flow: row nowrap;\n    justify-content: flex-start;\n  }\n  .navbar-expand-sm .navbar-nav {\n    flex-direction: row;\n  }\n  .navbar-expand-sm .navbar-nav .dropdown-menu {\n    position: absolute;\n  }\n  .navbar-expand-sm .navbar-nav .nav-link {\n    padding-right: 0.5rem;\n    padding-left: 0.5rem;\n  }\n  .navbar-expand-sm > .container,\n  .navbar-expand-sm > .container-fluid {\n    flex-wrap: nowrap;\n  }\n  .navbar-expand-sm .navbar-collapse {\n    display: flex !important;\n    flex-basis: auto;\n  }\n  .navbar-expand-sm .navbar-toggler {\n    display: none;\n  }\n}\n\n@media (max-width: 767.98px) {\n  .navbar-expand-md > .container,\n  .navbar-expand-md > .container-fluid {\n    padding-right: 0;\n    padding-left: 0;\n  }\n}\n\n@media (min-width: 768px) {\n  .navbar-expand-md {\n    flex-flow: row nowrap;\n    justify-content: flex-start;\n  }\n  .navbar-expand-md .navbar-nav {\n    flex-direction: row;\n  }\n  .navbar-expand-md .navbar-nav .dropdown-menu {\n    position: absolute;\n  }\n  .navbar-expand-md .navbar-nav .nav-link {\n    padding-right: 0.5rem;\n    padding-left: 0.5rem;\n  }\n  .navbar-expand-md > .container,\n  .navbar-expand-md > .container-fluid {\n    flex-wrap: nowrap;\n  }\n  .navbar-expand-md .navbar-collapse {\n    display: flex !important;\n    flex-basis: auto;\n  }\n  .navbar-expand-md .navbar-toggler {\n    display: none;\n  }\n}\n\n@media (max-width: 991.98px) {\n  .navbar-expand-lg > .container,\n  .navbar-expand-lg > .container-fluid {\n    padding-right: 0;\n    padding-left: 0;\n  }\n}\n\n@media (min-width: 992px) {\n  .navbar-expand-lg {\n    flex-flow: row nowrap;\n    justify-content: flex-start;\n  }\n  .navbar-expand-lg .navbar-nav {\n    flex-direction: row;\n  }\n  .navbar-expand-lg .navbar-nav .dropdown-menu {\n    position: absolute;\n  }\n  .navbar-expand-lg .navbar-nav .nav-link {\n    padding-right: 0.5rem;\n    padding-left: 0.5rem;\n  }\n  .navbar-expand-lg > .container,\n  .navbar-expand-lg > .container-fluid {\n    flex-wrap: nowrap;\n  }\n  .navbar-expand-lg .navbar-collapse {\n    display: flex !important;\n    flex-basis: auto;\n  }\n  .navbar-expand-lg .navbar-toggler {\n    display: none;\n  }\n}\n\n@media (max-width: 1199.98px) {\n  .navbar-expand-xl > .container,\n  .navbar-expand-xl > .container-fluid {\n    padding-right: 0;\n    padding-left: 0;\n  }\n}\n\n@media (min-width: 1200px) {\n  .navbar-expand-xl {\n    flex-flow: row nowrap;\n    justify-content: flex-start;\n  }\n  .navbar-expand-xl .navbar-nav {\n    flex-direction: row;\n  }\n  .navbar-expand-xl .navbar-nav .dropdown-menu {\n    position: absolute;\n  }\n  .navbar-expand-xl .navbar-nav .nav-link {\n    padding-right: 0.5rem;\n    padding-left: 0.5rem;\n  }\n  .navbar-expand-xl > .container,\n  .navbar-expand-xl > .container-fluid {\n    flex-wrap: nowrap;\n  }\n  .navbar-expand-xl .navbar-collapse {\n    display: flex !important;\n    flex-basis: auto;\n  }\n  .navbar-expand-xl .navbar-toggler {\n    display: none;\n  }\n}\n\n.navbar-expand {\n  flex-flow: row nowrap;\n  justify-content: flex-start;\n}\n\n.navbar-expand > .container,\n.navbar-expand > .container-fluid {\n  padding-right: 0;\n  padding-left: 0;\n}\n\n.navbar-expand .navbar-nav {\n  flex-direction: row;\n}\n\n.navbar-expand .navbar-nav .dropdown-menu {\n  position: absolute;\n}\n\n.navbar-expand .navbar-nav .nav-link {\n  padding-right: 0.5rem;\n  padding-left: 0.5rem;\n}\n\n.navbar-expand > .container,\n.navbar-expand > .container-fluid {\n  flex-wrap: nowrap;\n}\n\n.navbar-expand .navbar-collapse {\n  display: flex !important;\n  flex-basis: auto;\n}\n\n.navbar-expand .navbar-toggler {\n  display: none;\n}\n\n.navbar-light .navbar-brand {\n  color: rgba(10, 2, 30, 0.9);\n}\n\n.navbar-light .navbar-brand:hover, .navbar-light .navbar-brand:focus {\n  color: rgba(10, 2, 30, 0.9);\n}\n\n.navbar-light .navbar-nav .nav-link {\n  color: rgba(10, 2, 30, 0.5);\n}\n\n.navbar-light .navbar-nav .nav-link:hover, .navbar-light .navbar-nav .nav-link:focus {\n  color: rgba(10, 2, 30, 0.7);\n}\n\n.navbar-light .navbar-nav .nav-link.disabled {\n  color: rgba(10, 2, 30, 0.3);\n}\n\n.navbar-light .navbar-nav .show > .nav-link,\n.navbar-light .navbar-nav .active > .nav-link,\n.navbar-light .navbar-nav .nav-link.show,\n.navbar-light .navbar-nav .nav-link.active {\n  color: rgba(10, 2, 30, 0.9);\n}\n\n.navbar-light .navbar-toggler {\n  color: rgba(10, 2, 30, 0.5);\n  border-color: rgba(10, 2, 30, 0.1);\n}\n\n.navbar-light .navbar-toggler-icon {\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(10, 2, 30, 0.5)' stroke-width='2' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E\");\n}\n\n.navbar-light .navbar-text {\n  color: rgba(10, 2, 30, 0.5);\n}\n\n.navbar-light .navbar-text a {\n  color: rgba(10, 2, 30, 0.9);\n}\n\n.navbar-light .navbar-text a:hover, .navbar-light .navbar-text a:focus {\n  color: rgba(10, 2, 30, 0.9);\n}\n\n.navbar-dark .navbar-brand {\n  color: #fff;\n}\n\n.navbar-dark .navbar-brand:hover, .navbar-dark .navbar-brand:focus {\n  color: #fff;\n}\n\n.navbar-dark .navbar-nav .nav-link {\n  color: rgba(255, 255, 255, 0.5);\n}\n\n.navbar-dark .navbar-nav .nav-link:hover, .navbar-dark .navbar-nav .nav-link:focus {\n  color: rgba(255, 255, 255, 0.75);\n}\n\n.navbar-dark .navbar-nav .nav-link.disabled {\n  color: rgba(255, 255, 255, 0.25);\n}\n\n.navbar-dark .navbar-nav .show > .nav-link,\n.navbar-dark .navbar-nav .active > .nav-link,\n.navbar-dark .navbar-nav .nav-link.show,\n.navbar-dark .navbar-nav .nav-link.active {\n  color: #fff;\n}\n\n.navbar-dark .navbar-toggler {\n  color: rgba(255, 255, 255, 0.5);\n  border-color: rgba(255, 255, 255, 0.1);\n}\n\n.navbar-dark .navbar-toggler-icon {\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(255, 255, 255, 0.5)' stroke-width='2' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E\");\n}\n\n.navbar-dark .navbar-text {\n  color: rgba(255, 255, 255, 0.5);\n}\n\n.navbar-dark .navbar-text a {\n  color: #fff;\n}\n\n.navbar-dark .navbar-text a:hover, .navbar-dark .navbar-text a:focus {\n  color: #fff;\n}\n\n.card {\n  position: relative;\n  display: flex;\n  flex-direction: column;\n  min-width: 0;\n  word-wrap: break-word;\n  background-color: #fff;\n  background-clip: border-box;\n  border: 1px solid rgba(10, 2, 30, 0.125);\n  border-radius: 0.25rem;\n}\n\n.card > hr {\n  margin-right: 0;\n  margin-left: 0;\n}\n\n.card > .list-group:first-child .list-group-item:first-child {\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n\n.card > .list-group:last-child .list-group-item:last-child {\n  border-bottom-right-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n}\n\n.card-body {\n  flex: 1 1 auto;\n  padding: 1.25rem;\n}\n\n.card-title {\n  margin-bottom: 0.75rem;\n}\n\n.card-subtitle {\n  margin-top: -0.375rem;\n  margin-bottom: 0;\n}\n\n.card-text:last-child {\n  margin-bottom: 0;\n}\n\n.card-link:hover {\n  text-decoration: none;\n}\n\n.card-link + .card-link {\n  margin-left: 1.25rem;\n}\n\n.card-header {\n  padding: 0.75rem 1.25rem;\n  margin-bottom: 0;\n  background-color: rgba(10, 2, 30, 0.03);\n  border-bottom: 1px solid rgba(10, 2, 30, 0.125);\n}\n\n.card-header:first-child {\n  border-radius: calc( 0.25rem - 1px) calc( 0.25rem - 1px) 0 0;\n}\n\n.card-header + .list-group .list-group-item:first-child {\n  border-top: 0;\n}\n\n.card-footer {\n  padding: 0.75rem 1.25rem;\n  background-color: rgba(10, 2, 30, 0.03);\n  border-top: 1px solid rgba(10, 2, 30, 0.125);\n}\n\n.card-footer:last-child {\n  border-radius: 0 0 calc( 0.25rem - 1px) calc( 0.25rem - 1px);\n}\n\n.card-header-tabs {\n  margin-right: -0.625rem;\n  margin-bottom: -0.75rem;\n  margin-left: -0.625rem;\n  border-bottom: 0;\n}\n\n.card-header-pills {\n  margin-right: -0.625rem;\n  margin-left: -0.625rem;\n}\n\n.card-img-overlay {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  padding: 1.25rem;\n}\n\n.card-img {\n  width: 100%;\n  border-radius: calc( 0.25rem - 1px);\n}\n\n.card-img-top {\n  width: 100%;\n  border-top-left-radius: calc( 0.25rem - 1px);\n  border-top-right-radius: calc( 0.25rem - 1px);\n}\n\n.card-img-bottom {\n  width: 100%;\n  border-bottom-right-radius: calc( 0.25rem - 1px);\n  border-bottom-left-radius: calc( 0.25rem - 1px);\n}\n\n.card-deck {\n  display: flex;\n  flex-direction: column;\n}\n\n.card-deck .card {\n  margin-bottom: 15px;\n}\n\n@media (min-width: 576px) {\n  .card-deck {\n    flex-flow: row wrap;\n    margin-right: -15px;\n    margin-left: -15px;\n  }\n  .card-deck .card {\n    display: flex;\n    flex: 1 0 0%;\n    flex-direction: column;\n    margin-right: 15px;\n    margin-bottom: 0;\n    margin-left: 15px;\n  }\n}\n\n.card-group {\n  display: flex;\n  flex-direction: column;\n}\n\n.card-group > .card {\n  margin-bottom: 15px;\n}\n\n@media (min-width: 576px) {\n  .card-group {\n    flex-flow: row wrap;\n  }\n  .card-group > .card {\n    flex: 1 0 0%;\n    margin-bottom: 0;\n  }\n  .card-group > .card + .card {\n    margin-left: 0;\n    border-left: 0;\n  }\n  .card-group > .card:first-child {\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n  .card-group > .card:first-child .card-img-top,\n  .card-group > .card:first-child .card-header {\n    border-top-right-radius: 0;\n  }\n  .card-group > .card:first-child .card-img-bottom,\n  .card-group > .card:first-child .card-footer {\n    border-bottom-right-radius: 0;\n  }\n  .card-group > .card:last-child {\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n  .card-group > .card:last-child .card-img-top,\n  .card-group > .card:last-child .card-header {\n    border-top-left-radius: 0;\n  }\n  .card-group > .card:last-child .card-img-bottom,\n  .card-group > .card:last-child .card-footer {\n    border-bottom-left-radius: 0;\n  }\n  .card-group > .card:only-child {\n    border-radius: 0.25rem;\n  }\n  .card-group > .card:only-child .card-img-top,\n  .card-group > .card:only-child .card-header {\n    border-top-left-radius: 0.25rem;\n    border-top-right-radius: 0.25rem;\n  }\n  .card-group > .card:only-child .card-img-bottom,\n  .card-group > .card:only-child .card-footer {\n    border-bottom-right-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n  .card-group > .card:not(:first-child):not(:last-child):not(:only-child) {\n    border-radius: 0;\n  }\n  .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-img-top,\n  .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-img-bottom,\n  .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-header,\n  .card-group > .card:not(:first-child):not(:last-child):not(:only-child) .card-footer {\n    border-radius: 0;\n  }\n}\n\n.card-columns .card {\n  margin-bottom: 0.75rem;\n}\n\n@media (min-width: 576px) {\n  .card-columns {\n    -moz-column-count: 3;\n         column-count: 3;\n    -moz-column-gap: 1.25rem;\n         column-gap: 1.25rem;\n    orphans: 1;\n    widows: 1;\n  }\n  .card-columns .card {\n    display: inline-block;\n    width: 100%;\n  }\n}\n\n.accordion .card:not(:first-of-type):not(:last-of-type) {\n  border-bottom: 0;\n  border-radius: 0;\n}\n\n.accordion .card:not(:first-of-type) .card-header:first-child {\n  border-radius: 0;\n}\n\n.accordion .card:first-of-type {\n  border-bottom: 0;\n  border-bottom-right-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.accordion .card:last-of-type {\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n\n.breadcrumb {\n  display: flex;\n  flex-wrap: wrap;\n  padding: 0.75rem 1rem;\n  margin-bottom: 1rem;\n  list-style: none;\n  background-color: #E5E7EB;\n  border-radius: 0.25rem;\n}\n\n.breadcrumb-item + .breadcrumb-item {\n  padding-left: 0.5rem;\n}\n\n.breadcrumb-item + .breadcrumb-item::before {\n  display: inline-block;\n  padding-right: 0.5rem;\n  color: #4B5563;\n  content: \"/\";\n}\n\n.breadcrumb-item + .breadcrumb-item:hover::before {\n  text-decoration: underline;\n}\n\n.breadcrumb-item + .breadcrumb-item:hover::before {\n  text-decoration: none;\n}\n\n.breadcrumb-item.active {\n  color: #4B5563;\n}\n\n.pagination {\n  display: flex;\n  padding-left: 0;\n  list-style: none;\n  border-radius: 0.25rem;\n}\n\n.page-link {\n  position: relative;\n  display: block;\n  padding: 0.5rem 0.75rem;\n  margin-left: -1px;\n  line-height: 1.25;\n  color: #8b5cf6;\n  background-color: #fff;\n  border: 1px solid #D1D5DB;\n}\n\n.page-link:hover {\n  z-index: 2;\n  color: #5714f2;\n  text-decoration: none;\n  background-color: #E5E7EB;\n  border-color: #D1D5DB;\n}\n\n.page-link:focus {\n  z-index: 2;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.25);\n}\n\n.page-link:not(:disabled):not(.disabled) {\n  cursor: pointer;\n}\n\n.page-item:first-child .page-link {\n  margin-left: 0;\n  border-top-left-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n}\n\n.page-item:last-child .page-link {\n  border-top-right-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n\n.page-item.active .page-link {\n  z-index: 1;\n  color: #fff;\n  background-color: #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.page-item.disabled .page-link {\n  color: #4B5563;\n  pointer-events: none;\n  cursor: auto;\n  background-color: #fff;\n  border-color: #D1D5DB;\n}\n\n.pagination-lg .page-link {\n  padding: 0.75rem 1.5rem;\n  font-size: 1.01625rem;\n  line-height: 1.5;\n}\n\n.pagination-lg .page-item:first-child .page-link {\n  border-top-left-radius: 0.3rem;\n  border-bottom-left-radius: 0.3rem;\n}\n\n.pagination-lg .page-item:last-child .page-link {\n  border-top-right-radius: 0.3rem;\n  border-bottom-right-radius: 0.3rem;\n}\n\n.pagination-sm .page-link {\n  padding: 0.25rem 0.5rem;\n  font-size: 0.711375rem;\n  line-height: 1.5;\n}\n\n.pagination-sm .page-item:first-child .page-link {\n  border-top-left-radius: 0.2rem;\n  border-bottom-left-radius: 0.2rem;\n}\n\n.pagination-sm .page-item:last-child .page-link {\n  border-top-right-radius: 0.2rem;\n  border-bottom-right-radius: 0.2rem;\n}\n\n.badge {\n  display: inline-block;\n  padding: 0.25em 0.4em;\n  font-size: 75%;\n  font-weight: 700;\n  line-height: 1;\n  text-align: center;\n  white-space: nowrap;\n  vertical-align: baseline;\n  border-radius: 0.25rem;\n}\n\n.badge:empty {\n  display: none;\n}\n\n.btn .badge {\n  position: relative;\n  top: -1px;\n}\n\n.badge-pill {\n  padding-right: 0.6em;\n  padding-left: 0.6em;\n  border-radius: 10rem;\n}\n\n.badge-primary {\n  color: #fff;\n  background-color: #8b5cf6;\n}\n\n.badge-primary[href]:hover, .badge-primary[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #692cf3;\n}\n\n.badge-secondary {\n  color: #fff;\n  background-color: #1F2937;\n}\n\n.badge-secondary[href]:hover, .badge-secondary[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #0d1116;\n}\n\n.badge-success {\n  color: #fff;\n  background-color: #10b981;\n}\n\n.badge-success[href]:hover, .badge-success[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #0c8a60;\n}\n\n.badge-info {\n  color: #fff;\n  background-color: #3b82f6;\n}\n\n.badge-info[href]:hover, .badge-info[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #0b63f3;\n}\n\n.badge-warning {\n  color: #111827;\n  background-color: #f59e0b;\n}\n\n.badge-warning[href]:hover, .badge-warning[href]:focus {\n  color: #111827;\n  text-decoration: none;\n  background-color: #c57f08;\n}\n\n.badge-danger {\n  color: #fff;\n  background-color: #ef4444;\n}\n\n.badge-danger[href]:hover, .badge-danger[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #eb1515;\n}\n\n.badge-light {\n  color: #fff;\n  background-color: #6B7280;\n}\n\n.badge-light[href]:hover, .badge-light[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #545964;\n}\n\n.badge-dark {\n  color: #fff;\n  background-color: #111827;\n}\n\n.badge-dark[href]:hover, .badge-dark[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #020203;\n}\n\n.badge-gray-100 {\n  color: #111827;\n  background-color: #F3F4F6;\n}\n\n.badge-gray-100[href]:hover, .badge-gray-100[href]:focus {\n  color: #111827;\n  text-decoration: none;\n  background-color: #d6d9e0;\n}\n\n.badge-gray-200 {\n  color: #111827;\n  background-color: #E5E7EB;\n}\n\n.badge-gray-200[href]:hover, .badge-gray-200[href]:focus {\n  color: #111827;\n  text-decoration: none;\n  background-color: #c8ccd5;\n}\n\n.badge-gray-300 {\n  color: #111827;\n  background-color: #D1D5DB;\n}\n\n.badge-gray-300[href]:hover, .badge-gray-300[href]:focus {\n  color: #111827;\n  text-decoration: none;\n  background-color: #b4bbc5;\n}\n\n.badge-gray-400 {\n  color: #111827;\n  background-color: #9CA3AF;\n}\n\n.badge-gray-400[href]:hover, .badge-gray-400[href]:focus {\n  color: #111827;\n  text-decoration: none;\n  background-color: #808998;\n}\n\n.badge-gray-500 {\n  color: #fff;\n  background-color: #6B7280;\n}\n\n.badge-gray-500[href]:hover, .badge-gray-500[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #545964;\n}\n\n.badge-gray-600 {\n  color: #fff;\n  background-color: #4B5563;\n}\n\n.badge-gray-600[href]:hover, .badge-gray-600[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #353c46;\n}\n\n.badge-gray-700 {\n  color: #fff;\n  background-color: #374151;\n}\n\n.badge-gray-700[href]:hover, .badge-gray-700[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #222933;\n}\n\n.badge-gray-800 {\n  color: #fff;\n  background-color: #1F2937;\n}\n\n.badge-gray-800[href]:hover, .badge-gray-800[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #0d1116;\n}\n\n.badge-gray-900 {\n  color: #fff;\n  background-color: #111827;\n}\n\n.badge-gray-900[href]:hover, .badge-gray-900[href]:focus {\n  color: #fff;\n  text-decoration: none;\n  background-color: #020203;\n}\n\n.jumbotron {\n  padding: 2rem 1rem;\n  margin-bottom: 2rem;\n  background-color: #E5E7EB;\n  border-radius: 0.3rem;\n}\n\n@media (min-width: 576px) {\n  .jumbotron {\n    padding: 4rem 2rem;\n  }\n}\n\n.jumbotron-fluid {\n  padding-right: 0;\n  padding-left: 0;\n  border-radius: 0;\n}\n\n.alert {\n  position: relative;\n  padding: 0.2rem 1.25rem;\n  margin-bottom: 1rem;\n  border: 1px solid transparent;\n  border-radius: 0.25rem;\n}\n\n.alert-heading {\n  color: inherit;\n}\n\n.alert-link {\n  font-weight: 700;\n}\n\n.alert-dismissible {\n  padding-right: 3.7195rem;\n}\n\n.alert-dismissible .close {\n  position: absolute;\n  top: 0;\n  right: 0;\n  padding: 0.2rem 1.25rem;\n  color: inherit;\n}\n\n.alert-primary {\n  color: #4d318e;\n  background-color: #e8defd;\n  border-color: #dfd1fc;\n}\n\n.alert-primary hr {\n  border-top-color: #ceb9fa;\n}\n\n.alert-primary .alert-link {\n  color: #382468;\n}\n\n.alert-secondary {\n  color: #15162b;\n  background-color: #d2d4d7;\n  border-color: #c0c3c7;\n}\n\n.alert-secondary hr {\n  border-top-color: #b3b6bb;\n}\n\n.alert-secondary .alert-link {\n  color: #040409;\n}\n\n.alert-success {\n  color: #0d6152;\n  background-color: #cff1e6;\n  border-color: #bcebdc;\n}\n\n.alert-success hr {\n  border-top-color: #a8e5d2;\n}\n\n.alert-success .alert-link {\n  color: #07342c;\n}\n\n.alert-info {\n  color: #24448e;\n  background-color: #d8e6fd;\n  border-color: #c8dcfc;\n}\n\n.alert-info hr {\n  border-top-color: #b0cdfb;\n}\n\n.alert-info .alert-link {\n  color: #1a3165;\n}\n\n.alert-warning {\n  color: #845314;\n  background-color: #fdecce;\n  border-color: #fce4bb;\n}\n\n.alert-warning hr {\n  border-top-color: #fbdaa3;\n}\n\n.alert-warning .alert-link {\n  color: #58370d;\n}\n\n.alert-danger {\n  color: #812432;\n  background-color: #fcdada;\n  border-color: #fbcbcb;\n}\n\n.alert-danger hr {\n  border-top-color: #f9b3b3;\n}\n\n.alert-danger .alert-link {\n  color: #591923;\n}\n\n.alert-light {\n  color: #3d3c51;\n  background-color: #e1e3e6;\n  border-color: #d6d8db;\n}\n\n.alert-light hr {\n  border-top-color: #c8cbcf;\n}\n\n.alert-light .alert-link {\n  color: #272634;\n}\n\n.alert-dark {\n  color: #0e0d23;\n  background-color: #cfd1d4;\n  border-color: #bcbec3;\n}\n\n.alert-dark hr {\n  border-top-color: #afb1b7;\n}\n\n.alert-dark .alert-link {\n  color: black;\n}\n\n.alert-gray-100 {\n  color: #83808e;\n  background-color: #fdfdfd;\n  border-color: #fcfcfc;\n}\n\n.alert-gray-100 hr {\n  border-top-color: #efefef;\n}\n\n.alert-gray-100 .alert-link {\n  color: #6a6774;\n}\n\n.alert-gray-200 {\n  color: #7c7989;\n  background-color: #fafafb;\n  border-color: #f8f8f9;\n}\n\n.alert-gray-200 hr {\n  border-top-color: #eaeaed;\n}\n\n.alert-gray-200 .alert-link {\n  color: #63616e;\n}\n\n.alert-gray-300 {\n  color: #727080;\n  background-color: #f6f7f8;\n  border-color: #f2f3f5;\n}\n\n.alert-gray-300 hr {\n  border-top-color: #e4e6ea;\n}\n\n.alert-gray-300 .alert-link {\n  color: #5a5865;\n}\n\n.alert-gray-400 {\n  color: #56566a;\n  background-color: #ebedef;\n  border-color: #e3e5e9;\n}\n\n.alert-gray-400 hr {\n  border-top-color: #d5d8de;\n}\n\n.alert-gray-400 .alert-link {\n  color: #3f3f4e;\n}\n\n.alert-gray-500 {\n  color: #3d3c51;\n  background-color: #e1e3e6;\n  border-color: #d6d8db;\n}\n\n.alert-gray-500 hr {\n  border-top-color: #c8cbcf;\n}\n\n.alert-gray-500 .alert-link {\n  color: #272634;\n}\n\n.alert-gray-600 {\n  color: #2c2d42;\n  background-color: #dbdde0;\n  border-color: #cdcfd3;\n}\n\n.alert-gray-600 hr {\n  border-top-color: #bfc2c7;\n}\n\n.alert-gray-600 .alert-link {\n  color: #181823;\n}\n\n.alert-gray-700 {\n  color: #222339;\n  background-color: #d7d9dc;\n  border-color: #c7cace;\n}\n\n.alert-gray-700 hr {\n  border-top-color: #b9bdc2;\n}\n\n.alert-gray-700 .alert-link {\n  color: #0f0f19;\n}\n\n.alert-gray-800 {\n  color: #15162b;\n  background-color: #d2d4d7;\n  border-color: #c0c3c7;\n}\n\n.alert-gray-800 hr {\n  border-top-color: #b3b6bb;\n}\n\n.alert-gray-800 .alert-link {\n  color: #040409;\n}\n\n.alert-gray-900 {\n  color: #0e0d23;\n  background-color: #cfd1d4;\n  border-color: #bcbec3;\n}\n\n.alert-gray-900 hr {\n  border-top-color: #afb1b7;\n}\n\n.alert-gray-900 .alert-link {\n  color: black;\n}\n\n@-webkit-keyframes progress-bar-stripes {\n  from {\n    background-position: 1rem 0;\n  }\n  to {\n    background-position: 0 0;\n  }\n}\n\n@keyframes progress-bar-stripes {\n  from {\n    background-position: 1rem 0;\n  }\n  to {\n    background-position: 0 0;\n  }\n}\n\n.progress {\n  display: flex;\n  height: 1rem;\n  overflow: hidden;\n  font-size: 0.60975rem;\n  background-color: #E5E7EB;\n  border-radius: 0.25rem;\n}\n\n.progress-bar {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  color: #fff;\n  text-align: center;\n  white-space: nowrap;\n  background-color: #8b5cf6;\n  transition: width 0.6s ease;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .progress-bar {\n    transition: none;\n  }\n}\n\n.progress-bar-striped {\n  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);\n  background-size: 1rem 1rem;\n}\n\n.progress-bar-animated {\n  -webkit-animation: progress-bar-stripes 1s linear infinite;\n          animation: progress-bar-stripes 1s linear infinite;\n}\n\n.media {\n  display: flex;\n  align-items: flex-start;\n}\n\n.media-body {\n  flex: 1;\n}\n\n.list-group {\n  display: flex;\n  flex-direction: column;\n  padding-left: 0;\n  margin-bottom: 0;\n}\n\n.list-group-item-action {\n  width: 100%;\n  color: #374151;\n  text-align: inherit;\n}\n\n.list-group-item-action:hover, .list-group-item-action:focus {\n  color: #374151;\n  text-decoration: none;\n  background-color: #F3F4F6;\n}\n\n.list-group-item-action:active {\n  color: #111827;\n  background-color: #E5E7EB;\n}\n\n.list-group-item {\n  position: relative;\n  display: block;\n  padding: 0.75rem 1.25rem;\n  margin-bottom: -1px;\n  background-color: #fff;\n  border: 1px solid rgba(10, 2, 30, 0.125);\n}\n\n.list-group-item:first-child {\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n\n.list-group-item:last-child {\n  margin-bottom: 0;\n  border-bottom-right-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n}\n\n.list-group-item:hover, .list-group-item:focus {\n  z-index: 1;\n  text-decoration: none;\n}\n\n.list-group-item.disabled, .list-group-item:disabled {\n  color: #4B5563;\n  background-color: #fff;\n}\n\n.list-group-item.active {\n  z-index: 2;\n  color: #fff;\n  background-color: #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.list-group-flush .list-group-item {\n  border-right: 0;\n  border-left: 0;\n  border-radius: 0;\n}\n\n.list-group-flush:first-child .list-group-item:first-child {\n  border-top: 0;\n}\n\n.list-group-flush:last-child .list-group-item:last-child {\n  border-bottom: 0;\n}\n\n.list-group-item-primary {\n  color: #4d318e;\n  background-color: #dfd1fc;\n}\n\n.list-group-item-primary.list-group-item-action:hover, .list-group-item-primary.list-group-item-action:focus {\n  color: #4d318e;\n  background-color: #ceb9fa;\n}\n\n.list-group-item-primary.list-group-item-action.active {\n  color: #fff;\n  background-color: #4d318e;\n  border-color: #4d318e;\n}\n\n.list-group-item-secondary {\n  color: #15162b;\n  background-color: #c0c3c7;\n}\n\n.list-group-item-secondary.list-group-item-action:hover, .list-group-item-secondary.list-group-item-action:focus {\n  color: #15162b;\n  background-color: #b3b6bb;\n}\n\n.list-group-item-secondary.list-group-item-action.active {\n  color: #fff;\n  background-color: #15162b;\n  border-color: #15162b;\n}\n\n.list-group-item-success {\n  color: #0d6152;\n  background-color: #bcebdc;\n}\n\n.list-group-item-success.list-group-item-action:hover, .list-group-item-success.list-group-item-action:focus {\n  color: #0d6152;\n  background-color: #a8e5d2;\n}\n\n.list-group-item-success.list-group-item-action.active {\n  color: #fff;\n  background-color: #0d6152;\n  border-color: #0d6152;\n}\n\n.list-group-item-info {\n  color: #24448e;\n  background-color: #c8dcfc;\n}\n\n.list-group-item-info.list-group-item-action:hover, .list-group-item-info.list-group-item-action:focus {\n  color: #24448e;\n  background-color: #b0cdfb;\n}\n\n.list-group-item-info.list-group-item-action.active {\n  color: #fff;\n  background-color: #24448e;\n  border-color: #24448e;\n}\n\n.list-group-item-warning {\n  color: #845314;\n  background-color: #fce4bb;\n}\n\n.list-group-item-warning.list-group-item-action:hover, .list-group-item-warning.list-group-item-action:focus {\n  color: #845314;\n  background-color: #fbdaa3;\n}\n\n.list-group-item-warning.list-group-item-action.active {\n  color: #fff;\n  background-color: #845314;\n  border-color: #845314;\n}\n\n.list-group-item-danger {\n  color: #812432;\n  background-color: #fbcbcb;\n}\n\n.list-group-item-danger.list-group-item-action:hover, .list-group-item-danger.list-group-item-action:focus {\n  color: #812432;\n  background-color: #f9b3b3;\n}\n\n.list-group-item-danger.list-group-item-action.active {\n  color: #fff;\n  background-color: #812432;\n  border-color: #812432;\n}\n\n.list-group-item-light {\n  color: #3d3c51;\n  background-color: #d6d8db;\n}\n\n.list-group-item-light.list-group-item-action:hover, .list-group-item-light.list-group-item-action:focus {\n  color: #3d3c51;\n  background-color: #c8cbcf;\n}\n\n.list-group-item-light.list-group-item-action.active {\n  color: #fff;\n  background-color: #3d3c51;\n  border-color: #3d3c51;\n}\n\n.list-group-item-dark {\n  color: #0e0d23;\n  background-color: #bcbec3;\n}\n\n.list-group-item-dark.list-group-item-action:hover, .list-group-item-dark.list-group-item-action:focus {\n  color: #0e0d23;\n  background-color: #afb1b7;\n}\n\n.list-group-item-dark.list-group-item-action.active {\n  color: #fff;\n  background-color: #0e0d23;\n  border-color: #0e0d23;\n}\n\n.list-group-item-gray-100 {\n  color: #83808e;\n  background-color: #fcfcfc;\n}\n\n.list-group-item-gray-100.list-group-item-action:hover, .list-group-item-gray-100.list-group-item-action:focus {\n  color: #83808e;\n  background-color: #efefef;\n}\n\n.list-group-item-gray-100.list-group-item-action.active {\n  color: #fff;\n  background-color: #83808e;\n  border-color: #83808e;\n}\n\n.list-group-item-gray-200 {\n  color: #7c7989;\n  background-color: #f8f8f9;\n}\n\n.list-group-item-gray-200.list-group-item-action:hover, .list-group-item-gray-200.list-group-item-action:focus {\n  color: #7c7989;\n  background-color: #eaeaed;\n}\n\n.list-group-item-gray-200.list-group-item-action.active {\n  color: #fff;\n  background-color: #7c7989;\n  border-color: #7c7989;\n}\n\n.list-group-item-gray-300 {\n  color: #727080;\n  background-color: #f2f3f5;\n}\n\n.list-group-item-gray-300.list-group-item-action:hover, .list-group-item-gray-300.list-group-item-action:focus {\n  color: #727080;\n  background-color: #e4e6ea;\n}\n\n.list-group-item-gray-300.list-group-item-action.active {\n  color: #fff;\n  background-color: #727080;\n  border-color: #727080;\n}\n\n.list-group-item-gray-400 {\n  color: #56566a;\n  background-color: #e3e5e9;\n}\n\n.list-group-item-gray-400.list-group-item-action:hover, .list-group-item-gray-400.list-group-item-action:focus {\n  color: #56566a;\n  background-color: #d5d8de;\n}\n\n.list-group-item-gray-400.list-group-item-action.active {\n  color: #fff;\n  background-color: #56566a;\n  border-color: #56566a;\n}\n\n.list-group-item-gray-500 {\n  color: #3d3c51;\n  background-color: #d6d8db;\n}\n\n.list-group-item-gray-500.list-group-item-action:hover, .list-group-item-gray-500.list-group-item-action:focus {\n  color: #3d3c51;\n  background-color: #c8cbcf;\n}\n\n.list-group-item-gray-500.list-group-item-action.active {\n  color: #fff;\n  background-color: #3d3c51;\n  border-color: #3d3c51;\n}\n\n.list-group-item-gray-600 {\n  color: #2c2d42;\n  background-color: #cdcfd3;\n}\n\n.list-group-item-gray-600.list-group-item-action:hover, .list-group-item-gray-600.list-group-item-action:focus {\n  color: #2c2d42;\n  background-color: #bfc2c7;\n}\n\n.list-group-item-gray-600.list-group-item-action.active {\n  color: #fff;\n  background-color: #2c2d42;\n  border-color: #2c2d42;\n}\n\n.list-group-item-gray-700 {\n  color: #222339;\n  background-color: #c7cace;\n}\n\n.list-group-item-gray-700.list-group-item-action:hover, .list-group-item-gray-700.list-group-item-action:focus {\n  color: #222339;\n  background-color: #b9bdc2;\n}\n\n.list-group-item-gray-700.list-group-item-action.active {\n  color: #fff;\n  background-color: #222339;\n  border-color: #222339;\n}\n\n.list-group-item-gray-800 {\n  color: #15162b;\n  background-color: #c0c3c7;\n}\n\n.list-group-item-gray-800.list-group-item-action:hover, .list-group-item-gray-800.list-group-item-action:focus {\n  color: #15162b;\n  background-color: #b3b6bb;\n}\n\n.list-group-item-gray-800.list-group-item-action.active {\n  color: #fff;\n  background-color: #15162b;\n  border-color: #15162b;\n}\n\n.list-group-item-gray-900 {\n  color: #0e0d23;\n  background-color: #bcbec3;\n}\n\n.list-group-item-gray-900.list-group-item-action:hover, .list-group-item-gray-900.list-group-item-action:focus {\n  color: #0e0d23;\n  background-color: #afb1b7;\n}\n\n.list-group-item-gray-900.list-group-item-action.active {\n  color: #fff;\n  background-color: #0e0d23;\n  border-color: #0e0d23;\n}\n\n.close {\n  float: right;\n  font-size: 1.2195rem;\n  font-weight: 700;\n  line-height: 1;\n  color: #0a021e;\n  text-shadow: 0 1px 0 #fff;\n  opacity: .5;\n}\n\n.close:not(:disabled):not(.disabled) {\n  cursor: pointer;\n}\n\n.close:not(:disabled):not(.disabled):hover, .close:not(:disabled):not(.disabled):focus {\n  color: #0a021e;\n  text-decoration: none;\n  opacity: .75;\n}\n\nbutton.close {\n  padding: 0;\n  background-color: transparent;\n  border: 0;\n  -webkit-appearance: none;\n}\n\n.modal-open {\n  overflow: hidden;\n}\n\n.modal-open .modal {\n  overflow-x: hidden;\n  overflow-y: auto;\n}\n\n.modal {\n  position: fixed;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  z-index: 1050;\n  display: none;\n  overflow: hidden;\n  outline: 0;\n}\n\n.modal-dialog {\n  position: relative;\n  width: auto;\n  margin: 0.5rem;\n  pointer-events: none;\n}\n\n.modal.fade .modal-dialog {\n  transition: transform 0.3s ease-out;\n  transform: translate(0, -25%);\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .modal.fade .modal-dialog {\n    transition: none;\n  }\n}\n\n.modal.show .modal-dialog {\n  transform: translate(0, 0);\n}\n\n.modal-dialog-centered {\n  display: flex;\n  align-items: center;\n  min-height: calc(100% - (0.5rem * 2));\n}\n\n.modal-dialog-centered::before {\n  display: block;\n  height: calc(100vh - (0.5rem * 2));\n  content: \"\";\n}\n\n.modal-content {\n  position: relative;\n  display: flex;\n  flex-direction: column;\n  width: 100%;\n  pointer-events: auto;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid rgba(10, 2, 30, 0.2);\n  border-radius: 0.3rem;\n  outline: 0;\n}\n\n.modal-backdrop {\n  position: fixed;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  z-index: 1040;\n  background-color: #0a021e;\n}\n\n.modal-backdrop.fade {\n  opacity: 0;\n}\n\n.modal-backdrop.show {\n  opacity: 0.5;\n}\n\n.modal-header {\n  display: flex;\n  align-items: flex-start;\n  justify-content: space-between;\n  padding: 1rem;\n  border-bottom: 1px solid #E5E7EB;\n  border-top-left-radius: 0.3rem;\n  border-top-right-radius: 0.3rem;\n}\n\n.modal-header .close {\n  padding: 1rem;\n  margin: -1rem -1rem -1rem auto;\n}\n\n.modal-title {\n  margin-bottom: 0;\n  line-height: 1.5;\n}\n\n.modal-body {\n  position: relative;\n  flex: 1 1 auto;\n  padding: 1rem;\n}\n\n.modal-footer {\n  display: flex;\n  align-items: center;\n  justify-content: flex-end;\n  padding: 1rem;\n  border-top: 1px solid #E5E7EB;\n}\n\n.modal-footer > :not(:first-child) {\n  margin-left: .25rem;\n}\n\n.modal-footer > :not(:last-child) {\n  margin-right: .25rem;\n}\n\n.modal-scrollbar-measure {\n  position: absolute;\n  top: -9999px;\n  width: 50px;\n  height: 50px;\n  overflow: scroll;\n}\n\n@media (min-width: 576px) {\n  .modal-dialog {\n    max-width: 500px;\n    margin: 1.75rem auto;\n  }\n  .modal-dialog-centered {\n    min-height: calc(100% - (1.75rem * 2));\n  }\n  .modal-dialog-centered::before {\n    height: calc(100vh - (1.75rem * 2));\n  }\n  .modal-sm {\n    max-width: 300px;\n  }\n}\n\n@media (min-width: 992px) {\n  .modal-lg {\n    max-width: 800px;\n  }\n}\n\n.tooltip {\n  position: absolute;\n  z-index: 1070;\n  display: block;\n  margin: 0;\n  font-family: \"Nunito\", sans-serif;\n  font-style: normal;\n  font-weight: 400;\n  line-height: 1.5;\n  text-align: left;\n  text-align: start;\n  text-decoration: none;\n  text-shadow: none;\n  text-transform: none;\n  letter-spacing: normal;\n  word-break: normal;\n  word-spacing: normal;\n  white-space: normal;\n  line-break: auto;\n  font-size: 0.711375rem;\n  word-wrap: break-word;\n  opacity: 0;\n}\n\n.tooltip.show {\n  opacity: 0.9;\n}\n\n.tooltip .arrow {\n  position: absolute;\n  display: block;\n  width: 0.8rem;\n  height: 0.4rem;\n}\n\n.tooltip .arrow::before {\n  position: absolute;\n  content: \"\";\n  border-color: transparent;\n  border-style: solid;\n}\n\n.bs-tooltip-top, .bs-tooltip-auto[x-placement^=\"top\"] {\n  padding: 0.4rem 0;\n}\n\n.bs-tooltip-top .arrow, .bs-tooltip-auto[x-placement^=\"top\"] .arrow {\n  bottom: 0;\n}\n\n.bs-tooltip-top .arrow::before, .bs-tooltip-auto[x-placement^=\"top\"] .arrow::before {\n  top: 0;\n  border-width: 0.4rem 0.4rem 0;\n  border-top-color: #0a021e;\n}\n\n.bs-tooltip-right, .bs-tooltip-auto[x-placement^=\"right\"] {\n  padding: 0 0.4rem;\n}\n\n.bs-tooltip-right .arrow, .bs-tooltip-auto[x-placement^=\"right\"] .arrow {\n  left: 0;\n  width: 0.4rem;\n  height: 0.8rem;\n}\n\n.bs-tooltip-right .arrow::before, .bs-tooltip-auto[x-placement^=\"right\"] .arrow::before {\n  right: 0;\n  border-width: 0.4rem 0.4rem 0.4rem 0;\n  border-right-color: #0a021e;\n}\n\n.bs-tooltip-bottom, .bs-tooltip-auto[x-placement^=\"bottom\"] {\n  padding: 0.4rem 0;\n}\n\n.bs-tooltip-bottom .arrow, .bs-tooltip-auto[x-placement^=\"bottom\"] .arrow {\n  top: 0;\n}\n\n.bs-tooltip-bottom .arrow::before, .bs-tooltip-auto[x-placement^=\"bottom\"] .arrow::before {\n  bottom: 0;\n  border-width: 0 0.4rem 0.4rem;\n  border-bottom-color: #0a021e;\n}\n\n.bs-tooltip-left, .bs-tooltip-auto[x-placement^=\"left\"] {\n  padding: 0 0.4rem;\n}\n\n.bs-tooltip-left .arrow, .bs-tooltip-auto[x-placement^=\"left\"] .arrow {\n  right: 0;\n  width: 0.4rem;\n  height: 0.8rem;\n}\n\n.bs-tooltip-left .arrow::before, .bs-tooltip-auto[x-placement^=\"left\"] .arrow::before {\n  left: 0;\n  border-width: 0.4rem 0 0.4rem 0.4rem;\n  border-left-color: #0a021e;\n}\n\n.tooltip-inner {\n  max-width: 200px;\n  padding: 0.25rem 0.5rem;\n  color: #fff;\n  text-align: center;\n  background-color: #0a021e;\n  border-radius: 0.25rem;\n}\n\n.toast {\n  max-width: 350px;\n  overflow: hidden;\n  font-size: 0.875rem;\n  background-color: rgba(255, 255, 255, 0.85);\n  background-clip: padding-box;\n  border: 1px solid rgba(0, 0, 0, 0.1);\n  border-radius: 0.25rem;\n  box-shadow: 0 0.25rem 0.75rem rgba(10, 2, 30, 0.1);\n  -webkit-backdrop-filter: blur(10px);\n          backdrop-filter: blur(10px);\n  opacity: 0;\n}\n\n.toast:not(:last-child) {\n  margin-bottom: 0.75rem;\n}\n\n.toast.showing {\n  opacity: 1;\n}\n\n.toast.show {\n  display: block;\n  opacity: 1;\n}\n\n.toast.hide {\n  display: none;\n}\n\n.toast-header {\n  display: flex;\n  align-items: center;\n  padding: 0.25rem 0.75rem;\n  color: #4B5563;\n  background-color: rgba(255, 255, 255, 0.85);\n  background-clip: padding-box;\n  border-bottom: 1px solid rgba(0, 0, 0, 0.05);\n}\n\n.toast-body {\n  padding: 0.75rem;\n}\n\n.popover {\n  position: absolute;\n  top: 0;\n  left: 0;\n  z-index: 1060;\n  display: block;\n  max-width: 276px;\n  font-family: \"Nunito\", sans-serif;\n  font-style: normal;\n  font-weight: 400;\n  line-height: 1.5;\n  text-align: left;\n  text-align: start;\n  text-decoration: none;\n  text-shadow: none;\n  text-transform: none;\n  letter-spacing: normal;\n  word-break: normal;\n  word-spacing: normal;\n  white-space: normal;\n  line-break: auto;\n  font-size: 0.711375rem;\n  word-wrap: break-word;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid rgba(10, 2, 30, 0.2);\n  border-radius: 0.3rem;\n}\n\n.popover .arrow {\n  position: absolute;\n  display: block;\n  width: 1rem;\n  height: 0.5rem;\n  margin: 0 0.3rem;\n}\n\n.popover .arrow::before, .popover .arrow::after {\n  position: absolute;\n  display: block;\n  content: \"\";\n  border-color: transparent;\n  border-style: solid;\n}\n\n.bs-popover-top, .bs-popover-auto[x-placement^=\"top\"] {\n  margin-bottom: 0.5rem;\n}\n\n.bs-popover-top .arrow, .bs-popover-auto[x-placement^=\"top\"] .arrow {\n  bottom: calc((0.5rem + 1px) * -1);\n}\n\n.bs-popover-top .arrow::before, .bs-popover-auto[x-placement^=\"top\"] .arrow::before,\n.bs-popover-top .arrow::after,\n.bs-popover-auto[x-placement^=\"top\"] .arrow::after {\n  border-width: 0.5rem 0.5rem 0;\n}\n\n.bs-popover-top .arrow::before, .bs-popover-auto[x-placement^=\"top\"] .arrow::before {\n  bottom: 0;\n  border-top-color: rgba(10, 2, 30, 0.25);\n}\n\n\n.bs-popover-top .arrow::after,\n.bs-popover-auto[x-placement^=\"top\"] .arrow::after {\n  bottom: 1px;\n  border-top-color: #fff;\n}\n\n.bs-popover-right, .bs-popover-auto[x-placement^=\"right\"] {\n  margin-left: 0.5rem;\n}\n\n.bs-popover-right .arrow, .bs-popover-auto[x-placement^=\"right\"] .arrow {\n  left: calc((0.5rem + 1px) * -1);\n  width: 0.5rem;\n  height: 1rem;\n  margin: 0.3rem 0;\n}\n\n.bs-popover-right .arrow::before, .bs-popover-auto[x-placement^=\"right\"] .arrow::before,\n.bs-popover-right .arrow::after,\n.bs-popover-auto[x-placement^=\"right\"] .arrow::after {\n  border-width: 0.5rem 0.5rem 0.5rem 0;\n}\n\n.bs-popover-right .arrow::before, .bs-popover-auto[x-placement^=\"right\"] .arrow::before {\n  left: 0;\n  border-right-color: rgba(10, 2, 30, 0.25);\n}\n\n\n.bs-popover-right .arrow::after,\n.bs-popover-auto[x-placement^=\"right\"] .arrow::after {\n  left: 1px;\n  border-right-color: #fff;\n}\n\n.bs-popover-bottom, .bs-popover-auto[x-placement^=\"bottom\"] {\n  margin-top: 0.5rem;\n}\n\n.bs-popover-bottom .arrow, .bs-popover-auto[x-placement^=\"bottom\"] .arrow {\n  top: calc((0.5rem + 1px) * -1);\n}\n\n.bs-popover-bottom .arrow::before, .bs-popover-auto[x-placement^=\"bottom\"] .arrow::before,\n.bs-popover-bottom .arrow::after,\n.bs-popover-auto[x-placement^=\"bottom\"] .arrow::after {\n  border-width: 0 0.5rem 0.5rem 0.5rem;\n}\n\n.bs-popover-bottom .arrow::before, .bs-popover-auto[x-placement^=\"bottom\"] .arrow::before {\n  top: 0;\n  border-bottom-color: rgba(10, 2, 30, 0.25);\n}\n\n\n.bs-popover-bottom .arrow::after,\n.bs-popover-auto[x-placement^=\"bottom\"] .arrow::after {\n  top: 1px;\n  border-bottom-color: #fff;\n}\n\n.bs-popover-bottom .popover-header::before, .bs-popover-auto[x-placement^=\"bottom\"] .popover-header::before {\n  position: absolute;\n  top: 0;\n  left: 50%;\n  display: block;\n  width: 1rem;\n  margin-left: -0.5rem;\n  content: \"\";\n  border-bottom: 1px solid #f7f7f7;\n}\n\n.bs-popover-left, .bs-popover-auto[x-placement^=\"left\"] {\n  margin-right: 0.5rem;\n}\n\n.bs-popover-left .arrow, .bs-popover-auto[x-placement^=\"left\"] .arrow {\n  right: calc((0.5rem + 1px) * -1);\n  width: 0.5rem;\n  height: 1rem;\n  margin: 0.3rem 0;\n}\n\n.bs-popover-left .arrow::before, .bs-popover-auto[x-placement^=\"left\"] .arrow::before,\n.bs-popover-left .arrow::after,\n.bs-popover-auto[x-placement^=\"left\"] .arrow::after {\n  border-width: 0.5rem 0 0.5rem 0.5rem;\n}\n\n.bs-popover-left .arrow::before, .bs-popover-auto[x-placement^=\"left\"] .arrow::before {\n  right: 0;\n  border-left-color: rgba(10, 2, 30, 0.25);\n}\n\n\n.bs-popover-left .arrow::after,\n.bs-popover-auto[x-placement^=\"left\"] .arrow::after {\n  right: 1px;\n  border-left-color: #fff;\n}\n\n.popover-header {\n  padding: 0.5rem 0.75rem;\n  margin-bottom: 0;\n  font-size: 0.813rem;\n  color: inherit;\n  background-color: #f7f7f7;\n  border-bottom: 1px solid #ebebeb;\n  border-top-left-radius: calc(0.3rem - 1px);\n  border-top-right-radius: calc(0.3rem - 1px);\n}\n\n.popover-header:empty {\n  display: none;\n}\n\n.popover-body {\n  padding: 0.5rem 0.75rem;\n  color: #111827;\n}\n\n.carousel {\n  position: relative;\n}\n\n.carousel-inner {\n  position: relative;\n  width: 100%;\n  overflow: hidden;\n}\n\n.carousel-item {\n  position: relative;\n  display: none;\n  align-items: center;\n  width: 100%;\n  -webkit-backface-visibility: hidden;\n          backface-visibility: hidden;\n  perspective: 1000px;\n}\n\n.carousel-item.active,\n.carousel-item-next,\n.carousel-item-prev {\n  display: block;\n  transition: transform 0.6s ease;\n}\n\n@media screen and (prefers-reduced-motion: reduce) {\n  .carousel-item.active,\n  .carousel-item-next,\n  .carousel-item-prev {\n    transition: none;\n  }\n}\n\n.carousel-item-next,\n.carousel-item-prev {\n  position: absolute;\n  top: 0;\n}\n\n.carousel-item-next.carousel-item-left,\n.carousel-item-prev.carousel-item-right {\n  transform: translateX(0);\n}\n\n@supports (transform-style: preserve-3d) {\n  .carousel-item-next.carousel-item-left,\n  .carousel-item-prev.carousel-item-right {\n    transform: translate3d(0, 0, 0);\n  }\n}\n\n.carousel-item-next,\n.active.carousel-item-right {\n  transform: translateX(100%);\n}\n\n@supports (transform-style: preserve-3d) {\n  .carousel-item-next,\n  .active.carousel-item-right {\n    transform: translate3d(100%, 0, 0);\n  }\n}\n\n.carousel-item-prev,\n.active.carousel-item-left {\n  transform: translateX(-100%);\n}\n\n@supports (transform-style: preserve-3d) {\n  .carousel-item-prev,\n  .active.carousel-item-left {\n    transform: translate3d(-100%, 0, 0);\n  }\n}\n\n.carousel-fade .carousel-item {\n  opacity: 0;\n  transition-duration: .6s;\n  transition-property: opacity;\n}\n\n.carousel-fade .carousel-item.active,\n.carousel-fade .carousel-item-next.carousel-item-left,\n.carousel-fade .carousel-item-prev.carousel-item-right {\n  opacity: 1;\n}\n\n.carousel-fade .active.carousel-item-left,\n.carousel-fade .active.carousel-item-right {\n  opacity: 0;\n}\n\n.carousel-fade .carousel-item-next,\n.carousel-fade .carousel-item-prev,\n.carousel-fade .carousel-item.active,\n.carousel-fade .active.carousel-item-left,\n.carousel-fade .active.carousel-item-prev {\n  transform: translateX(0);\n}\n\n@supports (transform-style: preserve-3d) {\n  .carousel-fade .carousel-item-next,\n  .carousel-fade .carousel-item-prev,\n  .carousel-fade .carousel-item.active,\n  .carousel-fade .active.carousel-item-left,\n  .carousel-fade .active.carousel-item-prev {\n    transform: translate3d(0, 0, 0);\n  }\n}\n\n.carousel-control-prev,\n.carousel-control-next {\n  position: absolute;\n  top: 0;\n  bottom: 0;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 15%;\n  color: #fff;\n  text-align: center;\n  opacity: 0.5;\n}\n\n.carousel-control-prev:hover, .carousel-control-prev:focus,\n.carousel-control-next:hover,\n.carousel-control-next:focus {\n  color: #fff;\n  text-decoration: none;\n  outline: 0;\n  opacity: .9;\n}\n\n.carousel-control-prev {\n  left: 0;\n}\n\n.carousel-control-next {\n  right: 0;\n}\n\n.carousel-control-prev-icon,\n.carousel-control-next-icon {\n  display: inline-block;\n  width: 20px;\n  height: 20px;\n  background: transparent no-repeat center center;\n  background-size: 100% 100%;\n}\n\n.carousel-control-prev-icon {\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' viewBox='0 0 8 8'%3E%3Cpath d='M5.25 0l-4 4 4 4 1.5-1.5-2.5-2.5 2.5-2.5-1.5-1.5z'/%3E%3C/svg%3E\");\n}\n\n.carousel-control-next-icon {\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='%23fff' viewBox='0 0 8 8'%3E%3Cpath d='M2.75 0l-1.5 1.5 2.5 2.5-2.5 2.5 1.5 1.5 4-4-4-4z'/%3E%3C/svg%3E\");\n}\n\n.carousel-indicators {\n  position: absolute;\n  right: 0;\n  bottom: 10px;\n  left: 0;\n  z-index: 15;\n  display: flex;\n  justify-content: center;\n  padding-left: 0;\n  margin-right: 15%;\n  margin-left: 15%;\n  list-style: none;\n}\n\n.carousel-indicators li {\n  position: relative;\n  flex: 0 1 auto;\n  width: 30px;\n  height: 3px;\n  margin-right: 3px;\n  margin-left: 3px;\n  text-indent: -999px;\n  cursor: pointer;\n  background-color: rgba(255, 255, 255, 0.5);\n}\n\n.carousel-indicators li::before {\n  position: absolute;\n  top: -10px;\n  left: 0;\n  display: inline-block;\n  width: 100%;\n  height: 10px;\n  content: \"\";\n}\n\n.carousel-indicators li::after {\n  position: absolute;\n  bottom: -10px;\n  left: 0;\n  display: inline-block;\n  width: 100%;\n  height: 10px;\n  content: \"\";\n}\n\n.carousel-indicators .active {\n  background-color: #fff;\n}\n\n.carousel-caption {\n  position: absolute;\n  right: 15%;\n  bottom: 20px;\n  left: 15%;\n  z-index: 10;\n  padding-top: 20px;\n  padding-bottom: 20px;\n  color: #fff;\n  text-align: center;\n}\n\n.align-baseline {\n  vertical-align: baseline !important;\n}\n\n.align-top {\n  vertical-align: top !important;\n}\n\n.align-middle {\n  vertical-align: middle !important;\n}\n\n.align-bottom {\n  vertical-align: bottom !important;\n}\n\n.align-text-bottom {\n  vertical-align: text-bottom !important;\n}\n\n.align-text-top {\n  vertical-align: text-top !important;\n}\n\n.bg-primary {\n  background-color: #8b5cf6 !important;\n}\n\na.bg-primary:hover, a.bg-primary:focus,\nbutton.bg-primary:hover,\nbutton.bg-primary:focus {\n  background-color: #692cf3 !important;\n}\n\n.bg-secondary {\n  background-color: #1F2937 !important;\n}\n\na.bg-secondary:hover, a.bg-secondary:focus,\nbutton.bg-secondary:hover,\nbutton.bg-secondary:focus {\n  background-color: #0d1116 !important;\n}\n\n.bg-success {\n  background-color: #10b981 !important;\n}\n\na.bg-success:hover, a.bg-success:focus,\nbutton.bg-success:hover,\nbutton.bg-success:focus {\n  background-color: #0c8a60 !important;\n}\n\n.bg-info {\n  background-color: #3b82f6 !important;\n}\n\na.bg-info:hover, a.bg-info:focus,\nbutton.bg-info:hover,\nbutton.bg-info:focus {\n  background-color: #0b63f3 !important;\n}\n\n.bg-warning {\n  background-color: #f59e0b !important;\n}\n\na.bg-warning:hover, a.bg-warning:focus,\nbutton.bg-warning:hover,\nbutton.bg-warning:focus {\n  background-color: #c57f08 !important;\n}\n\n.bg-danger {\n  background-color: #ef4444 !important;\n}\n\na.bg-danger:hover, a.bg-danger:focus,\nbutton.bg-danger:hover,\nbutton.bg-danger:focus {\n  background-color: #eb1515 !important;\n}\n\n.bg-light {\n  background-color: #6B7280 !important;\n}\n\na.bg-light:hover, a.bg-light:focus,\nbutton.bg-light:hover,\nbutton.bg-light:focus {\n  background-color: #545964 !important;\n}\n\n.bg-dark {\n  background-color: #111827 !important;\n}\n\na.bg-dark:hover, a.bg-dark:focus,\nbutton.bg-dark:hover,\nbutton.bg-dark:focus {\n  background-color: #020203 !important;\n}\n\n.bg-gray-100 {\n  background-color: #F3F4F6 !important;\n}\n\na.bg-gray-100:hover, a.bg-gray-100:focus,\nbutton.bg-gray-100:hover,\nbutton.bg-gray-100:focus {\n  background-color: #d6d9e0 !important;\n}\n\n.bg-gray-200 {\n  background-color: #E5E7EB !important;\n}\n\na.bg-gray-200:hover, a.bg-gray-200:focus,\nbutton.bg-gray-200:hover,\nbutton.bg-gray-200:focus {\n  background-color: #c8ccd5 !important;\n}\n\n.bg-gray-300 {\n  background-color: #D1D5DB !important;\n}\n\na.bg-gray-300:hover, a.bg-gray-300:focus,\nbutton.bg-gray-300:hover,\nbutton.bg-gray-300:focus {\n  background-color: #b4bbc5 !important;\n}\n\n.bg-gray-400 {\n  background-color: #9CA3AF !important;\n}\n\na.bg-gray-400:hover, a.bg-gray-400:focus,\nbutton.bg-gray-400:hover,\nbutton.bg-gray-400:focus {\n  background-color: #808998 !important;\n}\n\n.bg-gray-500 {\n  background-color: #6B7280 !important;\n}\n\na.bg-gray-500:hover, a.bg-gray-500:focus,\nbutton.bg-gray-500:hover,\nbutton.bg-gray-500:focus {\n  background-color: #545964 !important;\n}\n\n.bg-gray-600 {\n  background-color: #4B5563 !important;\n}\n\na.bg-gray-600:hover, a.bg-gray-600:focus,\nbutton.bg-gray-600:hover,\nbutton.bg-gray-600:focus {\n  background-color: #353c46 !important;\n}\n\n.bg-gray-700 {\n  background-color: #374151 !important;\n}\n\na.bg-gray-700:hover, a.bg-gray-700:focus,\nbutton.bg-gray-700:hover,\nbutton.bg-gray-700:focus {\n  background-color: #222933 !important;\n}\n\n.bg-gray-800 {\n  background-color: #1F2937 !important;\n}\n\na.bg-gray-800:hover, a.bg-gray-800:focus,\nbutton.bg-gray-800:hover,\nbutton.bg-gray-800:focus {\n  background-color: #0d1116 !important;\n}\n\n.bg-gray-900 {\n  background-color: #111827 !important;\n}\n\na.bg-gray-900:hover, a.bg-gray-900:focus,\nbutton.bg-gray-900:hover,\nbutton.bg-gray-900:focus {\n  background-color: #020203 !important;\n}\n\n.bg-white {\n  background-color: #fff !important;\n}\n\n.bg-transparent {\n  background-color: transparent !important;\n}\n\n.border {\n  border: 1px solid #D1D5DB !important;\n}\n\n.border-top {\n  border-top: 1px solid #D1D5DB !important;\n}\n\n.border-right {\n  border-right: 1px solid #D1D5DB !important;\n}\n\n.border-bottom {\n  border-bottom: 1px solid #D1D5DB !important;\n}\n\n.border-left {\n  border-left: 1px solid #D1D5DB !important;\n}\n\n.border-0 {\n  border: 0 !important;\n}\n\n.border-top-0 {\n  border-top: 0 !important;\n}\n\n.border-right-0 {\n  border-right: 0 !important;\n}\n\n.border-bottom-0 {\n  border-bottom: 0 !important;\n}\n\n.border-left-0 {\n  border-left: 0 !important;\n}\n\n.border-primary {\n  border-color: #8b5cf6 !important;\n}\n\n.border-secondary {\n  border-color: #1F2937 !important;\n}\n\n.border-success {\n  border-color: #10b981 !important;\n}\n\n.border-info {\n  border-color: #3b82f6 !important;\n}\n\n.border-warning {\n  border-color: #f59e0b !important;\n}\n\n.border-danger {\n  border-color: #ef4444 !important;\n}\n\n.border-light {\n  border-color: #6B7280 !important;\n}\n\n.border-dark {\n  border-color: #111827 !important;\n}\n\n.border-gray-100 {\n  border-color: #F3F4F6 !important;\n}\n\n.border-gray-200 {\n  border-color: #E5E7EB !important;\n}\n\n.border-gray-300 {\n  border-color: #D1D5DB !important;\n}\n\n.border-gray-400 {\n  border-color: #9CA3AF !important;\n}\n\n.border-gray-500 {\n  border-color: #6B7280 !important;\n}\n\n.border-gray-600 {\n  border-color: #4B5563 !important;\n}\n\n.border-gray-700 {\n  border-color: #374151 !important;\n}\n\n.border-gray-800 {\n  border-color: #1F2937 !important;\n}\n\n.border-gray-900 {\n  border-color: #111827 !important;\n}\n\n.border-white {\n  border-color: #fff !important;\n}\n\n.rounded {\n  border-radius: 0.25rem !important;\n}\n\n.rounded-top {\n  border-top-left-radius: 0.25rem !important;\n  border-top-right-radius: 0.25rem !important;\n}\n\n.rounded-right {\n  border-top-right-radius: 0.25rem !important;\n  border-bottom-right-radius: 0.25rem !important;\n}\n\n.rounded-bottom {\n  border-bottom-right-radius: 0.25rem !important;\n  border-bottom-left-radius: 0.25rem !important;\n}\n\n.rounded-left {\n  border-top-left-radius: 0.25rem !important;\n  border-bottom-left-radius: 0.25rem !important;\n}\n\n.rounded-circle {\n  border-radius: 50% !important;\n}\n\n.rounded-0 {\n  border-radius: 0 !important;\n}\n\n.clearfix::after {\n  display: block;\n  clear: both;\n  content: \"\";\n}\n\n.d-none {\n  display: none !important;\n}\n\n.d-inline {\n  display: inline !important;\n}\n\n.d-inline-block {\n  display: inline-block !important;\n}\n\n.d-block {\n  display: block !important;\n}\n\n.d-table {\n  display: table !important;\n}\n\n.d-table-row {\n  display: table-row !important;\n}\n\n.d-table-cell {\n  display: table-cell !important;\n}\n\n.d-flex {\n  display: flex !important;\n}\n\n.d-inline-flex {\n  display: inline-flex !important;\n}\n\n@media (min-width: 576px) {\n  .d-sm-none {\n    display: none !important;\n  }\n  .d-sm-inline {\n    display: inline !important;\n  }\n  .d-sm-inline-block {\n    display: inline-block !important;\n  }\n  .d-sm-block {\n    display: block !important;\n  }\n  .d-sm-table {\n    display: table !important;\n  }\n  .d-sm-table-row {\n    display: table-row !important;\n  }\n  .d-sm-table-cell {\n    display: table-cell !important;\n  }\n  .d-sm-flex {\n    display: flex !important;\n  }\n  .d-sm-inline-flex {\n    display: inline-flex !important;\n  }\n}\n\n@media (min-width: 768px) {\n  .d-md-none {\n    display: none !important;\n  }\n  .d-md-inline {\n    display: inline !important;\n  }\n  .d-md-inline-block {\n    display: inline-block !important;\n  }\n  .d-md-block {\n    display: block !important;\n  }\n  .d-md-table {\n    display: table !important;\n  }\n  .d-md-table-row {\n    display: table-row !important;\n  }\n  .d-md-table-cell {\n    display: table-cell !important;\n  }\n  .d-md-flex {\n    display: flex !important;\n  }\n  .d-md-inline-flex {\n    display: inline-flex !important;\n  }\n}\n\n@media (min-width: 992px) {\n  .d-lg-none {\n    display: none !important;\n  }\n  .d-lg-inline {\n    display: inline !important;\n  }\n  .d-lg-inline-block {\n    display: inline-block !important;\n  }\n  .d-lg-block {\n    display: block !important;\n  }\n  .d-lg-table {\n    display: table !important;\n  }\n  .d-lg-table-row {\n    display: table-row !important;\n  }\n  .d-lg-table-cell {\n    display: table-cell !important;\n  }\n  .d-lg-flex {\n    display: flex !important;\n  }\n  .d-lg-inline-flex {\n    display: inline-flex !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  .d-xl-none {\n    display: none !important;\n  }\n  .d-xl-inline {\n    display: inline !important;\n  }\n  .d-xl-inline-block {\n    display: inline-block !important;\n  }\n  .d-xl-block {\n    display: block !important;\n  }\n  .d-xl-table {\n    display: table !important;\n  }\n  .d-xl-table-row {\n    display: table-row !important;\n  }\n  .d-xl-table-cell {\n    display: table-cell !important;\n  }\n  .d-xl-flex {\n    display: flex !important;\n  }\n  .d-xl-inline-flex {\n    display: inline-flex !important;\n  }\n}\n\n@media print {\n  .d-print-none {\n    display: none !important;\n  }\n  .d-print-inline {\n    display: inline !important;\n  }\n  .d-print-inline-block {\n    display: inline-block !important;\n  }\n  .d-print-block {\n    display: block !important;\n  }\n  .d-print-table {\n    display: table !important;\n  }\n  .d-print-table-row {\n    display: table-row !important;\n  }\n  .d-print-table-cell {\n    display: table-cell !important;\n  }\n  .d-print-flex {\n    display: flex !important;\n  }\n  .d-print-inline-flex {\n    display: inline-flex !important;\n  }\n}\n\n.embed-responsive {\n  position: relative;\n  display: block;\n  width: 100%;\n  padding: 0;\n  overflow: hidden;\n}\n\n.embed-responsive::before {\n  display: block;\n  content: \"\";\n}\n\n.embed-responsive .embed-responsive-item,\n.embed-responsive iframe,\n.embed-responsive embed,\n.embed-responsive object,\n.embed-responsive video {\n  position: absolute;\n  top: 0;\n  bottom: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  border: 0;\n}\n\n.embed-responsive-21by9::before {\n  padding-top: 42.85714286%;\n}\n\n.embed-responsive-16by9::before {\n  padding-top: 56.25%;\n}\n\n.embed-responsive-4by3::before {\n  padding-top: 75%;\n}\n\n.embed-responsive-1by1::before {\n  padding-top: 100%;\n}\n\n.flex-row {\n  flex-direction: row !important;\n}\n\n.flex-column {\n  flex-direction: column !important;\n}\n\n.flex-row-reverse {\n  flex-direction: row-reverse !important;\n}\n\n.flex-column-reverse {\n  flex-direction: column-reverse !important;\n}\n\n.flex-wrap {\n  flex-wrap: wrap !important;\n}\n\n.flex-nowrap {\n  flex-wrap: nowrap !important;\n}\n\n.flex-wrap-reverse {\n  flex-wrap: wrap-reverse !important;\n}\n\n.flex-fill {\n  flex: 1 1 auto !important;\n}\n\n.flex-grow-0 {\n  flex-grow: 0 !important;\n}\n\n.flex-grow-1 {\n  flex-grow: 1 !important;\n}\n\n.flex-shrink-0 {\n  flex-shrink: 0 !important;\n}\n\n.flex-shrink-1 {\n  flex-shrink: 1 !important;\n}\n\n.justify-content-start {\n  justify-content: flex-start !important;\n}\n\n.justify-content-end {\n  justify-content: flex-end !important;\n}\n\n.justify-content-center {\n  justify-content: center !important;\n}\n\n.justify-content-between {\n  justify-content: space-between !important;\n}\n\n.justify-content-around {\n  justify-content: space-around !important;\n}\n\n.align-items-start {\n  align-items: flex-start !important;\n}\n\n.align-items-end {\n  align-items: flex-end !important;\n}\n\n.align-items-center {\n  align-items: center !important;\n}\n\n.align-items-baseline {\n  align-items: baseline !important;\n}\n\n.align-items-stretch {\n  align-items: stretch !important;\n}\n\n.align-content-start {\n  align-content: flex-start !important;\n}\n\n.align-content-end {\n  align-content: flex-end !important;\n}\n\n.align-content-center {\n  align-content: center !important;\n}\n\n.align-content-between {\n  align-content: space-between !important;\n}\n\n.align-content-around {\n  align-content: space-around !important;\n}\n\n.align-content-stretch {\n  align-content: stretch !important;\n}\n\n.align-self-auto {\n  align-self: auto !important;\n}\n\n.align-self-start {\n  align-self: flex-start !important;\n}\n\n.align-self-end {\n  align-self: flex-end !important;\n}\n\n.align-self-center {\n  align-self: center !important;\n}\n\n.align-self-baseline {\n  align-self: baseline !important;\n}\n\n.align-self-stretch {\n  align-self: stretch !important;\n}\n\n@media (min-width: 576px) {\n  .flex-sm-row {\n    flex-direction: row !important;\n  }\n  .flex-sm-column {\n    flex-direction: column !important;\n  }\n  .flex-sm-row-reverse {\n    flex-direction: row-reverse !important;\n  }\n  .flex-sm-column-reverse {\n    flex-direction: column-reverse !important;\n  }\n  .flex-sm-wrap {\n    flex-wrap: wrap !important;\n  }\n  .flex-sm-nowrap {\n    flex-wrap: nowrap !important;\n  }\n  .flex-sm-wrap-reverse {\n    flex-wrap: wrap-reverse !important;\n  }\n  .flex-sm-fill {\n    flex: 1 1 auto !important;\n  }\n  .flex-sm-grow-0 {\n    flex-grow: 0 !important;\n  }\n  .flex-sm-grow-1 {\n    flex-grow: 1 !important;\n  }\n  .flex-sm-shrink-0 {\n    flex-shrink: 0 !important;\n  }\n  .flex-sm-shrink-1 {\n    flex-shrink: 1 !important;\n  }\n  .justify-content-sm-start {\n    justify-content: flex-start !important;\n  }\n  .justify-content-sm-end {\n    justify-content: flex-end !important;\n  }\n  .justify-content-sm-center {\n    justify-content: center !important;\n  }\n  .justify-content-sm-between {\n    justify-content: space-between !important;\n  }\n  .justify-content-sm-around {\n    justify-content: space-around !important;\n  }\n  .align-items-sm-start {\n    align-items: flex-start !important;\n  }\n  .align-items-sm-end {\n    align-items: flex-end !important;\n  }\n  .align-items-sm-center {\n    align-items: center !important;\n  }\n  .align-items-sm-baseline {\n    align-items: baseline !important;\n  }\n  .align-items-sm-stretch {\n    align-items: stretch !important;\n  }\n  .align-content-sm-start {\n    align-content: flex-start !important;\n  }\n  .align-content-sm-end {\n    align-content: flex-end !important;\n  }\n  .align-content-sm-center {\n    align-content: center !important;\n  }\n  .align-content-sm-between {\n    align-content: space-between !important;\n  }\n  .align-content-sm-around {\n    align-content: space-around !important;\n  }\n  .align-content-sm-stretch {\n    align-content: stretch !important;\n  }\n  .align-self-sm-auto {\n    align-self: auto !important;\n  }\n  .align-self-sm-start {\n    align-self: flex-start !important;\n  }\n  .align-self-sm-end {\n    align-self: flex-end !important;\n  }\n  .align-self-sm-center {\n    align-self: center !important;\n  }\n  .align-self-sm-baseline {\n    align-self: baseline !important;\n  }\n  .align-self-sm-stretch {\n    align-self: stretch !important;\n  }\n}\n\n@media (min-width: 768px) {\n  .flex-md-row {\n    flex-direction: row !important;\n  }\n  .flex-md-column {\n    flex-direction: column !important;\n  }\n  .flex-md-row-reverse {\n    flex-direction: row-reverse !important;\n  }\n  .flex-md-column-reverse {\n    flex-direction: column-reverse !important;\n  }\n  .flex-md-wrap {\n    flex-wrap: wrap !important;\n  }\n  .flex-md-nowrap {\n    flex-wrap: nowrap !important;\n  }\n  .flex-md-wrap-reverse {\n    flex-wrap: wrap-reverse !important;\n  }\n  .flex-md-fill {\n    flex: 1 1 auto !important;\n  }\n  .flex-md-grow-0 {\n    flex-grow: 0 !important;\n  }\n  .flex-md-grow-1 {\n    flex-grow: 1 !important;\n  }\n  .flex-md-shrink-0 {\n    flex-shrink: 0 !important;\n  }\n  .flex-md-shrink-1 {\n    flex-shrink: 1 !important;\n  }\n  .justify-content-md-start {\n    justify-content: flex-start !important;\n  }\n  .justify-content-md-end {\n    justify-content: flex-end !important;\n  }\n  .justify-content-md-center {\n    justify-content: center !important;\n  }\n  .justify-content-md-between {\n    justify-content: space-between !important;\n  }\n  .justify-content-md-around {\n    justify-content: space-around !important;\n  }\n  .align-items-md-start {\n    align-items: flex-start !important;\n  }\n  .align-items-md-end {\n    align-items: flex-end !important;\n  }\n  .align-items-md-center {\n    align-items: center !important;\n  }\n  .align-items-md-baseline {\n    align-items: baseline !important;\n  }\n  .align-items-md-stretch {\n    align-items: stretch !important;\n  }\n  .align-content-md-start {\n    align-content: flex-start !important;\n  }\n  .align-content-md-end {\n    align-content: flex-end !important;\n  }\n  .align-content-md-center {\n    align-content: center !important;\n  }\n  .align-content-md-between {\n    align-content: space-between !important;\n  }\n  .align-content-md-around {\n    align-content: space-around !important;\n  }\n  .align-content-md-stretch {\n    align-content: stretch !important;\n  }\n  .align-self-md-auto {\n    align-self: auto !important;\n  }\n  .align-self-md-start {\n    align-self: flex-start !important;\n  }\n  .align-self-md-end {\n    align-self: flex-end !important;\n  }\n  .align-self-md-center {\n    align-self: center !important;\n  }\n  .align-self-md-baseline {\n    align-self: baseline !important;\n  }\n  .align-self-md-stretch {\n    align-self: stretch !important;\n  }\n}\n\n@media (min-width: 992px) {\n  .flex-lg-row {\n    flex-direction: row !important;\n  }\n  .flex-lg-column {\n    flex-direction: column !important;\n  }\n  .flex-lg-row-reverse {\n    flex-direction: row-reverse !important;\n  }\n  .flex-lg-column-reverse {\n    flex-direction: column-reverse !important;\n  }\n  .flex-lg-wrap {\n    flex-wrap: wrap !important;\n  }\n  .flex-lg-nowrap {\n    flex-wrap: nowrap !important;\n  }\n  .flex-lg-wrap-reverse {\n    flex-wrap: wrap-reverse !important;\n  }\n  .flex-lg-fill {\n    flex: 1 1 auto !important;\n  }\n  .flex-lg-grow-0 {\n    flex-grow: 0 !important;\n  }\n  .flex-lg-grow-1 {\n    flex-grow: 1 !important;\n  }\n  .flex-lg-shrink-0 {\n    flex-shrink: 0 !important;\n  }\n  .flex-lg-shrink-1 {\n    flex-shrink: 1 !important;\n  }\n  .justify-content-lg-start {\n    justify-content: flex-start !important;\n  }\n  .justify-content-lg-end {\n    justify-content: flex-end !important;\n  }\n  .justify-content-lg-center {\n    justify-content: center !important;\n  }\n  .justify-content-lg-between {\n    justify-content: space-between !important;\n  }\n  .justify-content-lg-around {\n    justify-content: space-around !important;\n  }\n  .align-items-lg-start {\n    align-items: flex-start !important;\n  }\n  .align-items-lg-end {\n    align-items: flex-end !important;\n  }\n  .align-items-lg-center {\n    align-items: center !important;\n  }\n  .align-items-lg-baseline {\n    align-items: baseline !important;\n  }\n  .align-items-lg-stretch {\n    align-items: stretch !important;\n  }\n  .align-content-lg-start {\n    align-content: flex-start !important;\n  }\n  .align-content-lg-end {\n    align-content: flex-end !important;\n  }\n  .align-content-lg-center {\n    align-content: center !important;\n  }\n  .align-content-lg-between {\n    align-content: space-between !important;\n  }\n  .align-content-lg-around {\n    align-content: space-around !important;\n  }\n  .align-content-lg-stretch {\n    align-content: stretch !important;\n  }\n  .align-self-lg-auto {\n    align-self: auto !important;\n  }\n  .align-self-lg-start {\n    align-self: flex-start !important;\n  }\n  .align-self-lg-end {\n    align-self: flex-end !important;\n  }\n  .align-self-lg-center {\n    align-self: center !important;\n  }\n  .align-self-lg-baseline {\n    align-self: baseline !important;\n  }\n  .align-self-lg-stretch {\n    align-self: stretch !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  .flex-xl-row {\n    flex-direction: row !important;\n  }\n  .flex-xl-column {\n    flex-direction: column !important;\n  }\n  .flex-xl-row-reverse {\n    flex-direction: row-reverse !important;\n  }\n  .flex-xl-column-reverse {\n    flex-direction: column-reverse !important;\n  }\n  .flex-xl-wrap {\n    flex-wrap: wrap !important;\n  }\n  .flex-xl-nowrap {\n    flex-wrap: nowrap !important;\n  }\n  .flex-xl-wrap-reverse {\n    flex-wrap: wrap-reverse !important;\n  }\n  .flex-xl-fill {\n    flex: 1 1 auto !important;\n  }\n  .flex-xl-grow-0 {\n    flex-grow: 0 !important;\n  }\n  .flex-xl-grow-1 {\n    flex-grow: 1 !important;\n  }\n  .flex-xl-shrink-0 {\n    flex-shrink: 0 !important;\n  }\n  .flex-xl-shrink-1 {\n    flex-shrink: 1 !important;\n  }\n  .justify-content-xl-start {\n    justify-content: flex-start !important;\n  }\n  .justify-content-xl-end {\n    justify-content: flex-end !important;\n  }\n  .justify-content-xl-center {\n    justify-content: center !important;\n  }\n  .justify-content-xl-between {\n    justify-content: space-between !important;\n  }\n  .justify-content-xl-around {\n    justify-content: space-around !important;\n  }\n  .align-items-xl-start {\n    align-items: flex-start !important;\n  }\n  .align-items-xl-end {\n    align-items: flex-end !important;\n  }\n  .align-items-xl-center {\n    align-items: center !important;\n  }\n  .align-items-xl-baseline {\n    align-items: baseline !important;\n  }\n  .align-items-xl-stretch {\n    align-items: stretch !important;\n  }\n  .align-content-xl-start {\n    align-content: flex-start !important;\n  }\n  .align-content-xl-end {\n    align-content: flex-end !important;\n  }\n  .align-content-xl-center {\n    align-content: center !important;\n  }\n  .align-content-xl-between {\n    align-content: space-between !important;\n  }\n  .align-content-xl-around {\n    align-content: space-around !important;\n  }\n  .align-content-xl-stretch {\n    align-content: stretch !important;\n  }\n  .align-self-xl-auto {\n    align-self: auto !important;\n  }\n  .align-self-xl-start {\n    align-self: flex-start !important;\n  }\n  .align-self-xl-end {\n    align-self: flex-end !important;\n  }\n  .align-self-xl-center {\n    align-self: center !important;\n  }\n  .align-self-xl-baseline {\n    align-self: baseline !important;\n  }\n  .align-self-xl-stretch {\n    align-self: stretch !important;\n  }\n}\n\n.float-left {\n  float: left !important;\n}\n\n.float-right {\n  float: right !important;\n}\n\n.float-none {\n  float: none !important;\n}\n\n@media (min-width: 576px) {\n  .float-sm-left {\n    float: left !important;\n  }\n  .float-sm-right {\n    float: right !important;\n  }\n  .float-sm-none {\n    float: none !important;\n  }\n}\n\n@media (min-width: 768px) {\n  .float-md-left {\n    float: left !important;\n  }\n  .float-md-right {\n    float: right !important;\n  }\n  .float-md-none {\n    float: none !important;\n  }\n}\n\n@media (min-width: 992px) {\n  .float-lg-left {\n    float: left !important;\n  }\n  .float-lg-right {\n    float: right !important;\n  }\n  .float-lg-none {\n    float: none !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  .float-xl-left {\n    float: left !important;\n  }\n  .float-xl-right {\n    float: right !important;\n  }\n  .float-xl-none {\n    float: none !important;\n  }\n}\n\n.position-static {\n  position: static !important;\n}\n\n.position-relative {\n  position: relative !important;\n}\n\n.position-absolute {\n  position: absolute !important;\n}\n\n.position-fixed {\n  position: fixed !important;\n}\n\n.position-sticky {\n  position: sticky !important;\n}\n\n.fixed-top {\n  position: fixed;\n  top: 0;\n  right: 0;\n  left: 0;\n  z-index: 1030;\n}\n\n.fixed-bottom {\n  position: fixed;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  z-index: 1030;\n}\n\n@supports (position: sticky) {\n  .sticky-top {\n    position: sticky;\n    top: 0;\n    z-index: 1020;\n  }\n}\n\n.sr-only {\n  position: absolute;\n  width: 1px;\n  height: 1px;\n  padding: 0;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  white-space: nowrap;\n  border: 0;\n}\n\n.sr-only-focusable:active, .sr-only-focusable:focus {\n  position: static;\n  width: auto;\n  height: auto;\n  overflow: visible;\n  clip: auto;\n  white-space: normal;\n}\n\n.shadow-sm {\n  box-shadow: 0 0.125rem 0.25rem rgba(10, 2, 30, 0.075) !important;\n}\n\n.shadow {\n  box-shadow: 0 0.5rem 1rem rgba(10, 2, 30, 0.15) !important;\n}\n\n.shadow-lg {\n  box-shadow: 0 1rem 3rem rgba(10, 2, 30, 0.175) !important;\n}\n\n.shadow-none {\n  box-shadow: none !important;\n}\n\n.w-25 {\n  width: 25% !important;\n}\n\n.w-50 {\n  width: 50% !important;\n}\n\n.w-75 {\n  width: 75% !important;\n}\n\n.w-100 {\n  width: 100% !important;\n}\n\n.w-auto {\n  width: auto !important;\n}\n\n.h-25 {\n  height: 25% !important;\n}\n\n.h-50 {\n  height: 50% !important;\n}\n\n.h-75 {\n  height: 75% !important;\n}\n\n.h-100 {\n  height: 100% !important;\n}\n\n.h-auto {\n  height: auto !important;\n}\n\n.mw-100 {\n  max-width: 100% !important;\n}\n\n.mh-100 {\n  max-height: 100% !important;\n}\n\n.m-0 {\n  margin: 0 !important;\n}\n\n.mt-0,\n.my-0 {\n  margin-top: 0 !important;\n}\n\n.mr-0,\n.mx-0 {\n  margin-right: 0 !important;\n}\n\n.mb-0,\n.my-0 {\n  margin-bottom: 0 !important;\n}\n\n.ml-0,\n.mx-0 {\n  margin-left: 0 !important;\n}\n\n.m-1 {\n  margin: 0.25rem !important;\n}\n\n.mt-1,\n.my-1 {\n  margin-top: 0.25rem !important;\n}\n\n.mr-1,\n.mx-1 {\n  margin-right: 0.25rem !important;\n}\n\n.mb-1,\n.my-1 {\n  margin-bottom: 0.25rem !important;\n}\n\n.ml-1,\n.mx-1 {\n  margin-left: 0.25rem !important;\n}\n\n.m-2 {\n  margin: 0.5rem !important;\n}\n\n.mt-2,\n.my-2 {\n  margin-top: 0.5rem !important;\n}\n\n.mr-2,\n.mx-2 {\n  margin-right: 0.5rem !important;\n}\n\n.mb-2,\n.my-2 {\n  margin-bottom: 0.5rem !important;\n}\n\n.ml-2,\n.mx-2 {\n  margin-left: 0.5rem !important;\n}\n\n.m-3 {\n  margin: 1rem !important;\n}\n\n.mt-3,\n.my-3 {\n  margin-top: 1rem !important;\n}\n\n.mr-3,\n.mx-3 {\n  margin-right: 1rem !important;\n}\n\n.mb-3,\n.my-3 {\n  margin-bottom: 1rem !important;\n}\n\n.ml-3,\n.mx-3 {\n  margin-left: 1rem !important;\n}\n\n.m-4 {\n  margin: 1.5rem !important;\n}\n\n.mt-4,\n.my-4 {\n  margin-top: 1.5rem !important;\n}\n\n.mr-4,\n.mx-4 {\n  margin-right: 1.5rem !important;\n}\n\n.mb-4,\n.my-4 {\n  margin-bottom: 1.5rem !important;\n}\n\n.ml-4,\n.mx-4 {\n  margin-left: 1.5rem !important;\n}\n\n.m-5 {\n  margin: 3rem !important;\n}\n\n.mt-5,\n.my-5 {\n  margin-top: 3rem !important;\n}\n\n.mr-5,\n.mx-5 {\n  margin-right: 3rem !important;\n}\n\n.mb-5,\n.my-5 {\n  margin-bottom: 3rem !important;\n}\n\n.ml-5,\n.mx-5 {\n  margin-left: 3rem !important;\n}\n\n.p-0 {\n  padding: 0 !important;\n}\n\n.pt-0,\n.py-0 {\n  padding-top: 0 !important;\n}\n\n.pr-0,\n.px-0 {\n  padding-right: 0 !important;\n}\n\n.pb-0,\n.py-0 {\n  padding-bottom: 0 !important;\n}\n\n.pl-0,\n.px-0 {\n  padding-left: 0 !important;\n}\n\n.p-1 {\n  padding: 0.25rem !important;\n}\n\n.pt-1,\n.py-1 {\n  padding-top: 0.25rem !important;\n}\n\n.pr-1,\n.px-1 {\n  padding-right: 0.25rem !important;\n}\n\n.pb-1,\n.py-1 {\n  padding-bottom: 0.25rem !important;\n}\n\n.pl-1,\n.px-1 {\n  padding-left: 0.25rem !important;\n}\n\n.p-2 {\n  padding: 0.5rem !important;\n}\n\n.pt-2,\n.py-2 {\n  padding-top: 0.5rem !important;\n}\n\n.pr-2,\n.px-2 {\n  padding-right: 0.5rem !important;\n}\n\n.pb-2,\n.py-2 {\n  padding-bottom: 0.5rem !important;\n}\n\n.pl-2,\n.px-2 {\n  padding-left: 0.5rem !important;\n}\n\n.p-3 {\n  padding: 1rem !important;\n}\n\n.pt-3,\n.py-3 {\n  padding-top: 1rem !important;\n}\n\n.pr-3,\n.px-3 {\n  padding-right: 1rem !important;\n}\n\n.pb-3,\n.py-3 {\n  padding-bottom: 1rem !important;\n}\n\n.pl-3,\n.px-3 {\n  padding-left: 1rem !important;\n}\n\n.p-4 {\n  padding: 1.5rem !important;\n}\n\n.pt-4,\n.py-4 {\n  padding-top: 1.5rem !important;\n}\n\n.pr-4,\n.px-4 {\n  padding-right: 1.5rem !important;\n}\n\n.pb-4,\n.py-4 {\n  padding-bottom: 1.5rem !important;\n}\n\n.pl-4,\n.px-4 {\n  padding-left: 1.5rem !important;\n}\n\n.p-5 {\n  padding: 3rem !important;\n}\n\n.pt-5,\n.py-5 {\n  padding-top: 3rem !important;\n}\n\n.pr-5,\n.px-5 {\n  padding-right: 3rem !important;\n}\n\n.pb-5,\n.py-5 {\n  padding-bottom: 3rem !important;\n}\n\n.pl-5,\n.px-5 {\n  padding-left: 3rem !important;\n}\n\n.m-auto {\n  margin: auto !important;\n}\n\n.mt-auto,\n.my-auto {\n  margin-top: auto !important;\n}\n\n.mr-auto,\n.mx-auto {\n  margin-right: auto !important;\n}\n\n.mb-auto,\n.my-auto {\n  margin-bottom: auto !important;\n}\n\n.ml-auto,\n.mx-auto {\n  margin-left: auto !important;\n}\n\n@media (min-width: 576px) {\n  .m-sm-0 {\n    margin: 0 !important;\n  }\n  .mt-sm-0,\n  .my-sm-0 {\n    margin-top: 0 !important;\n  }\n  .mr-sm-0,\n  .mx-sm-0 {\n    margin-right: 0 !important;\n  }\n  .mb-sm-0,\n  .my-sm-0 {\n    margin-bottom: 0 !important;\n  }\n  .ml-sm-0,\n  .mx-sm-0 {\n    margin-left: 0 !important;\n  }\n  .m-sm-1 {\n    margin: 0.25rem !important;\n  }\n  .mt-sm-1,\n  .my-sm-1 {\n    margin-top: 0.25rem !important;\n  }\n  .mr-sm-1,\n  .mx-sm-1 {\n    margin-right: 0.25rem !important;\n  }\n  .mb-sm-1,\n  .my-sm-1 {\n    margin-bottom: 0.25rem !important;\n  }\n  .ml-sm-1,\n  .mx-sm-1 {\n    margin-left: 0.25rem !important;\n  }\n  .m-sm-2 {\n    margin: 0.5rem !important;\n  }\n  .mt-sm-2,\n  .my-sm-2 {\n    margin-top: 0.5rem !important;\n  }\n  .mr-sm-2,\n  .mx-sm-2 {\n    margin-right: 0.5rem !important;\n  }\n  .mb-sm-2,\n  .my-sm-2 {\n    margin-bottom: 0.5rem !important;\n  }\n  .ml-sm-2,\n  .mx-sm-2 {\n    margin-left: 0.5rem !important;\n  }\n  .m-sm-3 {\n    margin: 1rem !important;\n  }\n  .mt-sm-3,\n  .my-sm-3 {\n    margin-top: 1rem !important;\n  }\n  .mr-sm-3,\n  .mx-sm-3 {\n    margin-right: 1rem !important;\n  }\n  .mb-sm-3,\n  .my-sm-3 {\n    margin-bottom: 1rem !important;\n  }\n  .ml-sm-3,\n  .mx-sm-3 {\n    margin-left: 1rem !important;\n  }\n  .m-sm-4 {\n    margin: 1.5rem !important;\n  }\n  .mt-sm-4,\n  .my-sm-4 {\n    margin-top: 1.5rem !important;\n  }\n  .mr-sm-4,\n  .mx-sm-4 {\n    margin-right: 1.5rem !important;\n  }\n  .mb-sm-4,\n  .my-sm-4 {\n    margin-bottom: 1.5rem !important;\n  }\n  .ml-sm-4,\n  .mx-sm-4 {\n    margin-left: 1.5rem !important;\n  }\n  .m-sm-5 {\n    margin: 3rem !important;\n  }\n  .mt-sm-5,\n  .my-sm-5 {\n    margin-top: 3rem !important;\n  }\n  .mr-sm-5,\n  .mx-sm-5 {\n    margin-right: 3rem !important;\n  }\n  .mb-sm-5,\n  .my-sm-5 {\n    margin-bottom: 3rem !important;\n  }\n  .ml-sm-5,\n  .mx-sm-5 {\n    margin-left: 3rem !important;\n  }\n  .p-sm-0 {\n    padding: 0 !important;\n  }\n  .pt-sm-0,\n  .py-sm-0 {\n    padding-top: 0 !important;\n  }\n  .pr-sm-0,\n  .px-sm-0 {\n    padding-right: 0 !important;\n  }\n  .pb-sm-0,\n  .py-sm-0 {\n    padding-bottom: 0 !important;\n  }\n  .pl-sm-0,\n  .px-sm-0 {\n    padding-left: 0 !important;\n  }\n  .p-sm-1 {\n    padding: 0.25rem !important;\n  }\n  .pt-sm-1,\n  .py-sm-1 {\n    padding-top: 0.25rem !important;\n  }\n  .pr-sm-1,\n  .px-sm-1 {\n    padding-right: 0.25rem !important;\n  }\n  .pb-sm-1,\n  .py-sm-1 {\n    padding-bottom: 0.25rem !important;\n  }\n  .pl-sm-1,\n  .px-sm-1 {\n    padding-left: 0.25rem !important;\n  }\n  .p-sm-2 {\n    padding: 0.5rem !important;\n  }\n  .pt-sm-2,\n  .py-sm-2 {\n    padding-top: 0.5rem !important;\n  }\n  .pr-sm-2,\n  .px-sm-2 {\n    padding-right: 0.5rem !important;\n  }\n  .pb-sm-2,\n  .py-sm-2 {\n    padding-bottom: 0.5rem !important;\n  }\n  .pl-sm-2,\n  .px-sm-2 {\n    padding-left: 0.5rem !important;\n  }\n  .p-sm-3 {\n    padding: 1rem !important;\n  }\n  .pt-sm-3,\n  .py-sm-3 {\n    padding-top: 1rem !important;\n  }\n  .pr-sm-3,\n  .px-sm-3 {\n    padding-right: 1rem !important;\n  }\n  .pb-sm-3,\n  .py-sm-3 {\n    padding-bottom: 1rem !important;\n  }\n  .pl-sm-3,\n  .px-sm-3 {\n    padding-left: 1rem !important;\n  }\n  .p-sm-4 {\n    padding: 1.5rem !important;\n  }\n  .pt-sm-4,\n  .py-sm-4 {\n    padding-top: 1.5rem !important;\n  }\n  .pr-sm-4,\n  .px-sm-4 {\n    padding-right: 1.5rem !important;\n  }\n  .pb-sm-4,\n  .py-sm-4 {\n    padding-bottom: 1.5rem !important;\n  }\n  .pl-sm-4,\n  .px-sm-4 {\n    padding-left: 1.5rem !important;\n  }\n  .p-sm-5 {\n    padding: 3rem !important;\n  }\n  .pt-sm-5,\n  .py-sm-5 {\n    padding-top: 3rem !important;\n  }\n  .pr-sm-5,\n  .px-sm-5 {\n    padding-right: 3rem !important;\n  }\n  .pb-sm-5,\n  .py-sm-5 {\n    padding-bottom: 3rem !important;\n  }\n  .pl-sm-5,\n  .px-sm-5 {\n    padding-left: 3rem !important;\n  }\n  .m-sm-auto {\n    margin: auto !important;\n  }\n  .mt-sm-auto,\n  .my-sm-auto {\n    margin-top: auto !important;\n  }\n  .mr-sm-auto,\n  .mx-sm-auto {\n    margin-right: auto !important;\n  }\n  .mb-sm-auto,\n  .my-sm-auto {\n    margin-bottom: auto !important;\n  }\n  .ml-sm-auto,\n  .mx-sm-auto {\n    margin-left: auto !important;\n  }\n}\n\n@media (min-width: 768px) {\n  .m-md-0 {\n    margin: 0 !important;\n  }\n  .mt-md-0,\n  .my-md-0 {\n    margin-top: 0 !important;\n  }\n  .mr-md-0,\n  .mx-md-0 {\n    margin-right: 0 !important;\n  }\n  .mb-md-0,\n  .my-md-0 {\n    margin-bottom: 0 !important;\n  }\n  .ml-md-0,\n  .mx-md-0 {\n    margin-left: 0 !important;\n  }\n  .m-md-1 {\n    margin: 0.25rem !important;\n  }\n  .mt-md-1,\n  .my-md-1 {\n    margin-top: 0.25rem !important;\n  }\n  .mr-md-1,\n  .mx-md-1 {\n    margin-right: 0.25rem !important;\n  }\n  .mb-md-1,\n  .my-md-1 {\n    margin-bottom: 0.25rem !important;\n  }\n  .ml-md-1,\n  .mx-md-1 {\n    margin-left: 0.25rem !important;\n  }\n  .m-md-2 {\n    margin: 0.5rem !important;\n  }\n  .mt-md-2,\n  .my-md-2 {\n    margin-top: 0.5rem !important;\n  }\n  .mr-md-2,\n  .mx-md-2 {\n    margin-right: 0.5rem !important;\n  }\n  .mb-md-2,\n  .my-md-2 {\n    margin-bottom: 0.5rem !important;\n  }\n  .ml-md-2,\n  .mx-md-2 {\n    margin-left: 0.5rem !important;\n  }\n  .m-md-3 {\n    margin: 1rem !important;\n  }\n  .mt-md-3,\n  .my-md-3 {\n    margin-top: 1rem !important;\n  }\n  .mr-md-3,\n  .mx-md-3 {\n    margin-right: 1rem !important;\n  }\n  .mb-md-3,\n  .my-md-3 {\n    margin-bottom: 1rem !important;\n  }\n  .ml-md-3,\n  .mx-md-3 {\n    margin-left: 1rem !important;\n  }\n  .m-md-4 {\n    margin: 1.5rem !important;\n  }\n  .mt-md-4,\n  .my-md-4 {\n    margin-top: 1.5rem !important;\n  }\n  .mr-md-4,\n  .mx-md-4 {\n    margin-right: 1.5rem !important;\n  }\n  .mb-md-4,\n  .my-md-4 {\n    margin-bottom: 1.5rem !important;\n  }\n  .ml-md-4,\n  .mx-md-4 {\n    margin-left: 1.5rem !important;\n  }\n  .m-md-5 {\n    margin: 3rem !important;\n  }\n  .mt-md-5,\n  .my-md-5 {\n    margin-top: 3rem !important;\n  }\n  .mr-md-5,\n  .mx-md-5 {\n    margin-right: 3rem !important;\n  }\n  .mb-md-5,\n  .my-md-5 {\n    margin-bottom: 3rem !important;\n  }\n  .ml-md-5,\n  .mx-md-5 {\n    margin-left: 3rem !important;\n  }\n  .p-md-0 {\n    padding: 0 !important;\n  }\n  .pt-md-0,\n  .py-md-0 {\n    padding-top: 0 !important;\n  }\n  .pr-md-0,\n  .px-md-0 {\n    padding-right: 0 !important;\n  }\n  .pb-md-0,\n  .py-md-0 {\n    padding-bottom: 0 !important;\n  }\n  .pl-md-0,\n  .px-md-0 {\n    padding-left: 0 !important;\n  }\n  .p-md-1 {\n    padding: 0.25rem !important;\n  }\n  .pt-md-1,\n  .py-md-1 {\n    padding-top: 0.25rem !important;\n  }\n  .pr-md-1,\n  .px-md-1 {\n    padding-right: 0.25rem !important;\n  }\n  .pb-md-1,\n  .py-md-1 {\n    padding-bottom: 0.25rem !important;\n  }\n  .pl-md-1,\n  .px-md-1 {\n    padding-left: 0.25rem !important;\n  }\n  .p-md-2 {\n    padding: 0.5rem !important;\n  }\n  .pt-md-2,\n  .py-md-2 {\n    padding-top: 0.5rem !important;\n  }\n  .pr-md-2,\n  .px-md-2 {\n    padding-right: 0.5rem !important;\n  }\n  .pb-md-2,\n  .py-md-2 {\n    padding-bottom: 0.5rem !important;\n  }\n  .pl-md-2,\n  .px-md-2 {\n    padding-left: 0.5rem !important;\n  }\n  .p-md-3 {\n    padding: 1rem !important;\n  }\n  .pt-md-3,\n  .py-md-3 {\n    padding-top: 1rem !important;\n  }\n  .pr-md-3,\n  .px-md-3 {\n    padding-right: 1rem !important;\n  }\n  .pb-md-3,\n  .py-md-3 {\n    padding-bottom: 1rem !important;\n  }\n  .pl-md-3,\n  .px-md-3 {\n    padding-left: 1rem !important;\n  }\n  .p-md-4 {\n    padding: 1.5rem !important;\n  }\n  .pt-md-4,\n  .py-md-4 {\n    padding-top: 1.5rem !important;\n  }\n  .pr-md-4,\n  .px-md-4 {\n    padding-right: 1.5rem !important;\n  }\n  .pb-md-4,\n  .py-md-4 {\n    padding-bottom: 1.5rem !important;\n  }\n  .pl-md-4,\n  .px-md-4 {\n    padding-left: 1.5rem !important;\n  }\n  .p-md-5 {\n    padding: 3rem !important;\n  }\n  .pt-md-5,\n  .py-md-5 {\n    padding-top: 3rem !important;\n  }\n  .pr-md-5,\n  .px-md-5 {\n    padding-right: 3rem !important;\n  }\n  .pb-md-5,\n  .py-md-5 {\n    padding-bottom: 3rem !important;\n  }\n  .pl-md-5,\n  .px-md-5 {\n    padding-left: 3rem !important;\n  }\n  .m-md-auto {\n    margin: auto !important;\n  }\n  .mt-md-auto,\n  .my-md-auto {\n    margin-top: auto !important;\n  }\n  .mr-md-auto,\n  .mx-md-auto {\n    margin-right: auto !important;\n  }\n  .mb-md-auto,\n  .my-md-auto {\n    margin-bottom: auto !important;\n  }\n  .ml-md-auto,\n  .mx-md-auto {\n    margin-left: auto !important;\n  }\n}\n\n@media (min-width: 992px) {\n  .m-lg-0 {\n    margin: 0 !important;\n  }\n  .mt-lg-0,\n  .my-lg-0 {\n    margin-top: 0 !important;\n  }\n  .mr-lg-0,\n  .mx-lg-0 {\n    margin-right: 0 !important;\n  }\n  .mb-lg-0,\n  .my-lg-0 {\n    margin-bottom: 0 !important;\n  }\n  .ml-lg-0,\n  .mx-lg-0 {\n    margin-left: 0 !important;\n  }\n  .m-lg-1 {\n    margin: 0.25rem !important;\n  }\n  .mt-lg-1,\n  .my-lg-1 {\n    margin-top: 0.25rem !important;\n  }\n  .mr-lg-1,\n  .mx-lg-1 {\n    margin-right: 0.25rem !important;\n  }\n  .mb-lg-1,\n  .my-lg-1 {\n    margin-bottom: 0.25rem !important;\n  }\n  .ml-lg-1,\n  .mx-lg-1 {\n    margin-left: 0.25rem !important;\n  }\n  .m-lg-2 {\n    margin: 0.5rem !important;\n  }\n  .mt-lg-2,\n  .my-lg-2 {\n    margin-top: 0.5rem !important;\n  }\n  .mr-lg-2,\n  .mx-lg-2 {\n    margin-right: 0.5rem !important;\n  }\n  .mb-lg-2,\n  .my-lg-2 {\n    margin-bottom: 0.5rem !important;\n  }\n  .ml-lg-2,\n  .mx-lg-2 {\n    margin-left: 0.5rem !important;\n  }\n  .m-lg-3 {\n    margin: 1rem !important;\n  }\n  .mt-lg-3,\n  .my-lg-3 {\n    margin-top: 1rem !important;\n  }\n  .mr-lg-3,\n  .mx-lg-3 {\n    margin-right: 1rem !important;\n  }\n  .mb-lg-3,\n  .my-lg-3 {\n    margin-bottom: 1rem !important;\n  }\n  .ml-lg-3,\n  .mx-lg-3 {\n    margin-left: 1rem !important;\n  }\n  .m-lg-4 {\n    margin: 1.5rem !important;\n  }\n  .mt-lg-4,\n  .my-lg-4 {\n    margin-top: 1.5rem !important;\n  }\n  .mr-lg-4,\n  .mx-lg-4 {\n    margin-right: 1.5rem !important;\n  }\n  .mb-lg-4,\n  .my-lg-4 {\n    margin-bottom: 1.5rem !important;\n  }\n  .ml-lg-4,\n  .mx-lg-4 {\n    margin-left: 1.5rem !important;\n  }\n  .m-lg-5 {\n    margin: 3rem !important;\n  }\n  .mt-lg-5,\n  .my-lg-5 {\n    margin-top: 3rem !important;\n  }\n  .mr-lg-5,\n  .mx-lg-5 {\n    margin-right: 3rem !important;\n  }\n  .mb-lg-5,\n  .my-lg-5 {\n    margin-bottom: 3rem !important;\n  }\n  .ml-lg-5,\n  .mx-lg-5 {\n    margin-left: 3rem !important;\n  }\n  .p-lg-0 {\n    padding: 0 !important;\n  }\n  .pt-lg-0,\n  .py-lg-0 {\n    padding-top: 0 !important;\n  }\n  .pr-lg-0,\n  .px-lg-0 {\n    padding-right: 0 !important;\n  }\n  .pb-lg-0,\n  .py-lg-0 {\n    padding-bottom: 0 !important;\n  }\n  .pl-lg-0,\n  .px-lg-0 {\n    padding-left: 0 !important;\n  }\n  .p-lg-1 {\n    padding: 0.25rem !important;\n  }\n  .pt-lg-1,\n  .py-lg-1 {\n    padding-top: 0.25rem !important;\n  }\n  .pr-lg-1,\n  .px-lg-1 {\n    padding-right: 0.25rem !important;\n  }\n  .pb-lg-1,\n  .py-lg-1 {\n    padding-bottom: 0.25rem !important;\n  }\n  .pl-lg-1,\n  .px-lg-1 {\n    padding-left: 0.25rem !important;\n  }\n  .p-lg-2 {\n    padding: 0.5rem !important;\n  }\n  .pt-lg-2,\n  .py-lg-2 {\n    padding-top: 0.5rem !important;\n  }\n  .pr-lg-2,\n  .px-lg-2 {\n    padding-right: 0.5rem !important;\n  }\n  .pb-lg-2,\n  .py-lg-2 {\n    padding-bottom: 0.5rem !important;\n  }\n  .pl-lg-2,\n  .px-lg-2 {\n    padding-left: 0.5rem !important;\n  }\n  .p-lg-3 {\n    padding: 1rem !important;\n  }\n  .pt-lg-3,\n  .py-lg-3 {\n    padding-top: 1rem !important;\n  }\n  .pr-lg-3,\n  .px-lg-3 {\n    padding-right: 1rem !important;\n  }\n  .pb-lg-3,\n  .py-lg-3 {\n    padding-bottom: 1rem !important;\n  }\n  .pl-lg-3,\n  .px-lg-3 {\n    padding-left: 1rem !important;\n  }\n  .p-lg-4 {\n    padding: 1.5rem !important;\n  }\n  .pt-lg-4,\n  .py-lg-4 {\n    padding-top: 1.5rem !important;\n  }\n  .pr-lg-4,\n  .px-lg-4 {\n    padding-right: 1.5rem !important;\n  }\n  .pb-lg-4,\n  .py-lg-4 {\n    padding-bottom: 1.5rem !important;\n  }\n  .pl-lg-4,\n  .px-lg-4 {\n    padding-left: 1.5rem !important;\n  }\n  .p-lg-5 {\n    padding: 3rem !important;\n  }\n  .pt-lg-5,\n  .py-lg-5 {\n    padding-top: 3rem !important;\n  }\n  .pr-lg-5,\n  .px-lg-5 {\n    padding-right: 3rem !important;\n  }\n  .pb-lg-5,\n  .py-lg-5 {\n    padding-bottom: 3rem !important;\n  }\n  .pl-lg-5,\n  .px-lg-5 {\n    padding-left: 3rem !important;\n  }\n  .m-lg-auto {\n    margin: auto !important;\n  }\n  .mt-lg-auto,\n  .my-lg-auto {\n    margin-top: auto !important;\n  }\n  .mr-lg-auto,\n  .mx-lg-auto {\n    margin-right: auto !important;\n  }\n  .mb-lg-auto,\n  .my-lg-auto {\n    margin-bottom: auto !important;\n  }\n  .ml-lg-auto,\n  .mx-lg-auto {\n    margin-left: auto !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  .m-xl-0 {\n    margin: 0 !important;\n  }\n  .mt-xl-0,\n  .my-xl-0 {\n    margin-top: 0 !important;\n  }\n  .mr-xl-0,\n  .mx-xl-0 {\n    margin-right: 0 !important;\n  }\n  .mb-xl-0,\n  .my-xl-0 {\n    margin-bottom: 0 !important;\n  }\n  .ml-xl-0,\n  .mx-xl-0 {\n    margin-left: 0 !important;\n  }\n  .m-xl-1 {\n    margin: 0.25rem !important;\n  }\n  .mt-xl-1,\n  .my-xl-1 {\n    margin-top: 0.25rem !important;\n  }\n  .mr-xl-1,\n  .mx-xl-1 {\n    margin-right: 0.25rem !important;\n  }\n  .mb-xl-1,\n  .my-xl-1 {\n    margin-bottom: 0.25rem !important;\n  }\n  .ml-xl-1,\n  .mx-xl-1 {\n    margin-left: 0.25rem !important;\n  }\n  .m-xl-2 {\n    margin: 0.5rem !important;\n  }\n  .mt-xl-2,\n  .my-xl-2 {\n    margin-top: 0.5rem !important;\n  }\n  .mr-xl-2,\n  .mx-xl-2 {\n    margin-right: 0.5rem !important;\n  }\n  .mb-xl-2,\n  .my-xl-2 {\n    margin-bottom: 0.5rem !important;\n  }\n  .ml-xl-2,\n  .mx-xl-2 {\n    margin-left: 0.5rem !important;\n  }\n  .m-xl-3 {\n    margin: 1rem !important;\n  }\n  .mt-xl-3,\n  .my-xl-3 {\n    margin-top: 1rem !important;\n  }\n  .mr-xl-3,\n  .mx-xl-3 {\n    margin-right: 1rem !important;\n  }\n  .mb-xl-3,\n  .my-xl-3 {\n    margin-bottom: 1rem !important;\n  }\n  .ml-xl-3,\n  .mx-xl-3 {\n    margin-left: 1rem !important;\n  }\n  .m-xl-4 {\n    margin: 1.5rem !important;\n  }\n  .mt-xl-4,\n  .my-xl-4 {\n    margin-top: 1.5rem !important;\n  }\n  .mr-xl-4,\n  .mx-xl-4 {\n    margin-right: 1.5rem !important;\n  }\n  .mb-xl-4,\n  .my-xl-4 {\n    margin-bottom: 1.5rem !important;\n  }\n  .ml-xl-4,\n  .mx-xl-4 {\n    margin-left: 1.5rem !important;\n  }\n  .m-xl-5 {\n    margin: 3rem !important;\n  }\n  .mt-xl-5,\n  .my-xl-5 {\n    margin-top: 3rem !important;\n  }\n  .mr-xl-5,\n  .mx-xl-5 {\n    margin-right: 3rem !important;\n  }\n  .mb-xl-5,\n  .my-xl-5 {\n    margin-bottom: 3rem !important;\n  }\n  .ml-xl-5,\n  .mx-xl-5 {\n    margin-left: 3rem !important;\n  }\n  .p-xl-0 {\n    padding: 0 !important;\n  }\n  .pt-xl-0,\n  .py-xl-0 {\n    padding-top: 0 !important;\n  }\n  .pr-xl-0,\n  .px-xl-0 {\n    padding-right: 0 !important;\n  }\n  .pb-xl-0,\n  .py-xl-0 {\n    padding-bottom: 0 !important;\n  }\n  .pl-xl-0,\n  .px-xl-0 {\n    padding-left: 0 !important;\n  }\n  .p-xl-1 {\n    padding: 0.25rem !important;\n  }\n  .pt-xl-1,\n  .py-xl-1 {\n    padding-top: 0.25rem !important;\n  }\n  .pr-xl-1,\n  .px-xl-1 {\n    padding-right: 0.25rem !important;\n  }\n  .pb-xl-1,\n  .py-xl-1 {\n    padding-bottom: 0.25rem !important;\n  }\n  .pl-xl-1,\n  .px-xl-1 {\n    padding-left: 0.25rem !important;\n  }\n  .p-xl-2 {\n    padding: 0.5rem !important;\n  }\n  .pt-xl-2,\n  .py-xl-2 {\n    padding-top: 0.5rem !important;\n  }\n  .pr-xl-2,\n  .px-xl-2 {\n    padding-right: 0.5rem !important;\n  }\n  .pb-xl-2,\n  .py-xl-2 {\n    padding-bottom: 0.5rem !important;\n  }\n  .pl-xl-2,\n  .px-xl-2 {\n    padding-left: 0.5rem !important;\n  }\n  .p-xl-3 {\n    padding: 1rem !important;\n  }\n  .pt-xl-3,\n  .py-xl-3 {\n    padding-top: 1rem !important;\n  }\n  .pr-xl-3,\n  .px-xl-3 {\n    padding-right: 1rem !important;\n  }\n  .pb-xl-3,\n  .py-xl-3 {\n    padding-bottom: 1rem !important;\n  }\n  .pl-xl-3,\n  .px-xl-3 {\n    padding-left: 1rem !important;\n  }\n  .p-xl-4 {\n    padding: 1.5rem !important;\n  }\n  .pt-xl-4,\n  .py-xl-4 {\n    padding-top: 1.5rem !important;\n  }\n  .pr-xl-4,\n  .px-xl-4 {\n    padding-right: 1.5rem !important;\n  }\n  .pb-xl-4,\n  .py-xl-4 {\n    padding-bottom: 1.5rem !important;\n  }\n  .pl-xl-4,\n  .px-xl-4 {\n    padding-left: 1.5rem !important;\n  }\n  .p-xl-5 {\n    padding: 3rem !important;\n  }\n  .pt-xl-5,\n  .py-xl-5 {\n    padding-top: 3rem !important;\n  }\n  .pr-xl-5,\n  .px-xl-5 {\n    padding-right: 3rem !important;\n  }\n  .pb-xl-5,\n  .py-xl-5 {\n    padding-bottom: 3rem !important;\n  }\n  .pl-xl-5,\n  .px-xl-5 {\n    padding-left: 3rem !important;\n  }\n  .m-xl-auto {\n    margin: auto !important;\n  }\n  .mt-xl-auto,\n  .my-xl-auto {\n    margin-top: auto !important;\n  }\n  .mr-xl-auto,\n  .mx-xl-auto {\n    margin-right: auto !important;\n  }\n  .mb-xl-auto,\n  .my-xl-auto {\n    margin-bottom: auto !important;\n  }\n  .ml-xl-auto,\n  .mx-xl-auto {\n    margin-left: auto !important;\n  }\n}\n\n.text-monospace {\n  font-family: SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n}\n\n.text-justify {\n  text-align: justify !important;\n}\n\n.text-nowrap {\n  white-space: nowrap !important;\n}\n\n.text-truncate {\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n}\n\n.text-left {\n  text-align: left !important;\n}\n\n.text-right {\n  text-align: right !important;\n}\n\n.text-center {\n  text-align: center !important;\n}\n\n@media (min-width: 576px) {\n  .text-sm-left {\n    text-align: left !important;\n  }\n  .text-sm-right {\n    text-align: right !important;\n  }\n  .text-sm-center {\n    text-align: center !important;\n  }\n}\n\n@media (min-width: 768px) {\n  .text-md-left {\n    text-align: left !important;\n  }\n  .text-md-right {\n    text-align: right !important;\n  }\n  .text-md-center {\n    text-align: center !important;\n  }\n}\n\n@media (min-width: 992px) {\n  .text-lg-left {\n    text-align: left !important;\n  }\n  .text-lg-right {\n    text-align: right !important;\n  }\n  .text-lg-center {\n    text-align: center !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  .text-xl-left {\n    text-align: left !important;\n  }\n  .text-xl-right {\n    text-align: right !important;\n  }\n  .text-xl-center {\n    text-align: center !important;\n  }\n}\n\n.text-lowercase {\n  text-transform: lowercase !important;\n}\n\n.text-uppercase {\n  text-transform: uppercase !important;\n}\n\n.text-capitalize {\n  text-transform: capitalize !important;\n}\n\n.font-weight-light {\n  font-weight: 300 !important;\n}\n\n.font-weight-normal {\n  font-weight: 400 !important;\n}\n\n.font-weight-bold {\n  font-weight: 700 !important;\n}\n\n.font-italic {\n  font-style: italic !important;\n}\n\n.text-white {\n  color: #fff !important;\n}\n\n.text-primary {\n  color: #8b5cf6 !important;\n}\n\na.text-primary:hover, a.text-primary:focus {\n  color: #692cf3 !important;\n}\n\n.text-secondary {\n  color: #1F2937 !important;\n}\n\na.text-secondary:hover, a.text-secondary:focus {\n  color: #0d1116 !important;\n}\n\n.text-success {\n  color: #10b981 !important;\n}\n\na.text-success:hover, a.text-success:focus {\n  color: #0c8a60 !important;\n}\n\n.text-info {\n  color: #3b82f6 !important;\n}\n\na.text-info:hover, a.text-info:focus {\n  color: #0b63f3 !important;\n}\n\n.text-warning {\n  color: #f59e0b !important;\n}\n\na.text-warning:hover, a.text-warning:focus {\n  color: #c57f08 !important;\n}\n\n.text-danger {\n  color: #ef4444 !important;\n}\n\na.text-danger:hover, a.text-danger:focus {\n  color: #eb1515 !important;\n}\n\n.text-light {\n  color: #6B7280 !important;\n}\n\na.text-light:hover, a.text-light:focus {\n  color: #545964 !important;\n}\n\n.text-dark {\n  color: #111827 !important;\n}\n\na.text-dark:hover, a.text-dark:focus {\n  color: #020203 !important;\n}\n\n.text-gray-100 {\n  color: #F3F4F6 !important;\n}\n\na.text-gray-100:hover, a.text-gray-100:focus {\n  color: #d6d9e0 !important;\n}\n\n.text-gray-200 {\n  color: #E5E7EB !important;\n}\n\na.text-gray-200:hover, a.text-gray-200:focus {\n  color: #c8ccd5 !important;\n}\n\n.text-gray-300 {\n  color: #D1D5DB !important;\n}\n\na.text-gray-300:hover, a.text-gray-300:focus {\n  color: #b4bbc5 !important;\n}\n\n.text-gray-400 {\n  color: #9CA3AF !important;\n}\n\na.text-gray-400:hover, a.text-gray-400:focus {\n  color: #808998 !important;\n}\n\n.text-gray-500 {\n  color: #6B7280 !important;\n}\n\na.text-gray-500:hover, a.text-gray-500:focus {\n  color: #545964 !important;\n}\n\n.text-gray-600 {\n  color: #4B5563 !important;\n}\n\na.text-gray-600:hover, a.text-gray-600:focus {\n  color: #353c46 !important;\n}\n\n.text-gray-700 {\n  color: #374151 !important;\n}\n\na.text-gray-700:hover, a.text-gray-700:focus {\n  color: #222933 !important;\n}\n\n.text-gray-800 {\n  color: #1F2937 !important;\n}\n\na.text-gray-800:hover, a.text-gray-800:focus {\n  color: #0d1116 !important;\n}\n\n.text-gray-900 {\n  color: #111827 !important;\n}\n\na.text-gray-900:hover, a.text-gray-900:focus {\n  color: #020203 !important;\n}\n\n.text-body {\n  color: #111827 !important;\n}\n\n.text-muted {\n  color: #4B5563 !important;\n}\n\n.text-black-50 {\n  color: rgba(10, 2, 30, 0.5) !important;\n}\n\n.text-white-50 {\n  color: rgba(255, 255, 255, 0.5) !important;\n}\n\n.text-hide {\n  font: 0/0 a;\n  color: transparent;\n  text-shadow: none;\n  background-color: transparent;\n  border: 0;\n}\n\n.visible {\n  visibility: visible !important;\n}\n\n.invisible {\n  visibility: hidden !important;\n}\n\n@media print {\n  *,\n  *::before,\n  *::after {\n    text-shadow: none !important;\n    box-shadow: none !important;\n  }\n  a:not(.btn) {\n    text-decoration: underline;\n  }\n  abbr[title]::after {\n    content: \" (\" attr(title) \")\";\n  }\n  pre {\n    white-space: pre-wrap !important;\n  }\n  pre,\n  blockquote {\n    border: 1px solid #6B7280;\n    page-break-inside: avoid;\n  }\n  thead {\n    display: table-header-group;\n  }\n  tr,\n  img {\n    page-break-inside: avoid;\n  }\n  p,\n  h2,\n  h3 {\n    orphans: 3;\n    widows: 3;\n  }\n  h2,\n  h3 {\n    page-break-after: avoid;\n  }\n  @page {\n    size: a3;\n  }\n  body {\n    min-width: 992px !important;\n  }\n  .container {\n    min-width: 992px !important;\n  }\n  .navbar {\n    display: none;\n  }\n  .badge {\n    border: 1px solid #0a021e;\n  }\n  .table {\n    border-collapse: collapse !important;\n  }\n  .table td,\n  .table th {\n    background-color: #fff !important;\n  }\n  .table-bordered th,\n  .table-bordered td {\n    border: 1px solid #D1D5DB !important;\n  }\n  .table-dark {\n    color: inherit;\n  }\n  .table-dark th,\n  .table-dark td,\n  .table-dark thead th,\n  .table-dark tbody + tbody {\n    border-color: #D1D5DB;\n  }\n  .table .thead-dark th {\n    color: inherit;\n    border-color: #D1D5DB;\n  }\n}\n\n[dir=\"rtl\"] .text-left {\n  text-align: right !important;\n}\n\n[dir=\"rtl\"] .text-right {\n  text-align: left !important;\n}\n\n@media (min-width: 576px) {\n  [dir=\"rtl\"] .text-sm-left {\n    text-align: right !important;\n  }\n  [dir=\"rtl\"] .text-sm-right {\n    text-align: left !important;\n  }\n}\n\n@media (min-width: 768px) {\n  [dir=\"rtl\"] .text-md-left {\n    text-align: right !important;\n  }\n  [dir=\"rtl\"] .text-md-right {\n    text-align: left !important;\n  }\n}\n\n@media (min-width: 992px) {\n  [dir=\"rtl\"] .text-lg-left {\n    text-align: right !important;\n  }\n  [dir=\"rtl\"] .text-lg-right {\n    text-align: left !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  [dir=\"rtl\"] .text-xl-left {\n    text-align: right !important;\n  }\n  [dir=\"rtl\"] .text-xl-right {\n    text-align: left !important;\n  }\n}\n\n[dir=\"rtl\"] .float-left {\n  float: right !important;\n}\n\n[dir=\"rtl\"] .float-right {\n  float: left !important;\n}\n\n@media (min-width: 576px) {\n  [dir=\"rtl\"] .float-sm-left {\n    float: right !important;\n  }\n  [dir=\"rtl\"] .float-sm-right {\n    float: left !important;\n  }\n}\n\n@media (min-width: 768px) {\n  [dir=\"rtl\"] .float-md-left {\n    float: right !important;\n  }\n  [dir=\"rtl\"] .float-md-right {\n    float: left !important;\n  }\n}\n\n@media (min-width: 992px) {\n  [dir=\"rtl\"] .float-lg-left {\n    float: right !important;\n  }\n  [dir=\"rtl\"] .float-lg-right {\n    float: left !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  [dir=\"rtl\"] .float-xl-left {\n    float: right !important;\n  }\n  [dir=\"rtl\"] .float-xl-right {\n    float: left !important;\n  }\n}\n\n[dir=\"rtl\"] .mr-0,\n[dir=\"rtl\"] .mx-0 {\n  margin-left: 0 !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .ml-0,\n[dir=\"rtl\"] .mx-0 {\n  margin-right: 0 !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .mr-1,\n[dir=\"rtl\"] .mx-1 {\n  margin-left: 0.25rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .ml-1,\n[dir=\"rtl\"] .mx-1 {\n  margin-right: 0.25rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .mr-2,\n[dir=\"rtl\"] .mx-2 {\n  margin-left: 0.5rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .ml-2,\n[dir=\"rtl\"] .mx-2 {\n  margin-right: 0.5rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .mr-3,\n[dir=\"rtl\"] .mx-3 {\n  margin-left: 1rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .ml-3,\n[dir=\"rtl\"] .mx-3 {\n  margin-right: 1rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .mr-4,\n[dir=\"rtl\"] .mx-4 {\n  margin-left: 1.5rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .ml-4,\n[dir=\"rtl\"] .mx-4 {\n  margin-right: 1.5rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .mr-5,\n[dir=\"rtl\"] .mx-5 {\n  margin-left: 3rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .ml-5,\n[dir=\"rtl\"] .mx-5 {\n  margin-right: 3rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .pr-0,\n[dir=\"rtl\"] .px-0 {\n  padding-left: 0 !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .pl-0,\n[dir=\"rtl\"] .px-0 {\n  padding-right: 0 !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .pr-1,\n[dir=\"rtl\"] .px-1 {\n  padding-left: 0.25rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .pl-1,\n[dir=\"rtl\"] .px-1 {\n  padding-right: 0.25rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .pr-2,\n[dir=\"rtl\"] .px-2 {\n  padding-left: 0.5rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .pl-2,\n[dir=\"rtl\"] .px-2 {\n  padding-right: 0.5rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .pr-3,\n[dir=\"rtl\"] .px-3 {\n  padding-left: 1rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .pl-3,\n[dir=\"rtl\"] .px-3 {\n  padding-right: 1rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .pr-4,\n[dir=\"rtl\"] .px-4 {\n  padding-left: 1.5rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .pl-4,\n[dir=\"rtl\"] .px-4 {\n  padding-right: 1.5rem !important;\n  margin-left: unset !important;\n}\n\n[dir=\"rtl\"] .pr-5,\n[dir=\"rtl\"] .px-5 {\n  padding-left: 3rem !important;\n  margin-right: unset !important;\n}\n\n[dir=\"rtl\"] .pl-5,\n[dir=\"rtl\"] .px-5 {\n  padding-right: 3rem !important;\n  margin-left: unset !important;\n}\n\n@media (min-width: 576px) {\n  [dir=\"rtl\"] .mr-sm-0,\n  [dir=\"rtl\"] .mx-sm-0 {\n    margin-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-sm-0,\n  [dir=\"rtl\"] .mx-sm-0 {\n    margin-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-sm-1,\n  [dir=\"rtl\"] .mx-sm-1 {\n    margin-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-sm-1,\n  [dir=\"rtl\"] .mx-sm-1 {\n    margin-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-sm-2,\n  [dir=\"rtl\"] .mx-sm-2 {\n    margin-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-sm-2,\n  [dir=\"rtl\"] .mx-sm-2 {\n    margin-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-sm-3,\n  [dir=\"rtl\"] .mx-sm-3 {\n    margin-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-sm-3,\n  [dir=\"rtl\"] .mx-sm-3 {\n    margin-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-sm-4,\n  [dir=\"rtl\"] .mx-sm-4 {\n    margin-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-sm-4,\n  [dir=\"rtl\"] .mx-sm-4 {\n    margin-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-sm-5,\n  [dir=\"rtl\"] .mx-sm-5 {\n    margin-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-sm-5,\n  [dir=\"rtl\"] .mx-sm-5 {\n    margin-right: 3rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-sm-0,\n  [dir=\"rtl\"] .px-sm-0 {\n    padding-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-sm-0,\n  [dir=\"rtl\"] .px-sm-0 {\n    padding-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-sm-1,\n  [dir=\"rtl\"] .px-sm-1 {\n    padding-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-sm-1,\n  [dir=\"rtl\"] .px-sm-1 {\n    padding-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-sm-2,\n  [dir=\"rtl\"] .px-sm-2 {\n    padding-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-sm-2,\n  [dir=\"rtl\"] .px-sm-2 {\n    padding-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-sm-3,\n  [dir=\"rtl\"] .px-sm-3 {\n    padding-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-sm-3,\n  [dir=\"rtl\"] .px-sm-3 {\n    padding-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-sm-4,\n  [dir=\"rtl\"] .px-sm-4 {\n    padding-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-sm-4,\n  [dir=\"rtl\"] .px-sm-4 {\n    padding-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-sm-5,\n  [dir=\"rtl\"] .px-sm-5 {\n    padding-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-sm-5,\n  [dir=\"rtl\"] .px-sm-5 {\n    padding-right: 3rem !important;\n    margin-left: unset !important;\n  }\n}\n\n@media (min-width: 768px) {\n  [dir=\"rtl\"] .mr-md-0,\n  [dir=\"rtl\"] .mx-md-0 {\n    margin-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-md-0,\n  [dir=\"rtl\"] .mx-md-0 {\n    margin-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-md-1,\n  [dir=\"rtl\"] .mx-md-1 {\n    margin-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-md-1,\n  [dir=\"rtl\"] .mx-md-1 {\n    margin-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-md-2,\n  [dir=\"rtl\"] .mx-md-2 {\n    margin-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-md-2,\n  [dir=\"rtl\"] .mx-md-2 {\n    margin-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-md-3,\n  [dir=\"rtl\"] .mx-md-3 {\n    margin-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-md-3,\n  [dir=\"rtl\"] .mx-md-3 {\n    margin-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-md-4,\n  [dir=\"rtl\"] .mx-md-4 {\n    margin-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-md-4,\n  [dir=\"rtl\"] .mx-md-4 {\n    margin-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-md-5,\n  [dir=\"rtl\"] .mx-md-5 {\n    margin-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-md-5,\n  [dir=\"rtl\"] .mx-md-5 {\n    margin-right: 3rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-md-0,\n  [dir=\"rtl\"] .px-md-0 {\n    padding-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-md-0,\n  [dir=\"rtl\"] .px-md-0 {\n    padding-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-md-1,\n  [dir=\"rtl\"] .px-md-1 {\n    padding-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-md-1,\n  [dir=\"rtl\"] .px-md-1 {\n    padding-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-md-2,\n  [dir=\"rtl\"] .px-md-2 {\n    padding-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-md-2,\n  [dir=\"rtl\"] .px-md-2 {\n    padding-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-md-3,\n  [dir=\"rtl\"] .px-md-3 {\n    padding-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-md-3,\n  [dir=\"rtl\"] .px-md-3 {\n    padding-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-md-4,\n  [dir=\"rtl\"] .px-md-4 {\n    padding-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-md-4,\n  [dir=\"rtl\"] .px-md-4 {\n    padding-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-md-5,\n  [dir=\"rtl\"] .px-md-5 {\n    padding-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-md-5,\n  [dir=\"rtl\"] .px-md-5 {\n    padding-right: 3rem !important;\n    margin-left: unset !important;\n  }\n}\n\n@media (min-width: 992px) {\n  [dir=\"rtl\"] .mr-lg-0,\n  [dir=\"rtl\"] .mx-lg-0 {\n    margin-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-lg-0,\n  [dir=\"rtl\"] .mx-lg-0 {\n    margin-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-lg-1,\n  [dir=\"rtl\"] .mx-lg-1 {\n    margin-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-lg-1,\n  [dir=\"rtl\"] .mx-lg-1 {\n    margin-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-lg-2,\n  [dir=\"rtl\"] .mx-lg-2 {\n    margin-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-lg-2,\n  [dir=\"rtl\"] .mx-lg-2 {\n    margin-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-lg-3,\n  [dir=\"rtl\"] .mx-lg-3 {\n    margin-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-lg-3,\n  [dir=\"rtl\"] .mx-lg-3 {\n    margin-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-lg-4,\n  [dir=\"rtl\"] .mx-lg-4 {\n    margin-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-lg-4,\n  [dir=\"rtl\"] .mx-lg-4 {\n    margin-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-lg-5,\n  [dir=\"rtl\"] .mx-lg-5 {\n    margin-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-lg-5,\n  [dir=\"rtl\"] .mx-lg-5 {\n    margin-right: 3rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-lg-0,\n  [dir=\"rtl\"] .px-lg-0 {\n    padding-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-lg-0,\n  [dir=\"rtl\"] .px-lg-0 {\n    padding-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-lg-1,\n  [dir=\"rtl\"] .px-lg-1 {\n    padding-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-lg-1,\n  [dir=\"rtl\"] .px-lg-1 {\n    padding-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-lg-2,\n  [dir=\"rtl\"] .px-lg-2 {\n    padding-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-lg-2,\n  [dir=\"rtl\"] .px-lg-2 {\n    padding-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-lg-3,\n  [dir=\"rtl\"] .px-lg-3 {\n    padding-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-lg-3,\n  [dir=\"rtl\"] .px-lg-3 {\n    padding-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-lg-4,\n  [dir=\"rtl\"] .px-lg-4 {\n    padding-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-lg-4,\n  [dir=\"rtl\"] .px-lg-4 {\n    padding-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-lg-5,\n  [dir=\"rtl\"] .px-lg-5 {\n    padding-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-lg-5,\n  [dir=\"rtl\"] .px-lg-5 {\n    padding-right: 3rem !important;\n    margin-left: unset !important;\n  }\n}\n\n@media (min-width: 1200px) {\n  [dir=\"rtl\"] .mr-xl-0,\n  [dir=\"rtl\"] .mx-xl-0 {\n    margin-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-xl-0,\n  [dir=\"rtl\"] .mx-xl-0 {\n    margin-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-xl-1,\n  [dir=\"rtl\"] .mx-xl-1 {\n    margin-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-xl-1,\n  [dir=\"rtl\"] .mx-xl-1 {\n    margin-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-xl-2,\n  [dir=\"rtl\"] .mx-xl-2 {\n    margin-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-xl-2,\n  [dir=\"rtl\"] .mx-xl-2 {\n    margin-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-xl-3,\n  [dir=\"rtl\"] .mx-xl-3 {\n    margin-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-xl-3,\n  [dir=\"rtl\"] .mx-xl-3 {\n    margin-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-xl-4,\n  [dir=\"rtl\"] .mx-xl-4 {\n    margin-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-xl-4,\n  [dir=\"rtl\"] .mx-xl-4 {\n    margin-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .mr-xl-5,\n  [dir=\"rtl\"] .mx-xl-5 {\n    margin-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .ml-xl-5,\n  [dir=\"rtl\"] .mx-xl-5 {\n    margin-right: 3rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-xl-0,\n  [dir=\"rtl\"] .px-xl-0 {\n    padding-left: 0 !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-xl-0,\n  [dir=\"rtl\"] .px-xl-0 {\n    padding-right: 0 !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-xl-1,\n  [dir=\"rtl\"] .px-xl-1 {\n    padding-left: 0.25rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-xl-1,\n  [dir=\"rtl\"] .px-xl-1 {\n    padding-right: 0.25rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-xl-2,\n  [dir=\"rtl\"] .px-xl-2 {\n    padding-left: 0.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-xl-2,\n  [dir=\"rtl\"] .px-xl-2 {\n    padding-right: 0.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-xl-3,\n  [dir=\"rtl\"] .px-xl-3 {\n    padding-left: 1rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-xl-3,\n  [dir=\"rtl\"] .px-xl-3 {\n    padding-right: 1rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-xl-4,\n  [dir=\"rtl\"] .px-xl-4 {\n    padding-left: 1.5rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-xl-4,\n  [dir=\"rtl\"] .px-xl-4 {\n    padding-right: 1.5rem !important;\n    margin-left: unset !important;\n  }\n  [dir=\"rtl\"] .pr-xl-5,\n  [dir=\"rtl\"] .px-xl-5 {\n    padding-left: 3rem !important;\n    margin-right: unset !important;\n  }\n  [dir=\"rtl\"] .pl-xl-5,\n  [dir=\"rtl\"] .px-xl-5 {\n    padding-right: 3rem !important;\n    margin-left: unset !important;\n  }\n}\n\n[dir=\"rtl\"] .input-group > .input-group-prepend > .btn,\n[dir=\"rtl\"] .input-group > .input-group-prepend > .input-group-text,\n[dir=\"rtl\"] .input-group > .input-group-append:not(:last-child) > .btn,\n[dir=\"rtl\"] .input-group > .input-group-append:not(:last-child) > .input-group-text,\n[dir=\"rtl\"] .input-group > .input-group-append:last-child > .btn:not(:last-child):not(.dropdown-toggle),\n[dir=\"rtl\"] .input-group > .input-group-append:last-child > .input-group-text:not(:last-child) {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n  border-top-right-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n\n[dir=\"rtl\"] .input-group > .input-group-append > .btn,\n[dir=\"rtl\"] .input-group > .input-group-append > .input-group-text,\n[dir=\"rtl\"] .input-group > .input-group-prepend:not(:first-child) > .btn,\n[dir=\"rtl\"] .input-group > .input-group-prepend:not(:first-child) > .input-group-text,\n[dir=\"rtl\"] .input-group > .input-group-prepend:first-child > .btn:not(:first-child),\n[dir=\"rtl\"] .input-group > .input-group-prepend:first-child > .input-group-text:not(:first-child) {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n  border-top-left-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n}\n\n[dir=\"rtl\"] .input-group > .form-control:not(:last-child),\n[dir=\"rtl\"] .input-group > .custom-select:not(:last-child) {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n  border-top-right-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n\n[dir=\"rtl\"] .input-group > .form-control:not(:first-child),\n[dir=\"rtl\"] .input-group > .custom-select:not(:first-child) {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n  border-top-left-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n}\n\n[dir=\"rtl\"] .btn-group > .btn:not(:last-child):not(.dropdown-toggle),\n[dir=\"rtl\"] .btn-group > .btn-group:not(:last-child) > .btn,\n[dir=\"rtl\"] .btn-group > .btn:not(:first-child),\n[dir=\"rtl\"] .btn-group > .btn-group:not(:first-child) > .btn {\n  border-radius: 0;\n}\n\n.sidebar-gradient-purple-indigo .sidebar-left {\n  /* fallback/image non-cover color */\n  background-color: #8b5cf6;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #8b5cf6 0%, #33214b 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #8b5cf6 0%, #33214b 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.gradient-purple-indigo {\n  /* fallback/image non-cover color */\n  background-color: #8b5cf6;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #8b5cf6 0%, #33214b 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #8b5cf6 0%, #33214b 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.btn.gradient-purple-indigo:active, .btn.gradient-purple-indigo.active {\n  /* fallback/image non-cover color */\n  background-color: #8b5cf6;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-90deg, #8b5cf6 0%, #33214b 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-90deg, #8b5cf6 0%, #33214b 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.sidebar-gradient-black-blue .sidebar-left {\n  /* fallback/image non-cover color */\n  background-color: #004e92;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #004e92 0%, #000428 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #004e92 0%, #000428 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.gradient-black-blue {\n  /* fallback/image non-cover color */\n  background-color: #004e92;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #004e92 0%, #000428 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #004e92 0%, #000428 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.btn.gradient-black-blue:active, .btn.gradient-black-blue.active {\n  /* fallback/image non-cover color */\n  background-color: #004e92;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-90deg, #004e92 0%, #000428 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-90deg, #004e92 0%, #000428 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.sidebar-gradient-black-gray .sidebar-left {\n  /* fallback/image non-cover color */\n  background-color: #404040;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #404040 0%, #000000 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #404040 0%, #000000 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.gradient-black-gray {\n  /* fallback/image non-cover color */\n  background-color: #404040;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #404040 0%, #000000 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #404040 0%, #000000 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.btn.gradient-black-gray:active, .btn.gradient-black-gray.active {\n  /* fallback/image non-cover color */\n  background-color: #404040;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-90deg, #404040 0%, #000000 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-90deg, #404040 0%, #000000 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.sidebar-gradient-steel-gray .sidebar-left {\n  /* fallback/image non-cover color */\n  background-color: #616d86;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #616d86 0%, #1f1c2c 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #616d86 0%, #1f1c2c 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.gradient-steel-gray {\n  /* fallback/image non-cover color */\n  background-color: #616d86;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-154deg, #616d86 0%, #1f1c2c 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-154deg, #616d86 0%, #1f1c2c 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.btn.gradient-steel-gray:active, .btn.gradient-steel-gray.active {\n  /* fallback/image non-cover color */\n  background-color: #616d86;\n  /* Firefox 3.6+ */\n  /* Safari 4+, Chrome 1+ */\n  /* Safari 5.1+, Chrome 10+ */\n  /* Opera 11.10+ */\n  background-image: -o-linear-gradient(-90deg, #616d86 0%, #1f1c2c 100%);\n  /* IE10+ */\n  /* Standard */\n  background: linear-gradient(-90deg, #616d86 0%, #1f1c2c 100%);\n  /* IE6-9 */\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$from', endColorstr='$to',GradientType=1 );\n}\n\n.sidebar-blue .sidebar-left {\n  background: #3b82f6;\n}\n\n.blue {\n  background: #3b82f6;\n}\n\n.sidebar-midnight-blue .sidebar-left {\n  background: #0c0c3c;\n}\n\n.midnight-blue {\n  background: #0c0c3c;\n}\n\n.sidebar-indigo .sidebar-left {\n  background: #6366f1;\n}\n\n.indigo {\n  background: #6366f1;\n}\n\n.sidebar-dark-purple .sidebar-left {\n  background: #322740;\n}\n\n.dark-purple {\n  background: #322740;\n}\n\n.sidebar-purple .sidebar-left {\n  background: #8b5cf6;\n}\n\n.purple {\n  background: #8b5cf6;\n}\n\n.sidebar-pink .sidebar-left {\n  background: #ec4899;\n}\n\n.pink {\n  background: #ec4899;\n}\n\n.sidebar-red .sidebar-left {\n  background: #ef4444;\n}\n\n.red {\n  background: #ef4444;\n}\n\n.sidebar-orange .sidebar-left {\n  background: #f97316;\n}\n\n.orange {\n  background: #f97316;\n}\n\n.sidebar-yellow .sidebar-left {\n  background: #f59e0b;\n}\n\n.yellow {\n  background: #f59e0b;\n}\n\n.sidebar-green .sidebar-left {\n  background: #10b981;\n}\n\n.green {\n  background: #10b981;\n}\n\n.sidebar-teal .sidebar-left {\n  background: #14b8a6;\n}\n\n.teal {\n  background: #14b8a6;\n}\n\n.sidebar-cyan .sidebar-left {\n  background: #06b6d4;\n}\n\n.cyan {\n  background: #06b6d4;\n}\n\n.sidebar-gray .sidebar-left {\n  background: #71717a;\n}\n\n.gray {\n  background: #71717a;\n}\n\n.sidebar-slate-gray .sidebar-left {\n  background: #64748b;\n}\n\n.slate-gray {\n  background: #64748b;\n}\n\n/*\r\n$full-map: (\r\n  blue: (\r\n    100: #f31312,\r\n    .....,\r\n    900: #f32332\r\n  ),\r\n  red: (\r\n    100: #f31312,\r\n    .....,\r\n    900: #f32332\r\n  )\r\n)\r\n*/\n.blue-50 {\n  background-color: white;\n}\n\n.text-blue-50 {\n  color: black;\n}\n\n.blue-100 {\n  background-color: #fefeff;\n}\n\n.text-blue-100 {\n  color: black;\n}\n\n.blue-200 {\n  background-color: #cddffd;\n}\n\n.text-blue-200 {\n  color: black;\n}\n\n.blue-300 {\n  background-color: #9dc0fa;\n}\n\n.text-blue-300 {\n  color: black;\n}\n\n.blue-400 {\n  background-color: #6ca1f8;\n}\n\n.text-blue-400 {\n  color: black;\n}\n\n.blue-500 {\n  background-color: #3b82f6;\n}\n\n.text-blue-500 {\n  color: black;\n}\n\n.blue-600 {\n  background-color: #0b63f3;\n}\n\n.text-blue-600 {\n  color: black;\n}\n\n.blue-700 {\n  background-color: #094fc2;\n}\n\n.text-blue-700 {\n  color: white;\n}\n\n.blue-800 {\n  background-color: #073b91;\n}\n\n.text-blue-800 {\n  color: white;\n}\n\n.blue-900 {\n  background-color: #042761;\n}\n\n.text-blue-900 {\n  color: white;\n}\n\n.indigo-50 {\n  background-color: white;\n}\n\n.text-indigo-50 {\n  color: black;\n}\n\n.indigo-100 {\n  background-color: white;\n}\n\n.text-indigo-100 {\n  color: black;\n}\n\n.indigo-200 {\n  background-color: #eff0fe;\n}\n\n.text-indigo-200 {\n  color: black;\n}\n\n.indigo-300 {\n  background-color: #c1c2f9;\n}\n\n.text-indigo-300 {\n  color: black;\n}\n\n.indigo-400 {\n  background-color: #9294f5;\n}\n\n.text-indigo-400 {\n  color: black;\n}\n\n.indigo-500 {\n  background-color: #6366f1;\n}\n\n.text-indigo-500 {\n  color: black;\n}\n\n.indigo-600 {\n  background-color: #3438ed;\n}\n\n.text-indigo-600 {\n  color: black;\n}\n\n.indigo-700 {\n  background-color: #1418da;\n}\n\n.text-indigo-700 {\n  color: black;\n}\n\n.indigo-800 {\n  background-color: #0f13ac;\n}\n\n.text-indigo-800 {\n  color: white;\n}\n\n.indigo-900 {\n  background-color: #0b0e7d;\n}\n\n.text-indigo-900 {\n  color: white;\n}\n\n.purple-50 {\n  background-color: white;\n}\n\n.text-purple-50 {\n  color: black;\n}\n\n.purple-100 {\n  background-color: white;\n}\n\n.text-purple-100 {\n  color: black;\n}\n\n.purple-200 {\n  background-color: #f2edfe;\n}\n\n.text-purple-200 {\n  color: black;\n}\n\n.purple-300 {\n  background-color: #d0bdfb;\n}\n\n.text-purple-300 {\n  color: black;\n}\n\n.purple-400 {\n  background-color: #ad8cf9;\n}\n\n.text-purple-400 {\n  color: black;\n}\n\n.purple-500 {\n  background-color: #8b5cf6;\n}\n\n.text-purple-500 {\n  color: black;\n}\n\n.purple-600 {\n  background-color: #692cf3;\n}\n\n.text-purple-600 {\n  color: black;\n}\n\n.purple-700 {\n  background-color: #4d0ce0;\n}\n\n.text-purple-700 {\n  color: black;\n}\n\n.purple-800 {\n  background-color: #3c0aaf;\n}\n\n.text-purple-800 {\n  color: white;\n}\n\n.purple-900 {\n  background-color: #2c077f;\n}\n\n.text-purple-900 {\n  color: white;\n}\n\n.pink-50 {\n  background-color: white;\n}\n\n.text-pink-50 {\n  color: black;\n}\n\n.pink-100 {\n  background-color: white;\n}\n\n.text-pink-100 {\n  color: black;\n}\n\n.pink-200 {\n  background-color: #fad3e6;\n}\n\n.text-pink-200 {\n  color: black;\n}\n\n.pink-300 {\n  background-color: #f6a4cd;\n}\n\n.text-pink-300 {\n  color: black;\n}\n\n.pink-400 {\n  background-color: #f176b3;\n}\n\n.text-pink-400 {\n  color: black;\n}\n\n.pink-500 {\n  background-color: #ec4899;\n}\n\n.text-pink-500 {\n  color: black;\n}\n\n.pink-600 {\n  background-color: #e71a7f;\n}\n\n.text-pink-600 {\n  color: black;\n}\n\n.pink-700 {\n  background-color: #bb1366;\n}\n\n.text-pink-700 {\n  color: black;\n}\n\n.pink-800 {\n  background-color: #8c0f4d;\n}\n\n.text-pink-800 {\n  color: white;\n}\n\n.pink-900 {\n  background-color: #5e0a33;\n}\n\n.text-pink-900 {\n  color: white;\n}\n\n.red-50 {\n  background-color: white;\n}\n\n.text-red-50 {\n  color: black;\n}\n\n.red-100 {\n  background-color: white;\n}\n\n.text-red-100 {\n  color: black;\n}\n\n.red-200 {\n  background-color: #fbd1d1;\n}\n\n.text-red-200 {\n  color: black;\n}\n\n.red-300 {\n  background-color: #f7a2a2;\n}\n\n.text-red-300 {\n  color: black;\n}\n\n.red-400 {\n  background-color: #f37373;\n}\n\n.text-red-400 {\n  color: black;\n}\n\n.red-500 {\n  background-color: #ef4444;\n}\n\n.text-red-500 {\n  color: black;\n}\n\n.red-600 {\n  background-color: #eb1515;\n}\n\n.text-red-600 {\n  color: black;\n}\n\n.red-700 {\n  background-color: #bd1010;\n}\n\n.text-red-700 {\n  color: black;\n}\n\n.red-800 {\n  background-color: #8e0c0c;\n}\n\n.text-red-800 {\n  color: white;\n}\n\n.red-900 {\n  background-color: #5f0808;\n}\n\n.text-red-900 {\n  color: white;\n}\n\n.orange-50 {\n  background-color: white;\n}\n\n.text-orange-50 {\n  color: black;\n}\n\n.orange-100 {\n  background-color: #feeadd;\n}\n\n.text-orange-100 {\n  color: black;\n}\n\n.orange-200 {\n  background-color: #fdcdab;\n}\n\n.text-orange-200 {\n  color: black;\n}\n\n.orange-300 {\n  background-color: #fcaf79;\n}\n\n.text-orange-300 {\n  color: black;\n}\n\n.orange-400 {\n  background-color: #fa9148;\n}\n\n.text-orange-400 {\n  color: black;\n}\n\n.orange-500 {\n  background-color: #f97316;\n}\n\n.text-orange-500 {\n  color: black;\n}\n\n.orange-600 {\n  background-color: #d65b06;\n}\n\n.text-orange-600 {\n  color: black;\n}\n\n.orange-700 {\n  background-color: #a54604;\n}\n\n.text-orange-700 {\n  color: white;\n}\n\n.orange-800 {\n  background-color: #733103;\n}\n\n.text-orange-800 {\n  color: white;\n}\n\n.orange-900 {\n  background-color: #411c02;\n}\n\n.text-orange-900 {\n  color: white;\n}\n\n.yellow-50 {\n  background-color: white;\n}\n\n.text-yellow-50 {\n  color: black;\n}\n\n.yellow-100 {\n  background-color: #fdeccf;\n}\n\n.text-yellow-100 {\n  color: black;\n}\n\n.yellow-200 {\n  background-color: #fbd89e;\n}\n\n.text-yellow-200 {\n  color: black;\n}\n\n.yellow-300 {\n  background-color: #f9c56d;\n}\n\n.text-yellow-300 {\n  color: black;\n}\n\n.yellow-400 {\n  background-color: #f7b13c;\n}\n\n.text-yellow-400 {\n  color: black;\n}\n\n.yellow-500 {\n  background-color: #f59e0b;\n}\n\n.text-yellow-500 {\n  color: black;\n}\n\n.yellow-600 {\n  background-color: #c57f08;\n}\n\n.text-yellow-600 {\n  color: black;\n}\n\n.yellow-700 {\n  background-color: #945f06;\n}\n\n.text-yellow-700 {\n  color: white;\n}\n\n.yellow-800 {\n  background-color: #634004;\n}\n\n.text-yellow-800 {\n  color: white;\n}\n\n.yellow-900 {\n  background-color: #322002;\n}\n\n.text-yellow-900 {\n  color: white;\n}\n\n.green-50 {\n  background-color: #cdfbec;\n}\n\n.text-green-50 {\n  color: black;\n}\n\n.green-100 {\n  background-color: #9ef7d9;\n}\n\n.text-green-100 {\n  color: black;\n}\n\n.green-200 {\n  background-color: #6ff3c7;\n}\n\n.text-green-200 {\n  color: black;\n}\n\n.green-300 {\n  background-color: #40efb5;\n}\n\n.text-green-300 {\n  color: black;\n}\n\n.green-400 {\n  background-color: #14e8a2;\n}\n\n.text-green-400 {\n  color: black;\n}\n\n.green-500 {\n  background-color: #10b981;\n}\n\n.text-green-500 {\n  color: white;\n}\n\n.green-600 {\n  background-color: #0c8a60;\n}\n\n.text-green-600 {\n  color: white;\n}\n\n.green-700 {\n  background-color: #085b40;\n}\n\n.text-green-700 {\n  color: white;\n}\n\n.green-800 {\n  background-color: #042c1f;\n}\n\n.text-green-800 {\n  color: white;\n}\n\n.green-900 {\n  background-color: black;\n}\n\n.text-green-900 {\n  color: white;\n}\n\n.teal-50 {\n  background-color: #d1faf6;\n}\n\n.text-teal-50 {\n  color: black;\n}\n\n.teal-100 {\n  background-color: #a3f5ec;\n}\n\n.text-teal-100 {\n  color: black;\n}\n\n.teal-200 {\n  background-color: #75f0e3;\n}\n\n.text-teal-200 {\n  color: black;\n}\n\n.teal-300 {\n  background-color: #47ebd9;\n}\n\n.text-teal-300 {\n  color: black;\n}\n\n.teal-400 {\n  background-color: #19e6d0;\n}\n\n.text-teal-400 {\n  color: black;\n}\n\n.teal-500 {\n  background-color: #14b8a6;\n}\n\n.text-teal-500 {\n  color: white;\n}\n\n.teal-600 {\n  background-color: #0f8a7d;\n}\n\n.text-teal-600 {\n  color: white;\n}\n\n.teal-700 {\n  background-color: #0a5c53;\n}\n\n.text-teal-700 {\n  color: white;\n}\n\n.teal-800 {\n  background-color: #052e2a;\n}\n\n.text-teal-800 {\n  color: white;\n}\n\n.teal-900 {\n  background-color: black;\n}\n\n.text-teal-900 {\n  color: white;\n}\n\n.cyan-50 {\n  background-color: #dbf9fe;\n}\n\n.text-cyan-50 {\n  color: black;\n}\n\n.cyan-100 {\n  background-color: #a9f0fd;\n}\n\n.text-cyan-100 {\n  color: black;\n}\n\n.cyan-200 {\n  background-color: #78e8fb;\n}\n\n.text-cyan-200 {\n  color: black;\n}\n\n.cyan-300 {\n  background-color: #46e0fa;\n}\n\n.text-cyan-300 {\n  color: black;\n}\n\n.cyan-400 {\n  background-color: #15d7f8;\n}\n\n.text-cyan-400 {\n  color: black;\n}\n\n.cyan-500 {\n  background-color: #06b6d4;\n}\n\n.text-cyan-500 {\n  color: black;\n}\n\n.cyan-600 {\n  background-color: #058ba2;\n}\n\n.text-cyan-600 {\n  color: white;\n}\n\n.cyan-700 {\n  background-color: #036171;\n}\n\n.text-cyan-700 {\n  color: white;\n}\n\n.cyan-800 {\n  background-color: #02363f;\n}\n\n.text-cyan-800 {\n  color: white;\n}\n\n.cyan-900 {\n  background-color: #000c0e;\n}\n\n.text-cyan-900 {\n  color: white;\n}\n\n.white-50 {\n  background-color: white;\n}\n\n.text-white-50 {\n  color: black;\n}\n\n.white-100 {\n  background-color: white;\n}\n\n.text-white-100 {\n  color: black;\n}\n\n.white-200 {\n  background-color: white;\n}\n\n.text-white-200 {\n  color: black;\n}\n\n.white-300 {\n  background-color: white;\n}\n\n.text-white-300 {\n  color: black;\n}\n\n.white-400 {\n  background-color: white;\n}\n\n.text-white-400 {\n  color: black;\n}\n\n.white-500 {\n  background-color: #fff;\n}\n\n.text-white-500 {\n  color: black;\n}\n\n.white-600 {\n  background-color: #e6e5e5;\n}\n\n.text-white-600 {\n  color: black;\n}\n\n.white-700 {\n  background-color: #cccccc;\n}\n\n.text-white-700 {\n  color: black;\n}\n\n.white-800 {\n  background-color: #b3b2b2;\n}\n\n.text-white-800 {\n  color: black;\n}\n\n.white-900 {\n  background-color: #999999;\n}\n\n.text-white-900 {\n  color: black;\n}\n\n.gray-50 {\n  background-color: #d1d6dc;\n}\n\n.text-gray-50 {\n  color: black;\n}\n\n.gray-100 {\n  background-color: #b4bbc6;\n}\n\n.text-gray-100 {\n  color: black;\n}\n\n.gray-200 {\n  background-color: #97a1b0;\n}\n\n.text-gray-200 {\n  color: black;\n}\n\n.gray-300 {\n  background-color: #7a879a;\n}\n\n.text-gray-300 {\n  color: black;\n}\n\n.gray-400 {\n  background-color: #616e80;\n}\n\n.text-gray-400 {\n  color: black;\n}\n\n.gray-500 {\n  background-color: #4B5563;\n}\n\n.text-gray-500 {\n  color: white;\n}\n\n.gray-600 {\n  background-color: #353c46;\n}\n\n.text-gray-600 {\n  color: white;\n}\n\n.gray-700 {\n  background-color: #1f2329;\n}\n\n.text-gray-700 {\n  color: white;\n}\n\n.gray-800 {\n  background-color: #090a0c;\n}\n\n.text-gray-800 {\n  color: white;\n}\n\n.gray-900 {\n  background-color: black;\n}\n\n.text-gray-900 {\n  color: white;\n}\n\n.gray-dark-50 {\n  background-color: #93a7c2;\n}\n\n.text-gray-dark-50 {\n  color: black;\n}\n\n.gray-dark-100 {\n  background-color: #728cb0;\n}\n\n.text-gray-dark-100 {\n  color: black;\n}\n\n.gray-dark-200 {\n  background-color: #567299;\n}\n\n.text-gray-dark-200 {\n  color: black;\n}\n\n.gray-dark-300 {\n  background-color: #445a78;\n}\n\n.text-gray-dark-300 {\n  color: white;\n}\n\n.gray-dark-400 {\n  background-color: #314158;\n}\n\n.text-gray-dark-400 {\n  color: white;\n}\n\n.gray-dark-500 {\n  background-color: #1F2937;\n}\n\n.text-gray-dark-500 {\n  color: white;\n}\n\n.gray-dark-600 {\n  background-color: #0d1116;\n}\n\n.text-gray-dark-600 {\n  color: white;\n}\n\n.gray-dark-700 {\n  background-color: black;\n}\n\n.text-gray-dark-700 {\n  color: white;\n}\n\n.gray-dark-800 {\n  background-color: black;\n}\n\n.text-gray-dark-800 {\n  color: white;\n}\n\n.gray-dark-900 {\n  background-color: black;\n}\n\n.text-gray-dark-900 {\n  color: white;\n}\n\n.purple-50 {\n  background-color: white;\n}\n\n.text-purple-50 {\n  color: black;\n}\n\n.purple-100 {\n  background-color: white;\n}\n\n.text-purple-100 {\n  color: black;\n}\n\n.purple-200 {\n  background-color: #f2edfe;\n}\n\n.text-purple-200 {\n  color: black;\n}\n\n.purple-300 {\n  background-color: #d0bdfb;\n}\n\n.text-purple-300 {\n  color: black;\n}\n\n.purple-400 {\n  background-color: #ad8cf9;\n}\n\n.text-purple-400 {\n  color: black;\n}\n\n.purple-500 {\n  background-color: #8b5cf6;\n}\n\n.text-purple-500 {\n  color: black;\n}\n\n.purple-600 {\n  background-color: #692cf3;\n}\n\n.text-purple-600 {\n  color: black;\n}\n\n.purple-700 {\n  background-color: #4d0ce0;\n}\n\n.text-purple-700 {\n  color: black;\n}\n\n.purple-800 {\n  background-color: #3c0aaf;\n}\n\n.text-purple-800 {\n  color: white;\n}\n\n.purple-900 {\n  background-color: #2c077f;\n}\n\n.text-purple-900 {\n  color: white;\n}\n\n.pink-50 {\n  background-color: white;\n}\n\n.text-pink-50 {\n  color: black;\n}\n\n.pink-100 {\n  background-color: white;\n}\n\n.text-pink-100 {\n  color: black;\n}\n\n.pink-200 {\n  background-color: #fad3e6;\n}\n\n.text-pink-200 {\n  color: black;\n}\n\n.pink-300 {\n  background-color: #f6a4cd;\n}\n\n.text-pink-300 {\n  color: black;\n}\n\n.pink-400 {\n  background-color: #f176b3;\n}\n\n.text-pink-400 {\n  color: black;\n}\n\n.pink-500 {\n  background-color: #ec4899;\n}\n\n.text-pink-500 {\n  color: black;\n}\n\n.pink-600 {\n  background-color: #e71a7f;\n}\n\n.text-pink-600 {\n  color: black;\n}\n\n.pink-700 {\n  background-color: #bb1366;\n}\n\n.text-pink-700 {\n  color: black;\n}\n\n.pink-800 {\n  background-color: #8c0f4d;\n}\n\n.text-pink-800 {\n  color: white;\n}\n\n.pink-900 {\n  background-color: #5e0a33;\n}\n\n.text-pink-900 {\n  color: white;\n}\n\n.red-50 {\n  background-color: white;\n}\n\n.text-red-50 {\n  color: black;\n}\n\n.red-100 {\n  background-color: white;\n}\n\n.text-red-100 {\n  color: black;\n}\n\n.red-200 {\n  background-color: #fbd1d1;\n}\n\n.text-red-200 {\n  color: black;\n}\n\n.red-300 {\n  background-color: #f7a2a2;\n}\n\n.text-red-300 {\n  color: black;\n}\n\n.red-400 {\n  background-color: #f37373;\n}\n\n.text-red-400 {\n  color: black;\n}\n\n.red-500 {\n  background-color: #ef4444;\n}\n\n.text-red-500 {\n  color: black;\n}\n\n.red-600 {\n  background-color: #eb1515;\n}\n\n.text-red-600 {\n  color: black;\n}\n\n.red-700 {\n  background-color: #bd1010;\n}\n\n.text-red-700 {\n  color: black;\n}\n\n.red-800 {\n  background-color: #8e0c0c;\n}\n\n.text-red-800 {\n  color: white;\n}\n\n.red-900 {\n  background-color: #5f0808;\n}\n\n.text-red-900 {\n  color: white;\n}\n\n.orange-50 {\n  background-color: white;\n}\n\n.text-orange-50 {\n  color: black;\n}\n\n.orange-100 {\n  background-color: #feeadd;\n}\n\n.text-orange-100 {\n  color: black;\n}\n\n.orange-200 {\n  background-color: #fdcdab;\n}\n\n.text-orange-200 {\n  color: black;\n}\n\n.orange-300 {\n  background-color: #fcaf79;\n}\n\n.text-orange-300 {\n  color: black;\n}\n\n.orange-400 {\n  background-color: #fa9148;\n}\n\n.text-orange-400 {\n  color: black;\n}\n\n.orange-500 {\n  background-color: #f97316;\n}\n\n.text-orange-500 {\n  color: black;\n}\n\n.orange-600 {\n  background-color: #d65b06;\n}\n\n.text-orange-600 {\n  color: black;\n}\n\n.orange-700 {\n  background-color: #a54604;\n}\n\n.text-orange-700 {\n  color: white;\n}\n\n.orange-800 {\n  background-color: #733103;\n}\n\n.text-orange-800 {\n  color: white;\n}\n\n.orange-900 {\n  background-color: #411c02;\n}\n\n.text-orange-900 {\n  color: white;\n}\n\n.yellow-50 {\n  background-color: white;\n}\n\n.text-yellow-50 {\n  color: black;\n}\n\n.yellow-100 {\n  background-color: #fdeccf;\n}\n\n.text-yellow-100 {\n  color: black;\n}\n\n.yellow-200 {\n  background-color: #fbd89e;\n}\n\n.text-yellow-200 {\n  color: black;\n}\n\n.yellow-300 {\n  background-color: #f9c56d;\n}\n\n.text-yellow-300 {\n  color: black;\n}\n\n.yellow-400 {\n  background-color: #f7b13c;\n}\n\n.text-yellow-400 {\n  color: black;\n}\n\n.yellow-500 {\n  background-color: #f59e0b;\n}\n\n.text-yellow-500 {\n  color: black;\n}\n\n.yellow-600 {\n  background-color: #c57f08;\n}\n\n.text-yellow-600 {\n  color: black;\n}\n\n.yellow-700 {\n  background-color: #945f06;\n}\n\n.text-yellow-700 {\n  color: white;\n}\n\n.yellow-800 {\n  background-color: #634004;\n}\n\n.text-yellow-800 {\n  color: white;\n}\n\n.yellow-900 {\n  background-color: #322002;\n}\n\n.text-yellow-900 {\n  color: white;\n}\n\n.green-50 {\n  background-color: #cdfbec;\n}\n\n.text-green-50 {\n  color: black;\n}\n\n.green-100 {\n  background-color: #9ef7d9;\n}\n\n.text-green-100 {\n  color: black;\n}\n\n.green-200 {\n  background-color: #6ff3c7;\n}\n\n.text-green-200 {\n  color: black;\n}\n\n.green-300 {\n  background-color: #40efb5;\n}\n\n.text-green-300 {\n  color: black;\n}\n\n.green-400 {\n  background-color: #14e8a2;\n}\n\n.text-green-400 {\n  color: black;\n}\n\n.green-500 {\n  background-color: #10b981;\n}\n\n.text-green-500 {\n  color: white;\n}\n\n.green-600 {\n  background-color: #0c8a60;\n}\n\n.text-green-600 {\n  color: white;\n}\n\n.green-700 {\n  background-color: #085b40;\n}\n\n.text-green-700 {\n  color: white;\n}\n\n.green-800 {\n  background-color: #042c1f;\n}\n\n.text-green-800 {\n  color: white;\n}\n\n.green-900 {\n  background-color: black;\n}\n\n.text-green-900 {\n  color: white;\n}\n\n.teal-50 {\n  background-color: #d1faf6;\n}\n\n.text-teal-50 {\n  color: black;\n}\n\n.teal-100 {\n  background-color: #a3f5ec;\n}\n\n.text-teal-100 {\n  color: black;\n}\n\n.teal-200 {\n  background-color: #75f0e3;\n}\n\n.text-teal-200 {\n  color: black;\n}\n\n.teal-300 {\n  background-color: #47ebd9;\n}\n\n.text-teal-300 {\n  color: black;\n}\n\n.teal-400 {\n  background-color: #19e6d0;\n}\n\n.text-teal-400 {\n  color: black;\n}\n\n.teal-500 {\n  background-color: #14b8a6;\n}\n\n.text-teal-500 {\n  color: white;\n}\n\n.teal-600 {\n  background-color: #0f8a7d;\n}\n\n.text-teal-600 {\n  color: white;\n}\n\n.teal-700 {\n  background-color: #0a5c53;\n}\n\n.text-teal-700 {\n  color: white;\n}\n\n.teal-800 {\n  background-color: #052e2a;\n}\n\n.text-teal-800 {\n  color: white;\n}\n\n.teal-900 {\n  background-color: black;\n}\n\n.text-teal-900 {\n  color: white;\n}\n\n.cyan-50 {\n  background-color: #dbf9fe;\n}\n\n.text-cyan-50 {\n  color: black;\n}\n\n.cyan-100 {\n  background-color: #a9f0fd;\n}\n\n.text-cyan-100 {\n  color: black;\n}\n\n.cyan-200 {\n  background-color: #78e8fb;\n}\n\n.text-cyan-200 {\n  color: black;\n}\n\n.cyan-300 {\n  background-color: #46e0fa;\n}\n\n.text-cyan-300 {\n  color: black;\n}\n\n.cyan-400 {\n  background-color: #15d7f8;\n}\n\n.text-cyan-400 {\n  color: black;\n}\n\n.cyan-500 {\n  background-color: #06b6d4;\n}\n\n.text-cyan-500 {\n  color: black;\n}\n\n.cyan-600 {\n  background-color: #058ba2;\n}\n\n.text-cyan-600 {\n  color: white;\n}\n\n.cyan-700 {\n  background-color: #036171;\n}\n\n.text-cyan-700 {\n  color: white;\n}\n\n.cyan-800 {\n  background-color: #02363f;\n}\n\n.text-cyan-800 {\n  color: white;\n}\n\n.cyan-900 {\n  background-color: #000c0e;\n}\n\n.text-cyan-900 {\n  color: white;\n}\n\n.white-50 {\n  background-color: white;\n}\n\n.text-white-50 {\n  color: black;\n}\n\n.white-100 {\n  background-color: white;\n}\n\n.text-white-100 {\n  color: black;\n}\n\n.white-200 {\n  background-color: white;\n}\n\n.text-white-200 {\n  color: black;\n}\n\n.white-300 {\n  background-color: white;\n}\n\n.text-white-300 {\n  color: black;\n}\n\n.white-400 {\n  background-color: white;\n}\n\n.text-white-400 {\n  color: black;\n}\n\n.white-500 {\n  background-color: #fff;\n}\n\n.text-white-500 {\n  color: black;\n}\n\n.white-600 {\n  background-color: #e6e5e5;\n}\n\n.text-white-600 {\n  color: black;\n}\n\n.white-700 {\n  background-color: #cccccc;\n}\n\n.text-white-700 {\n  color: black;\n}\n\n.white-800 {\n  background-color: #b3b2b2;\n}\n\n.text-white-800 {\n  color: black;\n}\n\n.white-900 {\n  background-color: #999999;\n}\n\n.text-white-900 {\n  color: black;\n}\n\n.gray-50 {\n  background-color: #d1d6dc;\n}\n\n.text-gray-50 {\n  color: black;\n}\n\n.gray-100 {\n  background-color: #b4bbc6;\n}\n\n.text-gray-100 {\n  color: black;\n}\n\n.gray-200 {\n  background-color: #97a1b0;\n}\n\n.text-gray-200 {\n  color: black;\n}\n\n.gray-300 {\n  background-color: #7a879a;\n}\n\n.text-gray-300 {\n  color: black;\n}\n\n.gray-400 {\n  background-color: #616e80;\n}\n\n.text-gray-400 {\n  color: black;\n}\n\n.gray-500 {\n  background-color: #4B5563;\n}\n\n.text-gray-500 {\n  color: white;\n}\n\n.gray-600 {\n  background-color: #353c46;\n}\n\n.text-gray-600 {\n  color: white;\n}\n\n.gray-700 {\n  background-color: #1f2329;\n}\n\n.text-gray-700 {\n  color: white;\n}\n\n.gray-800 {\n  background-color: #090a0c;\n}\n\n.text-gray-800 {\n  color: white;\n}\n\n.gray-900 {\n  background-color: black;\n}\n\n.text-gray-900 {\n  color: white;\n}\n\n@-webkit-keyframes bounce {\n  0%, 20%, 50%, 80%, 100% {\n    transform: translateY(0);\n  }\n  40% {\n    transform: translateY(-30px);\n  }\n  60% {\n    transform: translateY(-15px);\n  }\n}\n\n@keyframes bounce {\n  0%, 20%, 50%, 80%, 100% {\n    transform: translateY(0);\n  }\n  40% {\n    transform: translateY(-30px);\n  }\n  60% {\n    transform: translateY(-15px);\n  }\n}\n\n@-webkit-keyframes flash {\n  0%, 50%, 100% {\n    opacity: 1;\n  }\n  25%, 75% {\n    opacity: 0;\n  }\n}\n\n@keyframes flash {\n  0%, 50%, 100% {\n    opacity: 1;\n  }\n  25%, 75% {\n    opacity: 0;\n  }\n}\n\n@-webkit-keyframes jello {\n  11.1% {\n    transform: none;\n  }\n  22.2% {\n    transform: skewX(-12.5deg) skewY(-12.5deg);\n  }\n  33.3% {\n    transform: skewX(6.25deg) skewY(6.25deg);\n  }\n  44.4% {\n    transform: skewX(-3.125deg) skewY(-3.125deg);\n  }\n  55.5% {\n    transform: skewX(1.5625deg) skewY(1.5625deg);\n  }\n  66.6% {\n    transform: skewX(-0.78125deg) skewY(-0.78125deg);\n  }\n  77.7% {\n    transform: skewX(0.390625deg) skewY(0.390625deg);\n  }\n  88.8% {\n    transform: skewX(-0.1953125deg) skewY(-0.1953125deg);\n  }\n  100% {\n    transform: none;\n  }\n}\n\n@keyframes jello {\n  11.1% {\n    transform: none;\n  }\n  22.2% {\n    transform: skewX(-12.5deg) skewY(-12.5deg);\n  }\n  33.3% {\n    transform: skewX(6.25deg) skewY(6.25deg);\n  }\n  44.4% {\n    transform: skewX(-3.125deg) skewY(-3.125deg);\n  }\n  55.5% {\n    transform: skewX(1.5625deg) skewY(1.5625deg);\n  }\n  66.6% {\n    transform: skewX(-0.78125deg) skewY(-0.78125deg);\n  }\n  77.7% {\n    transform: skewX(0.390625deg) skewY(0.390625deg);\n  }\n  88.8% {\n    transform: skewX(-0.1953125deg) skewY(-0.1953125deg);\n  }\n  100% {\n    transform: none;\n  }\n}\n\n@-webkit-keyframes pulse {\n  0% {\n    transform: scale(1);\n  }\n  50% {\n    transform: scale(1.1);\n  }\n  100% {\n    transform: scale(1);\n  }\n}\n\n@keyframes pulse {\n  0% {\n    transform: scale(1);\n  }\n  50% {\n    transform: scale(1.1);\n  }\n  100% {\n    transform: scale(1);\n  }\n}\n\n@-webkit-keyframes rubberBand {\n  0% {\n    transform: scale3d(1, 1, 1);\n  }\n  30% {\n    transform: scale3d(1.25, 0.75, 1);\n  }\n  40% {\n    transform: scale3d(0.75, 1.25, 1);\n  }\n  50% {\n    transform: scale3d(1.15, 0.85, 1);\n  }\n  65% {\n    transform: scale3d(0.95, 1.05, 1);\n  }\n  75% {\n    transform: scale3d(1.05, 0.95, 1);\n  }\n  100% {\n    transform: scale3d(1, 1, 1);\n  }\n}\n\n@keyframes rubberBand {\n  0% {\n    transform: scale3d(1, 1, 1);\n  }\n  30% {\n    transform: scale3d(1.25, 0.75, 1);\n  }\n  40% {\n    transform: scale3d(0.75, 1.25, 1);\n  }\n  50% {\n    transform: scale3d(1.15, 0.85, 1);\n  }\n  65% {\n    transform: scale3d(0.95, 1.05, 1);\n  }\n  75% {\n    transform: scale3d(1.05, 0.95, 1);\n  }\n  100% {\n    transform: scale3d(1, 1, 1);\n  }\n}\n\n@-webkit-keyframes shake {\n  0%, 100% {\n    transform: translateX(0);\n  }\n  10%, 30%, 50%, 70%, 90% {\n    transform: translateX(-10px);\n  }\n  20%, 40%, 60%, 80% {\n    transform: translateX(10px);\n  }\n}\n\n@keyframes shake {\n  0%, 100% {\n    transform: translateX(0);\n  }\n  10%, 30%, 50%, 70%, 90% {\n    transform: translateX(-10px);\n  }\n  20%, 40%, 60%, 80% {\n    transform: translateX(10px);\n  }\n}\n\n@-webkit-keyframes swing {\n  20%, 40%, 60%, 80%, 100% {\n    transform-origin: top center;\n  }\n  20% {\n    transform: rotate(15deg);\n  }\n  40% {\n    transform: rotate(-10deg);\n  }\n  60% {\n    transform: rotate(5deg);\n  }\n  80% {\n    transform: rotate(-5deg);\n  }\n  100% {\n    transform: rotate(0deg);\n  }\n}\n\n@keyframes swing {\n  20%, 40%, 60%, 80%, 100% {\n    transform-origin: top center;\n  }\n  20% {\n    transform: rotate(15deg);\n  }\n  40% {\n    transform: rotate(-10deg);\n  }\n  60% {\n    transform: rotate(5deg);\n  }\n  80% {\n    transform: rotate(-5deg);\n  }\n  100% {\n    transform: rotate(0deg);\n  }\n}\n\n@-webkit-keyframes tada {\n  0% {\n    transform: scale(1);\n  }\n  10%, 20% {\n    transform: scale(0.9) rotate(-3deg);\n  }\n  30%, 50%, 70%, 90% {\n    transform: scale(1.1) rotate(3deg);\n  }\n  40%, 60%, 80% {\n    transform: scale(1.1) rotate(-3deg);\n  }\n  100% {\n    transform: scale(1) rotate(0);\n  }\n}\n\n@keyframes tada {\n  0% {\n    transform: scale(1);\n  }\n  10%, 20% {\n    transform: scale(0.9) rotate(-3deg);\n  }\n  30%, 50%, 70%, 90% {\n    transform: scale(1.1) rotate(3deg);\n  }\n  40%, 60%, 80% {\n    transform: scale(1.1) rotate(-3deg);\n  }\n  100% {\n    transform: scale(1) rotate(0);\n  }\n}\n\n@-webkit-keyframes wobble {\n  0% {\n    transform: translateX(0%);\n  }\n  15% {\n    transform: translateX(-25%) rotate(-5deg);\n  }\n  30% {\n    transform: translateX(20%) rotate(3deg);\n  }\n  45% {\n    transform: translateX(-15%) rotate(-3deg);\n  }\n  60% {\n    transform: translateX(10%) rotate(2deg);\n  }\n  75% {\n    transform: translateX(-5%) rotate(-1deg);\n  }\n  100% {\n    transform: translateX(0%);\n  }\n}\n\n@keyframes wobble {\n  0% {\n    transform: translateX(0%);\n  }\n  15% {\n    transform: translateX(-25%) rotate(-5deg);\n  }\n  30% {\n    transform: translateX(20%) rotate(3deg);\n  }\n  45% {\n    transform: translateX(-15%) rotate(-3deg);\n  }\n  60% {\n    transform: translateX(10%) rotate(2deg);\n  }\n  75% {\n    transform: translateX(-5%) rotate(-1deg);\n  }\n  100% {\n    transform: translateX(0%);\n  }\n}\n\n@-webkit-keyframes fadeIn {\n  0% {\n    opacity: 0;\n  }\n  100% {\n    opacity: 1;\n  }\n}\n\n@keyframes fadeIn {\n  0% {\n    opacity: 0;\n  }\n  100% {\n    opacity: 1;\n  }\n}\n\n@-webkit-keyframes fadeInDown {\n  0% {\n    opacity: 0;\n    transform: translateY(-20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@keyframes fadeInDown {\n  0% {\n    opacity: 0;\n    transform: translateY(-20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@-webkit-keyframes fadeInDownBig {\n  0% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@keyframes fadeInDownBig {\n  0% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@-webkit-keyframes fadeInLeft {\n  0% {\n    opacity: 0;\n    transform: translateX(-20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@keyframes fadeInLeft {\n  0% {\n    opacity: 0;\n    transform: translateX(-20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@-webkit-keyframes fadeInLeftBig {\n  0% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@keyframes fadeInLeftBig {\n  0% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@-webkit-keyframes fadeInRight {\n  0% {\n    opacity: 0;\n    transform: translateX(20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@keyframes fadeInRight {\n  0% {\n    opacity: 0;\n    transform: translateX(20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@-webkit-keyframes fadeInRightBig {\n  0% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@keyframes fadeInRightBig {\n  0% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@-webkit-keyframes fadeInUp {\n  0% {\n    opacity: 0;\n    transform: translateY(20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@keyframes fadeInUp {\n  0% {\n    opacity: 0;\n    transform: translateY(20px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@-webkit-keyframes fadeInUpBig {\n  0% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@keyframes fadeInUpBig {\n  0% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@-webkit-keyframes fadeOut {\n  0% {\n    opacity: 1;\n  }\n  100% {\n    opacity: 0;\n  }\n}\n\n@keyframes fadeOut {\n  0% {\n    opacity: 1;\n  }\n  100% {\n    opacity: 0;\n  }\n}\n\n@-webkit-keyframes fadeOutDown {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(20px);\n  }\n}\n\n@keyframes fadeOutDown {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(20px);\n  }\n}\n\n@-webkit-keyframes fadeOutDownBig {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n}\n\n@keyframes fadeOutDownBig {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n}\n\n@-webkit-keyframes fadeOutLeft {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(-20px);\n  }\n}\n\n@keyframes fadeOutLeft {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(-20px);\n  }\n}\n\n@-webkit-keyframes fadeOutLeftBig {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n}\n\n@keyframes fadeOutLeftBig {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n}\n\n@-webkit-keyframes fadeOutRight {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(20px);\n  }\n}\n\n@keyframes fadeOutRight {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(20px);\n  }\n}\n\n@-webkit-keyframes fadeOutRightBig {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n}\n\n@keyframes fadeOutRightBig {\n  0% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n}\n\n@-webkit-keyframes fadeOutUp {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(-20px);\n  }\n}\n\n@keyframes fadeOutUp {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(-20px);\n  }\n}\n\n@-webkit-keyframes fadeOutUpBig {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n}\n\n@keyframes fadeOutUpBig {\n  0% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n}\n\n@-webkit-keyframes slideInDown {\n  0% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@keyframes slideInDown {\n  0% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@-webkit-keyframes slideInLeft {\n  0% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@keyframes slideInLeft {\n  0% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@-webkit-keyframes slideInRight {\n  0% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@keyframes slideInRight {\n  0% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateX(0);\n  }\n}\n\n@-webkit-keyframes slideInUp {\n  0% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@keyframes slideInUp {\n  0% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n  100% {\n    opacity: 1;\n    transform: translateY(0);\n  }\n}\n\n@-webkit-keyframes slideOutDown {\n  0% {\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n}\n\n@keyframes slideOutDown {\n  0% {\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(2000px);\n  }\n}\n\n@-webkit-keyframes slideOutLeft {\n  0% {\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n}\n\n@keyframes slideOutLeft {\n  0% {\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(-2000px);\n  }\n}\n\n@-webkit-keyframes slideOutRight {\n  0% {\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n}\n\n@keyframes slideOutRight {\n  0% {\n    transform: translateX(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateX(2000px);\n  }\n}\n\n@-webkit-keyframes slideOutUp {\n  0% {\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n}\n\n@keyframes slideOutUp {\n  0% {\n    transform: translateY(0);\n  }\n  100% {\n    opacity: 0;\n    transform: translateY(-2000px);\n  }\n}\n\n@-webkit-keyframes zoomIn {\n  0% {\n    opacity: 0;\n    transform: scale3d(0.3, 0.3, 0.3);\n  }\n  50% {\n    opacity: 1;\n  }\n}\n\n@keyframes zoomIn {\n  0% {\n    opacity: 0;\n    transform: scale3d(0.3, 0.3, 0.3);\n  }\n  50% {\n    opacity: 1;\n  }\n}\n\n@-webkit-keyframes zoomInDown {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);\n  }\n}\n\n@keyframes zoomInDown {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);\n  }\n}\n\n@-webkit-keyframes zoomInLeft {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);\n  }\n}\n\n@keyframes zoomInLeft {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);\n  }\n}\n\n@-webkit-keyframes zoomInRight {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);\n  }\n}\n\n@keyframes zoomInRight {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);\n  }\n}\n\n@-webkit-keyframes zoomInUp {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);\n  }\n}\n\n@keyframes zoomInUp {\n  0% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);\n  }\n  60% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);\n  }\n}\n\n@-webkit-keyframes zoomOut {\n  0% {\n    opacity: 1;\n  }\n  50% {\n    opacity: 0;\n    transform: scale3d(0.3, 0.3, 0.3);\n  }\n  100% {\n    opacity: 0;\n  }\n}\n\n@keyframes zoomOut {\n  0% {\n    opacity: 1;\n  }\n  50% {\n    opacity: 0;\n    transform: scale3d(0.3, 0.3, 0.3);\n  }\n  100% {\n    opacity: 0;\n  }\n}\n\n@-webkit-keyframes zoomOutDown {\n  40% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);\n  }\n  100% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);\n    transform-origin: center bottom;\n  }\n}\n\n@keyframes zoomOutDown {\n  40% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);\n  }\n  100% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);\n    transform-origin: center bottom;\n  }\n}\n\n@-webkit-keyframes zoomOutLeft {\n  40% {\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);\n  }\n  100% {\n    opacity: 0;\n    transform: scale(0.1) translate3d(-2000px, 0, 0);\n    transform-origin: left center;\n  }\n}\n\n@keyframes zoomOutLeft {\n  40% {\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);\n  }\n  100% {\n    opacity: 0;\n    transform: scale(0.1) translate3d(-2000px, 0, 0);\n    transform-origin: left center;\n  }\n}\n\n@-webkit-keyframes zoomOutRight {\n  40% {\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);\n  }\n  100% {\n    opacity: 0;\n    transform: scale(0.1) translate3d(2000px, 0, 0);\n    transform-origin: right center;\n  }\n}\n\n@keyframes zoomOutRight {\n  40% {\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);\n  }\n  100% {\n    opacity: 0;\n    transform: scale(0.1) translate3d(2000px, 0, 0);\n    transform-origin: right center;\n  }\n}\n\n@-webkit-keyframes zoomOutUp {\n  40% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);\n  }\n  100% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);\n    transform-origin: center bottom;\n  }\n}\n\n@keyframes zoomOutUp {\n  40% {\n    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n            animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);\n    opacity: 1;\n    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);\n  }\n  100% {\n    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n            animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);\n    opacity: 0;\n    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);\n    transform-origin: center bottom;\n  }\n}\n\n.page-enter-active {\n  -webkit-animation: slide-in 0.3s ease-out forwards;\n          animation: slide-in 0.3s ease-out forwards;\n}\n\n.page-leave-active {\n  -webkit-animation: slide-out 0.3s ease-out forwards;\n          animation: slide-out 0.3s ease-out forwards;\n}\n\n@-webkit-keyframes slide-in {\n  from {\n    transform: scale(0.9);\n    opacity: 0;\n  }\n  to {\n    transform: scale(1);\n    opacity: 1;\n  }\n}\n\n@keyframes slide-in {\n  from {\n    transform: scale(0.9);\n    opacity: 0;\n  }\n  to {\n    transform: scale(1);\n    opacity: 1;\n  }\n}\n\n@-webkit-keyframes slide-out {\n  from {\n    transform: scale(1);\n    opacity: 1;\n  }\n  to {\n    transform: scale(0.9);\n    opacity: 0;\n  }\n}\n\n@keyframes slide-out {\n  from {\n    transform: scale(1);\n    opacity: 1;\n  }\n  to {\n    transform: scale(0.9);\n    opacity: 0;\n  }\n}\n\n@keyframes zoomIn {\n  0% {\n    transform: scale(0.5);\n    opacity: 0;\n  }\n  100% {\n    transform: scale(1);\n    opacity: 1;\n  }\n}\n\n@keyframes spin {\n  0% {\n    transform: rotate(0);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n\n.spin {\n  -webkit-animation: spin 2s infinite linear;\n          animation: spin 2s infinite linear;\n}\n\nh1, h2, h3, h4, h5, h6, .card-title, .text-title {\n  color: #05070b;\n}\n\n.text-10 {\n  font-size: 10px;\n}\n\n.text-11 {\n  font-size: 11px;\n}\n\n.text-12 {\n  font-size: 12px;\n}\n\n.text-13 {\n  font-size: 13px;\n}\n\n.text-14 {\n  font-size: 14px;\n}\n\n.text-15 {\n  font-size: 15px;\n}\n\n.text-16 {\n  font-size: 16px;\n}\n\n.text-17 {\n  font-size: 17px;\n}\n\n.text-18 {\n  font-size: 18px;\n}\n\n.text-19 {\n  font-size: 19px;\n}\n\n.text-20 {\n  font-size: 20px;\n}\n\n.text-21 {\n  font-size: 21px;\n}\n\n.text-22 {\n  font-size: 22px;\n}\n\n.text-23 {\n  font-size: 23px;\n}\n\n.text-24 {\n  font-size: 24px;\n}\n\n.text-25 {\n  font-size: 25px;\n}\n\n.text-26 {\n  font-size: 26px;\n}\n\n.text-27 {\n  font-size: 27px;\n}\n\n.text-28 {\n  font-size: 28px;\n}\n\n.text-29 {\n  font-size: 29px;\n}\n\n.text-30 {\n  font-size: 30px;\n}\n\n.text-31 {\n  font-size: 31px;\n}\n\n.text-32 {\n  font-size: 32px;\n}\n\n.text-33 {\n  font-size: 33px;\n}\n\n.text-34 {\n  font-size: 34px;\n}\n\n.text-35 {\n  font-size: 35px;\n}\n\n.text-36 {\n  font-size: 36px;\n}\n\n.text-37 {\n  font-size: 37px;\n}\n\n.text-38 {\n  font-size: 38px;\n}\n\n.text-39 {\n  font-size: 39px;\n}\n\n.text-40 {\n  font-size: 40px;\n}\n\n.text-41 {\n  font-size: 41px;\n}\n\n.text-42 {\n  font-size: 42px;\n}\n\n.text-43 {\n  font-size: 43px;\n}\n\n.text-44 {\n  font-size: 44px;\n}\n\n.text-45 {\n  font-size: 45px;\n}\n\n.text-46 {\n  font-size: 46px;\n}\n\n.text-47 {\n  font-size: 47px;\n}\n\n.text-48 {\n  font-size: 48px;\n}\n\n.text-49 {\n  font-size: 49px;\n}\n\n.text-50 {\n  font-size: 50px;\n}\n\n.text-51 {\n  font-size: 51px;\n}\n\n.text-52 {\n  font-size: 52px;\n}\n\n.text-53 {\n  font-size: 53px;\n}\n\n.text-54 {\n  font-size: 54px;\n}\n\n.text-55 {\n  font-size: 55px;\n}\n\n.text-56 {\n  font-size: 56px;\n}\n\n.text-57 {\n  font-size: 57px;\n}\n\n.text-58 {\n  font-size: 58px;\n}\n\n.text-59 {\n  font-size: 59px;\n}\n\n.text-60 {\n  font-size: 60px;\n}\n\n.text-61 {\n  font-size: 61px;\n}\n\n.text-62 {\n  font-size: 62px;\n}\n\n.text-63 {\n  font-size: 63px;\n}\n\n.text-64 {\n  font-size: 64px;\n}\n\n.text-65 {\n  font-size: 65px;\n}\n\n.text-66 {\n  font-size: 66px;\n}\n\n.text-67 {\n  font-size: 67px;\n}\n\n.text-68 {\n  font-size: 68px;\n}\n\n.text-69 {\n  font-size: 69px;\n}\n\n.text-70 {\n  font-size: 70px;\n}\n\n.text-71 {\n  font-size: 71px;\n}\n\n.text-72 {\n  font-size: 72px;\n}\n\n.text-73 {\n  font-size: 73px;\n}\n\n.text-74 {\n  font-size: 74px;\n}\n\n.text-75 {\n  font-size: 75px;\n}\n\n.text-76 {\n  font-size: 76px;\n}\n\n.text-77 {\n  font-size: 77px;\n}\n\n.text-78 {\n  font-size: 78px;\n}\n\n.font-weight-300 {\n  font-weight: 300;\n}\n\n.font-weight-301 {\n  font-weight: 301;\n}\n\n.font-weight-302 {\n  font-weight: 302;\n}\n\n.font-weight-303 {\n  font-weight: 303;\n}\n\n.font-weight-304 {\n  font-weight: 304;\n}\n\n.font-weight-305 {\n  font-weight: 305;\n}\n\n.font-weight-306 {\n  font-weight: 306;\n}\n\n.font-weight-307 {\n  font-weight: 307;\n}\n\n.font-weight-308 {\n  font-weight: 308;\n}\n\n.font-weight-309 {\n  font-weight: 309;\n}\n\n.font-weight-310 {\n  font-weight: 310;\n}\n\n.font-weight-311 {\n  font-weight: 311;\n}\n\n.font-weight-312 {\n  font-weight: 312;\n}\n\n.font-weight-313 {\n  font-weight: 313;\n}\n\n.font-weight-314 {\n  font-weight: 314;\n}\n\n.font-weight-315 {\n  font-weight: 315;\n}\n\n.font-weight-316 {\n  font-weight: 316;\n}\n\n.font-weight-317 {\n  font-weight: 317;\n}\n\n.font-weight-318 {\n  font-weight: 318;\n}\n\n.font-weight-319 {\n  font-weight: 319;\n}\n\n.font-weight-320 {\n  font-weight: 320;\n}\n\n.font-weight-321 {\n  font-weight: 321;\n}\n\n.font-weight-322 {\n  font-weight: 322;\n}\n\n.font-weight-323 {\n  font-weight: 323;\n}\n\n.font-weight-324 {\n  font-weight: 324;\n}\n\n.font-weight-325 {\n  font-weight: 325;\n}\n\n.font-weight-326 {\n  font-weight: 326;\n}\n\n.font-weight-327 {\n  font-weight: 327;\n}\n\n.font-weight-328 {\n  font-weight: 328;\n}\n\n.font-weight-329 {\n  font-weight: 329;\n}\n\n.font-weight-330 {\n  font-weight: 330;\n}\n\n.font-weight-331 {\n  font-weight: 331;\n}\n\n.font-weight-332 {\n  font-weight: 332;\n}\n\n.font-weight-333 {\n  font-weight: 333;\n}\n\n.font-weight-334 {\n  font-weight: 334;\n}\n\n.font-weight-335 {\n  font-weight: 335;\n}\n\n.font-weight-336 {\n  font-weight: 336;\n}\n\n.font-weight-337 {\n  font-weight: 337;\n}\n\n.font-weight-338 {\n  font-weight: 338;\n}\n\n.font-weight-339 {\n  font-weight: 339;\n}\n\n.font-weight-340 {\n  font-weight: 340;\n}\n\n.font-weight-341 {\n  font-weight: 341;\n}\n\n.font-weight-342 {\n  font-weight: 342;\n}\n\n.font-weight-343 {\n  font-weight: 343;\n}\n\n.font-weight-344 {\n  font-weight: 344;\n}\n\n.font-weight-345 {\n  font-weight: 345;\n}\n\n.font-weight-346 {\n  font-weight: 346;\n}\n\n.font-weight-347 {\n  font-weight: 347;\n}\n\n.font-weight-348 {\n  font-weight: 348;\n}\n\n.font-weight-349 {\n  font-weight: 349;\n}\n\n.font-weight-350 {\n  font-weight: 350;\n}\n\n.font-weight-351 {\n  font-weight: 351;\n}\n\n.font-weight-352 {\n  font-weight: 352;\n}\n\n.font-weight-353 {\n  font-weight: 353;\n}\n\n.font-weight-354 {\n  font-weight: 354;\n}\n\n.font-weight-355 {\n  font-weight: 355;\n}\n\n.font-weight-356 {\n  font-weight: 356;\n}\n\n.font-weight-357 {\n  font-weight: 357;\n}\n\n.font-weight-358 {\n  font-weight: 358;\n}\n\n.font-weight-359 {\n  font-weight: 359;\n}\n\n.font-weight-360 {\n  font-weight: 360;\n}\n\n.font-weight-361 {\n  font-weight: 361;\n}\n\n.font-weight-362 {\n  font-weight: 362;\n}\n\n.font-weight-363 {\n  font-weight: 363;\n}\n\n.font-weight-364 {\n  font-weight: 364;\n}\n\n.font-weight-365 {\n  font-weight: 365;\n}\n\n.font-weight-366 {\n  font-weight: 366;\n}\n\n.font-weight-367 {\n  font-weight: 367;\n}\n\n.font-weight-368 {\n  font-weight: 368;\n}\n\n.font-weight-369 {\n  font-weight: 369;\n}\n\n.font-weight-370 {\n  font-weight: 370;\n}\n\n.font-weight-371 {\n  font-weight: 371;\n}\n\n.font-weight-372 {\n  font-weight: 372;\n}\n\n.font-weight-373 {\n  font-weight: 373;\n}\n\n.font-weight-374 {\n  font-weight: 374;\n}\n\n.font-weight-375 {\n  font-weight: 375;\n}\n\n.font-weight-376 {\n  font-weight: 376;\n}\n\n.font-weight-377 {\n  font-weight: 377;\n}\n\n.font-weight-378 {\n  font-weight: 378;\n}\n\n.font-weight-379 {\n  font-weight: 379;\n}\n\n.font-weight-380 {\n  font-weight: 380;\n}\n\n.font-weight-381 {\n  font-weight: 381;\n}\n\n.font-weight-382 {\n  font-weight: 382;\n}\n\n.font-weight-383 {\n  font-weight: 383;\n}\n\n.font-weight-384 {\n  font-weight: 384;\n}\n\n.font-weight-385 {\n  font-weight: 385;\n}\n\n.font-weight-386 {\n  font-weight: 386;\n}\n\n.font-weight-387 {\n  font-weight: 387;\n}\n\n.font-weight-388 {\n  font-weight: 388;\n}\n\n.font-weight-389 {\n  font-weight: 389;\n}\n\n.font-weight-390 {\n  font-weight: 390;\n}\n\n.font-weight-391 {\n  font-weight: 391;\n}\n\n.font-weight-392 {\n  font-weight: 392;\n}\n\n.font-weight-393 {\n  font-weight: 393;\n}\n\n.font-weight-394 {\n  font-weight: 394;\n}\n\n.font-weight-395 {\n  font-weight: 395;\n}\n\n.font-weight-396 {\n  font-weight: 396;\n}\n\n.font-weight-397 {\n  font-weight: 397;\n}\n\n.font-weight-398 {\n  font-weight: 398;\n}\n\n.font-weight-399 {\n  font-weight: 399;\n}\n\n.font-weight-400 {\n  font-weight: 400;\n}\n\n.font-weight-401 {\n  font-weight: 401;\n}\n\n.font-weight-402 {\n  font-weight: 402;\n}\n\n.font-weight-403 {\n  font-weight: 403;\n}\n\n.font-weight-404 {\n  font-weight: 404;\n}\n\n.font-weight-405 {\n  font-weight: 405;\n}\n\n.font-weight-406 {\n  font-weight: 406;\n}\n\n.font-weight-407 {\n  font-weight: 407;\n}\n\n.font-weight-408 {\n  font-weight: 408;\n}\n\n.font-weight-409 {\n  font-weight: 409;\n}\n\n.font-weight-410 {\n  font-weight: 410;\n}\n\n.font-weight-411 {\n  font-weight: 411;\n}\n\n.font-weight-412 {\n  font-weight: 412;\n}\n\n.font-weight-413 {\n  font-weight: 413;\n}\n\n.font-weight-414 {\n  font-weight: 414;\n}\n\n.font-weight-415 {\n  font-weight: 415;\n}\n\n.font-weight-416 {\n  font-weight: 416;\n}\n\n.font-weight-417 {\n  font-weight: 417;\n}\n\n.font-weight-418 {\n  font-weight: 418;\n}\n\n.font-weight-419 {\n  font-weight: 419;\n}\n\n.font-weight-420 {\n  font-weight: 420;\n}\n\n.font-weight-421 {\n  font-weight: 421;\n}\n\n.font-weight-422 {\n  font-weight: 422;\n}\n\n.font-weight-423 {\n  font-weight: 423;\n}\n\n.font-weight-424 {\n  font-weight: 424;\n}\n\n.font-weight-425 {\n  font-weight: 425;\n}\n\n.font-weight-426 {\n  font-weight: 426;\n}\n\n.font-weight-427 {\n  font-weight: 427;\n}\n\n.font-weight-428 {\n  font-weight: 428;\n}\n\n.font-weight-429 {\n  font-weight: 429;\n}\n\n.font-weight-430 {\n  font-weight: 430;\n}\n\n.font-weight-431 {\n  font-weight: 431;\n}\n\n.font-weight-432 {\n  font-weight: 432;\n}\n\n.font-weight-433 {\n  font-weight: 433;\n}\n\n.font-weight-434 {\n  font-weight: 434;\n}\n\n.font-weight-435 {\n  font-weight: 435;\n}\n\n.font-weight-436 {\n  font-weight: 436;\n}\n\n.font-weight-437 {\n  font-weight: 437;\n}\n\n.font-weight-438 {\n  font-weight: 438;\n}\n\n.font-weight-439 {\n  font-weight: 439;\n}\n\n.font-weight-440 {\n  font-weight: 440;\n}\n\n.font-weight-441 {\n  font-weight: 441;\n}\n\n.font-weight-442 {\n  font-weight: 442;\n}\n\n.font-weight-443 {\n  font-weight: 443;\n}\n\n.font-weight-444 {\n  font-weight: 444;\n}\n\n.font-weight-445 {\n  font-weight: 445;\n}\n\n.font-weight-446 {\n  font-weight: 446;\n}\n\n.font-weight-447 {\n  font-weight: 447;\n}\n\n.font-weight-448 {\n  font-weight: 448;\n}\n\n.font-weight-449 {\n  font-weight: 449;\n}\n\n.font-weight-450 {\n  font-weight: 450;\n}\n\n.font-weight-451 {\n  font-weight: 451;\n}\n\n.font-weight-452 {\n  font-weight: 452;\n}\n\n.font-weight-453 {\n  font-weight: 453;\n}\n\n.font-weight-454 {\n  font-weight: 454;\n}\n\n.font-weight-455 {\n  font-weight: 455;\n}\n\n.font-weight-456 {\n  font-weight: 456;\n}\n\n.font-weight-457 {\n  font-weight: 457;\n}\n\n.font-weight-458 {\n  font-weight: 458;\n}\n\n.font-weight-459 {\n  font-weight: 459;\n}\n\n.font-weight-460 {\n  font-weight: 460;\n}\n\n.font-weight-461 {\n  font-weight: 461;\n}\n\n.font-weight-462 {\n  font-weight: 462;\n}\n\n.font-weight-463 {\n  font-weight: 463;\n}\n\n.font-weight-464 {\n  font-weight: 464;\n}\n\n.font-weight-465 {\n  font-weight: 465;\n}\n\n.font-weight-466 {\n  font-weight: 466;\n}\n\n.font-weight-467 {\n  font-weight: 467;\n}\n\n.font-weight-468 {\n  font-weight: 468;\n}\n\n.font-weight-469 {\n  font-weight: 469;\n}\n\n.font-weight-470 {\n  font-weight: 470;\n}\n\n.font-weight-471 {\n  font-weight: 471;\n}\n\n.font-weight-472 {\n  font-weight: 472;\n}\n\n.font-weight-473 {\n  font-weight: 473;\n}\n\n.font-weight-474 {\n  font-weight: 474;\n}\n\n.font-weight-475 {\n  font-weight: 475;\n}\n\n.font-weight-476 {\n  font-weight: 476;\n}\n\n.font-weight-477 {\n  font-weight: 477;\n}\n\n.font-weight-478 {\n  font-weight: 478;\n}\n\n.font-weight-479 {\n  font-weight: 479;\n}\n\n.font-weight-480 {\n  font-weight: 480;\n}\n\n.font-weight-481 {\n  font-weight: 481;\n}\n\n.font-weight-482 {\n  font-weight: 482;\n}\n\n.font-weight-483 {\n  font-weight: 483;\n}\n\n.font-weight-484 {\n  font-weight: 484;\n}\n\n.font-weight-485 {\n  font-weight: 485;\n}\n\n.font-weight-486 {\n  font-weight: 486;\n}\n\n.font-weight-487 {\n  font-weight: 487;\n}\n\n.font-weight-488 {\n  font-weight: 488;\n}\n\n.font-weight-489 {\n  font-weight: 489;\n}\n\n.font-weight-490 {\n  font-weight: 490;\n}\n\n.font-weight-491 {\n  font-weight: 491;\n}\n\n.font-weight-492 {\n  font-weight: 492;\n}\n\n.font-weight-493 {\n  font-weight: 493;\n}\n\n.font-weight-494 {\n  font-weight: 494;\n}\n\n.font-weight-495 {\n  font-weight: 495;\n}\n\n.font-weight-496 {\n  font-weight: 496;\n}\n\n.font-weight-497 {\n  font-weight: 497;\n}\n\n.font-weight-498 {\n  font-weight: 498;\n}\n\n.font-weight-499 {\n  font-weight: 499;\n}\n\n.font-weight-500 {\n  font-weight: 500;\n}\n\n.font-weight-501 {\n  font-weight: 501;\n}\n\n.font-weight-502 {\n  font-weight: 502;\n}\n\n.font-weight-503 {\n  font-weight: 503;\n}\n\n.font-weight-504 {\n  font-weight: 504;\n}\n\n.font-weight-505 {\n  font-weight: 505;\n}\n\n.font-weight-506 {\n  font-weight: 506;\n}\n\n.font-weight-507 {\n  font-weight: 507;\n}\n\n.font-weight-508 {\n  font-weight: 508;\n}\n\n.font-weight-509 {\n  font-weight: 509;\n}\n\n.font-weight-510 {\n  font-weight: 510;\n}\n\n.font-weight-511 {\n  font-weight: 511;\n}\n\n.font-weight-512 {\n  font-weight: 512;\n}\n\n.font-weight-513 {\n  font-weight: 513;\n}\n\n.font-weight-514 {\n  font-weight: 514;\n}\n\n.font-weight-515 {\n  font-weight: 515;\n}\n\n.font-weight-516 {\n  font-weight: 516;\n}\n\n.font-weight-517 {\n  font-weight: 517;\n}\n\n.font-weight-518 {\n  font-weight: 518;\n}\n\n.font-weight-519 {\n  font-weight: 519;\n}\n\n.font-weight-520 {\n  font-weight: 520;\n}\n\n.font-weight-521 {\n  font-weight: 521;\n}\n\n.font-weight-522 {\n  font-weight: 522;\n}\n\n.font-weight-523 {\n  font-weight: 523;\n}\n\n.font-weight-524 {\n  font-weight: 524;\n}\n\n.font-weight-525 {\n  font-weight: 525;\n}\n\n.font-weight-526 {\n  font-weight: 526;\n}\n\n.font-weight-527 {\n  font-weight: 527;\n}\n\n.font-weight-528 {\n  font-weight: 528;\n}\n\n.font-weight-529 {\n  font-weight: 529;\n}\n\n.font-weight-530 {\n  font-weight: 530;\n}\n\n.font-weight-531 {\n  font-weight: 531;\n}\n\n.font-weight-532 {\n  font-weight: 532;\n}\n\n.font-weight-533 {\n  font-weight: 533;\n}\n\n.font-weight-534 {\n  font-weight: 534;\n}\n\n.font-weight-535 {\n  font-weight: 535;\n}\n\n.font-weight-536 {\n  font-weight: 536;\n}\n\n.font-weight-537 {\n  font-weight: 537;\n}\n\n.font-weight-538 {\n  font-weight: 538;\n}\n\n.font-weight-539 {\n  font-weight: 539;\n}\n\n.font-weight-540 {\n  font-weight: 540;\n}\n\n.font-weight-541 {\n  font-weight: 541;\n}\n\n.font-weight-542 {\n  font-weight: 542;\n}\n\n.font-weight-543 {\n  font-weight: 543;\n}\n\n.font-weight-544 {\n  font-weight: 544;\n}\n\n.font-weight-545 {\n  font-weight: 545;\n}\n\n.font-weight-546 {\n  font-weight: 546;\n}\n\n.font-weight-547 {\n  font-weight: 547;\n}\n\n.font-weight-548 {\n  font-weight: 548;\n}\n\n.font-weight-549 {\n  font-weight: 549;\n}\n\n.font-weight-550 {\n  font-weight: 550;\n}\n\n.font-weight-551 {\n  font-weight: 551;\n}\n\n.font-weight-552 {\n  font-weight: 552;\n}\n\n.font-weight-553 {\n  font-weight: 553;\n}\n\n.font-weight-554 {\n  font-weight: 554;\n}\n\n.font-weight-555 {\n  font-weight: 555;\n}\n\n.font-weight-556 {\n  font-weight: 556;\n}\n\n.font-weight-557 {\n  font-weight: 557;\n}\n\n.font-weight-558 {\n  font-weight: 558;\n}\n\n.font-weight-559 {\n  font-weight: 559;\n}\n\n.font-weight-560 {\n  font-weight: 560;\n}\n\n.font-weight-561 {\n  font-weight: 561;\n}\n\n.font-weight-562 {\n  font-weight: 562;\n}\n\n.font-weight-563 {\n  font-weight: 563;\n}\n\n.font-weight-564 {\n  font-weight: 564;\n}\n\n.font-weight-565 {\n  font-weight: 565;\n}\n\n.font-weight-566 {\n  font-weight: 566;\n}\n\n.font-weight-567 {\n  font-weight: 567;\n}\n\n.font-weight-568 {\n  font-weight: 568;\n}\n\n.font-weight-569 {\n  font-weight: 569;\n}\n\n.font-weight-570 {\n  font-weight: 570;\n}\n\n.font-weight-571 {\n  font-weight: 571;\n}\n\n.font-weight-572 {\n  font-weight: 572;\n}\n\n.font-weight-573 {\n  font-weight: 573;\n}\n\n.font-weight-574 {\n  font-weight: 574;\n}\n\n.font-weight-575 {\n  font-weight: 575;\n}\n\n.font-weight-576 {\n  font-weight: 576;\n}\n\n.font-weight-577 {\n  font-weight: 577;\n}\n\n.font-weight-578 {\n  font-weight: 578;\n}\n\n.font-weight-579 {\n  font-weight: 579;\n}\n\n.font-weight-580 {\n  font-weight: 580;\n}\n\n.font-weight-581 {\n  font-weight: 581;\n}\n\n.font-weight-582 {\n  font-weight: 582;\n}\n\n.font-weight-583 {\n  font-weight: 583;\n}\n\n.font-weight-584 {\n  font-weight: 584;\n}\n\n.font-weight-585 {\n  font-weight: 585;\n}\n\n.font-weight-586 {\n  font-weight: 586;\n}\n\n.font-weight-587 {\n  font-weight: 587;\n}\n\n.font-weight-588 {\n  font-weight: 588;\n}\n\n.font-weight-589 {\n  font-weight: 589;\n}\n\n.font-weight-590 {\n  font-weight: 590;\n}\n\n.font-weight-591 {\n  font-weight: 591;\n}\n\n.font-weight-592 {\n  font-weight: 592;\n}\n\n.font-weight-593 {\n  font-weight: 593;\n}\n\n.font-weight-594 {\n  font-weight: 594;\n}\n\n.font-weight-595 {\n  font-weight: 595;\n}\n\n.font-weight-596 {\n  font-weight: 596;\n}\n\n.font-weight-597 {\n  font-weight: 597;\n}\n\n.font-weight-598 {\n  font-weight: 598;\n}\n\n.font-weight-599 {\n  font-weight: 599;\n}\n\n.font-weight-600 {\n  font-weight: 600;\n}\n\n.font-weight-601 {\n  font-weight: 601;\n}\n\n.font-weight-602 {\n  font-weight: 602;\n}\n\n.font-weight-603 {\n  font-weight: 603;\n}\n\n.font-weight-604 {\n  font-weight: 604;\n}\n\n.font-weight-605 {\n  font-weight: 605;\n}\n\n.font-weight-606 {\n  font-weight: 606;\n}\n\n.font-weight-607 {\n  font-weight: 607;\n}\n\n.font-weight-608 {\n  font-weight: 608;\n}\n\n.font-weight-609 {\n  font-weight: 609;\n}\n\n.font-weight-610 {\n  font-weight: 610;\n}\n\n.font-weight-611 {\n  font-weight: 611;\n}\n\n.font-weight-612 {\n  font-weight: 612;\n}\n\n.font-weight-613 {\n  font-weight: 613;\n}\n\n.font-weight-614 {\n  font-weight: 614;\n}\n\n.font-weight-615 {\n  font-weight: 615;\n}\n\n.font-weight-616 {\n  font-weight: 616;\n}\n\n.font-weight-617 {\n  font-weight: 617;\n}\n\n.font-weight-618 {\n  font-weight: 618;\n}\n\n.font-weight-619 {\n  font-weight: 619;\n}\n\n.font-weight-620 {\n  font-weight: 620;\n}\n\n.font-weight-621 {\n  font-weight: 621;\n}\n\n.font-weight-622 {\n  font-weight: 622;\n}\n\n.font-weight-623 {\n  font-weight: 623;\n}\n\n.font-weight-624 {\n  font-weight: 624;\n}\n\n.font-weight-625 {\n  font-weight: 625;\n}\n\n.font-weight-626 {\n  font-weight: 626;\n}\n\n.font-weight-627 {\n  font-weight: 627;\n}\n\n.font-weight-628 {\n  font-weight: 628;\n}\n\n.font-weight-629 {\n  font-weight: 629;\n}\n\n.font-weight-630 {\n  font-weight: 630;\n}\n\n.font-weight-631 {\n  font-weight: 631;\n}\n\n.font-weight-632 {\n  font-weight: 632;\n}\n\n.font-weight-633 {\n  font-weight: 633;\n}\n\n.font-weight-634 {\n  font-weight: 634;\n}\n\n.font-weight-635 {\n  font-weight: 635;\n}\n\n.font-weight-636 {\n  font-weight: 636;\n}\n\n.font-weight-637 {\n  font-weight: 637;\n}\n\n.font-weight-638 {\n  font-weight: 638;\n}\n\n.font-weight-639 {\n  font-weight: 639;\n}\n\n.font-weight-640 {\n  font-weight: 640;\n}\n\n.font-weight-641 {\n  font-weight: 641;\n}\n\n.font-weight-642 {\n  font-weight: 642;\n}\n\n.font-weight-643 {\n  font-weight: 643;\n}\n\n.font-weight-644 {\n  font-weight: 644;\n}\n\n.font-weight-645 {\n  font-weight: 645;\n}\n\n.font-weight-646 {\n  font-weight: 646;\n}\n\n.font-weight-647 {\n  font-weight: 647;\n}\n\n.font-weight-648 {\n  font-weight: 648;\n}\n\n.font-weight-649 {\n  font-weight: 649;\n}\n\n.font-weight-650 {\n  font-weight: 650;\n}\n\n.font-weight-651 {\n  font-weight: 651;\n}\n\n.font-weight-652 {\n  font-weight: 652;\n}\n\n.font-weight-653 {\n  font-weight: 653;\n}\n\n.font-weight-654 {\n  font-weight: 654;\n}\n\n.font-weight-655 {\n  font-weight: 655;\n}\n\n.font-weight-656 {\n  font-weight: 656;\n}\n\n.font-weight-657 {\n  font-weight: 657;\n}\n\n.font-weight-658 {\n  font-weight: 658;\n}\n\n.font-weight-659 {\n  font-weight: 659;\n}\n\n.font-weight-660 {\n  font-weight: 660;\n}\n\n.font-weight-661 {\n  font-weight: 661;\n}\n\n.font-weight-662 {\n  font-weight: 662;\n}\n\n.font-weight-663 {\n  font-weight: 663;\n}\n\n.font-weight-664 {\n  font-weight: 664;\n}\n\n.font-weight-665 {\n  font-weight: 665;\n}\n\n.font-weight-666 {\n  font-weight: 666;\n}\n\n.font-weight-667 {\n  font-weight: 667;\n}\n\n.font-weight-668 {\n  font-weight: 668;\n}\n\n.font-weight-669 {\n  font-weight: 669;\n}\n\n.font-weight-670 {\n  font-weight: 670;\n}\n\n.font-weight-671 {\n  font-weight: 671;\n}\n\n.font-weight-672 {\n  font-weight: 672;\n}\n\n.font-weight-673 {\n  font-weight: 673;\n}\n\n.font-weight-674 {\n  font-weight: 674;\n}\n\n.font-weight-675 {\n  font-weight: 675;\n}\n\n.font-weight-676 {\n  font-weight: 676;\n}\n\n.font-weight-677 {\n  font-weight: 677;\n}\n\n.font-weight-678 {\n  font-weight: 678;\n}\n\n.font-weight-679 {\n  font-weight: 679;\n}\n\n.font-weight-680 {\n  font-weight: 680;\n}\n\n.font-weight-681 {\n  font-weight: 681;\n}\n\n.font-weight-682 {\n  font-weight: 682;\n}\n\n.font-weight-683 {\n  font-weight: 683;\n}\n\n.font-weight-684 {\n  font-weight: 684;\n}\n\n.font-weight-685 {\n  font-weight: 685;\n}\n\n.font-weight-686 {\n  font-weight: 686;\n}\n\n.font-weight-687 {\n  font-weight: 687;\n}\n\n.font-weight-688 {\n  font-weight: 688;\n}\n\n.font-weight-689 {\n  font-weight: 689;\n}\n\n.font-weight-690 {\n  font-weight: 690;\n}\n\n.font-weight-691 {\n  font-weight: 691;\n}\n\n.font-weight-692 {\n  font-weight: 692;\n}\n\n.font-weight-693 {\n  font-weight: 693;\n}\n\n.font-weight-694 {\n  font-weight: 694;\n}\n\n.font-weight-695 {\n  font-weight: 695;\n}\n\n.font-weight-696 {\n  font-weight: 696;\n}\n\n.font-weight-697 {\n  font-weight: 697;\n}\n\n.font-weight-698 {\n  font-weight: 698;\n}\n\n.font-weight-699 {\n  font-weight: 699;\n}\n\n.font-weight-700 {\n  font-weight: 700;\n}\n\n.font-weight-701 {\n  font-weight: 701;\n}\n\n.font-weight-702 {\n  font-weight: 702;\n}\n\n.font-weight-703 {\n  font-weight: 703;\n}\n\n.font-weight-704 {\n  font-weight: 704;\n}\n\n.font-weight-705 {\n  font-weight: 705;\n}\n\n.font-weight-706 {\n  font-weight: 706;\n}\n\n.font-weight-707 {\n  font-weight: 707;\n}\n\n.font-weight-708 {\n  font-weight: 708;\n}\n\n.font-weight-709 {\n  font-weight: 709;\n}\n\n.font-weight-710 {\n  font-weight: 710;\n}\n\n.font-weight-711 {\n  font-weight: 711;\n}\n\n.font-weight-712 {\n  font-weight: 712;\n}\n\n.font-weight-713 {\n  font-weight: 713;\n}\n\n.font-weight-714 {\n  font-weight: 714;\n}\n\n.font-weight-715 {\n  font-weight: 715;\n}\n\n.font-weight-716 {\n  font-weight: 716;\n}\n\n.font-weight-717 {\n  font-weight: 717;\n}\n\n.font-weight-718 {\n  font-weight: 718;\n}\n\n.font-weight-719 {\n  font-weight: 719;\n}\n\n.font-weight-720 {\n  font-weight: 720;\n}\n\n.font-weight-721 {\n  font-weight: 721;\n}\n\n.font-weight-722 {\n  font-weight: 722;\n}\n\n.font-weight-723 {\n  font-weight: 723;\n}\n\n.font-weight-724 {\n  font-weight: 724;\n}\n\n.font-weight-725 {\n  font-weight: 725;\n}\n\n.font-weight-726 {\n  font-weight: 726;\n}\n\n.font-weight-727 {\n  font-weight: 727;\n}\n\n.font-weight-728 {\n  font-weight: 728;\n}\n\n.font-weight-729 {\n  font-weight: 729;\n}\n\n.font-weight-730 {\n  font-weight: 730;\n}\n\n.font-weight-731 {\n  font-weight: 731;\n}\n\n.font-weight-732 {\n  font-weight: 732;\n}\n\n.font-weight-733 {\n  font-weight: 733;\n}\n\n.font-weight-734 {\n  font-weight: 734;\n}\n\n.font-weight-735 {\n  font-weight: 735;\n}\n\n.font-weight-736 {\n  font-weight: 736;\n}\n\n.font-weight-737 {\n  font-weight: 737;\n}\n\n.font-weight-738 {\n  font-weight: 738;\n}\n\n.font-weight-739 {\n  font-weight: 739;\n}\n\n.font-weight-740 {\n  font-weight: 740;\n}\n\n.font-weight-741 {\n  font-weight: 741;\n}\n\n.font-weight-742 {\n  font-weight: 742;\n}\n\n.font-weight-743 {\n  font-weight: 743;\n}\n\n.font-weight-744 {\n  font-weight: 744;\n}\n\n.font-weight-745 {\n  font-weight: 745;\n}\n\n.font-weight-746 {\n  font-weight: 746;\n}\n\n.font-weight-747 {\n  font-weight: 747;\n}\n\n.font-weight-748 {\n  font-weight: 748;\n}\n\n.font-weight-749 {\n  font-weight: 749;\n}\n\n.font-weight-750 {\n  font-weight: 750;\n}\n\n.font-weight-751 {\n  font-weight: 751;\n}\n\n.font-weight-752 {\n  font-weight: 752;\n}\n\n.font-weight-753 {\n  font-weight: 753;\n}\n\n.font-weight-754 {\n  font-weight: 754;\n}\n\n.font-weight-755 {\n  font-weight: 755;\n}\n\n.font-weight-756 {\n  font-weight: 756;\n}\n\n.font-weight-757 {\n  font-weight: 757;\n}\n\n.font-weight-758 {\n  font-weight: 758;\n}\n\n.font-weight-759 {\n  font-weight: 759;\n}\n\n.font-weight-760 {\n  font-weight: 760;\n}\n\n.font-weight-761 {\n  font-weight: 761;\n}\n\n.font-weight-762 {\n  font-weight: 762;\n}\n\n.font-weight-763 {\n  font-weight: 763;\n}\n\n.font-weight-764 {\n  font-weight: 764;\n}\n\n.font-weight-765 {\n  font-weight: 765;\n}\n\n.font-weight-766 {\n  font-weight: 766;\n}\n\n.font-weight-767 {\n  font-weight: 767;\n}\n\n.font-weight-768 {\n  font-weight: 768;\n}\n\n.font-weight-769 {\n  font-weight: 769;\n}\n\n.font-weight-770 {\n  font-weight: 770;\n}\n\n.font-weight-771 {\n  font-weight: 771;\n}\n\n.font-weight-772 {\n  font-weight: 772;\n}\n\n.font-weight-773 {\n  font-weight: 773;\n}\n\n.font-weight-774 {\n  font-weight: 774;\n}\n\n.font-weight-775 {\n  font-weight: 775;\n}\n\n.font-weight-776 {\n  font-weight: 776;\n}\n\n.font-weight-777 {\n  font-weight: 777;\n}\n\n.font-weight-778 {\n  font-weight: 778;\n}\n\n.font-weight-779 {\n  font-weight: 779;\n}\n\n.font-weight-780 {\n  font-weight: 780;\n}\n\n.font-weight-781 {\n  font-weight: 781;\n}\n\n.font-weight-782 {\n  font-weight: 782;\n}\n\n.font-weight-783 {\n  font-weight: 783;\n}\n\n.font-weight-784 {\n  font-weight: 784;\n}\n\n.font-weight-785 {\n  font-weight: 785;\n}\n\n.font-weight-786 {\n  font-weight: 786;\n}\n\n.font-weight-787 {\n  font-weight: 787;\n}\n\n.font-weight-788 {\n  font-weight: 788;\n}\n\n.font-weight-789 {\n  font-weight: 789;\n}\n\n.font-weight-790 {\n  font-weight: 790;\n}\n\n.font-weight-791 {\n  font-weight: 791;\n}\n\n.font-weight-792 {\n  font-weight: 792;\n}\n\n.font-weight-793 {\n  font-weight: 793;\n}\n\n.font-weight-794 {\n  font-weight: 794;\n}\n\n.font-weight-795 {\n  font-weight: 795;\n}\n\n.font-weight-796 {\n  font-weight: 796;\n}\n\n.font-weight-797 {\n  font-weight: 797;\n}\n\n.font-weight-798 {\n  font-weight: 798;\n}\n\n.font-weight-799 {\n  font-weight: 799;\n}\n\n.font-weight-800 {\n  font-weight: 800;\n}\n\n.font-weight-801 {\n  font-weight: 801;\n}\n\n.font-weight-802 {\n  font-weight: 802;\n}\n\n.font-weight-803 {\n  font-weight: 803;\n}\n\n.font-weight-804 {\n  font-weight: 804;\n}\n\n.font-weight-805 {\n  font-weight: 805;\n}\n\n.font-weight-806 {\n  font-weight: 806;\n}\n\n.font-weight-807 {\n  font-weight: 807;\n}\n\n.font-weight-808 {\n  font-weight: 808;\n}\n\n.font-weight-809 {\n  font-weight: 809;\n}\n\n.font-weight-810 {\n  font-weight: 810;\n}\n\n.font-weight-811 {\n  font-weight: 811;\n}\n\n.font-weight-812 {\n  font-weight: 812;\n}\n\n.font-weight-813 {\n  font-weight: 813;\n}\n\n.font-weight-814 {\n  font-weight: 814;\n}\n\n.font-weight-815 {\n  font-weight: 815;\n}\n\n.font-weight-816 {\n  font-weight: 816;\n}\n\n.font-weight-817 {\n  font-weight: 817;\n}\n\n.font-weight-818 {\n  font-weight: 818;\n}\n\n.font-weight-819 {\n  font-weight: 819;\n}\n\n.font-weight-820 {\n  font-weight: 820;\n}\n\n.font-weight-821 {\n  font-weight: 821;\n}\n\n.font-weight-822 {\n  font-weight: 822;\n}\n\n.font-weight-823 {\n  font-weight: 823;\n}\n\n.font-weight-824 {\n  font-weight: 824;\n}\n\n.font-weight-825 {\n  font-weight: 825;\n}\n\n.font-weight-826 {\n  font-weight: 826;\n}\n\n.font-weight-827 {\n  font-weight: 827;\n}\n\n.font-weight-828 {\n  font-weight: 828;\n}\n\n.font-weight-829 {\n  font-weight: 829;\n}\n\n.font-weight-830 {\n  font-weight: 830;\n}\n\n.font-weight-831 {\n  font-weight: 831;\n}\n\n.font-weight-832 {\n  font-weight: 832;\n}\n\n.font-weight-833 {\n  font-weight: 833;\n}\n\n.font-weight-834 {\n  font-weight: 834;\n}\n\n.font-weight-835 {\n  font-weight: 835;\n}\n\n.font-weight-836 {\n  font-weight: 836;\n}\n\n.font-weight-837 {\n  font-weight: 837;\n}\n\n.font-weight-838 {\n  font-weight: 838;\n}\n\n.font-weight-839 {\n  font-weight: 839;\n}\n\n.font-weight-840 {\n  font-weight: 840;\n}\n\n.font-weight-841 {\n  font-weight: 841;\n}\n\n.font-weight-842 {\n  font-weight: 842;\n}\n\n.font-weight-843 {\n  font-weight: 843;\n}\n\n.font-weight-844 {\n  font-weight: 844;\n}\n\n.font-weight-845 {\n  font-weight: 845;\n}\n\n.font-weight-846 {\n  font-weight: 846;\n}\n\n.font-weight-847 {\n  font-weight: 847;\n}\n\n.font-weight-848 {\n  font-weight: 848;\n}\n\n.font-weight-849 {\n  font-weight: 849;\n}\n\n.font-weight-850 {\n  font-weight: 850;\n}\n\n.font-weight-851 {\n  font-weight: 851;\n}\n\n.font-weight-852 {\n  font-weight: 852;\n}\n\n.font-weight-853 {\n  font-weight: 853;\n}\n\n.font-weight-854 {\n  font-weight: 854;\n}\n\n.font-weight-855 {\n  font-weight: 855;\n}\n\n.font-weight-856 {\n  font-weight: 856;\n}\n\n.font-weight-857 {\n  font-weight: 857;\n}\n\n.font-weight-858 {\n  font-weight: 858;\n}\n\n.font-weight-859 {\n  font-weight: 859;\n}\n\n.font-weight-860 {\n  font-weight: 860;\n}\n\n.font-weight-861 {\n  font-weight: 861;\n}\n\n.font-weight-862 {\n  font-weight: 862;\n}\n\n.font-weight-863 {\n  font-weight: 863;\n}\n\n.font-weight-864 {\n  font-weight: 864;\n}\n\n.font-weight-865 {\n  font-weight: 865;\n}\n\n.font-weight-866 {\n  font-weight: 866;\n}\n\n.font-weight-867 {\n  font-weight: 867;\n}\n\n.font-weight-868 {\n  font-weight: 868;\n}\n\n.font-weight-869 {\n  font-weight: 869;\n}\n\n.font-weight-870 {\n  font-weight: 870;\n}\n\n.font-weight-871 {\n  font-weight: 871;\n}\n\n.font-weight-872 {\n  font-weight: 872;\n}\n\n.font-weight-873 {\n  font-weight: 873;\n}\n\n.font-weight-874 {\n  font-weight: 874;\n}\n\n.font-weight-875 {\n  font-weight: 875;\n}\n\n.font-weight-876 {\n  font-weight: 876;\n}\n\n.font-weight-877 {\n  font-weight: 877;\n}\n\n.font-weight-878 {\n  font-weight: 878;\n}\n\n.font-weight-879 {\n  font-weight: 879;\n}\n\n.font-weight-880 {\n  font-weight: 880;\n}\n\n.font-weight-881 {\n  font-weight: 881;\n}\n\n.font-weight-882 {\n  font-weight: 882;\n}\n\n.font-weight-883 {\n  font-weight: 883;\n}\n\n.font-weight-884 {\n  font-weight: 884;\n}\n\n.font-weight-885 {\n  font-weight: 885;\n}\n\n.font-weight-886 {\n  font-weight: 886;\n}\n\n.font-weight-887 {\n  font-weight: 887;\n}\n\n.font-weight-888 {\n  font-weight: 888;\n}\n\n.font-weight-889 {\n  font-weight: 889;\n}\n\n.font-weight-890 {\n  font-weight: 890;\n}\n\n.font-weight-891 {\n  font-weight: 891;\n}\n\n.font-weight-892 {\n  font-weight: 892;\n}\n\n.font-weight-893 {\n  font-weight: 893;\n}\n\n.font-weight-894 {\n  font-weight: 894;\n}\n\n.font-weight-895 {\n  font-weight: 895;\n}\n\n.font-weight-896 {\n  font-weight: 896;\n}\n\n.font-weight-897 {\n  font-weight: 897;\n}\n\n.font-weight-898 {\n  font-weight: 898;\n}\n\n.font-weight-899 {\n  font-weight: 899;\n}\n\n.font-weight-900 {\n  font-weight: 900;\n}\n\n.text-small {\n  font-size: .75rem;\n}\n\n.p-readable {\n  max-width: 650px;\n}\n\n.section-info {\n  font-size: 14px;\n  color: #6B7280;\n}\n\n.heading {\n  color: #0e0a16;\n  font-weight: 700;\n}\n\n.br {\n  margin: 10px 0;\n}\n\n.text-mute {\n  color: #6B7280;\n}\n\n.display-content {\n  margin: 20px 0;\n}\n\n.display-1 {\n  font-size: 6rem;\n  font-weight: 300;\n  line-height: 1.2;\n}\n\n.display-2 {\n  font-size: 5.5rem;\n  font-weight: 300;\n  line-height: 1.2;\n}\n\n.display-3 {\n  font-size: 4.5rem;\n  font-weight: 300;\n  line-height: 1.2;\n}\n\n.lead {\n  font-size: 1.25rem;\n  font-weight: 300;\n}\n\n.t-font-bold {\n  font-weight: 500 !important;\n}\n\n.t-font-bolder {\n  font-weight: 600 !important;\n}\n\n.t-font-boldest {\n  font-weight: 700 !important;\n}\n\n.t-font-u {\n  text-transform: uppercase;\n}\n\n.blockquote {\n  margin-bottom: 1rem;\n  font-size: 1.25rem;\n}\n\n.blockquote-footer {\n  display: block;\n  font-size: 80%;\n  color: #6B7280;\n}\n\na.typo_link {\n  position: relative;\n}\n\na.typo_link:hover {\n  color: #6366f1;\n}\n\na.typo_link:hover:after {\n  width: 100%;\n}\n\na.typo_link:after {\n  display: block;\n  position: absolute;\n  content: \"\";\n  width: 0%;\n  height: 1px;\n  left: 0;\n  bottom: -4px;\n  transition: width 0.3s ease;\n}\n\na.typo_link.text-primary:after {\n  background-color: #8b5cf6;\n}\n\na.typo_link.text-secondary:after {\n  background-color: #1F2937;\n}\n\na.typo_link.text-success:after {\n  background-color: #10b981;\n}\n\na.typo_link.text-info:after {\n  background-color: #3b82f6;\n}\n\na.typo_link.text-warning:after {\n  background-color: #f59e0b;\n}\n\na.typo_link.text-danger:after {\n  background-color: #ef4444;\n}\n\na.typo_link.text-light:after {\n  background-color: #6B7280;\n}\n\na.typo_link.text-dark:after {\n  background-color: #111827;\n}\n\na.typo_link.text-gray-100:after {\n  background-color: #F3F4F6;\n}\n\na.typo_link.text-gray-200:after {\n  background-color: #E5E7EB;\n}\n\na.typo_link.text-gray-300:after {\n  background-color: #D1D5DB;\n}\n\na.typo_link.text-gray-400:after {\n  background-color: #9CA3AF;\n}\n\na.typo_link.text-gray-500:after {\n  background-color: #6B7280;\n}\n\na.typo_link.text-gray-600:after {\n  background-color: #4B5563;\n}\n\na.typo_link.text-gray-700:after {\n  background-color: #374151;\n}\n\na.typo_link.text-gray-800:after {\n  background-color: #1F2937;\n}\n\na.typo_link.text-gray-900:after {\n  background-color: #111827;\n}\n\n.divider {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n}\n\n.divider > span:first-child {\n  width: 100%;\n  height: 1px;\n  background: #E5E7EB;\n  display: inline-block;\n  flex: 1;\n}\n\n.divider > span:last-child {\n  width: 100%;\n  height: 1px;\n  background: #E5E7EB;\n  display: inline-block;\n  flex: 1;\n}\n\n.divider > span:not(:first-child):not(:last-child) {\n  padding: 0 2rem;\n}\n\n.cursor-pointer {\n  cursor: pointer !important;\n}\n\n.quantity_alert_warehouse {\n  width: 200px;\n}\n\n.menu-icon-language {\n  padding: 0 8px;\n  display: flex;\n  flex-wrap: wrap;\n}\n\n.menu-icon-language > a {\n  display: inline-flex;\n  width: 6rem;\n  flex-direction: column;\n  align-items: center;\n  padding: 18px 12px;\n  color: #1F2937;\n  border-radius: 4px;\n  cursor: pointer;\n}\n\n.menu-icon-language > a i {\n  font-size: 28px;\n  margin-bottom: 4px;\n}\n\n.menu-icon-language > a:hover {\n  background: #8b5cf6;\n}\n\n.barcodea4 {\n  width: 8.25in;\n  height: 11.6in;\n  display: block;\n  border: 1px solid #CCC;\n  margin: 10px auto;\n  padding: 0.1in 0 0 0.1in;\n  page-break-after: always;\n}\n\n.barcode_non_a4 {\n  width: 8.45in;\n  height: 10.3in;\n  display: block;\n  border: 1px solid #CCC;\n  margin: 10px auto;\n  padding-top: 0.1in;\n  page-break-after: always;\n}\n\n.barcode_non_a4 .barcode-item {\n  display: block;\n  overflow: hidden;\n  text-align: center;\n  border: 1px dotted #CCC;\n  font-size: 12px;\n  line-height: 14px;\n  text-transform: uppercase;\n  float: left;\n}\n\n.barcode_non_a4 .barcode-name {\n  display: block;\n}\n\n.barcodea4 .barcode-name {\n  display: block;\n}\n\n.barcodea4 .style24 .barcode-name {\n  font-size: 14px;\n}\n\n.barcodea4 .style18 .barcode-name {\n  font-size: 14px;\n}\n\n.barcodea4 .style12 .barcode-name {\n  font-size: 15px;\n}\n\n.barcode_non_a4 .barcode-name {\n  font-size: 14px;\n}\n\n.barcode_non_a4 .style10 .barcode-name {\n  font-size: 16px;\n}\n\n.barcodea4 .barcode-item {\n  display: block;\n  overflow: hidden;\n  text-align: center;\n  border: 1px dotted #CCC;\n  font-size: 12px;\n  line-height: 14px;\n  text-transform: uppercase;\n  float: left;\n}\n\n.barcodea4 .style40 {\n  width: 1.799in;\n  height: 1.003in;\n  margin: 0 0.07in;\n  padding-top: 0.05in;\n}\n\n.barcode_non_a4 .style30 {\n  width: 2.625in;\n  height: 1in;\n  margin: 0 0.07in;\n  padding-top: 0.05in;\n}\n\n.barcode_non_a4 .style30:nth-child(3n+1) {\n  margin-left: 0.1in;\n}\n\n.barcodea4 .style24 {\n  width: 2.48in;\n  height: 1.335in;\n  margin-left: 0.079in;\n  padding-top: 0.05in;\n}\n\n.barcode_non_a4 .style20 {\n  width: 4in;\n  height: 1in;\n  margin: 0 0.1in;\n  padding-top: 0.05in;\n}\n\n.barcodea4 .style18 {\n  width: 2.5in;\n  height: 1.835in;\n  margin-left: 0.079in;\n  padding-top: 0.05in;\n  font-size: 13px;\n  line-height: 20px;\n}\n\n.barcode_non_a4 .style14 {\n  width: 4in;\n  height: 1.33in;\n  margin: 0 0.1in;\n  padding-top: 0.1in;\n}\n\n.barcodea4 .style12 {\n  width: 2.5in;\n  height: 2.834in;\n  margin-left: 0.079in;\n  padding-top: 0.05in;\n  font-size: 14px;\n  line-height: 20px;\n}\n\n.barcode_non_a4 .style10 {\n  width: 4in;\n  height: 2in;\n  margin: 0 0.1in;\n  padding-top: 0.1in;\n  font-size: 14px;\n  line-height: 20px;\n}\n\n@media print {\n  .barcode_non_a4, .barcodea4 {\n    margin: 0;\n  }\n}\n\n.box-shadow-1 {\n  box-shadow: 0 1px 15px 1px rgba(0, 0, 0, 0.04), 0 1px 6px rgba(0, 0, 0, 0.04);\n}\n\n.box-shadow-2 {\n  box-shadow: 0 1px 15px 1px rgba(0, 0, 0, 0.24), 0 1px 6px rgba(0, 0, 0, 0.04);\n}\n\n.layout-sidebar-compact .main-header {\n  position: absolute !important;\n  width: 100%;\n  left: 0;\n  box-shadow: none;\n  display: flex;\n  align-items: center;\n  flex-wrap: wrap;\n  justify-content: space-between;\n  background: transparent;\n  z-index: 100;\n  transition: width 0.24s ease-in-out;\n}\n\n.layout-sidebar-compact .main-header .logo {\n  display: none;\n}\n\n.layout-sidebar-compact .main-header button.dropdown-toggle {\n  padding: 0px !important;\n}\n\n.layout-sidebar-compact .main-header .header-part-right .dropdown-menu.show {\n  left: -60px !important;\n}\n\n.main-header {\n  position: fixed;\n  height: 80px;\n  display: flex;\n  align-items: center;\n  flex-wrap: wrap;\n  justify-content: space-between;\n  background: #fff;\n  z-index: 100;\n}\n\n.main-header .menu-toggle {\n  width: 90px;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  cursor: pointer;\n  margin-right: 12px;\n}\n\n.main-header .menu-toggle div {\n  width: 24px;\n  height: 1px;\n  background: #111827;\n  margin: 3px 0;\n}\n\n.main-header .search-bar {\n  display: flex;\n  align-items: center;\n  justify-content: left;\n  background: #F3F4F6;\n  border: 1px solid #E5E7EB;\n  border-radius: 20px;\n  position: relative;\n  width: 230px;\n  height: 40px;\n}\n\n.main-header .search-bar input {\n  background: transparent;\n  border: 0;\n  color: #212121;\n  font-size: 0.8rem;\n  line-height: 2;\n  height: 100%;\n  outline: initial !important;\n  padding: 0.5rem 1rem;\n  width: calc(100% - 32px);\n}\n\n.main-header .search-bar .search-icon {\n  font-size: 18px;\n  width: 24px;\n  display: inline-block;\n}\n\n.main-header .logo {\n  width: 76px;\n}\n\n.main-header .logo img {\n  width: 60px;\n  height: 60px;\n  margin: 0 auto;\n  display: block;\n}\n\n.main-header .header-icon {\n  font-size: 19px;\n  cursor: pointer;\n  height: 36px;\n  width: 36px;\n  line-height: 36px;\n  display: inline-block;\n  text-align: center;\n  border-radius: 8px;\n  margin: 0 2px;\n}\n\n.main-header .header-icon:hover {\n  background: #F3F4F6;\n}\n\n.main-header .header-icon.dropdown-toggle:after {\n  display: none;\n}\n\n.main-header .header-part-right {\n  display: flex;\n  align-items: center;\n}\n\n.main-header .header-part-right .user {\n  margin-right: 2rem;\n}\n\n.main-header .header-part-right .user img {\n  width: 36px;\n  height: 36px;\n  border-radius: 50%;\n}\n\n.main-header .notification-dropdown {\n  padding: 0;\n  max-height: 260px;\n  cursor: pointer;\n}\n\n.main-header .notification-dropdown .dropdown-item {\n  display: flex;\n  align-items: center;\n  padding: 0;\n  height: 72px;\n  border-bottom: 1px solid #D1D5DB;\n}\n\n.main-header .notification-dropdown .dropdown-item .notification-icon {\n  background: #E5E7EB;\n  height: 100%;\n  width: 44px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n.main-header .notification-dropdown .dropdown-item .notification-icon i {\n  font-size: 18px;\n}\n\n.main-header .notification-dropdown .dropdown-item .notification-details {\n  padding: 0.25rem 0.75rem;\n}\n\n.main-header .notification-dropdown .dropdown-item:active {\n  color: inherit;\n  background: inherit;\n}\n\n@media (max-width: 1024px) {\n  .main-header .search-bar {\n    width: 180px;\n    display: none;\n  }\n  .main-header .menu-toggle {\n    width: 24px;\n    margin: 0 36px;\n  }\n  .main-header .header-part-right .user {\n    margin-right: 1rem;\n  }\n}\n\n@media (max-width: 790px) {\n  .main-header .search-bar {\n    display: none;\n  }\n  .main-header .menu-toggle {\n    width: 24px;\n    margin-right: 36px;\n  }\n}\n\n@media (max-width: 576px) {\n  .main-header {\n    height: 70px;\n    padding: 0 1.5rem;\n  }\n  .main-header .logo {\n    width: 60px;\n  }\n  .main-header .menu-toggle {\n    width: 24px !important;\n    margin: 0 10px !important;\n  }\n  .main-header .header-part-right .user {\n    margin-right: 0;\n    padding-right: 0;\n  }\n  .notification-dropdown {\n    left: -180px !important;\n  }\n}\n\n@media (max-width: 360px) {\n  .main-header .menu-toggle {\n    margin: 0;\n  }\n}\n\n.layout-sidebar-compact.app-admin-wrap {\n  width: 100%;\n}\n\n.layout-sidebar-compact.sidenav-open .main-content-wrap {\n  width: calc(\r 100% - 76px - 220px);\n}\n\n.layout-sidebar-compact.sidenav-open .sidebar-left {\n  left: 0;\n}\n\n.layout-sidebar-compact .main-content-wrap {\n  width: 100%;\n  float: right;\n  margin-top: 0;\n  transition: width 0.24s ease-in-out;\n  padding: 0 2rem;\n  position: relative;\n  min-height: calc(100vh - 80px);\n  background: #fff;\n}\n\n.layout-sidebar-compact .main-content {\n  margin-top: 104px;\n  display: flex;\n  flex-direction: column;\n  min-height: calc(100vh - 104px);\n}\n\n.layout-sidebar-compact .sidebar-left-secondary,\n.layout-sidebar-compact .sidebar-left {\n  position: fixed;\n  top: 0;\n  height: 100%;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.08);\n  z-index: 100;\n}\n\n.layout-sidebar-compact .sidebar-left {\n  left: calc(-76px - 20px);\n  transition: left 0.24s ease-in-out;\n}\n\n.layout-sidebar-compact .sidebar-left .logo {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  height: 68px;\n  border-bottom: 1px solid rgba(243, 244, 246, 0.05);\n}\n\n.layout-sidebar-compact .sidebar-left .logo img {\n  width: 40px;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left {\n  list-style: none;\n  text-align: center;\n  width: 76px;\n  height: 100%;\n  margin: 0;\n  padding: 0;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item {\n  position: relative;\n  display: block;\n  width: 100%;\n  color: #fff;\n  cursor: pointer;\n  border-bottom: 1px solid rgba(243, 244, 246, 0.05);\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item:focus, .layout-sidebar-compact .sidebar-left .navigation-left .nav-item:active {\n  outline: none;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item.lvl1 {\n  text-align: center;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item.active {\n  color: #fff;\n  border-left: 2px solid #fff;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item .nav-item-hold {\n  width: 100%;\n  padding: 22px 0;\n  display: block;\n  color: #ffffff;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item .nav-item-hold:focus, .layout-sidebar-compact .sidebar-left .navigation-left .nav-item .nav-item-hold:active {\n  outline: none;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item .nav-item-hold .nav-icon,\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item .nav-item-hold .feather {\n  font-size: 24px;\n  height: 24px;\n  width: 24px;\n  display: block;\n  margin: 0 auto;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item .nav-item-hold .nav-text {\n  display: none;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item .nav-item-hold a {\n  color: #fff;\n}\n\n.layout-sidebar-compact .sidebar-left .navigation-left .nav-item.active .triangle {\n  display: none;\n}\n\n.layout-sidebar-compact.sidenav-open .sidebar-left-secondary {\n  left: 76px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary {\n  left: calc(-220px - 20px);\n  width: 220px;\n  padding: 0.75rem 0;\n  transition: left 0.24s ease-in-out;\n  background: #fff;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .sidebar-close {\n  display: none;\n  position: absolute;\n  top: 0;\n  right: 0;\n  font-size: 18px;\n  padding: 16px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary header {\n  padding: 0px 24px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary header .logo {\n  padding: 10px 0;\n  margin-bottom: 14px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary header .logo img {\n  width: auto;\n  height: 24px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary header h6 {\n  font-size: 18px;\n  margin-bottom: 4px;\n  font-weight: 600;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary header p {\n  color: #4B5563;\n  margin-bottom: 12px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .submenu-area {\n  display: none;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav {\n  list-style: none;\n  padding: 0;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item {\n  display: block;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a {\n  color: #05070b;\n  text-transform: capitalize;\n  display: flex;\n  align-items: center;\n  font-size: 13px;\n  cursor: pointer;\n  padding: 12px 24px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a:hover {\n  background: #E5E7EB;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a.open {\n  color: #8b5cf6;\n  background: #E5E7EB;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a.open .nav-icon {\n  color: #8b5cf6;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a .nav-icon {\n  font-size: 18px;\n  margin-right: 8px;\n  vertical-align: middle;\n  color: #4B5563;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a .item-name {\n  vertical-align: middle;\n  font-weight: 400;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a .dd-arrow {\n  margin-left: auto;\n  font-size: 11px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item .submenu {\n  margin-left: 8px;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary > .childNav {\n  margin: 0;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary li.nav-item.open > div > a > .dd-arrow {\n  transform: rotate(90deg);\n}\n\n.layout-sidebar-compact .sidebar-left-secondary li.nav-item.open > div > .childNav {\n  max-height: 1000px;\n  overflow: visible;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary li.nav-item > div > a > .dd-arrow {\n  transition: all 0.4s ease-in-out;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary li.nav-item > div > .childNav {\n  max-height: 0;\n  overflow: hidden;\n  background: #fff;\n  transition: all 0.4s ease-in-out;\n}\n\n.layout-sidebar-compact .sidebar-left-secondary li.nav-item > div > .childNav li.nav-item a {\n  padding: 12px 12px 12px 50px;\n}\n\n.layout-sidebar-compact .sidebar-overlay {\n  display: none;\n  position: fixed;\n  width: calc(\r 100% - 76px - 220px);\n  height: calc(100vh - 80px);\n  bottom: 0;\n  right: 0;\n  background: rgba(0, 0, 0, 0);\n  z-index: 101;\n  cursor: w-resize;\n}\n\n.layout-sidebar-compact .sidebar-overlay.open {\n  display: block;\n}\n\n@media (max-width: 1200px) {\n  .layout-sidebar-compact.sidenav-open .main-content-wrap {\n    width: 100%;\n  }\n  .layout-sidebar-compact .sidebar-left-secondary .sidebar-close {\n    display: block;\n  }\n  .layout-sidebar-compact .sidebar-left-secondary,\n  .layout-sidebar-compact .sidebar-left {\n    z-index: 101;\n  }\n}\n\n@media (max-width: 576px) {\n  .main-content-wrap {\n    padding: 1.5rem;\n  }\n  .main-content-wrap.sidenav-open {\n    width: 100%;\n  }\n  .main-content-wrap {\n    margin-top: 70px;\n  }\n  .sidebar-left-secondary,\n  .sidebar-left {\n    top: 70px;\n    height: calc(100vh - 70px);\n  }\n  .sidebar-left {\n    left: calc(-90px - 20px);\n  }\n  .sidebar-left .navigation-left {\n    width: 90px;\n  }\n  .sidebar-left .navigation-left .nav-item.active .triangle {\n    border-width: 0 0 24px 24px;\n  }\n  .sidebar-left .navigation-left .nav-item .nav-item-hold {\n    padding: 16px 0;\n  }\n  .sidebar-left-secondary {\n    left: calc(-190px - 20px);\n    width: 190px;\n  }\n  .sidebar-left-secondary.open {\n    left: 90px;\n  }\n  .sidebar-overlay {\n    height: calc(100vh - 70px);\n  }\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact .sidebar-left {\n  left: auto !important;\n  right: calc(-76px - 20px);\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact.sidenav-open .sidebar-left {\n  left: auto !important;\n  right: 0;\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact.sidenav-open .sidebar-left-secondary {\n  right: 76px;\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact .sidebar-left-secondary {\n  left: auto !important;\n  right: calc(-220px - 20px);\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact .sidebar-left-secondary header {\n  text-align: right;\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a .dd-arrow {\n  margin-left: unset !important;\n  margin-right: auto;\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a .nav-icon {\n  margin-left: 8px;\n  margin-right: 0;\n}\n\n[dir=\"rtl\"] .layout-sidebar-compact .main-content-wrap {\n  float: left;\n}\n\n.layout-sidebar-large .main-header {\n  position: fixed;\n  width: 100%;\n  height: 80px;\n  box-shadow: 0 1px 15px rgba(0, 0, 0, 0.04), 0 1px 6px rgba(0, 0, 0, 0.04);\n  display: flex;\n  align-items: center;\n  flex-wrap: wrap;\n  justify-content: space-between;\n  background: #fff;\n  z-index: 100;\n}\n\n.layout-sidebar-large .main-header .menu-toggle {\n  width: 90px;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  cursor: pointer;\n  margin-right: 12px;\n}\n\n.layout-sidebar-large .main-header .menu-toggle div {\n  width: 24px;\n  height: 1px;\n  background: #111827;\n  margin: 3px 0;\n}\n\n.layout-sidebar-large .main-header .search-bar {\n  display: flex;\n  align-items: center;\n  justify-content: left;\n  background: #F3F4F6;\n  border: 1px solid #E5E7EB;\n  border-radius: 20px;\n  position: relative;\n  width: 230px;\n  height: 40px;\n}\n\n.layout-sidebar-large .main-header .search-bar input {\n  background: transparent;\n  border: 0;\n  color: #212121;\n  font-size: 0.8rem;\n  line-height: 2;\n  height: 100%;\n  outline: initial !important;\n  padding: 0.5rem 1rem;\n  width: calc(100% - 32px);\n}\n\n.layout-sidebar-large .main-header .search-bar .search-icon {\n  font-size: 18px;\n  width: 24px;\n  display: inline-block;\n}\n\n.layout-sidebar-large .main-header .logo {\n  width: 120px;\n}\n\n.layout-sidebar-large .main-header .logo img {\n  width: 60px;\n  height: 60px;\n  margin: 0 auto;\n  display: block;\n}\n\n.layout-sidebar-large .main-header .header-icon {\n  font-size: 19px;\n  cursor: pointer;\n  height: 36px;\n  width: 36px;\n  line-height: 36px;\n  display: inline-block;\n  text-align: center;\n  border-radius: 8px;\n  margin: 0 2px;\n}\n\n.layout-sidebar-large .main-header .header-icon:hover {\n  background: #F3F4F6;\n}\n\n.layout-sidebar-large .main-header .header-icon.dropdown-toggle:after {\n  display: none;\n}\n\n.layout-sidebar-large .main-header .header-part-right {\n  display: flex;\n  align-items: center;\n}\n\n.layout-sidebar-large .main-header .header-part-right .user {\n  margin-right: 2rem;\n}\n\n.layout-sidebar-large .main-header .header-part-right .user img {\n  width: 36px;\n  height: 36px;\n  border-radius: 50%;\n}\n\n.layout-sidebar-large .main-header .notification-dropdown {\n  padding: 0;\n  max-height: 260px;\n  cursor: pointer;\n}\n\n.layout-sidebar-large .main-header .notification-dropdown .dropdown-item {\n  display: flex;\n  align-items: center;\n  padding: 0;\n  height: 72px;\n  border-bottom: 1px solid #D1D5DB;\n}\n\n.layout-sidebar-large .main-header .notification-dropdown .dropdown-item .notification-icon {\n  background: #E5E7EB;\n  height: 100%;\n  width: 44px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n.layout-sidebar-large .main-header .notification-dropdown .dropdown-item .notification-icon i {\n  font-size: 18px;\n}\n\n.layout-sidebar-large .main-header .notification-dropdown .dropdown-item .notification-details {\n  padding: 0.25rem 0.75rem;\n}\n\n.layout-sidebar-large .main-header .notification-dropdown .dropdown-item:active {\n  color: inherit;\n  background: inherit;\n}\n\n.layout-sidebar-large .main-header button.dropdown-toggle {\n  padding: 0px !important;\n}\n\n@media (max-width: 991px) {\n  .layout-sidebar-large .main-header .search-bar {\n    width: 180px;\n  }\n  .layout-sidebar-large .main-header .menu-toggle {\n    width: 24px;\n    margin-right: 36px;\n  }\n}\n\n@media (max-width: 790px) {\n  .layout-sidebar-large .main-header .search-bar {\n    display: none;\n  }\n  .layout-sidebar-large .main-header .switch {\n    display: none;\n  }\n  .layout-sidebar-large .main-header .menu-toggle {\n    width: 24px;\n    margin-right: 36px;\n  }\n}\n\n@media (max-width: 576px) {\n  .layout-sidebar-large .main-header {\n    height: 70px;\n    padding: 0 1.5rem;\n  }\n  .layout-sidebar-large .main-header .logo {\n    width: 60px;\n  }\n  .layout-sidebar-large .main-header .search-bar {\n    display: none;\n  }\n  .layout-sidebar-large .main-header .menu-toggle {\n    width: 60px;\n  }\n  .layout-sidebar-large .main-header .header-part-right .user {\n    margin-right: 0;\n    padding-right: 0;\n  }\n  .layout-sidebar-large .notification-dropdown {\n    left: -0px !important;\n  }\n}\n\n@media (max-width: 360px) {\n  .layout-sidebar-large .main-header .menu-toggle {\n    margin: 0;\n  }\n}\n\n.app-admin-wrap {\n  width: 100%;\n}\n\n.layout-sidebar-large .main-content-wrap {\n  width: 100%;\n  float: right;\n  margin-top: 80px;\n  transition: width 0.24s ease-in-out;\n  padding: 2rem 2rem 0;\n  position: relative;\n  min-height: calc(100vh - 80px);\n  background: #fff;\n}\n\n.layout-sidebar-large .main-content-wrap.sidenav-open {\n  width: calc(100% - 120px);\n}\n\n.layout-sidebar-large .sidebar-left-secondary,\n.layout-sidebar-large .sidebar-left {\n  position: fixed;\n  top: 80px;\n  height: calc(100vh - 80px);\n  background: #fff;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.08);\n}\n\n.layout-sidebar-large .sidebar-left {\n  left: calc(-120px - 20px);\n  z-index: 90;\n  transition: left 0.24s ease-in-out;\n}\n\n.layout-sidebar-large .sidebar-left.open {\n  left: 0;\n}\n\n.layout-sidebar-large .sidebar-left .logo {\n  display: none;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left {\n  list-style: none;\n  text-align: center;\n  width: 120px;\n  height: 100%;\n  margin: 0;\n  padding: 0;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item {\n  position: relative;\n  display: block;\n  width: 100%;\n  color: #05070b;\n  cursor: pointer;\n  border-bottom: 1px solid #D1D5DB;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item:focus, .layout-sidebar-large .sidebar-left .navigation-left .nav-item:active {\n  outline: none;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item.lvl1 {\n  text-align: center;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item.active {\n  color: #8b5cf6;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item.active .nav-item-hold {\n  color: #8b5cf6;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item .nav-item-hold {\n  display: block;\n  width: 100%;\n  padding: 26px 0;\n  color: #111827;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item .nav-item-hold:focus, .layout-sidebar-large .sidebar-left .navigation-left .nav-item .nav-item-hold:active {\n  outline: none;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item .nav-item-hold .nav-icon,\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item .nav-item-hold .feather {\n  font-size: 32px;\n  height: 32px;\n  width: 32px;\n  display: block;\n  margin: 0 auto 6px;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item .nav-item-hold .nav-text {\n  font-size: 13px;\n  display: block;\n  font-weight: 400;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item .nav-item-hold a {\n  color: #05070b;\n}\n\n.layout-sidebar-large .sidebar-left .navigation-left .nav-item.active .triangle {\n  position: absolute;\n  width: 0;\n  height: 0;\n  right: 0;\n  bottom: 0;\n  border-style: solid;\n  border-width: 0 0 30px 30px;\n  border-color: transparent transparent #8b5cf6 transparent;\n}\n\n.layout-sidebar-large .sidebar-left-secondary {\n  left: calc(-220px - 20px);\n  z-index: 89;\n  width: 220px;\n  padding: 0.75rem 0;\n  transition: left 0.24s ease-in-out;\n  background: #fff;\n}\n\n.layout-sidebar-large .sidebar-left-secondary.open {\n  left: 120px;\n}\n\n.layout-sidebar-large .sidebar-left-secondary header {\n  display: none;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav {\n  list-style: none;\n  padding: 0;\n  display: none;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item {\n  display: block;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a {\n  color: #05070b;\n  text-transform: capitalize;\n  display: flex;\n  align-items: center;\n  font-size: 13px;\n  cursor: pointer;\n  padding: 12px 24px;\n  transition: 0.15s all ease-in;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a:hover {\n  background: #E5E7EB;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a.open {\n  color: #8b5cf6;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a.open .nav-icon {\n  color: #8b5cf6;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a.router-link-active {\n  color: #8b5cf6;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a.router-link-active .nav-icon {\n  color: #8b5cf6;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a .nav-icon {\n  font-size: 18px;\n  margin-right: 8px;\n  vertical-align: middle;\n  color: #4B5563;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a .item-name {\n  vertical-align: middle;\n  font-weight: 400;\n}\n\n.layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a .dd-arrow {\n  margin-left: auto;\n  font-size: 11px;\n  transition: all 0.3s ease-in;\n}\n\n.layout-sidebar-large .sidebar-left-secondary > .childNav {\n  margin: 0;\n}\n\n.layout-sidebar-large .sidebar-left-secondary li.nav-item.open > div > a > .dd-arrow {\n  transform: rotate(90deg);\n}\n\n.layout-sidebar-large .sidebar-left-secondary li.nav-item.open > div > .childNav {\n  max-height: 1000px;\n  overflow: visible;\n}\n\n.layout-sidebar-large .sidebar-left-secondary li.nav-item > div > a > .dd-arrow {\n  transition: all 0.4s ease-in-out;\n}\n\n.layout-sidebar-large .sidebar-left-secondary li.nav-item > div > .childNav {\n  max-height: 0;\n  overflow: hidden;\n  background: #fff;\n  transition: all 0.4s ease-in-out;\n}\n\n.layout-sidebar-large .sidebar-left-secondary li.nav-item > div > .childNav li.nav-item a {\n  padding: 12px 12px 12px 50px;\n}\n\n.layout-sidebar-large .sidebar-overlay {\n  display: none;\n  position: fixed;\n  width: calc(\r 100% - 120px - 220px);\n  height: calc(100vh - 80px);\n  bottom: 0;\n  right: 0;\n  background: rgba(0, 0, 0, 0);\n  z-index: 101;\n  cursor: w-resize;\n}\n\n.layout-sidebar-large .sidebar-overlay.open {\n  display: block;\n}\n\n.module-loader {\n  position: fixed;\n  background: rgba(255, 255, 255, 0.5);\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100vh;\n  z-index: 9;\n}\n\n.module-loader .loader,\n.module-loader .spinner {\n  position: fixed;\n  top: 45%;\n  left: calc(50% + 56px);\n  z-index: inherit;\n}\n\n@media (max-width: 1200px) {\n  .layout-sidebar-large .main-content-wrap.sidenav-open {\n    width: 100%;\n  }\n}\n\n@media (max-width: 576px) {\n  .main-content-wrap {\n    padding: 1.5rem;\n  }\n  .main-content-wrap.sidenav-open {\n    width: 100%;\n  }\n  .main-content-wrap {\n    margin-top: 70px;\n  }\n  .sidebar-left-secondary,\n  .sidebar-left {\n    top: 70px !important;\n    height: calc(100vh - 70px) !important;\n  }\n  .sidebar-left {\n    left: calc(-90px - 20px);\n  }\n  .sidebar-left .navigation-left {\n    width: 90px;\n  }\n  .sidebar-left .navigation-left .nav-item.active .triangle {\n    border-width: 0 0 24px 24px;\n  }\n  .sidebar-left .navigation-left .nav-item .nav-item-hold {\n    padding: 16px 0;\n  }\n  .sidebar-left-secondary {\n    left: calc(-190px - 20px);\n    width: 190px;\n  }\n  .sidebar-left-secondary.open {\n    left: 90px;\n  }\n  .sidebar-overlay {\n    height: calc(100vh - 70px);\n  }\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-left {\n  left: auto !important;\n  right: calc(-120px - 20px);\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-left.open {\n  left: auto !important;\n  right: 0;\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-left .navigation-left .nav-item .triangle {\n  transform: rotate(90deg);\n  right: auto;\n  left: 0;\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-left-secondary {\n  left: auto !important;\n  right: calc(-220px - 20px);\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-left-secondary.open {\n  left: auto !important;\n  right: 120px;\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a .dd-arrow {\n  margin-left: unset !important;\n  margin-right: auto;\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-left-secondary .childNav li.nav-item a .nav-icon {\n  margin-left: 8px;\n  margin-right: 0;\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .main-content-wrap {\n  float: left;\n}\n\n[dir=\"rtl\"] .layout-sidebar-large .sidebar-overlay {\n  right: auto !important;\n  left: 0;\n  cursor: e-resize;\n}\n\n.app-footer {\n  margin-top: 2rem;\n  background: #F3F4F6;\n  padding: 1.25rem;\n  border-top-left-radius: 10px;\n  border-top-right-radius: 10px;\n}\n\n.app-footer .footer-bottom {\n  width: 100%;\n}\n\n.app-footer .footer-bottom .btn {\n  position: fixed;\n  bottom: 30px;\n  right: 60px;\n}\n\n.app-footer .footer-bottom .logo {\n  width: 3rem;\n  height: auto;\n  margin: 4px;\n}\n\n.sidebar-left-secondary .childNav li.nav-item.open > a {\n  background: #E5E7EB;\n}\n\n.sidebar-left-secondary .childNav li.nav-item.open > a > .dd-arrow {\n  transform: rotate(90deg);\n}\n\n.sidebar-left-secondary .childNav li.nav-item.open > .submenu {\n  max-height: 1000px;\n}\n\n.sidebar-left-secondary .childNav li.nav-item .submenu {\n  margin: 0;\n  padding: 0;\n  list-style: none;\n  max-height: 0;\n  overflow: hidden;\n  transition: all 0.3s ease-in;\n}\n\n.sidebar-left-secondary .childNav li.nav-item .submenu > li a {\n  padding-left: 50px;\n}\n\n[dir=\"rtl\"] .notification-dropdown .dropdown-item .notification-details {\n  text-align: right;\n}\n\n[dir=\"rtl\"] .main-header .user {\n  margin-left: 2rem;\n  margin-right: 0;\n}\n\n[role=\"tab\"] .btn {\n  width: 100%;\n  text-align: left;\n}\n\n[role=\"tab\"] .btn:hover, [role=\"tab\"] .btn:focus {\n  text-decoration: none;\n}\n\n.accordion > .card {\n  overflow: hidden;\n}\n\n.avatar-sm {\n  width: 36px;\n  height: 36px;\n}\n\n.avatar-md {\n  width: 54px;\n  height: 54px;\n}\n\n.avatar-lg {\n  width: 80px;\n  height: 80px;\n}\n\n.avatar-xl {\n  width: 150px;\n  height: 150px;\n}\n\n.avatar-sm-table {\n  width: 20px;\n  height: 20px;\n}\n\n.border-bottom-primary {\n  border-bottom: 1px solid #8b5cf6;\n}\n\n.border-bottom-secondary {\n  border-bottom: 1px solid #1F2937;\n}\n\n.border-bottom-success {\n  border-bottom: 1px solid #10b981;\n}\n\n.border-bottom-info {\n  border-bottom: 1px solid #3b82f6;\n}\n\n.border-bottom-warning {\n  border-bottom: 1px solid #f59e0b;\n}\n\n.border-bottom-danger {\n  border-bottom: 1px solid #ef4444;\n}\n\n.border-bottom-light {\n  border-bottom: 1px solid #6B7280;\n}\n\n.border-bottom-dark {\n  border-bottom: 1px solid #111827;\n}\n\n.border-bottom-gray-100 {\n  border-bottom: 1px solid #F3F4F6;\n}\n\n.border-bottom-gray-200 {\n  border-bottom: 1px solid #E5E7EB;\n}\n\n.border-bottom-gray-300 {\n  border-bottom: 1px solid #D1D5DB;\n}\n\n.border-bottom-gray-400 {\n  border-bottom: 1px solid #9CA3AF;\n}\n\n.border-bottom-gray-500 {\n  border-bottom: 1px solid #6B7280;\n}\n\n.border-bottom-gray-600 {\n  border-bottom: 1px solid #4B5563;\n}\n\n.border-bottom-gray-700 {\n  border-bottom: 1px solid #374151;\n}\n\n.border-bottom-gray-800 {\n  border-bottom: 1px solid #1F2937;\n}\n\n.border-bottom-gray-900 {\n  border-bottom: 1px solid #111827;\n}\n\n.border-bottom-dotted-primary {\n  border-bottom: 1px dotted #8b5cf6;\n}\n\n.border-bottom-dotted-secondary {\n  border-bottom: 1px dotted #1F2937;\n}\n\n.border-bottom-dotted-success {\n  border-bottom: 1px dotted #10b981;\n}\n\n.border-bottom-dotted-info {\n  border-bottom: 1px dotted #3b82f6;\n}\n\n.border-bottom-dotted-warning {\n  border-bottom: 1px dotted #f59e0b;\n}\n\n.border-bottom-dotted-danger {\n  border-bottom: 1px dotted #ef4444;\n}\n\n.border-bottom-dotted-light {\n  border-bottom: 1px dotted #6B7280;\n}\n\n.border-bottom-dotted-dark {\n  border-bottom: 1px dotted #111827;\n}\n\n.border-bottom-dotted-gray-100 {\n  border-bottom: 1px dotted #F3F4F6;\n}\n\n.border-bottom-dotted-gray-200 {\n  border-bottom: 1px dotted #E5E7EB;\n}\n\n.border-bottom-dotted-gray-300 {\n  border-bottom: 1px dotted #D1D5DB;\n}\n\n.border-bottom-dotted-gray-400 {\n  border-bottom: 1px dotted #9CA3AF;\n}\n\n.border-bottom-dotted-gray-500 {\n  border-bottom: 1px dotted #6B7280;\n}\n\n.border-bottom-dotted-gray-600 {\n  border-bottom: 1px dotted #4B5563;\n}\n\n.border-bottom-dotted-gray-700 {\n  border-bottom: 1px dotted #374151;\n}\n\n.border-bottom-dotted-gray-800 {\n  border-bottom: 1px dotted #1F2937;\n}\n\n.border-bottom-dotted-gray-900 {\n  border-bottom: 1px dotted #111827;\n}\n\n.card {\n  border-radius: 10px;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.08);\n  border: 0;\n}\n\n.card.border-top {\n  box-shadow: 0 4px 15px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.1), inset 0 2px 0 0 #10b981;\n}\n\n.card-header, .card-footer {\n  border-color: rgba(0, 0, 0, 0.03);\n}\n\n.card-title {\n  font-size: 1.1rem;\n  margin-bottom: 1.5rem;\n}\n\n.card-img-overlay * {\n  position: relative;\n  z-index: 1;\n}\n\n.card-img-overlay:after {\n  position: absolute;\n  content: \"\";\n  top: 0;\n  left: 0;\n  right: 0;\n  margin: auto;\n  height: 100%;\n  width: 100%;\n  background: rgba(0, 0, 0, 0.36);\n  z-index: 0;\n}\n\n.card-img-overlay .separator {\n  width: 35px;\n  margin: auto;\n}\n\n.card-img-overlay .card-footer {\n  position: absolute;\n  bottom: 16px;\n  left: 20px;\n  border: 0;\n  background: transparent;\n}\n\n.card-img-overlay .card-footer [class^=\"i-\"] {\n  font-size: .875rem;\n  vertical-align: text-bottom;\n}\n\n.card-icon .card-body {\n  padding: 2rem .5rem;\n}\n\n.card-icon [class^=\"i-\"] {\n  font-size: 32px;\n}\n\n.card-icon [class^=\"i-\"], .card-icon .lead {\n  color: #8b5cf6;\n}\n\n.card-icon-big .card-body {\n  padding: 2rem .5rem;\n}\n\n.card-icon-big [class^=\"i-\"] {\n  font-size: 48px;\n}\n\n.card-icon-big [class^=\"i-\"] {\n  color: rgba(139, 92, 246, 0.6);\n}\n\n.card-icon-bg {\n  position: relative;\n  z-index: 1;\n}\n\n.card-icon-bg .card-body {\n  display: flex;\n}\n\n.card-icon-bg .card-body .content {\n  margin: auto;\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n}\n\n.card-icon-bg [class^=\"i-\"] {\n  font-size: 4rem;\n  color: rgba(107, 114, 128, 0.28);\n}\n\n.card-icon-bg .lead {\n  line-height: 1;\n}\n\n.card-icon-bg-primary [class^=\"i-\"] {\n  color: rgba(139, 92, 246, 0.28);\n}\n\n.card-icon-bg-secondary [class^=\"i-\"] {\n  color: rgba(31, 41, 55, 0.28);\n}\n\n.card-icon-bg-success [class^=\"i-\"] {\n  color: rgba(16, 185, 129, 0.28);\n}\n\n.card-icon-bg-info [class^=\"i-\"] {\n  color: rgba(59, 130, 246, 0.28);\n}\n\n.card-icon-bg-warning [class^=\"i-\"] {\n  color: rgba(245, 158, 11, 0.28);\n}\n\n.card-icon-bg-danger [class^=\"i-\"] {\n  color: rgba(239, 68, 68, 0.28);\n}\n\n.card-icon-bg-light [class^=\"i-\"] {\n  color: rgba(107, 114, 128, 0.28);\n}\n\n.card-icon-bg-dark [class^=\"i-\"] {\n  color: rgba(17, 24, 39, 0.28);\n}\n\n.card-icon-bg-gray-100 [class^=\"i-\"] {\n  color: rgba(243, 244, 246, 0.28);\n}\n\n.card-icon-bg-gray-200 [class^=\"i-\"] {\n  color: rgba(229, 231, 235, 0.28);\n}\n\n.card-icon-bg-gray-300 [class^=\"i-\"] {\n  color: rgba(209, 213, 219, 0.28);\n}\n\n.card-icon-bg-gray-400 [class^=\"i-\"] {\n  color: rgba(156, 163, 175, 0.28);\n}\n\n.card-icon-bg-gray-500 [class^=\"i-\"] {\n  color: rgba(107, 114, 128, 0.28);\n}\n\n.card-icon-bg-gray-600 [class^=\"i-\"] {\n  color: rgba(75, 85, 99, 0.28);\n}\n\n.card-icon-bg-gray-700 [class^=\"i-\"] {\n  color: rgba(55, 65, 81, 0.28);\n}\n\n.card-icon-bg-gray-800 [class^=\"i-\"] {\n  color: rgba(31, 41, 55, 0.28);\n}\n\n.card-icon-bg-gray-900 [class^=\"i-\"] {\n  color: rgba(17, 24, 39, 0.28);\n}\n\n.card-profile-1 .avatar {\n  width: 80px;\n  height: 80px;\n  overflow: hidden;\n  margin: auto;\n  border-radius: 50%;\n}\n\n.card-ecommerce-1 .card-body [class^=\"i-\"] {\n  display: block;\n  font-size: 78px;\n  color: #8b5cf6;\n}\n\n.card-ecommerce-2 .row {\n  margin: 0;\n}\n\n.card-ecommerce-2 .card-action, .card-ecommerce-2 .col {\n  padding: 1rem;\n}\n\n.card-ecommerce-2 .card-action {\n  position: relative;\n  display: flex;\n  align-items: center;\n}\n\n.card-ecommerce-2 .card-action .icon {\n  font-size: 22px;\n  height: 24px;\n  display: inline-block;\n  width: 24px;\n  line-height: 24px;\n  margin: 0 8px;\n  cursor: pointer;\n}\n\n.card-ecommerce-2 .card-action:before {\n  position: absolute;\n  content: \"\";\n  top: 0;\n  left: 0;\n  width: 1px;\n  height: 100%;\n  background: rgba(17, 24, 39, 0.1);\n}\n\n.card-ecommerce-3 .card-img-left {\n  height: 220px;\n  -o-object-fit: cover;\n     object-fit: cover;\n}\n\n.card-socials-simple a {\n  display: inline-block;\n  padding: 4px;\n}\n\n.card-zoom-in {\n  position: relative;\n  background-color: white;\n  transition: all 0.6s cubic-bezier(0.165, 0.84, 0.44, 1);\n}\n\n.card-zoom-in:after {\n  content: '';\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  top: 0;\n  left: 0;\n  border-radius: 5px;\n  opacity: 0;\n  box-shadow: 0 5px 15px rgba(0, 0, 0, 0.3);\n  transition: all 0.6s cubic-bezier(0.165, 0.84, 0.44, 1);\n}\n\n.card-zoom-in:hover {\n  transform: scale(1.2);\n}\n\n.card-zoom-in:hover:after {\n  opacity: 1;\n}\n\n@media screen and (max-width: 576px) {\n  .card-ecommerce-3 .card-img-left {\n    width: 100%;\n  }\n}\n\n#calendar {\n  float: right;\n  width: 100%;\n}\n\n#external-events h4 {\n  font-size: 16px;\n  margin-top: 0;\n  padding-top: 1em;\n}\n\n#external-events .fc-event {\n  margin: 2px 0;\n  cursor: move;\n}\n\n.create_event_wrap p {\n  margin: 1.5em 0;\n  font-size: 11px;\n  color: #666;\n}\n\n.create_event_wrap p input {\n  margin: 0;\n  vertical-align: middle;\n}\n\n.fc-event {\n  position: relative;\n  display: block;\n  font-size: .85em;\n  line-height: 1.3;\n  border-radius: 3px;\n  border: 0px solid #8b5cf6 !important;\n}\n\na.fc-day-grid-event {\n  background: #8b5cf6;\n  padding: 5px;\n}\n\nth.fc-day-header {\n  border-bottom-width: 2px;\n  padding: 10px 0px;\n  display: table-cell;\n  background: #F5F5F5;\n  font-size: 16px;\n  font-weight: bold;\n  text-align: center;\n}\n\ntd.fc-head-container {\n  padding: 0px !important;\n}\n\n.fc-toolbar h2 {\n  margin: 0;\n  font-weight: bold;\n}\n\nspan.fa {\n  font-family: 'iconsmind' !important;\n  speak: none;\n  font-style: normal;\n  font-weight: normal;\n  font-variant: normal;\n  text-transform: none;\n  line-height: 1;\n  -webkit-font-smoothing: antialiased;\n}\n\nspan.fa.fa-chevron-left:before {\n  content: \"\\F077\";\n}\n\nspan.fa.fa-chevron-right:before {\n  content: \"\\F07D\";\n}\n\n.breadcrumb {\n  background: transparent;\n  align-items: center;\n  margin: 0 0 1.25rem;\n  padding: 0;\n}\n\n.breadcrumb h1 {\n  font-size: 1.5rem;\n  line-height: 1;\n  margin: 0;\n}\n\n.breadcrumb ul {\n  list-style: none;\n  padding: 0;\n  margin: 0;\n}\n\n.breadcrumb ul li {\n  display: inline-block;\n  position: relative;\n  padding: 0 .5rem;\n  line-height: 1;\n  vertical-align: bottom;\n  color: #4B5563;\n}\n\n.breadcrumb ul li:after {\n  position: absolute;\n  top: -1px;\n  right: 0;\n  content: \"\";\n  height: 16px;\n  width: 1px;\n  background: #4B5563;\n  border-radius: 5px;\n}\n\n.breadcrumb ul li:last-child:after {\n  display: none;\n}\n\n.breadcrumb ul li a {\n  color: #05070b;\n}\n\n[dir=\"rtl\"] .breadcrumb h1 {\n  font-size: 1.5rem;\n  line-height: 1;\n  margin: 0;\n  margin-left: .5rem;\n}\n\n@media (max-width: 576px) {\n  .breadcrumb {\n    flex-direction: column;\n    align-items: flex-start;\n  }\n  .breadcrumb ul li:first-child {\n    padding-left: 0;\n  }\n}\n\nhtml [type=\"button\"],\n.btn[type=\"button\"] {\n  -webkit-appearance: none !important;\n}\n\n.btn {\n  padding: .5rem 1.25rem;\n}\n\n.btn.rounded, .btn.btn-rounded {\n  border-radius: 40px !important;\n}\n\n.btn.btn-xl {\n  padding: .75rem 2rem;\n  font-size: 1.18rem;\n}\n\n.btn:focus {\n  box-shadow: none;\n}\n\n.btn-secondary,\n.btn-raised-secondary {\n  color: #111827 !important;\n  background-color: #fff !important;\n}\n\n.btn-icon [class^=\"i-\"],\n.btn-icon .icon {\n  vertical-align: middle;\n  margin: 0 2px;\n  -webkit-font-smoothing: subpixel-antialiased;\n}\n\n.btn-icon.rounded-circle {\n  width: 44px;\n  height: 44px;\n  padding: 0;\n}\n\n.btn-icon-text [class^=\"i-\"],\n.btn-icon-text .icon {\n  vertical-align: middle;\n  margin: 0 2px;\n  -webkit-font-smoothing: subpixel-antialiased;\n}\n\n.btn-outline-email {\n  background: rgba(229, 231, 235, 0.6);\n}\n\n.btn-spinner {\n  width: 1em;\n  height: 1em;\n  background: transparent;\n  border-radius: 50%;\n  margin: 0 16px 0 0;\n  border: 2px solid transparent;\n}\n\n.btn-checkbox .checkbox, .btn-checkbox .radio {\n  display: inline;\n}\n\n.btn.btn-outline-light.btn-svg {\n  border-color: #374151;\n}\n\n.btn.btn-outline-light.btn-svg.active, .btn.btn-outline-light.btn-svg:hover {\n  background: #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.btn.btn-outline-light.btn-svg.active svg, .btn.btn-outline-light.btn-svg:hover svg {\n  fill: #ffffff;\n}\n\n.btn.btn-outline-light.btn-svg:focus {\n  box-shadow: none !important;\n}\n\n.btn-raised {\n  color: #fff;\n}\n\n.btn-primary,\n.btn-outline-primary {\n  border-color: #8b5cf6;\n}\n\n.btn-primary .btn-spinner,\n.btn-outline-primary .btn-spinner {\n  -webkit-animation: btn-glow-primary 1s ease infinite;\n          animation: btn-glow-primary 1s ease infinite;\n}\n\n.btn-primary:hover,\n.btn-outline-primary:hover {\n  background: #8b5cf6;\n  box-shadow: 0 8px 25px -8px #8b5cf6;\n  border-color: #8b5cf6;\n}\n\n.btn-primary:focus,\n.btn-outline-primary:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #8b5cf6;\n}\n\n.btn-raised.btn-raised-primary {\n  background: #8b5cf6;\n  box-shadow: 0 4px 6px rgba(139, 92, 246, 0.11), 0 1px 3px rgba(139, 92, 246, 0.08);\n}\n\n@-webkit-keyframes btn-glow-primary {\n  0% {\n    box-shadow: 0 0 0 0.4em #692cf3, 0 0 0 0.1em #692cf3;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #692cf3, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-primary {\n  0% {\n    box-shadow: 0 0 0 0.4em #692cf3, 0 0 0 0.1em #692cf3;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #692cf3, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-secondary,\n.btn-outline-secondary {\n  border-color: #1F2937;\n}\n\n.btn-secondary .btn-spinner,\n.btn-outline-secondary .btn-spinner {\n  -webkit-animation: btn-glow-secondary 1s ease infinite;\n          animation: btn-glow-secondary 1s ease infinite;\n}\n\n.btn-secondary:hover,\n.btn-outline-secondary:hover {\n  background: #1F2937;\n  box-shadow: 0 8px 25px -8px #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-secondary:focus,\n.btn-outline-secondary:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #1F2937;\n}\n\n.btn-raised.btn-raised-secondary {\n  background: #1F2937;\n  box-shadow: 0 4px 6px rgba(31, 41, 55, 0.11), 0 1px 3px rgba(31, 41, 55, 0.08);\n}\n\n@-webkit-keyframes btn-glow-secondary {\n  0% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 0.1em #0d1116;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-secondary {\n  0% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 0.1em #0d1116;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-success,\n.btn-outline-success {\n  border-color: #10b981;\n}\n\n.btn-success .btn-spinner,\n.btn-outline-success .btn-spinner {\n  -webkit-animation: btn-glow-success 1s ease infinite;\n          animation: btn-glow-success 1s ease infinite;\n}\n\n.btn-success:hover,\n.btn-outline-success:hover {\n  background: #10b981;\n  box-shadow: 0 8px 25px -8px #10b981;\n  border-color: #10b981;\n}\n\n.btn-success:focus,\n.btn-outline-success:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #10b981;\n}\n\n.btn-raised.btn-raised-success {\n  background: #10b981;\n  box-shadow: 0 4px 6px rgba(16, 185, 129, 0.11), 0 1px 3px rgba(16, 185, 129, 0.08);\n}\n\n@-webkit-keyframes btn-glow-success {\n  0% {\n    box-shadow: 0 0 0 0.4em #0c8a60, 0 0 0 0.1em #0c8a60;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0c8a60, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-success {\n  0% {\n    box-shadow: 0 0 0 0.4em #0c8a60, 0 0 0 0.1em #0c8a60;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0c8a60, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-info,\n.btn-outline-info {\n  border-color: #3b82f6;\n}\n\n.btn-info .btn-spinner,\n.btn-outline-info .btn-spinner {\n  -webkit-animation: btn-glow-info 1s ease infinite;\n          animation: btn-glow-info 1s ease infinite;\n}\n\n.btn-info:hover,\n.btn-outline-info:hover {\n  background: #3b82f6;\n  box-shadow: 0 8px 25px -8px #3b82f6;\n  border-color: #3b82f6;\n}\n\n.btn-info:focus,\n.btn-outline-info:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #3b82f6;\n}\n\n.btn-raised.btn-raised-info {\n  background: #3b82f6;\n  box-shadow: 0 4px 6px rgba(59, 130, 246, 0.11), 0 1px 3px rgba(59, 130, 246, 0.08);\n}\n\n@-webkit-keyframes btn-glow-info {\n  0% {\n    box-shadow: 0 0 0 0.4em #0b63f3, 0 0 0 0.1em #0b63f3;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0b63f3, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-info {\n  0% {\n    box-shadow: 0 0 0 0.4em #0b63f3, 0 0 0 0.1em #0b63f3;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0b63f3, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-warning,\n.btn-outline-warning {\n  border-color: #f59e0b;\n}\n\n.btn-warning .btn-spinner,\n.btn-outline-warning .btn-spinner {\n  -webkit-animation: btn-glow-warning 1s ease infinite;\n          animation: btn-glow-warning 1s ease infinite;\n}\n\n.btn-warning:hover,\n.btn-outline-warning:hover {\n  background: #f59e0b;\n  box-shadow: 0 8px 25px -8px #f59e0b;\n  border-color: #f59e0b;\n}\n\n.btn-warning:focus,\n.btn-outline-warning:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #f59e0b;\n}\n\n.btn-raised.btn-raised-warning {\n  background: #f59e0b;\n  box-shadow: 0 4px 6px rgba(245, 158, 11, 0.11), 0 1px 3px rgba(245, 158, 11, 0.08);\n}\n\n@-webkit-keyframes btn-glow-warning {\n  0% {\n    box-shadow: 0 0 0 0.4em #c57f08, 0 0 0 0.1em #c57f08;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #c57f08, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-warning {\n  0% {\n    box-shadow: 0 0 0 0.4em #c57f08, 0 0 0 0.1em #c57f08;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #c57f08, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-danger,\n.btn-outline-danger {\n  border-color: #ef4444;\n}\n\n.btn-danger .btn-spinner,\n.btn-outline-danger .btn-spinner {\n  -webkit-animation: btn-glow-danger 1s ease infinite;\n          animation: btn-glow-danger 1s ease infinite;\n}\n\n.btn-danger:hover,\n.btn-outline-danger:hover {\n  background: #ef4444;\n  box-shadow: 0 8px 25px -8px #ef4444;\n  border-color: #ef4444;\n}\n\n.btn-danger:focus,\n.btn-outline-danger:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #ef4444;\n}\n\n.btn-raised.btn-raised-danger {\n  background: #ef4444;\n  box-shadow: 0 4px 6px rgba(239, 68, 68, 0.11), 0 1px 3px rgba(239, 68, 68, 0.08);\n}\n\n@-webkit-keyframes btn-glow-danger {\n  0% {\n    box-shadow: 0 0 0 0.4em #eb1515, 0 0 0 0.1em #eb1515;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #eb1515, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-danger {\n  0% {\n    box-shadow: 0 0 0 0.4em #eb1515, 0 0 0 0.1em #eb1515;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #eb1515, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-light,\n.btn-outline-light {\n  border-color: #6B7280;\n}\n\n.btn-light .btn-spinner,\n.btn-outline-light .btn-spinner {\n  -webkit-animation: btn-glow-light 1s ease infinite;\n          animation: btn-glow-light 1s ease infinite;\n}\n\n.btn-light:hover,\n.btn-outline-light:hover {\n  background: #6B7280;\n  box-shadow: 0 8px 25px -8px #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-light:focus,\n.btn-outline-light:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #6B7280;\n}\n\n.btn-raised.btn-raised-light {\n  background: #6B7280;\n  box-shadow: 0 4px 6px rgba(107, 114, 128, 0.11), 0 1px 3px rgba(107, 114, 128, 0.08);\n}\n\n@-webkit-keyframes btn-glow-light {\n  0% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 0.1em #545964;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-light {\n  0% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 0.1em #545964;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-dark,\n.btn-outline-dark {\n  border-color: #111827;\n}\n\n.btn-dark .btn-spinner,\n.btn-outline-dark .btn-spinner {\n  -webkit-animation: btn-glow-dark 1s ease infinite;\n          animation: btn-glow-dark 1s ease infinite;\n}\n\n.btn-dark:hover,\n.btn-outline-dark:hover {\n  background: #111827;\n  box-shadow: 0 8px 25px -8px #111827;\n  border-color: #111827;\n}\n\n.btn-dark:focus,\n.btn-outline-dark:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #111827;\n}\n\n.btn-raised.btn-raised-dark {\n  background: #111827;\n  box-shadow: 0 4px 6px rgba(17, 24, 39, 0.11), 0 1px 3px rgba(17, 24, 39, 0.08);\n}\n\n@-webkit-keyframes btn-glow-dark {\n  0% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 0.1em #020203;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-dark {\n  0% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 0.1em #020203;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-100,\n.btn-outline-gray-100 {\n  border-color: #F3F4F6;\n}\n\n.btn-gray-100 .btn-spinner,\n.btn-outline-gray-100 .btn-spinner {\n  -webkit-animation: btn-glow-gray-100 1s ease infinite;\n          animation: btn-glow-gray-100 1s ease infinite;\n}\n\n.btn-gray-100:hover,\n.btn-outline-gray-100:hover {\n  background: #F3F4F6;\n  box-shadow: 0 8px 25px -8px #F3F4F6;\n  border-color: #F3F4F6;\n}\n\n.btn-gray-100:focus,\n.btn-outline-gray-100:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #F3F4F6;\n}\n\n.btn-raised.btn-raised-gray-100 {\n  background: #F3F4F6;\n  box-shadow: 0 4px 6px rgba(243, 244, 246, 0.11), 0 1px 3px rgba(243, 244, 246, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-100 {\n  0% {\n    box-shadow: 0 0 0 0.4em #d6d9e0, 0 0 0 0.1em #d6d9e0;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #d6d9e0, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-100 {\n  0% {\n    box-shadow: 0 0 0 0.4em #d6d9e0, 0 0 0 0.1em #d6d9e0;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #d6d9e0, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-200,\n.btn-outline-gray-200 {\n  border-color: #E5E7EB;\n}\n\n.btn-gray-200 .btn-spinner,\n.btn-outline-gray-200 .btn-spinner {\n  -webkit-animation: btn-glow-gray-200 1s ease infinite;\n          animation: btn-glow-gray-200 1s ease infinite;\n}\n\n.btn-gray-200:hover,\n.btn-outline-gray-200:hover {\n  background: #E5E7EB;\n  box-shadow: 0 8px 25px -8px #E5E7EB;\n  border-color: #E5E7EB;\n}\n\n.btn-gray-200:focus,\n.btn-outline-gray-200:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #E5E7EB;\n}\n\n.btn-raised.btn-raised-gray-200 {\n  background: #E5E7EB;\n  box-shadow: 0 4px 6px rgba(229, 231, 235, 0.11), 0 1px 3px rgba(229, 231, 235, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-200 {\n  0% {\n    box-shadow: 0 0 0 0.4em #c8ccd5, 0 0 0 0.1em #c8ccd5;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #c8ccd5, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-200 {\n  0% {\n    box-shadow: 0 0 0 0.4em #c8ccd5, 0 0 0 0.1em #c8ccd5;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #c8ccd5, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-300,\n.btn-outline-gray-300 {\n  border-color: #D1D5DB;\n}\n\n.btn-gray-300 .btn-spinner,\n.btn-outline-gray-300 .btn-spinner {\n  -webkit-animation: btn-glow-gray-300 1s ease infinite;\n          animation: btn-glow-gray-300 1s ease infinite;\n}\n\n.btn-gray-300:hover,\n.btn-outline-gray-300:hover {\n  background: #D1D5DB;\n  box-shadow: 0 8px 25px -8px #D1D5DB;\n  border-color: #D1D5DB;\n}\n\n.btn-gray-300:focus,\n.btn-outline-gray-300:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #D1D5DB;\n}\n\n.btn-raised.btn-raised-gray-300 {\n  background: #D1D5DB;\n  box-shadow: 0 4px 6px rgba(209, 213, 219, 0.11), 0 1px 3px rgba(209, 213, 219, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-300 {\n  0% {\n    box-shadow: 0 0 0 0.4em #b4bbc5, 0 0 0 0.1em #b4bbc5;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #b4bbc5, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-300 {\n  0% {\n    box-shadow: 0 0 0 0.4em #b4bbc5, 0 0 0 0.1em #b4bbc5;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #b4bbc5, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-400,\n.btn-outline-gray-400 {\n  border-color: #9CA3AF;\n}\n\n.btn-gray-400 .btn-spinner,\n.btn-outline-gray-400 .btn-spinner {\n  -webkit-animation: btn-glow-gray-400 1s ease infinite;\n          animation: btn-glow-gray-400 1s ease infinite;\n}\n\n.btn-gray-400:hover,\n.btn-outline-gray-400:hover {\n  background: #9CA3AF;\n  box-shadow: 0 8px 25px -8px #9CA3AF;\n  border-color: #9CA3AF;\n}\n\n.btn-gray-400:focus,\n.btn-outline-gray-400:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #9CA3AF;\n}\n\n.btn-raised.btn-raised-gray-400 {\n  background: #9CA3AF;\n  box-shadow: 0 4px 6px rgba(156, 163, 175, 0.11), 0 1px 3px rgba(156, 163, 175, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-400 {\n  0% {\n    box-shadow: 0 0 0 0.4em #808998, 0 0 0 0.1em #808998;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #808998, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-400 {\n  0% {\n    box-shadow: 0 0 0 0.4em #808998, 0 0 0 0.1em #808998;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #808998, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-500,\n.btn-outline-gray-500 {\n  border-color: #6B7280;\n}\n\n.btn-gray-500 .btn-spinner,\n.btn-outline-gray-500 .btn-spinner {\n  -webkit-animation: btn-glow-gray-500 1s ease infinite;\n          animation: btn-glow-gray-500 1s ease infinite;\n}\n\n.btn-gray-500:hover,\n.btn-outline-gray-500:hover {\n  background: #6B7280;\n  box-shadow: 0 8px 25px -8px #6B7280;\n  border-color: #6B7280;\n}\n\n.btn-gray-500:focus,\n.btn-outline-gray-500:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #6B7280;\n}\n\n.btn-raised.btn-raised-gray-500 {\n  background: #6B7280;\n  box-shadow: 0 4px 6px rgba(107, 114, 128, 0.11), 0 1px 3px rgba(107, 114, 128, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-500 {\n  0% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 0.1em #545964;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-500 {\n  0% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 0.1em #545964;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #545964, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-600,\n.btn-outline-gray-600 {\n  border-color: #4B5563;\n}\n\n.btn-gray-600 .btn-spinner,\n.btn-outline-gray-600 .btn-spinner {\n  -webkit-animation: btn-glow-gray-600 1s ease infinite;\n          animation: btn-glow-gray-600 1s ease infinite;\n}\n\n.btn-gray-600:hover,\n.btn-outline-gray-600:hover {\n  background: #4B5563;\n  box-shadow: 0 8px 25px -8px #4B5563;\n  border-color: #4B5563;\n}\n\n.btn-gray-600:focus,\n.btn-outline-gray-600:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #4B5563;\n}\n\n.btn-raised.btn-raised-gray-600 {\n  background: #4B5563;\n  box-shadow: 0 4px 6px rgba(75, 85, 99, 0.11), 0 1px 3px rgba(75, 85, 99, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-600 {\n  0% {\n    box-shadow: 0 0 0 0.4em #353c46, 0 0 0 0.1em #353c46;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #353c46, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-600 {\n  0% {\n    box-shadow: 0 0 0 0.4em #353c46, 0 0 0 0.1em #353c46;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #353c46, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-700,\n.btn-outline-gray-700 {\n  border-color: #374151;\n}\n\n.btn-gray-700 .btn-spinner,\n.btn-outline-gray-700 .btn-spinner {\n  -webkit-animation: btn-glow-gray-700 1s ease infinite;\n          animation: btn-glow-gray-700 1s ease infinite;\n}\n\n.btn-gray-700:hover,\n.btn-outline-gray-700:hover {\n  background: #374151;\n  box-shadow: 0 8px 25px -8px #374151;\n  border-color: #374151;\n}\n\n.btn-gray-700:focus,\n.btn-outline-gray-700:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #374151;\n}\n\n.btn-raised.btn-raised-gray-700 {\n  background: #374151;\n  box-shadow: 0 4px 6px rgba(55, 65, 81, 0.11), 0 1px 3px rgba(55, 65, 81, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-700 {\n  0% {\n    box-shadow: 0 0 0 0.4em #222933, 0 0 0 0.1em #222933;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #222933, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-700 {\n  0% {\n    box-shadow: 0 0 0 0.4em #222933, 0 0 0 0.1em #222933;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #222933, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-800,\n.btn-outline-gray-800 {\n  border-color: #1F2937;\n}\n\n.btn-gray-800 .btn-spinner,\n.btn-outline-gray-800 .btn-spinner {\n  -webkit-animation: btn-glow-gray-800 1s ease infinite;\n          animation: btn-glow-gray-800 1s ease infinite;\n}\n\n.btn-gray-800:hover,\n.btn-outline-gray-800:hover {\n  background: #1F2937;\n  box-shadow: 0 8px 25px -8px #1F2937;\n  border-color: #1F2937;\n}\n\n.btn-gray-800:focus,\n.btn-outline-gray-800:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #1F2937;\n}\n\n.btn-raised.btn-raised-gray-800 {\n  background: #1F2937;\n  box-shadow: 0 4px 6px rgba(31, 41, 55, 0.11), 0 1px 3px rgba(31, 41, 55, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-800 {\n  0% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 0.1em #0d1116;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-800 {\n  0% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 0.1em #0d1116;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #0d1116, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-gray-900,\n.btn-outline-gray-900 {\n  border-color: #111827;\n}\n\n.btn-gray-900 .btn-spinner,\n.btn-outline-gray-900 .btn-spinner {\n  -webkit-animation: btn-glow-gray-900 1s ease infinite;\n          animation: btn-glow-gray-900 1s ease infinite;\n}\n\n.btn-gray-900:hover,\n.btn-outline-gray-900:hover {\n  background: #111827;\n  box-shadow: 0 8px 25px -8px #111827;\n  border-color: #111827;\n}\n\n.btn-gray-900:focus,\n.btn-outline-gray-900:focus {\n  box-shadow: none;\n  box-shadow: 0 8px 25px -8px #111827;\n}\n\n.btn-raised.btn-raised-gray-900 {\n  background: #111827;\n  box-shadow: 0 4px 6px rgba(17, 24, 39, 0.11), 0 1px 3px rgba(17, 24, 39, 0.08);\n}\n\n@-webkit-keyframes btn-glow-gray-900 {\n  0% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 0.1em #020203;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes btn-glow-gray-900 {\n  0% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 0.1em #020203;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #ffffff;\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em #020203, 0 0 0 3.6em transparent;\n  }\n}\n\n.btn-facebook {\n  color: #fff;\n  background-color: #3765c9;\n  border-color: #3765c9;\n}\n\n.btn-facebook:hover {\n  background-color: #3765c9;\n  border-color: #3765c9;\n}\n\n.btn-google {\n  color: #fff;\n  background-color: #ec412c;\n  border-color: #ec412c;\n}\n\n.btn-twitter {\n  color: #fff;\n  background-color: #039ff5;\n  border-color: #039ff5;\n}\n\n.btn-instagram {\n  color: #fff;\n  background-color: #c13584;\n  border-color: #c13584;\n}\n\n.btn-linkedin {\n  color: #fff;\n  background-color: #0077b5;\n  border-color: #0077b5;\n}\n\n.btn-dribble {\n  color: #fff;\n  background-color: #ea4c89;\n  border-color: #ea4c89;\n}\n\n.btn-youtube {\n  color: #fff;\n  background-color: #c4302b;\n  border-color: #c4302b;\n}\n\n.btn-outline-facebook {\n  color: #3765c9 !important;\n  border-color: #3765c9;\n  background: rgba(229, 231, 235, 0.6);\n}\n\n.btn-outline-facebook:hover {\n  background: #315bb5;\n  border-color: #315bb5;\n  color: #fff !important;\n}\n\n.btn-outline-google {\n  color: #ec412c !important;\n  border-color: #ec412c;\n  background: rgba(229, 231, 235, 0.6);\n}\n\n.btn-outline-google:hover {\n  background: #e92c15;\n  border-color: #e92c15;\n  color: #fff !important;\n}\n\n.btn-outline-twitter {\n  color: #039ff5 !important;\n  border-color: #039ff5;\n  background: rgba(229, 231, 235, 0.6);\n}\n\n.btn-outline-twitter:hover {\n  background: #038fdc;\n  border-color: #038fdc;\n}\n\n.ripple {\n  position: relative;\n  overflow: hidden;\n  transform: translate3d(0, 0, 0);\n}\n\n.ripple:after {\n  content: \"\";\n  display: block;\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  top: 0;\n  left: 0;\n  pointer-events: none;\n  background-image: radial-gradient(circle, #fff 10%, transparent 10.01%);\n  background-repeat: no-repeat;\n  background-position: 50%;\n  transform: scale(10, 10);\n  opacity: 0;\n  transition: transform .5s, opacity 1s;\n}\n\n.ripple:active:after {\n  transform: scale(0, 0);\n  opacity: .3;\n  transition: 0s;\n}\n\n.nav-tabs {\n  border: 0;\n}\n\n.nav-tabs .nav-item .nav-link {\n  border: 0;\n  padding: 1rem;\n}\n\n.nav-tabs .nav-item .nav-link:not(.disabled) {\n  color: inherit;\n}\n\n.nav-tabs .nav-item .nav-link.active {\n  border-bottom: 2px solid #8b5cf6;\n  background: rgba(139, 92, 246, 0.1);\n}\n\n.nav-tabs .nav-item .dropdown-toggle:after {\n  position: absolute;\n  top: calc(50% - 2px);\n  right: 6px !important;\n}\n\n.tab-content {\n  padding: 1rem;\n}\n\nngb-tabset.p-0 .tab-content {\n  padding: 1rem 0;\n}\n\n.dropdown-toggle {\n  position: relative;\n}\n\n.dropdown-toggle.btn {\n  padding-right: 28px;\n}\n\n.dropdown-toggle::after {\n  position: absolute;\n  top: calc(50% - 2px);\n  right: 10px !important;\n}\n\n.dropdown-menu {\n  border: 0;\n  padding: 0 !important;\n  box-shadow: 0 1px 15px 1px rgba(0, 0, 0, 0.04), 0 1px 6px rgba(0, 0, 0, 0.08);\n}\n\n.dropdown-item {\n  padding: 0.42rem 1.5rem;\n}\n\n.menu-icon-grid {\n  width: 220px;\n  padding: 0 8px;\n  display: flex;\n  flex-wrap: wrap;\n  justify-content: space-between;\n}\n\n.menu-icon-grid > a {\n  display: inline-flex;\n  width: 6rem;\n  flex-direction: column;\n  align-items: center;\n  padding: 18px 12px;\n  color: #1F2937;\n  border-radius: 4px;\n}\n\n.menu-icon-grid > a i {\n  font-size: 28px;\n  margin-bottom: 4px;\n}\n\n.menu-icon-grid > a:hover {\n  background: #8b5cf6;\n  color: #fff;\n}\n\n.mega-menu {\n  position: static;\n}\n\n.mega-menu .dropdown-menu {\n  left: auto;\n  right: auto;\n  width: calc(100% - 120px);\n  max-width: 1200px;\n  padding: 0;\n  overflow: hidden;\n  max-height: calc(100vh - 100px);\n  overflow-y: scroll;\n}\n\n.mega-menu .dropdown-menu .bg-img {\n  background: linear-gradient(to right, #8b5cf6, #3b82f6);\n}\n\n.mega-menu .dropdown-menu .bg-img,\n.mega-menu .dropdown-menu .bg-img .title {\n  color: #ffffff;\n}\n\n.mega-menu .dropdown-menu ul.links {\n  list-style: none;\n  margin: 0;\n  padding: 0;\n  -moz-column-count: 2;\n       column-count: 2;\n}\n\n.mega-menu .dropdown-menu ul.links li a {\n  display: inline-block;\n  margin-bottom: 8px;\n  color: #4B5563;\n}\n\n.mega-menu .dropdown-menu ul.links li a:hover {\n  color: #8b5cf6;\n}\n\n.widget_dropdown .dropdown-menu {\n  left: auto !important;\n  right: 2px !important;\n}\n\n@media (max-width: 767px) {\n  .mega-menu .dropdown-menu {\n    width: calc(100% - 10px);\n  }\n}\n\n[dir=\"rtl\"] .mega-menu .dropdown-menu {\n  left: 0 !important;\n  right: 0 !important;\n  margin: auto !important;\n}\n\ntable.dataTable-collapse {\n  border-collapse: collapse !important;\n}\n\n.table thead th {\n  vertical-align: bottom;\n  border-bottom: 1px solid #dee2e6;\n}\n\n.form-group {\n  position: relative;\n  margin-bottom: 10px;\n}\n\n.form-group label {\n  font-size: 12px;\n  color: #4B5563;\n  margin-bottom: 4px;\n}\n\n.form-control {\n  border: initial;\n  outline: initial !important;\n  background: #F3F4F6;\n  border: 1px solid #9CA3AF;\n  color: #111827;\n}\n\n.form-control::-moz-placeholder {\n  color: #6B7280;\n}\n\n.form-control:-ms-input-placeholder {\n  color: #6B7280;\n}\n\n.form-control::placeholder {\n  color: #6B7280;\n}\n\n.form-control.rounded, .form-control.form-control-rounded {\n  border-radius: 20px;\n}\n\nselect.form-control {\n  -webkit-appearance: none;\n}\n\n.input-group [type=\"text\"].form-control {\n  height: 34px;\n}\n\n.input-group-append .btn {\n  height: 34px;\n  border: 0;\n}\n\n.card-input {\n  display: flex;\n  flex-wrap: wrap;\n}\n\n.card-input legend {\n  margin-right: auto;\n  width: auto;\n}\n\n.card-input .ul-widget-list__payment-method img {\n  height: 24px;\n  width: auto;\n}\n\n[ngbdatepicker] {\n  height: 34px;\n}\n\n/* checkbox-custom */\n.checkbox, .radio {\n  display: block;\n  position: relative;\n  padding-left: 28px;\n  margin-bottom: 12px;\n  cursor: pointer;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n\n.checkbox:hover input ~ .checkmark, .radio:hover input ~ .checkmark {\n  background-color: #6B7280;\n}\n\n.checkbox input, .radio input {\n  position: absolute;\n  opacity: 0;\n  cursor: pointer;\n  height: 0;\n  width: 0;\n}\n\n.checkbox input:checked ~ .checkmark, .radio input:checked ~ .checkmark {\n  background-color: #8b5cf6;\n}\n\n.checkbox input:checked ~ .checkmark:after, .radio input:checked ~ .checkmark:after {\n  display: block;\n}\n\n.checkbox input[disabled] ~ *, .radio input[disabled] ~ * {\n  color: #D1D5DB;\n}\n\n.checkbox .checkmark, .radio .checkmark {\n  position: absolute;\n  top: 0;\n  left: 0;\n  height: 20px;\n  width: 20px;\n  border-radius: 4px;\n  background-color: #D1D5DB;\n}\n\n.checkbox .checkmark:after, .radio .checkmark:after {\n  content: \"\";\n  position: absolute;\n  display: none;\n  left: 0;\n  top: 0;\n  right: 0;\n  width: 4px;\n  bottom: 0;\n  margin: auto;\n  height: 8px;\n  border: solid #fff;\n  border-width: 0 2px 2px 0;\n  transform: rotate(45deg);\n}\n\n.checkbox-primary input:checked ~ .checkmark {\n  background-color: #8b5cf6 !important;\n}\n\n.checkbox-secondary input:checked ~ .checkmark {\n  background-color: #1F2937 !important;\n}\n\n.checkbox-success input:checked ~ .checkmark {\n  background-color: #10b981 !important;\n}\n\n.checkbox-info input:checked ~ .checkmark {\n  background-color: #3b82f6 !important;\n}\n\n.checkbox-warning input:checked ~ .checkmark {\n  background-color: #f59e0b !important;\n}\n\n.checkbox-danger input:checked ~ .checkmark {\n  background-color: #ef4444 !important;\n}\n\n.checkbox-light input:checked ~ .checkmark {\n  background-color: #6B7280 !important;\n}\n\n.checkbox-dark input:checked ~ .checkmark {\n  background-color: #111827 !important;\n}\n\n.checkbox-gray-100 input:checked ~ .checkmark {\n  background-color: #F3F4F6 !important;\n}\n\n.checkbox-gray-200 input:checked ~ .checkmark {\n  background-color: #E5E7EB !important;\n}\n\n.checkbox-gray-300 input:checked ~ .checkmark {\n  background-color: #D1D5DB !important;\n}\n\n.checkbox-gray-400 input:checked ~ .checkmark {\n  background-color: #9CA3AF !important;\n}\n\n.checkbox-gray-500 input:checked ~ .checkmark {\n  background-color: #6B7280 !important;\n}\n\n.checkbox-gray-600 input:checked ~ .checkmark {\n  background-color: #4B5563 !important;\n}\n\n.checkbox-gray-700 input:checked ~ .checkmark {\n  background-color: #374151 !important;\n}\n\n.checkbox-gray-800 input:checked ~ .checkmark {\n  background-color: #1F2937 !important;\n}\n\n.checkbox-gray-900 input:checked ~ .checkmark {\n  background-color: #111827 !important;\n}\n\n.checkbox-outline-primary:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-primary input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-primary .checkmark {\n  background: #fff;\n  border: 1px solid #8b5cf6;\n}\n\n.checkbox-outline-primary .checkmark:after {\n  border-color: #8b5cf6;\n}\n\n.checkbox-outline-secondary:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-secondary input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-secondary .checkmark {\n  background: #fff;\n  border: 1px solid #1F2937;\n}\n\n.checkbox-outline-secondary .checkmark:after {\n  border-color: #1F2937;\n}\n\n.checkbox-outline-success:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-success input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-success .checkmark {\n  background: #fff;\n  border: 1px solid #10b981;\n}\n\n.checkbox-outline-success .checkmark:after {\n  border-color: #10b981;\n}\n\n.checkbox-outline-info:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-info input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-info .checkmark {\n  background: #fff;\n  border: 1px solid #3b82f6;\n}\n\n.checkbox-outline-info .checkmark:after {\n  border-color: #3b82f6;\n}\n\n.checkbox-outline-warning:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-warning input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-warning .checkmark {\n  background: #fff;\n  border: 1px solid #f59e0b;\n}\n\n.checkbox-outline-warning .checkmark:after {\n  border-color: #f59e0b;\n}\n\n.checkbox-outline-danger:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-danger input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-danger .checkmark {\n  background: #fff;\n  border: 1px solid #ef4444;\n}\n\n.checkbox-outline-danger .checkmark:after {\n  border-color: #ef4444;\n}\n\n.checkbox-outline-light:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-light input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-light .checkmark {\n  background: #fff;\n  border: 1px solid #6B7280;\n}\n\n.checkbox-outline-light .checkmark:after {\n  border-color: #6B7280;\n}\n\n.checkbox-outline-dark:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-dark input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-dark .checkmark {\n  background: #fff;\n  border: 1px solid #111827;\n}\n\n.checkbox-outline-dark .checkmark:after {\n  border-color: #111827;\n}\n\n.checkbox-outline-gray-100:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-100 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-100 .checkmark {\n  background: #fff;\n  border: 1px solid #F3F4F6;\n}\n\n.checkbox-outline-gray-100 .checkmark:after {\n  border-color: #F3F4F6;\n}\n\n.checkbox-outline-gray-200:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-200 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-200 .checkmark {\n  background: #fff;\n  border: 1px solid #E5E7EB;\n}\n\n.checkbox-outline-gray-200 .checkmark:after {\n  border-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-300:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-300 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-300 .checkmark {\n  background: #fff;\n  border: 1px solid #D1D5DB;\n}\n\n.checkbox-outline-gray-300 .checkmark:after {\n  border-color: #D1D5DB;\n}\n\n.checkbox-outline-gray-400:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-400 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-400 .checkmark {\n  background: #fff;\n  border: 1px solid #9CA3AF;\n}\n\n.checkbox-outline-gray-400 .checkmark:after {\n  border-color: #9CA3AF;\n}\n\n.checkbox-outline-gray-500:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-500 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-500 .checkmark {\n  background: #fff;\n  border: 1px solid #6B7280;\n}\n\n.checkbox-outline-gray-500 .checkmark:after {\n  border-color: #6B7280;\n}\n\n.checkbox-outline-gray-600:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-600 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-600 .checkmark {\n  background: #fff;\n  border: 1px solid #4B5563;\n}\n\n.checkbox-outline-gray-600 .checkmark:after {\n  border-color: #4B5563;\n}\n\n.checkbox-outline-gray-700:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-700 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-700 .checkmark {\n  background: #fff;\n  border: 1px solid #374151;\n}\n\n.checkbox-outline-gray-700 .checkmark:after {\n  border-color: #374151;\n}\n\n.checkbox-outline-gray-800:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-800 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-800 .checkmark {\n  background: #fff;\n  border: 1px solid #1F2937;\n}\n\n.checkbox-outline-gray-800 .checkmark:after {\n  border-color: #1F2937;\n}\n\n.checkbox-outline-gray-900:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.checkbox-outline-gray-900 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.checkbox-outline-gray-900 .checkmark {\n  background: #fff;\n  border: 1px solid #111827;\n}\n\n.checkbox-outline-gray-900 .checkmark:after {\n  border-color: #111827;\n}\n\n.radio .checkmark {\n  border-radius: 50%;\n}\n\n.radio .checkmark:after {\n  height: 6px;\n  width: 6px;\n  border-radius: 50%;\n  background: white;\n}\n\n.radio-primary input:checked ~ .checkmark {\n  background-color: #8b5cf6;\n}\n\n.radio-secondary input:checked ~ .checkmark {\n  background-color: #1F2937;\n}\n\n.radio-success input:checked ~ .checkmark {\n  background-color: #10b981;\n}\n\n.radio-info input:checked ~ .checkmark {\n  background-color: #3b82f6;\n}\n\n.radio-warning input:checked ~ .checkmark {\n  background-color: #f59e0b;\n}\n\n.radio-danger input:checked ~ .checkmark {\n  background-color: #ef4444;\n}\n\n.radio-light input:checked ~ .checkmark {\n  background-color: #6B7280;\n}\n\n.radio-dark input:checked ~ .checkmark {\n  background-color: #111827;\n}\n\n.radio-gray-100 input:checked ~ .checkmark {\n  background-color: #F3F4F6;\n}\n\n.radio-gray-200 input:checked ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-gray-300 input:checked ~ .checkmark {\n  background-color: #D1D5DB;\n}\n\n.radio-gray-400 input:checked ~ .checkmark {\n  background-color: #9CA3AF;\n}\n\n.radio-gray-500 input:checked ~ .checkmark {\n  background-color: #6B7280;\n}\n\n.radio-gray-600 input:checked ~ .checkmark {\n  background-color: #4B5563;\n}\n\n.radio-gray-700 input:checked ~ .checkmark {\n  background-color: #374151;\n}\n\n.radio-gray-800 input:checked ~ .checkmark {\n  background-color: #1F2937;\n}\n\n.radio-gray-900 input:checked ~ .checkmark {\n  background-color: #111827;\n}\n\n.radio-outline-primary:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-primary input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-primary .checkmark {\n  background: #fff;\n  border: 1px solid #8b5cf6;\n}\n\n.radio-outline-primary .checkmark:after {\n  border: 0;\n  background: #8b5cf6;\n}\n\n.radio-outline-secondary:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-secondary input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-secondary .checkmark {\n  background: #fff;\n  border: 1px solid #1F2937;\n}\n\n.radio-outline-secondary .checkmark:after {\n  border: 0;\n  background: #1F2937;\n}\n\n.radio-outline-success:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-success input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-success .checkmark {\n  background: #fff;\n  border: 1px solid #10b981;\n}\n\n.radio-outline-success .checkmark:after {\n  border: 0;\n  background: #10b981;\n}\n\n.radio-outline-info:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-info input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-info .checkmark {\n  background: #fff;\n  border: 1px solid #3b82f6;\n}\n\n.radio-outline-info .checkmark:after {\n  border: 0;\n  background: #3b82f6;\n}\n\n.radio-outline-warning:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-warning input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-warning .checkmark {\n  background: #fff;\n  border: 1px solid #f59e0b;\n}\n\n.radio-outline-warning .checkmark:after {\n  border: 0;\n  background: #f59e0b;\n}\n\n.radio-outline-danger:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-danger input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-danger .checkmark {\n  background: #fff;\n  border: 1px solid #ef4444;\n}\n\n.radio-outline-danger .checkmark:after {\n  border: 0;\n  background: #ef4444;\n}\n\n.radio-outline-light:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-light input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-light .checkmark {\n  background: #fff;\n  border: 1px solid #6B7280;\n}\n\n.radio-outline-light .checkmark:after {\n  border: 0;\n  background: #6B7280;\n}\n\n.radio-outline-dark:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-dark input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-dark .checkmark {\n  background: #fff;\n  border: 1px solid #111827;\n}\n\n.radio-outline-dark .checkmark:after {\n  border: 0;\n  background: #111827;\n}\n\n.radio-outline-gray-100:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-100 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-100 .checkmark {\n  background: #fff;\n  border: 1px solid #F3F4F6;\n}\n\n.radio-outline-gray-100 .checkmark:after {\n  border: 0;\n  background: #F3F4F6;\n}\n\n.radio-outline-gray-200:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-200 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-200 .checkmark {\n  background: #fff;\n  border: 1px solid #E5E7EB;\n}\n\n.radio-outline-gray-200 .checkmark:after {\n  border: 0;\n  background: #E5E7EB;\n}\n\n.radio-outline-gray-300:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-300 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-300 .checkmark {\n  background: #fff;\n  border: 1px solid #D1D5DB;\n}\n\n.radio-outline-gray-300 .checkmark:after {\n  border: 0;\n  background: #D1D5DB;\n}\n\n.radio-outline-gray-400:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-400 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-400 .checkmark {\n  background: #fff;\n  border: 1px solid #9CA3AF;\n}\n\n.radio-outline-gray-400 .checkmark:after {\n  border: 0;\n  background: #9CA3AF;\n}\n\n.radio-outline-gray-500:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-500 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-500 .checkmark {\n  background: #fff;\n  border: 1px solid #6B7280;\n}\n\n.radio-outline-gray-500 .checkmark:after {\n  border: 0;\n  background: #6B7280;\n}\n\n.radio-outline-gray-600:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-600 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-600 .checkmark {\n  background: #fff;\n  border: 1px solid #4B5563;\n}\n\n.radio-outline-gray-600 .checkmark:after {\n  border: 0;\n  background: #4B5563;\n}\n\n.radio-outline-gray-700:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-700 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-700 .checkmark {\n  background: #fff;\n  border: 1px solid #374151;\n}\n\n.radio-outline-gray-700 .checkmark:after {\n  border: 0;\n  background: #374151;\n}\n\n.radio-outline-gray-800:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-800 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-800 .checkmark {\n  background: #fff;\n  border: 1px solid #1F2937;\n}\n\n.radio-outline-gray-800 .checkmark:after {\n  border: 0;\n  background: #1F2937;\n}\n\n.radio-outline-gray-900:hover input ~ .checkmark {\n  background-color: #E5E7EB;\n}\n\n.radio-outline-gray-900 input:checked ~ .checkmark {\n  background-color: #fff !important;\n}\n\n.radio-outline-gray-900 .checkmark {\n  background: #fff;\n  border: 1px solid #111827;\n}\n\n.radio-outline-gray-900 .checkmark:after {\n  border: 0;\n  background: #111827;\n}\n\n.switch {\n  position: relative;\n  display: inline-block;\n  padding-left: 50px;\n  height: 16px;\n}\n\n.switch span:not(.slider) {\n  position: relative;\n  top: -2px;\n  cursor: pointer;\n}\n\n.switch input {\n  opacity: 0;\n  width: 0;\n  height: 0;\n}\n\n.switch .slider {\n  position: absolute;\n  cursor: pointer;\n  width: 42px;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  border-radius: 34px;\n  background-color: #D1D5DB;\n  transition: 0.4s;\n}\n\n.switch .slider:before {\n  position: absolute;\n  content: \"\";\n  height: 24px;\n  width: 24px;\n  left: -1px;\n  bottom: -4px;\n  background-color: #fff;\n  transition: 0.4s;\n  border-radius: 50%;\n  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);\n}\n\n.switch input:checked + .slider {\n  background-color: #8b5cf6;\n}\n\n.switch input:focus + .slider {\n  box-shadow: 0 0 1px #8b5cf6;\n}\n\n.switch input:checked + .slider:before {\n  transform: translateX(20px);\n}\n\n.switch-primary input:checked + .slider {\n  background-color: #8b5cf6;\n}\n\n.switch-primary input:focus + .slider {\n  box-shadow: 0 0 1px #8b5cf6;\n}\n\n.switch-secondary input:checked + .slider {\n  background-color: #1F2937;\n}\n\n.switch-secondary input:focus + .slider {\n  box-shadow: 0 0 1px #1F2937;\n}\n\n.switch-success input:checked + .slider {\n  background-color: #10b981;\n}\n\n.switch-success input:focus + .slider {\n  box-shadow: 0 0 1px #10b981;\n}\n\n.switch-info input:checked + .slider {\n  background-color: #3b82f6;\n}\n\n.switch-info input:focus + .slider {\n  box-shadow: 0 0 1px #3b82f6;\n}\n\n.switch-warning input:checked + .slider {\n  background-color: #f59e0b;\n}\n\n.switch-warning input:focus + .slider {\n  box-shadow: 0 0 1px #f59e0b;\n}\n\n.switch-danger input:checked + .slider {\n  background-color: #ef4444;\n}\n\n.switch-danger input:focus + .slider {\n  box-shadow: 0 0 1px #ef4444;\n}\n\n.switch-light input:checked + .slider {\n  background-color: #6B7280;\n}\n\n.switch-light input:focus + .slider {\n  box-shadow: 0 0 1px #6B7280;\n}\n\n.switch-dark input:checked + .slider {\n  background-color: #111827;\n}\n\n.switch-dark input:focus + .slider {\n  box-shadow: 0 0 1px #111827;\n}\n\n.switch-gray-100 input:checked + .slider {\n  background-color: #F3F4F6;\n}\n\n.switch-gray-100 input:focus + .slider {\n  box-shadow: 0 0 1px #F3F4F6;\n}\n\n.switch-gray-200 input:checked + .slider {\n  background-color: #E5E7EB;\n}\n\n.switch-gray-200 input:focus + .slider {\n  box-shadow: 0 0 1px #E5E7EB;\n}\n\n.switch-gray-300 input:checked + .slider {\n  background-color: #D1D5DB;\n}\n\n.switch-gray-300 input:focus + .slider {\n  box-shadow: 0 0 1px #D1D5DB;\n}\n\n.switch-gray-400 input:checked + .slider {\n  background-color: #9CA3AF;\n}\n\n.switch-gray-400 input:focus + .slider {\n  box-shadow: 0 0 1px #9CA3AF;\n}\n\n.switch-gray-500 input:checked + .slider {\n  background-color: #6B7280;\n}\n\n.switch-gray-500 input:focus + .slider {\n  box-shadow: 0 0 1px #6B7280;\n}\n\n.switch-gray-600 input:checked + .slider {\n  background-color: #4B5563;\n}\n\n.switch-gray-600 input:focus + .slider {\n  box-shadow: 0 0 1px #4B5563;\n}\n\n.switch-gray-700 input:checked + .slider {\n  background-color: #374151;\n}\n\n.switch-gray-700 input:focus + .slider {\n  box-shadow: 0 0 1px #374151;\n}\n\n.switch-gray-800 input:checked + .slider {\n  background-color: #1F2937;\n}\n\n.switch-gray-800 input:focus + .slider {\n  box-shadow: 0 0 1px #1F2937;\n}\n\n.switch-gray-900 input:checked + .slider {\n  background-color: #111827;\n}\n\n.switch-gray-900 input:focus + .slider {\n  box-shadow: 0 0 1px #111827;\n}\n\n[dir=\"rtl\"] .checkbox, [dir=\"rtl\"] .radio,\n[dir=\"rtl\"] .radio {\n  padding-left: 0px;\n  padding-right: 28px;\n}\n\n[dir=\"rtl\"] .checkbox .checkmark, [dir=\"rtl\"] .radio .checkmark,\n[dir=\"rtl\"] .radio .checkmark {\n  left: auto;\n  right: 0;\n}\n\n.icon-regular {\n  font-size: 18px;\n  -webkit-font-smoothing: subpixel-antialiased;\n}\n\n.link-icon {\n  display: flex;\n  flex-direction: row;\n  align-items: center;\n  color: #111827;\n}\n\n.link-icon i {\n  margin: 0 8px;\n}\n\n.spinner-glow {\n  display: inline-block;\n  width: 1em;\n  height: 1em;\n  background: #D1D5DB;\n  border-radius: 50%;\n  margin: 4px auto;\n  border: 2px solid transparent;\n  -webkit-animation: glow 1s ease infinite;\n          animation: glow 1s ease infinite;\n}\n\n@-webkit-keyframes glow {\n  0% {\n    box-shadow: 0 0 0 .4em #a1a2a1, 0 0 0 .1em #a1a2a1;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #605556;\n  }\n  100% {\n    box-shadow: 0 0 0 .4em #a1a2a1, 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow {\n  0% {\n    box-shadow: 0 0 0 .4em #a1a2a1, 0 0 0 .1em #a1a2a1;\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: #605556;\n  }\n  100% {\n    box-shadow: 0 0 0 .4em #a1a2a1, 0 0 0 3.6em transparent;\n  }\n}\n\n.spinner-glow-primary {\n  background: rgba(139, 92, 246, 0.45);\n  -webkit-animation: glow-primary 1s ease infinite;\n          animation: glow-primary 1s ease infinite;\n}\n\n.spinner-glow-secondary {\n  background: rgba(31, 41, 55, 0.45);\n  -webkit-animation: glow-secondary 1s ease infinite;\n          animation: glow-secondary 1s ease infinite;\n}\n\n.spinner-glow-success {\n  background: rgba(16, 185, 129, 0.45);\n  -webkit-animation: glow-success 1s ease infinite;\n          animation: glow-success 1s ease infinite;\n}\n\n.spinner-glow-info {\n  background: rgba(59, 130, 246, 0.45);\n  -webkit-animation: glow-info 1s ease infinite;\n          animation: glow-info 1s ease infinite;\n}\n\n.spinner-glow-warning {\n  background: rgba(245, 158, 11, 0.45);\n  -webkit-animation: glow-warning 1s ease infinite;\n          animation: glow-warning 1s ease infinite;\n}\n\n.spinner-glow-danger {\n  background: rgba(239, 68, 68, 0.45);\n  -webkit-animation: glow-danger 1s ease infinite;\n          animation: glow-danger 1s ease infinite;\n}\n\n.spinner-glow-light {\n  background: rgba(107, 114, 128, 0.45);\n  -webkit-animation: glow-light 1s ease infinite;\n          animation: glow-light 1s ease infinite;\n}\n\n.spinner-glow-dark {\n  background: rgba(17, 24, 39, 0.45);\n  -webkit-animation: glow-dark 1s ease infinite;\n          animation: glow-dark 1s ease infinite;\n}\n\n.spinner-glow-gray-100 {\n  background: rgba(243, 244, 246, 0.45);\n  -webkit-animation: glow-gray-100 1s ease infinite;\n          animation: glow-gray-100 1s ease infinite;\n}\n\n.spinner-glow-gray-200 {\n  background: rgba(229, 231, 235, 0.45);\n  -webkit-animation: glow-gray-200 1s ease infinite;\n          animation: glow-gray-200 1s ease infinite;\n}\n\n.spinner-glow-gray-300 {\n  background: rgba(209, 213, 219, 0.45);\n  -webkit-animation: glow-gray-300 1s ease infinite;\n          animation: glow-gray-300 1s ease infinite;\n}\n\n.spinner-glow-gray-400 {\n  background: rgba(156, 163, 175, 0.45);\n  -webkit-animation: glow-gray-400 1s ease infinite;\n          animation: glow-gray-400 1s ease infinite;\n}\n\n.spinner-glow-gray-500 {\n  background: rgba(107, 114, 128, 0.45);\n  -webkit-animation: glow-gray-500 1s ease infinite;\n          animation: glow-gray-500 1s ease infinite;\n}\n\n.spinner-glow-gray-600 {\n  background: rgba(75, 85, 99, 0.45);\n  -webkit-animation: glow-gray-600 1s ease infinite;\n          animation: glow-gray-600 1s ease infinite;\n}\n\n.spinner-glow-gray-700 {\n  background: rgba(55, 65, 81, 0.45);\n  -webkit-animation: glow-gray-700 1s ease infinite;\n          animation: glow-gray-700 1s ease infinite;\n}\n\n.spinner-glow-gray-800 {\n  background: rgba(31, 41, 55, 0.45);\n  -webkit-animation: glow-gray-800 1s ease infinite;\n          animation: glow-gray-800 1s ease infinite;\n}\n\n.spinner-glow-gray-900 {\n  background: rgba(17, 24, 39, 0.45);\n  -webkit-animation: glow-gray-900 1s ease infinite;\n          animation: glow-gray-900 1s ease infinite;\n}\n\n@-webkit-keyframes glow-primary {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(139, 92, 246, 0.45), 0 0 0 0.1em rgba(139, 92, 246, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(139, 92, 246, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(139, 92, 246, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-primary {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(139, 92, 246, 0.45), 0 0 0 0.1em rgba(139, 92, 246, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(139, 92, 246, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(139, 92, 246, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-secondary {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.45), 0 0 0 0.1em rgba(31, 41, 55, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(31, 41, 55, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-secondary {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.45), 0 0 0 0.1em rgba(31, 41, 55, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(31, 41, 55, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-success {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(16, 185, 129, 0.45), 0 0 0 0.1em rgba(16, 185, 129, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(16, 185, 129, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(16, 185, 129, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-success {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(16, 185, 129, 0.45), 0 0 0 0.1em rgba(16, 185, 129, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(16, 185, 129, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(16, 185, 129, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-info {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(59, 130, 246, 0.45), 0 0 0 0.1em rgba(59, 130, 246, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(59, 130, 246, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(59, 130, 246, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-info {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(59, 130, 246, 0.45), 0 0 0 0.1em rgba(59, 130, 246, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(59, 130, 246, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(59, 130, 246, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-warning {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(245, 158, 11, 0.45), 0 0 0 0.1em rgba(245, 158, 11, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(245, 158, 11, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(245, 158, 11, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-warning {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(245, 158, 11, 0.45), 0 0 0 0.1em rgba(245, 158, 11, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(245, 158, 11, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(245, 158, 11, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-danger {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(239, 68, 68, 0.45), 0 0 0 0.1em rgba(239, 68, 68, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(239, 68, 68, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(239, 68, 68, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-danger {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(239, 68, 68, 0.45), 0 0 0 0.1em rgba(239, 68, 68, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(239, 68, 68, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(239, 68, 68, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-light {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.45), 0 0 0 0.1em rgba(107, 114, 128, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(107, 114, 128, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-light {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.45), 0 0 0 0.1em rgba(107, 114, 128, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(107, 114, 128, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-dark {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.45), 0 0 0 0.1em rgba(17, 24, 39, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(17, 24, 39, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-dark {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.45), 0 0 0 0.1em rgba(17, 24, 39, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(17, 24, 39, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-100 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(243, 244, 246, 0.45), 0 0 0 0.1em rgba(243, 244, 246, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(243, 244, 246, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(243, 244, 246, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-100 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(243, 244, 246, 0.45), 0 0 0 0.1em rgba(243, 244, 246, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(243, 244, 246, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(243, 244, 246, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-200 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(229, 231, 235, 0.45), 0 0 0 0.1em rgba(229, 231, 235, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(229, 231, 235, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(229, 231, 235, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-200 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(229, 231, 235, 0.45), 0 0 0 0.1em rgba(229, 231, 235, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(229, 231, 235, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(229, 231, 235, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-300 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(209, 213, 219, 0.45), 0 0 0 0.1em rgba(209, 213, 219, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(209, 213, 219, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(209, 213, 219, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-300 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(209, 213, 219, 0.45), 0 0 0 0.1em rgba(209, 213, 219, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(209, 213, 219, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(209, 213, 219, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-400 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(156, 163, 175, 0.45), 0 0 0 0.1em rgba(156, 163, 175, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(156, 163, 175, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(156, 163, 175, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-400 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(156, 163, 175, 0.45), 0 0 0 0.1em rgba(156, 163, 175, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(156, 163, 175, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(156, 163, 175, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-500 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.45), 0 0 0 0.1em rgba(107, 114, 128, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(107, 114, 128, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-500 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.45), 0 0 0 0.1em rgba(107, 114, 128, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(107, 114, 128, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(107, 114, 128, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-600 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(75, 85, 99, 0.45), 0 0 0 0.1em rgba(75, 85, 99, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(75, 85, 99, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(75, 85, 99, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-600 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(75, 85, 99, 0.45), 0 0 0 0.1em rgba(75, 85, 99, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(75, 85, 99, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(75, 85, 99, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-700 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(55, 65, 81, 0.45), 0 0 0 0.1em rgba(55, 65, 81, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(55, 65, 81, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(55, 65, 81, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-700 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(55, 65, 81, 0.45), 0 0 0 0.1em rgba(55, 65, 81, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(55, 65, 81, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(55, 65, 81, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-800 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.45), 0 0 0 0.1em rgba(31, 41, 55, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(31, 41, 55, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-800 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.45), 0 0 0 0.1em rgba(31, 41, 55, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(31, 41, 55, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(31, 41, 55, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@-webkit-keyframes glow-gray-900 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.45), 0 0 0 0.1em rgba(17, 24, 39, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(17, 24, 39, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n@keyframes glow-gray-900 {\n  0% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.45), 0 0 0 0.1em rgba(17, 24, 39, 0.45);\n    transform: rotate(360deg);\n  }\n  50% {\n    border-top-color: rgba(17, 24, 39, 0.9);\n  }\n  100% {\n    box-shadow: 0 0 0 0.4em rgba(17, 24, 39, 0.75), 0 0 0 3.6em transparent;\n  }\n}\n\n.spinner {\n  display: inline-block;\n  font-size: 10px;\n  margin: auto;\n  text-indent: -9999em;\n  width: 4em;\n  height: 4em;\n  border-radius: 50%;\n  position: relative;\n  -webkit-animation: spin 1.4s infinite linear;\n  animation: spin 1.4s infinite linear;\n  transform: translateZ(0);\n}\n\n.spinner:before {\n  width: 50%;\n  height: 50%;\n  border-radius: 100% 0 0 0;\n  position: absolute;\n  top: 0;\n  left: 0;\n  content: '';\n}\n\n.spinner:after {\n  background: #fff;\n  width: 75%;\n  height: 75%;\n  border-radius: 50%;\n  content: '';\n  margin: auto;\n  position: absolute;\n  top: 0;\n  left: 0;\n  bottom: 0;\n  right: 0;\n}\n\n.spinner-primary {\n  background: #8b5cf6;\n  background: linear-gradient(to right, #8b5cf6 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-primary:before {\n  background: #8b5cf6;\n}\n\n.spinner-secondary {\n  background: #1F2937;\n  background: linear-gradient(to right, #1F2937 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-secondary:before {\n  background: #1F2937;\n}\n\n.spinner-success {\n  background: #10b981;\n  background: linear-gradient(to right, #10b981 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-success:before {\n  background: #10b981;\n}\n\n.spinner-info {\n  background: #3b82f6;\n  background: linear-gradient(to right, #3b82f6 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-info:before {\n  background: #3b82f6;\n}\n\n.spinner-warning {\n  background: #f59e0b;\n  background: linear-gradient(to right, #f59e0b 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-warning:before {\n  background: #f59e0b;\n}\n\n.spinner-danger {\n  background: #ef4444;\n  background: linear-gradient(to right, #ef4444 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-danger:before {\n  background: #ef4444;\n}\n\n.spinner-light {\n  background: #6B7280;\n  background: linear-gradient(to right, #6B7280 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-light:before {\n  background: #6B7280;\n}\n\n.spinner-dark {\n  background: #111827;\n  background: linear-gradient(to right, #111827 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-dark:before {\n  background: #111827;\n}\n\n.spinner-gray-100 {\n  background: #F3F4F6;\n  background: linear-gradient(to right, #F3F4F6 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-100:before {\n  background: #F3F4F6;\n}\n\n.spinner-gray-200 {\n  background: #E5E7EB;\n  background: linear-gradient(to right, #E5E7EB 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-200:before {\n  background: #E5E7EB;\n}\n\n.spinner-gray-300 {\n  background: #D1D5DB;\n  background: linear-gradient(to right, #D1D5DB 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-300:before {\n  background: #D1D5DB;\n}\n\n.spinner-gray-400 {\n  background: #9CA3AF;\n  background: linear-gradient(to right, #9CA3AF 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-400:before {\n  background: #9CA3AF;\n}\n\n.spinner-gray-500 {\n  background: #6B7280;\n  background: linear-gradient(to right, #6B7280 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-500:before {\n  background: #6B7280;\n}\n\n.spinner-gray-600 {\n  background: #4B5563;\n  background: linear-gradient(to right, #4B5563 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-600:before {\n  background: #4B5563;\n}\n\n.spinner-gray-700 {\n  background: #374151;\n  background: linear-gradient(to right, #374151 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-700:before {\n  background: #374151;\n}\n\n.spinner-gray-800 {\n  background: #1F2937;\n  background: linear-gradient(to right, #1F2937 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-800:before {\n  background: #1F2937;\n}\n\n.spinner-gray-900 {\n  background: #111827;\n  background: linear-gradient(to right, #111827 10%, rgba(67, 236, 76, 0) 42%);\n}\n\n.spinner-gray-900:before {\n  background: #111827;\n}\n\n@-webkit-keyframes spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n\n@keyframes spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}\n\n.spinner-bubble {\n  display: inline-block;\n  font-size: 8px;\n  margin: 30px auto;\n  width: 1em;\n  height: 1em;\n  border-radius: 50%;\n  position: relative;\n  text-indent: -9999em;\n  -webkit-animation: bubble-circle 1.3s infinite linear;\n  animation: bubble-circle 1.3s infinite linear;\n  transform: translateZ(0);\n}\n\n.spinner-bubble-primary {\n  color: #8b5cf6;\n}\n\n.spinner-bubble-secondary {\n  color: #1F2937;\n}\n\n.spinner-bubble-success {\n  color: #10b981;\n}\n\n.spinner-bubble-info {\n  color: #3b82f6;\n}\n\n.spinner-bubble-warning {\n  color: #f59e0b;\n}\n\n.spinner-bubble-danger {\n  color: #ef4444;\n}\n\n.spinner-bubble-light {\n  color: #6B7280;\n}\n\n.spinner-bubble-dark {\n  color: #111827;\n}\n\n.spinner-bubble-gray-100 {\n  color: #F3F4F6;\n}\n\n.spinner-bubble-gray-200 {\n  color: #E5E7EB;\n}\n\n.spinner-bubble-gray-300 {\n  color: #D1D5DB;\n}\n\n.spinner-bubble-gray-400 {\n  color: #9CA3AF;\n}\n\n.spinner-bubble-gray-500 {\n  color: #6B7280;\n}\n\n.spinner-bubble-gray-600 {\n  color: #4B5563;\n}\n\n.spinner-bubble-gray-700 {\n  color: #374151;\n}\n\n.spinner-bubble-gray-800 {\n  color: #1F2937;\n}\n\n.spinner-bubble-gray-900 {\n  color: #111827;\n}\n\n@-webkit-keyframes bubble-circle {\n  0%,\n  100% {\n    box-shadow: 0 -3em 0 0.2em, 2em -2em 0 0em, 3em 0 0 -1em, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 -1em, -3em 0 0 -1em, -2em -2em 0 0;\n  }\n  12.5% {\n    box-shadow: 0 -3em 0 0, 2em -2em 0 0.2em, 3em 0 0 0, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 -1em, -3em 0 0 -1em, -2em -2em 0 -1em;\n  }\n  25% {\n    box-shadow: 0 -3em 0 -0.5em, 2em -2em 0 0, 3em 0 0 0.2em, 2em 2em 0 0, 0 3em 0 -1em, -2em 2em 0 -1em, -3em 0 0 -1em, -2em -2em 0 -1em;\n  }\n  37.5% {\n    box-shadow: 0 -3em 0 -1em, 2em -2em 0 -1em, 3em 0em 0 0, 2em 2em 0 0.2em, 0 3em 0 0em, -2em 2em 0 -1em, -3em 0em 0 -1em, -2em -2em 0 -1em;\n  }\n  50% {\n    box-shadow: 0 -3em 0 -1em, 2em -2em 0 -1em, 3em 0 0 -1em, 2em 2em 0 0em, 0 3em 0 0.2em, -2em 2em 0 0, -3em 0em 0 -1em, -2em -2em 0 -1em;\n  }\n  62.5% {\n    box-shadow: 0 -3em 0 -1em, 2em -2em 0 -1em, 3em 0 0 -1em, 2em 2em 0 -1em, 0 3em 0 0, -2em 2em 0 0.2em, -3em 0 0 0, -2em -2em 0 -1em;\n  }\n  75% {\n    box-shadow: 0em -3em 0 -1em, 2em -2em 0 -1em, 3em 0em 0 -1em, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 0, -3em 0em 0 0.2em, -2em -2em 0 0;\n  }\n  87.5% {\n    box-shadow: 0em -3em 0 0, 2em -2em 0 -1em, 3em 0 0 -1em, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 0, -3em 0em 0 0, -2em -2em 0 0.2em;\n  }\n}\n\n@keyframes bubble-circle {\n  0%,\n  100% {\n    box-shadow: 0 -3em 0 0.2em, 2em -2em 0 0em, 3em 0 0 -1em, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 -1em, -3em 0 0 -1em, -2em -2em 0 0;\n  }\n  12.5% {\n    box-shadow: 0 -3em 0 0, 2em -2em 0 0.2em, 3em 0 0 0, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 -1em, -3em 0 0 -1em, -2em -2em 0 -1em;\n  }\n  25% {\n    box-shadow: 0 -3em 0 -0.5em, 2em -2em 0 0, 3em 0 0 0.2em, 2em 2em 0 0, 0 3em 0 -1em, -2em 2em 0 -1em, -3em 0 0 -1em, -2em -2em 0 -1em;\n  }\n  37.5% {\n    box-shadow: 0 -3em 0 -1em, 2em -2em 0 -1em, 3em 0em 0 0, 2em 2em 0 0.2em, 0 3em 0 0em, -2em 2em 0 -1em, -3em 0em 0 -1em, -2em -2em 0 -1em;\n  }\n  50% {\n    box-shadow: 0 -3em 0 -1em, 2em -2em 0 -1em, 3em 0 0 -1em, 2em 2em 0 0em, 0 3em 0 0.2em, -2em 2em 0 0, -3em 0em 0 -1em, -2em -2em 0 -1em;\n  }\n  62.5% {\n    box-shadow: 0 -3em 0 -1em, 2em -2em 0 -1em, 3em 0 0 -1em, 2em 2em 0 -1em, 0 3em 0 0, -2em 2em 0 0.2em, -3em 0 0 0, -2em -2em 0 -1em;\n  }\n  75% {\n    box-shadow: 0em -3em 0 -1em, 2em -2em 0 -1em, 3em 0em 0 -1em, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 0, -3em 0em 0 0.2em, -2em -2em 0 0;\n  }\n  87.5% {\n    box-shadow: 0em -3em 0 0, 2em -2em 0 -1em, 3em 0 0 -1em, 2em 2em 0 -1em, 0 3em 0 -1em, -2em 2em 0 0, -3em 0em 0 0, -2em -2em 0 0.2em;\n  }\n}\n\n.loader-bubble,\n.loader-bubble:before,\n.loader-bubble:after {\n  border-radius: 50%;\n  width: 2em;\n  height: 2em;\n  -webkit-animation-fill-mode: both;\n  animation-fill-mode: both;\n  -webkit-animation: bubble-horz 1.8s infinite ease-in-out;\n  animation: bubble-horz 1.8s infinite ease-in-out;\n}\n\n.loader-bubble {\n  display: inline-block;\n  font-size: 6px;\n  margin: auto;\n  position: relative;\n  text-indent: -9999em;\n  transform: translateZ(0);\n  -webkit-animation-delay: -0.16s;\n  animation-delay: -0.16s;\n}\n\n.loader-bubble-primary {\n  color: #8b5cf6;\n}\n\n.loader-bubble-secondary {\n  color: #1F2937;\n}\n\n.loader-bubble-success {\n  color: #10b981;\n}\n\n.loader-bubble-info {\n  color: #3b82f6;\n}\n\n.loader-bubble-warning {\n  color: #f59e0b;\n}\n\n.loader-bubble-danger {\n  color: #ef4444;\n}\n\n.loader-bubble-light {\n  color: #6B7280;\n}\n\n.loader-bubble-dark {\n  color: #111827;\n}\n\n.loader-bubble-gray-100 {\n  color: #F3F4F6;\n}\n\n.loader-bubble-gray-200 {\n  color: #E5E7EB;\n}\n\n.loader-bubble-gray-300 {\n  color: #D1D5DB;\n}\n\n.loader-bubble-gray-400 {\n  color: #9CA3AF;\n}\n\n.loader-bubble-gray-500 {\n  color: #6B7280;\n}\n\n.loader-bubble-gray-600 {\n  color: #4B5563;\n}\n\n.loader-bubble-gray-700 {\n  color: #374151;\n}\n\n.loader-bubble-gray-800 {\n  color: #1F2937;\n}\n\n.loader-bubble-gray-900 {\n  color: #111827;\n}\n\n.loader-bubble:before,\n.loader-bubble:after {\n  content: '';\n  position: absolute;\n  top: 0;\n}\n\n.loader-bubble:before {\n  left: -3.5em;\n  -webkit-animation-delay: -0.32s;\n  animation-delay: -0.32s;\n}\n\n.loader-bubble:after {\n  left: 3.5em;\n}\n\n@-webkit-keyframes bubble-horz {\n  0%,\n  80%,\n  100% {\n    box-shadow: 0 2.5em 0 -1.3em;\n  }\n  40% {\n    box-shadow: 0 2.5em 0 0;\n  }\n}\n\n@keyframes bubble-horz {\n  0%,\n  80%,\n  100% {\n    box-shadow: 0 2.5em 0 -1.3em;\n  }\n  40% {\n    box-shadow: 0 2.5em 0 0;\n  }\n}\n\n.alert {\n  border-radius: 10px;\n}\n\n.alert .close:focus {\n  outline: 0;\n}\n\n.alert-card {\n  border: none;\n  box-shadow: 0 4px 15px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.1), inset 0 2px 0 0 #9CA3AF;\n}\n\n.alert-card.alert-success {\n  box-shadow: 0 4px 15px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.1), inset 0 2px 0 0 #10b981;\n}\n\n.alert-card.alert-warning {\n  box-shadow: 0 4px 15px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.1), inset 0 2px 0 0 #f59e0b;\n}\n\n.alert-card.alert-info {\n  box-shadow: 0 4px 15px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.1), inset 0 2px 0 0 #3b82f6;\n}\n\n.alert-card.alert-danger {\n  box-shadow: 0 4px 15px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.1), inset 0 2px 0 0 #ef4444;\n}\n\n.alert-card.alert-dark {\n  box-shadow: 0 4px 15px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.1), inset 0 2px 0 0 #4B5563;\n}\n\n.swal2-container .swal2-modal {\n  font-family: \"Nunito\", sans-serif;\n}\n\n.swal2-container .swal2-spacer {\n  margin: 1.5rem 0;\n}\n\n.swal2-container .swal2-styled:not(.swal2-cancel) {\n  background: #8b5cf6 !important;\n  outline: none;\n}\n\n.swal2-container .swal2-styled:not(.swal2-cancel):focus {\n  box-shadow: 0 0 0 0.2rem rgba(139, 92, 246, 0.5);\n}\n\n.sidebar-container {\n  position: relative;\n  overflow: hidden;\n  min-height: 400px;\n}\n\n.sidebar-container .sidebar-content {\n  position: relative;\n  height: 100%;\n  transition: all .3s ease-in;\n}\n\n.sidebar-container .sidebar-content:after {\n  position: absolute;\n  content: \"\";\n  left: 0;\n  right: 0;\n  width: 100%;\n  height: 100%;\n}\n\n.sidebar-container .sidebar {\n  position: absolute;\n  top: 0;\n  transition: all .3s ease-in;\n  z-index: 60;\n}\n\n.sidebar-container .sidebar .sidebar-close {\n  display: none;\n  position: absolute;\n  top: 4px;\n  right: 4px;\n  cursor: pointer;\n  z-index: 999;\n}\n\n@media (max-width: 767px) {\n  .sidebar-container .sidebar {\n    background: #fff;\n  }\n  .sidebar-container .sidebar .sidebar-close {\n    display: block;\n  }\n}\n\n.badge {\n  font-weight: 600;\n}\n\n.badge-outline-primary {\n  background: unset;\n  border: 1px solid #8b5cf6;\n  color: #8b5cf6;\n}\n\n.badge-outline-secondary {\n  background: unset;\n  border: 1px solid #1F2937;\n  color: #1F2937;\n}\n\n.badge-outline-success {\n  background: unset;\n  border: 1px solid #10b981;\n  color: #10b981;\n}\n\n.badge-outline-info {\n  background: unset;\n  border: 1px solid #3b82f6;\n  color: #3b82f6;\n}\n\n.badge-outline-warning {\n  background: unset;\n  border: 1px solid #f59e0b;\n  color: #f59e0b;\n}\n\n.badge-outline-danger {\n  background: unset;\n  border: 1px solid #ef4444;\n  color: #ef4444;\n}\n\n.badge-outline-light {\n  background: unset;\n  border: 1px solid #6B7280;\n  color: #6B7280;\n}\n\n.badge-outline-dark {\n  background: unset;\n  border: 1px solid #111827;\n  color: #111827;\n}\n\n.badge-outline-gray-100 {\n  background: unset;\n  border: 1px solid #F3F4F6;\n  color: #F3F4F6;\n}\n\n.badge-outline-gray-200 {\n  background: unset;\n  border: 1px solid #E5E7EB;\n  color: #E5E7EB;\n}\n\n.badge-outline-gray-300 {\n  background: unset;\n  border: 1px solid #D1D5DB;\n  color: #D1D5DB;\n}\n\n.badge-outline-gray-400 {\n  background: unset;\n  border: 1px solid #9CA3AF;\n  color: #9CA3AF;\n}\n\n.badge-outline-gray-500 {\n  background: unset;\n  border: 1px solid #6B7280;\n  color: #6B7280;\n}\n\n.badge-outline-gray-600 {\n  background: unset;\n  border: 1px solid #4B5563;\n  color: #4B5563;\n}\n\n.badge-outline-gray-700 {\n  background: unset;\n  border: 1px solid #374151;\n  color: #374151;\n}\n\n.badge-outline-gray-800 {\n  background: unset;\n  border: 1px solid #1F2937;\n  color: #1F2937;\n}\n\n.badge-outline-gray-900 {\n  background: unset;\n  border: 1px solid #111827;\n  color: #111827;\n}\n\n.badge-top-container {\n  position: relative;\n}\n\n.badge-top-container .badge {\n  position: absolute;\n  top: 2px;\n  right: 4px;\n  border-radius: 10px;\n}\n\n.ul-badge-pill-primary {\n  background: #8b5cf6;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-secondary {\n  background: #1F2937;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-success {\n  background: #10b981;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-info {\n  background: #3b82f6;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-warning {\n  background: #f59e0b;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-danger {\n  background: #ef4444;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-light {\n  background: #6B7280;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-dark {\n  background: #111827;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-100 {\n  background: #F3F4F6;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-200 {\n  background: #E5E7EB;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-300 {\n  background: #D1D5DB;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-400 {\n  background: #9CA3AF;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-500 {\n  background: #6B7280;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-600 {\n  background: #4B5563;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-700 {\n  background: #374151;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-800 {\n  background: #1F2937;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.ul-badge-pill-gray-900 {\n  background: #111827;\n  border-radius: 50%;\n  width: 25px;\n  height: 18px;\n  color: #fff;\n  line-height: 20px;\n  font-size: 0.8rem;\n}\n\n.badge-round-primary {\n  background: #8b5cf6;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-primary.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-primary.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-primary.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-primary.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-secondary {\n  background: #1F2937;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-secondary.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-secondary.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-secondary.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-secondary.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-success {\n  background: #10b981;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-success.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-success.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-success.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-success.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-info {\n  background: #3b82f6;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-info.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-info.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-info.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-info.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-warning {\n  background: #f59e0b;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-warning.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-warning.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-warning.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-warning.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-danger {\n  background: #ef4444;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-danger.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-danger.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-danger.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-danger.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-light {\n  background: #6B7280;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-light.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-light.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-light.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-light.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-dark {\n  background: #111827;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-dark.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-dark.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-dark.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-dark.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-100 {\n  background: #F3F4F6;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-100.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-100.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-100.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-100.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-200 {\n  background: #E5E7EB;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-200.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-200.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-200.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-200.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-300 {\n  background: #D1D5DB;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-300.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-300.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-300.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-300.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-400 {\n  background: #9CA3AF;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-400.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-400.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-400.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-400.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-500 {\n  background: #6B7280;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-500.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-500.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-500.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-500.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-600 {\n  background: #4B5563;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-600.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-600.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-600.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-600.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-700 {\n  background: #374151;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-700.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-700.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-700.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-700.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-800 {\n  background: #1F2937;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-800.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-800.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-800.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-800.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-round-gray-900 {\n  background: #111827;\n  border-radius: 50%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  justify-content: center;\n}\n\n.badge-round-gray-900.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round-gray-900.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round-gray-900.sm {\n  width: 18px;\n  height: 18px;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-round-gray-900.pill {\n  width: 45px;\n  height: 18px;\n  line-height: 13px;\n  border-radius: 10px;\n}\n\n.badge-dot-primary {\n  height: 4px;\n  width: 4px;\n  background-color: #8b5cf6;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-secondary {\n  height: 4px;\n  width: 4px;\n  background-color: #1F2937;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-success {\n  height: 4px;\n  width: 4px;\n  background-color: #10b981;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-info {\n  height: 4px;\n  width: 4px;\n  background-color: #3b82f6;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-warning {\n  height: 4px;\n  width: 4px;\n  background-color: #f59e0b;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-danger {\n  height: 4px;\n  width: 4px;\n  background-color: #ef4444;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-light {\n  height: 4px;\n  width: 4px;\n  background-color: #6B7280;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-dark {\n  height: 4px;\n  width: 4px;\n  background-color: #111827;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-100 {\n  height: 4px;\n  width: 4px;\n  background-color: #F3F4F6;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-200 {\n  height: 4px;\n  width: 4px;\n  background-color: #E5E7EB;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-300 {\n  height: 4px;\n  width: 4px;\n  background-color: #D1D5DB;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-400 {\n  height: 4px;\n  width: 4px;\n  background-color: #9CA3AF;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-500 {\n  height: 4px;\n  width: 4px;\n  background-color: #6B7280;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-600 {\n  height: 4px;\n  width: 4px;\n  background-color: #4B5563;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-700 {\n  height: 4px;\n  width: 4px;\n  background-color: #374151;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-800 {\n  height: 4px;\n  width: 4px;\n  background-color: #1F2937;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.badge-dot-gray-900 {\n  height: 4px;\n  width: 4px;\n  background-color: #111827;\n  border-radius: 50%;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.outline-round-primary {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #8b5cf6;\n  color: #8b5cf6;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-secondary {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #1F2937;\n  color: #1F2937;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-success {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #10b981;\n  color: #10b981;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-info {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #3b82f6;\n  color: #3b82f6;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-warning {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #f59e0b;\n  color: #f59e0b;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-danger {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #ef4444;\n  color: #ef4444;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-light {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #6B7280;\n  color: #6B7280;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-dark {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #111827;\n  color: #111827;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-100 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #F3F4F6;\n  color: #F3F4F6;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-200 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #E5E7EB;\n  color: #E5E7EB;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-300 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #D1D5DB;\n  color: #D1D5DB;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-400 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #9CA3AF;\n  color: #9CA3AF;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-500 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #6B7280;\n  color: #6B7280;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-600 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #4B5563;\n  color: #4B5563;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-700 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #374151;\n  color: #374151;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-800 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #1F2937;\n  color: #1F2937;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.outline-round-gray-900 {\n  background: #fff;\n  border-radius: 50%;\n  width: 18px;\n  height: 18px;\n  border: 1px solid #111827;\n  color: #111827;\n  line-height: 13px;\n  justify-content: center;\n}\n\n.badge-square-primary {\n  background: #8b5cf6;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-primary.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-primary.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-secondary {\n  background: #1F2937;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-secondary.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-secondary.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-success {\n  background: #10b981;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-success.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-success.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-info {\n  background: #3b82f6;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-info.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-info.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-warning {\n  background: #f59e0b;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-warning.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-warning.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-danger {\n  background: #ef4444;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-danger.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-danger.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-light {\n  background: #6B7280;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-light.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-light.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-dark {\n  background: #111827;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-dark.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-dark.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-100 {\n  background: #F3F4F6;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-100.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-100.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-200 {\n  background: #E5E7EB;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-200.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-200.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-300 {\n  background: #D1D5DB;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-300.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-300.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-400 {\n  background: #9CA3AF;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-400.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-400.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-500 {\n  background: #6B7280;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-500.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-500.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-600 {\n  background: #4B5563;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-600.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-600.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-700 {\n  background: #374151;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-700.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-700.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-800 {\n  background: #1F2937;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-800.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-800.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-square-gray-900 {\n  background: #111827;\n  border-radius: 20%;\n  width: 25px;\n  height: 25px;\n  color: #fff;\n  line-height: 20px;\n  text-align: center;\n}\n\n.badge-square-gray-900.lg {\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square-gray-900.xl {\n  width: 50px;\n  height: 50px;\n  line-height: 40px;\n  font-size: 1.3rem;\n  font-weight: bold;\n}\n\n.badge-round {\n  border-radius: 50%;\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-round.badge-round-opacity-primary {\n  background: white;\n  color: #8b5cf6;\n}\n\n.badge-round.badge-round-opacity-secondary {\n  background: #728cb0;\n  color: #1F2937;\n}\n\n.badge-round.badge-round-opacity-success {\n  background: #9ef7d9;\n  color: #10b981;\n}\n\n.badge-round.badge-round-opacity-info {\n  background: #fefeff;\n  color: #3b82f6;\n}\n\n.badge-round.badge-round-opacity-warning {\n  background: #fdeccf;\n  color: #f59e0b;\n}\n\n.badge-round.badge-round-opacity-danger {\n  background: white;\n  color: #ef4444;\n}\n\n.badge-round.badge-round-opacity-light {\n  background: #d8dadf;\n  color: #6B7280;\n}\n\n.badge-round.badge-round-opacity-dark {\n  background: #5170b3;\n  color: #111827;\n}\n\n.badge-round.badge-round-opacity-gray-100 {\n  background: white;\n  color: #F3F4F6;\n}\n\n.badge-round.badge-round-opacity-gray-200 {\n  background: white;\n  color: #E5E7EB;\n}\n\n.badge-round.badge-round-opacity-gray-300 {\n  background: white;\n  color: #D1D5DB;\n}\n\n.badge-round.badge-round-opacity-gray-400 {\n  background: white;\n  color: #9CA3AF;\n}\n\n.badge-round.badge-round-opacity-gray-500 {\n  background: #d8dadf;\n  color: #6B7280;\n}\n\n.badge-round.badge-round-opacity-gray-600 {\n  background: #b4bbc6;\n  color: #4B5563;\n}\n\n.badge-round.badge-round-opacity-gray-700 {\n  background: #9aa6ba;\n  color: #374151;\n}\n\n.badge-round.badge-round-opacity-gray-800 {\n  background: #728cb0;\n  color: #1F2937;\n}\n\n.badge-round.badge-round-opacity-gray-900 {\n  background: #5170b3;\n  color: #111827;\n}\n\n.badge-square {\n  border-radius: 20%;\n  width: 40px;\n  height: 40px;\n  line-height: 30px;\n  font-size: 1.2rem;\n}\n\n.badge-square.badge-square-opacity-primary {\n  background: white;\n  color: #8b5cf6;\n}\n\n.badge-square.badge-square-opacity-secondary {\n  background: #728cb0;\n  color: #1F2937;\n}\n\n.badge-square.badge-square-opacity-success {\n  background: #9ef7d9;\n  color: #10b981;\n}\n\n.badge-square.badge-square-opacity-info {\n  background: #fefeff;\n  color: #3b82f6;\n}\n\n.badge-square.badge-square-opacity-warning {\n  background: #fdeccf;\n  color: #f59e0b;\n}\n\n.badge-square.badge-square-opacity-danger {\n  background: white;\n  color: #ef4444;\n}\n\n.badge-square.badge-square-opacity-light {\n  background: #d8dadf;\n  color: #6B7280;\n}\n\n.badge-square.badge-square-opacity-dark {\n  background: #5170b3;\n  color: #111827;\n}\n\n.badge-square.badge-square-opacity-gray-100 {\n  background: white;\n  color: #F3F4F6;\n}\n\n.badge-square.badge-square-opacity-gray-200 {\n  background: white;\n  color: #E5E7EB;\n}\n\n.badge-square.badge-square-opacity-gray-300 {\n  background: white;\n  color: #D1D5DB;\n}\n\n.badge-square.badge-square-opacity-gray-400 {\n  background: white;\n  color: #9CA3AF;\n}\n\n.badge-square.badge-square-opacity-gray-500 {\n  background: #d8dadf;\n  color: #6B7280;\n}\n\n.badge-square.badge-square-opacity-gray-600 {\n  background: #b4bbc6;\n  color: #4B5563;\n}\n\n.badge-square.badge-square-opacity-gray-700 {\n  background: #9aa6ba;\n  color: #374151;\n}\n\n.badge-square.badge-square-opacity-gray-800 {\n  background: #728cb0;\n  color: #1F2937;\n}\n\n.badge-square.badge-square-opacity-gray-900 {\n  background: #5170b3;\n  color: #111827;\n}\n\n.w-badge {\n  border-radius: 0;\n  padding: 4px;\n  color: #fff;\n}\n\n.r-badge {\n  padding: 4px;\n}\n\n.popover {\n  border: none;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.08);\n}\n\n.popover .arrow::before {\n  border-color: rgba(0, 0, 0, 0);\n}\n\n.search-ui {\n  position: fixed;\n  background: #fff;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  margin: auto;\n  padding: 0.75rem 1.5rem 1.5rem 4.5rem;\n  z-index: 999;\n  display: none;\n}\n\n.search-ui.open {\n  display: block;\n  -webkit-animation-name: slideInDown;\n  animation-name: slideInDown;\n  -webkit-animation-iteration-count: 1;\n  animation-iteration-count: 1;\n  -webkit-animation-duration: 0.3s;\n  animation-duration: 0.3s;\n  -webkit-animation-delay: 0;\n  animation-delay: 0;\n  -webkit-animation-timing-function: ease;\n  animation-timing-function: ease;\n  -webkit-animation-fill-mode: both;\n  animation-fill-mode: both;\n  -webkit-backface-visibility: hidden;\n  backface-visibility: hidden;\n  z-index: 999;\n}\n\n.search-ui .search-header .logo {\n  height: 64px;\n  width: auto;\n}\n\n.search-ui .search-height {\n  height: 55vh;\n}\n\n.search-ui input.search-input {\n  font-size: 4rem;\n  font-weight: 600;\n  border: 0;\n  margin-bottom: 1.5rem;\n}\n\n.search-ui input.search-input:focus {\n  outline: 0;\n}\n\n.search-ui input.search-input::-moz-placeholder {\n  color: #9CA3AF;\n}\n\n.search-ui input.search-input:-ms-input-placeholder {\n  color: #9CA3AF;\n}\n\n.search-ui input.search-input::placeholder {\n  color: #9CA3AF;\n}\n\n.search-ui .search-title {\n  margin-bottom: 1.25rem;\n}\n\n.search-ui .search-title span {\n  font-weight: 600;\n}\n\n@media (max-width: 767px) {\n  .search-ui {\n    padding: 1rem;\n  }\n}\n\n/* Tagging Basic Style */\n.tagging {\n  border: 1px solid #D1D5DB;\n  font-size: 1em;\n  height: auto;\n  padding: 10px 10px 15px;\n  border-radius: 4px;\n}\n\n.tagging.editable {\n  cursor: text;\n}\n\n.tag {\n  background: none repeat scroll 0 0 #8b5cf6;\n  border-radius: 2px;\n  color: white;\n  cursor: default;\n  display: inline-block;\n  position: relative;\n  white-space: nowrap;\n  padding: 4px 20px 4px 0;\n  margin: 5px 10px 0 0;\n}\n\n.tag span {\n  background: none repeat scroll 0 0 #7a44f5;\n  border-radius: 2px 0 0 2px;\n  margin-right: 5px;\n  padding: 5px 10px 5px;\n}\n\n.tag .tag-i {\n  color: white;\n  cursor: pointer;\n  font-size: 1.3em;\n  height: 0;\n  line-height: 0.1em;\n  position: absolute;\n  right: 5px;\n  top: 0.7em;\n  text-align: center;\n  width: 10px;\n}\n\n.tag .tag-i:hover {\n  color: black;\n  text-decoration: underline;\n}\n\n.type-zone {\n  border: 0 none;\n  height: auto;\n  width: auto;\n  min-width: 20px;\n  display: inline-block;\n}\n\n.type-zone:focus {\n  outline: none;\n}\n\n.customizer {\n  position: fixed;\n  z-index: 9999;\n  top: 100px;\n  right: -380px;\n  transition: 0.3s all ease-in-out;\n  width: 380px;\n}\n\n.customizer.open {\n  right: 0;\n}\n\n.customizer .handle {\n  position: absolute;\n  display: flex;\n  top: 8px;\n  left: -36px;\n  background: #8b5cf6;\n  cursor: pointer;\n  padding: 10px 8px;\n  border-top-left-radius: 4px;\n  border-bottom-left-radius: 4px;\n  box-shadow: -3px 0px 4px rgba(0, 0, 0, 0.06);\n  color: #fff;\n  font-size: 20px;\n  transition: 0.3s all ease-in-out;\n}\n\n.customizer .handle:hover {\n  background: #8b5cf6;\n  color: #fff;\n}\n\n.customizer .customizer-body {\n  border-top-left-radius: 10px;\n  border-bottom-left-radius: 10px;\n  background: #fff;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.08);\n  max-height: calc(100vh - 140px);\n  overflow-y: scroll;\n  overflow-x: visible;\n}\n\n.customizer .customizer-body .layouts {\n  display: flex;\n  flex-wrap: wrap;\n  margin: 0 -8px;\n}\n\n.customizer .customizer-body .layouts .layout-box {\n  position: relative;\n  margin: 0 8px;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.03);\n  border-radius: 8px;\n  overflow: hidden;\n  cursor: pointer;\n  width: calc(50% - 16px);\n  border: 1px solid rgba(0, 0, 0, 0.08);\n}\n\n.customizer .customizer-body .layouts .layout-box img {\n  width: 180px;\n}\n\n.customizer .customizer-body .layouts .layout-box i {\n  display: none;\n  position: absolute;\n  top: 0;\n  text-align: center;\n  right: 0;\n  height: 24px;\n  font-size: 18px;\n  line-height: 24px;\n  width: 32px;\n  color: #ffffff;\n  background: #8b5cf6;\n  border-radius: 0 0 0 6px;\n}\n\n.customizer .customizer-body .layouts .layout-box.active {\n  border: 1px solid #8b5cf6;\n}\n\n.customizer .customizer-body .layouts .layout-box.active i {\n  display: inline-block;\n}\n\n.customizer .customizer-body .colors {\n  display: flex;\n  flex-wrap: wrap;\n}\n\n.customizer .customizer-body .colors .color {\n  width: 36px;\n  height: 36px;\n  display: inline-block;\n  border-radius: 50%;\n  margin: 8px;\n  text-align: center;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.03);\n  cursor: pointer;\n}\n\n.customizer .customizer-body .colors .color.purple {\n  background: #8b5cf6;\n}\n\n.customizer .customizer-body .colors .color.blue {\n  background: #2f47c2;\n}\n\n.customizer .customizer-body .colors .color i {\n  display: none;\n  color: #ffffff;\n  font-size: 18px;\n  line-height: 36px;\n}\n\n.customizer .customizer-body .colors .color.active i {\n  display: unset;\n}\n\n@media (max-width: 767px) {\n  .customizer {\n    width: 280px;\n    right: -280px;\n  }\n}\n\n[dir=\"rtl\"] .customizer {\n  right: auto;\n  left: -380px;\n}\n\n[dir=\"rtl\"] .customizer.open {\n  right: auto;\n  left: 0;\n}\n\n[dir=\"rtl\"] .customizer .handle {\n  top: 8px;\n  left: auto;\n  right: -36px;\n  border-top-left-radius: 0;\n  border-top-right-radius: 4px;\n  border-bottom-left-radius: 0;\n  border-bottom-right-radius: 4px;\n  box-shadow: -3px 0px 4px rgba(0, 0, 0, 0.06);\n}\n\n.slider-default {\n  background: #FAFAFA !important;\n  border-radius: 15px !important;\n  border: 0px solid #D3D3D3 !important;\n  box-shadow: inset 0 1px 1px #F0F0F0, 0 3px 6px -5px #BBB;\n  height: 10px !important;\n}\n\n.slider-default .noUi-value-horizontal {\n  display: none;\n}\n\n.slider-default .noUi-handle {\n  width: 20px !important;\n  height: 20px !important;\n  left: -5px !important;\n  top: -5px !important;\n  border-radius: 50%;\n  border: 5px solid #8b5cf6;\n  box-shadow: none;\n  cursor: pointer;\n}\n\n.slider-default .noUi-handle:after,\n.slider-default .noUi-handle:before {\n  content: none !important;\n  display: block;\n  position: absolute;\n  height: 14px;\n  width: 1px;\n  background: #E8E7E6;\n  left: 14px;\n  top: 6px;\n}\n\n.slider-default .noUi-handle:focus {\n  outline: none;\n}\n\n.slider-default .noUi-connect {\n  background: #8b5cf6;\n  border-radius: 15px !important;\n  box-shadow: inset 0 0 3px rgba(51, 51, 51, 0.45);\n  transition: background 450ms;\n}\n\n.square-default {\n  background: #FAFAFA !important;\n  border-radius: 15px !important;\n  border: 0px solid #D3D3D3 !important;\n  box-shadow: inset 0 1px 1px #F0F0F0, 0 3px 6px -5px #BBB;\n  height: 10px !important;\n}\n\n.square-default .noUi-handle {\n  width: 20px !important;\n  height: 20px !important;\n  border: 5px solid #8b5cf6;\n  box-shadow: none;\n  cursor: pointer;\n}\n\n.square-default .noUi-handle:after,\n.square-default .noUi-handle:before {\n  content: \" \" !important;\n  display: none;\n  position: absolute;\n  height: 14px;\n  width: 1px;\n  background: #E8E7E6;\n  left: 14px;\n  top: 6px;\n}\n\n.square-default .noUi-handle:focus {\n  outline: none;\n}\n\n.square-default .noUi-connect {\n  background: #8b5cf6;\n  border-radius: 15px !important;\n  box-shadow: inset 0 0 3px rgba(51, 51, 51, 0.45);\n  transition: background 450ms;\n}\n\n.slider-primary .noUi-connect {\n  background: #8b5cf6;\n}\n\n.slider-primary .noUi-handle {\n  border: 5px solid #8b5cf6;\n}\n\n.slider-secondary .noUi-connect {\n  background: #1F2937;\n}\n\n.slider-secondary .noUi-handle {\n  border: 5px solid #1F2937;\n}\n\n.slider-success .noUi-connect {\n  background: #10b981;\n}\n\n.slider-success .noUi-handle {\n  border: 5px solid #10b981;\n}\n\n.slider-info .noUi-connect {\n  background: #3b82f6;\n}\n\n.slider-info .noUi-handle {\n  border: 5px solid #3b82f6;\n}\n\n.slider-warning .noUi-connect {\n  background: #f59e0b;\n}\n\n.slider-warning .noUi-handle {\n  border: 5px solid #f59e0b;\n}\n\n.slider-danger .noUi-connect {\n  background: #ef4444;\n}\n\n.slider-danger .noUi-handle {\n  border: 5px solid #ef4444;\n}\n\n.slider-light .noUi-connect {\n  background: #6B7280;\n}\n\n.slider-light .noUi-handle {\n  border: 5px solid #6B7280;\n}\n\n.slider-dark .noUi-connect {\n  background: #111827;\n}\n\n.slider-dark .noUi-handle {\n  border: 5px solid #111827;\n}\n\n.slider-gray-100 .noUi-connect {\n  background: #F3F4F6;\n}\n\n.slider-gray-100 .noUi-handle {\n  border: 5px solid #F3F4F6;\n}\n\n.slider-gray-200 .noUi-connect {\n  background: #E5E7EB;\n}\n\n.slider-gray-200 .noUi-handle {\n  border: 5px solid #E5E7EB;\n}\n\n.slider-gray-300 .noUi-connect {\n  background: #D1D5DB;\n}\n\n.slider-gray-300 .noUi-handle {\n  border: 5px solid #D1D5DB;\n}\n\n.slider-gray-400 .noUi-connect {\n  background: #9CA3AF;\n}\n\n.slider-gray-400 .noUi-handle {\n  border: 5px solid #9CA3AF;\n}\n\n.slider-gray-500 .noUi-connect {\n  background: #6B7280;\n}\n\n.slider-gray-500 .noUi-handle {\n  border: 5px solid #6B7280;\n}\n\n.slider-gray-600 .noUi-connect {\n  background: #4B5563;\n}\n\n.slider-gray-600 .noUi-handle {\n  border: 5px solid #4B5563;\n}\n\n.slider-gray-700 .noUi-connect {\n  background: #374151;\n}\n\n.slider-gray-700 .noUi-handle {\n  border: 5px solid #374151;\n}\n\n.slider-gray-800 .noUi-connect {\n  background: #1F2937;\n}\n\n.slider-gray-800 .noUi-handle {\n  border: 5px solid #1F2937;\n}\n\n.slider-gray-900 .noUi-connect {\n  background: #111827;\n}\n\n.slider-gray-900 .noUi-handle {\n  border: 5px solid #111827;\n}\n\n.slider-custom .noUi-connect {\n  background: #3FB8AF;\n}\n\n.slider-custom .noUi-handle {\n  border: 5px solid #B2DFDB;\n}\n\n.slider-extra-large {\n  height: 14px !important;\n}\n\n.slider-extra-large .noUi-handle {\n  width: 28px !important;\n  height: 28px !important;\n  top: -7px !important;\n}\n\n.slider-large {\n  height: 12px !important;\n}\n\n.slider-large .noUi-handle {\n  width: 24px !important;\n  height: 24px !important;\n  top: -6px !important;\n}\n\n.slider-small {\n  height: 6px !important;\n}\n\n.slider-small .noUi-handle {\n  top: -7px !important;\n}\n\n.slider-extra-small {\n  height: 3px !important;\n}\n\n.slider-extra-small .noUi-handle {\n  top: -8px !important;\n}\n\n.circle-filled.slider-primary .noUi-handle {\n  background: #8b5cf6;\n}\n\n.circle-filled.slider-secondary .noUi-handle {\n  background: #1F2937;\n}\n\n.circle-filled.slider-success .noUi-handle {\n  background: #10b981;\n}\n\n.circle-filled.slider-info .noUi-handle {\n  background: #3b82f6;\n}\n\n.circle-filled.slider-warning .noUi-handle {\n  background: #f59e0b;\n}\n\n.circle-filled.slider-danger .noUi-handle {\n  background: #ef4444;\n}\n\n.circle-filled.slider-light .noUi-handle {\n  background: #6B7280;\n}\n\n.circle-filled.slider-dark .noUi-handle {\n  background: #111827;\n}\n\n.circle-filled.slider-gray-100 .noUi-handle {\n  background: #F3F4F6;\n}\n\n.circle-filled.slider-gray-200 .noUi-handle {\n  background: #E5E7EB;\n}\n\n.circle-filled.slider-gray-300 .noUi-handle {\n  background: #D1D5DB;\n}\n\n.circle-filled.slider-gray-400 .noUi-handle {\n  background: #9CA3AF;\n}\n\n.circle-filled.slider-gray-500 .noUi-handle {\n  background: #6B7280;\n}\n\n.circle-filled.slider-gray-600 .noUi-handle {\n  background: #4B5563;\n}\n\n.circle-filled.slider-gray-700 .noUi-handle {\n  background: #374151;\n}\n\n.circle-filled.slider-gray-800 .noUi-handle {\n  background: #1F2937;\n}\n\n.circle-filled.slider-gray-900 .noUi-handle {\n  background: #111827;\n}\n\n.square-default.slider-primary .noUi-handle {\n  background: #8b5cf6;\n}\n\n.square-default.slider-secondary .noUi-handle {\n  background: #1F2937;\n}\n\n.square-default.slider-success .noUi-handle {\n  background: #10b981;\n}\n\n.square-default.slider-info .noUi-handle {\n  background: #3b82f6;\n}\n\n.square-default.slider-warning .noUi-handle {\n  background: #f59e0b;\n}\n\n.square-default.slider-danger .noUi-handle {\n  background: #ef4444;\n}\n\n.square-default.slider-light .noUi-handle {\n  background: #6B7280;\n}\n\n.square-default.slider-dark .noUi-handle {\n  background: #111827;\n}\n\n.square-default.slider-gray-100 .noUi-handle {\n  background: #F3F4F6;\n}\n\n.square-default.slider-gray-200 .noUi-handle {\n  background: #E5E7EB;\n}\n\n.square-default.slider-gray-300 .noUi-handle {\n  background: #D1D5DB;\n}\n\n.square-default.slider-gray-400 .noUi-handle {\n  background: #9CA3AF;\n}\n\n.square-default.slider-gray-500 .noUi-handle {\n  background: #6B7280;\n}\n\n.square-default.slider-gray-600 .noUi-handle {\n  background: #4B5563;\n}\n\n.square-default.slider-gray-700 .noUi-handle {\n  background: #374151;\n}\n\n.square-default.slider-gray-800 .noUi-handle {\n  background: #1F2937;\n}\n\n.square-default.slider-gray-900 .noUi-handle {\n  background: #111827;\n}\n\n.square-default.slider-custom .noUi-handle,\n.circle-filled.slider-custom .noUi-handle {\n  background: #B2DFDB;\n}\n\n.vertical-slider-example {\n  display: inline-block;\n}\n\n.noUi-vertical {\n  width: 10px !important;\n  height: 150px !important;\n}\n\n.toast-primary {\n  background-color: #8b5cf6 !important;\n}\n\n.toast-secondary {\n  background-color: #1F2937 !important;\n}\n\n.toast-success {\n  background-color: #10b981 !important;\n}\n\n.toast-info {\n  background-color: #3b82f6 !important;\n}\n\n.toast-warning {\n  background-color: #f59e0b !important;\n}\n\n.toast-danger {\n  background-color: #ef4444 !important;\n}\n\n.toast-light {\n  background-color: #6B7280 !important;\n}\n\n.toast-dark {\n  background-color: #111827 !important;\n}\n\n.toast-gray-100 {\n  background-color: #F3F4F6 !important;\n}\n\n.toast-gray-200 {\n  background-color: #E5E7EB !important;\n}\n\n.toast-gray-300 {\n  background-color: #D1D5DB !important;\n}\n\n.toast-gray-400 {\n  background-color: #9CA3AF !important;\n}\n\n.toast-gray-500 {\n  background-color: #6B7280 !important;\n}\n\n.toast-gray-600 {\n  background-color: #4B5563 !important;\n}\n\n.toast-gray-700 {\n  background-color: #374151 !important;\n}\n\n.toast-gray-800 {\n  background-color: #1F2937 !important;\n}\n\n.toast-gray-900 {\n  background-color: #111827 !important;\n}\n\n.dropzone {\n  min-height: 150px;\n  border: 2px dashed #673ab75e !important;\n  background: #F5F5F5 !important;\n  padding: 20px 20px;\n}\n\n.nav-tabs {\n  border-bottom: 1px solid #8b5cf6;\n}\n\n.nav-tabs .nav-item .nav-link.active {\n  border: 1px solid transparent;\n  background: rgba(102, 51, 153, 0.1);\n  border-color: #8b5cf6 #8b5cf6 #fff;\n}\n\n.dropdown-toggle:after {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  right: 5px;\n  vertical-align: .255em;\n  content: \"\";\n  border-top: .3em solid;\n  border-right: .3em solid transparent;\n  border-bottom: 0;\n  border-left: .3em solid transparent;\n}\n\n#calendar {\n  float: right;\n  width: 100%;\n}\n\n#external-events h4 {\n  font-size: 16px;\n  margin-top: 0;\n  padding-top: 1em;\n}\n\n#external-events .fc-event {\n  margin: 2px 0;\n  cursor: move;\n}\n\n.create_event_wrap p {\n  margin: 1.5em 0;\n  font-size: 11px;\n  color: #666;\n}\n\n.create_event_wrap p input {\n  margin: 0;\n  vertical-align: middle;\n}\n\n.fc-event {\n  position: relative;\n  display: block;\n  font-size: .85em;\n  line-height: 1.3;\n  border-radius: 3px;\n  border: 0px solid #8b5cf6 !important;\n}\n\na.fc-day-grid-event {\n  background: #8b5cf6;\n  padding: 5px;\n}\n\nth.fc-day-header {\n  border-bottom-width: 2px;\n  padding: 10px 0px;\n  display: table-cell;\n  background: #F5F5F5;\n  font-size: 16px;\n  font-weight: bold;\n  text-align: center;\n}\n\ntd.fc-head-container {\n  padding: 0px !important;\n}\n\n.fc-toolbar h2 {\n  margin: 0;\n  font-weight: bold;\n}\n\nspan.fa {\n  font-family: 'iconsmind' !important;\n  speak: none;\n  font-style: normal;\n  font-weight: normal;\n  font-variant: normal;\n  text-transform: none;\n  line-height: 1;\n  -webkit-font-smoothing: antialiased;\n}\n\nspan.fa.fa-chevron-left:before {\n  content: \"\\F077\";\n}\n\nspan.fa.fa-chevron-right:before {\n  content: \"\\F07D\";\n}\n\n.echarts {\n  width: 100%;\n  height: 100%;\n}\n\ntable.tableOne.vgt-table thead tr th {\n  background: #fff;\n}\n\ntable.tableOne.vgt-table {\n  font-size: 13px;\n}\n\n.vgt-global-search.vgt-clearfix {\n  background: #fff;\n}\n\n.vgt-table.full-height {\n  min-height: 308px !important;\n}\n\n.vgt-table.non-height {\n  min-height: none !important;\n}\n\n.vgt-wrap .vgt-inner-wrap {\n  box-shadow: unset !important;\n}\n\ndiv.vgt-wrap__footer.vgt-clearfix {\n  background: #fff;\n  font-size: 14px;\n}\n\n.vgt-wrap__footer .footer__navigation__page-btn span {\n  font-size: 14px !important;\n}\n\n.vgt-wrap__footer .footer__row-count__label {\n  font-size: 14px;\n  color: #909399;\n}\n\n.vgt-wrap__footer .footer__row-count::after {\n  display: none;\n}\n\n.vgt-wrap__footer .footer__row-count__select {\n  background-color: transparent;\n  width: auto;\n  padding: 0;\n  border: 0;\n  border-radius: 0;\n  height: auto;\n  font-size: 14px;\n  margin-left: 8px;\n  color: #606266;\n  font-weight: 700;\n  -webkit-appearance: auto !important;\n  -moz-appearance: auto !important;\n       appearance: auto !important;\n}\n\n.vgt-wrap__footer .footer__row-count__label {\n  margin-bottom: 0 !important;\n}\n\n.vgt-wrap__footer .footer__navigation {\n  font-size: 14px;\n}\n\nspan.chevron.right::after {\n  border-left: 6px solid #b0b1b3 !important;\n}\n\nspan.chevron.left::after {\n  border-right: 6px solid #b0b1b3 !important;\n}\n\ntable.tableOne tbody tr th.line-numbers {\n  background: #fff;\n}\n\ntable.tableOne tbody tr th.vgt-checkbox-col {\n  background: #fff;\n}\n\n.vgt-wrap__footer .footer__navigation > button:first-of-type {\n  margin-right: 0;\n}\n\ninput.vgt-input.vgt-pull-left {\n  width: auto;\n}\n\n.table-alert__box {\n  color: #155724 !important;\n  background-color: #d4edda !important;\n  border-color: #c3e6cb !important;\n  padding: 0.75rem !important;\n}\n\n.gull-border-none {\n  border-bottom: none !important;\n}\n\ntable.tableOne.vgt-table {\n  border: none !important;\n}\n\n.vgt-wrap__footer.vgt-clearfix {\n  border: none !important;\n}\n\n.vgt-global-search.vgt-clearfix {\n  border: none !important;\n}\n\nth.vgt-checkbox-col {\n  border-right: none !important;\n  border-bottom: 1px solid #dcdfe6;\n}\n\nth.line-numbers {\n  border-right: none !important;\n  border-bottom: 1px solid #dcdfe6;\n}\n\n.order-table.vgt-table {\n  font-size: 14px;\n  border: 0px solid #dcdfe6;\n}\n\n.order-table.vgt-table thead th {\n  color: #111827;\n  vertical-align: bottom;\n  border-bottom: 0px solid #dcdfe6;\n  padding-right: 1.5em;\n  background: transparent;\n  min-width: 140px !important;\n  font-size: 14px;\n  font-weight: 600 !important;\n}\n\n.order-table.vgt-table td {\n  padding: 10px;\n  vertical-align: middle;\n  border-bottom: 0px solid #dcdfe6;\n  color: #111827;\n  font-size: 14px;\n  min-width: 140px !important;\n}\n\n.order-table.vgt-table tbody tr {\n  transition: all 0.5s;\n  padding: 15px;\n  cursor: pointer;\n}\n\n.order-table.vgt-table tbody tr:hover {\n  background: #eee;\n  border-radius: 10px;\n}\n\n@media only screen and (max-width: 750px) {\n  .vgt-wrap__footer .footer__navigation__page-info {\n    display: none;\n  }\n  .vgt-table th.sortable button {\n    top: 8px;\n  }\n}\n\n@media (min-width: 750px) and (max-width: 1024px) {\n  .vgt-table th.sortable button {\n    top: 8px;\n  }\n}\n\n@media (min-width: 1024px) and (max-width: 1024px) {\n  .vgt-table th.sortable button {\n    top: 0px;\n  }\n}\n\n.tag-custom {\n  max-width: 1000% !important;\n  border-bottom: 1px solid #000;\n}\n\n.ti-input {\n  border: none !important;\n}\n\n.ti-tag.ti-valid {\n  min-height: 30px;\n  background-color: #8b5cf6 !important;\n  border-radius: 50rem !important;\n  padding: 0 12px !important;\n}\n\n.echarts {\n  width: 100% !important;\n  height: 100% !important;\n}\n\n.chart-wrapper {\n  height: 300px;\n  width: 100%;\n}\n\n.apexcharts-legend.center.position-bottom {\n  bottom: -2px !important;\n}\n\n@media (max-width: 767px) {\n  .apexcharts-toolbar {\n    display: none !important;\n  }\n}\n\n.v-select {\n  background: #F3F4F6;\n}\n\n.v-select.is-invalid ~ .invalid-feedback {\n  display: block;\n}\n\n.vs__search, .vs__search:focus {\n  height: calc(1rem + 7px);\n}\n\n.daterangepicker {\n  font-family: \"Nunito\", sans-serif;\n  font-size: 0.813rem;\n  line-height: 1.5;\n  border: 0;\n  margin: 0;\n}\n\n.daterangepicker::after, .daterangepicker::before {\n  display: none;\n}\n\n.daterangepicker .calendar-table .next span,\n.daterangepicker .calendar-table .prev span {\n  border-width: 0 1px 1px 0;\n}\n\n.daterangepicker .drp-calendar {\n  padding-bottom: 19px !important;\n}\n\n.daterangepicker .ranges li.active, .daterangepicker td.active, .daterangepicker td.active:hover {\n  background: #8b5cf6 !important;\n  color: #fff !important;\n}\n\n.daterangepicker td.in-range {\n  background-color: #E5E7EB;\n  color: #111827;\n}\n\n.daterangepicker .ranges li:hover {\n  background-color: #E5E7EB;\n}\n\n@media only screen and (max-width: 682px) {\n  .daterangepicker .ranges {\n    width: 100%;\n  }\n  .daterangepicker .ranges ul {\n    width: 100%;\n  }\n  .daterangepicker .calendars-container {\n    display: flex !important;\n    flex-direction: column !important;\n  }\n  .daterangepicker .drp-calendar.right {\n    padding: 0px !important;\n    margin-top: 225px;\n  }\n}\n\n.main-header {\n  position: fixed;\n  width: 100%;\n  height: 80px;\n  box-shadow: 0 1px 15px rgba(0, 0, 0, 0.04), 0 1px 6px rgba(0, 0, 0, 0.04);\n  display: flex;\n  align-items: center;\n  flex-wrap: wrap;\n  justify-content: space-between;\n  background: #fff;\n  z-index: 100;\n}\n\n.main-header .menu-toggle {\n  width: 90px;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  cursor: pointer;\n  margin-right: 12px;\n}\n\n.main-header .menu-toggle div {\n  width: 24px;\n  height: 1px;\n  background: #111827;\n  margin: 3px 0;\n}\n\n.main-header .search-bar {\n  display: flex;\n  align-items: center;\n  justify-content: left;\n  background: #F3F4F6;\n  border: 1px solid #E5E7EB;\n  border-radius: 20px;\n  position: relative;\n  width: 230px;\n  height: 40px;\n}\n\n.main-header .search-bar input {\n  background: transparent;\n  border: 0;\n  color: #212121;\n  font-size: 0.8rem;\n  line-height: 2;\n  height: 100%;\n  outline: initial !important;\n  padding: 0.5rem 1rem;\n  width: calc(100% - 32px);\n}\n\n.main-header .search-bar .search-icon {\n  font-size: 18px;\n  width: 24px;\n  display: inline-block;\n}\n\n.main-header .logo {\n  width: 120px;\n}\n\n.main-header .logo img {\n  width: 60px;\n  height: 60px;\n  margin: 0 auto;\n  display: block;\n}\n\n.main-header .show .header-icon {\n  background: #F3F4F6;\n}\n\n.main-header .header-icon {\n  font-size: 19px;\n  cursor: pointer;\n  height: 36px;\n  width: 36px;\n  line-height: 36px;\n  display: inline-block;\n  text-align: center;\n  border-radius: 8px;\n  margin: 0 2px;\n}\n\n.main-header .header-icon:hover {\n  background: #F3F4F6;\n}\n\n.main-header .header-icon.dropdown-toggle:after {\n  display: none;\n}\n\n.main-header .header-part-right {\n  display: flex;\n  align-items: center;\n}\n\n.main-header .header-part-right .user {\n  margin-right: 2rem;\n}\n\n.main-header .header-part-right .user img {\n  width: 36px;\n  height: 36px;\n  border-radius: 50%;\n  cursor: pointer;\n}\n\n.main-header .notification-dropdown {\n  padding: 0;\n  max-height: 260px;\n  cursor: pointer;\n}\n\n.main-header .notification-dropdown .dropdown-item {\n  display: flex;\n  align-items: center;\n  padding: 0;\n  height: 72px;\n  border-bottom: 1px solid #D1D5DB;\n}\n\n.main-header .notification-dropdown .dropdown-item .notification-icon {\n  background: #E5E7EB;\n  height: 100%;\n  width: 44px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n.main-header .notification-dropdown .dropdown-item .notification-icon i {\n  font-size: 18px;\n}\n\n.main-header .notification-dropdown .dropdown-item .notification-details {\n  padding: 0.25rem 0.75rem;\n}\n\n.main-header .notification-dropdown .dropdown-item:active {\n  color: inherit;\n  background: inherit;\n}\n\n@media (max-width: 991px) {\n  .main-header .search-bar {\n    width: 180px;\n  }\n  .main-header .menu-toggle {\n    width: 24px;\n    margin-right: 36px;\n  }\n}\n\n@media (max-width: 615px) {\n  .main-header .header-part-right .user {\n    margin-right: 0rem;\n  }\n}\n\n@media (max-width: 580px) {\n  .main-header {\n    height: 70px;\n    padding: 0 1.5rem;\n  }\n  .main-header .logo {\n    width: 60px;\n  }\n  .main-header .search-bar {\n    display: none;\n  }\n  .main-header .menu-toggle {\n    width: 60px;\n  }\n  .main-header .header-part-right .user {\n    margin-right: 0;\n    padding-right: 0;\n  }\n  .notification-dropdown {\n    left: 10px !important;\n  }\n}\n\n@media (max-width: 360px) {\n  .main-header .menu-toggle {\n    margin: 0;\n  }\n}\n\n.layout-horizontal-bar .header-topnav {\n  margin: 0;\n  padding: 0;\n  background-color: #fff;\n  position: relative;\n  z-index: 10;\n  position: fixed;\n  width: 100%;\n  /* height: 80px; */\n  top: 80px;\n  box-shadow: 0 1px 15px rgba(0, 0, 0, 0.04), 0 1px 6px rgba(0, 0, 0, 0.04);\n}\n\n.layout-horizontal-bar .header-topnav .container {\n  padding: 0;\n}\n\n.layout-horizontal-bar .header-topnav .topbar-branding {\n  float: left;\n  height: 48px;\n  padding: 8px;\n  margin: 0 8px;\n}\n\n.layout-horizontal-bar .header-topnav .topbar-branding img {\n  height: 100%;\n  width: auto;\n}\n\n.layout-horizontal-bar .header-topnav .ps {\n  overflow: initial !important;\n  overflow-anchor: none;\n  -ms-overflow-style: none;\n  touch-action: auto;\n  -ms-touch-action: auto;\n}\n\n.layout-horizontal-bar .header-topnav .topnav {\n  display: flex;\n  align-items: center;\n  height: auto;\n}\n\n.layout-horizontal-bar .header-topnav .header-topnav-right {\n  float: right;\n  height: 48px;\n  display: flex;\n  align-items: center;\n  padding-right: .67rem;\n}\n\n.layout-horizontal-bar .header-topnav .topnav:after {\n  content: \"\";\n  display: table;\n  clear: both;\n}\n\n.layout-horizontal-bar .header-topnav .topnav a {\n  color: #333 !important;\n  text-decoration: none;\n  background-color: transparent;\n  -webkit-text-decoration-skip: objects;\n}\n\n.layout-horizontal-bar .header-topnav .topnav label.menu-toggle {\n  height: 48px;\n  width: 48px;\n  box-sizing: border-box;\n  padding: 12px;\n  border-radius: 50%;\n}\n\n.layout-horizontal-bar .header-topnav .topnav label.menu-toggle .mat-icon {\n  font-size: 24px;\n}\n\n.layout-horizontal-bar .header-topnav .topnav .toggle,\n.layout-horizontal-bar .header-topnav .topnav [id^=drop] {\n  display: none;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul {\n  padding: 0;\n  margin: 0;\n  list-style: none;\n  position: relative;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul:not(.menu) {\n  box-shadow: 0 0 4px rgba(0, 0, 0, 0), 0 4px 8px rgba(0, 0, 0, 0.28);\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul.menu {\n  float: left;\n  height: 48px;\n  padding-right: 45px;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul.menu > li {\n  float: left;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul.menu > li > div > a,\n.layout-horizontal-bar .header-topnav .topnav ul.menu > li > div > div {\n  border-bottom: 2px solid;\n  height: 48px;\n  box-sizing: border-box;\n  border-color: transparent;\n  margin: 0 6px;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul li {\n  margin: 0px;\n  display: inline-block;\n}\n\n.layout-horizontal-bar .header-topnav .topnav a,\n.layout-horizontal-bar .header-topnav .topnav label {\n  display: flex;\n  flex-direction: row;\n  align-items: center;\n  padding: 13px 20px;\n  height: 44px;\n  font-size: .875rem;\n  text-decoration: none;\n  box-sizing: border-box;\n  cursor: pointer;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul li ul li:hover,\n.layout-horizontal-bar .header-topnav .topnav ul li ul li.open {\n  background: #eeeeee;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul ul {\n  opacity: 0;\n  visibility: hidden;\n  position: absolute;\n  background: #ffffff;\n  color: rgba(0, 0, 0, 0.87);\n  /* has to be the same number as the \"line-height\" of \"nav a\" */\n  top: 48px;\n  transform: translateY(-100px);\n  transition: all 0.3s ease-in-out;\n  z-index: -1;\n  border-radius: 5px;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul li:hover > div > div > ul,\n.layout-horizontal-bar .header-topnav .topnav ul li:hover > div > ul {\n  opacity: 1;\n  visibility: visible;\n  transform: translateY(0);\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul ul li {\n  width: 170px;\n  float: none;\n  display: list-item;\n  position: relative;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul ul ul {\n  top: 0;\n  left: 170px;\n}\n\n.layout-horizontal-bar .header-topnav .topnav ul ul ul li {\n  position: relative;\n  top: 0;\n}\n\n.layout-horizontal-bar .header-topnav .topnav li > a:after {\n  content: ' +';\n}\n\n.layout-horizontal-bar .header-topnav .topnav li > a:only-child:after {\n  content: '';\n}\n\n@media (max-width: 959px) {\n  .header-topnav-right {\n    position: absolute;\n    right: 6px;\n    top: 0;\n  }\n}\n\n/* Media Queries\r\n--------------------------------------------- */\n@media only screen and (max-width: 768px) {\n  .layout-horizontal-bar .header-topnav {\n    margin: 0;\n    padding: 0;\n    background-color: #fff;\n    position: relative;\n    z-index: 10;\n    position: fixed;\n    width: 200px;\n    top: 70px;\n    height: 100%;\n    padding-top: 20px;\n    left: -200px;\n    box-shadow: 0 1px 15px rgba(0, 0, 0, 0.04), 0 1px 6px rgba(0, 0, 0, 0.04);\n    transition: all .5s ease-in-out;\n  }\n  .layout-horizontal-bar .header-topnav .ps {\n    overflow: hidden !important;\n    overflow-anchor: none;\n    -ms-overflow-style: none;\n    touch-action: auto;\n    -ms-touch-action: auto;\n  }\n  .layout-horizontal-bar .topnav {\n    margin: 0;\n    max-height: calc(100vh - 80px) !important;\n    /* Hide menus on hover */\n  }\n  .layout-horizontal-bar .topnav .menu {\n    height: auto !important;\n    padding-right: 0px !important;\n    width: 100%;\n  }\n  .layout-horizontal-bar .topnav .menu li a {\n    border: none !important;\n  }\n  .layout-horizontal-bar .topnav ul.menu {\n    float: left;\n    padding-left: 0px;\n  }\n  .layout-horizontal-bar .topnav ul.menu > li {\n    float: left;\n  }\n  .layout-horizontal-bar .topnav ul.menu > li > div > a,\n  .layout-horizontal-bar .topnav ul.menu > li > div > div {\n    border-bottom: 2px solid;\n    height: auto !important;\n    box-sizing: border-box;\n    border-color: transparent;\n    margin: 0 6px;\n  }\n  .layout-horizontal-bar .topnav .toggle {\n    display: flex;\n    text-decoration: none;\n    border: none;\n  }\n  .layout-horizontal-bar .topnav ul {\n    transform: translateY(0px) !important;\n    transition: max-height 0.3s ease-in-out;\n  }\n  .layout-horizontal-bar .topnav [id^=drop]:checked + ul {\n    opacity: 1;\n    visibility: visible;\n    max-height: 2000px;\n  }\n  .layout-horizontal-bar .topnav [id^=drop]:checked + ul.menu {\n    max-height: 300px;\n    overflow-y: scroll;\n  }\n  .layout-horizontal-bar .topnav ul li {\n    position: relative;\n    opacity: 1;\n    visibility: visible;\n    width: 100%;\n    z-index: 1;\n  }\n  .layout-horizontal-bar .topnav ul ul .toggle,\n  .layout-horizontal-bar .topnav ul ul a {\n    padding: 0 40px;\n  }\n  .layout-horizontal-bar .topnav ul ul ul a {\n    padding: 0 80px;\n  }\n  .layout-horizontal-bar .topnav ul li ul li .toggle,\n  .layout-horizontal-bar .topnav ul ul a,\n  .layout-horizontal-bar .topnav ul ul ul a {\n    padding: 14px 20px;\n  }\n  .layout-horizontal-bar .topnav ul ul {\n    opacity: 1 !important;\n    visibility: hidden !important;\n    max-height: 0px;\n    position: relative !important;\n    background: #ffffff;\n    color: rgba(0, 0, 0, 0.87);\n    /* has to be the same number as the \"line-height\" of \"nav a\" */\n    top: 0px !important;\n    transform: translateY(-100px);\n    transition: all 1s ease-in-out !important;\n    z-index: 99 !important;\n    border-radius: 5px;\n    overflow: hidden;\n    left: 0px;\n  }\n  .layout-horizontal-bar .topnav ul li:hover > div > div > ul,\n  .layout-horizontal-bar .topnav ul li:hover > div > ul {\n    opacity: 1 !important;\n    visibility: visible !important;\n    transform: translateY(0);\n    transition: all 0.3s ease-in-out !important;\n    max-height: 400px;\n  }\n  .layout-horizontal-bar .topnav ul ul li {\n    opacity: 1;\n    visibility: visible;\n    width: 100% !important;\n  }\n  .layout-horizontal-bar .topnav ul:not(.menu) {\n    box-shadow: none !important;\n    margin-left: 5px;\n    border-left: 1px dashed #eee;\n  }\n  .layout-horizontal-bar .topnav ul ul ul {\n    left: 0;\n  }\n  .layout-horizontal-bar .topnav ul ul ul li {\n    position: static;\n  }\n}\n\n@media all and (max-width: 330px) {\n  .topnav ul li {\n    display: block;\n    width: 94%;\n  }\n}\n\n[dir=rtl] .topnav a .mat-icon,\n[dir=rtl] .topnav label .mat-icon {\n  margin-right: 0;\n  margin-left: 2px;\n}\n\n.app-footer {\n  margin-top: 2rem;\n  background: #E5E7EB;\n  padding: 1.25rem;\n  border-top-left-radius: 10px;\n  border-top-right-radius: 10px;\n}\n\n.app-footer .footer-bottom {\n  width: 100%;\n}\n\n.app-footer .footer-bottom .logo {\n  width: 3rem;\n  height: auto;\n  margin: 4px;\n}\n\n.custom-separator {\n  border-bottom: 1px dashed #ebedf2;\n  margin: 15px 0;\n}\n\ndiv.tab-border {\n  border: 1px dashed #ebedf2 !important;\n  margin: 30px 0 !important;\n}\n\n.m-0 {\n  margin: 0px !important;\n}\n\n.mt-0 {\n  margin-top: 0px !important;\n}\n\n.mr-0 {\n  margin-right: 0px !important;\n}\n\n.mb-0 {\n  margin-bottom: 0px !important;\n}\n\n.ml-0 {\n  margin-left: 0px !important;\n}\n\n.mx-0 {\n  margin-left: 0px !important;\n  margin-right: 0px !important;\n}\n\n.my-0 {\n  margin-top: 0px !important;\n  margin-bottom: 0px !important;\n}\n\n.p-0 {\n  padding: 0px !important;\n}\n\n.pt-0 {\n  padding-top: 0px !important;\n}\n\n.pr-0 {\n  padding-right: 0px !important;\n}\n\n.pb-0 {\n  padding-bottom: 0px !important;\n}\n\n.pl-0 {\n  padding-left: 0px !important;\n}\n\n.px-0 {\n  padding-left: 0px !important;\n  padding-right: 0px !important;\n}\n\n.py-0 {\n  padding-top: 0px !important;\n  padding-bottom: 0px !important;\n}\n\n.m-8 {\n  margin: 8px !important;\n}\n\n.mt-8 {\n  margin-top: 8px !important;\n}\n\n.mr-8 {\n  margin-right: 8px !important;\n}\n\n.mb-8 {\n  margin-bottom: 8px !important;\n}\n\n.ml-8 {\n  margin-left: 8px !important;\n}\n\n.mx-8 {\n  margin-left: 8px !important;\n  margin-right: 8px !important;\n}\n\n.my-8 {\n  margin-top: 8px !important;\n  margin-bottom: 8px !important;\n}\n\n.p-8 {\n  padding: 8px !important;\n}\n\n.pt-8 {\n  padding-top: 8px !important;\n}\n\n.pr-8 {\n  padding-right: 8px !important;\n}\n\n.pb-8 {\n  padding-bottom: 8px !important;\n}\n\n.pl-8 {\n  padding-left: 8px !important;\n}\n\n.px-8 {\n  padding-left: 8px !important;\n  padding-right: 8px !important;\n}\n\n.py-8 {\n  padding-top: 8px !important;\n  padding-bottom: 8px !important;\n}\n\n.m-12 {\n  margin: 12px !important;\n}\n\n.mt-12 {\n  margin-top: 12px !important;\n}\n\n.mr-12 {\n  margin-right: 12px !important;\n}\n\n.mb-12 {\n  margin-bottom: 12px !important;\n}\n\n.ml-12 {\n  margin-left: 12px !important;\n}\n\n.mx-12 {\n  margin-left: 12px !important;\n  margin-right: 12px !important;\n}\n\n.my-12 {\n  margin-top: 12px !important;\n  margin-bottom: 12px !important;\n}\n\n.p-12 {\n  padding: 12px !important;\n}\n\n.pt-12 {\n  padding-top: 12px !important;\n}\n\n.pr-12 {\n  padding-right: 12px !important;\n}\n\n.pb-12 {\n  padding-bottom: 12px !important;\n}\n\n.pl-12 {\n  padding-left: 12px !important;\n}\n\n.px-12 {\n  padding-left: 12px !important;\n  padding-right: 12px !important;\n}\n\n.py-12 {\n  padding-top: 12px !important;\n  padding-bottom: 12px !important;\n}\n\n.m-16 {\n  margin: 16px !important;\n}\n\n.mt-16 {\n  margin-top: 16px !important;\n}\n\n.mr-16 {\n  margin-right: 16px !important;\n}\n\n.mb-16 {\n  margin-bottom: 16px !important;\n}\n\n.ml-16 {\n  margin-left: 16px !important;\n}\n\n.mx-16 {\n  margin-left: 16px !important;\n  margin-right: 16px !important;\n}\n\n.my-16 {\n  margin-top: 16px !important;\n  margin-bottom: 16px !important;\n}\n\n.p-16 {\n  padding: 16px !important;\n}\n\n.pt-16 {\n  padding-top: 16px !important;\n}\n\n.pr-16 {\n  padding-right: 16px !important;\n}\n\n.pb-16 {\n  padding-bottom: 16px !important;\n}\n\n.pl-16 {\n  padding-left: 16px !important;\n}\n\n.px-16 {\n  padding-left: 16px !important;\n  padding-right: 16px !important;\n}\n\n.py-16 {\n  padding-top: 16px !important;\n  padding-bottom: 16px !important;\n}\n\n.m-24 {\n  margin: 24px !important;\n}\n\n.mt-24 {\n  margin-top: 24px !important;\n}\n\n.mr-24 {\n  margin-right: 24px !important;\n}\n\n.mb-24 {\n  margin-bottom: 24px !important;\n}\n\n.ml-24 {\n  margin-left: 24px !important;\n}\n\n.mx-24 {\n  margin-left: 24px !important;\n  margin-right: 24px !important;\n}\n\n.my-24 {\n  margin-top: 24px !important;\n  margin-bottom: 24px !important;\n}\n\n.p-24 {\n  padding: 24px !important;\n}\n\n.pt-24 {\n  padding-top: 24px !important;\n}\n\n.pr-24 {\n  padding-right: 24px !important;\n}\n\n.pb-24 {\n  padding-bottom: 24px !important;\n}\n\n.pl-24 {\n  padding-left: 24px !important;\n}\n\n.px-24 {\n  padding-left: 24px !important;\n  padding-right: 24px !important;\n}\n\n.py-24 {\n  padding-top: 24px !important;\n  padding-bottom: 24px !important;\n}\n\n.m-28 {\n  margin: 28px !important;\n}\n\n.mt-28 {\n  margin-top: 28px !important;\n}\n\n.mr-28 {\n  margin-right: 28px !important;\n}\n\n.mb-28 {\n  margin-bottom: 28px !important;\n}\n\n.ml-28 {\n  margin-left: 28px !important;\n}\n\n.mx-28 {\n  margin-left: 28px !important;\n  margin-right: 28px !important;\n}\n\n.my-28 {\n  margin-top: 28px !important;\n  margin-bottom: 28px !important;\n}\n\n.p-28 {\n  padding: 28px !important;\n}\n\n.pt-28 {\n  padding-top: 28px !important;\n}\n\n.pr-28 {\n  padding-right: 28px !important;\n}\n\n.pb-28 {\n  padding-bottom: 28px !important;\n}\n\n.pl-28 {\n  padding-left: 28px !important;\n}\n\n.px-28 {\n  padding-left: 28px !important;\n  padding-right: 28px !important;\n}\n\n.py-28 {\n  padding-top: 28px !important;\n  padding-bottom: 28px !important;\n}\n\n.m-30 {\n  margin: 30px !important;\n}\n\n.mt-30 {\n  margin-top: 30px !important;\n}\n\n.mr-30 {\n  margin-right: 30px !important;\n}\n\n.mb-30 {\n  margin-bottom: 30px !important;\n}\n\n.ml-30 {\n  margin-left: 30px !important;\n}\n\n.mx-30 {\n  margin-left: 30px !important;\n  margin-right: 30px !important;\n}\n\n.my-30 {\n  margin-top: 30px !important;\n  margin-bottom: 30px !important;\n}\n\n.p-30 {\n  padding: 30px !important;\n}\n\n.pt-30 {\n  padding-top: 30px !important;\n}\n\n.pr-30 {\n  padding-right: 30px !important;\n}\n\n.pb-30 {\n  padding-bottom: 30px !important;\n}\n\n.pl-30 {\n  padding-left: 30px !important;\n}\n\n.px-30 {\n  padding-left: 30px !important;\n  padding-right: 30px !important;\n}\n\n.py-30 {\n  padding-top: 30px !important;\n  padding-bottom: 30px !important;\n}\n\n.m-32 {\n  margin: 32px !important;\n}\n\n.mt-32 {\n  margin-top: 32px !important;\n}\n\n.mr-32 {\n  margin-right: 32px !important;\n}\n\n.mb-32 {\n  margin-bottom: 32px !important;\n}\n\n.ml-32 {\n  margin-left: 32px !important;\n}\n\n.mx-32 {\n  margin-left: 32px !important;\n  margin-right: 32px !important;\n}\n\n.my-32 {\n  margin-top: 32px !important;\n  margin-bottom: 32px !important;\n}\n\n.p-32 {\n  padding: 32px !important;\n}\n\n.pt-32 {\n  padding-top: 32px !important;\n}\n\n.pr-32 {\n  padding-right: 32px !important;\n}\n\n.pb-32 {\n  padding-bottom: 32px !important;\n}\n\n.pl-32 {\n  padding-left: 32px !important;\n}\n\n.px-32 {\n  padding-left: 32px !important;\n  padding-right: 32px !important;\n}\n\n.py-32 {\n  padding-top: 32px !important;\n  padding-bottom: 32px !important;\n}\n\n.m-36 {\n  margin: 36px !important;\n}\n\n.mt-36 {\n  margin-top: 36px !important;\n}\n\n.mr-36 {\n  margin-right: 36px !important;\n}\n\n.mb-36 {\n  margin-bottom: 36px !important;\n}\n\n.ml-36 {\n  margin-left: 36px !important;\n}\n\n.mx-36 {\n  margin-left: 36px !important;\n  margin-right: 36px !important;\n}\n\n.my-36 {\n  margin-top: 36px !important;\n  margin-bottom: 36px !important;\n}\n\n.p-36 {\n  padding: 36px !important;\n}\n\n.pt-36 {\n  padding-top: 36px !important;\n}\n\n.pr-36 {\n  padding-right: 36px !important;\n}\n\n.pb-36 {\n  padding-bottom: 36px !important;\n}\n\n.pl-36 {\n  padding-left: 36px !important;\n}\n\n.px-36 {\n  padding-left: 36px !important;\n  padding-right: 36px !important;\n}\n\n.py-36 {\n  padding-top: 36px !important;\n  padding-bottom: 36px !important;\n}\n\n.m-40 {\n  margin: 40px !important;\n}\n\n.mt-40 {\n  margin-top: 40px !important;\n}\n\n.mr-40 {\n  margin-right: 40px !important;\n}\n\n.mb-40 {\n  margin-bottom: 40px !important;\n}\n\n.ml-40 {\n  margin-left: 40px !important;\n}\n\n.mx-40 {\n  margin-left: 40px !important;\n  margin-right: 40px !important;\n}\n\n.my-40 {\n  margin-top: 40px !important;\n  margin-bottom: 40px !important;\n}\n\n.p-40 {\n  padding: 40px !important;\n}\n\n.pt-40 {\n  padding-top: 40px !important;\n}\n\n.pr-40 {\n  padding-right: 40px !important;\n}\n\n.pb-40 {\n  padding-bottom: 40px !important;\n}\n\n.pl-40 {\n  padding-left: 40px !important;\n}\n\n.px-40 {\n  padding-left: 40px !important;\n  padding-right: 40px !important;\n}\n\n.py-40 {\n  padding-top: 40px !important;\n  padding-bottom: 40px !important;\n}\n\n.m-44 {\n  margin: 44px !important;\n}\n\n.mt-44 {\n  margin-top: 44px !important;\n}\n\n.mr-44 {\n  margin-right: 44px !important;\n}\n\n.mb-44 {\n  margin-bottom: 44px !important;\n}\n\n.ml-44 {\n  margin-left: 44px !important;\n}\n\n.mx-44 {\n  margin-left: 44px !important;\n  margin-right: 44px !important;\n}\n\n.my-44 {\n  margin-top: 44px !important;\n  margin-bottom: 44px !important;\n}\n\n.p-44 {\n  padding: 44px !important;\n}\n\n.pt-44 {\n  padding-top: 44px !important;\n}\n\n.pr-44 {\n  padding-right: 44px !important;\n}\n\n.pb-44 {\n  padding-bottom: 44px !important;\n}\n\n.pl-44 {\n  padding-left: 44px !important;\n}\n\n.px-44 {\n  padding-left: 44px !important;\n  padding-right: 44px !important;\n}\n\n.py-44 {\n  padding-top: 44px !important;\n  padding-bottom: 44px !important;\n}\n\n.m-48 {\n  margin: 48px !important;\n}\n\n.mt-48 {\n  margin-top: 48px !important;\n}\n\n.mr-48 {\n  margin-right: 48px !important;\n}\n\n.mb-48 {\n  margin-bottom: 48px !important;\n}\n\n.ml-48 {\n  margin-left: 48px !important;\n}\n\n.mx-48 {\n  margin-left: 48px !important;\n  margin-right: 48px !important;\n}\n\n.my-48 {\n  margin-top: 48px !important;\n  margin-bottom: 48px !important;\n}\n\n.p-48 {\n  padding: 48px !important;\n}\n\n.pt-48 {\n  padding-top: 48px !important;\n}\n\n.pr-48 {\n  padding-right: 48px !important;\n}\n\n.pb-48 {\n  padding-bottom: 48px !important;\n}\n\n.pl-48 {\n  padding-left: 48px !important;\n}\n\n.px-48 {\n  padding-left: 48px !important;\n  padding-right: 48px !important;\n}\n\n.py-48 {\n  padding-top: 48px !important;\n  padding-bottom: 48px !important;\n}\n\n.m-80 {\n  margin: 80px !important;\n}\n\n.mt-80 {\n  margin-top: 80px !important;\n}\n\n.mr-80 {\n  margin-right: 80px !important;\n}\n\n.mb-80 {\n  margin-bottom: 80px !important;\n}\n\n.ml-80 {\n  margin-left: 80px !important;\n}\n\n.mx-80 {\n  margin-left: 80px !important;\n  margin-right: 80px !important;\n}\n\n.my-80 {\n  margin-top: 80px !important;\n  margin-bottom: 80px !important;\n}\n\n.p-80 {\n  padding: 80px !important;\n}\n\n.pt-80 {\n  padding-top: 80px !important;\n}\n\n.pr-80 {\n  padding-right: 80px !important;\n}\n\n.pb-80 {\n  padding-bottom: 80px !important;\n}\n\n.pl-80 {\n  padding-left: 80px !important;\n}\n\n.px-80 {\n  padding-left: 80px !important;\n  padding-right: 80px !important;\n}\n\n.py-80 {\n  padding-top: 80px !important;\n  padding-bottom: 80px !important;\n}\n\n.m-auto {\n  margin: auto !important;\n}\n\n.mx-auto {\n  margin-left: auto !important;\n  margin-right: auto !important;\n}\n\n.my-auto {\n  margin-top: auto !important;\n  margin-bottom: auto !important;\n}\n\n._dot {\n  width: 5px;\n  height: 5px;\n  background-color: #fff;\n  border-radius: 50%;\n}\n\n._inline-dot {\n  display: inline-block;\n}\n\n._round-button {\n  border-radius: 50% !important;\n}\n\n.progress--height-2 {\n  height: 5px;\n}\n\n.input-group ~ .invalid-feedback {\n  display: block;\n}\n\n.form-control.is-invalid .invalid-feedback {\n  display: block;\n}\n\n.b-form-file.is-invalid ~ .invalid-feedback {\n  display: block;\n}\n\ninput.is-invalid ~ .invalid-feedback {\n  display: block;\n}\n\n.tag-custom.is-invalid ~ .invalid-feedback {\n  display: block;\n}\n\n#my-strictly-unique-vue-upload-multiple-image {\n  font-family: \"Avenir\", Helvetica, Arial, sans-serif;\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n  text-align: center;\n  color: #2c3e50;\n}\n\n.inbox-main-sidebar-container {\n  padding: 15px;\n}\n\n.inbox-main-sidebar-container .inbox-main-content {\n  margin-left: 180px;\n}\n\n.inbox-main-sidebar-container .inbox-main-sidebar {\n  margin-left: 0px;\n  width: 180px;\n  height: 100%;\n  overflow: hidden;\n}\n\n.inbox-main-sidebar-container .inbox-main-sidebar .inbox-main-nav {\n  list-style: none;\n  padding: 0;\n  margin: 0;\n}\n\n.inbox-main-sidebar-container .inbox-main-sidebar .inbox-main-nav li a {\n  padding: 0.66rem 0;\n  display: flex;\n  flex-direction: row;\n  align-items: center;\n  color: #111827;\n}\n\n.inbox-main-sidebar-container .inbox-main-sidebar .inbox-main-nav li a.active {\n  color: #8b5cf6;\n}\n\n.inbox-main-sidebar-container .inbox-main-sidebar .inbox-main-nav li a:hover {\n  color: #8b5cf6;\n}\n\n.inbox-main-sidebar-container .inbox-main-sidebar .inbox-main-nav li a i {\n  margin-right: 8px;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container {\n  border-radius: 10px;\n  min-height: calc(100vh - 150px);\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .sidebar-content {\n  margin-left: 360px;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar-content .inbox-topbar {\n  height: 52px;\n  display: flex;\n  flex-direction: row;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar-content .inbox-details {\n  padding: 1.5rem 2rem;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar {\n  overflow: hidden;\n  width: 360px;\n  height: 100%;\n  border-right: 1px solid #E5E7EB;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .mail-item {\n  display: flex;\n  border-bottom: 1px solid #E5E7EB;\n  padding: 1.25rem 1rem;\n  cursor: pointer;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .mail-item:hover {\n  background: #F3F4F6;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .mail-item .avatar {\n  width: 15%;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .mail-item .details {\n  width: 60%;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .mail-item .date {\n  width: 25%;\n  font-size: 10px;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .mail-item .date span {\n  float: right;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .avatar img {\n  margin: 4px;\n  width: 32px;\n  height: 32px;\n  border-radius: 50%;\n}\n\n.inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar .name {\n  font-size: 12px;\n  display: block;\n}\n\n@media (max-width: 767px) {\n  .sidebar-container .sidebar-content {\n    margin-left: 0px;\n  }\n  .inbox-main-sidebar-container .inbox-secondary-sidebar-container .sidebar-content {\n    margin-left: 0px;\n  }\n  .inbox-main-sidebar-container .inbox-secondary-sidebar-container .inbox-secondary-sidebar {\n    margin-left: -280px;\n  }\n  .inbox-main-sidebar-container .inbox-main-sidebar {\n    margin-left: -260px;\n  }\n  .mail-item {\n    padding: 1rem 0.5rem !important;\n  }\n  .inbox-secondary-sidebar {\n    margin-left: 0px;\n    width: 280px !important;\n  }\n}\n\n[dir=\"rtl\"] .inbox-main-sidebar-container .inbox-main-sidebar .inbox-main-nav li a i {\n  margin-right: 0;\n  margin-left: 8px;\n}\n\n.pos_page {\n  position: absolute;\n  top: 0;\n  right: 0;\n  width: 100%;\n  min-height: 100vh;\n}\n\n#invoice-POS h1,\n#invoice-POS h2,\n#invoice-POS h3,\n#invoice-POS h4,\n#invoice-POS h5,\n#invoice-POS h6 {\n  color: #05070b;\n  font-weight: bolder;\n}\n\n#pos .pos-detail {\n  height: 42vh !important;\n}\n\n#pos .pos-detail .table-responsive {\n  max-height: 40vh !important;\n  height: 40vh !important;\n  border-bottom: none !important;\n}\n\n#pos .pos-detail .table-responsive tr {\n  font-size: 14px;\n}\n\n#pos .card-order {\n  min-height: 100%;\n}\n\n#pos .card-order .main-header {\n  position: relative;\n}\n\n#pos .grandtotal {\n  text-align: center;\n  height: 40px;\n  background-color: #7ec8ca;\n  margin-bottom: 20px;\n  font-size: 1.2rem;\n  font-weight: 800;\n  padding: 5px;\n}\n\n#pos .list-grid .list-item .list-thumb img {\n  width: 100% !important;\n  height: 100px !important;\n  max-height: 100px !important;\n  -o-object-fit: cover;\n     object-fit: cover;\n}\n\n#pos .list-grid {\n  height: 100%;\n  min-height: 100%;\n  overflow: scroll;\n}\n\n#pos .brand-Active {\n  border: 2px solid;\n}\n\n.centred {\n  text-align: center;\n  align-content: center;\n}\n\n@media (min-width: 1024px) {\n  #pos .list-grid {\n    height: 100vh;\n    min-height: 100vh;\n    overflow: scroll;\n  }\n}\n\n#pos .card.o-hidden {\n  width: 19%;\n  max-width: 19%;\n  min-width: 130px;\n}\n\n#pos .input-customer {\n  position: relative;\n  display: flex;\n  flex-wrap: unset;\n  align-items: stretch;\n  width: 100%;\n}\n\n#pos .card.o-hidden:hover {\n  cursor: pointer;\n  border: 1px solid;\n}\n\n#invoice-POS {\n  font-size: 14px;\n  line-height: 20px;\n  font-family: sans-serif;\n  text-transform: capitalize;\n  max-width: 400px;\n}\n\n@media print {\n  body {\n    visibility: hidden;\n  }\n  #invoice-POS {\n    visibility: visible;\n    font-size: 12px;\n    line-height: 20px;\n  }\n  @page {\n    margin: 0;\n  }\n}\n\n#total tr {\n  background-color: #ddd;\n}\n\n#top .logo {\n  height: 100px;\n  width: 100px;\n  background-size: 100px 100px;\n}\n\n.title {\n  float: right;\n}\n\n.title p {\n  text-align: right;\n}\n\ntable {\n  width: 100%;\n  border-collapse: collapse;\n}\n\n#invoice-POS table tr {\n  border-bottom: 3px dotted #ddd !important;\n}\n\n.tabletitle {\n  font-size: .5em;\n  background: #EEE;\n}\n\n#legalcopy {\n  margin-top: 5mm;\n}\n\n#legalcopy p {\n  text-align: center;\n}\n\n#bar {\n  text-align: center;\n}\n\n.quantity {\n  max-width: 95px;\n  width: 95px;\n}\n\n.quantity input {\n  text-align: center;\n  border: none;\n}\n\n.quantity .form-control:focus {\n  color: #374151;\n  background-color: unset;\n  border-color: #e1d5fd;\n  outline: 0;\n  box-shadow: unset;\n}\n\n.quantity span {\n  padding: 8px;\n}\n\n.list-horizontal .list-item .list-thumb img {\n  height: 74px;\n  -o-object-fit: cover;\n     object-fit: cover;\n}\n\n.list-horizontal .list-item .item-title {\n  white-space: nowrap !important;\n  overflow: hidden !important;\n  text-overflow: ellipsis !important;\n}\n\n.list-horizontal .list-item a {\n  color: #111827;\n}\n\n.list-grid .list-item .list-thumb img {\n  width: 100%;\n  height: 180px;\n  -o-object-fit: cover;\n     object-fit: cover;\n}\n\n.list-grid .list-item .card-body {\n  display: block !important;\n}\n\n.list-grid .list-item .item-title {\n  white-space: nowrap !important;\n  overflow: hidden !important;\n  text-overflow: ellipsis !important;\n  max-width: 300px;\n}\n\n.list-grid .list-item a {\n  color: #111827;\n}\n\n.list-grid .list-item .item-badges,\n.list-grid .list-item .item-actions {\n  position: absolute;\n  top: 16px;\n}\n\n.list-grid .list-item .item-actions {\n  right: 16px;\n}\n\n.list-grid .list-item .item-badges {\n  left: 16px;\n}\n\n.list-grid .list-item .item-select {\n  display: none;\n}\n\n@media (max-width: 991px) {\n  .list-horizontal .list-item .list-thumb img {\n    height: 100%;\n    width: 100px;\n  }\n  .list-horizontal .list-item .item-title {\n    max-width: 200px;\n  }\n}\n\n@media (max-width: 576px) {\n  .list-horizontal .list-item .item-title {\n    max-width: 150px;\n  }\n}\n\n.user-profile .header-cover {\n  position: relative;\n  background-size: cover;\n  background-repeat: no-repeat;\n  height: 300px;\n}\n\n.user-profile .header-cover::after {\n  content: \"\";\n  width: 100%;\n  height: 100%;\n  position: absolute;\n  background: rgba(0, 0, 0, 0.1);\n}\n\n.user-profile .user-info {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  align-items: center;\n  margin-top: -40px;\n  z-index: 9;\n}\n\n.user-profile .profile-picture {\n  border-radius: 50%;\n  border: 4px solid #fff;\n}\n\n.user-profile .profile-nav {\n  justify-content: center;\n}\n\n.timeline {\n  position: relative;\n  list-style: none;\n  padding: 0;\n  margin: 0;\n}\n\n.timeline .timeline-item {\n  position: relative;\n  width: 50%;\n  display: inline-block;\n}\n\n.timeline .timeline-item:nth-child(even) {\n  padding: 0 3rem 3rem 0;\n}\n\n.timeline .timeline-item:nth-child(even) .timeline-badge {\n  left: calc(100% - 24px);\n}\n\n.timeline .timeline-item:nth-child(odd) {\n  float: right;\n  padding: 0 0 3rem 3rem;\n  margin-top: 6rem;\n}\n\n.timeline .timeline-item:nth-child(odd) .timeline-badge {\n  right: calc(100% - 24px);\n}\n\n.timeline .timeline-item .timeline-badge {\n  position: absolute;\n  width: 48px;\n  height: 48px;\n}\n\n.timeline .timeline-item .badge-icon {\n  display: inline-block;\n  text-align: center;\n  font-size: 22px;\n  border-radius: 50%;\n  height: 100%;\n  width: 100%;\n  line-height: 48px;\n}\n\n.timeline .timeline-item .badge-img {\n  display: inline-block;\n  border-radius: 50%;\n  height: 100%;\n  width: 100%;\n}\n\n.timeline .timeline-group {\n  position: relative;\n  z-index: 99;\n  padding: 0 0 2rem 0;\n}\n\n.timeline .timeline-line {\n  position: absolute;\n  content: \"\";\n  width: 1px;\n  height: 100%;\n  background: #D1D5DB;\n  left: 0;\n  right: 0;\n  margin: auto;\n}\n\n@media (max-width: 767px) {\n  .user-profile .header-cover {\n    height: 200px;\n  }\n  .timeline .timeline-item {\n    width: 100%;\n    padding: 4rem 0 3rem !important;\n  }\n  .timeline .timeline-item:nth-child(odd) {\n    margin-top: 1rem;\n  }\n  .timeline .timeline-item .timeline-badge {\n    left: 0 !important;\n    right: 0 !important;\n    top: -16px;\n    margin: auto;\n  }\n  .timeline .timeline-group {\n    padding: 0 0 3rem;\n  }\n}\n\n.auth-layout-wrap {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  align-items: center;\n  min-height: 100vh;\n  background-size: cover;\n  background: url("+escape(__webpack_require__(/*! ./../../../images/photo-wide-4.jpg */"./resources/src/assets/images/photo-wide-4.jpg"))+");\n}\n\n.auth-layout-wrap .auth-content {\n  min-width: 340px;\n  margin: auto;\n}\n\n.auth-right {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  align-items: center;\n  height: 100%;\n}\n\n.auth-logo img {\n  width: 100px;\n  height: 100px;\n}\n\n@media (min-width: 1024px) {\n  .auth-layout-wrap .auth-content {\n    min-width: 340px;\n  }\n}\n\n@media (max-width: 767px) {\n  .auth-layout-wrap .auth-content {\n    padding: 15px;\n    min-width: 320px;\n  }\n  .auth-right {\n    padding: 80px 15px;\n  }\n}\n\n.not-found-wrap {\n  background-image: url("+escape(__webpack_require__(/*! ../../../images/page-bg-bottom.png */"./resources/src/assets/images/page-bg-bottom.png"))+");\n  background-position-y: bottom;\n  background-size: cover;\n  background-size: 100%;\n  height: 100vh;\n  background-repeat: no-repeat;\n  padding: 120px 0;\n}\n\n.not-found-wrap h1 {\n  font-weight: 800;\n  margin-bottom: 16px;\n  line-height: 1;\n}\n\n.not-found-wrap .subheading {\n  font-weight: 800;\n}\n\n.main-header {\n  position: relative;\n}\n\n.main-header .topbar .header-nav {\n  display: flex;\n  justify-content: space-between;\n  padding: 0;\n}\n\n.main-header .topbar .header-nav .topbar-item ul li {\n  padding-right: 40px;\n  text-transform: capitalize;\n}\n\n.homepage {\n  padding: 80px 0;\n  background: url(https://ui-lib.com/wp-content/uploads/2019/04/bg-1.png);\n  background-size: contain;\n  background-repeat: no-repeat;\n}\n\n.homepage .main-content .logo {\n  width: 80px;\n  margin: auto;\n}\n\n.homepage .main-content h1 {\n  color: #1F2937;\n  line-height: 1.5;\n}\n\n.homepage .main-content .btn-raised-primary:hover {\n  color: #fff;\n}\n\n.homepage .main-content .btn-raised {\n  transition: all .15s ease-in;\n}\n\n.homepage .main-content .btn-raised:hover {\n  transform: translateY(-2px);\n}\n\n.homepage .main-content .dashboard-photo {\n  margin: auto;\n  border-radius: 10px;\n  overflow: hidden;\n  max-width: 960px;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.08);\n}\n\n.homepage .main-content .dashboard-photo img {\n  width: 100%;\n}\n\n.features {\n  padding-top: 126px;\n  padding-bottom: 126px;\n  background: #f8fafe;\n}\n\n.features .section-title {\n  margin-bottom: 45px;\n}\n\n.features .section-title h2 {\n  margin-bottom: 5px;\n}\n\n.features .section-title p {\n  max-width: 550px;\n  margin: 0 auto;\n  opacity: 0.7;\n}\n\n.features .features-wrap .feature-card {\n  flex-direction: row;\n  justify-content: space-around;\n  padding: 20px 0px;\n  margin-bottom: 10px;\n  background: transparent;\n}\n\n.features .features-wrap .feature-card .card-icon {\n  padding: 15px;\n}\n\n.features .features-wrap .feature-card .card-title {\n  display: flex;\n  align-items: center;\n  margin: 0px;\n  flex-grow: 0.5;\n}\n\n.features .features-wrap .feature-card .card-title h6 {\n  margin: 0px;\n}\n\n.features .features-wrap .feature-card:hover, .features .features-wrap .feature-card.active {\n  background: linear-gradient(#8470b9, #473886);\n  cursor: pointer;\n}\n\n.features .features-wrap .feature-card:hover .card-icon, .features .features-wrap .feature-card.active .card-icon {\n  padding: 15px;\n  color: #fff;\n}\n\n.features .features-wrap .feature-card:hover .card-title h6, .features .features-wrap .feature-card.active .card-title h6 {\n  color: #fff;\n}\n\n.features .tab-panel {\n  display: none;\n  padding: 0 20px;\n}\n\n.features .tab-panel.active {\n  display: block;\n}\n\n.features .tab-panel img {\n  width: 100%;\n}\n\n.framework {\n  padding-top: 126px;\n  padding-bottom: 126px;\n  background: #f8fafe;\n}\n\n.framework .section-title {\n  padding-bottom: 40px;\n}\n\n.framework .item-photo {\n  height: 180px;\n  width: 180px;\n  padding: 25px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  border-radius: 50%;\n}\n\n.framework .item-photo img {\n  width: auto;\n  height: auto;\n}\n\n.framework .item-photo .item-photo-text {\n  font-size: 40px;\n}\n\n.demos {\n  padding-top: 80px;\n  padding-bottom: 80px;\n}\n\n.demos .section-title {\n  padding-bottom: 35px;\n}\n\n.demos .demo-photo .thumbnail {\n  display: block;\n}\n\n.demos .demo-photo img {\n  width: 100%;\n}\n\n.demos .demo-photo a {\n  text-transform: capitalize;\n}\n\n.demos .demo-photo a:hover {\n  color: #ffffff;\n}\n\n.component {\n  padding-top: 80px;\n  padding-bottom: 80px;\n}\n\n.component .section-title {\n  padding-bottom: 50px;\n}\n\n.component .component-list {\n  margin-bottom: 30px;\n}\n\n.component .component-list ul .comoponent-list-heading {\n  margin-left: 15px;\n  text-transform: capitalize;\n  margin-top: 2px;\n}\n\n.component .component-list ul li {\n  list-style: none;\n  margin-left: 45px;\n  opacity: 0.7;\n}\n\n.clients {\n  background-color: #f8fafe;\n  padding-top: 80px;\n  padding-bottom: 80px;\n}\n\n.clients .section-title {\n  padding-bottom: 50px;\n  text-align: center;\n}\n\n.clients .section-title h2 {\n  margin-bottom: 10px;\n}\n\n.clients .section-title p {\n  max-width: 550px;\n  margin: 0 auto;\n}\n\n.clients .complement {\n  max-width: 900px;\n  margin: 0 auto;\n}\n\n.clients .complement .client-card {\n  margin-bottom: 20px;\n  padding: 10px;\n  box-shadow: 0 4px 20px 1px rgba(0, 0, 0, 0.06), 0 1px 4px rgba(0, 0, 0, 0.08);\n}\n\n.clients .complement .client-card .user {\n  margin-left: 10px;\n}\n\n.clients .complement .client-card .user .user-photo {\n  margin-right: 30px;\n}\n\n.clients .complement .client-card .user .user-photo img {\n  width: 50px;\n  height: 50px;\n  border-radius: 50%;\n}\n\n.clients .complement .client-card .user .user-detail {\n  margin-top: 5px;\n}\n\n.clients .complement .client-card .user .user-detail h6 {\n  margin: 0px;\n}\n\n.clients .complement .client-card .user .user-detail p {\n  opacity: 0.8;\n}\n\n.clients .complement .client-card .user-comment {\n  margin-left: 10px;\n}\n\n.clients .complement .client-card .user-comment p {\n  max-width: 800px;\n  font-style: italic;\n  opacity: 0.7;\n}\n\n.blog {\n  padding-top: 80px;\n  padding-bottom: 80px;\n}\n\n.blog h2 {\n  max-width: 890px;\n  margin: 0px 0px 40px 0px;\n}\n\n.blog p {\n  max-width: 890px;\n  opacity: 0.7;\n}\n\n.blog .blog-photo {\n  margin: 20px 0px;\n}\n\n.blog .blog-photo img {\n  width: 100%;\n}\n\n.footer {\n  background-color: #f8fafe;\n  padding-top: 80px;\n}\n\n.footer .footer-item {\n  margin-bottom: 100px;\n}\n\n.footer .footer-item .social-media ul li {\n  list-style: none;\n  display: inline-block;\n  margin-left: 10px;\n}\n\n.footer .footer-item .social-media ul li a {\n  color: #111111a8;\n  background: #fff;\n  padding: 7px;\n  border-radius: 5px;\n}\n\n.footer .footer-bootom {\n  padding: 10px 0px;\n  border-top: 0.2px solid #fffffffa;\n}\n\n.footer .footer-bootom p {\n  margin: 0px;\n}\n\n.footer .btn-raised-primary:hover {\n  color: #fff;\n}\n\n.footer .btn-raised {\n  transition: all .15s ease-in;\n}\n\n.footer .btn-raised:hover {\n  transform: translateY(-2px);\n}\n\n@media (max-width: 960px) {\n  .dashboard .dashboard-photo {\n    max-width: calc(100% - 80px);\n  }\n  .dashboard {\n    height: 350px;\n  }\n}\n\n@media (max-width: 767px) {\n  .main-header .navbar-nav {\n    flex-direction: row;\n  }\n  .main-header .navbar-nav .nav-item {\n    margin-right: 8px;\n  }\n  .main-header .topbar .header-nav {\n    display: block;\n  }\n  .brand {\n    display: flex;\n    justify-content: space-between;\n    width: 100%;\n  }\n  .navbar-toggler {\n    padding: 5px 0px;\n    font-size: 1.25rem;\n    line-height: 1;\n    border: 0px solid #fff;\n    border-radius: 0.25rem;\n    display: flex;\n    flex-direction: column;\n    cursor: pointer;\n    display: flex;\n    justify-content: center;\n  }\n  .navbar-toggler .navbar-toggler-icon {\n    background: #1F2937;\n  }\n  .navbar-toggler:focus,\n  .navbar-toggler:hover {\n    text-decoration: none;\n    outline: none;\n  }\n  .navbar-collapse {\n    flex-basis: 100%;\n    flex-grow: 1;\n    align-items: center;\n    background: transparent;\n    background-size: auto;\n    background-repeat: no-repeat;\n    overflow: hidden;\n    z-index: 999;\n    text-align: center;\n  }\n  .navbar-toggler-icon {\n    display: inline-block;\n    width: 25px;\n    height: 2px;\n    vertical-align: middle;\n    content: \"\";\n    background: no-repeat center center;\n    background-size: 100% 100%;\n    background: #fff;\n    margin-top: 4px;\n  }\n  .dashboard {\n    height: 250px;\n  }\n  .features .features-wrap {\n    display: flex;\n    flex-direction: row;\n    flex-wrap: wrap;\n    justify-content: center;\n  }\n  .features .features-wrap .feature-card {\n    padding: 10px 10px;\n    margin: 5px 5px;\n  }\n  .features .features-wrap .feature-card .card-title {\n    margin: 0px;\n  }\n  .features .features-wrap .feature-card .card-title h6 {\n    margin: 0px;\n  }\n  .features .features-wrap .feature-card .card-icon {\n    display: none;\n  }\n  .framework .item-photo {\n    margin-bottom: 30px;\n  }\n  .component .component-list {\n    margin: 0 auto;\n  }\n  .component .component-list ul {\n    text-align: center;\n    padding: 0px;\n  }\n  .component .component-list ul li {\n    margin-left: 30px;\n  }\n  .component .component-list .comoponent-list-heading {\n    margin-left: 3px !important;\n  }\n  .footer .footer-item .social-media {\n    margin-top: 18px;\n  }\n  .footer .footer-item .social-media ul {\n    padding: 0px;\n  }\n  .footer .footer-item .social-media ul li {\n    margin-right: 20px;\n    margin-left: 0px;\n  }\n  .footer .footer-item .selling-btn {\n    margin-top: 10px;\n  }\n  .footer .footer-item .btn-arrow {\n    margin-top: 10px;\n  }\n}\n\n@media (max-width: 600px) {\n  .homepage {\n    padding: 80px 0;\n  }\n  .dashboard {\n    height: auto;\n    padding: 60px 0;\n  }\n  .dashboard .dashboard-photo {\n    position: unset !important;\n  }\n}\n\n@media only screen and (max-width: 991px) {\n  .ul-landing__navbar.collapse:not(.show) {\n    display: block !important;\n  }\n  .ul-landing__brand {\n    max-width: 80px !important;\n  }\n}\n\nlabel.ul-form__label {\n  font-size: 13px;\n  font-weight: 400;\n  margin-bottom: 5px;\n  text-align: right;\n  padding: 7px 0;\n}\n\nsmall.ul-form__text {\n  margin-top: 10px;\n  color: #6B7280;\n  font-weight: 400;\n}\n\n.input-right-icon {\n  position: relative;\n}\n\nspan.span-left-input-icon {\n  position: absolute;\n  top: 9px;\n  left: 10px;\n}\n\nspan.span-right-input-icon {\n  position: absolute;\n  top: 9px;\n  /* left: 0; */\n  right: 10px;\n}\n\ni.ul-form__icon {\n  color: #4B5563;\n  font-size: 15px;\n  font-weight: 600;\n}\n\n.ul-form__radio-inline {\n  display: flex;\n}\n\nspan.ul-form__radio-font {\n  font-size: 14px;\n  font-weight: 500;\n}\n\n.footer-delete-right {\n  float: right;\n}\n\n.ul-card__margin-25 {\n  margin: 25px 0;\n}\n\n@media only screen and (max-width: 991px) {\n  label.ul-form--margin {\n    text-align: left;\n    margin-left: 20px;\n  }\n}\n\nlabel.action-bar-horizontal-label {\n  font-size: 15px;\n}\n\n.ul-form__radio {\n  position: relative;\n}\n\nspan.checkmark.ul-radio__position {\n  position: absolute;\n  /* bottom: -22px; */\n  top: -8px;\n  left: 4px;\n}\n\ni.ul-tab__icon {\n  font-size: 14px;\n  font-weight: 500;\n}\n\n.ul-tab__border {\n  border: 1px dashed #6B7280;\n  margin: 30px 0;\n}\n\n.ul-tab__content {\n  margin: 0;\n  padding-left: 0;\n}\n\n.ul-dropdown__toggle {\n  padding: 8px 25px;\n  margin: 0 5px;\n}\n\n.tab-border {\n  border: 1px dashed #ebedf2 !important;\n  margin: 30px 0 !important;\n}\n\nspan._r_block-dot {\n  display: block;\n  margin: 2px 0;\n}\n\n._r_btn {\n  border: 1px solid #e8ecfa;\n}\n\n._r_drop_right {\n  padding-right: 14px !important;\n}\n\n.ul-accordion__link:hover {\n  list-style: none;\n  text-decoration: none !important;\n}\n\nbutton.ul-accordion__link {\n  text-decoration: none !important;\n}\n\n.ul-accordion__font {\n  font-size: 16px;\n}\n\n.ul-cursor--pointer {\n  cursor: pointer;\n}\n\n.ul-border__bottom {\n  border-bottom: 1px solid #6366f1;\n}\n\n.ul-card__v-space {\n  border-radius: 0;\n  box-shadow: 0;\n  margin: 30px 0;\n}\n\n.ul-card__border-radius {\n  border-radius: 0;\n  box-shadow: none;\n}\n\n.header-elements-inline {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  flex-wrap: nowrap;\n}\n\n.ul-card__list--icon-font i {\n  font-weight: 700;\n  margin: 0 2px;\n}\n\n.accordion .ul-collapse__icon--size a::before {\n  font-family: 'iconsmind';\n  font-size: 18px;\n  font-weight: 700;\n  vertical-align: bottom;\n  cursor: pointer;\n}\n\n.accordion .ul-collapse__left-icon a.collapsed:before {\n  font-family: 'iconsmind';\n  content: \"\\F083\";\n  margin: 0 8px;\n}\n\n.accordion .ul-collapse__left-icon a:before {\n  font-family: 'iconsmind';\n  content: \"\\F072\";\n  margin: 0 8px;\n}\n\n.accordion .ul-collapse__right-icon a.collapsed:before {\n  font-family: 'iconsmind';\n  content: \"\\F083\";\n  margin: 0 8px;\n  float: right;\n  position: absolute;\n  right: 15px;\n}\n\n.accordion .ul-collapse__right-icon a:before {\n  font-family: 'iconsmind';\n  content: \"\\F072\";\n  margin: 0 8px;\n  float: right;\n  position: absolute;\n  right: 15px;\n}\n\n.ul-widget__item {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  border-bottom: 0.07rem dashed #D1D5DB;\n  padding: 1.1rem 0;\n}\n\n.ul-widget1__title {\n  font-size: 1.1rem;\n  font-weight: 700;\n  color: #4B5563;\n}\n\n.ul-widget__desc {\n  font-size: 0.9rem;\n  font-weight: normal;\n}\n\n.ul-widget__number {\n  font-size: 1.4rem;\n  font-weight: 700;\n}\n\n.ul-widget__item:last-child {\n  border-bottom: 0;\n}\n\n.ul-widget__head {\n  display: flex;\n  justify-content: space-between;\n  border-bottom: 1px solid #E5E7EB;\n  align-items: center;\n}\n\n.ul-widget__head.\\--v-margin {\n  padding: 10px 0;\n}\n\n.ul-widget__head-title {\n  margin: 0;\n  font-size: 1.2rem;\n  font-weight: 500;\n  color: #1F2937;\n}\n\n.ul-widget-nav-tabs-line .nav-item .nav-link.active {\n  border: 1px solid transparent;\n  border-color: #fff #fff #6366f1 #fff;\n}\n\n.ul-widget-nav-tabs-line .nav-link {\n  font-weight: 700;\n}\n\n.ul-widget__body {\n  margin-top: 10px;\n}\n\n.ul-widget2__item {\n  display: flex;\n  justify-content: space-between;\n  margin-bottom: 1.4rem;\n  align-items: center;\n  position: relative;\n}\n\n.ul-widget2__info {\n  display: flex;\n  flex-direction: column;\n  flex-grow: 1;\n  margin-left: 10px;\n}\n\n.ul-widget2__title {\n  font-weight: 600;\n  color: #4B5563;\n}\n\n.ul-widget2__username {\n  font-size: 0.7rem;\n  color: #4B5563;\n}\n\n.ul-widget__link--font i {\n  font-weight: 700;\n  font-size: 13px;\n  letter-spacing: 2px;\n}\n\n.ul-widget__link--font {\n  color: #4B5563;\n  font-weight: 600;\n  font-size: 15px;\n}\n\n.ul-pl-0 {\n  padding-left: 0;\n}\n\n.ul-checkmark {\n  position: absolute;\n  top: -4px !important;\n  left: 20px !important;\n}\n\n.ul-widget2__actions {\n  opacity: 0;\n  visibility: hidden;\n}\n\n.ul-widget1:hover .ul-widget2__actions {\n  opacity: 1;\n  visibility: visible;\n  transition: 0.3s;\n}\n\n.pb-20 {\n  padding-bottom: 20px;\n}\n\n.ul-widget-notification-item {\n  display: flex;\n  align-items: center;\n  padding: 2px;\n  position: relative;\n  border-bottom: 1px solid #E5E7EB;\n  padding: 10px 0px;\n}\n\n.ul-widget-notification-item:last-child {\n  border-bottom: none;\n}\n\n.ul-widget-notification-item:hover {\n  background-color: #F3F4F6;\n}\n\n.ul-widget-notification-item-icon {\n  /* padding-left: 12px; */\n  padding-right: 20px;\n}\n\n.ul-widget-notification-item-title {\n  transition: color 0.3s ease;\n  font-size: 1rem;\n  font-weight: 400;\n  color: #374151;\n}\n\n.ul-widget-notification-item-time {\n  font-size: 13px;\n  font-weight: 300;\n  color: #6B7280;\n}\n\n.ul-widget-notification-item::after {\n  content: \"\\F07D\";\n  font-family: \"iconsmind\";\n  position: absolute;\n  /* top: 16px; */\n  right: 0;\n}\n\n.ul-widget-notification-item i {\n  font-size: 27px;\n}\n\n.ul-widget3-img img {\n  width: 3.2rem;\n  border-radius: 50%;\n}\n\n.ul-widget3-item {\n  margin-bottom: 1rem;\n  border-bottom: 0.07rem dashed #E5E7EB;\n}\n\n.ul-widget3-item:last-child {\n  border: none;\n}\n\n.ul-widget3-header {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  padding-bottom: 0.8rem;\n}\n\nspan.ul-widget3-status {\n  flex-grow: 1;\n  text-align: right;\n}\n\n.ul-widget3-info {\n  padding-left: 10px;\n}\n\n.ul-widget4__item {\n  display: flex;\n  align-items: center;\n  border-bottom: 1px dashed #D1D5DB;\n  padding: 15px 0;\n}\n\n.ul-widget4__item:last-child {\n  border-bottom: 0;\n}\n\n.ul-widget4__pic-icon {\n  margin-right: 15px;\n  font-size: 25px;\n}\n\na.ul-widget4__title {\n  color: #4B5563;\n  font-weight: 700;\n  font-size: 15px;\n}\n\na.ul-widget4__title:hover {\n  color: #6366f1;\n}\n\n.ul-widget4__img img {\n  width: 2.5rem;\n  border-radius: 5px;\n  margin-right: 15px;\n}\n\n.ul-widget4__users {\n  justify-content: space-between;\n}\n\n.ul-widget2__info.ul-widget4__users-info {\n  flex-grow: 1;\n  width: calc(100% - 135px);\n}\n\nspan.ul-widget4__number.t-font-boldest {\n  font-size: 1.1rem;\n  /* font-weight: 900; */\n}\n\n.ul-widget5__item {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  margin-bottom: 1.43rem;\n  padding-bottom: 1.57rem;\n  border-bottom: 0.07rem dashed #E5E7EB;\n}\n\n.ul-widget5__item:last-child {\n  border-bottom: none;\n}\n\n.ul-widget5__content {\n  display: flex;\n  align-items: center;\n}\n\n.ul-widget5__stats {\n  display: flex;\n  flex-direction: column;\n  text-align: right;\n}\n\n.ul-widget5__stats:first-child {\n  padding-right: 3rem;\n}\n\nspan.ul-widget5__number {\n  font-size: 1.3rem;\n  font-weight: 600;\n  color: #4B5563;\n}\n\n.ul-widget5__pic img {\n  padding-right: 1.43rem;\n  width: 8.6rem;\n  border-radius: 4px;\n}\n\np.ul-widget5__desc {\n  margin: 0;\n  padding: 0.4rem 0;\n  font-size: 1rem;\n  font-weight: 400;\n  color: #9CA3AF;\n}\n\n.ul-widget5__info span:nth-child(even) {\n  font-weight: 600;\n  padding-right: 0.71rem;\n}\n\n.ul-widget6__head .ul-widget6__item {\n  display: flex;\n  align-items: center;\n  margin-bottom: 1.07rem;\n}\n\n.ul-widget6__head .ul-widget6__item span {\n  flex: 1;\n  text-align: left;\n  font-size: 0.8rem;\n  color: #6B7280;\n  font-weight: 500;\n}\n\n.ul-widget6__head .ul-widget6__item span:last-child {\n  text-align: right;\n}\n\n.ul-widget6__body .ul-widget6__item {\n  display: flex;\n  align-items: center;\n  padding: 1.07rem 0;\n  border-bottom: 0.07rem dashed #E5E7EB;\n}\n\n.ul-widget6__body .ul-widget6__item:last-child {\n  border-bottom: none;\n}\n\n.ul-widget6__body .ul-widget6__item span {\n  flex: 1;\n  text-align: left;\n  color: #4B5563;\n  font-weight: 400;\n}\n\n.ul-widget6__body .ul-widget6__item span:last-child {\n  text-align: right;\n}\n\n.ul-widget6 .ul-widget6-footer {\n  text-align: right;\n  margin: 0;\n}\n\n.ul-widget-s5__pic img {\n  width: 4rem;\n  border-radius: 50%;\n}\n\n.ul-widget-s5__pic {\n  padding-right: 1rem;\n}\n\na.ul-widget4__title.ul-widget5__title {\n  font-size: 1.1rem;\n}\n\n.ul-widget-s5__desc {\n  margin: 0;\n  color: #4B5563;\n}\n\n.ul-widget-s5__item {\n  display: flex;\n  justify-content: space-between;\n}\n\n.ul-widget-s5__content {\n  display: flex;\n  align-items: center;\n}\n\n.ul-widget-s5__content:last-child {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n}\n\n.ul-widget-s5__progress {\n  flex: 1;\n  padding-right: 1rem;\n}\n\n.ul-widget-s5__stats {\n  justify-content: space-between;\n  display: flex;\n  margin-bottom: 0.7rem;\n}\n\n.ul-widget-s5__stats span {\n  font-size: 1rem;\n  font-weight: 600;\n  color: #374151;\n}\n\n.widget-badge {\n  margin: 0 !important;\n}\n\n.ul-widget-s6__items {\n  position: relative;\n}\n\n.ul-widget-s6__items:before {\n  content: \"\";\n  position: absolute;\n  display: block;\n  width: 1px;\n  background-color: #D1D5DB;\n  height: 100%;\n  left: 3px;\n  top: 14px;\n}\n\np.ul-widget6__dot {\n  height: 8px;\n  width: 8px;\n  margin: 0;\n  position: relative;\n  z-index: 1;\n}\n\n.ul-widget-s6__item {\n  display: flex;\n  justify-content: space-between;\n  margin: 1rem 0;\n}\n\np.ul-widget-s6__text {\n  flex-grow: 1;\n  margin-left: 11px;\n}\n\nspan.ul-widget-s6__text {\n  display: flex;\n  flex-grow: 1;\n  /* margin-right: -26px; */\n  padding-left: 12px;\n  color: #4B5563;\n  font-weight: 600;\n}\n\nspan.ul-widget-s6__time {\n  font-size: 0.77rem;\n  color: #6B7280;\n}\n\n.ul-widget6__item--table {\n  height: 400px;\n  overflow-y: scroll;\n}\n\ntr.ul-widget6__tr--sticky-th th {\n  position: sticky;\n  top: 0;\n  background-color: #fff;\n}\n\n.ul-widget-s7__items {\n  display: flex;\n}\n\n.ul-widget-s7__item-circle {\n  margin: 0 1rem;\n}\n\n.ul-widget-s7__item-circle i {\n  font-size: 16px;\n  font-weight: 900;\n}\n\n.ul-widget-s7 {\n  position: relative;\n  padding: 15px 0;\n}\n\n.ul-widget-s7:before {\n  content: \"\";\n  position: absolute;\n  width: 1;\n  height: 100%;\n  background-color: #9CA3AF;\n  width: 0.241rem;\n  /* top: 0; */\n  left: 72px;\n  top: 22px;\n}\n\np.ul-widget7__big-dot {\n  height: 13px;\n  width: 13px;\n  margin: 0;\n  position: relative;\n  z-index: 1;\n}\n\n.ul-widget-s7__item-time {\n  font-size: 1.2rem;\n  font-weight: 500;\n  color: #4B5563;\n}\n\n.ul-widget-s7__item-time.ul-middle {\n  display: flex;\n  align-items: center;\n}\n\n.ul-widget-s7__item-text {\n  font-size: 1rem;\n  color: #4B5563;\n}\n\n.ul-widget-s7:last-child:before {\n  background-color: #F3F4F6;\n}\n\n.ul-vertical-line {\n  height: 100%;\n  width: 7px;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.ul-widget8__tbl-responsive {\n  display: block;\n  width: 100%;\n  overflow-x: auto;\n}\n\n.ul-widget_user-card {\n  display: flex;\n  align-items: center;\n}\n\n@media only screen and (max-width: 425px) {\n  .ul-widget__number {\n    font-size: 1.1rem;\n    font-weight: 700;\n  }\n  .ul-widget1__title {\n    font-size: 0.9rem;\n  }\n  .ul-widget__desc {\n    font-size: 0.7rem;\n  }\n  .ul-widget__head {\n    flex-direction: column;\n  }\n  .ul-widget__head-label {\n    margin: 10px 0;\n  }\n  .ul-widget__head.v-margin {\n    flex-direction: unset;\n  }\n}\n\n@media only screen and (max-width: 1024px) {\n  .ul-widget2__actions {\n    opacity: 1;\n    visibility: visible;\n  }\n}\n\n@media only screen and (max-width: 768px) {\n  .ul-widget-s5__content:last-child {\n    width: 100%;\n  }\n  .ul-widget-s5__item {\n    justify-content: space-between;\n    display: block;\n  }\n  .ul-widget-s5__content {\n    margin: 15px 0;\n  }\n}\n\n@media only screen and (max-width: 375px) {\n  .ul-widget5 {\n    overflow-x: auto;\n  }\n  a.ul-widget4__title {\n    font-size: 12px;\n    padding-right: 5px;\n  }\n  a.ul-widget4__title.ul-widget5__title {\n    font-size: 11px;\n  }\n  p.ul-widget-s5__desc {\n    font-size: 11px;\n  }\n}\n\n@media only screen and (max-width: 725px) {\n  .ul-widget5__item {\n    display: block;\n    text-align: center !important;\n  }\n  .ul-widget5__content {\n    display: block;\n    margin-bottom: 15px;\n  }\n  .ul-widget5__stats:first-child {\n    padding-right: 0;\n  }\n  .ul-widget5__stats {\n    text-align: center;\n  }\n}\n\n.ul-card__widget-chart {\n  padding: 0px;\n}\n\n.ul-widget__chart-info {\n  padding: 15px;\n}\n\n.ul-widget__row {\n  align-items: center;\n  display: flex;\n}\n\n.ul-widget__content {\n  margin-left: 30px;\n}\n\n.ul-widget__row-v2 {\n  text-align: center;\n  text-align: -webkit-center;\n}\n\n.ul-widget-stat__font i {\n  font-size: 35px;\n}\n\n.ul-widget__content-v4 {\n  text-align: center;\n}\n\n.ul-widget-card__info {\n  display: flex;\n  justify-content: space-between;\n}\n\n.ul-widget-card__info span p:first-child {\n  font-size: 20px;\n  font-weight: 500;\n  margin-bottom: 2px;\n}\n\n.ul-widget-card__info span p:last-child {\n  font-size: 17px;\n  margin: 0;\n}\n\n.ul-widget-card__progress-rate {\n  display: flex;\n  justify-content: space-between;\n  margin-top: 12px;\n  margin-bottom: 5px;\n}\n\n.ul-widget-card__progress-rate span {\n  font-weight: 700;\n}\n\n.ul-widget-card__progress-rate span:last-child {\n  font-weight: 700;\n  color: #9CA3AF;\n}\n\n.progress--height {\n  height: 10px;\n}\n\n.ul-widget-card__user-info {\n  text-align: center;\n}\n\n.ul-widget-card--line {\n  border-bottom: 1px solid #D1D5DB;\n  padding-bottom: 20px;\n}\n\n.ul-widget-card--line:last-child {\n  border-bottom: none;\n}\n\n.ul-widget-card__rate-icon {\n  display: flex;\n  justify-content: space-between;\n  margin: 15px 0;\n}\n\n.ul-widget-card__rate-icon.\\--version-2 {\n  justify-content: flex-start;\n}\n\n.ul-widget-card__rate-icon.\\--version-2 span {\n  margin-right: 18px;\n}\n\n.ul-widget-card__rate-icon span i {\n  font-size: 14px;\n}\n\n.ul-widget-card__rate-icon span {\n  font-size: 15px;\n}\n\n.ul-widget-card__rate-icon span i {\n  font-size: 16px;\n  font-weight: 600;\n  margin-right: 2px;\n}\n\n.ul-widget-card__full-status {\n  display: flex;\n  justify-content: space-between;\n}\n\n.ul-widget-card__status1 {\n  display: grid;\n  text-align: -webkit-center;\n  text-align: center;\n}\n\n.ul-widget-card__status1 span:first-child {\n  font-size: 1.25rem;\n  font-weight: 600;\n}\n\n.ul-widget6__dot.ul-widget-card__dot-xl {\n  padding: 1.35rem;\n}\n\n.ul-widget-s6__badge .ul-widget-card__dot {\n  position: relative;\n}\n\n.ul-widget6__dot.ul-widget-card__dot-xl i {\n  position: absolute;\n  top: 35%;\n  content: \"\";\n  left: 35%;\n}\n\n.ul-widget-s6__items.ul-widget-card__position:before {\n  left: 20px;\n  top: 0;\n}\n\n.ul-widget-card__item {\n  display: flex;\n  align-items: center;\n  padding: 20px 0;\n}\n\n.ul-widget-card__info-v2 {\n  display: grid;\n  /* margin-right: 2px; */\n  margin-left: 20px;\n}\n\n.ul-widget-card__img-bg {\n  background-size: cover;\n  height: 500px;\n  background-repeat: no-repeat, repeat;\n}\n\n.ul-widget-card__cloud .ul-widget-card__head h1 {\n  color: #fff;\n}\n\n.ul-widget-card__cloud .ul-widget-card__head i {\n  color: #fff !important;\n}\n\n.ul-widget-card__head {\n  display: flex;\n  justify-content: space-around;\n  margin: 60px 0;\n  align-items: center;\n}\n\n.ul-widget-card__weather-info {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  font-size: 20px;\n  margin: 45px 0;\n}\n\n.ul-b4__box {\n  width: 5rem;\n  height: 5rem;\n  background-color: #9CA3AF;\n  display: inline-block;\n  margin: 0 5px;\n}\n\n.ul-b4__border {\n  border: 1px solid #6366f1;\n}\n\n.ul-b4__border-top {\n  border-top: 1px solid #6366f1;\n}\n\n.ul-b4__border-right {\n  border-right: 1px solid #6366f1;\n}\n\n.ul-b4__border-bottom {\n  border-bottom: 1px solid #6366f1;\n}\n\n.ul-b4__border-left {\n  border-left: 1px solid #6366f1;\n}\n\n.ul-b4-utilities__code pre {\n  margin: 0;\n  padding: 0;\n  font-size: 15px;\n}\n\n.ul-b4-utilities__code {\n  padding: 25px 10px;\n  background-color: #E5E7EB;\n}\n\n.ul-b4__border-0 {\n  border: none;\n}\n\n.ul-b4__border-top-0 {\n  border-top: none;\n  border-bottom: 1px solid #6366f1;\n  border-right: 1px solid #6366f1;\n  border-left: 1px solid #6366f1;\n}\n\n.ul-b4__border-right-0 {\n  border-right: none;\n  border-bottom: 1px solid #6366f1;\n  border-left: 1px solid #6366f1;\n  border-top: 1px solid #6366f1;\n}\n\n.ul-b4__border-bottom-0 {\n  border-bottom: none;\n  border-left: 1px solid #6366f1;\n  border-top: 1px solid #6366f1;\n  border-right: 1px solid #6366f1;\n}\n\n.ul-b4__border-left-0 {\n  border-bottom: 1px solid #6366f1;\n  border-left: none;\n  border-top: 1px solid #6366f1;\n  border-right: 1px solid #6366f1;\n}\n\n.ul-b4-display__info-1 {\n  margin-bottom: 60px;\n}\n\n.ul-b4-display__info-1 p {\n  font-size: 14px;\n  color: #4B5563;\n}\n\n.ul-b4-display__table {\n  margin-top: 20px;\n}\n\n.ul-b4-display__table tr th {\n  font-size: 17px;\n}\n\n.ul-b4-display__table tr td {\n  font-size: 14px;\n}\n\n.ul-display__print ul li code {\n  font-size: 15px;\n}\n\n.ul-display__margin {\n  margin: 40px 0;\n}\n\n.ul-display__paragraph {\n  font-size: 14px;\n}\n\n.ul-weather-card__img-overlay {\n  background-size: cover;\n  height: 400px;\n  background-position-y: center;\n  background-repeat: no-repeat;\n}\n\n.display-4 {\n  font-size: 3.5rem;\n}\n\n.ul-weather-card__weather-time {\n  padding: 30px;\n}\n\n.ul-weather-card__img-overlay span {\n  font-size: 20px;\n}\n\n.display-5 {\n  font-size: 2.5rem !important;\n}\n\n.ul-weather-card__weather-info i {\n  font-size: 25px;\n  font-weight: 600;\n}\n\n.ul-weather-card__weather-info {\n  margin: 20px 0;\n}\n\n.ul-weather-card__font-md {\n  font-size: 20px;\n  font-weight: 600;\n}\n\n.ul-weather-card__header {\n  display: flex;\n  align-items: center;\n}\n\n.ul-weather-card__header span {\n  color: #fff;\n  font-size: 18px;\n}\n\n.ul-weather-card__calendar {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n}\n\n.ul-weather-card__calendar-2 {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n}\n\n.ul-weather-card__both-group {\n  padding: 25px;\n}\n\n.ul-weather-card__inner-card {\n  width: 100%;\n}\n\n.ul-weather-card__info {\n  display: flex;\n  justify-content: space-between;\n  font-size: 16px;\n}\n\n.card .ul-weather-card__bg-img img {\n  width: 100%;\n  height: 300px;\n}\n\n.ul-weather-card__img-overlay-2 {\n  position: absolute;\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  padding: 1.25rem;\n}\n\n.ul-weather-card__img-overlay-2 span {\n  color: #fff;\n}\n\n.font-25 {\n  font-size: 25px;\n}\n\n.ul-weather-card__footer-color {\n  color: #6366f1;\n  font-weight: 600;\n}\n\n.ul-weather-card__footer-color-2 {\n  color: #ec4899;\n}\n\n.ul-weather-card__grid-style {\n  display: grid;\n}\n\n.ul-weather-card__weather-s-title {\n  font-size: 1rem;\n}\n\n.ul-weather-card__footer-color-3 h5 {\n  color: #14b8a6;\n}\n\n.ul-weather-card__footer-color-3 h4 {\n  color: #14b8a6;\n}\n\n.ul-widget-app__row-comments {\n  display: flex;\n  align-items: center;\n  padding: 14px;\n  margin-bottom: 10px;\n}\n\n.ul-widget-app__row-comments:hover {\n  background-color: #E5E7EB;\n}\n\n.ul-widget-app__row-comments:hover .ul-widget-app__icons a i {\n  opacity: 1;\n  visibility: visible;\n}\n\n.ul-widget-app__icons a i:hover {\n  color: #8b5cf6;\n}\n\n.ul-widget-app__roundbg-icon {\n  border-radius: 50% !important;\n  line-height: 40px;\n  height: 40px;\n  min-width: 40px;\n  text-align: center;\n  padding: 0px !important;\n}\n\n.ul-widget-app__comment {\n  width: calc(100% - 86px);\n}\n\n.ul-widget-app__profile-status {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n}\n\n.ul-widget-app__icons {\n  flex-grow: 1;\n}\n\n.ul-widget-app__icons {\n  font-size: 17px;\n}\n\n.ul-widget-app__icons a i {\n  margin: 0 3px;\n  font-weight: 600;\n  opacity: 0;\n  visibility: hidden;\n  vertical-align: middle;\n}\n\n.ul-widget-app__recent-messages {\n  height: calc(100vh - 350px);\n  overflow-y: scroll;\n  cursor: pointer;\n}\n\n.ul-widget-app__skill-margin span {\n  margin: 0 5px;\n}\n\n.ul-widget-app__profile-footer {\n  display: flex;\n  justify-content: space-around;\n  align-items: center;\n}\n\n.ul-widget-app__profile-footer-font a span {\n  vertical-align: middle;\n}\n\n.ul-widget-app__profile-footer-font a i {\n  vertical-align: middle;\n}\n\n.ul-widget-app__browser-list-1 {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n}\n\n.notification_widget .ul-widget-app__browser-list-1 {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  cursor: pointer;\n}\n\n.notification_widget .ul-widget-app__browser-list-1:hover {\n  background: #eee;\n}\n\n.ul-widget-app__browser-list-1 span {\n  flex-grow: 1;\n}\n\n.ul-widget-app__browser-list-1 span:last-child {\n  flex-grow: 0;\n}\n\nspan.ul-widget-app__find-font {\n  position: absolute;\n  /* left: 0; */\n  top: 4px;\n  right: 10px;\n  color: #8b5cf6;\n  bottom: 0;\n  font-size: 20px;\n}\n\n.ul-widget-app__small-title {\n  display: grid;\n}\n\n.user-profile.ul-widget-app__profile--position {\n  position: absolute;\n  top: 40%;\n  left: 0;\n  margin: 0 auto;\n  right: 0;\n  transform: translateY(-50%);\n}\n\n.timeline--align {\n  bottom: 8px;\n}\n\n.ul-product-detail__features ul li {\n  list-style: none;\n  margin: 8px 0;\n}\n\n.ul-counter-cart .btn-group {\n  display: flex;\n  align-items: center;\n}\n\n.ul-counter-cart .btn-group .btn {\n  padding: 0px !important;\n  border: 0;\n  background-color: transparent;\n  margin: 0px 14px;\n}\n\nul.gull-pagination li {\n  margin: 0 12px;\n}\n\nul.gull-pagination li .page-link {\n  border-radius: 50% !important;\n  border-color: #fff !important;\n}\n\n.page-link:hover {\n  background-color: #fff;\n}\n\n.page-link:focus {\n  box-shadow: 0 0 0 0.2rem white;\n}\n\n.page-item.disabled .page-link {\n  color: #d5d0d9;\n}\n\nhtml {\n  font-size: 16px;\n}\n\nbody {\n  letter-spacing: 0.3px;\n  line-height: 1.6;\n  background: #fff;\n  overflow-x: hidden;\n  overflow-y: scroll;\n}\n\n[tabindex=\"-1\"]:focus {\n  outline: none;\n}\n\nhr {\n  margin-top: 2rem;\n  margin-bottom: 2rem;\n  border: 0;\n  border-top: 1px solid rgba(0, 0, 0, 0.1);\n  height: 0;\n}\n\nselect,\nbutton,\ntextarea,\ninput {\n  vertical-align: baseline;\n}\n\ndiv {\n  box-sizing: border-box;\n}\n\nhtml[dir=\"rtl\"], html[dir=\"ltr\"],\nbody[dir=\"rtl\"],\nbody[dir=\"ltr\"] {\n  unicode-bidi: embed;\n}\n\nbdo[dir=\"rtl\"] {\n  direction: rtl;\n  unicode-bidi: bidi-override;\n}\n\nbdo[dir=\"ltr\"] {\n  direction: ltr;\n  unicode-bidi: bidi-override;\n}\n\nimg {\n  max-width: 100%;\n}\n\na,\na:focus,\na:hover {\n  text-decoration: none;\n}\n\nblockquote {\n  border-left: 2px solid #E5E7EB;\n  padding-left: 1rem;\n  margin-bottom: 1rem;\n  font-size: 1.01625rem;\n}\n\n.close:not(:disabled):not(.disabled):hover, .close:not(:disabled):not(.disabled):focus {\n  outline: none;\n}\n\n.o-hidden {\n  overflow: hidden;\n}\n\n.separator-breadcrumb {\n  margin-bottom: 2rem;\n}\n\n.line-height-1 {\n  line-height: 1;\n}\n\n.line-height-2 {\n  line-height: 2;\n}\n\n.line-height-3 {\n  line-height: 3;\n}\n\n.line-height-4 {\n  line-height: 4;\n}\n\n.line-height-5 {\n  line-height: 5;\n}\n\n.app-inro-circle {\n  text-align: center;\n  text-align: center;\n  position: absolute;\n  left: 0;\n  right: 0;\n  margin: auto;\n  top: calc(50% - 150px);\n}\n\n.app-inro-circle .big-bubble {\n  height: 280px;\n  width: 280px;\n  margin: 0 auto 20px;\n  text-align: center;\n  background: #8b5cf6;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n.app-inro-circle .big-bubble i {\n  font-size: 108px;\n  color: #ffffff;\n}\n\n.loadscreen {\n  text-align: center;\n  position: fixed;\n  width: 100%;\n  left: 0;\n  right: 0;\n  margin: auto;\n  top: 0;\n  height: 100vh;\n  background: #ffffff;\n  z-index: 999;\n}\n\n.loadscreen .loader {\n  position: absolute;\n  top: calc(50vh - 50px);\n  left: 0;\n  right: 0;\n  margin: auto;\n}\n\n.loadscreen .logo {\n  display: inline-block !important;\n  width: 80px;\n  height: 80px;\n}\n\n.img-preview {\n  overflow: hidden;\n  float: left;\n  background-color: #E5E7EB;\n  width: 100%;\n  text-align: center;\n  margin-right: 10px;\n  margin-bottom: 10px;\n}\n\n.preview-lg {\n  width: 200px;\n  height: 150px;\n}\n\n.preview-md {\n  width: 150px;\n  height: 120px;\n}\n\n.preview-sm {\n  width: 100px;\n  height: 75px;\n}\n\n.custom-select {\n  appearance: none;\n  -webkit-appearance: none;\n  -moz-appearance: none;\n}\n\n.header-cover {\n  background: url("+escape(__webpack_require__(/*! ./../../../images/photo-wide-5.jpeg */"./resources/src/assets/images/photo-wide-5.jpeg"))+");\n}\n\n.loading_page {\n  height: 80px;\n  width: 80px;\n  left: calc(50% - 50px);\n  margin-top: 5%;\n}\n\n.spinner.sm {\n  height: 2em;\n  width: 2em;\n}\n\n.row_deleted {\n  background-color: lavender;\n}\n\n.change_amount {\n  font-size: .9rem;\n  color: #868e96;\n  margin-left: 10px;\n}\n\n#nprogress .bar {\n  background: #8b5cf6;\n}\n\n#nprogress .spinner-icon {\n  border-top-color: #8b5cf6;\n  border-left-color: #8b5cf6;\n}\n\n#nprogress .spinner {\n  display: block;\n  position: fixed;\n  z-index: 1031;\n  top: 15px;\n  right: 15px;\n  width: auto;\n  height: auto;\n  background: transparent;\n}\n\n#nprogress .spinner:after {\n  background: transparent;\n}\n\n@media (max-width: 576px) {\n  .app-inro-circle .big-bubble {\n    width: 220px;\n    height: 220px;\n  }\n  button.close {\n    float: right;\n    font-size: 1.2195rem;\n    font-weight: 700;\n    line-height: 1;\n    color: #000;\n    text-shadow: 0 1px 0 #fff;\n    opacity: 0.5;\n    position: absolute;\n    top: 0;\n    right: 5px;\n  }\n}\n\n@media (max-width: 764px) {\n  .vgt-global-search.vgt-clearfix {\n    display: flex;\n    flex-direction: column;\n  }\n}\n\n[dir=\"rtl\"] .rtl-ps-none .ps__rail-x,\n[dir=\"rtl\"] .rtl-ps-none .ps__rail-y {\n  display: none;\n}\n\n.dark-theme {\n  background: #292929;\n}\n\n.dark-theme .text-muted {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .sidebar-left,\n.dark-theme .sidebar-left-secondary,\n.dark-theme .main-header,\n.dark-theme .card {\n  background: #292929;\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .border-bottom {\n  border-bottom: 1px solid #202020 !important;\n}\n\n.dark-theme .main-content-wrap {\n  background-color: #202020;\n  color: #d8d8d8 !important;\n}\n\n.dark-theme h1,\n.dark-theme h2,\n.dark-theme h3,\n.dark-theme h4,\n.dark-theme h5,\n.dark-theme h6,\n.dark-theme .card-title,\n.dark-theme .text-title {\n  color: #d8d8d8;\n}\n\n.dark-theme .card-title {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme a {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme input,\n.dark-theme textarea {\n  background: #202020 !important;\n  border-color: #292929;\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .app-footer {\n  background: #292929;\n}\n\n.dark-theme .navigation-left .nav-item {\n  color: #d8d8d8 !important;\n  border-bottom: 1px solid #202020 !important;\n}\n\n.dark-theme .navigation-left .nav-item .nav-item-hold {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .navigation-left .nav-item .nav-item-hold a {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .sidebar-left-secondary .childNav li.nav-item {\n  display: block;\n}\n\n.dark-theme .sidebar-left-secondary .childNav li.nav-item a {\n  color: #d8d8d8;\n}\n\n.dark-theme .sidebar-left-secondary .childNav li.nav-item a:hover {\n  background: #202020;\n}\n\n.dark-theme .sidebar-left-secondary .childNav li.nav-item a.open {\n  color: #8b5cf6;\n}\n\n.dark-theme .sidebar-left-secondary .childNav li.nav-item a.router-link-active {\n  color: #8b5cf6;\n}\n\n.dark-theme .sidebar-left-secondary .childNav li.nav-item a.router-link-active .nav-icon {\n  color: #8b5cf6;\n}\n\n.dark-theme .sidebar-left-secondary .childNav li.nav-item a .nav-icon {\n  color: #d8d8d8;\n}\n\n.dark-theme .search-ui {\n  position: fixed;\n  background: #202020;\n}\n\n.dark-theme .search-ui input.search-input {\n  background: #202020;\n}\n\n.dark-theme .search-ui input.search-input::-moz-placeholder {\n  color: #d8d8d8;\n}\n\n.dark-theme .search-ui input.search-input:-ms-input-placeholder {\n  color: #d8d8d8;\n}\n\n.dark-theme .search-ui input.search-input::placeholder {\n  color: #d8d8d8;\n}\n\n.dark-theme .search-bar {\n  background: #292929 !important;\n  border: 1px solid #202020 !important;\n}\n\n.dark-theme .search-bar input {\n  color: #d8d8d8 !important;\n  background: #292929 !important;\n}\n\n.dark-theme .border-top {\n  border-top: 1px solid #292929 !important;\n}\n\n.dark-theme .tab-border {\n  border: 1px dashed #202020 !important;\n}\n\n.dark-theme table.vgt-table {\n  background: #292929;\n}\n\n.dark-theme .vgt-table thead th {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme table.tableOne.vgt-table thead tr th {\n  background: #292929;\n  border-color: #202020;\n}\n\n.dark-theme .list-group-item {\n  background-color: #292929;\n  border: 1px solid #202020;\n}\n\n.dark-theme .page-link {\n  color: #d8d8d8;\n  background-color: #202020;\n  border: 1px solid #292929;\n}\n\n.dark-theme .dropdown-menu {\n  color: #d8d8d8;\n  background-color: #202020;\n  border: 1px solid #202020;\n}\n\n.dark-theme .table td {\n  border-top: 1px solid #202020;\n}\n\n.dark-theme .table thead th {\n  border-bottom: 2px solid #202020;\n}\n\n.dark-theme .table .thead-light th {\n  color: #d8d8d8;\n  background-color: #202020;\n  border-color: #202020;\n}\n\n.dark-theme .apexcharts-xaxis-label {\n  fill: #d8d8d8;\n}\n\n.dark-theme .apexcharts-yaxis-label {\n  fill: #d8d8d8;\n}\n\n.dark-theme .apexcharts-tooltip.light {\n  border: 1px solid #292929;\n  background: #202020;\n}\n\n.dark-theme .apexcharts-tooltip.light .apexcharts-tooltip-title {\n  background: #292929;\n  border-bottom: 1px solid #292929;\n}\n\n.dark-theme .apexcharts-legend-text {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .input-group-text {\n  color: #d8d8d8;\n  background-color: #202020;\n  border: 1px solid #202020;\n}\n\n.dark-theme .custom-select {\n  color: #d8d8d8;\n  background-color: #202020;\n  border: 1px solid #202020;\n}\n\n.dark-theme .header-icon:hover {\n  background: #202020 !important;\n}\n\n.dark-theme .calendar-parent {\n  background-color: #292929;\n}\n\n.dark-theme .cv-day,\n.dark-theme .cv-event,\n.dark-theme .cv-header-day,\n.dark-theme .cv-header-days,\n.dark-theme .cv-week,\n.dark-theme .cv-weeks {\n  border-style: solid;\n  border-color: #202020;\n}\n\n.dark-theme .theme-default .cv-day.outsideOfMonth,\n.dark-theme .theme-default .cv-day.past {\n  background-color: #292929;\n}\n\n.dark-theme .theme-default .cv-day.today {\n  background-color: #202020;\n}\n\n.dark-theme .theme-default .cv-header,\n.dark-theme .theme-default .cv-header-day {\n  background-color: #202020;\n}\n\n.dark-theme .cv-header,\n.dark-theme .cv-header button {\n  border-style: solid;\n  border-color: #292929;\n  background: #202020;\n}\n\n.dark-theme .vgt-global-search.vgt-clearfix {\n  background: #292929;\n}\n\n.dark-theme table.tableOne tbody tr th.line-numbers {\n  background: #292929;\n}\n\n.dark-theme div.vgt-wrap__footer.vgt-clearfix {\n  background: #292929;\n}\n\n.dark-theme table.vgt-table td {\n  border-bottom: 1px solid #202020;\n  color: #d8d8d8;\n}\n\n.dark-theme table.tableOne tbody tr th.vgt-checkbox-col {\n  background: #292929;\n}\n\n.dark-theme th.line-numbers {\n  border-bottom: 1px solid #292929;\n}\n\n.dark-theme th.vgt-checkbox-col {\n  border-bottom: 1px solid #292929;\n}\n\n.dark-theme .ul-widget__item {\n  border-bottom: 0.07rem dashed #202020;\n}\n\n.dark-theme .order-table.vgt-table tbody tr:hover {\n  background: #202020;\n  border-radius: 10px;\n}\n\n.dark-theme .page-item.disabled .page-link {\n  background-color: #292929;\n  border-color: #292929;\n}\n\n.dark-theme ul.gull-pagination li .page-link {\n  border-color: #292929 !important;\n}\n\n.dark-theme ul.gull-pagination li .page-link:hover {\n  background: #292929;\n}\n\n.dark-theme .layout-sidebar-compact .sidebar-left {\n  background: #202020;\n}\n\n.dark-theme .layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a.open {\n  color: #8b5cf6;\n  background: #202020;\n}\n\n.dark-theme .layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a.open .nav-icon {\n  color: #8b5cf6;\n}\n\n.dark-theme .layout-sidebar-compact .sidebar-left-secondary .childNav li.nav-item a .nav-icon {\n  color: #d8d8d8;\n}\n\n.dark-theme .chat-sidebar-container {\n  height: calc(100vh - 140px);\n  min-height: unset;\n}\n\n.dark-theme .chat-sidebar-container .chat-topbar {\n  height: 52px;\n}\n\n.dark-theme .chat-sidebar-container .chat-content-wrap .chat-content .message {\n  background: #202020;\n}\n\n.dark-theme .chat-sidebar-container .chat-content-wrap .chat-content .message:before {\n  border-color: transparent transparent #202020 transparent;\n}\n\n.dark-theme .chat-sidebar-container .chat-sidebar-wrap .contacts-scrollable .contact {\n  position: relative;\n  cursor: pointer;\n  transition: 0.15s all ease-in;\n}\n\n.dark-theme .chat-sidebar-container .chat-sidebar-wrap .contacts-scrollable .contact:hover {\n  background: #202020;\n}\n\n.dark-theme .chat-sidebar-container .chat-sidebar-wrap .contacts-scrollable .contact:before {\n  background: #292929;\n  border-radius: 50%;\n}\n\n.dark-theme .chat-sidebar-container .chat-sidebar-wrap .contacts-scrollable .contact.online:before {\n  background: #10b981;\n}\n\n.dark-theme .layout-sidebar-vertical .sidebar-panel {\n  box-shadow: 0 1px 15px #202020, 0 1px 6px #202020;\n  background: #292929;\n}\n\n.dark-theme .layout-sidebar-vertical .main-content-wrap .main-header {\n  background: #292929 !important;\n}\n\n.dark-theme .layout-sidebar-vertical-two .sidebar-panel {\n  box-shadow: 0 1px 15px #202020, 0 1px 6px #202020;\n  background: #292929;\n}\n\n.dark-theme .layout-sidebar-vertical-two .main-content-wrap .main-header {\n  background: #292929 !important;\n}\n\n.dark-theme .layout-horizontal-bar .header-topnav {\n  background: #292929;\n  box-shadow: 0 1px 15px transparent, 0 1px 6px transparent;\n}\n\n.dark-theme .layout-horizontal-bar .header-topnav .topnav a {\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .layout-horizontal-bar .header-topnav .topnav ul ul {\n  background: #292929;\n  color: #d8d8d8;\n}\n\n.dark-theme .layout-horizontal-bar .header-topnav .topnav ul li ul li:hover {\n  background: #202020;\n}\n\n.dark-theme .main-header .show .header-icon {\n  background: #202020;\n}\n\n.dark-theme .main-header .notification-dropdown {\n  color: #d8d8d8;\n}\n\n.dark-theme .main-header .notification-dropdown .dropdown-item {\n  border-bottom: 1px solid #292929;\n  color: #d8d8d8;\n}\n\n.dark-theme .main-header .notification-dropdown .notification-icon {\n  background: #292929 !important;\n}\n\n.dark-theme .dropdown-item:focus,\n.dark-theme .dropdown-item:hover {\n  color: #d8d8d8;\n  text-decoration: none;\n  background-color: #292929;\n}\n\n.dark-theme .subheader {\n  background-color: #292929;\n  position: fixed;\n  top: 80px;\n  z-index: 50;\n  width: 100%;\n}\n\n.dark-theme .subheader .subheader-navbar {\n  background-color: #292929;\n}\n\n@media (max-width: 577px) {\n  .dark-theme .subheader {\n    top: 70px;\n  }\n}\n\n.dark-theme .vnb {\n  background-color: #292929;\n}\n\n.dark-theme .vnb .tippy-box {\n  box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15) !important;\n  background-color: #292929 !important;\n}\n\n.dark-theme .vnb__menu-options__option__link {\n  color: #d8d8d8;\n}\n\n.dark-theme .vnb__menu-options__option__link .vnb__menu-options__option__arrow {\n  fill: #d8d8d8;\n}\n\n.dark-theme .vnb__menu-options__option__link:focus {\n  outline: none;\n  border: 1px solid none;\n}\n\n.dark-theme .vnb__menu-options__option__link:hover {\n  color: #d8d8d8;\n}\n\n.dark-theme .vnb__menu-options__option__link:hover .vnb__menu-options__option__arrow {\n  fill: #d8d8d8;\n}\n\n.dark-theme .vnb__menu-options__option__link__icon svg {\n  fill: #8b5cf6 !important;\n}\n\n.dark-theme .vnb__sub-menu-options {\n  background-color: #292929;\n}\n\n.dark-theme .vnb__sub-menu-options__option__link {\n  border-left: 2px solid #8B5CF6;\n  color: #d8d8d8;\n}\n\n.dark-theme .vnb__sub-menu-options__option__link:focus {\n  outline: none;\n  border: 1px solid none;\n}\n\n.dark-theme .vnb__sub-menu-options__option__link:hover {\n  background-color: #8B5CF6;\n  color: #d8d8d8 !important;\n}\n\n.dark-theme .vnb__popup {\n  height: 80vh !important;\n  overflow-x: hidden !important;\n  overflow-y: scroll !important;\n}\n\n.dark-theme .vnb__popup .vnb__popup__top__close-button {\n  top: 20px;\n  right: -33px;\n}\n\n.dark-theme .vnb__popup .vnb__popup__top__close-button:focus {\n  border: 1px solid none;\n  outline: none;\n}\n\n.dark-theme .vnb__popup .vnb__popup__top__close-button svg {\n  fill: #000 !important;\n}\n",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js!./node_modules/vue-good-table/dist/vue-good-table.css":
/*!***************************************************************************************!*\
  !*** ./node_modules/css-loader!./node_modules/vue-good-table/dist/vue-good-table.css ***!
  \***************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesVueGoodTableDistVueGoodTableCss(module,exports,__webpack_require__){

exports=module.exports=__webpack_require__(/*! ../../css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,"\n\n\n\n\n.vgt-table.striped tbody tr:nth-of-type(odd){background-color:rgba(51,68,109,.03)}.vgt-right-align{text-align:right}.vgt-left-align{text-align:left}.vgt-center-align{text-align:center}.vgt-pull-left{float:left!important}.vgt-pull-right{float:right!important}.vgt-clearfix::after{display:block;content:\"\";clear:both}.vgt-responsive{width:100%;overflow-x:auto;position:relative}.vgt-text-disabled{color:#909399}.sr-only{clip:rect(0 0 0 0);clip-path:inset(50%);height:1px;overflow:hidden;position:absolute;white-space:nowrap;width:1px}.vgt-wrap{position:relative}.vgt-fixed-header{position:absolute;z-index:10;overflow-x:auto}table.vgt-table{font-size:16px;border-collapse:collapse;background-color:#fff;width:100%;max-width:100%;table-layout:auto;border:1px solid #dcdfe6}table.vgt-table td{padding:.75em .75em .75em .75em;vertical-align:top;border-bottom:1px solid #dcdfe6;color:#606266}table.vgt-table tr.clickable{cursor:pointer}table.vgt-table tr.clickable:hover{background-color:#f1f5fd}.vgt-table th{padding:.75em 1.5em .75em .75em;vertical-align:middle;position:relative}.vgt-table th.sortable button{-webkit-appearance:none;-moz-appearance:none;appearance:none;background:0 0;border:none;position:absolute;top:0;left:0;width:100%;height:100%}.vgt-table th.sortable button:focus{outline:0}.vgt-table th.sortable button:after{content:\"\";position:absolute;height:0;width:0;right:6px;top:50%;margin-top:-7px;border-left:5px solid transparent;border-right:5px solid transparent;border-bottom:5px solid #606266}.vgt-table th.sortable button:before{content:\"\";position:absolute;height:0;width:0;right:6px;top:50%;margin-bottom:-7px;border-left:5px solid transparent;border-right:5px solid transparent;border-top:5px solid #606266}.vgt-table th.line-numbers,.vgt-table th.vgt-checkbox-col{padding:0 .75em 0 .75em;color:#606266;border-right:1px solid #dcdfe6;word-wrap:break-word;width:25px;text-align:center;background:linear-gradient(#f4f5f8,#f1f3f6)}.vgt-table th.filter-th{padding:.75em .75em .75em .75em}.vgt-table th.vgt-row-header{border-bottom:2px solid #dcdfe6;border-top:2px solid #dcdfe6;background-color:#fafafb}.vgt-table th.vgt-row-header .triangle{width:24px;height:24px;border-radius:15%;position:relative;margin:0 8px}.vgt-table th.vgt-row-header .triangle:after{content:\"\";position:absolute;display:block;left:50%;top:50%;margin-top:-6px;border-top:6px solid transparent;border-bottom:6px solid transparent;border-left:6px solid #606266;margin-left:-3px;transition:.3s ease transform}.vgt-table th.vgt-row-header .triangle.expand:after{transform:rotate(90deg)}.vgt-table thead th{color:#606266;vertical-align:bottom;border-bottom:1px solid #dcdfe6;padding-right:1.5em;background:linear-gradient(#f4f5f8,#f1f3f6)}.vgt-table thead th.vgt-checkbox-col{vertical-align:middle}.vgt-table thead th.sorting-asc button:after{border-bottom:5px solid #409eff}.vgt-table thead th.sorting-desc button:before{border-top:5px solid #409eff}.vgt-input,.vgt-select{width:100%;height:32px;line-height:1;display:block;font-size:14px;font-weight:400;padding:6px 12px;color:#606266;border-radius:4px;box-sizing:border-box;background-image:none;background-color:#fff;border:1px solid #dcdfe6;transition:border-color .2s cubic-bezier(.645,.045,.355,1)}.vgt-input::placeholder,.vgt-select::placeholder{color:#606266;opacity:.3}.vgt-input:focus,.vgt-select:focus{outline:0;border-color:#409eff}.vgt-loading{position:absolute;width:100%;z-index:10;margin-top:117px}.vgt-loading__content{background-color:#c0dfff;color:#409eff;padding:7px 30px;border-radius:3px}.vgt-inner-wrap.is-loading{opacity:.5;pointer-events:none}.vgt-table.bordered td,.vgt-table.bordered th{border:1px solid #dcdfe6}.vgt-table.bordered th.vgt-row-header{border-bottom:3px solid #dcdfe6}.vgt-wrap.rtl{direction:rtl}.vgt-wrap.rtl .vgt-table thead th,.vgt-wrap.rtl .vgt-table.condensed thead th{padding-left:1.5em;padding-right:.75em}.vgt-wrap.rtl .vgt-table th.sorting-asc:after,.vgt-wrap.rtl .vgt-table th.sorting:after{margin-right:5px;margin-left:0}.vgt-wrap.rtl .vgt-table th.sortable:after,.vgt-wrap.rtl .vgt-table th.sortable:before{right:inherit;left:6px}.vgt-table.condensed td,.vgt-table.condensed th.vgt-row-header{padding:.4em .4em .4em .4em}@media (max-width:576px){.vgt-compact *{box-sizing:border-box}.vgt-compact tbody,.vgt-compact td,.vgt-compact tr{display:block;width:100%}.vgt-compact thead{display:none}.vgt-compact tr{margin-bottom:15px}.vgt-compact td{text-align:right;position:relative}.vgt-compact td:before{content:attr(data-label);position:relative;float:left;left:0;width:40%;padding-left:10px;font-weight:700;text-align:left}.vgt-compact th.line-numbers{width:100%!important;display:block;padding:.3em 1em!important}}.vgt-global-search{padding:5px 0;display:flex;flex-wrap:nowrap;align-items:stretch;border:1px solid #dcdfe6;border-bottom:0;background:linear-gradient(#f4f5f8,#f1f3f6)}.vgt-global-search form{display:flex}.vgt-global-search form label{margin-top:3px}.vgt-global-search__input{position:relative;padding-left:40px;flex-grow:1}.vgt-global-search__input .input__icon{position:absolute;left:0;max-width:32px}.vgt-global-search__input .input__icon .magnifying-glass{margin-top:3px;margin-left:8px;display:block;width:16px;height:16px;border:2px solid #494949;position:relative;border-radius:50%}.vgt-global-search__input .input__icon .magnifying-glass:before{content:\"\";display:block;position:absolute;right:-7px;bottom:-5px;background:#494949;width:8px;height:4px;border-radius:2px;transform:rotate(45deg);-webkit-transform:rotate(45deg);-moz-transform:rotate(45deg);-ms-transform:rotate(45deg);-o-transform:rotate(45deg)}.vgt-global-search__actions{margin-left:10px}.vgt-selection-info-row{background:#fdf9e8;padding:5px 16px;font-size:13px;border-top:1px solid #dcdfe6;border-left:1px solid #dcdfe6;border-right:1px solid #dcdfe6;color:#d3aa3b;font-weight:700}.vgt-selection-info-row a{font-weight:700;display:inline-block;margin-left:10px}.vgt-wrap__actions-footer{border:1px solid #dcdfe6}.vgt-wrap__footer{color:#606266;font-size:1.1rem;padding:1em;border:1px solid #dcdfe6;background:linear-gradient(#f4f5f8,#f1f3f6)}.vgt-wrap__footer .footer__row-count{position:relative;padding-right:3px}.vgt-wrap__footer .footer__row-count__label,.vgt-wrap__footer .footer__row-count__select{display:inline-block;vertical-align:middle}.vgt-wrap__footer .footer__row-count__label{font-size:1.1rem}.vgt-wrap__footer .footer__row-count__select{font-size:1.1rem;background-color:transparent;width:auto;padding:0;border:0;border-radius:0;height:auto;margin-left:8px;color:#606266;font-weight:700;-webkit-appearance:none;-moz-appearance:none;appearance:none;padding-right:15px;padding-left:5px}.vgt-wrap__footer .footer__row-count__select::-ms-expand{display:none}.vgt-wrap__footer .footer__row-count__select:focus{outline:0;border-color:#409eff}.vgt-wrap__footer .footer__row-count::after{content:\"\";display:block;position:absolute;height:0;width:0;right:6px;top:50%;margin-top:-1px;border-top:6px solid #606266;border-left:6px solid transparent;border-right:6px solid transparent;border-bottom:none;pointer-events:none}.vgt-wrap__footer .footer__navigation{font-size:1.1rem}.vgt-wrap__footer .footer__navigation>button:first-of-type{margin-right:16px}.vgt-wrap__footer .footer__navigation__info,.vgt-wrap__footer .footer__navigation__page-btn,.vgt-wrap__footer .footer__navigation__page-info{display:inline-block;vertical-align:middle;color:#909399}.vgt-wrap__footer .footer__navigation__page-btn{-webkit-appearance:none;-moz-appearance:none;appearance:none;background:0 0;border:none;text-decoration:none;color:#606266;font-weight:700;white-space:nowrap;vertical-align:middle}.vgt-wrap__footer .footer__navigation__page-btn:hover{cursor:pointer}.vgt-wrap__footer .footer__navigation__page-btn.disabled,.vgt-wrap__footer .footer__navigation__page-btn.disabled:hover{opacity:.5;cursor:not-allowed}.vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.left:after,.vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.left:after{border-right-color:#606266}.vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.right:after,.vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.right:after{border-left-color:#606266}.vgt-wrap__footer .footer__navigation__page-btn span{display:inline-block;vertical-align:middle;font-size:1.1rem}.vgt-wrap__footer .footer__navigation__page-btn .chevron{width:24px;height:24px;border-radius:15%;position:relative;margin:0;display:inline-block;vertical-align:middle}.vgt-wrap__footer .footer__navigation__page-btn .chevron:after{content:\"\";position:absolute;display:block;left:50%;top:50%;margin-top:-6px;border-top:6px solid transparent;border-bottom:6px solid transparent}.vgt-wrap__footer .footer__navigation__page-btn .chevron.left::after{border-right:6px solid #409eff;margin-left:-3px}.vgt-wrap__footer .footer__navigation__page-btn .chevron.right::after{border-left:6px solid #409eff;margin-left:-3px}.vgt-wrap__footer .footer__navigation__info,.vgt-wrap__footer .footer__navigation__page-info{display:inline-block;margin:0 16px}.vgt-wrap__footer .footer__navigation__page-info span{display:inline-block;vertical-align:middle}.vgt-wrap__footer .footer__navigation__page-info__current-entry{width:30px;text-align:center;vertical-align:middle;display:inline-block;margin:0 10px;font-weight:700}@media only screen and (max-width:750px){.vgt-wrap__footer .footer__navigation__info{display:none}.vgt-wrap__footer .footer__navigation__page-btn{margin-left:16px}}.vgt-table.nocturnal{border:1px solid #435169;background-color:#324057}.vgt-table.nocturnal tr.clickable:hover{background-color:#445168}.vgt-table.nocturnal td{border-bottom:1px solid #435169;color:#c7ced8}.vgt-table.nocturnal th.line-numbers,.vgt-table.nocturnal th.vgt-checkbox-col{color:#c7ced8;border-right:1px solid #435169;background:linear-gradient(#2c394f,#2c394f)}.vgt-table.nocturnal thead th{color:#c7ced8;border-bottom:1px solid #435169;background:linear-gradient(#2c394f,#2c394f)}.vgt-table.nocturnal thead th.sortable:before{border-top-color:#3e5170}.vgt-table.nocturnal thead th.sortable:after{border-bottom-color:#3e5170}.vgt-table.nocturnal thead th.sortable.sorting-asc{color:#fff}.vgt-table.nocturnal thead th.sortable.sorting-asc:after{border-bottom-color:#409eff}.vgt-table.nocturnal thead th.sortable.sorting-desc{color:#fff}.vgt-table.nocturnal thead th.sortable.sorting-desc:before{border-top-color:#409eff}.vgt-table.nocturnal.bordered td,.vgt-table.nocturnal.bordered th{border:1px solid #435169}.vgt-table.nocturnal .vgt-input,.vgt-table.nocturnal .vgt-select{color:#c7ced8;background-color:#232d3f;border:1px solid #435169}.vgt-table.nocturnal .vgt-input::placeholder,.vgt-table.nocturnal .vgt-select::placeholder{color:#c7ced8;opacity:.3}.vgt-wrap.nocturnal .vgt-wrap__footer{color:#c7ced8;border:1px solid #435169;background:linear-gradient(#2c394f,#2c394f)}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__row-count{position:relative}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__row-count__label{color:#8290a7}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__row-count__select{color:#c7ced8;background:#232d3f;border:none;-webkit-appearance:none;-moz-appearance:none;appearance:none;padding-right:15px;padding-left:10px;border-radius:3px;text-align:center}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__row-count__select:focus{border-color:#409eff}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__row-count::after{content:\"\";display:block;position:absolute;height:0;width:0;right:6px;top:50%;margin-top:-1px;border-top:6px solid #c7ced8;border-left:6px solid transparent;border-right:6px solid transparent;border-bottom:none;pointer-events:none}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__navigation__page-btn{color:#c7ced8}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.left:after,.vgt-wrap.nocturnal .vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.left:after{border-right-color:#c7ced8}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.right:after,.vgt-wrap.nocturnal .vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.right:after{border-left-color:#c7ced8}.vgt-wrap.nocturnal .vgt-wrap__footer .footer__navigation__info,.vgt-wrap.nocturnal .vgt-wrap__footer .footer__navigation__page-info{color:#8290a7}.vgt-wrap.nocturnal .vgt-global-search{border:1px solid #435169;background:linear-gradient(#2c394f,#2c394f)}.vgt-wrap.nocturnal .vgt-global-search__input .input__icon .magnifying-glass{border:2px solid #3f4c63}.vgt-wrap.nocturnal .vgt-global-search__input .input__icon .magnifying-glass:before{background:#3f4c63}.vgt-wrap.nocturnal .vgt-global-search__input .vgt-input,.vgt-wrap.nocturnal .vgt-global-search__input .vgt-select{color:#c7ced8;background-color:#232d3f;border:1px solid #435169}.vgt-wrap.nocturnal .vgt-global-search__input .vgt-input::placeholder,.vgt-wrap.nocturnal .vgt-global-search__input .vgt-select::placeholder{color:#c7ced8;opacity:.3}.vgt-table.black-rhino{border:1px solid #435169;background-color:#dfe5ee}.vgt-table.black-rhino tr.clickable:hover{background-color:#fff}.vgt-table.black-rhino td{border-bottom:1px solid #bbc5d6;color:#49515e}.vgt-table.black-rhino th.line-numbers,.vgt-table.black-rhino th.vgt-checkbox-col{color:#dae2f0;border-right:1px solid #435169;background:linear-gradient(#4c5c79,#4e5d7c)}.vgt-table.black-rhino thead th{color:#dae2f0;text-shadow:1px 1px #3e5170;border-bottom:1px solid #435169;background:linear-gradient(#4c5c79,#4e5d7c)}.vgt-table.black-rhino thead th.sortable:before{border-top-color:#607498}.vgt-table.black-rhino thead th.sortable:after{border-bottom-color:#607498}.vgt-table.black-rhino thead th.sortable.sorting-asc{color:#fff}.vgt-table.black-rhino thead th.sortable.sorting-asc:after{border-bottom-color:#409eff}.vgt-table.black-rhino thead th.sortable.sorting-desc:before{border-top-color:#409eff}.vgt-table.black-rhino.bordered td{border:1px solid #bbc5d6}.vgt-table.black-rhino.bordered th{border:1px solid #435169}.vgt-table.black-rhino .vgt-input,.vgt-table.black-rhino .vgt-select{color:#dae2f0;background-color:#34445f;border:1px solid transparent}.vgt-table.black-rhino .vgt-input::placeholder,.vgt-table.black-rhino .vgt-select::placeholder{color:#dae2f0;opacity:.3}.vgt-wrap.black-rhino .vgt-wrap__footer{color:#dae2f0;border:1px solid #435169;background:linear-gradient(#4c5c79,#4e5d7c)}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__row-count{position:relative;padding-right:3px}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__row-count__label{color:#98a5b9}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__row-count__select{color:#49515e;background:#34445f;border:none;-webkit-appearance:none;-moz-appearance:none;appearance:none;padding-right:15px;padding-left:5px;border-radius:3px}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__row-count__select::-ms-expand{display:none}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__row-count__select:focus{border-color:#409eff}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__row-count::after{content:\"\";display:block;position:absolute;height:0;width:0;right:6px;top:50%;margin-top:-1px;border-top:6px solid #49515e;border-left:6px solid transparent;border-right:6px solid transparent;border-bottom:none;pointer-events:none}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__navigation__page-btn{color:#dae2f0}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.left:after,.vgt-wrap.black-rhino .vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.left:after{border-right-color:#dae2f0}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.right:after,.vgt-wrap.black-rhino .vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.right:after{border-left-color:#dae2f0}.vgt-wrap.black-rhino .vgt-wrap__footer .footer__navigation__info,.vgt-wrap.black-rhino .vgt-wrap__footer .footer__navigation__page-info{color:#dae2f0}.vgt-wrap.black-rhino .vgt-global-search{border:1px solid #435169;background:linear-gradient(#4c5c79,#4e5d7c)}.vgt-wrap.black-rhino .vgt-global-search__input .input__icon .magnifying-glass{border:2px solid #3f4c63}.vgt-wrap.black-rhino .vgt-global-search__input .input__icon .magnifying-glass:before{background:#3f4c63}.vgt-wrap.black-rhino .vgt-global-search__input .vgt-input,.vgt-wrap.black-rhino .vgt-global-search__input .vgt-select{color:#dae2f0;background-color:#44516c;border:1px solid transparent}.vgt-wrap.black-rhino .vgt-global-search__input .vgt-input::placeholder,.vgt-wrap.black-rhino .vgt-global-search__input .vgt-select::placeholder{color:#dae2f0;opacity:.3}.vgt-inner-wrap{border-radius:.25rem;box-shadow:0 1px 3px 0 rgba(50,50,93,.1),0 1px 2px 0 rgba(50,50,93,.06)}.vgt-table.polar-bear{border-spacing:0;border-collapse:separate;font-size:1rem;background-color:#fff;border:1px solid #e3e8ee;border-bottom:none;border-radius:.25rem}.vgt-table.polar-bear td{padding:1em .75em 1em .75em;border-bottom:1px solid #e4ebf3;color:#525f7f}.vgt-table.polar-bear td.vgt-right-align{text-align:right}.vgt-table.polar-bear th.line-numbers,.vgt-table.polar-bear th.vgt-checkbox-col{color:#394567;border-right:1px solid #e3e8ee;background:#f7fafc}.vgt-table.polar-bear thead th{color:#667b94;font-weight:600;border-bottom:1px solid #e3e8ee;background:#f7fafc}.vgt-table.polar-bear thead th.sorting-asc,.vgt-table.polar-bear thead th.sorting-desc{color:#5e72e4}.vgt-table.polar-bear thead th.sorting-desc:before{border-top:5px solid #7485e8}.vgt-table.polar-bear thead th.sorting-asc:after{border-bottom:5px solid #7485e8}.vgt-table.polar-bear thead th .vgt-input,.vgt-table.polar-bear thead th .vgt-select{height:2.75em;box-shadow:0 1px 2px 0 rgba(0,0,0,.05);border:1px solid #e4ebf3}.vgt-table.polar-bear thead th .vgt-input:focus,.vgt-table.polar-bear thead th .vgt-select:focus{outline:0;border-color:#cae0fe}.vgt-table.polar-bear thead tr:first-child th:first-child{border-top-left-radius:.25rem}.vgt-table.polar-bear thead tr:first-child th:last-child{border-top-right-radius:.25rem}.vgt-table.polar-bear.bordered td{border:1px solid #e3e8ee;background:#fff}.vgt-table.polar-bear.bordered th{border:1px solid #e3e8ee}.vgt-wrap.polar-bear .vgt-wrap__footer{color:#394567;border:1px solid #e3e8ee;border-bottom:0;border-top:0;background:linear-gradient(#f7fafc,#f7fafc)}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__row-count{position:relative;padding-right:3px}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__row-count__label{color:#98a5b9}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__row-count__select{text-align:center;color:#525f7f;background:#fff;border:none;-webkit-appearance:none;-moz-appearance:none;appearance:none;padding:5px;padding-right:30px;border-radius:3px;box-shadow:0 1px 2px 0 rgba(0,0,0,.05);border:1px solid #e4ebf3}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__row-count__select::-ms-expand{display:none}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__row-count__select:focus{border-color:#5e72e4}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__row-count::after{content:\"\";display:block;position:absolute;height:0;width:0;right:15px;top:50%;margin-top:-3px;border-top:6px solid #525f7f;border-left:6px solid transparent;border-right:6px solid transparent;border-bottom:none;pointer-events:none}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__navigation__page-btn{color:#394567}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.left:after,.vgt-wrap.polar-bear .vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.left:after{border-right-color:#394567}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__navigation__page-btn.disabled .chevron.right:after,.vgt-wrap.polar-bear .vgt-wrap__footer .footer__navigation__page-btn.disabled:hover .chevron.right:after{border-left-color:#394567}.vgt-wrap.polar-bear .vgt-wrap__footer .footer__navigation__info,.vgt-wrap.polar-bear .vgt-wrap__footer .footer__navigation__page-info{color:#394567}.vgt-wrap.polar-bear .vgt-global-search{border:1px solid #e3e8ee;border-bottom:0;border-top-left-radius:3px;border-top-right-radius:3px;background:#f7fafc}.vgt-wrap.polar-bear .vgt-global-search__input .input__icon .magnifying-glass{border:2px solid #dde3ea}.vgt-wrap.polar-bear .vgt-global-search__input .input__icon .magnifying-glass:before{background:#dde3ea}.vgt-wrap.polar-bear .vgt-global-search__input .vgt-input,.vgt-wrap.polar-bear .vgt-global-search__input .vgt-select{height:2.75em;box-shadow:0 1px 2px 0 rgba(0,0,0,.05);border:1px solid #e4ebf3}.vgt-wrap.polar-bear .vgt-global-search__input .vgt-input::placeholder,.vgt-wrap.polar-bear .vgt-global-search__input .vgt-select::placeholder{color:#394567;opacity:.3}",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js!./resources/src/assets/fonts/iconsmind/iconsmind.css":
/*!**************************************************************************************!*\
  !*** ./node_modules/css-loader!./resources/src/assets/fonts/iconsmind/iconsmind.css ***!
  \**************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsResourcesSrcAssetsFontsIconsmindIconsmindCss(module,exports,__webpack_require__){

var escape=__webpack_require__(/*! ../../../../../node_modules/css-loader/lib/url/escape.js */"./node_modules/css-loader/lib/url/escape.js");
exports=module.exports=__webpack_require__(/*! ../../../../../node_modules/css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,"@font-face {\n\tfont-family: 'icomoon';\n\tsrc:url("+escape(__webpack_require__(/*! ./icomoon.eot?-rdmvgc */"./resources/src/assets/fonts/iconsmind/icomoon.eot?-rdmvgc"))+");\n\tsrc:url("+escape(__webpack_require__(/*! ./icomoon.eot */"./resources/src/assets/fonts/iconsmind/icomoon.eot"))+"?#iefix-rdmvgc) format('embedded-opentype'),\n\t\turl("+escape(__webpack_require__(/*! ./icomoon.woff?-rdmvgc */"./resources/src/assets/fonts/iconsmind/icomoon.woff?-rdmvgc"))+") format('woff'),\n\t\turl("+escape(__webpack_require__(/*! ./icomoon.ttf?-rdmvgc */"./resources/src/assets/fonts/iconsmind/icomoon.ttf?-rdmvgc"))+") format('truetype')\n\t\t;\n\tfont-weight: normal;\n\tfont-style: normal;\n}\n\n[class^=\"i-\"], [class*=\" i-\"] {\n\tfont-family: 'icomoon' !important;\n\tspeak: none;\n\tfont-style: normal;\n\tfont-weight: normal;\n\tfont-variant: normal;\n\ttext-transform: none;\n\tline-height: 1;\n\n\t/* Better Font Rendering =========== */\n\t-webkit-font-smoothing: antialiased;\n\t-moz-osx-font-smoothing: grayscale;\n}\n\n.i-A-Z:before {\n\tcontent: \"\\E600\";\n}\n.i-Aa:before {\n\tcontent: \"\\E601\";\n}\n.i-Add-Bag:before {\n\tcontent: \"\\E602\";\n}\n.i-Add-Basket:before {\n\tcontent: \"\\E603\";\n}\n.i-Add-Cart:before {\n\tcontent: \"\\E604\";\n}\n.i-Add-File:before {\n\tcontent: \"\\E605\";\n}\n.i-Add-SpaceAfterParagraph:before {\n\tcontent: \"\\E606\";\n}\n.i-Add-SpaceBeforeParagraph:before {\n\tcontent: \"\\E607\";\n}\n.i-Add-User:before {\n\tcontent: \"\\E608\";\n}\n.i-Add-UserStar:before {\n\tcontent: \"\\E609\";\n}\n.i-Add-Window:before {\n\tcontent: \"\\E60A\";\n}\n.i-Add:before {\n\tcontent: \"\\E60B\";\n}\n.i-Address-Book:before {\n\tcontent: \"\\E60C\";\n}\n.i-Address-Book2:before {\n\tcontent: \"\\E60D\";\n}\n.i-Administrator:before {\n\tcontent: \"\\E60E\";\n}\n.i-Aerobics-2:before {\n\tcontent: \"\\E60F\";\n}\n.i-Aerobics-3:before {\n\tcontent: \"\\E610\";\n}\n.i-Aerobics:before {\n\tcontent: \"\\E611\";\n}\n.i-Affiliate:before {\n\tcontent: \"\\E612\";\n}\n.i-Aim:before {\n\tcontent: \"\\E613\";\n}\n.i-Air-Balloon:before {\n\tcontent: \"\\E614\";\n}\n.i-Airbrush:before {\n\tcontent: \"\\E615\";\n}\n.i-Airship:before {\n\tcontent: \"\\E616\";\n}\n.i-Alarm-Clock:before {\n\tcontent: \"\\E617\";\n}\n.i-Alarm-Clock2:before {\n\tcontent: \"\\E618\";\n}\n.i-Alarm:before {\n\tcontent: \"\\E619\";\n}\n.i-Alien-2:before {\n\tcontent: \"\\E61A\";\n}\n.i-Alien:before {\n\tcontent: \"\\E61B\";\n}\n.i-Aligator:before {\n\tcontent: \"\\E61C\";\n}\n.i-Align-Center:before {\n\tcontent: \"\\E61D\";\n}\n.i-Align-JustifyAll:before {\n\tcontent: \"\\E61E\";\n}\n.i-Align-JustifyCenter:before {\n\tcontent: \"\\E61F\";\n}\n.i-Align-JustifyLeft:before {\n\tcontent: \"\\E620\";\n}\n.i-Align-JustifyRight:before {\n\tcontent: \"\\E621\";\n}\n.i-Align-Left:before {\n\tcontent: \"\\E622\";\n}\n.i-Align-Right:before {\n\tcontent: \"\\E623\";\n}\n.i-Alpha:before {\n\tcontent: \"\\E624\";\n}\n.i-Ambulance:before {\n\tcontent: \"\\E625\";\n}\n.i-AMX:before {\n\tcontent: \"\\E626\";\n}\n.i-Anchor-2:before {\n\tcontent: \"\\E627\";\n}\n.i-Anchor:before {\n\tcontent: \"\\E628\";\n}\n.i-Android-Store:before {\n\tcontent: \"\\E629\";\n}\n.i-Android:before {\n\tcontent: \"\\E62A\";\n}\n.i-Angel-Smiley:before {\n\tcontent: \"\\E62B\";\n}\n.i-Angel:before {\n\tcontent: \"\\E62C\";\n}\n.i-Angry:before {\n\tcontent: \"\\E62D\";\n}\n.i-Apple-Bite:before {\n\tcontent: \"\\E62E\";\n}\n.i-Apple-Store:before {\n\tcontent: \"\\E62F\";\n}\n.i-Apple:before {\n\tcontent: \"\\E630\";\n}\n.i-Approved-Window:before {\n\tcontent: \"\\E631\";\n}\n.i-Aquarius-2:before {\n\tcontent: \"\\E632\";\n}\n.i-Aquarius:before {\n\tcontent: \"\\E633\";\n}\n.i-Archery-2:before {\n\tcontent: \"\\E634\";\n}\n.i-Archery:before {\n\tcontent: \"\\E635\";\n}\n.i-Argentina:before {\n\tcontent: \"\\E636\";\n}\n.i-Aries-2:before {\n\tcontent: \"\\E637\";\n}\n.i-Aries:before {\n\tcontent: \"\\E638\";\n}\n.i-Army-Key:before {\n\tcontent: \"\\E639\";\n}\n.i-Arrow-Around:before {\n\tcontent: \"\\E63A\";\n}\n.i-Arrow-Back3:before {\n\tcontent: \"\\E63B\";\n}\n.i-Arrow-Back:before {\n\tcontent: \"\\E63C\";\n}\n.i-Arrow-Back2:before {\n\tcontent: \"\\E63D\";\n}\n.i-Arrow-Barrier:before {\n\tcontent: \"\\E63E\";\n}\n.i-Arrow-Circle:before {\n\tcontent: \"\\E63F\";\n}\n.i-Arrow-Cross:before {\n\tcontent: \"\\E640\";\n}\n.i-Arrow-Down:before {\n\tcontent: \"\\E641\";\n}\n.i-Arrow-Down2:before {\n\tcontent: \"\\E642\";\n}\n.i-Arrow-Down3:before {\n\tcontent: \"\\E643\";\n}\n.i-Arrow-DowninCircle:before {\n\tcontent: \"\\E644\";\n}\n.i-Arrow-Fork:before {\n\tcontent: \"\\E645\";\n}\n.i-Arrow-Forward:before {\n\tcontent: \"\\E646\";\n}\n.i-Arrow-Forward2:before {\n\tcontent: \"\\E647\";\n}\n.i-Arrow-From:before {\n\tcontent: \"\\E648\";\n}\n.i-Arrow-Inside:before {\n\tcontent: \"\\E649\";\n}\n.i-Arrow-Inside45:before {\n\tcontent: \"\\E64A\";\n}\n.i-Arrow-InsideGap:before {\n\tcontent: \"\\E64B\";\n}\n.i-Arrow-InsideGap45:before {\n\tcontent: \"\\E64C\";\n}\n.i-Arrow-Into:before {\n\tcontent: \"\\E64D\";\n}\n.i-Arrow-Join:before {\n\tcontent: \"\\E64E\";\n}\n.i-Arrow-Junction:before {\n\tcontent: \"\\E64F\";\n}\n.i-Arrow-Left:before {\n\tcontent: \"\\E650\";\n}\n.i-Arrow-Left2:before {\n\tcontent: \"\\E651\";\n}\n.i-Arrow-LeftinCircle:before {\n\tcontent: \"\\E652\";\n}\n.i-Arrow-Loop:before {\n\tcontent: \"\\E653\";\n}\n.i-Arrow-Merge:before {\n\tcontent: \"\\E654\";\n}\n.i-Arrow-Mix:before {\n\tcontent: \"\\E655\";\n}\n.i-Arrow-Next:before {\n\tcontent: \"\\E656\";\n}\n.i-Arrow-OutLeft:before {\n\tcontent: \"\\E657\";\n}\n.i-Arrow-OutRight:before {\n\tcontent: \"\\E658\";\n}\n.i-Arrow-Outside:before {\n\tcontent: \"\\E659\";\n}\n.i-Arrow-Outside45:before {\n\tcontent: \"\\E65A\";\n}\n.i-Arrow-OutsideGap:before {\n\tcontent: \"\\E65B\";\n}\n.i-Arrow-OutsideGap45:before {\n\tcontent: \"\\E65C\";\n}\n.i-Arrow-Over:before {\n\tcontent: \"\\E65D\";\n}\n.i-Arrow-Refresh:before {\n\tcontent: \"\\E65E\";\n}\n.i-Arrow-Refresh2:before {\n\tcontent: \"\\E65F\";\n}\n.i-Arrow-Right:before {\n\tcontent: \"\\E660\";\n}\n.i-Arrow-Right2:before {\n\tcontent: \"\\E661\";\n}\n.i-Arrow-RightinCircle:before {\n\tcontent: \"\\E662\";\n}\n.i-Arrow-Shuffle:before {\n\tcontent: \"\\E663\";\n}\n.i-Arrow-Squiggly:before {\n\tcontent: \"\\E664\";\n}\n.i-Arrow-Through:before {\n\tcontent: \"\\E665\";\n}\n.i-Arrow-To:before {\n\tcontent: \"\\E666\";\n}\n.i-Arrow-TurnLeft:before {\n\tcontent: \"\\E667\";\n}\n.i-Arrow-TurnRight:before {\n\tcontent: \"\\E668\";\n}\n.i-Arrow-Up:before {\n\tcontent: \"\\E669\";\n}\n.i-Arrow-Up2:before {\n\tcontent: \"\\E66A\";\n}\n.i-Arrow-Up3:before {\n\tcontent: \"\\E66B\";\n}\n.i-Arrow-UpinCircle:before {\n\tcontent: \"\\E66C\";\n}\n.i-Arrow-XLeft:before {\n\tcontent: \"\\E66D\";\n}\n.i-Arrow-XRight:before {\n\tcontent: \"\\E66E\";\n}\n.i-Ask:before {\n\tcontent: \"\\E66F\";\n}\n.i-Assistant:before {\n\tcontent: \"\\E670\";\n}\n.i-Astronaut:before {\n\tcontent: \"\\E671\";\n}\n.i-At-Sign:before {\n\tcontent: \"\\E672\";\n}\n.i-ATM:before {\n\tcontent: \"\\E673\";\n}\n.i-Atom:before {\n\tcontent: \"\\E674\";\n}\n.i-Audio:before {\n\tcontent: \"\\E675\";\n}\n.i-Auto-Flash:before {\n\tcontent: \"\\E676\";\n}\n.i-Autumn:before {\n\tcontent: \"\\E677\";\n}\n.i-Baby-Clothes:before {\n\tcontent: \"\\E678\";\n}\n.i-Baby-Clothes2:before {\n\tcontent: \"\\E679\";\n}\n.i-Baby-Cry:before {\n\tcontent: \"\\E67A\";\n}\n.i-Baby:before {\n\tcontent: \"\\E67B\";\n}\n.i-Back2:before {\n\tcontent: \"\\E67C\";\n}\n.i-Back-Media:before {\n\tcontent: \"\\E67D\";\n}\n.i-Back-Music:before {\n\tcontent: \"\\E67E\";\n}\n.i-Back:before {\n\tcontent: \"\\E67F\";\n}\n.i-Background:before {\n\tcontent: \"\\E680\";\n}\n.i-Bacteria:before {\n\tcontent: \"\\E681\";\n}\n.i-Bag-Coins:before {\n\tcontent: \"\\E682\";\n}\n.i-Bag-Items:before {\n\tcontent: \"\\E683\";\n}\n.i-Bag-Quantity:before {\n\tcontent: \"\\E684\";\n}\n.i-Bag:before {\n\tcontent: \"\\E685\";\n}\n.i-Bakelite:before {\n\tcontent: \"\\E686\";\n}\n.i-Ballet-Shoes:before {\n\tcontent: \"\\E687\";\n}\n.i-Balloon:before {\n\tcontent: \"\\E688\";\n}\n.i-Banana:before {\n\tcontent: \"\\E689\";\n}\n.i-Band-Aid:before {\n\tcontent: \"\\E68A\";\n}\n.i-Bank:before {\n\tcontent: \"\\E68B\";\n}\n.i-Bar-Chart:before {\n\tcontent: \"\\E68C\";\n}\n.i-Bar-Chart2:before {\n\tcontent: \"\\E68D\";\n}\n.i-Bar-Chart3:before {\n\tcontent: \"\\E68E\";\n}\n.i-Bar-Chart4:before {\n\tcontent: \"\\E68F\";\n}\n.i-Bar-Chart5:before {\n\tcontent: \"\\E690\";\n}\n.i-Bar-Code:before {\n\tcontent: \"\\E691\";\n}\n.i-Barricade-2:before {\n\tcontent: \"\\E692\";\n}\n.i-Barricade:before {\n\tcontent: \"\\E693\";\n}\n.i-Baseball:before {\n\tcontent: \"\\E694\";\n}\n.i-Basket-Ball:before {\n\tcontent: \"\\E695\";\n}\n.i-Basket-Coins:before {\n\tcontent: \"\\E696\";\n}\n.i-Basket-Items:before {\n\tcontent: \"\\E697\";\n}\n.i-Basket-Quantity:before {\n\tcontent: \"\\E698\";\n}\n.i-Bat-2:before {\n\tcontent: \"\\E699\";\n}\n.i-Bat:before {\n\tcontent: \"\\E69A\";\n}\n.i-Bathrobe:before {\n\tcontent: \"\\E69B\";\n}\n.i-Batman-Mask:before {\n\tcontent: \"\\E69C\";\n}\n.i-Battery-0:before {\n\tcontent: \"\\E69D\";\n}\n.i-Battery-25:before {\n\tcontent: \"\\E69E\";\n}\n.i-Battery-50:before {\n\tcontent: \"\\E69F\";\n}\n.i-Battery-75:before {\n\tcontent: \"\\E6A0\";\n}\n.i-Battery-100:before {\n\tcontent: \"\\E6A1\";\n}\n.i-Battery-Charge:before {\n\tcontent: \"\\E6A2\";\n}\n.i-Bear:before {\n\tcontent: \"\\E6A3\";\n}\n.i-Beard-2:before {\n\tcontent: \"\\E6A4\";\n}\n.i-Beard-3:before {\n\tcontent: \"\\E6A5\";\n}\n.i-Beard:before {\n\tcontent: \"\\E6A6\";\n}\n.i-Bebo:before {\n\tcontent: \"\\E6A7\";\n}\n.i-Bee:before {\n\tcontent: \"\\E6A8\";\n}\n.i-Beer-Glass:before {\n\tcontent: \"\\E6A9\";\n}\n.i-Beer:before {\n\tcontent: \"\\E6AA\";\n}\n.i-Bell-2:before {\n\tcontent: \"\\E6AB\";\n}\n.i-Bell:before {\n\tcontent: \"\\E6AC\";\n}\n.i-Belt-2:before {\n\tcontent: \"\\E6AD\";\n}\n.i-Belt-3:before {\n\tcontent: \"\\E6AE\";\n}\n.i-Belt:before {\n\tcontent: \"\\E6AF\";\n}\n.i-Berlin-Tower:before {\n\tcontent: \"\\E6B0\";\n}\n.i-Beta:before {\n\tcontent: \"\\E6B1\";\n}\n.i-Betvibes:before {\n\tcontent: \"\\E6B2\";\n}\n.i-Bicycle-2:before {\n\tcontent: \"\\E6B3\";\n}\n.i-Bicycle-3:before {\n\tcontent: \"\\E6B4\";\n}\n.i-Bicycle:before {\n\tcontent: \"\\E6B5\";\n}\n.i-Big-Bang:before {\n\tcontent: \"\\E6B6\";\n}\n.i-Big-Data:before {\n\tcontent: \"\\E6B7\";\n}\n.i-Bike-Helmet:before {\n\tcontent: \"\\E6B8\";\n}\n.i-Bikini:before {\n\tcontent: \"\\E6B9\";\n}\n.i-Bilk-Bottle2:before {\n\tcontent: \"\\E6BA\";\n}\n.i-Billing:before {\n\tcontent: \"\\E6BB\";\n}\n.i-Bing:before {\n\tcontent: \"\\E6BC\";\n}\n.i-Binocular:before {\n\tcontent: \"\\E6BD\";\n}\n.i-Bio-Hazard:before {\n\tcontent: \"\\E6BE\";\n}\n.i-Biotech:before {\n\tcontent: \"\\E6BF\";\n}\n.i-Bird-DeliveringLetter:before {\n\tcontent: \"\\E6C0\";\n}\n.i-Bird:before {\n\tcontent: \"\\E6C1\";\n}\n.i-Birthday-Cake:before {\n\tcontent: \"\\E6C2\";\n}\n.i-Bisexual:before {\n\tcontent: \"\\E6C3\";\n}\n.i-Bishop:before {\n\tcontent: \"\\E6C4\";\n}\n.i-Bitcoin:before {\n\tcontent: \"\\E6C5\";\n}\n.i-Black-Cat:before {\n\tcontent: \"\\E6C6\";\n}\n.i-Blackboard:before {\n\tcontent: \"\\E6C7\";\n}\n.i-Blinklist:before {\n\tcontent: \"\\E6C8\";\n}\n.i-Block-Cloud:before {\n\tcontent: \"\\E6C9\";\n}\n.i-Block-Window:before {\n\tcontent: \"\\E6CA\";\n}\n.i-Blogger:before {\n\tcontent: \"\\E6CB\";\n}\n.i-Blood:before {\n\tcontent: \"\\E6CC\";\n}\n.i-Blouse:before {\n\tcontent: \"\\E6CD\";\n}\n.i-Blueprint:before {\n\tcontent: \"\\E6CE\";\n}\n.i-Board:before {\n\tcontent: \"\\E6CF\";\n}\n.i-Bodybuilding:before {\n\tcontent: \"\\E6D0\";\n}\n.i-Bold-Text:before {\n\tcontent: \"\\E6D1\";\n}\n.i-Bone:before {\n\tcontent: \"\\E6D2\";\n}\n.i-Bones:before {\n\tcontent: \"\\E6D3\";\n}\n.i-Book:before {\n\tcontent: \"\\E6D4\";\n}\n.i-Bookmark:before {\n\tcontent: \"\\E6D5\";\n}\n.i-Books-2:before {\n\tcontent: \"\\E6D6\";\n}\n.i-Books:before {\n\tcontent: \"\\E6D7\";\n}\n.i-Boom:before {\n\tcontent: \"\\E6D8\";\n}\n.i-Boot-2:before {\n\tcontent: \"\\E6D9\";\n}\n.i-Boot:before {\n\tcontent: \"\\E6DA\";\n}\n.i-Bottom-ToTop:before {\n\tcontent: \"\\E6DB\";\n}\n.i-Bow-2:before {\n\tcontent: \"\\E6DC\";\n}\n.i-Bow-3:before {\n\tcontent: \"\\E6DD\";\n}\n.i-Bow-4:before {\n\tcontent: \"\\E6DE\";\n}\n.i-Bow-5:before {\n\tcontent: \"\\E6DF\";\n}\n.i-Bow-6:before {\n\tcontent: \"\\E6E0\";\n}\n.i-Bow:before {\n\tcontent: \"\\E6E1\";\n}\n.i-Bowling-2:before {\n\tcontent: \"\\E6E2\";\n}\n.i-Bowling:before {\n\tcontent: \"\\E6E3\";\n}\n.i-Box2:before {\n\tcontent: \"\\E6E4\";\n}\n.i-Box-Close:before {\n\tcontent: \"\\E6E5\";\n}\n.i-Box-Full:before {\n\tcontent: \"\\E6E6\";\n}\n.i-Box-Open:before {\n\tcontent: \"\\E6E7\";\n}\n.i-Box-withFolders:before {\n\tcontent: \"\\E6E8\";\n}\n.i-Box:before {\n\tcontent: \"\\E6E9\";\n}\n.i-Boy:before {\n\tcontent: \"\\E6EA\";\n}\n.i-Bra:before {\n\tcontent: \"\\E6EB\";\n}\n.i-Brain-2:before {\n\tcontent: \"\\E6EC\";\n}\n.i-Brain-3:before {\n\tcontent: \"\\E6ED\";\n}\n.i-Brain:before {\n\tcontent: \"\\E6EE\";\n}\n.i-Brazil:before {\n\tcontent: \"\\E6EF\";\n}\n.i-Bread-2:before {\n\tcontent: \"\\E6F0\";\n}\n.i-Bread:before {\n\tcontent: \"\\E6F1\";\n}\n.i-Bridge:before {\n\tcontent: \"\\E6F2\";\n}\n.i-Brightkite:before {\n\tcontent: \"\\E6F3\";\n}\n.i-Broke-Link2:before {\n\tcontent: \"\\E6F4\";\n}\n.i-Broken-Link:before {\n\tcontent: \"\\E6F5\";\n}\n.i-Broom:before {\n\tcontent: \"\\E6F6\";\n}\n.i-Brush:before {\n\tcontent: \"\\E6F7\";\n}\n.i-Bucket:before {\n\tcontent: \"\\E6F8\";\n}\n.i-Bug:before {\n\tcontent: \"\\E6F9\";\n}\n.i-Building:before {\n\tcontent: \"\\E6FA\";\n}\n.i-Bulleted-List:before {\n\tcontent: \"\\E6FB\";\n}\n.i-Bus-2:before {\n\tcontent: \"\\E6FC\";\n}\n.i-Bus:before {\n\tcontent: \"\\E6FD\";\n}\n.i-Business-Man:before {\n\tcontent: \"\\E6FE\";\n}\n.i-Business-ManWoman:before {\n\tcontent: \"\\E6FF\";\n}\n.i-Business-Mens:before {\n\tcontent: \"\\E700\";\n}\n.i-Business-Woman:before {\n\tcontent: \"\\E701\";\n}\n.i-Butterfly:before {\n\tcontent: \"\\E702\";\n}\n.i-Button:before {\n\tcontent: \"\\E703\";\n}\n.i-Cable-Car:before {\n\tcontent: \"\\E704\";\n}\n.i-Cake:before {\n\tcontent: \"\\E705\";\n}\n.i-Calculator-2:before {\n\tcontent: \"\\E706\";\n}\n.i-Calculator-3:before {\n\tcontent: \"\\E707\";\n}\n.i-Calculator:before {\n\tcontent: \"\\E708\";\n}\n.i-Calendar-2:before {\n\tcontent: \"\\E709\";\n}\n.i-Calendar-3:before {\n\tcontent: \"\\E70A\";\n}\n.i-Calendar-4:before {\n\tcontent: \"\\E70B\";\n}\n.i-Calendar-Clock:before {\n\tcontent: \"\\E70C\";\n}\n.i-Calendar:before {\n\tcontent: \"\\E70D\";\n}\n.i-Camel:before {\n\tcontent: \"\\E70E\";\n}\n.i-Camera-2:before {\n\tcontent: \"\\E70F\";\n}\n.i-Camera-3:before {\n\tcontent: \"\\E710\";\n}\n.i-Camera-4:before {\n\tcontent: \"\\E711\";\n}\n.i-Camera-5:before {\n\tcontent: \"\\E712\";\n}\n.i-Camera-Back:before {\n\tcontent: \"\\E713\";\n}\n.i-Camera:before {\n\tcontent: \"\\E714\";\n}\n.i-Can-2:before {\n\tcontent: \"\\E715\";\n}\n.i-Can:before {\n\tcontent: \"\\E716\";\n}\n.i-Canada:before {\n\tcontent: \"\\E717\";\n}\n.i-Cancer-2:before {\n\tcontent: \"\\E718\";\n}\n.i-Cancer-3:before {\n\tcontent: \"\\E719\";\n}\n.i-Cancer:before {\n\tcontent: \"\\E71A\";\n}\n.i-Candle:before {\n\tcontent: \"\\E71B\";\n}\n.i-Candy-Cane:before {\n\tcontent: \"\\E71C\";\n}\n.i-Candy:before {\n\tcontent: \"\\E71D\";\n}\n.i-Cannon:before {\n\tcontent: \"\\E71E\";\n}\n.i-Cap-2:before {\n\tcontent: \"\\E71F\";\n}\n.i-Cap-3:before {\n\tcontent: \"\\E720\";\n}\n.i-Cap-Smiley:before {\n\tcontent: \"\\E721\";\n}\n.i-Cap:before {\n\tcontent: \"\\E722\";\n}\n.i-Capricorn-2:before {\n\tcontent: \"\\E723\";\n}\n.i-Capricorn:before {\n\tcontent: \"\\E724\";\n}\n.i-Car-2:before {\n\tcontent: \"\\E725\";\n}\n.i-Car-3:before {\n\tcontent: \"\\E726\";\n}\n.i-Car-Coins:before {\n\tcontent: \"\\E727\";\n}\n.i-Car-Items:before {\n\tcontent: \"\\E728\";\n}\n.i-Car-Wheel:before {\n\tcontent: \"\\E729\";\n}\n.i-Car:before {\n\tcontent: \"\\E72A\";\n}\n.i-Cardigan:before {\n\tcontent: \"\\E72B\";\n}\n.i-Cardiovascular:before {\n\tcontent: \"\\E72C\";\n}\n.i-Cart-Quantity:before {\n\tcontent: \"\\E72D\";\n}\n.i-Casette-Tape:before {\n\tcontent: \"\\E72E\";\n}\n.i-Cash-Register:before {\n\tcontent: \"\\E72F\";\n}\n.i-Cash-register2:before {\n\tcontent: \"\\E730\";\n}\n.i-Castle:before {\n\tcontent: \"\\E731\";\n}\n.i-Cat:before {\n\tcontent: \"\\E732\";\n}\n.i-Cathedral:before {\n\tcontent: \"\\E733\";\n}\n.i-Cauldron:before {\n\tcontent: \"\\E734\";\n}\n.i-CD-2:before {\n\tcontent: \"\\E735\";\n}\n.i-CD-Cover:before {\n\tcontent: \"\\E736\";\n}\n.i-CD:before {\n\tcontent: \"\\E737\";\n}\n.i-Cello:before {\n\tcontent: \"\\E738\";\n}\n.i-Celsius:before {\n\tcontent: \"\\E739\";\n}\n.i-Chacked-Flag:before {\n\tcontent: \"\\E73A\";\n}\n.i-Chair:before {\n\tcontent: \"\\E73B\";\n}\n.i-Charger:before {\n\tcontent: \"\\E73C\";\n}\n.i-Check-2:before {\n\tcontent: \"\\E73D\";\n}\n.i-Check:before {\n\tcontent: \"\\E73E\";\n}\n.i-Checked-User:before {\n\tcontent: \"\\E73F\";\n}\n.i-Checkmate:before {\n\tcontent: \"\\E740\";\n}\n.i-Checkout-Bag:before {\n\tcontent: \"\\E741\";\n}\n.i-Checkout-Basket:before {\n\tcontent: \"\\E742\";\n}\n.i-Checkout:before {\n\tcontent: \"\\E743\";\n}\n.i-Cheese:before {\n\tcontent: \"\\E744\";\n}\n.i-Cheetah:before {\n\tcontent: \"\\E745\";\n}\n.i-Chef-Hat:before {\n\tcontent: \"\\E746\";\n}\n.i-Chef-Hat2:before {\n\tcontent: \"\\E747\";\n}\n.i-Chef:before {\n\tcontent: \"\\E748\";\n}\n.i-Chemical-2:before {\n\tcontent: \"\\E749\";\n}\n.i-Chemical-3:before {\n\tcontent: \"\\E74A\";\n}\n.i-Chemical-4:before {\n\tcontent: \"\\E74B\";\n}\n.i-Chemical-5:before {\n\tcontent: \"\\E74C\";\n}\n.i-Chemical:before {\n\tcontent: \"\\E74D\";\n}\n.i-Chess-Board:before {\n\tcontent: \"\\E74E\";\n}\n.i-Chess:before {\n\tcontent: \"\\E74F\";\n}\n.i-Chicken:before {\n\tcontent: \"\\E750\";\n}\n.i-Chile:before {\n\tcontent: \"\\E751\";\n}\n.i-Chimney:before {\n\tcontent: \"\\E752\";\n}\n.i-China:before {\n\tcontent: \"\\E753\";\n}\n.i-Chinese-Temple:before {\n\tcontent: \"\\E754\";\n}\n.i-Chip:before {\n\tcontent: \"\\E755\";\n}\n.i-Chopsticks-2:before {\n\tcontent: \"\\E756\";\n}\n.i-Chopsticks:before {\n\tcontent: \"\\E757\";\n}\n.i-Christmas-Ball:before {\n\tcontent: \"\\E758\";\n}\n.i-Christmas-Bell:before {\n\tcontent: \"\\E759\";\n}\n.i-Christmas-Candle:before {\n\tcontent: \"\\E75A\";\n}\n.i-Christmas-Hat:before {\n\tcontent: \"\\E75B\";\n}\n.i-Christmas-Sleigh:before {\n\tcontent: \"\\E75C\";\n}\n.i-Christmas-Snowman:before {\n\tcontent: \"\\E75D\";\n}\n.i-Christmas-Sock:before {\n\tcontent: \"\\E75E\";\n}\n.i-Christmas-Tree:before {\n\tcontent: \"\\E75F\";\n}\n.i-Christmas:before {\n\tcontent: \"\\E760\";\n}\n.i-Chrome:before {\n\tcontent: \"\\E761\";\n}\n.i-Chrysler-Building:before {\n\tcontent: \"\\E762\";\n}\n.i-Cinema:before {\n\tcontent: \"\\E763\";\n}\n.i-Circular-Point:before {\n\tcontent: \"\\E764\";\n}\n.i-City-Hall:before {\n\tcontent: \"\\E765\";\n}\n.i-Clamp:before {\n\tcontent: \"\\E766\";\n}\n.i-Clapperboard-Close:before {\n\tcontent: \"\\E767\";\n}\n.i-Clapperboard-Open:before {\n\tcontent: \"\\E768\";\n}\n.i-Claps:before {\n\tcontent: \"\\E769\";\n}\n.i-Clef:before {\n\tcontent: \"\\E76A\";\n}\n.i-Clinic:before {\n\tcontent: \"\\E76B\";\n}\n.i-Clock-2:before {\n\tcontent: \"\\E76C\";\n}\n.i-Clock-3:before {\n\tcontent: \"\\E76D\";\n}\n.i-Clock-4:before {\n\tcontent: \"\\E76E\";\n}\n.i-Clock-Back:before {\n\tcontent: \"\\E76F\";\n}\n.i-Clock-Forward:before {\n\tcontent: \"\\E770\";\n}\n.i-Clock:before {\n\tcontent: \"\\E771\";\n}\n.i-Close-Window:before {\n\tcontent: \"\\E772\";\n}\n.i-Close:before {\n\tcontent: \"\\E773\";\n}\n.i-Clothing-Store:before {\n\tcontent: \"\\E774\";\n}\n.i-Cloud--:before {\n\tcontent: \"\\E775\";\n}\n.i-Cloud-:before {\n\tcontent: \"\\E776\";\n}\n.i-Cloud-Camera:before {\n\tcontent: \"\\E777\";\n}\n.i-Cloud-Computer:before {\n\tcontent: \"\\E778\";\n}\n.i-Cloud-Email:before {\n\tcontent: \"\\E779\";\n}\n.i-Cloud-Hail:before {\n\tcontent: \"\\E77A\";\n}\n.i-Cloud-Laptop:before {\n\tcontent: \"\\E77B\";\n}\n.i-Cloud-Lock:before {\n\tcontent: \"\\E77C\";\n}\n.i-Cloud-Moon:before {\n\tcontent: \"\\E77D\";\n}\n.i-Cloud-Music:before {\n\tcontent: \"\\E77E\";\n}\n.i-Cloud-Picture:before {\n\tcontent: \"\\E77F\";\n}\n.i-Cloud-Rain:before {\n\tcontent: \"\\E780\";\n}\n.i-Cloud-Remove:before {\n\tcontent: \"\\E781\";\n}\n.i-Cloud-Secure:before {\n\tcontent: \"\\E782\";\n}\n.i-Cloud-Settings:before {\n\tcontent: \"\\E783\";\n}\n.i-Cloud-Smartphone:before {\n\tcontent: \"\\E784\";\n}\n.i-Cloud-Snow:before {\n\tcontent: \"\\E785\";\n}\n.i-Cloud-Sun:before {\n\tcontent: \"\\E786\";\n}\n.i-Cloud-Tablet:before {\n\tcontent: \"\\E787\";\n}\n.i-Cloud-Video:before {\n\tcontent: \"\\E788\";\n}\n.i-Cloud-Weather:before {\n\tcontent: \"\\E789\";\n}\n.i-Cloud:before {\n\tcontent: \"\\E78A\";\n}\n.i-Clouds-Weather:before {\n\tcontent: \"\\E78B\";\n}\n.i-Clouds:before {\n\tcontent: \"\\E78C\";\n}\n.i-Clown:before {\n\tcontent: \"\\E78D\";\n}\n.i-CMYK:before {\n\tcontent: \"\\E78E\";\n}\n.i-Coat:before {\n\tcontent: \"\\E78F\";\n}\n.i-Cocktail:before {\n\tcontent: \"\\E790\";\n}\n.i-Coconut:before {\n\tcontent: \"\\E791\";\n}\n.i-Code-Window:before {\n\tcontent: \"\\E792\";\n}\n.i-Coding:before {\n\tcontent: \"\\E793\";\n}\n.i-Coffee-2:before {\n\tcontent: \"\\E794\";\n}\n.i-Coffee-Bean:before {\n\tcontent: \"\\E795\";\n}\n.i-Coffee-Machine:before {\n\tcontent: \"\\E796\";\n}\n.i-Coffee-toGo:before {\n\tcontent: \"\\E797\";\n}\n.i-Coffee:before {\n\tcontent: \"\\E798\";\n}\n.i-Coffin:before {\n\tcontent: \"\\E799\";\n}\n.i-Coin:before {\n\tcontent: \"\\E79A\";\n}\n.i-Coins-2:before {\n\tcontent: \"\\E79B\";\n}\n.i-Coins-3:before {\n\tcontent: \"\\E79C\";\n}\n.i-Coins:before {\n\tcontent: \"\\E79D\";\n}\n.i-Colombia:before {\n\tcontent: \"\\E79E\";\n}\n.i-Colosseum:before {\n\tcontent: \"\\E79F\";\n}\n.i-Column-2:before {\n\tcontent: \"\\E7A0\";\n}\n.i-Column-3:before {\n\tcontent: \"\\E7A1\";\n}\n.i-Column:before {\n\tcontent: \"\\E7A2\";\n}\n.i-Comb-2:before {\n\tcontent: \"\\E7A3\";\n}\n.i-Comb:before {\n\tcontent: \"\\E7A4\";\n}\n.i-Communication-Tower:before {\n\tcontent: \"\\E7A5\";\n}\n.i-Communication-Tower2:before {\n\tcontent: \"\\E7A6\";\n}\n.i-Compass-2:before {\n\tcontent: \"\\E7A7\";\n}\n.i-Compass-3:before {\n\tcontent: \"\\E7A8\";\n}\n.i-Compass-4:before {\n\tcontent: \"\\E7A9\";\n}\n.i-Compass-Rose:before {\n\tcontent: \"\\E7AA\";\n}\n.i-Compass:before {\n\tcontent: \"\\E7AB\";\n}\n.i-Computer-2:before {\n\tcontent: \"\\E7AC\";\n}\n.i-Computer-3:before {\n\tcontent: \"\\E7AD\";\n}\n.i-Computer-Secure:before {\n\tcontent: \"\\E7AE\";\n}\n.i-Computer:before {\n\tcontent: \"\\E7AF\";\n}\n.i-Conference:before {\n\tcontent: \"\\E7B0\";\n}\n.i-Confused:before {\n\tcontent: \"\\E7B1\";\n}\n.i-Conservation:before {\n\tcontent: \"\\E7B2\";\n}\n.i-Consulting:before {\n\tcontent: \"\\E7B3\";\n}\n.i-Contrast:before {\n\tcontent: \"\\E7B4\";\n}\n.i-Control-2:before {\n\tcontent: \"\\E7B5\";\n}\n.i-Control:before {\n\tcontent: \"\\E7B6\";\n}\n.i-Cookie-Man:before {\n\tcontent: \"\\E7B7\";\n}\n.i-Cookies:before {\n\tcontent: \"\\E7B8\";\n}\n.i-Cool-Guy:before {\n\tcontent: \"\\E7B9\";\n}\n.i-Cool:before {\n\tcontent: \"\\E7BA\";\n}\n.i-Copyright:before {\n\tcontent: \"\\E7BB\";\n}\n.i-Costume:before {\n\tcontent: \"\\E7BC\";\n}\n.i-Couple-Sign:before {\n\tcontent: \"\\E7BD\";\n}\n.i-Cow:before {\n\tcontent: \"\\E7BE\";\n}\n.i-CPU:before {\n\tcontent: \"\\E7BF\";\n}\n.i-Crane:before {\n\tcontent: \"\\E7C0\";\n}\n.i-Cranium:before {\n\tcontent: \"\\E7C1\";\n}\n.i-Credit-Card:before {\n\tcontent: \"\\E7C2\";\n}\n.i-Credit-Card2:before {\n\tcontent: \"\\E7C3\";\n}\n.i-Credit-Card3:before {\n\tcontent: \"\\E7C4\";\n}\n.i-Cricket:before {\n\tcontent: \"\\E7C5\";\n}\n.i-Criminal:before {\n\tcontent: \"\\E7C6\";\n}\n.i-Croissant:before {\n\tcontent: \"\\E7C7\";\n}\n.i-Crop-2:before {\n\tcontent: \"\\E7C8\";\n}\n.i-Crop-3:before {\n\tcontent: \"\\E7C9\";\n}\n.i-Crown-2:before {\n\tcontent: \"\\E7CA\";\n}\n.i-Crown:before {\n\tcontent: \"\\E7CB\";\n}\n.i-Crying:before {\n\tcontent: \"\\E7CC\";\n}\n.i-Cube-Molecule:before {\n\tcontent: \"\\E7CD\";\n}\n.i-Cube-Molecule2:before {\n\tcontent: \"\\E7CE\";\n}\n.i-Cupcake:before {\n\tcontent: \"\\E7CF\";\n}\n.i-Cursor-Click:before {\n\tcontent: \"\\E7D0\";\n}\n.i-Cursor-Click2:before {\n\tcontent: \"\\E7D1\";\n}\n.i-Cursor-Move:before {\n\tcontent: \"\\E7D2\";\n}\n.i-Cursor-Move2:before {\n\tcontent: \"\\E7D3\";\n}\n.i-Cursor-Select:before {\n\tcontent: \"\\E7D4\";\n}\n.i-Cursor:before {\n\tcontent: \"\\E7D5\";\n}\n.i-D-Eyeglasses:before {\n\tcontent: \"\\E7D6\";\n}\n.i-D-Eyeglasses2:before {\n\tcontent: \"\\E7D7\";\n}\n.i-Dam:before {\n\tcontent: \"\\E7D8\";\n}\n.i-Danemark:before {\n\tcontent: \"\\E7D9\";\n}\n.i-Danger-2:before {\n\tcontent: \"\\E7DA\";\n}\n.i-Danger:before {\n\tcontent: \"\\E7DB\";\n}\n.i-Dashboard:before {\n\tcontent: \"\\E7DC\";\n}\n.i-Data-Backup:before {\n\tcontent: \"\\E7DD\";\n}\n.i-Data-Block:before {\n\tcontent: \"\\E7DE\";\n}\n.i-Data-Center:before {\n\tcontent: \"\\E7DF\";\n}\n.i-Data-Clock:before {\n\tcontent: \"\\E7E0\";\n}\n.i-Data-Cloud:before {\n\tcontent: \"\\E7E1\";\n}\n.i-Data-Compress:before {\n\tcontent: \"\\E7E2\";\n}\n.i-Data-Copy:before {\n\tcontent: \"\\E7E3\";\n}\n.i-Data-Download:before {\n\tcontent: \"\\E7E4\";\n}\n.i-Data-Financial:before {\n\tcontent: \"\\E7E5\";\n}\n.i-Data-Key:before {\n\tcontent: \"\\E7E6\";\n}\n.i-Data-Lock:before {\n\tcontent: \"\\E7E7\";\n}\n.i-Data-Network:before {\n\tcontent: \"\\E7E8\";\n}\n.i-Data-Password:before {\n\tcontent: \"\\E7E9\";\n}\n.i-Data-Power:before {\n\tcontent: \"\\E7EA\";\n}\n.i-Data-Refresh:before {\n\tcontent: \"\\E7EB\";\n}\n.i-Data-Save:before {\n\tcontent: \"\\E7EC\";\n}\n.i-Data-Search:before {\n\tcontent: \"\\E7ED\";\n}\n.i-Data-Security:before {\n\tcontent: \"\\E7EE\";\n}\n.i-Data-Settings:before {\n\tcontent: \"\\E7EF\";\n}\n.i-Data-Sharing:before {\n\tcontent: \"\\E7F0\";\n}\n.i-Data-Shield:before {\n\tcontent: \"\\E7F1\";\n}\n.i-Data-Signal:before {\n\tcontent: \"\\E7F2\";\n}\n.i-Data-Storage:before {\n\tcontent: \"\\E7F3\";\n}\n.i-Data-Stream:before {\n\tcontent: \"\\E7F4\";\n}\n.i-Data-Transfer:before {\n\tcontent: \"\\E7F5\";\n}\n.i-Data-Unlock:before {\n\tcontent: \"\\E7F6\";\n}\n.i-Data-Upload:before {\n\tcontent: \"\\E7F7\";\n}\n.i-Data-Yes:before {\n\tcontent: \"\\E7F8\";\n}\n.i-Data:before {\n\tcontent: \"\\E7F9\";\n}\n.i-David-Star:before {\n\tcontent: \"\\E7FA\";\n}\n.i-Daylight:before {\n\tcontent: \"\\E7FB\";\n}\n.i-Death:before {\n\tcontent: \"\\E7FC\";\n}\n.i-Debian:before {\n\tcontent: \"\\E7FD\";\n}\n.i-Dec:before {\n\tcontent: \"\\E7FE\";\n}\n.i-Decrase-Inedit:before {\n\tcontent: \"\\E7FF\";\n}\n.i-Deer-2:before {\n\tcontent: \"\\E800\";\n}\n.i-Deer:before {\n\tcontent: \"\\E801\";\n}\n.i-Delete-File:before {\n\tcontent: \"\\E802\";\n}\n.i-Delete-Window:before {\n\tcontent: \"\\E803\";\n}\n.i-Delicious:before {\n\tcontent: \"\\E804\";\n}\n.i-Depression:before {\n\tcontent: \"\\E805\";\n}\n.i-Deviantart:before {\n\tcontent: \"\\E806\";\n}\n.i-Device-SyncwithCloud:before {\n\tcontent: \"\\E807\";\n}\n.i-Diamond:before {\n\tcontent: \"\\E808\";\n}\n.i-Dice-2:before {\n\tcontent: \"\\E809\";\n}\n.i-Dice:before {\n\tcontent: \"\\E80A\";\n}\n.i-Digg:before {\n\tcontent: \"\\E80B\";\n}\n.i-Digital-Drawing:before {\n\tcontent: \"\\E80C\";\n}\n.i-Diigo:before {\n\tcontent: \"\\E80D\";\n}\n.i-Dinosaur:before {\n\tcontent: \"\\E80E\";\n}\n.i-Diploma-2:before {\n\tcontent: \"\\E80F\";\n}\n.i-Diploma:before {\n\tcontent: \"\\E810\";\n}\n.i-Direction-East:before {\n\tcontent: \"\\E811\";\n}\n.i-Direction-North:before {\n\tcontent: \"\\E812\";\n}\n.i-Direction-South:before {\n\tcontent: \"\\E813\";\n}\n.i-Direction-West:before {\n\tcontent: \"\\E814\";\n}\n.i-Director:before {\n\tcontent: \"\\E815\";\n}\n.i-Disk:before {\n\tcontent: \"\\E816\";\n}\n.i-Dj:before {\n\tcontent: \"\\E817\";\n}\n.i-DNA-2:before {\n\tcontent: \"\\E818\";\n}\n.i-DNA-Helix:before {\n\tcontent: \"\\E819\";\n}\n.i-DNA:before {\n\tcontent: \"\\E81A\";\n}\n.i-Doctor:before {\n\tcontent: \"\\E81B\";\n}\n.i-Dog:before {\n\tcontent: \"\\E81C\";\n}\n.i-Dollar-Sign:before {\n\tcontent: \"\\E81D\";\n}\n.i-Dollar-Sign2:before {\n\tcontent: \"\\E81E\";\n}\n.i-Dollar:before {\n\tcontent: \"\\E81F\";\n}\n.i-Dolphin:before {\n\tcontent: \"\\E820\";\n}\n.i-Domino:before {\n\tcontent: \"\\E821\";\n}\n.i-Door-Hanger:before {\n\tcontent: \"\\E822\";\n}\n.i-Door:before {\n\tcontent: \"\\E823\";\n}\n.i-Doplr:before {\n\tcontent: \"\\E824\";\n}\n.i-Double-Circle:before {\n\tcontent: \"\\E825\";\n}\n.i-Double-Tap:before {\n\tcontent: \"\\E826\";\n}\n.i-Doughnut:before {\n\tcontent: \"\\E827\";\n}\n.i-Dove:before {\n\tcontent: \"\\E828\";\n}\n.i-Down-2:before {\n\tcontent: \"\\E829\";\n}\n.i-Down-3:before {\n\tcontent: \"\\E82A\";\n}\n.i-Down-4:before {\n\tcontent: \"\\E82B\";\n}\n.i-Down:before {\n\tcontent: \"\\E82C\";\n}\n.i-Download-2:before {\n\tcontent: \"\\E82D\";\n}\n.i-Download-fromCloud:before {\n\tcontent: \"\\E82E\";\n}\n.i-Download-Window:before {\n\tcontent: \"\\E82F\";\n}\n.i-Download:before {\n\tcontent: \"\\E830\";\n}\n.i-Downward:before {\n\tcontent: \"\\E831\";\n}\n.i-Drag-Down:before {\n\tcontent: \"\\E832\";\n}\n.i-Drag-Left:before {\n\tcontent: \"\\E833\";\n}\n.i-Drag-Right:before {\n\tcontent: \"\\E834\";\n}\n.i-Drag-Up:before {\n\tcontent: \"\\E835\";\n}\n.i-Drag:before {\n\tcontent: \"\\E836\";\n}\n.i-Dress:before {\n\tcontent: \"\\E837\";\n}\n.i-Drill-2:before {\n\tcontent: \"\\E838\";\n}\n.i-Drill:before {\n\tcontent: \"\\E839\";\n}\n.i-Drop:before {\n\tcontent: \"\\E83A\";\n}\n.i-Dropbox:before {\n\tcontent: \"\\E83B\";\n}\n.i-Drum:before {\n\tcontent: \"\\E83C\";\n}\n.i-Dry:before {\n\tcontent: \"\\E83D\";\n}\n.i-Duck:before {\n\tcontent: \"\\E83E\";\n}\n.i-Dumbbell:before {\n\tcontent: \"\\E83F\";\n}\n.i-Duplicate-Layer:before {\n\tcontent: \"\\E840\";\n}\n.i-Duplicate-Window:before {\n\tcontent: \"\\E841\";\n}\n.i-DVD:before {\n\tcontent: \"\\E842\";\n}\n.i-Eagle:before {\n\tcontent: \"\\E843\";\n}\n.i-Ear:before {\n\tcontent: \"\\E844\";\n}\n.i-Earphones-2:before {\n\tcontent: \"\\E845\";\n}\n.i-Earphones:before {\n\tcontent: \"\\E846\";\n}\n.i-Eci-i:before {\n\tcontent: \"\\E847\";\n}\n.i-Edit-Map:before {\n\tcontent: \"\\E848\";\n}\n.i-Edit:before {\n\tcontent: \"\\E849\";\n}\n.i-Eggs:before {\n\tcontent: \"\\E84A\";\n}\n.i-Egypt:before {\n\tcontent: \"\\E84B\";\n}\n.i-Eifel-Tower:before {\n\tcontent: \"\\E84C\";\n}\n.i-eject-2:before {\n\tcontent: \"\\E84D\";\n}\n.i-Eject:before {\n\tcontent: \"\\E84E\";\n}\n.i-El-Castillo:before {\n\tcontent: \"\\E84F\";\n}\n.i-Elbow:before {\n\tcontent: \"\\E850\";\n}\n.i-Electric-Guitar:before {\n\tcontent: \"\\E851\";\n}\n.i-Electricity:before {\n\tcontent: \"\\E852\";\n}\n.i-Elephant:before {\n\tcontent: \"\\E853\";\n}\n.i-Email:before {\n\tcontent: \"\\E854\";\n}\n.i-Embassy:before {\n\tcontent: \"\\E855\";\n}\n.i-Empire-StateBuilding:before {\n\tcontent: \"\\E856\";\n}\n.i-Empty-Box:before {\n\tcontent: \"\\E857\";\n}\n.i-End2:before {\n\tcontent: \"\\E858\";\n}\n.i-End-2:before {\n\tcontent: \"\\E859\";\n}\n.i-End:before {\n\tcontent: \"\\E85A\";\n}\n.i-Endways:before {\n\tcontent: \"\\E85B\";\n}\n.i-Engineering:before {\n\tcontent: \"\\E85C\";\n}\n.i-Envelope-2:before {\n\tcontent: \"\\E85D\";\n}\n.i-Envelope:before {\n\tcontent: \"\\E85E\";\n}\n.i-Environmental-2:before {\n\tcontent: \"\\E85F\";\n}\n.i-Environmental-3:before {\n\tcontent: \"\\E860\";\n}\n.i-Environmental:before {\n\tcontent: \"\\E861\";\n}\n.i-Equalizer:before {\n\tcontent: \"\\E862\";\n}\n.i-Eraser-2:before {\n\tcontent: \"\\E863\";\n}\n.i-Eraser-3:before {\n\tcontent: \"\\E864\";\n}\n.i-Eraser:before {\n\tcontent: \"\\E865\";\n}\n.i-Error-404Window:before {\n\tcontent: \"\\E866\";\n}\n.i-Euro-Sign:before {\n\tcontent: \"\\E867\";\n}\n.i-Euro-Sign2:before {\n\tcontent: \"\\E868\";\n}\n.i-Euro:before {\n\tcontent: \"\\E869\";\n}\n.i-Evernote:before {\n\tcontent: \"\\E86A\";\n}\n.i-Evil:before {\n\tcontent: \"\\E86B\";\n}\n.i-Explode:before {\n\tcontent: \"\\E86C\";\n}\n.i-Eye-2:before {\n\tcontent: \"\\E86D\";\n}\n.i-Eye-Blind:before {\n\tcontent: \"\\E86E\";\n}\n.i-Eye-Invisible:before {\n\tcontent: \"\\E86F\";\n}\n.i-Eye-Scan:before {\n\tcontent: \"\\E870\";\n}\n.i-Eye-Visible:before {\n\tcontent: \"\\E871\";\n}\n.i-Eye:before {\n\tcontent: \"\\E872\";\n}\n.i-Eyebrow-2:before {\n\tcontent: \"\\E873\";\n}\n.i-Eyebrow-3:before {\n\tcontent: \"\\E874\";\n}\n.i-Eyebrow:before {\n\tcontent: \"\\E875\";\n}\n.i-Eyeglasses-Smiley:before {\n\tcontent: \"\\E876\";\n}\n.i-Eyeglasses-Smiley2:before {\n\tcontent: \"\\E877\";\n}\n.i-Face-Style:before {\n\tcontent: \"\\E878\";\n}\n.i-Face-Style2:before {\n\tcontent: \"\\E879\";\n}\n.i-Face-Style3:before {\n\tcontent: \"\\E87A\";\n}\n.i-Face-Style4:before {\n\tcontent: \"\\E87B\";\n}\n.i-Face-Style5:before {\n\tcontent: \"\\E87C\";\n}\n.i-Face-Style6:before {\n\tcontent: \"\\E87D\";\n}\n.i-Facebook-2:before {\n\tcontent: \"\\E87E\";\n}\n.i-Facebook:before {\n\tcontent: \"\\E87F\";\n}\n.i-Factory-2:before {\n\tcontent: \"\\E880\";\n}\n.i-Factory:before {\n\tcontent: \"\\E881\";\n}\n.i-Fahrenheit:before {\n\tcontent: \"\\E882\";\n}\n.i-Family-Sign:before {\n\tcontent: \"\\E883\";\n}\n.i-Fan:before {\n\tcontent: \"\\E884\";\n}\n.i-Farmer:before {\n\tcontent: \"\\E885\";\n}\n.i-Fashion:before {\n\tcontent: \"\\E886\";\n}\n.i-Favorite-Window:before {\n\tcontent: \"\\E887\";\n}\n.i-Fax:before {\n\tcontent: \"\\E888\";\n}\n.i-Feather:before {\n\tcontent: \"\\E889\";\n}\n.i-Feedburner:before {\n\tcontent: \"\\E88A\";\n}\n.i-Female-2:before {\n\tcontent: \"\\E88B\";\n}\n.i-Female-Sign:before {\n\tcontent: \"\\E88C\";\n}\n.i-Female:before {\n\tcontent: \"\\E88D\";\n}\n.i-File-Block:before {\n\tcontent: \"\\E88E\";\n}\n.i-File-Bookmark:before {\n\tcontent: \"\\E88F\";\n}\n.i-File-Chart:before {\n\tcontent: \"\\E890\";\n}\n.i-File-Clipboard:before {\n\tcontent: \"\\E891\";\n}\n.i-File-ClipboardFileText:before {\n\tcontent: \"\\E892\";\n}\n.i-File-ClipboardTextImage:before {\n\tcontent: \"\\E893\";\n}\n.i-File-Cloud:before {\n\tcontent: \"\\E894\";\n}\n.i-File-Copy:before {\n\tcontent: \"\\E895\";\n}\n.i-File-Copy2:before {\n\tcontent: \"\\E896\";\n}\n.i-File-CSV:before {\n\tcontent: \"\\E897\";\n}\n.i-File-Download:before {\n\tcontent: \"\\E898\";\n}\n.i-File-Edit:before {\n\tcontent: \"\\E899\";\n}\n.i-File-Excel:before {\n\tcontent: \"\\E89A\";\n}\n.i-File-Favorite:before {\n\tcontent: \"\\E89B\";\n}\n.i-File-Fire:before {\n\tcontent: \"\\E89C\";\n}\n.i-File-Graph:before {\n\tcontent: \"\\E89D\";\n}\n.i-File-Hide:before {\n\tcontent: \"\\E89E\";\n}\n.i-File-Horizontal:before {\n\tcontent: \"\\E89F\";\n}\n.i-File-HorizontalText:before {\n\tcontent: \"\\E8A0\";\n}\n.i-File-HTML:before {\n\tcontent: \"\\E8A1\";\n}\n.i-File-JPG:before {\n\tcontent: \"\\E8A2\";\n}\n.i-File-Link:before {\n\tcontent: \"\\E8A3\";\n}\n.i-File-Loading:before {\n\tcontent: \"\\E8A4\";\n}\n.i-File-Lock:before {\n\tcontent: \"\\E8A5\";\n}\n.i-File-Love:before {\n\tcontent: \"\\E8A6\";\n}\n.i-File-Music:before {\n\tcontent: \"\\E8A7\";\n}\n.i-File-Network:before {\n\tcontent: \"\\E8A8\";\n}\n.i-File-Pictures:before {\n\tcontent: \"\\E8A9\";\n}\n.i-File-Pie:before {\n\tcontent: \"\\E8AA\";\n}\n.i-File-Presentation:before {\n\tcontent: \"\\E8AB\";\n}\n.i-File-Refresh:before {\n\tcontent: \"\\E8AC\";\n}\n.i-File-Search:before {\n\tcontent: \"\\E8AD\";\n}\n.i-File-Settings:before {\n\tcontent: \"\\E8AE\";\n}\n.i-File-Share:before {\n\tcontent: \"\\E8AF\";\n}\n.i-File-TextImage:before {\n\tcontent: \"\\E8B0\";\n}\n.i-File-Trash:before {\n\tcontent: \"\\E8B1\";\n}\n.i-File-TXT:before {\n\tcontent: \"\\E8B2\";\n}\n.i-File-Upload:before {\n\tcontent: \"\\E8B3\";\n}\n.i-File-Video:before {\n\tcontent: \"\\E8B4\";\n}\n.i-File-Word:before {\n\tcontent: \"\\E8B5\";\n}\n.i-File-Zip:before {\n\tcontent: \"\\E8B6\";\n}\n.i-File:before {\n\tcontent: \"\\E8B7\";\n}\n.i-Files:before {\n\tcontent: \"\\E8B8\";\n}\n.i-Film-Board:before {\n\tcontent: \"\\E8B9\";\n}\n.i-Film-Cartridge:before {\n\tcontent: \"\\E8BA\";\n}\n.i-Film-Strip:before {\n\tcontent: \"\\E8BB\";\n}\n.i-Film-Video:before {\n\tcontent: \"\\E8BC\";\n}\n.i-Film:before {\n\tcontent: \"\\E8BD\";\n}\n.i-Filter-2:before {\n\tcontent: \"\\E8BE\";\n}\n.i-Filter:before {\n\tcontent: \"\\E8BF\";\n}\n.i-Financial:before {\n\tcontent: \"\\E8C0\";\n}\n.i-Find-User:before {\n\tcontent: \"\\E8C1\";\n}\n.i-Finger-DragFourSides:before {\n\tcontent: \"\\E8C2\";\n}\n.i-Finger-DragTwoSides:before {\n\tcontent: \"\\E8C3\";\n}\n.i-Finger-Print:before {\n\tcontent: \"\\E8C4\";\n}\n.i-Finger:before {\n\tcontent: \"\\E8C5\";\n}\n.i-Fingerprint-2:before {\n\tcontent: \"\\E8C6\";\n}\n.i-Fingerprint:before {\n\tcontent: \"\\E8C7\";\n}\n.i-Fire-Flame:before {\n\tcontent: \"\\E8C8\";\n}\n.i-Fire-Flame2:before {\n\tcontent: \"\\E8C9\";\n}\n.i-Fire-Hydrant:before {\n\tcontent: \"\\E8CA\";\n}\n.i-Fire-Staion:before {\n\tcontent: \"\\E8CB\";\n}\n.i-Firefox:before {\n\tcontent: \"\\E8CC\";\n}\n.i-Firewall:before {\n\tcontent: \"\\E8CD\";\n}\n.i-First-Aid:before {\n\tcontent: \"\\E8CE\";\n}\n.i-First:before {\n\tcontent: \"\\E8CF\";\n}\n.i-Fish-Food:before {\n\tcontent: \"\\E8D0\";\n}\n.i-Fish:before {\n\tcontent: \"\\E8D1\";\n}\n.i-Fit-To:before {\n\tcontent: \"\\E8D2\";\n}\n.i-Fit-To2:before {\n\tcontent: \"\\E8D3\";\n}\n.i-Five-Fingers:before {\n\tcontent: \"\\E8D4\";\n}\n.i-Five-FingersDrag:before {\n\tcontent: \"\\E8D5\";\n}\n.i-Five-FingersDrag2:before {\n\tcontent: \"\\E8D6\";\n}\n.i-Five-FingersTouch:before {\n\tcontent: \"\\E8D7\";\n}\n.i-Flag-2:before {\n\tcontent: \"\\E8D8\";\n}\n.i-Flag-3:before {\n\tcontent: \"\\E8D9\";\n}\n.i-Flag-4:before {\n\tcontent: \"\\E8DA\";\n}\n.i-Flag-5:before {\n\tcontent: \"\\E8DB\";\n}\n.i-Flag-6:before {\n\tcontent: \"\\E8DC\";\n}\n.i-Flag:before {\n\tcontent: \"\\E8DD\";\n}\n.i-Flamingo:before {\n\tcontent: \"\\E8DE\";\n}\n.i-Flash-2:before {\n\tcontent: \"\\E8DF\";\n}\n.i-Flash-Video:before {\n\tcontent: \"\\E8E0\";\n}\n.i-Flash:before {\n\tcontent: \"\\E8E1\";\n}\n.i-Flashlight:before {\n\tcontent: \"\\E8E2\";\n}\n.i-Flask-2:before {\n\tcontent: \"\\E8E3\";\n}\n.i-Flask:before {\n\tcontent: \"\\E8E4\";\n}\n.i-Flick:before {\n\tcontent: \"\\E8E5\";\n}\n.i-Flickr:before {\n\tcontent: \"\\E8E6\";\n}\n.i-Flowerpot:before {\n\tcontent: \"\\E8E7\";\n}\n.i-Fluorescent:before {\n\tcontent: \"\\E8E8\";\n}\n.i-Fog-Day:before {\n\tcontent: \"\\E8E9\";\n}\n.i-Fog-Night:before {\n\tcontent: \"\\E8EA\";\n}\n.i-Folder-Add:before {\n\tcontent: \"\\E8EB\";\n}\n.i-Folder-Archive:before {\n\tcontent: \"\\E8EC\";\n}\n.i-Folder-Binder:before {\n\tcontent: \"\\E8ED\";\n}\n.i-Folder-Binder2:before {\n\tcontent: \"\\E8EE\";\n}\n.i-Folder-Block:before {\n\tcontent: \"\\E8EF\";\n}\n.i-Folder-Bookmark:before {\n\tcontent: \"\\E8F0\";\n}\n.i-Folder-Close:before {\n\tcontent: \"\\E8F1\";\n}\n.i-Folder-Cloud:before {\n\tcontent: \"\\E8F2\";\n}\n.i-Folder-Delete:before {\n\tcontent: \"\\E8F3\";\n}\n.i-Folder-Download:before {\n\tcontent: \"\\E8F4\";\n}\n.i-Folder-Edit:before {\n\tcontent: \"\\E8F5\";\n}\n.i-Folder-Favorite:before {\n\tcontent: \"\\E8F6\";\n}\n.i-Folder-Fire:before {\n\tcontent: \"\\E8F7\";\n}\n.i-Folder-Hide:before {\n\tcontent: \"\\E8F8\";\n}\n.i-Folder-Link:before {\n\tcontent: \"\\E8F9\";\n}\n.i-Folder-Loading:before {\n\tcontent: \"\\E8FA\";\n}\n.i-Folder-Lock:before {\n\tcontent: \"\\E8FB\";\n}\n.i-Folder-Love:before {\n\tcontent: \"\\E8FC\";\n}\n.i-Folder-Music:before {\n\tcontent: \"\\E8FD\";\n}\n.i-Folder-Network:before {\n\tcontent: \"\\E8FE\";\n}\n.i-Folder-Open:before {\n\tcontent: \"\\E8FF\";\n}\n.i-Folder-Open2:before {\n\tcontent: \"\\E900\";\n}\n.i-Folder-Organizing:before {\n\tcontent: \"\\E901\";\n}\n.i-Folder-Pictures:before {\n\tcontent: \"\\E902\";\n}\n.i-Folder-Refresh:before {\n\tcontent: \"\\E903\";\n}\n.i-Folder-Remove-:before {\n\tcontent: \"\\E904\";\n}\n.i-Folder-Search:before {\n\tcontent: \"\\E905\";\n}\n.i-Folder-Settings:before {\n\tcontent: \"\\E906\";\n}\n.i-Folder-Share:before {\n\tcontent: \"\\E907\";\n}\n.i-Folder-Trash:before {\n\tcontent: \"\\E908\";\n}\n.i-Folder-Upload:before {\n\tcontent: \"\\E909\";\n}\n.i-Folder-Video:before {\n\tcontent: \"\\E90A\";\n}\n.i-Folder-WithDocument:before {\n\tcontent: \"\\E90B\";\n}\n.i-Folder-Zip:before {\n\tcontent: \"\\E90C\";\n}\n.i-Folder:before {\n\tcontent: \"\\E90D\";\n}\n.i-Folders:before {\n\tcontent: \"\\E90E\";\n}\n.i-Font-Color:before {\n\tcontent: \"\\E90F\";\n}\n.i-Font-Name:before {\n\tcontent: \"\\E910\";\n}\n.i-Font-Size:before {\n\tcontent: \"\\E911\";\n}\n.i-Font-Style:before {\n\tcontent: \"\\E912\";\n}\n.i-Font-StyleSubscript:before {\n\tcontent: \"\\E913\";\n}\n.i-Font-StyleSuperscript:before {\n\tcontent: \"\\E914\";\n}\n.i-Font-Window:before {\n\tcontent: \"\\E915\";\n}\n.i-Foot-2:before {\n\tcontent: \"\\E916\";\n}\n.i-Foot:before {\n\tcontent: \"\\E917\";\n}\n.i-Football-2:before {\n\tcontent: \"\\E918\";\n}\n.i-Football:before {\n\tcontent: \"\\E919\";\n}\n.i-Footprint-2:before {\n\tcontent: \"\\E91A\";\n}\n.i-Footprint-3:before {\n\tcontent: \"\\E91B\";\n}\n.i-Footprint:before {\n\tcontent: \"\\E91C\";\n}\n.i-Forest:before {\n\tcontent: \"\\E91D\";\n}\n.i-Fork:before {\n\tcontent: \"\\E91E\";\n}\n.i-Formspring:before {\n\tcontent: \"\\E91F\";\n}\n.i-Formula:before {\n\tcontent: \"\\E920\";\n}\n.i-Forsquare:before {\n\tcontent: \"\\E921\";\n}\n.i-Forward:before {\n\tcontent: \"\\E922\";\n}\n.i-Fountain-Pen:before {\n\tcontent: \"\\E923\";\n}\n.i-Four-Fingers:before {\n\tcontent: \"\\E924\";\n}\n.i-Four-FingersDrag:before {\n\tcontent: \"\\E925\";\n}\n.i-Four-FingersDrag2:before {\n\tcontent: \"\\E926\";\n}\n.i-Four-FingersTouch:before {\n\tcontent: \"\\E927\";\n}\n.i-Fox:before {\n\tcontent: \"\\E928\";\n}\n.i-Frankenstein:before {\n\tcontent: \"\\E929\";\n}\n.i-French-Fries:before {\n\tcontent: \"\\E92A\";\n}\n.i-Friendfeed:before {\n\tcontent: \"\\E92B\";\n}\n.i-Friendster:before {\n\tcontent: \"\\E92C\";\n}\n.i-Frog:before {\n\tcontent: \"\\E92D\";\n}\n.i-Fruits:before {\n\tcontent: \"\\E92E\";\n}\n.i-Fuel:before {\n\tcontent: \"\\E92F\";\n}\n.i-Full-Bag:before {\n\tcontent: \"\\E930\";\n}\n.i-Full-Basket:before {\n\tcontent: \"\\E931\";\n}\n.i-Full-Cart:before {\n\tcontent: \"\\E932\";\n}\n.i-Full-Moon:before {\n\tcontent: \"\\E933\";\n}\n.i-Full-Screen:before {\n\tcontent: \"\\E934\";\n}\n.i-Full-Screen2:before {\n\tcontent: \"\\E935\";\n}\n.i-Full-View:before {\n\tcontent: \"\\E936\";\n}\n.i-Full-View2:before {\n\tcontent: \"\\E937\";\n}\n.i-Full-ViewWindow:before {\n\tcontent: \"\\E938\";\n}\n.i-Function:before {\n\tcontent: \"\\E939\";\n}\n.i-Funky:before {\n\tcontent: \"\\E93A\";\n}\n.i-Funny-Bicycle:before {\n\tcontent: \"\\E93B\";\n}\n.i-Furl:before {\n\tcontent: \"\\E93C\";\n}\n.i-Gamepad-2:before {\n\tcontent: \"\\E93D\";\n}\n.i-Gamepad:before {\n\tcontent: \"\\E93E\";\n}\n.i-Gas-Pump:before {\n\tcontent: \"\\E93F\";\n}\n.i-Gaugage-2:before {\n\tcontent: \"\\E940\";\n}\n.i-Gaugage:before {\n\tcontent: \"\\E941\";\n}\n.i-Gay:before {\n\tcontent: \"\\E942\";\n}\n.i-Gear-2:before {\n\tcontent: \"\\E943\";\n}\n.i-Gear:before {\n\tcontent: \"\\E944\";\n}\n.i-Gears-2:before {\n\tcontent: \"\\E945\";\n}\n.i-Gears:before {\n\tcontent: \"\\E946\";\n}\n.i-Geek-2:before {\n\tcontent: \"\\E947\";\n}\n.i-Geek:before {\n\tcontent: \"\\E948\";\n}\n.i-Gemini-2:before {\n\tcontent: \"\\E949\";\n}\n.i-Gemini:before {\n\tcontent: \"\\E94A\";\n}\n.i-Genius:before {\n\tcontent: \"\\E94B\";\n}\n.i-Gentleman:before {\n\tcontent: \"\\E94C\";\n}\n.i-Geo--:before {\n\tcontent: \"\\E94D\";\n}\n.i-Geo-:before {\n\tcontent: \"\\E94E\";\n}\n.i-Geo-Close:before {\n\tcontent: \"\\E94F\";\n}\n.i-Geo-Love:before {\n\tcontent: \"\\E950\";\n}\n.i-Geo-Number:before {\n\tcontent: \"\\E951\";\n}\n.i-Geo-Star:before {\n\tcontent: \"\\E952\";\n}\n.i-Geo:before {\n\tcontent: \"\\E953\";\n}\n.i-Geo2--:before {\n\tcontent: \"\\E954\";\n}\n.i-Geo2-:before {\n\tcontent: \"\\E955\";\n}\n.i-Geo2-Close:before {\n\tcontent: \"\\E956\";\n}\n.i-Geo2-Love:before {\n\tcontent: \"\\E957\";\n}\n.i-Geo2-Number:before {\n\tcontent: \"\\E958\";\n}\n.i-Geo2-Star:before {\n\tcontent: \"\\E959\";\n}\n.i-Geo2:before {\n\tcontent: \"\\E95A\";\n}\n.i-Geo3--:before {\n\tcontent: \"\\E95B\";\n}\n.i-Geo3-:before {\n\tcontent: \"\\E95C\";\n}\n.i-Geo3-Close:before {\n\tcontent: \"\\E95D\";\n}\n.i-Geo3-Love:before {\n\tcontent: \"\\E95E\";\n}\n.i-Geo3-Number:before {\n\tcontent: \"\\E95F\";\n}\n.i-Geo3-Star:before {\n\tcontent: \"\\E960\";\n}\n.i-Geo3:before {\n\tcontent: \"\\E961\";\n}\n.i-Gey:before {\n\tcontent: \"\\E962\";\n}\n.i-Gift-Box:before {\n\tcontent: \"\\E963\";\n}\n.i-Giraffe:before {\n\tcontent: \"\\E964\";\n}\n.i-Girl:before {\n\tcontent: \"\\E965\";\n}\n.i-Glass-Water:before {\n\tcontent: \"\\E966\";\n}\n.i-Glasses-2:before {\n\tcontent: \"\\E967\";\n}\n.i-Glasses-3:before {\n\tcontent: \"\\E968\";\n}\n.i-Glasses:before {\n\tcontent: \"\\E969\";\n}\n.i-Global-Position:before {\n\tcontent: \"\\E96A\";\n}\n.i-Globe-2:before {\n\tcontent: \"\\E96B\";\n}\n.i-Globe:before {\n\tcontent: \"\\E96C\";\n}\n.i-Gloves:before {\n\tcontent: \"\\E96D\";\n}\n.i-Go-Bottom:before {\n\tcontent: \"\\E96E\";\n}\n.i-Go-Top:before {\n\tcontent: \"\\E96F\";\n}\n.i-Goggles:before {\n\tcontent: \"\\E970\";\n}\n.i-Golf-2:before {\n\tcontent: \"\\E971\";\n}\n.i-Golf:before {\n\tcontent: \"\\E972\";\n}\n.i-Google-Buzz:before {\n\tcontent: \"\\E973\";\n}\n.i-Google-Drive:before {\n\tcontent: \"\\E974\";\n}\n.i-Google-Play:before {\n\tcontent: \"\\E975\";\n}\n.i-Google-Plus:before {\n\tcontent: \"\\E976\";\n}\n.i-Google:before {\n\tcontent: \"\\E977\";\n}\n.i-Gopro:before {\n\tcontent: \"\\E978\";\n}\n.i-Gorilla:before {\n\tcontent: \"\\E979\";\n}\n.i-Gowalla:before {\n\tcontent: \"\\E97A\";\n}\n.i-Grave:before {\n\tcontent: \"\\E97B\";\n}\n.i-Graveyard:before {\n\tcontent: \"\\E97C\";\n}\n.i-Greece:before {\n\tcontent: \"\\E97D\";\n}\n.i-Green-Energy:before {\n\tcontent: \"\\E97E\";\n}\n.i-Green-House:before {\n\tcontent: \"\\E97F\";\n}\n.i-Guitar:before {\n\tcontent: \"\\E980\";\n}\n.i-Gun-2:before {\n\tcontent: \"\\E981\";\n}\n.i-Gun-3:before {\n\tcontent: \"\\E982\";\n}\n.i-Gun:before {\n\tcontent: \"\\E983\";\n}\n.i-Gymnastics:before {\n\tcontent: \"\\E984\";\n}\n.i-Hair-2:before {\n\tcontent: \"\\E985\";\n}\n.i-Hair-3:before {\n\tcontent: \"\\E986\";\n}\n.i-Hair-4:before {\n\tcontent: \"\\E987\";\n}\n.i-Hair:before {\n\tcontent: \"\\E988\";\n}\n.i-Half-Moon:before {\n\tcontent: \"\\E989\";\n}\n.i-Halloween-HalfMoon:before {\n\tcontent: \"\\E98A\";\n}\n.i-Halloween-Moon:before {\n\tcontent: \"\\E98B\";\n}\n.i-Hamburger:before {\n\tcontent: \"\\E98C\";\n}\n.i-Hammer:before {\n\tcontent: \"\\E98D\";\n}\n.i-Hand-Touch:before {\n\tcontent: \"\\E98E\";\n}\n.i-Hand-Touch2:before {\n\tcontent: \"\\E98F\";\n}\n.i-Hand-TouchSmartphone:before {\n\tcontent: \"\\E990\";\n}\n.i-Hand:before {\n\tcontent: \"\\E991\";\n}\n.i-Hands:before {\n\tcontent: \"\\E992\";\n}\n.i-Handshake:before {\n\tcontent: \"\\E993\";\n}\n.i-Hanger:before {\n\tcontent: \"\\E994\";\n}\n.i-Happy:before {\n\tcontent: \"\\E995\";\n}\n.i-Hat-2:before {\n\tcontent: \"\\E996\";\n}\n.i-Hat:before {\n\tcontent: \"\\E997\";\n}\n.i-Haunted-House:before {\n\tcontent: \"\\E998\";\n}\n.i-HD-Video:before {\n\tcontent: \"\\E999\";\n}\n.i-HD:before {\n\tcontent: \"\\E99A\";\n}\n.i-HDD:before {\n\tcontent: \"\\E99B\";\n}\n.i-Headphone:before {\n\tcontent: \"\\E99C\";\n}\n.i-Headphones:before {\n\tcontent: \"\\E99D\";\n}\n.i-Headset:before {\n\tcontent: \"\\E99E\";\n}\n.i-Heart-2:before {\n\tcontent: \"\\E99F\";\n}\n.i-Heart:before {\n\tcontent: \"\\E9A0\";\n}\n.i-Heels-2:before {\n\tcontent: \"\\E9A1\";\n}\n.i-Heels:before {\n\tcontent: \"\\E9A2\";\n}\n.i-Height-Window:before {\n\tcontent: \"\\E9A3\";\n}\n.i-Helicopter-2:before {\n\tcontent: \"\\E9A4\";\n}\n.i-Helicopter:before {\n\tcontent: \"\\E9A5\";\n}\n.i-Helix-2:before {\n\tcontent: \"\\E9A6\";\n}\n.i-Hello:before {\n\tcontent: \"\\E9A7\";\n}\n.i-Helmet-2:before {\n\tcontent: \"\\E9A8\";\n}\n.i-Helmet-3:before {\n\tcontent: \"\\E9A9\";\n}\n.i-Helmet:before {\n\tcontent: \"\\E9AA\";\n}\n.i-Hipo:before {\n\tcontent: \"\\E9AB\";\n}\n.i-Hipster-Glasses:before {\n\tcontent: \"\\E9AC\";\n}\n.i-Hipster-Glasses2:before {\n\tcontent: \"\\E9AD\";\n}\n.i-Hipster-Glasses3:before {\n\tcontent: \"\\E9AE\";\n}\n.i-Hipster-Headphones:before {\n\tcontent: \"\\E9AF\";\n}\n.i-Hipster-Men:before {\n\tcontent: \"\\E9B0\";\n}\n.i-Hipster-Men2:before {\n\tcontent: \"\\E9B1\";\n}\n.i-Hipster-Men3:before {\n\tcontent: \"\\E9B2\";\n}\n.i-Hipster-Sunglasses:before {\n\tcontent: \"\\E9B3\";\n}\n.i-Hipster-Sunglasses2:before {\n\tcontent: \"\\E9B4\";\n}\n.i-Hipster-Sunglasses3:before {\n\tcontent: \"\\E9B5\";\n}\n.i-Hokey:before {\n\tcontent: \"\\E9B6\";\n}\n.i-Holly:before {\n\tcontent: \"\\E9B7\";\n}\n.i-Home-2:before {\n\tcontent: \"\\E9B8\";\n}\n.i-Home-3:before {\n\tcontent: \"\\E9B9\";\n}\n.i-Home-4:before {\n\tcontent: \"\\E9BA\";\n}\n.i-Home-5:before {\n\tcontent: \"\\E9BB\";\n}\n.i-Home-Window:before {\n\tcontent: \"\\E9BC\";\n}\n.i-Home:before {\n\tcontent: \"\\E9BD\";\n}\n.i-Homosexual:before {\n\tcontent: \"\\E9BE\";\n}\n.i-Honey:before {\n\tcontent: \"\\E9BF\";\n}\n.i-Hong-Kong:before {\n\tcontent: \"\\E9C0\";\n}\n.i-Hoodie:before {\n\tcontent: \"\\E9C1\";\n}\n.i-Horror:before {\n\tcontent: \"\\E9C2\";\n}\n.i-Horse:before {\n\tcontent: \"\\E9C3\";\n}\n.i-Hospital-2:before {\n\tcontent: \"\\E9C4\";\n}\n.i-Hospital:before {\n\tcontent: \"\\E9C5\";\n}\n.i-Host:before {\n\tcontent: \"\\E9C6\";\n}\n.i-Hot-Dog:before {\n\tcontent: \"\\E9C7\";\n}\n.i-Hotel:before {\n\tcontent: \"\\E9C8\";\n}\n.i-Hour:before {\n\tcontent: \"\\E9C9\";\n}\n.i-Hub:before {\n\tcontent: \"\\E9CA\";\n}\n.i-Humor:before {\n\tcontent: \"\\E9CB\";\n}\n.i-Hurt:before {\n\tcontent: \"\\E9CC\";\n}\n.i-Ice-Cream:before {\n\tcontent: \"\\E9CD\";\n}\n.i-ICQ:before {\n\tcontent: \"\\E9CE\";\n}\n.i-ID-2:before {\n\tcontent: \"\\E9CF\";\n}\n.i-ID-3:before {\n\tcontent: \"\\E9D0\";\n}\n.i-ID-Card:before {\n\tcontent: \"\\E9D1\";\n}\n.i-Idea-2:before {\n\tcontent: \"\\E9D2\";\n}\n.i-Idea-3:before {\n\tcontent: \"\\E9D3\";\n}\n.i-Idea-4:before {\n\tcontent: \"\\E9D4\";\n}\n.i-Idea-5:before {\n\tcontent: \"\\E9D5\";\n}\n.i-Idea:before {\n\tcontent: \"\\E9D6\";\n}\n.i-Identification-Badge:before {\n\tcontent: \"\\E9D7\";\n}\n.i-ImDB:before {\n\tcontent: \"\\E9D8\";\n}\n.i-Inbox-Empty:before {\n\tcontent: \"\\E9D9\";\n}\n.i-Inbox-Forward:before {\n\tcontent: \"\\E9DA\";\n}\n.i-Inbox-Full:before {\n\tcontent: \"\\E9DB\";\n}\n.i-Inbox-Into:before {\n\tcontent: \"\\E9DC\";\n}\n.i-Inbox-Out:before {\n\tcontent: \"\\E9DD\";\n}\n.i-Inbox-Reply:before {\n\tcontent: \"\\E9DE\";\n}\n.i-Inbox:before {\n\tcontent: \"\\E9DF\";\n}\n.i-Increase-Inedit:before {\n\tcontent: \"\\E9E0\";\n}\n.i-Indent-FirstLine:before {\n\tcontent: \"\\E9E1\";\n}\n.i-Indent-LeftMargin:before {\n\tcontent: \"\\E9E2\";\n}\n.i-Indent-RightMargin:before {\n\tcontent: \"\\E9E3\";\n}\n.i-India:before {\n\tcontent: \"\\E9E4\";\n}\n.i-Info-Window:before {\n\tcontent: \"\\E9E5\";\n}\n.i-Information:before {\n\tcontent: \"\\E9E6\";\n}\n.i-Inifity:before {\n\tcontent: \"\\E9E7\";\n}\n.i-Instagram:before {\n\tcontent: \"\\E9E8\";\n}\n.i-Internet-2:before {\n\tcontent: \"\\E9E9\";\n}\n.i-Internet-Explorer:before {\n\tcontent: \"\\E9EA\";\n}\n.i-Internet-Smiley:before {\n\tcontent: \"\\E9EB\";\n}\n.i-Internet:before {\n\tcontent: \"\\E9EC\";\n}\n.i-iOS-Apple:before {\n\tcontent: \"\\E9ED\";\n}\n.i-Israel:before {\n\tcontent: \"\\E9EE\";\n}\n.i-Italic-Text:before {\n\tcontent: \"\\E9EF\";\n}\n.i-Jacket-2:before {\n\tcontent: \"\\E9F0\";\n}\n.i-Jacket:before {\n\tcontent: \"\\E9F1\";\n}\n.i-Jamaica:before {\n\tcontent: \"\\E9F2\";\n}\n.i-Japan:before {\n\tcontent: \"\\E9F3\";\n}\n.i-Japanese-Gate:before {\n\tcontent: \"\\E9F4\";\n}\n.i-Jeans:before {\n\tcontent: \"\\E9F5\";\n}\n.i-Jeep-2:before {\n\tcontent: \"\\E9F6\";\n}\n.i-Jeep:before {\n\tcontent: \"\\E9F7\";\n}\n.i-Jet:before {\n\tcontent: \"\\E9F8\";\n}\n.i-Joystick:before {\n\tcontent: \"\\E9F9\";\n}\n.i-Juice:before {\n\tcontent: \"\\E9FA\";\n}\n.i-Jump-Rope:before {\n\tcontent: \"\\E9FB\";\n}\n.i-Kangoroo:before {\n\tcontent: \"\\E9FC\";\n}\n.i-Kenya:before {\n\tcontent: \"\\E9FD\";\n}\n.i-Key-2:before {\n\tcontent: \"\\E9FE\";\n}\n.i-Key-3:before {\n\tcontent: \"\\E9FF\";\n}\n.i-Key-Lock:before {\n\tcontent: \"\\EA00\";\n}\n.i-Key:before {\n\tcontent: \"\\EA01\";\n}\n.i-Keyboard:before {\n\tcontent: \"\\EA02\";\n}\n.i-Keyboard3:before {\n\tcontent: \"\\EA03\";\n}\n.i-Keypad:before {\n\tcontent: \"\\EA04\";\n}\n.i-King-2:before {\n\tcontent: \"\\EA05\";\n}\n.i-King:before {\n\tcontent: \"\\EA06\";\n}\n.i-Kiss:before {\n\tcontent: \"\\EA07\";\n}\n.i-Knee:before {\n\tcontent: \"\\EA08\";\n}\n.i-Knife-2:before {\n\tcontent: \"\\EA09\";\n}\n.i-Knife:before {\n\tcontent: \"\\EA0A\";\n}\n.i-Knight:before {\n\tcontent: \"\\EA0B\";\n}\n.i-Koala:before {\n\tcontent: \"\\EA0C\";\n}\n.i-Korea:before {\n\tcontent: \"\\EA0D\";\n}\n.i-Lamp:before {\n\tcontent: \"\\EA0E\";\n}\n.i-Landscape-2:before {\n\tcontent: \"\\EA0F\";\n}\n.i-Landscape:before {\n\tcontent: \"\\EA10\";\n}\n.i-Lantern:before {\n\tcontent: \"\\EA11\";\n}\n.i-Laptop-2:before {\n\tcontent: \"\\EA12\";\n}\n.i-Laptop-3:before {\n\tcontent: \"\\EA13\";\n}\n.i-Laptop-Phone:before {\n\tcontent: \"\\EA14\";\n}\n.i-Laptop-Secure:before {\n\tcontent: \"\\EA15\";\n}\n.i-Laptop-Tablet:before {\n\tcontent: \"\\EA16\";\n}\n.i-Laptop:before {\n\tcontent: \"\\EA17\";\n}\n.i-Laser:before {\n\tcontent: \"\\EA18\";\n}\n.i-Last-FM:before {\n\tcontent: \"\\EA19\";\n}\n.i-Last:before {\n\tcontent: \"\\EA1A\";\n}\n.i-Laughing:before {\n\tcontent: \"\\EA1B\";\n}\n.i-Layer-1635:before {\n\tcontent: \"\\EA1C\";\n}\n.i-Layer-1646:before {\n\tcontent: \"\\EA1D\";\n}\n.i-Layer-Backward:before {\n\tcontent: \"\\EA1E\";\n}\n.i-Layer-Forward:before {\n\tcontent: \"\\EA1F\";\n}\n.i-Leafs-2:before {\n\tcontent: \"\\EA20\";\n}\n.i-Leafs:before {\n\tcontent: \"\\EA21\";\n}\n.i-Leaning-Tower:before {\n\tcontent: \"\\EA22\";\n}\n.i-Left--Right:before {\n\tcontent: \"\\EA23\";\n}\n.i-Left--Right3:before {\n\tcontent: \"\\EA24\";\n}\n.i-Left-2:before {\n\tcontent: \"\\EA25\";\n}\n.i-Left-3:before {\n\tcontent: \"\\EA26\";\n}\n.i-Left-4:before {\n\tcontent: \"\\EA27\";\n}\n.i-Left-ToRight:before {\n\tcontent: \"\\EA28\";\n}\n.i-Left:before {\n\tcontent: \"\\EA29\";\n}\n.i-Leg-2:before {\n\tcontent: \"\\EA2A\";\n}\n.i-Leg:before {\n\tcontent: \"\\EA2B\";\n}\n.i-Lego:before {\n\tcontent: \"\\EA2C\";\n}\n.i-Lemon:before {\n\tcontent: \"\\EA2D\";\n}\n.i-Len-2:before {\n\tcontent: \"\\EA2E\";\n}\n.i-Len-3:before {\n\tcontent: \"\\EA2F\";\n}\n.i-Len:before {\n\tcontent: \"\\EA30\";\n}\n.i-Leo-2:before {\n\tcontent: \"\\EA31\";\n}\n.i-Leo:before {\n\tcontent: \"\\EA32\";\n}\n.i-Leopard:before {\n\tcontent: \"\\EA33\";\n}\n.i-Lesbian:before {\n\tcontent: \"\\EA34\";\n}\n.i-Lesbians:before {\n\tcontent: \"\\EA35\";\n}\n.i-Letter-Close:before {\n\tcontent: \"\\EA36\";\n}\n.i-Letter-Open:before {\n\tcontent: \"\\EA37\";\n}\n.i-Letter-Sent:before {\n\tcontent: \"\\EA38\";\n}\n.i-Libra-2:before {\n\tcontent: \"\\EA39\";\n}\n.i-Libra:before {\n\tcontent: \"\\EA3A\";\n}\n.i-Library-2:before {\n\tcontent: \"\\EA3B\";\n}\n.i-Library:before {\n\tcontent: \"\\EA3C\";\n}\n.i-Life-Jacket:before {\n\tcontent: \"\\EA3D\";\n}\n.i-Life-Safer:before {\n\tcontent: \"\\EA3E\";\n}\n.i-Light-Bulb:before {\n\tcontent: \"\\EA3F\";\n}\n.i-Light-Bulb2:before {\n\tcontent: \"\\EA40\";\n}\n.i-Light-BulbLeaf:before {\n\tcontent: \"\\EA41\";\n}\n.i-Lighthouse:before {\n\tcontent: \"\\EA42\";\n}\n.i-Like-2:before {\n\tcontent: \"\\EA43\";\n}\n.i-Like:before {\n\tcontent: \"\\EA44\";\n}\n.i-Line-Chart:before {\n\tcontent: \"\\EA45\";\n}\n.i-Line-Chart2:before {\n\tcontent: \"\\EA46\";\n}\n.i-Line-Chart3:before {\n\tcontent: \"\\EA47\";\n}\n.i-Line-Chart4:before {\n\tcontent: \"\\EA48\";\n}\n.i-Line-Spacing:before {\n\tcontent: \"\\EA49\";\n}\n.i-Line-SpacingText:before {\n\tcontent: \"\\EA4A\";\n}\n.i-Link-2:before {\n\tcontent: \"\\EA4B\";\n}\n.i-Link:before {\n\tcontent: \"\\EA4C\";\n}\n.i-Linkedin-2:before {\n\tcontent: \"\\EA4D\";\n}\n.i-Linkedin:before {\n\tcontent: \"\\EA4E\";\n}\n.i-Linux:before {\n\tcontent: \"\\EA4F\";\n}\n.i-Lion:before {\n\tcontent: \"\\EA50\";\n}\n.i-Livejournal:before {\n\tcontent: \"\\EA51\";\n}\n.i-Loading-2:before {\n\tcontent: \"\\EA52\";\n}\n.i-Loading-3:before {\n\tcontent: \"\\EA53\";\n}\n.i-Loading-Window:before {\n\tcontent: \"\\EA54\";\n}\n.i-Loading:before {\n\tcontent: \"\\EA55\";\n}\n.i-Location-2:before {\n\tcontent: \"\\EA56\";\n}\n.i-Location:before {\n\tcontent: \"\\EA57\";\n}\n.i-Lock-2:before {\n\tcontent: \"\\EA58\";\n}\n.i-Lock-3:before {\n\tcontent: \"\\EA59\";\n}\n.i-Lock-User:before {\n\tcontent: \"\\EA5A\";\n}\n.i-Lock-Window:before {\n\tcontent: \"\\EA5B\";\n}\n.i-Lock:before {\n\tcontent: \"\\EA5C\";\n}\n.i-Lollipop-2:before {\n\tcontent: \"\\EA5D\";\n}\n.i-Lollipop-3:before {\n\tcontent: \"\\EA5E\";\n}\n.i-Lollipop:before {\n\tcontent: \"\\EA5F\";\n}\n.i-Loop:before {\n\tcontent: \"\\EA60\";\n}\n.i-Loud:before {\n\tcontent: \"\\EA61\";\n}\n.i-Loudspeaker:before {\n\tcontent: \"\\EA62\";\n}\n.i-Love-2:before {\n\tcontent: \"\\EA63\";\n}\n.i-Love-User:before {\n\tcontent: \"\\EA64\";\n}\n.i-Love-Window:before {\n\tcontent: \"\\EA65\";\n}\n.i-Love:before {\n\tcontent: \"\\EA66\";\n}\n.i-Lowercase-Text:before {\n\tcontent: \"\\EA67\";\n}\n.i-Luggafe-Front:before {\n\tcontent: \"\\EA68\";\n}\n.i-Luggage-2:before {\n\tcontent: \"\\EA69\";\n}\n.i-Macro:before {\n\tcontent: \"\\EA6A\";\n}\n.i-Magic-Wand:before {\n\tcontent: \"\\EA6B\";\n}\n.i-Magnet:before {\n\tcontent: \"\\EA6C\";\n}\n.i-Magnifi-Glass-:before {\n\tcontent: \"\\EA6D\";\n}\n.i-Magnifi-Glass:before {\n\tcontent: \"\\EA6E\";\n}\n.i-Magnifi-Glass2:before {\n\tcontent: \"\\EA6F\";\n}\n.i-Mail-2:before {\n\tcontent: \"\\EA70\";\n}\n.i-Mail-3:before {\n\tcontent: \"\\EA71\";\n}\n.i-Mail-Add:before {\n\tcontent: \"\\EA72\";\n}\n.i-Mail-Attachement:before {\n\tcontent: \"\\EA73\";\n}\n.i-Mail-Block:before {\n\tcontent: \"\\EA74\";\n}\n.i-Mail-Delete:before {\n\tcontent: \"\\EA75\";\n}\n.i-Mail-Favorite:before {\n\tcontent: \"\\EA76\";\n}\n.i-Mail-Forward:before {\n\tcontent: \"\\EA77\";\n}\n.i-Mail-Gallery:before {\n\tcontent: \"\\EA78\";\n}\n.i-Mail-Inbox:before {\n\tcontent: \"\\EA79\";\n}\n.i-Mail-Link:before {\n\tcontent: \"\\EA7A\";\n}\n.i-Mail-Lock:before {\n\tcontent: \"\\EA7B\";\n}\n.i-Mail-Love:before {\n\tcontent: \"\\EA7C\";\n}\n.i-Mail-Money:before {\n\tcontent: \"\\EA7D\";\n}\n.i-Mail-Open:before {\n\tcontent: \"\\EA7E\";\n}\n.i-Mail-Outbox:before {\n\tcontent: \"\\EA7F\";\n}\n.i-Mail-Password:before {\n\tcontent: \"\\EA80\";\n}\n.i-Mail-Photo:before {\n\tcontent: \"\\EA81\";\n}\n.i-Mail-Read:before {\n\tcontent: \"\\EA82\";\n}\n.i-Mail-Removex:before {\n\tcontent: \"\\EA83\";\n}\n.i-Mail-Reply:before {\n\tcontent: \"\\EA84\";\n}\n.i-Mail-ReplyAll:before {\n\tcontent: \"\\EA85\";\n}\n.i-Mail-Search:before {\n\tcontent: \"\\EA86\";\n}\n.i-Mail-Send:before {\n\tcontent: \"\\EA87\";\n}\n.i-Mail-Settings:before {\n\tcontent: \"\\EA88\";\n}\n.i-Mail-Unread:before {\n\tcontent: \"\\EA89\";\n}\n.i-Mail-Video:before {\n\tcontent: \"\\EA8A\";\n}\n.i-Mail-withAtSign:before {\n\tcontent: \"\\EA8B\";\n}\n.i-Mail-WithCursors:before {\n\tcontent: \"\\EA8C\";\n}\n.i-Mail:before {\n\tcontent: \"\\EA8D\";\n}\n.i-Mailbox-Empty:before {\n\tcontent: \"\\EA8E\";\n}\n.i-Mailbox-Full:before {\n\tcontent: \"\\EA8F\";\n}\n.i-Male-2:before {\n\tcontent: \"\\EA90\";\n}\n.i-Male-Sign:before {\n\tcontent: \"\\EA91\";\n}\n.i-Male:before {\n\tcontent: \"\\EA92\";\n}\n.i-MaleFemale:before {\n\tcontent: \"\\EA93\";\n}\n.i-Man-Sign:before {\n\tcontent: \"\\EA94\";\n}\n.i-Management:before {\n\tcontent: \"\\EA95\";\n}\n.i-Mans-Underwear:before {\n\tcontent: \"\\EA96\";\n}\n.i-Mans-Underwear2:before {\n\tcontent: \"\\EA97\";\n}\n.i-Map-Marker:before {\n\tcontent: \"\\EA98\";\n}\n.i-Map-Marker2:before {\n\tcontent: \"\\EA99\";\n}\n.i-Map-Marker3:before {\n\tcontent: \"\\EA9A\";\n}\n.i-Map:before {\n\tcontent: \"\\EA9B\";\n}\n.i-Map2:before {\n\tcontent: \"\\EA9C\";\n}\n.i-Marker-2:before {\n\tcontent: \"\\EA9D\";\n}\n.i-Marker-3:before {\n\tcontent: \"\\EA9E\";\n}\n.i-Marker:before {\n\tcontent: \"\\EA9F\";\n}\n.i-Martini-Glass:before {\n\tcontent: \"\\EAA0\";\n}\n.i-Mask:before {\n\tcontent: \"\\EAA1\";\n}\n.i-Master-Card:before {\n\tcontent: \"\\EAA2\";\n}\n.i-Maximize-Window:before {\n\tcontent: \"\\EAA3\";\n}\n.i-Maximize:before {\n\tcontent: \"\\EAA4\";\n}\n.i-Medal-2:before {\n\tcontent: \"\\EAA5\";\n}\n.i-Medal-3:before {\n\tcontent: \"\\EAA6\";\n}\n.i-Medal:before {\n\tcontent: \"\\EAA7\";\n}\n.i-Medical-Sign:before {\n\tcontent: \"\\EAA8\";\n}\n.i-Medicine-2:before {\n\tcontent: \"\\EAA9\";\n}\n.i-Medicine-3:before {\n\tcontent: \"\\EAAA\";\n}\n.i-Medicine:before {\n\tcontent: \"\\EAAB\";\n}\n.i-Megaphone:before {\n\tcontent: \"\\EAAC\";\n}\n.i-Memory-Card:before {\n\tcontent: \"\\EAAD\";\n}\n.i-Memory-Card2:before {\n\tcontent: \"\\EAAE\";\n}\n.i-Memory-Card3:before {\n\tcontent: \"\\EAAF\";\n}\n.i-Men:before {\n\tcontent: \"\\EAB0\";\n}\n.i-Menorah:before {\n\tcontent: \"\\EAB1\";\n}\n.i-Mens:before {\n\tcontent: \"\\EAB2\";\n}\n.i-Metacafe:before {\n\tcontent: \"\\EAB3\";\n}\n.i-Mexico:before {\n\tcontent: \"\\EAB4\";\n}\n.i-Mic:before {\n\tcontent: \"\\EAB5\";\n}\n.i-Microphone-2:before {\n\tcontent: \"\\EAB6\";\n}\n.i-Microphone-3:before {\n\tcontent: \"\\EAB7\";\n}\n.i-Microphone-4:before {\n\tcontent: \"\\EAB8\";\n}\n.i-Microphone-5:before {\n\tcontent: \"\\EAB9\";\n}\n.i-Microphone-6:before {\n\tcontent: \"\\EABA\";\n}\n.i-Microphone-7:before {\n\tcontent: \"\\EABB\";\n}\n.i-Microphone:before {\n\tcontent: \"\\EABC\";\n}\n.i-Microscope:before {\n\tcontent: \"\\EABD\";\n}\n.i-Milk-Bottle:before {\n\tcontent: \"\\EABE\";\n}\n.i-Mine:before {\n\tcontent: \"\\EABF\";\n}\n.i-Minimize-Maximize-Close-Window:before {\n\tcontent: \"\\EAC0\";\n}\n.i-Minimize-Window:before {\n\tcontent: \"\\EAC1\";\n}\n.i-Minimize:before {\n\tcontent: \"\\EAC2\";\n}\n.i-Mirror:before {\n\tcontent: \"\\EAC3\";\n}\n.i-Mixer:before {\n\tcontent: \"\\EAC4\";\n}\n.i-Mixx:before {\n\tcontent: \"\\EAC5\";\n}\n.i-Money-2:before {\n\tcontent: \"\\EAC6\";\n}\n.i-Money-Bag:before {\n\tcontent: \"\\EAC7\";\n}\n.i-Money-Smiley:before {\n\tcontent: \"\\EAC8\";\n}\n.i-Money:before {\n\tcontent: \"\\EAC9\";\n}\n.i-Monitor-2:before {\n\tcontent: \"\\EACA\";\n}\n.i-Monitor-3:before {\n\tcontent: \"\\EACB\";\n}\n.i-Monitor-4:before {\n\tcontent: \"\\EACC\";\n}\n.i-Monitor-5:before {\n\tcontent: \"\\EACD\";\n}\n.i-Monitor-Analytics:before {\n\tcontent: \"\\EACE\";\n}\n.i-Monitor-Laptop:before {\n\tcontent: \"\\EACF\";\n}\n.i-Monitor-phone:before {\n\tcontent: \"\\EAD0\";\n}\n.i-Monitor-Tablet:before {\n\tcontent: \"\\EAD1\";\n}\n.i-Monitor-Vertical:before {\n\tcontent: \"\\EAD2\";\n}\n.i-Monitor:before {\n\tcontent: \"\\EAD3\";\n}\n.i-Monitoring:before {\n\tcontent: \"\\EAD4\";\n}\n.i-Monkey:before {\n\tcontent: \"\\EAD5\";\n}\n.i-Monster:before {\n\tcontent: \"\\EAD6\";\n}\n.i-Morocco:before {\n\tcontent: \"\\EAD7\";\n}\n.i-Motorcycle:before {\n\tcontent: \"\\EAD8\";\n}\n.i-Mouse-2:before {\n\tcontent: \"\\EAD9\";\n}\n.i-Mouse-3:before {\n\tcontent: \"\\EADA\";\n}\n.i-Mouse-4:before {\n\tcontent: \"\\EADB\";\n}\n.i-Mouse-Pointer:before {\n\tcontent: \"\\EADC\";\n}\n.i-Mouse:before {\n\tcontent: \"\\EADD\";\n}\n.i-Moustache-Smiley:before {\n\tcontent: \"\\EADE\";\n}\n.i-Movie-Ticket:before {\n\tcontent: \"\\EADF\";\n}\n.i-Movie:before {\n\tcontent: \"\\EAE0\";\n}\n.i-Mp3-File:before {\n\tcontent: \"\\EAE1\";\n}\n.i-Museum:before {\n\tcontent: \"\\EAE2\";\n}\n.i-Mushroom:before {\n\tcontent: \"\\EAE3\";\n}\n.i-Music-Note:before {\n\tcontent: \"\\EAE4\";\n}\n.i-Music-Note2:before {\n\tcontent: \"\\EAE5\";\n}\n.i-Music-Note3:before {\n\tcontent: \"\\EAE6\";\n}\n.i-Music-Note4:before {\n\tcontent: \"\\EAE7\";\n}\n.i-Music-Player:before {\n\tcontent: \"\\EAE8\";\n}\n.i-Mustache-2:before {\n\tcontent: \"\\EAE9\";\n}\n.i-Mustache-3:before {\n\tcontent: \"\\EAEA\";\n}\n.i-Mustache-4:before {\n\tcontent: \"\\EAEB\";\n}\n.i-Mustache-5:before {\n\tcontent: \"\\EAEC\";\n}\n.i-Mustache-6:before {\n\tcontent: \"\\EAED\";\n}\n.i-Mustache-7:before {\n\tcontent: \"\\EAEE\";\n}\n.i-Mustache-8:before {\n\tcontent: \"\\EAEF\";\n}\n.i-Mustache:before {\n\tcontent: \"\\EAF0\";\n}\n.i-Mute:before {\n\tcontent: \"\\EAF1\";\n}\n.i-Myspace:before {\n\tcontent: \"\\EAF2\";\n}\n.i-Navigat-Start:before {\n\tcontent: \"\\EAF3\";\n}\n.i-Navigate-End:before {\n\tcontent: \"\\EAF4\";\n}\n.i-Navigation-LeftWindow:before {\n\tcontent: \"\\EAF5\";\n}\n.i-Navigation-RightWindow:before {\n\tcontent: \"\\EAF6\";\n}\n.i-Nepal:before {\n\tcontent: \"\\EAF7\";\n}\n.i-Netscape:before {\n\tcontent: \"\\EAF8\";\n}\n.i-Network-Window:before {\n\tcontent: \"\\EAF9\";\n}\n.i-Network:before {\n\tcontent: \"\\EAFA\";\n}\n.i-Neutron:before {\n\tcontent: \"\\EAFB\";\n}\n.i-New-Mail:before {\n\tcontent: \"\\EAFC\";\n}\n.i-New-Tab:before {\n\tcontent: \"\\EAFD\";\n}\n.i-Newspaper-2:before {\n\tcontent: \"\\EAFE\";\n}\n.i-Newspaper:before {\n\tcontent: \"\\EAFF\";\n}\n.i-Newsvine:before {\n\tcontent: \"\\EB00\";\n}\n.i-Next2:before {\n\tcontent: \"\\EB01\";\n}\n.i-Next-3:before {\n\tcontent: \"\\EB02\";\n}\n.i-Next-Music:before {\n\tcontent: \"\\EB03\";\n}\n.i-Next:before {\n\tcontent: \"\\EB04\";\n}\n.i-No-Battery:before {\n\tcontent: \"\\EB05\";\n}\n.i-No-Drop:before {\n\tcontent: \"\\EB06\";\n}\n.i-No-Flash:before {\n\tcontent: \"\\EB07\";\n}\n.i-No-Smoking:before {\n\tcontent: \"\\EB08\";\n}\n.i-Noose:before {\n\tcontent: \"\\EB09\";\n}\n.i-Normal-Text:before {\n\tcontent: \"\\EB0A\";\n}\n.i-Note:before {\n\tcontent: \"\\EB0B\";\n}\n.i-Notepad-2:before {\n\tcontent: \"\\EB0C\";\n}\n.i-Notepad:before {\n\tcontent: \"\\EB0D\";\n}\n.i-Nuclear:before {\n\tcontent: \"\\EB0E\";\n}\n.i-Numbering-List:before {\n\tcontent: \"\\EB0F\";\n}\n.i-Nurse:before {\n\tcontent: \"\\EB10\";\n}\n.i-Office-Lamp:before {\n\tcontent: \"\\EB11\";\n}\n.i-Office:before {\n\tcontent: \"\\EB12\";\n}\n.i-Oil:before {\n\tcontent: \"\\EB13\";\n}\n.i-Old-Camera:before {\n\tcontent: \"\\EB14\";\n}\n.i-Old-Cassette:before {\n\tcontent: \"\\EB15\";\n}\n.i-Old-Clock:before {\n\tcontent: \"\\EB16\";\n}\n.i-Old-Radio:before {\n\tcontent: \"\\EB17\";\n}\n.i-Old-Sticky:before {\n\tcontent: \"\\EB18\";\n}\n.i-Old-Sticky2:before {\n\tcontent: \"\\EB19\";\n}\n.i-Old-Telephone:before {\n\tcontent: \"\\EB1A\";\n}\n.i-Old-TV:before {\n\tcontent: \"\\EB1B\";\n}\n.i-On-Air:before {\n\tcontent: \"\\EB1C\";\n}\n.i-On-Off-2:before {\n\tcontent: \"\\EB1D\";\n}\n.i-On-Off-3:before {\n\tcontent: \"\\EB1E\";\n}\n.i-On-off:before {\n\tcontent: \"\\EB1F\";\n}\n.i-One-Finger:before {\n\tcontent: \"\\EB20\";\n}\n.i-One-FingerTouch:before {\n\tcontent: \"\\EB21\";\n}\n.i-One-Window:before {\n\tcontent: \"\\EB22\";\n}\n.i-Open-Banana:before {\n\tcontent: \"\\EB23\";\n}\n.i-Open-Book:before {\n\tcontent: \"\\EB24\";\n}\n.i-Opera-House:before {\n\tcontent: \"\\EB25\";\n}\n.i-Opera:before {\n\tcontent: \"\\EB26\";\n}\n.i-Optimization:before {\n\tcontent: \"\\EB27\";\n}\n.i-Orientation-2:before {\n\tcontent: \"\\EB28\";\n}\n.i-Orientation-3:before {\n\tcontent: \"\\EB29\";\n}\n.i-Orientation:before {\n\tcontent: \"\\EB2A\";\n}\n.i-Orkut:before {\n\tcontent: \"\\EB2B\";\n}\n.i-Ornament:before {\n\tcontent: \"\\EB2C\";\n}\n.i-Over-Time:before {\n\tcontent: \"\\EB2D\";\n}\n.i-Over-Time2:before {\n\tcontent: \"\\EB2E\";\n}\n.i-Owl:before {\n\tcontent: \"\\EB2F\";\n}\n.i-Pac-Man:before {\n\tcontent: \"\\EB30\";\n}\n.i-Paint-Brush:before {\n\tcontent: \"\\EB31\";\n}\n.i-Paint-Bucket:before {\n\tcontent: \"\\EB32\";\n}\n.i-Paintbrush:before {\n\tcontent: \"\\EB33\";\n}\n.i-Palette:before {\n\tcontent: \"\\EB34\";\n}\n.i-Palm-Tree:before {\n\tcontent: \"\\EB35\";\n}\n.i-Panda:before {\n\tcontent: \"\\EB36\";\n}\n.i-Panorama:before {\n\tcontent: \"\\EB37\";\n}\n.i-Pantheon:before {\n\tcontent: \"\\EB38\";\n}\n.i-Pantone:before {\n\tcontent: \"\\EB39\";\n}\n.i-Pants:before {\n\tcontent: \"\\EB3A\";\n}\n.i-Paper-Plane:before {\n\tcontent: \"\\EB3B\";\n}\n.i-Paper:before {\n\tcontent: \"\\EB3C\";\n}\n.i-Parasailing:before {\n\tcontent: \"\\EB3D\";\n}\n.i-Parrot:before {\n\tcontent: \"\\EB3E\";\n}\n.i-Password-2shopping:before {\n\tcontent: \"\\EB3F\";\n}\n.i-Password-Field:before {\n\tcontent: \"\\EB40\";\n}\n.i-Password-shopping:before {\n\tcontent: \"\\EB41\";\n}\n.i-Password:before {\n\tcontent: \"\\EB42\";\n}\n.i-pause-2:before {\n\tcontent: \"\\EB43\";\n}\n.i-Pause:before {\n\tcontent: \"\\EB44\";\n}\n.i-Paw:before {\n\tcontent: \"\\EB45\";\n}\n.i-Pawn:before {\n\tcontent: \"\\EB46\";\n}\n.i-Paypal:before {\n\tcontent: \"\\EB47\";\n}\n.i-Pen-2:before {\n\tcontent: \"\\EB48\";\n}\n.i-Pen-3:before {\n\tcontent: \"\\EB49\";\n}\n.i-Pen-4:before {\n\tcontent: \"\\EB4A\";\n}\n.i-Pen-5:before {\n\tcontent: \"\\EB4B\";\n}\n.i-Pen-6:before {\n\tcontent: \"\\EB4C\";\n}\n.i-Pen:before {\n\tcontent: \"\\EB4D\";\n}\n.i-Pencil-Ruler:before {\n\tcontent: \"\\EB4E\";\n}\n.i-Pencil:before {\n\tcontent: \"\\EB4F\";\n}\n.i-Penguin:before {\n\tcontent: \"\\EB50\";\n}\n.i-Pentagon:before {\n\tcontent: \"\\EB51\";\n}\n.i-People-onCloud:before {\n\tcontent: \"\\EB52\";\n}\n.i-Pepper-withFire:before {\n\tcontent: \"\\EB53\";\n}\n.i-Pepper:before {\n\tcontent: \"\\EB54\";\n}\n.i-Petrol:before {\n\tcontent: \"\\EB55\";\n}\n.i-Petronas-Tower:before {\n\tcontent: \"\\EB56\";\n}\n.i-Philipines:before {\n\tcontent: \"\\EB57\";\n}\n.i-Phone-2:before {\n\tcontent: \"\\EB58\";\n}\n.i-Phone-3:before {\n\tcontent: \"\\EB59\";\n}\n.i-Phone-3G:before {\n\tcontent: \"\\EB5A\";\n}\n.i-Phone-4G:before {\n\tcontent: \"\\EB5B\";\n}\n.i-Phone-Simcard:before {\n\tcontent: \"\\EB5C\";\n}\n.i-Phone-SMS:before {\n\tcontent: \"\\EB5D\";\n}\n.i-Phone-Wifi:before {\n\tcontent: \"\\EB5E\";\n}\n.i-Phone:before {\n\tcontent: \"\\EB5F\";\n}\n.i-Photo-2:before {\n\tcontent: \"\\EB60\";\n}\n.i-Photo-3:before {\n\tcontent: \"\\EB61\";\n}\n.i-Photo-Album:before {\n\tcontent: \"\\EB62\";\n}\n.i-Photo-Album2:before {\n\tcontent: \"\\EB63\";\n}\n.i-Photo-Album3:before {\n\tcontent: \"\\EB64\";\n}\n.i-Photo:before {\n\tcontent: \"\\EB65\";\n}\n.i-Photos:before {\n\tcontent: \"\\EB66\";\n}\n.i-Physics:before {\n\tcontent: \"\\EB67\";\n}\n.i-Pi:before {\n\tcontent: \"\\EB68\";\n}\n.i-Piano:before {\n\tcontent: \"\\EB69\";\n}\n.i-Picasa:before {\n\tcontent: \"\\EB6A\";\n}\n.i-Pie-Chart:before {\n\tcontent: \"\\EB6B\";\n}\n.i-Pie-Chart2:before {\n\tcontent: \"\\EB6C\";\n}\n.i-Pie-Chart3:before {\n\tcontent: \"\\EB6D\";\n}\n.i-Pilates-2:before {\n\tcontent: \"\\EB6E\";\n}\n.i-Pilates-3:before {\n\tcontent: \"\\EB6F\";\n}\n.i-Pilates:before {\n\tcontent: \"\\EB70\";\n}\n.i-Pilot:before {\n\tcontent: \"\\EB71\";\n}\n.i-Pinch:before {\n\tcontent: \"\\EB72\";\n}\n.i-Ping-Pong:before {\n\tcontent: \"\\EB73\";\n}\n.i-Pinterest:before {\n\tcontent: \"\\EB74\";\n}\n.i-Pipe:before {\n\tcontent: \"\\EB75\";\n}\n.i-Pipette:before {\n\tcontent: \"\\EB76\";\n}\n.i-Piramids:before {\n\tcontent: \"\\EB77\";\n}\n.i-Pisces-2:before {\n\tcontent: \"\\EB78\";\n}\n.i-Pisces:before {\n\tcontent: \"\\EB79\";\n}\n.i-Pizza-Slice:before {\n\tcontent: \"\\EB7A\";\n}\n.i-Pizza:before {\n\tcontent: \"\\EB7B\";\n}\n.i-Plane-2:before {\n\tcontent: \"\\EB7C\";\n}\n.i-Plane:before {\n\tcontent: \"\\EB7D\";\n}\n.i-Plant:before {\n\tcontent: \"\\EB7E\";\n}\n.i-Plasmid:before {\n\tcontent: \"\\EB7F\";\n}\n.i-Plaster:before {\n\tcontent: \"\\EB80\";\n}\n.i-Plastic-CupPhone:before {\n\tcontent: \"\\EB81\";\n}\n.i-Plastic-CupPhone2:before {\n\tcontent: \"\\EB82\";\n}\n.i-Plate:before {\n\tcontent: \"\\EB83\";\n}\n.i-Plates:before {\n\tcontent: \"\\EB84\";\n}\n.i-Plaxo:before {\n\tcontent: \"\\EB85\";\n}\n.i-Play-Music:before {\n\tcontent: \"\\EB86\";\n}\n.i-Plug-In:before {\n\tcontent: \"\\EB87\";\n}\n.i-Plug-In2:before {\n\tcontent: \"\\EB88\";\n}\n.i-Plurk:before {\n\tcontent: \"\\EB89\";\n}\n.i-Pointer:before {\n\tcontent: \"\\EB8A\";\n}\n.i-Poland:before {\n\tcontent: \"\\EB8B\";\n}\n.i-Police-Man:before {\n\tcontent: \"\\EB8C\";\n}\n.i-Police-Station:before {\n\tcontent: \"\\EB8D\";\n}\n.i-Police-Woman:before {\n\tcontent: \"\\EB8E\";\n}\n.i-Police:before {\n\tcontent: \"\\EB8F\";\n}\n.i-Polo-Shirt:before {\n\tcontent: \"\\EB90\";\n}\n.i-Portrait:before {\n\tcontent: \"\\EB91\";\n}\n.i-Portugal:before {\n\tcontent: \"\\EB92\";\n}\n.i-Post-Mail:before {\n\tcontent: \"\\EB93\";\n}\n.i-Post-Mail2:before {\n\tcontent: \"\\EB94\";\n}\n.i-Post-Office:before {\n\tcontent: \"\\EB95\";\n}\n.i-Post-Sign:before {\n\tcontent: \"\\EB96\";\n}\n.i-Post-Sign2ways:before {\n\tcontent: \"\\EB97\";\n}\n.i-Posterous:before {\n\tcontent: \"\\EB98\";\n}\n.i-Pound-Sign:before {\n\tcontent: \"\\EB99\";\n}\n.i-Pound-Sign2:before {\n\tcontent: \"\\EB9A\";\n}\n.i-Pound:before {\n\tcontent: \"\\EB9B\";\n}\n.i-Power-2:before {\n\tcontent: \"\\EB9C\";\n}\n.i-Power-3:before {\n\tcontent: \"\\EB9D\";\n}\n.i-Power-Cable:before {\n\tcontent: \"\\EB9E\";\n}\n.i-Power-Station:before {\n\tcontent: \"\\EB9F\";\n}\n.i-Power:before {\n\tcontent: \"\\EBA0\";\n}\n.i-Prater:before {\n\tcontent: \"\\EBA1\";\n}\n.i-Present:before {\n\tcontent: \"\\EBA2\";\n}\n.i-Presents:before {\n\tcontent: \"\\EBA3\";\n}\n.i-Press:before {\n\tcontent: \"\\EBA4\";\n}\n.i-Preview:before {\n\tcontent: \"\\EBA5\";\n}\n.i-Previous:before {\n\tcontent: \"\\EBA6\";\n}\n.i-Pricing:before {\n\tcontent: \"\\EBA7\";\n}\n.i-Printer:before {\n\tcontent: \"\\EBA8\";\n}\n.i-Professor:before {\n\tcontent: \"\\EBA9\";\n}\n.i-Profile:before {\n\tcontent: \"\\EBAA\";\n}\n.i-Project:before {\n\tcontent: \"\\EBAB\";\n}\n.i-Projector-2:before {\n\tcontent: \"\\EBAC\";\n}\n.i-Projector:before {\n\tcontent: \"\\EBAD\";\n}\n.i-Pulse:before {\n\tcontent: \"\\EBAE\";\n}\n.i-Pumpkin:before {\n\tcontent: \"\\EBAF\";\n}\n.i-Punk:before {\n\tcontent: \"\\EBB0\";\n}\n.i-Punker:before {\n\tcontent: \"\\EBB1\";\n}\n.i-Puzzle:before {\n\tcontent: \"\\EBB2\";\n}\n.i-QIK:before {\n\tcontent: \"\\EBB3\";\n}\n.i-QR-Code:before {\n\tcontent: \"\\EBB4\";\n}\n.i-Queen-2:before {\n\tcontent: \"\\EBB5\";\n}\n.i-Queen:before {\n\tcontent: \"\\EBB6\";\n}\n.i-Quill-2:before {\n\tcontent: \"\\EBB7\";\n}\n.i-Quill-3:before {\n\tcontent: \"\\EBB8\";\n}\n.i-Quill:before {\n\tcontent: \"\\EBB9\";\n}\n.i-Quotes-2:before {\n\tcontent: \"\\EBBA\";\n}\n.i-Quotes:before {\n\tcontent: \"\\EBBB\";\n}\n.i-Radio:before {\n\tcontent: \"\\EBBC\";\n}\n.i-Radioactive:before {\n\tcontent: \"\\EBBD\";\n}\n.i-Rafting:before {\n\tcontent: \"\\EBBE\";\n}\n.i-Rain-Drop:before {\n\tcontent: \"\\EBBF\";\n}\n.i-Rainbow-2:before {\n\tcontent: \"\\EBC0\";\n}\n.i-Rainbow:before {\n\tcontent: \"\\EBC1\";\n}\n.i-Ram:before {\n\tcontent: \"\\EBC2\";\n}\n.i-Razzor-Blade:before {\n\tcontent: \"\\EBC3\";\n}\n.i-Receipt-2:before {\n\tcontent: \"\\EBC4\";\n}\n.i-Receipt-3:before {\n\tcontent: \"\\EBC5\";\n}\n.i-Receipt-4:before {\n\tcontent: \"\\EBC6\";\n}\n.i-Receipt:before {\n\tcontent: \"\\EBC7\";\n}\n.i-Record2:before {\n\tcontent: \"\\EBC8\";\n}\n.i-Record-3:before {\n\tcontent: \"\\EBC9\";\n}\n.i-Record-Music:before {\n\tcontent: \"\\EBCA\";\n}\n.i-Record:before {\n\tcontent: \"\\EBCB\";\n}\n.i-Recycling-2:before {\n\tcontent: \"\\EBCC\";\n}\n.i-Recycling:before {\n\tcontent: \"\\EBCD\";\n}\n.i-Reddit:before {\n\tcontent: \"\\EBCE\";\n}\n.i-Redhat:before {\n\tcontent: \"\\EBCF\";\n}\n.i-Redirect:before {\n\tcontent: \"\\EBD0\";\n}\n.i-Redo:before {\n\tcontent: \"\\EBD1\";\n}\n.i-Reel:before {\n\tcontent: \"\\EBD2\";\n}\n.i-Refinery:before {\n\tcontent: \"\\EBD3\";\n}\n.i-Refresh-Window:before {\n\tcontent: \"\\EBD4\";\n}\n.i-Refresh:before {\n\tcontent: \"\\EBD5\";\n}\n.i-Reload-2:before {\n\tcontent: \"\\EBD6\";\n}\n.i-Reload-3:before {\n\tcontent: \"\\EBD7\";\n}\n.i-Reload:before {\n\tcontent: \"\\EBD8\";\n}\n.i-Remote-Controll:before {\n\tcontent: \"\\EBD9\";\n}\n.i-Remote-Controll2:before {\n\tcontent: \"\\EBDA\";\n}\n.i-Remove-Bag:before {\n\tcontent: \"\\EBDB\";\n}\n.i-Remove-Basket:before {\n\tcontent: \"\\EBDC\";\n}\n.i-Remove-Cart:before {\n\tcontent: \"\\EBDD\";\n}\n.i-Remove-File:before {\n\tcontent: \"\\EBDE\";\n}\n.i-Remove-User:before {\n\tcontent: \"\\EBDF\";\n}\n.i-Remove-Window:before {\n\tcontent: \"\\EBE0\";\n}\n.i-Remove:before {\n\tcontent: \"\\EBE1\";\n}\n.i-Rename:before {\n\tcontent: \"\\EBE2\";\n}\n.i-Repair:before {\n\tcontent: \"\\EBE3\";\n}\n.i-Repeat-2:before {\n\tcontent: \"\\EBE4\";\n}\n.i-Repeat-3:before {\n\tcontent: \"\\EBE5\";\n}\n.i-Repeat-4:before {\n\tcontent: \"\\EBE6\";\n}\n.i-Repeat-5:before {\n\tcontent: \"\\EBE7\";\n}\n.i-Repeat-6:before {\n\tcontent: \"\\EBE8\";\n}\n.i-Repeat-7:before {\n\tcontent: \"\\EBE9\";\n}\n.i-Repeat:before {\n\tcontent: \"\\EBEA\";\n}\n.i-Reset:before {\n\tcontent: \"\\EBEB\";\n}\n.i-Resize:before {\n\tcontent: \"\\EBEC\";\n}\n.i-Restore-Window:before {\n\tcontent: \"\\EBED\";\n}\n.i-Retouching:before {\n\tcontent: \"\\EBEE\";\n}\n.i-Retro-Camera:before {\n\tcontent: \"\\EBEF\";\n}\n.i-Retro:before {\n\tcontent: \"\\EBF0\";\n}\n.i-Retweet:before {\n\tcontent: \"\\EBF1\";\n}\n.i-Reverbnation:before {\n\tcontent: \"\\EBF2\";\n}\n.i-Rewind:before {\n\tcontent: \"\\EBF3\";\n}\n.i-RGB:before {\n\tcontent: \"\\EBF4\";\n}\n.i-Ribbon-2:before {\n\tcontent: \"\\EBF5\";\n}\n.i-Ribbon-3:before {\n\tcontent: \"\\EBF6\";\n}\n.i-Ribbon:before {\n\tcontent: \"\\EBF7\";\n}\n.i-Right-2:before {\n\tcontent: \"\\EBF8\";\n}\n.i-Right-3:before {\n\tcontent: \"\\EBF9\";\n}\n.i-Right-4:before {\n\tcontent: \"\\EBFA\";\n}\n.i-Right-ToLeft:before {\n\tcontent: \"\\EBFB\";\n}\n.i-Right:before {\n\tcontent: \"\\EBFC\";\n}\n.i-Road-2:before {\n\tcontent: \"\\EBFD\";\n}\n.i-Road-3:before {\n\tcontent: \"\\EBFE\";\n}\n.i-Road:before {\n\tcontent: \"\\EBFF\";\n}\n.i-Robot-2:before {\n\tcontent: \"\\EC00\";\n}\n.i-Robot:before {\n\tcontent: \"\\EC01\";\n}\n.i-Rock-andRoll:before {\n\tcontent: \"\\EC02\";\n}\n.i-Rocket:before {\n\tcontent: \"\\EC03\";\n}\n.i-Roller:before {\n\tcontent: \"\\EC04\";\n}\n.i-Roof:before {\n\tcontent: \"\\EC05\";\n}\n.i-Rook:before {\n\tcontent: \"\\EC06\";\n}\n.i-Rotate-Gesture:before {\n\tcontent: \"\\EC07\";\n}\n.i-Rotate-Gesture2:before {\n\tcontent: \"\\EC08\";\n}\n.i-Rotate-Gesture3:before {\n\tcontent: \"\\EC09\";\n}\n.i-Rotation-390:before {\n\tcontent: \"\\EC0A\";\n}\n.i-Rotation:before {\n\tcontent: \"\\EC0B\";\n}\n.i-Router-2:before {\n\tcontent: \"\\EC0C\";\n}\n.i-Router:before {\n\tcontent: \"\\EC0D\";\n}\n.i-RSS:before {\n\tcontent: \"\\EC0E\";\n}\n.i-Ruler-2:before {\n\tcontent: \"\\EC0F\";\n}\n.i-Ruler:before {\n\tcontent: \"\\EC10\";\n}\n.i-Running-Shoes:before {\n\tcontent: \"\\EC11\";\n}\n.i-Running:before {\n\tcontent: \"\\EC12\";\n}\n.i-Safari:before {\n\tcontent: \"\\EC13\";\n}\n.i-Safe-Box:before {\n\tcontent: \"\\EC14\";\n}\n.i-Safe-Box2:before {\n\tcontent: \"\\EC15\";\n}\n.i-Safety-PinClose:before {\n\tcontent: \"\\EC16\";\n}\n.i-Safety-PinOpen:before {\n\tcontent: \"\\EC17\";\n}\n.i-Sagittarus-2:before {\n\tcontent: \"\\EC18\";\n}\n.i-Sagittarus:before {\n\tcontent: \"\\EC19\";\n}\n.i-Sailing-Ship:before {\n\tcontent: \"\\EC1A\";\n}\n.i-Sand-watch:before {\n\tcontent: \"\\EC1B\";\n}\n.i-Sand-watch2:before {\n\tcontent: \"\\EC1C\";\n}\n.i-Santa-Claus:before {\n\tcontent: \"\\EC1D\";\n}\n.i-Santa-Claus2:before {\n\tcontent: \"\\EC1E\";\n}\n.i-Santa-onSled:before {\n\tcontent: \"\\EC1F\";\n}\n.i-Satelite-2:before {\n\tcontent: \"\\EC20\";\n}\n.i-Satelite:before {\n\tcontent: \"\\EC21\";\n}\n.i-Save-Window:before {\n\tcontent: \"\\EC22\";\n}\n.i-Save:before {\n\tcontent: \"\\EC23\";\n}\n.i-Saw:before {\n\tcontent: \"\\EC24\";\n}\n.i-Saxophone:before {\n\tcontent: \"\\EC25\";\n}\n.i-Scale:before {\n\tcontent: \"\\EC26\";\n}\n.i-Scarf:before {\n\tcontent: \"\\EC27\";\n}\n.i-Scissor:before {\n\tcontent: \"\\EC28\";\n}\n.i-Scooter-Front:before {\n\tcontent: \"\\EC29\";\n}\n.i-Scooter:before {\n\tcontent: \"\\EC2A\";\n}\n.i-Scorpio-2:before {\n\tcontent: \"\\EC2B\";\n}\n.i-Scorpio:before {\n\tcontent: \"\\EC2C\";\n}\n.i-Scotland:before {\n\tcontent: \"\\EC2D\";\n}\n.i-Screwdriver:before {\n\tcontent: \"\\EC2E\";\n}\n.i-Scroll-Fast:before {\n\tcontent: \"\\EC2F\";\n}\n.i-Scroll:before {\n\tcontent: \"\\EC30\";\n}\n.i-Scroller-2:before {\n\tcontent: \"\\EC31\";\n}\n.i-Scroller:before {\n\tcontent: \"\\EC32\";\n}\n.i-Sea-Dog:before {\n\tcontent: \"\\EC33\";\n}\n.i-Search-onCloud:before {\n\tcontent: \"\\EC34\";\n}\n.i-Search-People:before {\n\tcontent: \"\\EC35\";\n}\n.i-secound:before {\n\tcontent: \"\\EC36\";\n}\n.i-secound2:before {\n\tcontent: \"\\EC37\";\n}\n.i-Security-Block:before {\n\tcontent: \"\\EC38\";\n}\n.i-Security-Bug:before {\n\tcontent: \"\\EC39\";\n}\n.i-Security-Camera:before {\n\tcontent: \"\\EC3A\";\n}\n.i-Security-Check:before {\n\tcontent: \"\\EC3B\";\n}\n.i-Security-Settings:before {\n\tcontent: \"\\EC3C\";\n}\n.i-Security-Smiley:before {\n\tcontent: \"\\EC3D\";\n}\n.i-Securiy-Remove:before {\n\tcontent: \"\\EC3E\";\n}\n.i-Seed:before {\n\tcontent: \"\\EC3F\";\n}\n.i-Selfie:before {\n\tcontent: \"\\EC40\";\n}\n.i-Serbia:before {\n\tcontent: \"\\EC41\";\n}\n.i-Server-2:before {\n\tcontent: \"\\EC42\";\n}\n.i-Server:before {\n\tcontent: \"\\EC43\";\n}\n.i-Servers:before {\n\tcontent: \"\\EC44\";\n}\n.i-Settings-Window:before {\n\tcontent: \"\\EC45\";\n}\n.i-Sewing-Machine:before {\n\tcontent: \"\\EC46\";\n}\n.i-Sexual:before {\n\tcontent: \"\\EC47\";\n}\n.i-Share-onCloud:before {\n\tcontent: \"\\EC48\";\n}\n.i-Share-Window:before {\n\tcontent: \"\\EC49\";\n}\n.i-Share:before {\n\tcontent: \"\\EC4A\";\n}\n.i-Sharethis:before {\n\tcontent: \"\\EC4B\";\n}\n.i-Shark:before {\n\tcontent: \"\\EC4C\";\n}\n.i-Sheep:before {\n\tcontent: \"\\EC4D\";\n}\n.i-Sheriff-Badge:before {\n\tcontent: \"\\EC4E\";\n}\n.i-Shield:before {\n\tcontent: \"\\EC4F\";\n}\n.i-Ship-2:before {\n\tcontent: \"\\EC50\";\n}\n.i-Ship:before {\n\tcontent: \"\\EC51\";\n}\n.i-Shirt:before {\n\tcontent: \"\\EC52\";\n}\n.i-Shoes-2:before {\n\tcontent: \"\\EC53\";\n}\n.i-Shoes-3:before {\n\tcontent: \"\\EC54\";\n}\n.i-Shoes:before {\n\tcontent: \"\\EC55\";\n}\n.i-Shop-2:before {\n\tcontent: \"\\EC56\";\n}\n.i-Shop-3:before {\n\tcontent: \"\\EC57\";\n}\n.i-Shop-4:before {\n\tcontent: \"\\EC58\";\n}\n.i-Shop:before {\n\tcontent: \"\\EC59\";\n}\n.i-Shopping-Bag:before {\n\tcontent: \"\\EC5A\";\n}\n.i-Shopping-Basket:before {\n\tcontent: \"\\EC5B\";\n}\n.i-Shopping-Cart:before {\n\tcontent: \"\\EC5C\";\n}\n.i-Short-Pants:before {\n\tcontent: \"\\EC5D\";\n}\n.i-Shoutwire:before {\n\tcontent: \"\\EC5E\";\n}\n.i-Shovel:before {\n\tcontent: \"\\EC5F\";\n}\n.i-Shuffle-2:before {\n\tcontent: \"\\EC60\";\n}\n.i-Shuffle-3:before {\n\tcontent: \"\\EC61\";\n}\n.i-Shuffle-4:before {\n\tcontent: \"\\EC62\";\n}\n.i-Shuffle:before {\n\tcontent: \"\\EC63\";\n}\n.i-Shutter:before {\n\tcontent: \"\\EC64\";\n}\n.i-Sidebar-Window:before {\n\tcontent: \"\\EC65\";\n}\n.i-Signal:before {\n\tcontent: \"\\EC66\";\n}\n.i-Singapore:before {\n\tcontent: \"\\EC67\";\n}\n.i-Skate-Shoes:before {\n\tcontent: \"\\EC68\";\n}\n.i-Skateboard-2:before {\n\tcontent: \"\\EC69\";\n}\n.i-Skateboard:before {\n\tcontent: \"\\EC6A\";\n}\n.i-Skeleton:before {\n\tcontent: \"\\EC6B\";\n}\n.i-Ski:before {\n\tcontent: \"\\EC6C\";\n}\n.i-Skirt:before {\n\tcontent: \"\\EC6D\";\n}\n.i-Skrill:before {\n\tcontent: \"\\EC6E\";\n}\n.i-Skull:before {\n\tcontent: \"\\EC6F\";\n}\n.i-Skydiving:before {\n\tcontent: \"\\EC70\";\n}\n.i-Skype:before {\n\tcontent: \"\\EC71\";\n}\n.i-Sled-withGifts:before {\n\tcontent: \"\\EC72\";\n}\n.i-Sled:before {\n\tcontent: \"\\EC73\";\n}\n.i-Sleeping:before {\n\tcontent: \"\\EC74\";\n}\n.i-Sleet:before {\n\tcontent: \"\\EC75\";\n}\n.i-Slippers:before {\n\tcontent: \"\\EC76\";\n}\n.i-Smart:before {\n\tcontent: \"\\EC77\";\n}\n.i-Smartphone-2:before {\n\tcontent: \"\\EC78\";\n}\n.i-Smartphone-3:before {\n\tcontent: \"\\EC79\";\n}\n.i-Smartphone-4:before {\n\tcontent: \"\\EC7A\";\n}\n.i-Smartphone-Secure:before {\n\tcontent: \"\\EC7B\";\n}\n.i-Smartphone:before {\n\tcontent: \"\\EC7C\";\n}\n.i-Smile:before {\n\tcontent: \"\\EC7D\";\n}\n.i-Smoking-Area:before {\n\tcontent: \"\\EC7E\";\n}\n.i-Smoking-Pipe:before {\n\tcontent: \"\\EC7F\";\n}\n.i-Snake:before {\n\tcontent: \"\\EC80\";\n}\n.i-Snorkel:before {\n\tcontent: \"\\EC81\";\n}\n.i-Snow-2:before {\n\tcontent: \"\\EC82\";\n}\n.i-Snow-Dome:before {\n\tcontent: \"\\EC83\";\n}\n.i-Snow-Storm:before {\n\tcontent: \"\\EC84\";\n}\n.i-Snow:before {\n\tcontent: \"\\EC85\";\n}\n.i-Snowflake-2:before {\n\tcontent: \"\\EC86\";\n}\n.i-Snowflake-3:before {\n\tcontent: \"\\EC87\";\n}\n.i-Snowflake-4:before {\n\tcontent: \"\\EC88\";\n}\n.i-Snowflake:before {\n\tcontent: \"\\EC89\";\n}\n.i-Snowman:before {\n\tcontent: \"\\EC8A\";\n}\n.i-Soccer-Ball:before {\n\tcontent: \"\\EC8B\";\n}\n.i-Soccer-Shoes:before {\n\tcontent: \"\\EC8C\";\n}\n.i-Socks:before {\n\tcontent: \"\\EC8D\";\n}\n.i-Solar:before {\n\tcontent: \"\\EC8E\";\n}\n.i-Sound-Wave:before {\n\tcontent: \"\\EC8F\";\n}\n.i-Sound:before {\n\tcontent: \"\\EC90\";\n}\n.i-Soundcloud:before {\n\tcontent: \"\\EC91\";\n}\n.i-Soup:before {\n\tcontent: \"\\EC92\";\n}\n.i-South-Africa:before {\n\tcontent: \"\\EC93\";\n}\n.i-Space-Needle:before {\n\tcontent: \"\\EC94\";\n}\n.i-Spain:before {\n\tcontent: \"\\EC95\";\n}\n.i-Spam-Mail:before {\n\tcontent: \"\\EC96\";\n}\n.i-Speach-Bubble:before {\n\tcontent: \"\\EC97\";\n}\n.i-Speach-Bubble2:before {\n\tcontent: \"\\EC98\";\n}\n.i-Speach-Bubble3:before {\n\tcontent: \"\\EC99\";\n}\n.i-Speach-Bubble4:before {\n\tcontent: \"\\EC9A\";\n}\n.i-Speach-Bubble5:before {\n\tcontent: \"\\EC9B\";\n}\n.i-Speach-Bubble6:before {\n\tcontent: \"\\EC9C\";\n}\n.i-Speach-Bubble7:before {\n\tcontent: \"\\EC9D\";\n}\n.i-Speach-Bubble8:before {\n\tcontent: \"\\EC9E\";\n}\n.i-Speach-Bubble9:before {\n\tcontent: \"\\EC9F\";\n}\n.i-Speach-Bubble10:before {\n\tcontent: \"\\ECA0\";\n}\n.i-Speach-Bubble11:before {\n\tcontent: \"\\ECA1\";\n}\n.i-Speach-Bubble12:before {\n\tcontent: \"\\ECA2\";\n}\n.i-Speach-Bubble13:before {\n\tcontent: \"\\ECA3\";\n}\n.i-Speach-BubbleAsking:before {\n\tcontent: \"\\ECA4\";\n}\n.i-Speach-BubbleComic:before {\n\tcontent: \"\\ECA5\";\n}\n.i-Speach-BubbleComic2:before {\n\tcontent: \"\\ECA6\";\n}\n.i-Speach-BubbleComic3:before {\n\tcontent: \"\\ECA7\";\n}\n.i-Speach-BubbleComic4:before {\n\tcontent: \"\\ECA8\";\n}\n.i-Speach-BubbleDialog:before {\n\tcontent: \"\\ECA9\";\n}\n.i-Speach-Bubbles:before {\n\tcontent: \"\\ECAA\";\n}\n.i-Speak-2:before {\n\tcontent: \"\\ECAB\";\n}\n.i-Speak:before {\n\tcontent: \"\\ECAC\";\n}\n.i-Speaker-2:before {\n\tcontent: \"\\ECAD\";\n}\n.i-Speaker:before {\n\tcontent: \"\\ECAE\";\n}\n.i-Spell-Check:before {\n\tcontent: \"\\ECAF\";\n}\n.i-Spell-CheckABC:before {\n\tcontent: \"\\ECB0\";\n}\n.i-Spermium:before {\n\tcontent: \"\\ECB1\";\n}\n.i-Spider:before {\n\tcontent: \"\\ECB2\";\n}\n.i-Spiderweb:before {\n\tcontent: \"\\ECB3\";\n}\n.i-Split-FourSquareWindow:before {\n\tcontent: \"\\ECB4\";\n}\n.i-Split-Horizontal:before {\n\tcontent: \"\\ECB5\";\n}\n.i-Split-Horizontal2Window:before {\n\tcontent: \"\\ECB6\";\n}\n.i-Split-Vertical:before {\n\tcontent: \"\\ECB7\";\n}\n.i-Split-Vertical2:before {\n\tcontent: \"\\ECB8\";\n}\n.i-Split-Window:before {\n\tcontent: \"\\ECB9\";\n}\n.i-Spoder:before {\n\tcontent: \"\\ECBA\";\n}\n.i-Spoon:before {\n\tcontent: \"\\ECBB\";\n}\n.i-Sport-Mode:before {\n\tcontent: \"\\ECBC\";\n}\n.i-Sports-Clothings1:before {\n\tcontent: \"\\ECBD\";\n}\n.i-Sports-Clothings2:before {\n\tcontent: \"\\ECBE\";\n}\n.i-Sports-Shirt:before {\n\tcontent: \"\\ECBF\";\n}\n.i-Spot:before {\n\tcontent: \"\\ECC0\";\n}\n.i-Spray:before {\n\tcontent: \"\\ECC1\";\n}\n.i-Spread:before {\n\tcontent: \"\\ECC2\";\n}\n.i-Spring:before {\n\tcontent: \"\\ECC3\";\n}\n.i-Spurl:before {\n\tcontent: \"\\ECC4\";\n}\n.i-Spy:before {\n\tcontent: \"\\ECC5\";\n}\n.i-Squirrel:before {\n\tcontent: \"\\ECC6\";\n}\n.i-SSL:before {\n\tcontent: \"\\ECC7\";\n}\n.i-St-BasilsCathedral:before {\n\tcontent: \"\\ECC8\";\n}\n.i-St-PaulsCathedral:before {\n\tcontent: \"\\ECC9\";\n}\n.i-Stamp-2:before {\n\tcontent: \"\\ECCA\";\n}\n.i-Stamp:before {\n\tcontent: \"\\ECCB\";\n}\n.i-Stapler:before {\n\tcontent: \"\\ECCC\";\n}\n.i-Star-Track:before {\n\tcontent: \"\\ECCD\";\n}\n.i-Star:before {\n\tcontent: \"\\ECCE\";\n}\n.i-Starfish:before {\n\tcontent: \"\\ECCF\";\n}\n.i-Start2:before {\n\tcontent: \"\\ECD0\";\n}\n.i-Start-3:before {\n\tcontent: \"\\ECD1\";\n}\n.i-Start-ways:before {\n\tcontent: \"\\ECD2\";\n}\n.i-Start:before {\n\tcontent: \"\\ECD3\";\n}\n.i-Statistic:before {\n\tcontent: \"\\ECD4\";\n}\n.i-Stethoscope:before {\n\tcontent: \"\\ECD5\";\n}\n.i-stop--2:before {\n\tcontent: \"\\ECD6\";\n}\n.i-Stop-Music:before {\n\tcontent: \"\\ECD7\";\n}\n.i-Stop:before {\n\tcontent: \"\\ECD8\";\n}\n.i-Stopwatch-2:before {\n\tcontent: \"\\ECD9\";\n}\n.i-Stopwatch:before {\n\tcontent: \"\\ECDA\";\n}\n.i-Storm:before {\n\tcontent: \"\\ECDB\";\n}\n.i-Street-View:before {\n\tcontent: \"\\ECDC\";\n}\n.i-Street-View2:before {\n\tcontent: \"\\ECDD\";\n}\n.i-Strikethrough-Text:before {\n\tcontent: \"\\ECDE\";\n}\n.i-Stroller:before {\n\tcontent: \"\\ECDF\";\n}\n.i-Structure:before {\n\tcontent: \"\\ECE0\";\n}\n.i-Student-Female:before {\n\tcontent: \"\\ECE1\";\n}\n.i-Student-Hat:before {\n\tcontent: \"\\ECE2\";\n}\n.i-Student-Hat2:before {\n\tcontent: \"\\ECE3\";\n}\n.i-Student-Male:before {\n\tcontent: \"\\ECE4\";\n}\n.i-Student-MaleFemale:before {\n\tcontent: \"\\ECE5\";\n}\n.i-Students:before {\n\tcontent: \"\\ECE6\";\n}\n.i-Studio-Flash:before {\n\tcontent: \"\\ECE7\";\n}\n.i-Studio-Lightbox:before {\n\tcontent: \"\\ECE8\";\n}\n.i-Stumbleupon:before {\n\tcontent: \"\\ECE9\";\n}\n.i-Suit:before {\n\tcontent: \"\\ECEA\";\n}\n.i-Suitcase:before {\n\tcontent: \"\\ECEB\";\n}\n.i-Sum-2:before {\n\tcontent: \"\\ECEC\";\n}\n.i-Sum:before {\n\tcontent: \"\\ECED\";\n}\n.i-Summer:before {\n\tcontent: \"\\ECEE\";\n}\n.i-Sun-CloudyRain:before {\n\tcontent: \"\\ECEF\";\n}\n.i-Sun:before {\n\tcontent: \"\\ECF0\";\n}\n.i-Sunglasses-2:before {\n\tcontent: \"\\ECF1\";\n}\n.i-Sunglasses-3:before {\n\tcontent: \"\\ECF2\";\n}\n.i-Sunglasses-Smiley:before {\n\tcontent: \"\\ECF3\";\n}\n.i-Sunglasses-Smiley2:before {\n\tcontent: \"\\ECF4\";\n}\n.i-Sunglasses-W:before {\n\tcontent: \"\\ECF5\";\n}\n.i-Sunglasses-W2:before {\n\tcontent: \"\\ECF6\";\n}\n.i-Sunglasses-W3:before {\n\tcontent: \"\\ECF7\";\n}\n.i-Sunglasses:before {\n\tcontent: \"\\ECF8\";\n}\n.i-Sunrise:before {\n\tcontent: \"\\ECF9\";\n}\n.i-Sunset:before {\n\tcontent: \"\\ECFA\";\n}\n.i-Superman:before {\n\tcontent: \"\\ECFB\";\n}\n.i-Support:before {\n\tcontent: \"\\ECFC\";\n}\n.i-Surprise:before {\n\tcontent: \"\\ECFD\";\n}\n.i-Sushi:before {\n\tcontent: \"\\ECFE\";\n}\n.i-Sweden:before {\n\tcontent: \"\\ECFF\";\n}\n.i-Swimming-Short:before {\n\tcontent: \"\\ED00\";\n}\n.i-Swimming:before {\n\tcontent: \"\\ED01\";\n}\n.i-Swimmwear:before {\n\tcontent: \"\\ED02\";\n}\n.i-Switch:before {\n\tcontent: \"\\ED03\";\n}\n.i-Switzerland:before {\n\tcontent: \"\\ED04\";\n}\n.i-Sync-Cloud:before {\n\tcontent: \"\\ED05\";\n}\n.i-Sync:before {\n\tcontent: \"\\ED06\";\n}\n.i-Synchronize-2:before {\n\tcontent: \"\\ED07\";\n}\n.i-Synchronize:before {\n\tcontent: \"\\ED08\";\n}\n.i-T-Shirt:before {\n\tcontent: \"\\ED09\";\n}\n.i-Tablet-2:before {\n\tcontent: \"\\ED0A\";\n}\n.i-Tablet-3:before {\n\tcontent: \"\\ED0B\";\n}\n.i-Tablet-Orientation:before {\n\tcontent: \"\\ED0C\";\n}\n.i-Tablet-Phone:before {\n\tcontent: \"\\ED0D\";\n}\n.i-Tablet-Secure:before {\n\tcontent: \"\\ED0E\";\n}\n.i-Tablet-Vertical:before {\n\tcontent: \"\\ED0F\";\n}\n.i-Tablet:before {\n\tcontent: \"\\ED10\";\n}\n.i-Tactic:before {\n\tcontent: \"\\ED11\";\n}\n.i-Tag-2:before {\n\tcontent: \"\\ED12\";\n}\n.i-Tag-3:before {\n\tcontent: \"\\ED13\";\n}\n.i-Tag-4:before {\n\tcontent: \"\\ED14\";\n}\n.i-Tag-5:before {\n\tcontent: \"\\ED15\";\n}\n.i-Tag:before {\n\tcontent: \"\\ED16\";\n}\n.i-Taj-Mahal:before {\n\tcontent: \"\\ED17\";\n}\n.i-Talk-Man:before {\n\tcontent: \"\\ED18\";\n}\n.i-Tap:before {\n\tcontent: \"\\ED19\";\n}\n.i-Target-Market:before {\n\tcontent: \"\\ED1A\";\n}\n.i-Target:before {\n\tcontent: \"\\ED1B\";\n}\n.i-Taurus-2:before {\n\tcontent: \"\\ED1C\";\n}\n.i-Taurus:before {\n\tcontent: \"\\ED1D\";\n}\n.i-Taxi-2:before {\n\tcontent: \"\\ED1E\";\n}\n.i-Taxi-Sign:before {\n\tcontent: \"\\ED1F\";\n}\n.i-Taxi:before {\n\tcontent: \"\\ED20\";\n}\n.i-Teacher:before {\n\tcontent: \"\\ED21\";\n}\n.i-Teapot:before {\n\tcontent: \"\\ED22\";\n}\n.i-Technorati:before {\n\tcontent: \"\\ED23\";\n}\n.i-Teddy-Bear:before {\n\tcontent: \"\\ED24\";\n}\n.i-Tee-Mug:before {\n\tcontent: \"\\ED25\";\n}\n.i-Telephone-2:before {\n\tcontent: \"\\ED26\";\n}\n.i-Telephone:before {\n\tcontent: \"\\ED27\";\n}\n.i-Telescope:before {\n\tcontent: \"\\ED28\";\n}\n.i-Temperature-2:before {\n\tcontent: \"\\ED29\";\n}\n.i-Temperature-3:before {\n\tcontent: \"\\ED2A\";\n}\n.i-Temperature:before {\n\tcontent: \"\\ED2B\";\n}\n.i-Temple:before {\n\tcontent: \"\\ED2C\";\n}\n.i-Tennis-Ball:before {\n\tcontent: \"\\ED2D\";\n}\n.i-Tennis:before {\n\tcontent: \"\\ED2E\";\n}\n.i-Tent:before {\n\tcontent: \"\\ED2F\";\n}\n.i-Test-Tube:before {\n\tcontent: \"\\ED30\";\n}\n.i-Test-Tube2:before {\n\tcontent: \"\\ED31\";\n}\n.i-Testimonal:before {\n\tcontent: \"\\ED32\";\n}\n.i-Text-Box:before {\n\tcontent: \"\\ED33\";\n}\n.i-Text-Effect:before {\n\tcontent: \"\\ED34\";\n}\n.i-Text-HighlightColor:before {\n\tcontent: \"\\ED35\";\n}\n.i-Text-Paragraph:before {\n\tcontent: \"\\ED36\";\n}\n.i-Thailand:before {\n\tcontent: \"\\ED37\";\n}\n.i-The-WhiteHouse:before {\n\tcontent: \"\\ED38\";\n}\n.i-This-SideUp:before {\n\tcontent: \"\\ED39\";\n}\n.i-Thread:before {\n\tcontent: \"\\ED3A\";\n}\n.i-Three-ArrowFork:before {\n\tcontent: \"\\ED3B\";\n}\n.i-Three-Fingers:before {\n\tcontent: \"\\ED3C\";\n}\n.i-Three-FingersDrag:before {\n\tcontent: \"\\ED3D\";\n}\n.i-Three-FingersDrag2:before {\n\tcontent: \"\\ED3E\";\n}\n.i-Three-FingersTouch:before {\n\tcontent: \"\\ED3F\";\n}\n.i-Thumb:before {\n\tcontent: \"\\ED40\";\n}\n.i-Thumbs-DownSmiley:before {\n\tcontent: \"\\ED41\";\n}\n.i-Thumbs-UpSmiley:before {\n\tcontent: \"\\ED42\";\n}\n.i-Thunder:before {\n\tcontent: \"\\ED43\";\n}\n.i-Thunderstorm:before {\n\tcontent: \"\\ED44\";\n}\n.i-Ticket:before {\n\tcontent: \"\\ED45\";\n}\n.i-Tie-2:before {\n\tcontent: \"\\ED46\";\n}\n.i-Tie-3:before {\n\tcontent: \"\\ED47\";\n}\n.i-Tie-4:before {\n\tcontent: \"\\ED48\";\n}\n.i-Tie:before {\n\tcontent: \"\\ED49\";\n}\n.i-Tiger:before {\n\tcontent: \"\\ED4A\";\n}\n.i-Time-Backup:before {\n\tcontent: \"\\ED4B\";\n}\n.i-Time-Bomb:before {\n\tcontent: \"\\ED4C\";\n}\n.i-Time-Clock:before {\n\tcontent: \"\\ED4D\";\n}\n.i-Time-Fire:before {\n\tcontent: \"\\ED4E\";\n}\n.i-Time-Machine:before {\n\tcontent: \"\\ED4F\";\n}\n.i-Time-Window:before {\n\tcontent: \"\\ED50\";\n}\n.i-Timer-2:before {\n\tcontent: \"\\ED51\";\n}\n.i-Timer:before {\n\tcontent: \"\\ED52\";\n}\n.i-To-Bottom:before {\n\tcontent: \"\\ED53\";\n}\n.i-To-Bottom2:before {\n\tcontent: \"\\ED54\";\n}\n.i-To-Left:before {\n\tcontent: \"\\ED55\";\n}\n.i-To-Right:before {\n\tcontent: \"\\ED56\";\n}\n.i-To-Top:before {\n\tcontent: \"\\ED57\";\n}\n.i-To-Top2:before {\n\tcontent: \"\\ED58\";\n}\n.i-Token-:before {\n\tcontent: \"\\ED59\";\n}\n.i-Tomato:before {\n\tcontent: \"\\ED5A\";\n}\n.i-Tongue:before {\n\tcontent: \"\\ED5B\";\n}\n.i-Tooth-2:before {\n\tcontent: \"\\ED5C\";\n}\n.i-Tooth:before {\n\tcontent: \"\\ED5D\";\n}\n.i-Top-ToBottom:before {\n\tcontent: \"\\ED5E\";\n}\n.i-Touch-Window:before {\n\tcontent: \"\\ED5F\";\n}\n.i-Tourch:before {\n\tcontent: \"\\ED60\";\n}\n.i-Tower-2:before {\n\tcontent: \"\\ED61\";\n}\n.i-Tower-Bridge:before {\n\tcontent: \"\\ED62\";\n}\n.i-Tower:before {\n\tcontent: \"\\ED63\";\n}\n.i-Trace:before {\n\tcontent: \"\\ED64\";\n}\n.i-Tractor:before {\n\tcontent: \"\\ED65\";\n}\n.i-traffic-Light:before {\n\tcontent: \"\\ED66\";\n}\n.i-Traffic-Light2:before {\n\tcontent: \"\\ED67\";\n}\n.i-Train-2:before {\n\tcontent: \"\\ED68\";\n}\n.i-Train:before {\n\tcontent: \"\\ED69\";\n}\n.i-Tram:before {\n\tcontent: \"\\ED6A\";\n}\n.i-Transform-2:before {\n\tcontent: \"\\ED6B\";\n}\n.i-Transform-3:before {\n\tcontent: \"\\ED6C\";\n}\n.i-Transform-4:before {\n\tcontent: \"\\ED6D\";\n}\n.i-Transform:before {\n\tcontent: \"\\ED6E\";\n}\n.i-Trash-withMen:before {\n\tcontent: \"\\ED6F\";\n}\n.i-Tree-2:before {\n\tcontent: \"\\ED70\";\n}\n.i-Tree-3:before {\n\tcontent: \"\\ED71\";\n}\n.i-Tree-4:before {\n\tcontent: \"\\ED72\";\n}\n.i-Tree-5:before {\n\tcontent: \"\\ED73\";\n}\n.i-Tree:before {\n\tcontent: \"\\ED74\";\n}\n.i-Trekking:before {\n\tcontent: \"\\ED75\";\n}\n.i-Triangle-ArrowDown:before {\n\tcontent: \"\\ED76\";\n}\n.i-Triangle-ArrowLeft:before {\n\tcontent: \"\\ED77\";\n}\n.i-Triangle-ArrowRight:before {\n\tcontent: \"\\ED78\";\n}\n.i-Triangle-ArrowUp:before {\n\tcontent: \"\\ED79\";\n}\n.i-Tripod-2:before {\n\tcontent: \"\\ED7A\";\n}\n.i-Tripod-andVideo:before {\n\tcontent: \"\\ED7B\";\n}\n.i-Tripod-withCamera:before {\n\tcontent: \"\\ED7C\";\n}\n.i-Tripod-withGopro:before {\n\tcontent: \"\\ED7D\";\n}\n.i-Trophy-2:before {\n\tcontent: \"\\ED7E\";\n}\n.i-Trophy:before {\n\tcontent: \"\\ED7F\";\n}\n.i-Truck:before {\n\tcontent: \"\\ED80\";\n}\n.i-Trumpet:before {\n\tcontent: \"\\ED81\";\n}\n.i-Tumblr:before {\n\tcontent: \"\\ED82\";\n}\n.i-Turkey:before {\n\tcontent: \"\\ED83\";\n}\n.i-Turn-Down:before {\n\tcontent: \"\\ED84\";\n}\n.i-Turn-Down2:before {\n\tcontent: \"\\ED85\";\n}\n.i-Turn-DownFromLeft:before {\n\tcontent: \"\\ED86\";\n}\n.i-Turn-DownFromRight:before {\n\tcontent: \"\\ED87\";\n}\n.i-Turn-Left:before {\n\tcontent: \"\\ED88\";\n}\n.i-Turn-Left3:before {\n\tcontent: \"\\ED89\";\n}\n.i-Turn-Right:before {\n\tcontent: \"\\ED8A\";\n}\n.i-Turn-Right3:before {\n\tcontent: \"\\ED8B\";\n}\n.i-Turn-Up:before {\n\tcontent: \"\\ED8C\";\n}\n.i-Turn-Up2:before {\n\tcontent: \"\\ED8D\";\n}\n.i-Turtle:before {\n\tcontent: \"\\ED8E\";\n}\n.i-Tuxedo:before {\n\tcontent: \"\\ED8F\";\n}\n.i-TV:before {\n\tcontent: \"\\ED90\";\n}\n.i-Twister:before {\n\tcontent: \"\\ED91\";\n}\n.i-Twitter-2:before {\n\tcontent: \"\\ED92\";\n}\n.i-Twitter:before {\n\tcontent: \"\\ED93\";\n}\n.i-Two-Fingers:before {\n\tcontent: \"\\ED94\";\n}\n.i-Two-FingersDrag:before {\n\tcontent: \"\\ED95\";\n}\n.i-Two-FingersDrag2:before {\n\tcontent: \"\\ED96\";\n}\n.i-Two-FingersScroll:before {\n\tcontent: \"\\ED97\";\n}\n.i-Two-FingersTouch:before {\n\tcontent: \"\\ED98\";\n}\n.i-Two-Windows:before {\n\tcontent: \"\\ED99\";\n}\n.i-Type-Pass:before {\n\tcontent: \"\\ED9A\";\n}\n.i-Ukraine:before {\n\tcontent: \"\\ED9B\";\n}\n.i-Umbrela:before {\n\tcontent: \"\\ED9C\";\n}\n.i-Umbrella-2:before {\n\tcontent: \"\\ED9D\";\n}\n.i-Umbrella-3:before {\n\tcontent: \"\\ED9E\";\n}\n.i-Under-LineText:before {\n\tcontent: \"\\ED9F\";\n}\n.i-Undo:before {\n\tcontent: \"\\EDA0\";\n}\n.i-United-Kingdom:before {\n\tcontent: \"\\EDA1\";\n}\n.i-United-States:before {\n\tcontent: \"\\EDA2\";\n}\n.i-University-2:before {\n\tcontent: \"\\EDA3\";\n}\n.i-University:before {\n\tcontent: \"\\EDA4\";\n}\n.i-Unlike-2:before {\n\tcontent: \"\\EDA5\";\n}\n.i-Unlike:before {\n\tcontent: \"\\EDA6\";\n}\n.i-Unlock-2:before {\n\tcontent: \"\\EDA7\";\n}\n.i-Unlock-3:before {\n\tcontent: \"\\EDA8\";\n}\n.i-Unlock:before {\n\tcontent: \"\\EDA9\";\n}\n.i-Up--Down:before {\n\tcontent: \"\\EDAA\";\n}\n.i-Up--Down3:before {\n\tcontent: \"\\EDAB\";\n}\n.i-Up-2:before {\n\tcontent: \"\\EDAC\";\n}\n.i-Up-3:before {\n\tcontent: \"\\EDAD\";\n}\n.i-Up-4:before {\n\tcontent: \"\\EDAE\";\n}\n.i-Up:before {\n\tcontent: \"\\EDAF\";\n}\n.i-Upgrade:before {\n\tcontent: \"\\EDB0\";\n}\n.i-Upload-2:before {\n\tcontent: \"\\EDB1\";\n}\n.i-Upload-toCloud:before {\n\tcontent: \"\\EDB2\";\n}\n.i-Upload-Window:before {\n\tcontent: \"\\EDB3\";\n}\n.i-Upload:before {\n\tcontent: \"\\EDB4\";\n}\n.i-Uppercase-Text:before {\n\tcontent: \"\\EDB5\";\n}\n.i-Upward:before {\n\tcontent: \"\\EDB6\";\n}\n.i-URL-Window:before {\n\tcontent: \"\\EDB7\";\n}\n.i-Usb-2:before {\n\tcontent: \"\\EDB8\";\n}\n.i-Usb-Cable:before {\n\tcontent: \"\\EDB9\";\n}\n.i-Usb:before {\n\tcontent: \"\\EDBA\";\n}\n.i-User:before {\n\tcontent: \"\\EDBB\";\n}\n.i-Ustream:before {\n\tcontent: \"\\EDBC\";\n}\n.i-Vase:before {\n\tcontent: \"\\EDBD\";\n}\n.i-Vector-2:before {\n\tcontent: \"\\EDBE\";\n}\n.i-Vector-3:before {\n\tcontent: \"\\EDBF\";\n}\n.i-Vector-4:before {\n\tcontent: \"\\EDC0\";\n}\n.i-Vector-5:before {\n\tcontent: \"\\EDC1\";\n}\n.i-Vector:before {\n\tcontent: \"\\EDC2\";\n}\n.i-Venn-Diagram:before {\n\tcontent: \"\\EDC3\";\n}\n.i-Vest-2:before {\n\tcontent: \"\\EDC4\";\n}\n.i-Vest:before {\n\tcontent: \"\\EDC5\";\n}\n.i-Viddler:before {\n\tcontent: \"\\EDC6\";\n}\n.i-Video-2:before {\n\tcontent: \"\\EDC7\";\n}\n.i-Video-3:before {\n\tcontent: \"\\EDC8\";\n}\n.i-Video-4:before {\n\tcontent: \"\\EDC9\";\n}\n.i-Video-5:before {\n\tcontent: \"\\EDCA\";\n}\n.i-Video-6:before {\n\tcontent: \"\\EDCB\";\n}\n.i-Video-GameController:before {\n\tcontent: \"\\EDCC\";\n}\n.i-Video-Len:before {\n\tcontent: \"\\EDCD\";\n}\n.i-Video-Len2:before {\n\tcontent: \"\\EDCE\";\n}\n.i-Video-Photographer:before {\n\tcontent: \"\\EDCF\";\n}\n.i-Video-Tripod:before {\n\tcontent: \"\\EDD0\";\n}\n.i-Video:before {\n\tcontent: \"\\EDD1\";\n}\n.i-Vietnam:before {\n\tcontent: \"\\EDD2\";\n}\n.i-View-Height:before {\n\tcontent: \"\\EDD3\";\n}\n.i-View-Width:before {\n\tcontent: \"\\EDD4\";\n}\n.i-Vimeo:before {\n\tcontent: \"\\EDD5\";\n}\n.i-Virgo-2:before {\n\tcontent: \"\\EDD6\";\n}\n.i-Virgo:before {\n\tcontent: \"\\EDD7\";\n}\n.i-Virus-2:before {\n\tcontent: \"\\EDD8\";\n}\n.i-Virus-3:before {\n\tcontent: \"\\EDD9\";\n}\n.i-Virus:before {\n\tcontent: \"\\EDDA\";\n}\n.i-Visa:before {\n\tcontent: \"\\EDDB\";\n}\n.i-Voice:before {\n\tcontent: \"\\EDDC\";\n}\n.i-Voicemail:before {\n\tcontent: \"\\EDDD\";\n}\n.i-Volleyball:before {\n\tcontent: \"\\EDDE\";\n}\n.i-Volume-Down:before {\n\tcontent: \"\\EDDF\";\n}\n.i-Volume-Up:before {\n\tcontent: \"\\EDE0\";\n}\n.i-VPN:before {\n\tcontent: \"\\EDE1\";\n}\n.i-Wacom-Tablet:before {\n\tcontent: \"\\EDE2\";\n}\n.i-Waiter:before {\n\tcontent: \"\\EDE3\";\n}\n.i-Walkie-Talkie:before {\n\tcontent: \"\\EDE4\";\n}\n.i-Wallet-2:before {\n\tcontent: \"\\EDE5\";\n}\n.i-Wallet-3:before {\n\tcontent: \"\\EDE6\";\n}\n.i-Wallet:before {\n\tcontent: \"\\EDE7\";\n}\n.i-Warehouse:before {\n\tcontent: \"\\EDE8\";\n}\n.i-Warning-Window:before {\n\tcontent: \"\\EDE9\";\n}\n.i-Watch-2:before {\n\tcontent: \"\\EDEA\";\n}\n.i-Watch-3:before {\n\tcontent: \"\\EDEB\";\n}\n.i-Watch:before {\n\tcontent: \"\\EDEC\";\n}\n.i-Wave-2:before {\n\tcontent: \"\\EDED\";\n}\n.i-Wave:before {\n\tcontent: \"\\EDEE\";\n}\n.i-Webcam:before {\n\tcontent: \"\\EDEF\";\n}\n.i-weight-Lift:before {\n\tcontent: \"\\EDF0\";\n}\n.i-Wheelbarrow:before {\n\tcontent: \"\\EDF1\";\n}\n.i-Wheelchair:before {\n\tcontent: \"\\EDF2\";\n}\n.i-Width-Window:before {\n\tcontent: \"\\EDF3\";\n}\n.i-Wifi-2:before {\n\tcontent: \"\\EDF4\";\n}\n.i-Wifi-Keyboard:before {\n\tcontent: \"\\EDF5\";\n}\n.i-Wifi:before {\n\tcontent: \"\\EDF6\";\n}\n.i-Wind-Turbine:before {\n\tcontent: \"\\EDF7\";\n}\n.i-Windmill:before {\n\tcontent: \"\\EDF8\";\n}\n.i-Window-2:before {\n\tcontent: \"\\EDF9\";\n}\n.i-Window:before {\n\tcontent: \"\\EDFA\";\n}\n.i-Windows-2:before {\n\tcontent: \"\\EDFB\";\n}\n.i-Windows-Microsoft:before {\n\tcontent: \"\\EDFC\";\n}\n.i-Windows:before {\n\tcontent: \"\\EDFD\";\n}\n.i-Windsock:before {\n\tcontent: \"\\EDFE\";\n}\n.i-Windy:before {\n\tcontent: \"\\EDFF\";\n}\n.i-Wine-Bottle:before {\n\tcontent: \"\\EE00\";\n}\n.i-Wine-Glass:before {\n\tcontent: \"\\EE01\";\n}\n.i-Wink:before {\n\tcontent: \"\\EE02\";\n}\n.i-Winter-2:before {\n\tcontent: \"\\EE03\";\n}\n.i-Winter:before {\n\tcontent: \"\\EE04\";\n}\n.i-Wireless:before {\n\tcontent: \"\\EE05\";\n}\n.i-Witch-Hat:before {\n\tcontent: \"\\EE06\";\n}\n.i-Witch:before {\n\tcontent: \"\\EE07\";\n}\n.i-Wizard:before {\n\tcontent: \"\\EE08\";\n}\n.i-Wolf:before {\n\tcontent: \"\\EE09\";\n}\n.i-Woman-Sign:before {\n\tcontent: \"\\EE0A\";\n}\n.i-WomanMan:before {\n\tcontent: \"\\EE0B\";\n}\n.i-Womans-Underwear:before {\n\tcontent: \"\\EE0C\";\n}\n.i-Womans-Underwear2:before {\n\tcontent: \"\\EE0D\";\n}\n.i-Women:before {\n\tcontent: \"\\EE0E\";\n}\n.i-Wonder-Woman:before {\n\tcontent: \"\\EE0F\";\n}\n.i-Wordpress:before {\n\tcontent: \"\\EE10\";\n}\n.i-Worker-Clothes:before {\n\tcontent: \"\\EE11\";\n}\n.i-Worker:before {\n\tcontent: \"\\EE12\";\n}\n.i-Wrap-Text:before {\n\tcontent: \"\\EE13\";\n}\n.i-Wreath:before {\n\tcontent: \"\\EE14\";\n}\n.i-Wrench:before {\n\tcontent: \"\\EE15\";\n}\n.i-X-Box:before {\n\tcontent: \"\\EE16\";\n}\n.i-X-ray:before {\n\tcontent: \"\\EE17\";\n}\n.i-Xanga:before {\n\tcontent: \"\\EE18\";\n}\n.i-Xing:before {\n\tcontent: \"\\EE19\";\n}\n.i-Yacht:before {\n\tcontent: \"\\EE1A\";\n}\n.i-Yahoo-Buzz:before {\n\tcontent: \"\\EE1B\";\n}\n.i-Yahoo:before {\n\tcontent: \"\\EE1C\";\n}\n.i-Yelp:before {\n\tcontent: \"\\EE1D\";\n}\n.i-Yes:before {\n\tcontent: \"\\EE1E\";\n}\n.i-Ying-Yang:before {\n\tcontent: \"\\EE1F\";\n}\n.i-Youtube:before {\n\tcontent: \"\\EE20\";\n}\n.i-Z-A:before {\n\tcontent: \"\\EE21\";\n}\n.i-Zebra:before {\n\tcontent: \"\\EE22\";\n}\n.i-Zombie:before {\n\tcontent: \"\\EE23\";\n}\n.i-Zoom-Gesture:before {\n\tcontent: \"\\EE24\";\n}\n.i-Zootool:before {\n\tcontent: \"\\EE25\";\n}\n",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/@trevoreyre/autocomplete-vue/dist/style.css":
/*!**************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader??ref--6-1!./node_modules/postcss-loader/src??ref--6-2!./node_modules/@trevoreyre/autocomplete-vue/dist/style.css ***!
  \**************************************************************************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesPostcssLoaderSrcIndexJsNode_modulesTrevoreyreAutocompleteVueDistStyleCss(module,exports,__webpack_require__){

exports=module.exports=__webpack_require__(/*! ../../../css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,".autocomplete-input{border:1px solid #eee;border-radius:8px;width:100%;padding:12px 12px 12px 48px;box-sizing:border-box;position:relative;font-size:16px;line-height:1.5;flex:1;background-color:#eee;background-image:url(\"data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNjY2IiBzdHJva2Utd2lkdGg9IjIiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCI+PGNpcmNsZSBjeD0iMTEiIGN5PSIxMSIgcj0iOCIvPjxwYXRoIGQ9Ik0yMSAyMWwtNC00Ii8+PC9zdmc+\");background-repeat:no-repeat;background-position:12px}.autocomplete-input:focus,.autocomplete-input[aria-expanded=true]{border-color:rgba(0,0,0,.12);background-color:#fff;outline:none;box-shadow:0 2px 2px rgba(0,0,0,.16)}[data-position=below] .autocomplete-input[aria-expanded=true]{border-bottom-color:transparent;border-radius:8px 8px 0 0}[data-position=above] .autocomplete-input[aria-expanded=true]{border-top-color:transparent;border-radius:0 0 8px 8px;z-index:2}.autocomplete[data-loading=true]:after{content:\"\";border:3px solid rgba(0,0,0,.12);border-right-color:rgba(0,0,0,.48);border-radius:100%;width:20px;height:20px;position:absolute;right:12px;top:50%;transform:translateY(-50%);-webkit-animation:rotate 1s linear infinite;animation:rotate 1s linear infinite}.autocomplete-result-list{margin:0;border:1px solid rgba(0,0,0,.12);padding:0;box-sizing:border-box;max-height:296px;overflow-y:auto;background:#fff;list-style:none;box-shadow:0 2px 2px rgba(0,0,0,.16)}[data-position=below] .autocomplete-result-list{margin-top:-1px;border-top-color:transparent;border-radius:0 0 8px 8px;padding-bottom:8px}[data-position=above] .autocomplete-result-list{margin-bottom:-1px;border-bottom-color:transparent;border-radius:8px 8px 0 0;padding-top:8px}.autocomplete-result{cursor:default;padding:12px 12px 12px 48px;background-image:url(\"data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjY2NjIiBzdHJva2Utd2lkdGg9IjIiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCI+PGNpcmNsZSBjeD0iMTEiIGN5PSIxMSIgcj0iOCIvPjxwYXRoIGQ9Ik0yMSAyMWwtNC00Ii8+PC9zdmc+\");background-repeat:no-repeat;background-position:12px}.autocomplete-result:hover,.autocomplete-result[aria-selected=true]{background-color:rgba(0,0,0,.06)}@-webkit-keyframes rotate{0%{transform:translateY(-50%) rotate(0deg)}to{transform:translateY(-50%) rotate(359deg)}}@keyframes rotate{0%{transform:translateY(-50%) rotate(0deg)}to{transform:translateY(-50%) rotate(359deg)}}",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/sweetalert2/dist/sweetalert2.min.css":
/*!*******************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader??ref--6-1!./node_modules/postcss-loader/src??ref--6-2!./node_modules/sweetalert2/dist/sweetalert2.min.css ***!
  \*******************************************************************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesPostcssLoaderSrcIndexJsNode_modulesSweetalert2DistSweetalert2MinCss(module,exports,__webpack_require__){

exports=module.exports=__webpack_require__(/*! ../../css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,".swal2-popup.swal2-toast{flex-direction:row;align-items:center;width:auto;padding:.625em;overflow-y:hidden;background:#fff;box-shadow:0 0 .625em #d9d9d9}.swal2-popup.swal2-toast .swal2-header{flex-direction:row;padding:0}.swal2-popup.swal2-toast .swal2-title{flex-grow:1;justify-content:flex-start;margin:0 .6em;font-size:1em}.swal2-popup.swal2-toast .swal2-footer{margin:.5em 0 0;padding:.5em 0 0;font-size:.8em}.swal2-popup.swal2-toast .swal2-close{position:static;width:.8em;height:.8em;line-height:.8}.swal2-popup.swal2-toast .swal2-content{justify-content:flex-start;padding:0;font-size:1em}.swal2-popup.swal2-toast .swal2-icon{width:2em;min-width:2em;height:2em;margin:0}.swal2-popup.swal2-toast .swal2-icon .swal2-icon-content{display:flex;align-items:center;font-size:1.8em;font-weight:700}@media all and (-ms-high-contrast:none),(-ms-high-contrast:active){.swal2-popup.swal2-toast .swal2-icon .swal2-icon-content{font-size:.25em}}.swal2-popup.swal2-toast .swal2-icon.swal2-success .swal2-success-ring{width:2em;height:2em}.swal2-popup.swal2-toast .swal2-icon.swal2-error [class^=swal2-x-mark-line]{top:.875em;width:1.375em}.swal2-popup.swal2-toast .swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=left]{left:.3125em}.swal2-popup.swal2-toast .swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=right]{right:.3125em}.swal2-popup.swal2-toast .swal2-actions{flex-basis:auto!important;width:auto;height:auto;margin:0 .3125em}.swal2-popup.swal2-toast .swal2-styled{margin:0 .3125em;padding:.3125em .625em;font-size:1em}.swal2-popup.swal2-toast .swal2-styled:focus{box-shadow:0 0 0 1px #fff,0 0 0 3px rgba(50,100,150,.4)}.swal2-popup.swal2-toast .swal2-success{border-color:#a5dc86}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-circular-line]{position:absolute;width:1.6em;height:3em;transform:rotate(45deg);border-radius:50%}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-circular-line][class$=left]{top:-.8em;left:-.5em;transform:rotate(-45deg);transform-origin:2em 2em;border-radius:4em 0 0 4em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-circular-line][class$=right]{top:-.25em;left:.9375em;transform-origin:0 1.5em;border-radius:0 4em 4em 0}.swal2-popup.swal2-toast .swal2-success .swal2-success-ring{width:2em;height:2em}.swal2-popup.swal2-toast .swal2-success .swal2-success-fix{top:0;left:.4375em;width:.4375em;height:2.6875em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-line]{height:.3125em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-line][class$=tip]{top:1.125em;left:.1875em;width:.75em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-line][class$=long]{top:.9375em;right:.1875em;width:1.375em}.swal2-popup.swal2-toast .swal2-success.swal2-icon-show .swal2-success-line-tip{-webkit-animation:swal2-toast-animate-success-line-tip .75s;animation:swal2-toast-animate-success-line-tip .75s}.swal2-popup.swal2-toast .swal2-success.swal2-icon-show .swal2-success-line-long{-webkit-animation:swal2-toast-animate-success-line-long .75s;animation:swal2-toast-animate-success-line-long .75s}.swal2-popup.swal2-toast.swal2-show{-webkit-animation:swal2-toast-show .5s;animation:swal2-toast-show .5s}.swal2-popup.swal2-toast.swal2-hide{-webkit-animation:swal2-toast-hide .1s forwards;animation:swal2-toast-hide .1s forwards}.swal2-container{display:flex;position:fixed;z-index:1060;top:0;right:0;bottom:0;left:0;flex-direction:row;align-items:center;justify-content:center;padding:.625em;overflow-x:hidden;transition:background-color .1s;-webkit-overflow-scrolling:touch}.swal2-container.swal2-backdrop-show,.swal2-container.swal2-noanimation{background:rgba(0,0,0,.4)}.swal2-container.swal2-backdrop-hide{background:0 0!important}.swal2-container.swal2-top{align-items:flex-start}.swal2-container.swal2-top-left,.swal2-container.swal2-top-start{align-items:flex-start;justify-content:flex-start}.swal2-container.swal2-top-end,.swal2-container.swal2-top-right{align-items:flex-start;justify-content:flex-end}.swal2-container.swal2-center{align-items:center}.swal2-container.swal2-center-left,.swal2-container.swal2-center-start{align-items:center;justify-content:flex-start}.swal2-container.swal2-center-end,.swal2-container.swal2-center-right{align-items:center;justify-content:flex-end}.swal2-container.swal2-bottom{align-items:flex-end}.swal2-container.swal2-bottom-left,.swal2-container.swal2-bottom-start{align-items:flex-end;justify-content:flex-start}.swal2-container.swal2-bottom-end,.swal2-container.swal2-bottom-right{align-items:flex-end;justify-content:flex-end}.swal2-container.swal2-bottom-end>:first-child,.swal2-container.swal2-bottom-left>:first-child,.swal2-container.swal2-bottom-right>:first-child,.swal2-container.swal2-bottom-start>:first-child,.swal2-container.swal2-bottom>:first-child{margin-top:auto}.swal2-container.swal2-grow-fullscreen>.swal2-modal{display:flex!important;flex:1;align-self:stretch;justify-content:center}.swal2-container.swal2-grow-row>.swal2-modal{display:flex!important;flex:1;align-content:center;justify-content:center}.swal2-container.swal2-grow-column{flex:1;flex-direction:column}.swal2-container.swal2-grow-column.swal2-bottom,.swal2-container.swal2-grow-column.swal2-center,.swal2-container.swal2-grow-column.swal2-top{align-items:center}.swal2-container.swal2-grow-column.swal2-bottom-left,.swal2-container.swal2-grow-column.swal2-bottom-start,.swal2-container.swal2-grow-column.swal2-center-left,.swal2-container.swal2-grow-column.swal2-center-start,.swal2-container.swal2-grow-column.swal2-top-left,.swal2-container.swal2-grow-column.swal2-top-start{align-items:flex-start}.swal2-container.swal2-grow-column.swal2-bottom-end,.swal2-container.swal2-grow-column.swal2-bottom-right,.swal2-container.swal2-grow-column.swal2-center-end,.swal2-container.swal2-grow-column.swal2-center-right,.swal2-container.swal2-grow-column.swal2-top-end,.swal2-container.swal2-grow-column.swal2-top-right{align-items:flex-end}.swal2-container.swal2-grow-column>.swal2-modal{display:flex!important;flex:1;align-content:center;justify-content:center}.swal2-container.swal2-no-transition{transition:none!important}.swal2-container:not(.swal2-top):not(.swal2-top-start):not(.swal2-top-end):not(.swal2-top-left):not(.swal2-top-right):not(.swal2-center-start):not(.swal2-center-end):not(.swal2-center-left):not(.swal2-center-right):not(.swal2-bottom):not(.swal2-bottom-start):not(.swal2-bottom-end):not(.swal2-bottom-left):not(.swal2-bottom-right):not(.swal2-grow-fullscreen)>.swal2-modal{margin:auto}@media all and (-ms-high-contrast:none),(-ms-high-contrast:active){.swal2-container .swal2-modal{margin:0!important}}.swal2-popup{display:none;position:relative;box-sizing:border-box;flex-direction:column;justify-content:center;width:32em;max-width:100%;padding:1.25em;border:none;border-radius:.3125em;background:#fff;font-family:inherit;font-size:1rem}.swal2-popup:focus{outline:0}.swal2-popup.swal2-loading{overflow-y:hidden}.swal2-header{display:flex;flex-direction:column;align-items:center;padding:0 1.8em}.swal2-title{position:relative;max-width:100%;margin:0 0 .4em;padding:0;color:#595959;font-size:1.875em;font-weight:600;text-align:center;text-transform:none;word-wrap:break-word}.swal2-actions{display:flex;z-index:1;flex-wrap:wrap;align-items:center;justify-content:center;width:100%;margin:1.25em auto 0}.swal2-actions:not(.swal2-loading) .swal2-styled[disabled]{opacity:.4}.swal2-actions:not(.swal2-loading) .swal2-styled:hover{background-image:linear-gradient(rgba(0,0,0,.1),rgba(0,0,0,.1))}.swal2-actions:not(.swal2-loading) .swal2-styled:active{background-image:linear-gradient(rgba(0,0,0,.2),rgba(0,0,0,.2))}.swal2-actions.swal2-loading .swal2-styled.swal2-confirm{box-sizing:border-box;width:2.5em;height:2.5em;margin:.46875em;padding:0;-webkit-animation:swal2-rotate-loading 1.5s linear 0s infinite normal;animation:swal2-rotate-loading 1.5s linear 0s infinite normal;border:.25em solid transparent;border-radius:100%;border-color:transparent;background-color:transparent!important;color:transparent!important;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.swal2-actions.swal2-loading .swal2-styled.swal2-cancel{margin-right:30px;margin-left:30px}.swal2-actions.swal2-loading :not(.swal2-styled).swal2-confirm::after{content:\"\";display:inline-block;width:15px;height:15px;margin-left:5px;-webkit-animation:swal2-rotate-loading 1.5s linear 0s infinite normal;animation:swal2-rotate-loading 1.5s linear 0s infinite normal;border:3px solid #999;border-radius:50%;border-right-color:transparent;box-shadow:1px 1px 1px #fff}.swal2-styled{margin:.3125em;padding:.625em 2em;box-shadow:none;font-weight:500}.swal2-styled:not([disabled]){cursor:pointer}.swal2-styled.swal2-confirm{border:0;border-radius:.25em;background:initial;background-color:#3085d6;color:#fff;font-size:1.0625em}.swal2-styled.swal2-cancel{border:0;border-radius:.25em;background:initial;background-color:#aaa;color:#fff;font-size:1.0625em}.swal2-styled:focus{outline:0;box-shadow:0 0 0 1px #fff,0 0 0 3px rgba(50,100,150,.4)}.swal2-styled::-moz-focus-inner{border:0}.swal2-footer{justify-content:center;margin:1.25em 0 0;padding:1em 0 0;border-top:1px solid #eee;color:#545454;font-size:1em}.swal2-timer-progress-bar-container{position:absolute;right:0;bottom:0;left:0;height:.25em;overflow:hidden;border-bottom-right-radius:.3125em;border-bottom-left-radius:.3125em}.swal2-timer-progress-bar{width:100%;height:.25em;background:rgba(0,0,0,.2)}.swal2-image{max-width:100%;margin:1.25em auto}.swal2-close{position:absolute;z-index:2;top:0;right:0;align-items:center;justify-content:center;width:1.2em;height:1.2em;padding:0;overflow:hidden;transition:color .1s ease-out;border:none;border-radius:0;background:0 0;color:#ccc;font-family:serif;font-size:2.5em;line-height:1.2;cursor:pointer}.swal2-close:hover{transform:none;background:0 0;color:#f27474}.swal2-close::-moz-focus-inner{border:0}.swal2-content{z-index:1;justify-content:center;margin:0;padding:0 1.6em;color:#545454;font-size:1.125em;font-weight:400;line-height:normal;text-align:center;word-wrap:break-word}.swal2-checkbox,.swal2-file,.swal2-input,.swal2-radio,.swal2-select,.swal2-textarea{margin:1em auto}.swal2-file,.swal2-input,.swal2-textarea{box-sizing:border-box;width:100%;transition:border-color .3s,box-shadow .3s;border:1px solid #d9d9d9;border-radius:.1875em;background:inherit;box-shadow:inset 0 1px 1px rgba(0,0,0,.06);color:inherit;font-size:1.125em}.swal2-file.swal2-inputerror,.swal2-input.swal2-inputerror,.swal2-textarea.swal2-inputerror{border-color:#f27474!important;box-shadow:0 0 2px #f27474!important}.swal2-file:focus,.swal2-input:focus,.swal2-textarea:focus{border:1px solid #b4dbed;outline:0;box-shadow:0 0 3px #c4e6f5}.swal2-file::-moz-placeholder,.swal2-input::-moz-placeholder,.swal2-textarea::-moz-placeholder{color:#ccc}.swal2-file:-ms-input-placeholder,.swal2-input:-ms-input-placeholder,.swal2-textarea:-ms-input-placeholder{color:#ccc}.swal2-file::-moz-placeholder, .swal2-input::-moz-placeholder, .swal2-textarea::-moz-placeholder{color:#ccc}.swal2-file:-ms-input-placeholder, .swal2-input:-ms-input-placeholder, .swal2-textarea:-ms-input-placeholder{color:#ccc}.swal2-file::placeholder,.swal2-input::placeholder,.swal2-textarea::placeholder{color:#ccc}.swal2-range{margin:1em auto;background:#fff}.swal2-range input{width:80%}.swal2-range output{width:20%;color:inherit;font-weight:600;text-align:center}.swal2-range input,.swal2-range output{height:2.625em;padding:0;font-size:1.125em;line-height:2.625em}.swal2-input{height:2.625em;padding:0 .75em}.swal2-input[type=number]{max-width:10em}.swal2-file{background:inherit;font-size:1.125em}.swal2-textarea{height:6.75em;padding:.75em}.swal2-select{min-width:50%;max-width:100%;padding:.375em .625em;background:inherit;color:inherit;font-size:1.125em}.swal2-checkbox,.swal2-radio{align-items:center;justify-content:center;background:#fff;color:inherit}.swal2-checkbox label,.swal2-radio label{margin:0 .6em;font-size:1.125em}.swal2-checkbox input,.swal2-radio input{margin:0 .4em}.swal2-validation-message{display:none;align-items:center;justify-content:center;padding:.625em;overflow:hidden;background:#f0f0f0;color:#666;font-size:1em;font-weight:300}.swal2-validation-message::before{content:\"!\";display:inline-block;width:1.5em;min-width:1.5em;height:1.5em;margin:0 .625em;border-radius:50%;background-color:#f27474;color:#fff;font-weight:600;line-height:1.5em;text-align:center}.swal2-icon{position:relative;box-sizing:content-box;justify-content:center;width:5em;height:5em;margin:1.25em auto 1.875em;border:.25em solid transparent;border-radius:50%;font-family:inherit;line-height:5em;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.swal2-icon .swal2-icon-content{display:flex;align-items:center;font-size:3.75em}.swal2-icon.swal2-error{border-color:#f27474;color:#f27474}.swal2-icon.swal2-error .swal2-x-mark{position:relative;flex-grow:1}.swal2-icon.swal2-error [class^=swal2-x-mark-line]{display:block;position:absolute;top:2.3125em;width:2.9375em;height:.3125em;border-radius:.125em;background-color:#f27474}.swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=left]{left:1.0625em;transform:rotate(45deg)}.swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=right]{right:1em;transform:rotate(-45deg)}.swal2-icon.swal2-error.swal2-icon-show{-webkit-animation:swal2-animate-error-icon .5s;animation:swal2-animate-error-icon .5s}.swal2-icon.swal2-error.swal2-icon-show .swal2-x-mark{-webkit-animation:swal2-animate-error-x-mark .5s;animation:swal2-animate-error-x-mark .5s}.swal2-icon.swal2-warning{border-color:#facea8;color:#f8bb86}.swal2-icon.swal2-info{border-color:#9de0f6;color:#3fc3ee}.swal2-icon.swal2-question{border-color:#c9dae1;color:#87adbd}.swal2-icon.swal2-success{border-color:#a5dc86;color:#a5dc86}.swal2-icon.swal2-success [class^=swal2-success-circular-line]{position:absolute;width:3.75em;height:7.5em;transform:rotate(45deg);border-radius:50%}.swal2-icon.swal2-success [class^=swal2-success-circular-line][class$=left]{top:-.4375em;left:-2.0635em;transform:rotate(-45deg);transform-origin:3.75em 3.75em;border-radius:7.5em 0 0 7.5em}.swal2-icon.swal2-success [class^=swal2-success-circular-line][class$=right]{top:-.6875em;left:1.875em;transform:rotate(-45deg);transform-origin:0 3.75em;border-radius:0 7.5em 7.5em 0}.swal2-icon.swal2-success .swal2-success-ring{position:absolute;z-index:2;top:-.25em;left:-.25em;box-sizing:content-box;width:100%;height:100%;border:.25em solid rgba(165,220,134,.3);border-radius:50%}.swal2-icon.swal2-success .swal2-success-fix{position:absolute;z-index:1;top:.5em;left:1.625em;width:.4375em;height:5.625em;transform:rotate(-45deg)}.swal2-icon.swal2-success [class^=swal2-success-line]{display:block;position:absolute;z-index:2;height:.3125em;border-radius:.125em;background-color:#a5dc86}.swal2-icon.swal2-success [class^=swal2-success-line][class$=tip]{top:2.875em;left:.8125em;width:1.5625em;transform:rotate(45deg)}.swal2-icon.swal2-success [class^=swal2-success-line][class$=long]{top:2.375em;right:.5em;width:2.9375em;transform:rotate(-45deg)}.swal2-icon.swal2-success.swal2-icon-show .swal2-success-line-tip{-webkit-animation:swal2-animate-success-line-tip .75s;animation:swal2-animate-success-line-tip .75s}.swal2-icon.swal2-success.swal2-icon-show .swal2-success-line-long{-webkit-animation:swal2-animate-success-line-long .75s;animation:swal2-animate-success-line-long .75s}.swal2-icon.swal2-success.swal2-icon-show .swal2-success-circular-line-right{-webkit-animation:swal2-rotate-success-circular-line 4.25s ease-in;animation:swal2-rotate-success-circular-line 4.25s ease-in}.swal2-progress-steps{align-items:center;margin:0 0 1.25em;padding:0;background:inherit;font-weight:600}.swal2-progress-steps li{display:inline-block;position:relative}.swal2-progress-steps .swal2-progress-step{z-index:20;width:2em;height:2em;border-radius:2em;background:#3085d6;color:#fff;line-height:2em;text-align:center}.swal2-progress-steps .swal2-progress-step.swal2-active-progress-step{background:#3085d6}.swal2-progress-steps .swal2-progress-step.swal2-active-progress-step~.swal2-progress-step{background:#add8e6;color:#fff}.swal2-progress-steps .swal2-progress-step.swal2-active-progress-step~.swal2-progress-step-line{background:#add8e6}.swal2-progress-steps .swal2-progress-step-line{z-index:10;width:2.5em;height:.4em;margin:0 -1px;background:#3085d6}[class^=swal2]{-webkit-tap-highlight-color:transparent}.swal2-show{-webkit-animation:swal2-show .3s;animation:swal2-show .3s}.swal2-hide{-webkit-animation:swal2-hide .15s forwards;animation:swal2-hide .15s forwards}.swal2-noanimation{transition:none}.swal2-scrollbar-measure{position:absolute;top:-9999px;width:50px;height:50px;overflow:scroll}.swal2-rtl .swal2-close{right:auto;left:0}.swal2-rtl .swal2-timer-progress-bar{right:0;left:auto}@supports (-ms-accelerator:true){.swal2-range input{width:100%!important}.swal2-range output{display:none}}@media all and (-ms-high-contrast:none),(-ms-high-contrast:active){.swal2-range input{width:100%!important}.swal2-range output{display:none}}@-moz-document url-prefix(){.swal2-close:focus{outline:2px solid rgba(50,100,150,.4)}}@-webkit-keyframes swal2-toast-show{0%{transform:translateY(-.625em) rotateZ(2deg)}33%{transform:translateY(0) rotateZ(-2deg)}66%{transform:translateY(.3125em) rotateZ(2deg)}100%{transform:translateY(0) rotateZ(0)}}@keyframes swal2-toast-show{0%{transform:translateY(-.625em) rotateZ(2deg)}33%{transform:translateY(0) rotateZ(-2deg)}66%{transform:translateY(.3125em) rotateZ(2deg)}100%{transform:translateY(0) rotateZ(0)}}@-webkit-keyframes swal2-toast-hide{100%{transform:rotateZ(1deg);opacity:0}}@keyframes swal2-toast-hide{100%{transform:rotateZ(1deg);opacity:0}}@-webkit-keyframes swal2-toast-animate-success-line-tip{0%{top:.5625em;left:.0625em;width:0}54%{top:.125em;left:.125em;width:0}70%{top:.625em;left:-.25em;width:1.625em}84%{top:1.0625em;left:.75em;width:.5em}100%{top:1.125em;left:.1875em;width:.75em}}@keyframes swal2-toast-animate-success-line-tip{0%{top:.5625em;left:.0625em;width:0}54%{top:.125em;left:.125em;width:0}70%{top:.625em;left:-.25em;width:1.625em}84%{top:1.0625em;left:.75em;width:.5em}100%{top:1.125em;left:.1875em;width:.75em}}@-webkit-keyframes swal2-toast-animate-success-line-long{0%{top:1.625em;right:1.375em;width:0}65%{top:1.25em;right:.9375em;width:0}84%{top:.9375em;right:0;width:1.125em}100%{top:.9375em;right:.1875em;width:1.375em}}@keyframes swal2-toast-animate-success-line-long{0%{top:1.625em;right:1.375em;width:0}65%{top:1.25em;right:.9375em;width:0}84%{top:.9375em;right:0;width:1.125em}100%{top:.9375em;right:.1875em;width:1.375em}}@-webkit-keyframes swal2-show{0%{transform:scale(.7)}45%{transform:scale(1.05)}80%{transform:scale(.95)}100%{transform:scale(1)}}@keyframes swal2-show{0%{transform:scale(.7)}45%{transform:scale(1.05)}80%{transform:scale(.95)}100%{transform:scale(1)}}@-webkit-keyframes swal2-hide{0%{transform:scale(1);opacity:1}100%{transform:scale(.5);opacity:0}}@keyframes swal2-hide{0%{transform:scale(1);opacity:1}100%{transform:scale(.5);opacity:0}}@-webkit-keyframes swal2-animate-success-line-tip{0%{top:1.1875em;left:.0625em;width:0}54%{top:1.0625em;left:.125em;width:0}70%{top:2.1875em;left:-.375em;width:3.125em}84%{top:3em;left:1.3125em;width:1.0625em}100%{top:2.8125em;left:.8125em;width:1.5625em}}@keyframes swal2-animate-success-line-tip{0%{top:1.1875em;left:.0625em;width:0}54%{top:1.0625em;left:.125em;width:0}70%{top:2.1875em;left:-.375em;width:3.125em}84%{top:3em;left:1.3125em;width:1.0625em}100%{top:2.8125em;left:.8125em;width:1.5625em}}@-webkit-keyframes swal2-animate-success-line-long{0%{top:3.375em;right:2.875em;width:0}65%{top:3.375em;right:2.875em;width:0}84%{top:2.1875em;right:0;width:3.4375em}100%{top:2.375em;right:.5em;width:2.9375em}}@keyframes swal2-animate-success-line-long{0%{top:3.375em;right:2.875em;width:0}65%{top:3.375em;right:2.875em;width:0}84%{top:2.1875em;right:0;width:3.4375em}100%{top:2.375em;right:.5em;width:2.9375em}}@-webkit-keyframes swal2-rotate-success-circular-line{0%{transform:rotate(-45deg)}5%{transform:rotate(-45deg)}12%{transform:rotate(-405deg)}100%{transform:rotate(-405deg)}}@keyframes swal2-rotate-success-circular-line{0%{transform:rotate(-45deg)}5%{transform:rotate(-45deg)}12%{transform:rotate(-405deg)}100%{transform:rotate(-405deg)}}@-webkit-keyframes swal2-animate-error-x-mark{0%{margin-top:1.625em;transform:scale(.4);opacity:0}50%{margin-top:1.625em;transform:scale(.4);opacity:0}80%{margin-top:-.375em;transform:scale(1.15)}100%{margin-top:0;transform:scale(1);opacity:1}}@keyframes swal2-animate-error-x-mark{0%{margin-top:1.625em;transform:scale(.4);opacity:0}50%{margin-top:1.625em;transform:scale(.4);opacity:0}80%{margin-top:-.375em;transform:scale(1.15)}100%{margin-top:0;transform:scale(1);opacity:1}}@-webkit-keyframes swal2-animate-error-icon{0%{transform:rotateX(100deg);opacity:0}100%{transform:rotateX(0);opacity:1}}@keyframes swal2-animate-error-icon{0%{transform:rotateX(100deg);opacity:0}100%{transform:rotateX(0);opacity:1}}@-webkit-keyframes swal2-rotate-loading{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes swal2-rotate-loading{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown){overflow:hidden}body.swal2-height-auto{height:auto!important}body.swal2-no-backdrop .swal2-container{top:auto;right:auto;bottom:auto;left:auto;max-width:calc(100% - .625em * 2);background-color:transparent!important}body.swal2-no-backdrop .swal2-container>.swal2-modal{box-shadow:0 0 10px rgba(0,0,0,.4)}body.swal2-no-backdrop .swal2-container.swal2-top{top:0;left:50%;transform:translateX(-50%)}body.swal2-no-backdrop .swal2-container.swal2-top-left,body.swal2-no-backdrop .swal2-container.swal2-top-start{top:0;left:0}body.swal2-no-backdrop .swal2-container.swal2-top-end,body.swal2-no-backdrop .swal2-container.swal2-top-right{top:0;right:0}body.swal2-no-backdrop .swal2-container.swal2-center{top:50%;left:50%;transform:translate(-50%,-50%)}body.swal2-no-backdrop .swal2-container.swal2-center-left,body.swal2-no-backdrop .swal2-container.swal2-center-start{top:50%;left:0;transform:translateY(-50%)}body.swal2-no-backdrop .swal2-container.swal2-center-end,body.swal2-no-backdrop .swal2-container.swal2-center-right{top:50%;right:0;transform:translateY(-50%)}body.swal2-no-backdrop .swal2-container.swal2-bottom{bottom:0;left:50%;transform:translateX(-50%)}body.swal2-no-backdrop .swal2-container.swal2-bottom-left,body.swal2-no-backdrop .swal2-container.swal2-bottom-start{bottom:0;left:0}body.swal2-no-backdrop .swal2-container.swal2-bottom-end,body.swal2-no-backdrop .swal2-container.swal2-bottom-right{right:0;bottom:0}@media print{body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown){overflow-y:scroll!important}body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown)>[aria-hidden=true]{display:none}body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown) .swal2-container{position:static!important}}body.swal2-toast-shown .swal2-container{background-color:transparent}body.swal2-toast-shown .swal2-container.swal2-top{top:0;right:auto;bottom:auto;left:50%;transform:translateX(-50%)}body.swal2-toast-shown .swal2-container.swal2-top-end,body.swal2-toast-shown .swal2-container.swal2-top-right{top:0;right:0;bottom:auto;left:auto}body.swal2-toast-shown .swal2-container.swal2-top-left,body.swal2-toast-shown .swal2-container.swal2-top-start{top:0;right:auto;bottom:auto;left:0}body.swal2-toast-shown .swal2-container.swal2-center-left,body.swal2-toast-shown .swal2-container.swal2-center-start{top:50%;right:auto;bottom:auto;left:0;transform:translateY(-50%)}body.swal2-toast-shown .swal2-container.swal2-center{top:50%;right:auto;bottom:auto;left:50%;transform:translate(-50%,-50%)}body.swal2-toast-shown .swal2-container.swal2-center-end,body.swal2-toast-shown .swal2-container.swal2-center-right{top:50%;right:0;bottom:auto;left:auto;transform:translateY(-50%)}body.swal2-toast-shown .swal2-container.swal2-bottom-left,body.swal2-toast-shown .swal2-container.swal2-bottom-start{top:auto;right:auto;bottom:0;left:0}body.swal2-toast-shown .swal2-container.swal2-bottom{top:auto;right:auto;bottom:0;left:50%;transform:translateX(-50%)}body.swal2-toast-shown .swal2-container.swal2-bottom-end,body.swal2-toast-shown .swal2-container.swal2-bottom-right{top:auto;right:0;bottom:0;left:auto}body.swal2-toast-column .swal2-toast{flex-direction:column;align-items:stretch}body.swal2-toast-column .swal2-toast .swal2-actions{flex:1;align-self:stretch;height:2.2em;margin-top:.3125em}body.swal2-toast-column .swal2-toast .swal2-loading{justify-content:center}body.swal2-toast-column .swal2-toast .swal2-input{height:2em;margin:.3125em auto;font-size:1em}body.swal2-toast-column .swal2-toast .swal2-validation-message{font-size:1em}",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.css":
/*!*************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader??ref--6-1!./node_modules/postcss-loader/src??ref--6-2!./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.css ***!
  \*************************************************************************************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesPostcssLoaderSrcIndexJsNode_modulesVueMjDaterangepickerDistVueMjDaterangepickerCss(module,exports,__webpack_require__){

exports=module.exports=__webpack_require__(/*! ../../css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,".mj-daterange-picker{text-align:left;min-width:400px;width:var(--default-width);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;border:1px solid var(--border-color);border-radius:4px}.mj-daterange-picker *{-webkit-box-sizing:border-box;box-sizing:border-box}.mj-daterange-picker .panels-choices{display:grid;grid-gap:10px 10px;grid-template-columns:1fr 1fr 1fr 1fr 1fr;border-bottom:1px solid var(--border-color);padding:20px}.mj-daterange-picker .panels-choices .panel-button{font-size:12px;font-weight:700;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;height:32px;padding:5px 15px;border-radius:4px;cursor:pointer;background-color:#f2f4f5}.mj-daterange-picker .panels-choices .panel-button.is-current,.mj-daterange-picker .panels-choices .panel-button:hover{background-color:var(--primary-color);color:#fff}.mj-daterange-picker .preset-ranges{padding:20px;display:-webkit-box;display:-ms-flexbox;display:flex;-ms-flex-wrap:wrap;flex-wrap:wrap;border-bottom:1px solid var(--border-color)}.mj-daterange-picker .preset-ranges .preset{width:50%;font-size:13px;height:20px;cursor:pointer;position:relative;margin:5px 0}.mj-daterange-picker .preset-ranges .preset input{position:absolute;opacity:0;height:0;width:0}.mj-daterange-picker .preset-ranges .preset input:checked~label .check{background-color:var(--primary-color)}.mj-daterange-picker .preset-ranges .preset input:checked~label .check:after{background-color:transparent}.mj-daterange-picker .preset-ranges .preset label{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.mj-daterange-picker .preset-ranges .preset label span+span{margin-left:10px}.mj-daterange-picker .preset-ranges .preset label .check{display:block;position:relative;height:20px;width:20px;background-color:var(--secondary-color);border-radius:10px}.mj-daterange-picker .preset-ranges .preset label .check:after{content:\"\";position:absolute;height:10px;width:10px;left:50%;top:50%;background-color:#fff;border-radius:100%;border:3px solid #fff;-webkit-transform:translateX(-50%) translateY(-50%);transform:translateX(-50%) translateY(-50%)}.mj-daterange-picker .preset-ranges .preset *{cursor:pointer}.mj-calendar{color:var(--contrast-color);background-color:var(--normal-color);padding:20px}.mj-calendar .calendar-header{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.mj-calendar .calendar-header .calendar-month-name{-webkit-box-flex:1;-ms-flex:1;flex:1;text-align:center;color:var(--secondary-color);font-weight:700;font-size:14px}.mj-calendar .calendar-header .calendar-arrow{fill:var(--secondary-color);cursor:pointer}.mj-calendar .calendar-months{margin-top:20px;display:grid;grid-gap:10px 10px;grid-template-columns:1fr 1fr 1fr}.mj-calendar .calendar-months .month{height:50px;padding:10px;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;border:1px solid var(--border-color);border-radius:4px;font-size:13px}.mj-calendar .calendar-months .month:hover{background-color:var(--hover-range-color)}.mj-calendar .calendar-months .month.is-disabled{cursor:not-allowed;opacity:.5;pointer-events:none}.mj-calendar .calendar-months .month.is-selected{background-color:var(--primary-color);color:#fff}.mj-calendar .calendar-months .month:not(.is-disabled){cursor:pointer}.mj-calendar .calendar-quarters{margin-top:20px}.mj-calendar .calendar-quarters .quarter{display:grid;grid-gap:10px 10px;grid-template-columns:1fr 3fr;margin:10px 0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;font-size:13px}.mj-calendar .calendar-quarters .quarter .months{display:grid;grid-gap:10px 10px;-webkit-box-align:center;-ms-flex-align:center;align-items:center;grid-template-columns:1fr 1fr 1fr;border:1px solid var(--border-color);border-radius:4px;height:50px;padding:10px 30px}.mj-calendar .calendar-quarters .quarter .months:hover{background-color:var(--hover-range-color)}.mj-calendar .calendar-quarters .quarter .months .month{text-align:center}.mj-calendar .calendar-quarters .quarter.is-selected .months{background-color:var(--primary-color);color:#fff}.mj-calendar .calendar-quarters .quarter.is-disabled .months{opacity:.5}.mj-calendar .calendar-quarters .quarter.is-disabled{cursor:not-allowed;pointer-events:none}.mj-calendar .calendar-quarters .quarter:not(.is-disabled) .months{cursor:pointer}.mj-calendar .calendar-years .year{height:50px;padding:10px;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;border:1px solid var(--border-color);border-radius:4px;font-size:13px;margin:10px 0}.mj-calendar .calendar-years .year:hover{background-color:var(--hover-range-color)}.mj-calendar .calendar-years .year.is-selected{background-color:var(--primary-color);color:#fff}.mj-calendar .calendar-years .year.is-disabled{cursor:not-allowed;opacity:.5;pointer-events:none}.mj-calendar .calendar-years .year:not(.is-disabled){cursor:pointer}.mj-calendar .calendar-days,.mj-calendar .calendar-days-name{display:-webkit-box;display:-ms-flexbox;display:flex;-ms-flex-wrap:wrap;flex-wrap:wrap}.mj-calendar .calendar-days-name .day,.mj-calendar .calendar-days .day{width:14.28571%;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.mj-calendar .calendar-days-name .day{font-size:11px;color:var(--ternary-color);height:30px}.mj-calendar .calendar-days .day{height:40px;font-size:13px;border-top:2px solid #fff;border-bottom:2px solid #fff}.mj-calendar .calendar-days .day:not(.is-current-month){color:var(--ternary-color)}.mj-calendar .calendar-days .day.is-disabled{cursor:not-allowed;opacity:.5;pointer-events:none}.mj-calendar .calendar-days .day.is-today span{color:var(--secondary-color);font-weight:700}.mj-calendar .calendar-days .day.is-in-range{background-color:var(--hover-range-color)}.mj-calendar .calendar-days .day.is-first-range{border-top-left-radius:4px;border-bottom-left-radius:4px}.mj-calendar .calendar-days .day.is-last-range{border-top-right-radius:4px;border-bottom-right-radius:4px}.mj-calendar .calendar-days .day.is-edge-range,.mj-calendar .calendar-days .day.is-selected{background-color:var(--primary-color);color:#fff}.mj-calendar .calendar-days .day:not(.is-disabled){cursor:pointer}.mj-calendar.mj-calendar-days .calendar-days .day:not(.is-edge-range):hover{background-color:var(--hover-day-color)}.mj-daterange-picker-controls{margin-top:10px;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;border-top:1px solid var(--border-color);padding:20px}.mj-daterange-picker-controls .mj-daterange-picker-button{height:36px;min-width:150px;padding:5px;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;border-radius:4px;font-size:12px}.mj-daterange-picker-controls .mj-daterange-picker-button:not(.is-disabled){cursor:pointer}.mj-daterange-picker-reset{border:1px solid #e6eaed}.mj-daterange-picker-submit{background-color:var(--primary-color);color:#fff}.mj-daterange-picker-submit.is-disabled{opacity:.5;cursor:not-allowed;pointer-events:none}",""]);

// exports


/***/},

/***/"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/vue-select/dist/vue-select.css":
/*!*************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader??ref--6-1!./node_modules/postcss-loader/src??ref--6-2!./node_modules/vue-select/dist/vue-select.css ***!
  \*************************************************************************************************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderIndexJsNode_modulesPostcssLoaderSrcIndexJsNode_modulesVueSelectDistVueSelectCss(module,exports,__webpack_require__){

exports=module.exports=__webpack_require__(/*! ../../css-loader/lib/css-base.js */"./node_modules/css-loader/lib/css-base.js")(false);
// imports


// module
exports.push([module.i,".v-select{position:relative;font-family:inherit}.v-select,.v-select *{box-sizing:border-box}@-webkit-keyframes vSelectSpinner{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}@keyframes vSelectSpinner{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}.vs__fade-enter-active,.vs__fade-leave-active{pointer-events:none;transition:opacity .15s cubic-bezier(1,.5,.8,1)}.vs__fade-enter,.vs__fade-leave-to{opacity:0}.vs--disabled .vs__clear,.vs--disabled .vs__dropdown-toggle,.vs--disabled .vs__open-indicator,.vs--disabled .vs__search,.vs--disabled .vs__selected{cursor:not-allowed;background-color:#f8f8f8}.v-select[dir=rtl] .vs__actions{padding:0 3px 0 6px}.v-select[dir=rtl] .vs__clear{margin-left:6px;margin-right:0}.v-select[dir=rtl] .vs__deselect{margin-left:0;margin-right:2px}.v-select[dir=rtl] .vs__dropdown-menu{text-align:right}.vs__dropdown-toggle{-webkit-appearance:none;-moz-appearance:none;appearance:none;display:flex;padding:0 0 4px;background:none;border:1px solid rgba(60,60,60,.26);border-radius:4px;white-space:normal}.vs__selected-options{display:flex;flex-basis:100%;flex-grow:1;flex-wrap:wrap;padding:0 2px;position:relative}.vs__actions{display:flex;align-items:center;padding:4px 6px 0 3px}.vs--searchable .vs__dropdown-toggle{cursor:text}.vs--unsearchable .vs__dropdown-toggle{cursor:pointer}.vs--open .vs__dropdown-toggle{border-bottom-color:transparent;border-bottom-left-radius:0;border-bottom-right-radius:0}.vs__open-indicator{fill:rgba(60,60,60,.5);transform:scale(1);transition:transform .15s cubic-bezier(1,-.115,.975,.855);transition-timing-function:cubic-bezier(1,-.115,.975,.855)}.vs--open .vs__open-indicator{transform:rotate(180deg) scale(1)}.vs--loading .vs__open-indicator{opacity:0}.vs__clear{fill:rgba(60,60,60,.5);padding:0;border:0;background-color:transparent;cursor:pointer;margin-right:8px}.vs__dropdown-menu{display:block;box-sizing:border-box;position:absolute;top:calc(100% - 1px);left:0;z-index:1000;padding:5px 0;margin:0;width:100%;max-height:350px;min-width:160px;overflow-y:auto;box-shadow:0 3px 6px 0 rgba(0,0,0,.15);border:1px solid rgba(60,60,60,.26);border-top-style:none;border-radius:0 0 4px 4px;text-align:left;list-style:none;background:#fff}.vs__no-options{text-align:center}.vs__dropdown-option{line-height:1.42857143;display:block;padding:3px 20px;clear:both;color:#333;white-space:nowrap}.vs__dropdown-option:hover{cursor:pointer}.vs__dropdown-option--highlight{background:#5897fb;color:#fff}.vs__dropdown-option--disabled{background:inherit;color:rgba(60,60,60,.5)}.vs__dropdown-option--disabled:hover{cursor:inherit}.vs__selected{display:flex;align-items:center;background-color:#f0f0f0;border:1px solid rgba(60,60,60,.26);border-radius:4px;color:#333;line-height:1.4;margin:4px 2px 0;padding:0 .25em;z-index:0}.vs__deselect{display:inline-flex;-webkit-appearance:none;-moz-appearance:none;appearance:none;margin-left:4px;padding:0;border:0;cursor:pointer;background:none;fill:rgba(60,60,60,.5);text-shadow:0 1px 0 #fff}.vs--single .vs__selected{background-color:transparent;border-color:transparent}.vs--single.vs--open .vs__selected{position:absolute;opacity:.4}.vs--single.vs--searching .vs__selected{display:none}.vs__search::-webkit-search-cancel-button{display:none}.vs__search::-ms-clear,.vs__search::-webkit-search-decoration,.vs__search::-webkit-search-results-button,.vs__search::-webkit-search-results-decoration{display:none}.vs__search,.vs__search:focus{-webkit-appearance:none;-moz-appearance:none;appearance:none;line-height:1.4;font-size:1em;border:1px solid transparent;border-left:none;outline:none;margin:4px 0 0;padding:0 7px;background:none;box-shadow:none;width:0;max-width:100%;flex-grow:1;z-index:1}.vs__search::-moz-placeholder{color:inherit}.vs__search:-ms-input-placeholder{color:inherit}.vs__search::placeholder{color:inherit}.vs--unsearchable .vs__search{opacity:1}.vs--unsearchable:not(.vs--disabled) .vs__search:hover{cursor:pointer}.vs--single.vs--searching:not(.vs--open):not(.vs--loading) .vs__search{opacity:.2}.vs__spinner{align-self:center;opacity:0;font-size:5px;text-indent:-9999em;overflow:hidden;border:.9em solid hsla(0,0%,39.2%,.1);border-left-color:rgba(60,60,60,.45);transform:translateZ(0);-webkit-animation:vSelectSpinner 1.1s linear infinite;animation:vSelectSpinner 1.1s linear infinite;transition:opacity .1s}.vs__spinner,.vs__spinner:after{border-radius:50%;width:5em;height:5em}.vs--loading .vs__spinner{opacity:1}",""]);

// exports


/***/},

/***/"./node_modules/css-loader/lib/css-base.js":
/*!*************************************************!*\
  !*** ./node_modules/css-loader/lib/css-base.js ***!
  \*************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderLibCssBaseJs(module,exports){

/*
	MIT License http://www.opensource.org/licenses/mit-license.php
	Author Tobias Koppers @sokra
*/
// css base code, injected by the css-loader
module.exports=function(useSourceMap){
var list=[];

// return the list of modules as css string
list.toString=function toString(){
return this.map(function(item){
var content=cssWithMappingToString(item,useSourceMap);
if(item[2]){
return "@media "+item[2]+"{"+content+"}";
}else {
return content;
}
}).join("");
};

// import a list of modules into the list
list.i=function(modules,mediaQuery){
if(typeof modules==="string")
modules=[[null,modules,""]];
var alreadyImportedModules={};
for(var i=0;i<this.length;i++){
var id=this[i][0];
if(typeof id==="number")
alreadyImportedModules[id]=true;
}
for(i=0;i<modules.length;i++){
var item=modules[i];
// skip already imported module
// this implementation is not 100% perfect for weird media query combinations
//  when a module is imported multiple times with different media queries.
//  I hope this will never occur (Hey this way we have smaller bundles)
if(typeof item[0]!=="number"||!alreadyImportedModules[item[0]]){
if(mediaQuery&&!item[2]){
item[2]=mediaQuery;
}else if(mediaQuery){
item[2]="("+item[2]+") and ("+mediaQuery+")";
}
list.push(item);
}
}
};
return list;
};

function cssWithMappingToString(item,useSourceMap){
var content=item[1]||'';
var cssMapping=item[3];
if(!cssMapping){
return content;
}

if(useSourceMap&&typeof btoa==='function'){
var sourceMapping=toComment(cssMapping);
var sourceURLs=cssMapping.sources.map(function(source){
return '/*# sourceURL='+cssMapping.sourceRoot+source+' */';
});

return [content].concat(sourceURLs).concat([sourceMapping]).join('\n');
}

return [content].join('\n');
}

// Adapted from convert-source-map (MIT)
function toComment(sourceMap){
// eslint-disable-next-line no-undef
var base64=btoa(unescape(encodeURIComponent(JSON.stringify(sourceMap))));
var data='sourceMappingURL=data:application/json;charset=utf-8;base64,'+base64;

return '/*# '+data+' */';
}


/***/},

/***/"./node_modules/css-loader/lib/url/escape.js":
/*!***************************************************!*\
  !*** ./node_modules/css-loader/lib/url/escape.js ***!
  \***************************************************/
/*! no static exports found */
/***/function node_modulesCssLoaderLibUrlEscapeJs(module,exports){

module.exports=function escape(url){
if(typeof url!=='string'){
return url;
}
// If url is already wrapped in quotes, remove them
if(/^['"].*['"]$/.test(url)){
url=url.slice(1,-1);
}
// Should url be wrapped?
// See https://drafts.csswg.org/css-values-3/#urls
if(/["'() \t\n]/.test(url)){
return '"'+url.replace(/"/g,'\\"').replace(/\n/g,'\\n')+'"';
}

return url;
};


/***/},

/***/"./node_modules/nprogress/nprogress.js":
/*!*********************************************!*\
  !*** ./node_modules/nprogress/nprogress.js ***!
  \*********************************************/
/*! no static exports found */
/***/function node_modulesNprogressNprogressJs(module,exports,__webpack_require__){

var __WEBPACK_AMD_DEFINE_FACTORY__,__WEBPACK_AMD_DEFINE_RESULT__;/* NProgress, (c) 2013, 2014 Rico Sta. Cruz - http://ricostacruz.com/nprogress
 * @license MIT */
(function(root,factory){

{
!(__WEBPACK_AMD_DEFINE_FACTORY__=factory,
__WEBPACK_AMD_DEFINE_RESULT__=typeof __WEBPACK_AMD_DEFINE_FACTORY__==='function'?
__WEBPACK_AMD_DEFINE_FACTORY__.call(exports,__webpack_require__,exports,module):
__WEBPACK_AMD_DEFINE_FACTORY__,
__WEBPACK_AMD_DEFINE_RESULT__!==undefined&&(module.exports=__WEBPACK_AMD_DEFINE_RESULT__));
}

})(this,function(){
var NProgress={};

NProgress.version='0.2.0';

var Settings=NProgress.settings={
minimum:0.08,
easing:'ease',
positionUsing:'',
speed:200,
trickle:true,
trickleRate:0.02,
trickleSpeed:800,
showSpinner:true,
barSelector:'[role="bar"]',
spinnerSelector:'[role="spinner"]',
parent:'body',
template:'<div class="bar" role="bar"><div class="peg"></div></div><div class="spinner" role="spinner"><div class="spinner-icon"></div></div>'};


/**
   * Updates configuration.
   *
   *     NProgress.configure({
   *       minimum: 0.1
   *     });
   */
NProgress.configure=function(options){
var key,value;
for(key in options){
value=options[key];
if(value!==undefined&&options.hasOwnProperty(key))Settings[key]=value;
}

return this;
};

/**
   * Last number.
   */

NProgress.status=null;

/**
   * Sets the progress bar status, where `n` is a number from `0.0` to `1.0`.
   *
   *     NProgress.set(0.4);
   *     NProgress.set(1.0);
   */

NProgress.set=function(n){
var started=NProgress.isStarted();

n=clamp(n,Settings.minimum,1);
NProgress.status=n===1?null:n;

var progress=NProgress.render(!started),
bar=progress.querySelector(Settings.barSelector),
speed=Settings.speed,
ease=Settings.easing;

progress.offsetWidth;/* Repaint */

queue(function(next){
// Set positionUsing if it hasn't already been set
if(Settings.positionUsing==='')Settings.positionUsing=NProgress.getPositioningCSS();

// Add transition
css(bar,barPositionCSS(n,speed,ease));

if(n===1){
// Fade out
css(progress,{
transition:'none',
opacity:1});

progress.offsetWidth;/* Repaint */

setTimeout(function(){
css(progress,{
transition:'all '+speed+'ms linear',
opacity:0});

setTimeout(function(){
NProgress.remove();
next();
},speed);
},speed);
}else {
setTimeout(next,speed);
}
});

return this;
};

NProgress.isStarted=function(){
return typeof NProgress.status==='number';
};

/**
   * Shows the progress bar.
   * This is the same as setting the status to 0%, except that it doesn't go backwards.
   *
   *     NProgress.start();
   *
   */
NProgress.start=function(){
if(!NProgress.status)NProgress.set(0);

var work=function work(){
setTimeout(function(){
if(!NProgress.status)return;
NProgress.trickle();
work();
},Settings.trickleSpeed);
};

if(Settings.trickle)work();

return this;
};

/**
   * Hides the progress bar.
   * This is the *sort of* the same as setting the status to 100%, with the
   * difference being `done()` makes some placebo effect of some realistic motion.
   *
   *     NProgress.done();
   *
   * If `true` is passed, it will show the progress bar even if its hidden.
   *
   *     NProgress.done(true);
   */

NProgress.done=function(force){
if(!force&&!NProgress.status)return this;

return NProgress.inc(0.3+0.5*Math.random()).set(1);
};

/**
   * Increments by a random amount.
   */

NProgress.inc=function(amount){
var n=NProgress.status;

if(!n){
return NProgress.start();
}else {
if(typeof amount!=='number'){
amount=(1-n)*clamp(Math.random()*n,0.1,0.95);
}

n=clamp(n+amount,0,0.994);
return NProgress.set(n);
}
};

NProgress.trickle=function(){
return NProgress.inc(Math.random()*Settings.trickleRate);
};

/**
   * Waits for all supplied jQuery promises and
   * increases the progress as the promises resolve.
   *
   * @param $promise jQUery Promise
   */
(function(){
var initial=0,current=0;

NProgress.promise=function($promise){
if(!$promise||$promise.state()==="resolved"){
return this;
}

if(current===0){
NProgress.start();
}

initial++;
current++;

$promise.always(function(){
current--;
if(current===0){
initial=0;
NProgress.done();
}else {
NProgress.set((initial-current)/initial);
}
});

return this;
};

})();

/**
   * (Internal) renders the progress bar markup based on the `template`
   * setting.
   */

NProgress.render=function(fromStart){
if(NProgress.isRendered())return document.getElementById('nprogress');

addClass(document.documentElement,'nprogress-busy');

var progress=document.createElement('div');
progress.id='nprogress';
progress.innerHTML=Settings.template;

var bar=progress.querySelector(Settings.barSelector),
perc=fromStart?'-100':toBarPerc(NProgress.status||0),
parent=document.querySelector(Settings.parent),
spinner;

css(bar,{
transition:'all 0 linear',
transform:'translate3d('+perc+'%,0,0)'});


if(!Settings.showSpinner){
spinner=progress.querySelector(Settings.spinnerSelector);
spinner&&removeElement(spinner);
}

if(parent!=document.body){
addClass(parent,'nprogress-custom-parent');
}

parent.appendChild(progress);
return progress;
};

/**
   * Removes the element. Opposite of render().
   */

NProgress.remove=function(){
removeClass(document.documentElement,'nprogress-busy');
removeClass(document.querySelector(Settings.parent),'nprogress-custom-parent');
var progress=document.getElementById('nprogress');
progress&&removeElement(progress);
};

/**
   * Checks if the progress bar is rendered.
   */

NProgress.isRendered=function(){
return !!document.getElementById('nprogress');
};

/**
   * Determine which positioning CSS rule to use.
   */

NProgress.getPositioningCSS=function(){
// Sniff on document.body.style
var bodyStyle=document.body.style;

// Sniff prefixes
var vendorPrefix='WebkitTransform'in bodyStyle?'Webkit':
'MozTransform'in bodyStyle?'Moz':
'msTransform'in bodyStyle?'ms':
'OTransform'in bodyStyle?'O':'';

if(vendorPrefix+'Perspective'in bodyStyle){
// Modern browsers with 3D support, e.g. Webkit, IE10
return 'translate3d';
}else if(vendorPrefix+'Transform'in bodyStyle){
// Browsers without 3D support, e.g. IE9
return 'translate';
}else {
// Browsers without translate() support, e.g. IE7-8
return 'margin';
}
};

/**
   * Helpers
   */

function clamp(n,min,max){
if(n<min)return min;
if(n>max)return max;
return n;
}

/**
   * (Internal) converts a percentage (`0..1`) to a bar translateX
   * percentage (`-100%..0%`).
   */

function toBarPerc(n){
return (-1+n)*100;
}


/**
   * (Internal) returns the correct CSS for changing the bar's
   * position given an n percentage, and speed and ease from Settings
   */

function barPositionCSS(n,speed,ease){
var barCSS;

if(Settings.positionUsing==='translate3d'){
barCSS={transform:'translate3d('+toBarPerc(n)+'%,0,0)'};
}else if(Settings.positionUsing==='translate'){
barCSS={transform:'translate('+toBarPerc(n)+'%,0)'};
}else {
barCSS={'margin-left':toBarPerc(n)+'%'};
}

barCSS.transition='all '+speed+'ms '+ease;

return barCSS;
}

/**
   * (Internal) Queues a function to be executed.
   */

var queue=function(){
var pending=[];

function next(){
var fn=pending.shift();
if(fn){
fn(next);
}
}

return function(fn){
pending.push(fn);
if(pending.length==1)next();
};
}();

/**
   * (Internal) Applies css properties to an element, similar to the jQuery 
   * css method.
   *
   * While this helper does assist with vendor prefixed property names, it 
   * does not perform any manipulation of values prior to setting styles.
   */

var css=function(){
var cssPrefixes=['Webkit','O','Moz','ms'],
cssProps={};

function camelCase(string){
return string.replace(/^-ms-/,'ms-').replace(/-([\da-z])/gi,function(match,letter){
return letter.toUpperCase();
});
}

function getVendorProp(name){
var style=document.body.style;
if(name in style)return name;

var i=cssPrefixes.length,
capName=name.charAt(0).toUpperCase()+name.slice(1),
vendorName;
while(i--){
vendorName=cssPrefixes[i]+capName;
if(vendorName in style)return vendorName;
}

return name;
}

function getStyleProp(name){
name=camelCase(name);
return cssProps[name]||(cssProps[name]=getVendorProp(name));
}

function applyCss(element,prop,value){
prop=getStyleProp(prop);
element.style[prop]=value;
}

return function(element,properties){
var args=arguments,
prop,
value;

if(args.length==2){
for(prop in properties){
value=properties[prop];
if(value!==undefined&&properties.hasOwnProperty(prop))applyCss(element,prop,value);
}
}else {
applyCss(element,args[1],args[2]);
}
};
}();

/**
   * (Internal) Determines if an element or space separated list of class names contains a class name.
   */

function hasClass(element,name){
var list=typeof element=='string'?element:classList(element);
return list.indexOf(' '+name+' ')>=0;
}

/**
   * (Internal) Adds a class to an element.
   */

function addClass(element,name){
var oldList=classList(element),
newList=oldList+name;

if(hasClass(oldList,name))return;

// Trim the opening space.
element.className=newList.substring(1);
}

/**
   * (Internal) Removes a class from an element.
   */

function removeClass(element,name){
var oldList=classList(element),
newList;

if(!hasClass(element,name))return;

// Replace the class name.
newList=oldList.replace(' '+name+' ',' ');

// Trim the opening and closing spaces.
element.className=newList.substring(1,newList.length-1);
}

/**
   * (Internal) Gets a space separated list of the class names on the element. 
   * The list is wrapped with a single space on each end to facilitate finding 
   * matches within the list.
   */

function classList(element){
return (' '+(element.className||'')+' ').replace(/\s+/gi,' ');
}

/**
   * (Internal) Removes an element from the DOM.
   */

function removeElement(element){
element&&element.parentNode&&element.parentNode.removeChild(element);
}

return NProgress;
});



/***/},

/***/"./node_modules/popper.js/dist/esm/popper.js":
/*!***************************************************!*\
  !*** ./node_modules/popper.js/dist/esm/popper.js ***!
  \***************************************************/
/*! exports provided: default */
/***/function node_modulesPopperJsDistEsmPopperJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* WEBPACK VAR INJECTION */(function(global){/**!
 * @fileOverview Kickass library to create and place poppers near their reference elements.
 * @version 1.16.1
 * @license
 * Copyright (c) 2016 Federico Zivolo and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var isBrowser=typeof window!=='undefined'&&typeof document!=='undefined'&&typeof navigator!=='undefined';

var timeoutDuration=function(){
var longerTimeoutBrowsers=['Edge','Trident','Firefox'];
for(var i=0;i<longerTimeoutBrowsers.length;i+=1){
if(isBrowser&&navigator.userAgent.indexOf(longerTimeoutBrowsers[i])>=0){
return 1;
}
}
return 0;
}();

function microtaskDebounce(fn){
var called=false;
return function(){
if(called){
return;
}
called=true;
window.Promise.resolve().then(function(){
called=false;
fn();
});
};
}

function taskDebounce(fn){
var scheduled=false;
return function(){
if(!scheduled){
scheduled=true;
setTimeout(function(){
scheduled=false;
fn();
},timeoutDuration);
}
};
}

var supportsMicroTasks=isBrowser&&window.Promise;

/**
* Create a debounced version of a method, that's asynchronously deferred
* but called in the minimum time possible.
*
* @method
* @memberof Popper.Utils
* @argument {Function} fn
* @returns {Function}
*/
var debounce=supportsMicroTasks?microtaskDebounce:taskDebounce;

/**
 * Check if the given variable is a function
 * @method
 * @memberof Popper.Utils
 * @argument {Any} functionToCheck - variable to check
 * @returns {Boolean} answer to: is a function?
 */
function isFunction(functionToCheck){
var getType={};
return functionToCheck&&getType.toString.call(functionToCheck)==='[object Function]';
}

/**
 * Get CSS computed property of the given element
 * @method
 * @memberof Popper.Utils
 * @argument {Eement} element
 * @argument {String} property
 */
function getStyleComputedProperty(element,property){
if(element.nodeType!==1){
return [];
}
// NOTE: 1 DOM access here
var window=element.ownerDocument.defaultView;
var css=window.getComputedStyle(element,null);
return property?css[property]:css;
}

/**
 * Returns the parentNode or the host of the element
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element
 * @returns {Element} parent
 */
function getParentNode(element){
if(element.nodeName==='HTML'){
return element;
}
return element.parentNode||element.host;
}

/**
 * Returns the scrolling parent of the given element
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element
 * @returns {Element} scroll parent
 */
function getScrollParent(element){
// Return body, `getScroll` will take care to get the correct `scrollTop` from it
if(!element){
return document.body;
}

switch(element.nodeName){
case'HTML':
case'BODY':
return element.ownerDocument.body;
case'#document':
return element.body;}


// Firefox want us to check `-x` and `-y` variations as well

var _getStyleComputedProp=getStyleComputedProperty(element),
overflow=_getStyleComputedProp.overflow,
overflowX=_getStyleComputedProp.overflowX,
overflowY=_getStyleComputedProp.overflowY;

if(/(auto|scroll|overlay)/.test(overflow+overflowY+overflowX)){
return element;
}

return getScrollParent(getParentNode(element));
}

/**
 * Returns the reference node of the reference object, or the reference object itself.
 * @method
 * @memberof Popper.Utils
 * @param {Element|Object} reference - the reference element (the popper will be relative to this)
 * @returns {Element} parent
 */
function getReferenceNode(reference){
return reference&&reference.referenceNode?reference.referenceNode:reference;
}

var isIE11=isBrowser&&!!(window.MSInputMethodContext&&document.documentMode);
var isIE10=isBrowser&&/MSIE 10/.test(navigator.userAgent);

/**
 * Determines if the browser is Internet Explorer
 * @method
 * @memberof Popper.Utils
 * @param {Number} version to check
 * @returns {Boolean} isIE
 */
function isIE(version){
if(version===11){
return isIE11;
}
if(version===10){
return isIE10;
}
return isIE11||isIE10;
}

/**
 * Returns the offset parent of the given element
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element
 * @returns {Element} offset parent
 */
function getOffsetParent(element){
if(!element){
return document.documentElement;
}

var noOffsetParent=isIE(10)?document.body:null;

// NOTE: 1 DOM access here
var offsetParent=element.offsetParent||null;
// Skip hidden elements which don't have an offsetParent
while(offsetParent===noOffsetParent&&element.nextElementSibling){
offsetParent=(element=element.nextElementSibling).offsetParent;
}

var nodeName=offsetParent&&offsetParent.nodeName;

if(!nodeName||nodeName==='BODY'||nodeName==='HTML'){
return element?element.ownerDocument.documentElement:document.documentElement;
}

// .offsetParent will return the closest TH, TD or TABLE in case
// no offsetParent is present, I hate this job...
if(['TH','TD','TABLE'].indexOf(offsetParent.nodeName)!==-1&&getStyleComputedProperty(offsetParent,'position')==='static'){
return getOffsetParent(offsetParent);
}

return offsetParent;
}

function isOffsetContainer(element){
var nodeName=element.nodeName;

if(nodeName==='BODY'){
return false;
}
return nodeName==='HTML'||getOffsetParent(element.firstElementChild)===element;
}

/**
 * Finds the root node (document, shadowDOM root) of the given element
 * @method
 * @memberof Popper.Utils
 * @argument {Element} node
 * @returns {Element} root node
 */
function getRoot(node){
if(node.parentNode!==null){
return getRoot(node.parentNode);
}

return node;
}

/**
 * Finds the offset parent common to the two provided nodes
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element1
 * @argument {Element} element2
 * @returns {Element} common offset parent
 */
function findCommonOffsetParent(element1,element2){
// This check is needed to avoid errors in case one of the elements isn't defined for any reason
if(!element1||!element1.nodeType||!element2||!element2.nodeType){
return document.documentElement;
}

// Here we make sure to give as "start" the element that comes first in the DOM
var order=element1.compareDocumentPosition(element2)&Node.DOCUMENT_POSITION_FOLLOWING;
var start=order?element1:element2;
var end=order?element2:element1;

// Get common ancestor container
var range=document.createRange();
range.setStart(start,0);
range.setEnd(end,0);
var commonAncestorContainer=range.commonAncestorContainer;

// Both nodes are inside #document

if(element1!==commonAncestorContainer&&element2!==commonAncestorContainer||start.contains(end)){
if(isOffsetContainer(commonAncestorContainer)){
return commonAncestorContainer;
}

return getOffsetParent(commonAncestorContainer);
}

// one of the nodes is inside shadowDOM, find which one
var element1root=getRoot(element1);
if(element1root.host){
return findCommonOffsetParent(element1root.host,element2);
}else {
return findCommonOffsetParent(element1,getRoot(element2).host);
}
}

/**
 * Gets the scroll value of the given element in the given side (top and left)
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element
 * @argument {String} side `top` or `left`
 * @returns {number} amount of scrolled pixels
 */
function getScroll(element){
var side=arguments.length>1&&arguments[1]!==undefined?arguments[1]:'top';

var upperSide=side==='top'?'scrollTop':'scrollLeft';
var nodeName=element.nodeName;

if(nodeName==='BODY'||nodeName==='HTML'){
var html=element.ownerDocument.documentElement;
var scrollingElement=element.ownerDocument.scrollingElement||html;
return scrollingElement[upperSide];
}

return element[upperSide];
}

/*
 * Sum or subtract the element scroll values (left and top) from a given rect object
 * @method
 * @memberof Popper.Utils
 * @param {Object} rect - Rect object you want to change
 * @param {HTMLElement} element - The element from the function reads the scroll values
 * @param {Boolean} subtract - set to true if you want to subtract the scroll values
 * @return {Object} rect - The modifier rect object
 */
function includeScroll(rect,element){
var subtract=arguments.length>2&&arguments[2]!==undefined?arguments[2]:false;

var scrollTop=getScroll(element,'top');
var scrollLeft=getScroll(element,'left');
var modifier=subtract?-1:1;
rect.top+=scrollTop*modifier;
rect.bottom+=scrollTop*modifier;
rect.left+=scrollLeft*modifier;
rect.right+=scrollLeft*modifier;
return rect;
}

/*
 * Helper to detect borders of a given element
 * @method
 * @memberof Popper.Utils
 * @param {CSSStyleDeclaration} styles
 * Result of `getStyleComputedProperty` on the given element
 * @param {String} axis - `x` or `y`
 * @return {number} borders - The borders size of the given axis
 */

function getBordersSize(styles,axis){
var sideA=axis==='x'?'Left':'Top';
var sideB=sideA==='Left'?'Right':'Bottom';

return parseFloat(styles['border'+sideA+'Width'])+parseFloat(styles['border'+sideB+'Width']);
}

function getSize(axis,body,html,computedStyle){
return Math.max(body['offset'+axis],body['scroll'+axis],html['client'+axis],html['offset'+axis],html['scroll'+axis],isIE(10)?parseInt(html['offset'+axis])+parseInt(computedStyle['margin'+(axis==='Height'?'Top':'Left')])+parseInt(computedStyle['margin'+(axis==='Height'?'Bottom':'Right')]):0);
}

function getWindowSizes(document){
var body=document.body;
var html=document.documentElement;
var computedStyle=isIE(10)&&getComputedStyle(html);

return {
height:getSize('Height',body,html,computedStyle),
width:getSize('Width',body,html,computedStyle)};

}

var classCallCheck=function classCallCheck(instance,Constructor){
if(!(instance instanceof Constructor)){
throw new TypeError("Cannot call a class as a function");
}
};

var createClass=function(){
function defineProperties(target,props){
for(var i=0;i<props.length;i++){
var descriptor=props[i];
descriptor.enumerable=descriptor.enumerable||false;
descriptor.configurable=true;
if("value"in descriptor)descriptor.writable=true;
Object.defineProperty(target,descriptor.key,descriptor);
}
}

return function(Constructor,protoProps,staticProps){
if(protoProps)defineProperties(Constructor.prototype,protoProps);
if(staticProps)defineProperties(Constructor,staticProps);
return Constructor;
};
}();





var defineProperty=function defineProperty(obj,key,value){
if(key in obj){
Object.defineProperty(obj,key,{
value:value,
enumerable:true,
configurable:true,
writable:true});

}else {
obj[key]=value;
}

return obj;
};

var _extends=Object.assign||function(target){
for(var i=1;i<arguments.length;i++){
var source=arguments[i];

for(var key in source){
if(Object.prototype.hasOwnProperty.call(source,key)){
target[key]=source[key];
}
}
}

return target;
};

/**
 * Given element offsets, generate an output similar to getBoundingClientRect
 * @method
 * @memberof Popper.Utils
 * @argument {Object} offsets
 * @returns {Object} ClientRect like output
 */
function getClientRect(offsets){
return _extends({},offsets,{
right:offsets.left+offsets.width,
bottom:offsets.top+offsets.height});

}

/**
 * Get bounding client rect of given element
 * @method
 * @memberof Popper.Utils
 * @param {HTMLElement} element
 * @return {Object} client rect
 */
function getBoundingClientRect(element){
var rect={};

// IE10 10 FIX: Please, don't ask, the element isn't
// considered in DOM in some circumstances...
// This isn't reproducible in IE10 compatibility mode of IE11
try{
if(isIE(10)){
rect=element.getBoundingClientRect();
var scrollTop=getScroll(element,'top');
var scrollLeft=getScroll(element,'left');
rect.top+=scrollTop;
rect.left+=scrollLeft;
rect.bottom+=scrollTop;
rect.right+=scrollLeft;
}else {
rect=element.getBoundingClientRect();
}
}catch(e){}

var result={
left:rect.left,
top:rect.top,
width:rect.right-rect.left,
height:rect.bottom-rect.top};


// subtract scrollbar size from sizes
var sizes=element.nodeName==='HTML'?getWindowSizes(element.ownerDocument):{};
var width=sizes.width||element.clientWidth||result.width;
var height=sizes.height||element.clientHeight||result.height;

var horizScrollbar=element.offsetWidth-width;
var vertScrollbar=element.offsetHeight-height;

// if an hypothetical scrollbar is detected, we must be sure it's not a `border`
// we make this check conditional for performance reasons
if(horizScrollbar||vertScrollbar){
var styles=getStyleComputedProperty(element);
horizScrollbar-=getBordersSize(styles,'x');
vertScrollbar-=getBordersSize(styles,'y');

result.width-=horizScrollbar;
result.height-=vertScrollbar;
}

return getClientRect(result);
}

function getOffsetRectRelativeToArbitraryNode(children,parent){
var fixedPosition=arguments.length>2&&arguments[2]!==undefined?arguments[2]:false;

var isIE10=isIE(10);
var isHTML=parent.nodeName==='HTML';
var childrenRect=getBoundingClientRect(children);
var parentRect=getBoundingClientRect(parent);
var scrollParent=getScrollParent(children);

var styles=getStyleComputedProperty(parent);
var borderTopWidth=parseFloat(styles.borderTopWidth);
var borderLeftWidth=parseFloat(styles.borderLeftWidth);

// In cases where the parent is fixed, we must ignore negative scroll in offset calc
if(fixedPosition&&isHTML){
parentRect.top=Math.max(parentRect.top,0);
parentRect.left=Math.max(parentRect.left,0);
}
var offsets=getClientRect({
top:childrenRect.top-parentRect.top-borderTopWidth,
left:childrenRect.left-parentRect.left-borderLeftWidth,
width:childrenRect.width,
height:childrenRect.height});

offsets.marginTop=0;
offsets.marginLeft=0;

// Subtract margins of documentElement in case it's being used as parent
// we do this only on HTML because it's the only element that behaves
// differently when margins are applied to it. The margins are included in
// the box of the documentElement, in the other cases not.
if(!isIE10&&isHTML){
var marginTop=parseFloat(styles.marginTop);
var marginLeft=parseFloat(styles.marginLeft);

offsets.top-=borderTopWidth-marginTop;
offsets.bottom-=borderTopWidth-marginTop;
offsets.left-=borderLeftWidth-marginLeft;
offsets.right-=borderLeftWidth-marginLeft;

// Attach marginTop and marginLeft because in some circumstances we may need them
offsets.marginTop=marginTop;
offsets.marginLeft=marginLeft;
}

if(isIE10&&!fixedPosition?parent.contains(scrollParent):parent===scrollParent&&scrollParent.nodeName!=='BODY'){
offsets=includeScroll(offsets,parent);
}

return offsets;
}

function getViewportOffsetRectRelativeToArtbitraryNode(element){
var excludeScroll=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;

var html=element.ownerDocument.documentElement;
var relativeOffset=getOffsetRectRelativeToArbitraryNode(element,html);
var width=Math.max(html.clientWidth,window.innerWidth||0);
var height=Math.max(html.clientHeight,window.innerHeight||0);

var scrollTop=!excludeScroll?getScroll(html):0;
var scrollLeft=!excludeScroll?getScroll(html,'left'):0;

var offset={
top:scrollTop-relativeOffset.top+relativeOffset.marginTop,
left:scrollLeft-relativeOffset.left+relativeOffset.marginLeft,
width:width,
height:height};


return getClientRect(offset);
}

/**
 * Check if the given element is fixed or is inside a fixed parent
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element
 * @argument {Element} customContainer
 * @returns {Boolean} answer to "isFixed?"
 */
function isFixed(element){
var nodeName=element.nodeName;
if(nodeName==='BODY'||nodeName==='HTML'){
return false;
}
if(getStyleComputedProperty(element,'position')==='fixed'){
return true;
}
var parentNode=getParentNode(element);
if(!parentNode){
return false;
}
return isFixed(parentNode);
}

/**
 * Finds the first parent of an element that has a transformed property defined
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element
 * @returns {Element} first transformed parent or documentElement
 */

function getFixedPositionOffsetParent(element){
// This check is needed to avoid errors in case one of the elements isn't defined for any reason
if(!element||!element.parentElement||isIE()){
return document.documentElement;
}
var el=element.parentElement;
while(el&&getStyleComputedProperty(el,'transform')==='none'){
el=el.parentElement;
}
return el||document.documentElement;
}

/**
 * Computed the boundaries limits and return them
 * @method
 * @memberof Popper.Utils
 * @param {HTMLElement} popper
 * @param {HTMLElement} reference
 * @param {number} padding
 * @param {HTMLElement} boundariesElement - Element used to define the boundaries
 * @param {Boolean} fixedPosition - Is in fixed position mode
 * @returns {Object} Coordinates of the boundaries
 */
function getBoundaries(popper,reference,padding,boundariesElement){
var fixedPosition=arguments.length>4&&arguments[4]!==undefined?arguments[4]:false;

// NOTE: 1 DOM access here

var boundaries={top:0,left:0};
var offsetParent=fixedPosition?getFixedPositionOffsetParent(popper):findCommonOffsetParent(popper,getReferenceNode(reference));

// Handle viewport case
if(boundariesElement==='viewport'){
boundaries=getViewportOffsetRectRelativeToArtbitraryNode(offsetParent,fixedPosition);
}else {
// Handle other cases based on DOM element used as boundaries
var boundariesNode=void 0;
if(boundariesElement==='scrollParent'){
boundariesNode=getScrollParent(getParentNode(reference));
if(boundariesNode.nodeName==='BODY'){
boundariesNode=popper.ownerDocument.documentElement;
}
}else if(boundariesElement==='window'){
boundariesNode=popper.ownerDocument.documentElement;
}else {
boundariesNode=boundariesElement;
}

var offsets=getOffsetRectRelativeToArbitraryNode(boundariesNode,offsetParent,fixedPosition);

// In case of HTML, we need a different computation
if(boundariesNode.nodeName==='HTML'&&!isFixed(offsetParent)){
var _getWindowSizes=getWindowSizes(popper.ownerDocument),
height=_getWindowSizes.height,
width=_getWindowSizes.width;

boundaries.top+=offsets.top-offsets.marginTop;
boundaries.bottom=height+offsets.top;
boundaries.left+=offsets.left-offsets.marginLeft;
boundaries.right=width+offsets.left;
}else {
// for all the other DOM elements, this one is good
boundaries=offsets;
}
}

// Add paddings
padding=padding||0;
var isPaddingNumber=typeof padding==='number';
boundaries.left+=isPaddingNumber?padding:padding.left||0;
boundaries.top+=isPaddingNumber?padding:padding.top||0;
boundaries.right-=isPaddingNumber?padding:padding.right||0;
boundaries.bottom-=isPaddingNumber?padding:padding.bottom||0;

return boundaries;
}

function getArea(_ref){
var width=_ref.width,
height=_ref.height;

return width*height;
}

/**
 * Utility used to transform the `auto` placement to the placement with more
 * available space.
 * @method
 * @memberof Popper.Utils
 * @argument {Object} data - The data object generated by update method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function computeAutoPlacement(placement,refRect,popper,reference,boundariesElement){
var padding=arguments.length>5&&arguments[5]!==undefined?arguments[5]:0;

if(placement.indexOf('auto')===-1){
return placement;
}

var boundaries=getBoundaries(popper,reference,padding,boundariesElement);

var rects={
top:{
width:boundaries.width,
height:refRect.top-boundaries.top},

right:{
width:boundaries.right-refRect.right,
height:boundaries.height},

bottom:{
width:boundaries.width,
height:boundaries.bottom-refRect.bottom},

left:{
width:refRect.left-boundaries.left,
height:boundaries.height}};



var sortedAreas=Object.keys(rects).map(function(key){
return _extends({
key:key},
rects[key],{
area:getArea(rects[key])});

}).sort(function(a,b){
return b.area-a.area;
});

var filteredAreas=sortedAreas.filter(function(_ref2){
var width=_ref2.width,
height=_ref2.height;
return width>=popper.clientWidth&&height>=popper.clientHeight;
});

var computedPlacement=filteredAreas.length>0?filteredAreas[0].key:sortedAreas[0].key;

var variation=placement.split('-')[1];

return computedPlacement+(variation?'-'+variation:'');
}

/**
 * Get offsets to the reference element
 * @method
 * @memberof Popper.Utils
 * @param {Object} state
 * @param {Element} popper - the popper element
 * @param {Element} reference - the reference element (the popper will be relative to this)
 * @param {Element} fixedPosition - is in fixed position mode
 * @returns {Object} An object containing the offsets which will be applied to the popper
 */
function getReferenceOffsets(state,popper,reference){
var fixedPosition=arguments.length>3&&arguments[3]!==undefined?arguments[3]:null;

var commonOffsetParent=fixedPosition?getFixedPositionOffsetParent(popper):findCommonOffsetParent(popper,getReferenceNode(reference));
return getOffsetRectRelativeToArbitraryNode(reference,commonOffsetParent,fixedPosition);
}

/**
 * Get the outer sizes of the given element (offset size + margins)
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element
 * @returns {Object} object containing width and height properties
 */
function getOuterSizes(element){
var window=element.ownerDocument.defaultView;
var styles=window.getComputedStyle(element);
var x=parseFloat(styles.marginTop||0)+parseFloat(styles.marginBottom||0);
var y=parseFloat(styles.marginLeft||0)+parseFloat(styles.marginRight||0);
var result={
width:element.offsetWidth+y,
height:element.offsetHeight+x};

return result;
}

/**
 * Get the opposite placement of the given one
 * @method
 * @memberof Popper.Utils
 * @argument {String} placement
 * @returns {String} flipped placement
 */
function getOppositePlacement(placement){
var hash={left:'right',right:'left',bottom:'top',top:'bottom'};
return placement.replace(/left|right|bottom|top/g,function(matched){
return hash[matched];
});
}

/**
 * Get offsets to the popper
 * @method
 * @memberof Popper.Utils
 * @param {Object} position - CSS position the Popper will get applied
 * @param {HTMLElement} popper - the popper element
 * @param {Object} referenceOffsets - the reference offsets (the popper will be relative to this)
 * @param {String} placement - one of the valid placement options
 * @returns {Object} popperOffsets - An object containing the offsets which will be applied to the popper
 */
function getPopperOffsets(popper,referenceOffsets,placement){
placement=placement.split('-')[0];

// Get popper node sizes
var popperRect=getOuterSizes(popper);

// Add position, width and height to our offsets object
var popperOffsets={
width:popperRect.width,
height:popperRect.height};


// depending by the popper placement we have to compute its offsets slightly differently
var isHoriz=['right','left'].indexOf(placement)!==-1;
var mainSide=isHoriz?'top':'left';
var secondarySide=isHoriz?'left':'top';
var measurement=isHoriz?'height':'width';
var secondaryMeasurement=!isHoriz?'height':'width';

popperOffsets[mainSide]=referenceOffsets[mainSide]+referenceOffsets[measurement]/2-popperRect[measurement]/2;
if(placement===secondarySide){
popperOffsets[secondarySide]=referenceOffsets[secondarySide]-popperRect[secondaryMeasurement];
}else {
popperOffsets[secondarySide]=referenceOffsets[getOppositePlacement(secondarySide)];
}

return popperOffsets;
}

/**
 * Mimics the `find` method of Array
 * @method
 * @memberof Popper.Utils
 * @argument {Array} arr
 * @argument prop
 * @argument value
 * @returns index or -1
 */
function find(arr,check){
// use native find if supported
if(Array.prototype.find){
return arr.find(check);
}

// use `filter` to obtain the same behavior of `find`
return arr.filter(check)[0];
}

/**
 * Return the index of the matching object
 * @method
 * @memberof Popper.Utils
 * @argument {Array} arr
 * @argument prop
 * @argument value
 * @returns index or -1
 */
function findIndex(arr,prop,value){
// use native findIndex if supported
if(Array.prototype.findIndex){
return arr.findIndex(function(cur){
return cur[prop]===value;
});
}

// use `find` + `indexOf` if `findIndex` isn't supported
var match=find(arr,function(obj){
return obj[prop]===value;
});
return arr.indexOf(match);
}

/**
 * Loop trough the list of modifiers and run them in order,
 * each of them will then edit the data object.
 * @method
 * @memberof Popper.Utils
 * @param {dataObject} data
 * @param {Array} modifiers
 * @param {String} ends - Optional modifier name used as stopper
 * @returns {dataObject}
 */
function runModifiers(modifiers,data,ends){
var modifiersToRun=ends===undefined?modifiers:modifiers.slice(0,findIndex(modifiers,'name',ends));

modifiersToRun.forEach(function(modifier){
if(modifier['function']){
// eslint-disable-line dot-notation
console.warn('`modifier.function` is deprecated, use `modifier.fn`!');
}
var fn=modifier['function']||modifier.fn;// eslint-disable-line dot-notation
if(modifier.enabled&&isFunction(fn)){
// Add properties to offsets to make them a complete clientRect object
// we do this before each modifier to make sure the previous one doesn't
// mess with these values
data.offsets.popper=getClientRect(data.offsets.popper);
data.offsets.reference=getClientRect(data.offsets.reference);

data=fn(data,modifier);
}
});

return data;
}

/**
 * Updates the position of the popper, computing the new offsets and applying
 * the new style.<br />
 * Prefer `scheduleUpdate` over `update` because of performance reasons.
 * @method
 * @memberof Popper
 */
function update(){
// if popper is destroyed, don't perform any further update
if(this.state.isDestroyed){
return;
}

var data={
instance:this,
styles:{},
arrowStyles:{},
attributes:{},
flipped:false,
offsets:{}};


// compute reference element offsets
data.offsets.reference=getReferenceOffsets(this.state,this.popper,this.reference,this.options.positionFixed);

// compute auto placement, store placement inside the data object,
// modifiers will be able to edit `placement` if needed
// and refer to originalPlacement to know the original value
data.placement=computeAutoPlacement(this.options.placement,data.offsets.reference,this.popper,this.reference,this.options.modifiers.flip.boundariesElement,this.options.modifiers.flip.padding);

// store the computed placement inside `originalPlacement`
data.originalPlacement=data.placement;

data.positionFixed=this.options.positionFixed;

// compute the popper offsets
data.offsets.popper=getPopperOffsets(this.popper,data.offsets.reference,data.placement);

data.offsets.popper.position=this.options.positionFixed?'fixed':'absolute';

// run the modifiers
data=runModifiers(this.modifiers,data);

// the first `update` will call `onCreate` callback
// the other ones will call `onUpdate` callback
if(!this.state.isCreated){
this.state.isCreated=true;
this.options.onCreate(data);
}else {
this.options.onUpdate(data);
}
}

/**
 * Helper used to know if the given modifier is enabled.
 * @method
 * @memberof Popper.Utils
 * @returns {Boolean}
 */
function isModifierEnabled(modifiers,modifierName){
return modifiers.some(function(_ref){
var name=_ref.name,
enabled=_ref.enabled;
return enabled&&name===modifierName;
});
}

/**
 * Get the prefixed supported property name
 * @method
 * @memberof Popper.Utils
 * @argument {String} property (camelCase)
 * @returns {String} prefixed property (camelCase or PascalCase, depending on the vendor prefix)
 */
function getSupportedPropertyName(property){
var prefixes=[false,'ms','Webkit','Moz','O'];
var upperProp=property.charAt(0).toUpperCase()+property.slice(1);

for(var i=0;i<prefixes.length;i++){
var prefix=prefixes[i];
var toCheck=prefix?''+prefix+upperProp:property;
if(typeof document.body.style[toCheck]!=='undefined'){
return toCheck;
}
}
return null;
}

/**
 * Destroys the popper.
 * @method
 * @memberof Popper
 */
function destroy(){
this.state.isDestroyed=true;

// touch DOM only if `applyStyle` modifier is enabled
if(isModifierEnabled(this.modifiers,'applyStyle')){
this.popper.removeAttribute('x-placement');
this.popper.style.position='';
this.popper.style.top='';
this.popper.style.left='';
this.popper.style.right='';
this.popper.style.bottom='';
this.popper.style.willChange='';
this.popper.style[getSupportedPropertyName('transform')]='';
}

this.disableEventListeners();

// remove the popper if user explicitly asked for the deletion on destroy
// do not use `remove` because IE11 doesn't support it
if(this.options.removeOnDestroy){
this.popper.parentNode.removeChild(this.popper);
}
return this;
}

/**
 * Get the window associated with the element
 * @argument {Element} element
 * @returns {Window}
 */
function getWindow(element){
var ownerDocument=element.ownerDocument;
return ownerDocument?ownerDocument.defaultView:window;
}

function attachToScrollParents(scrollParent,event,callback,scrollParents){
var isBody=scrollParent.nodeName==='BODY';
var target=isBody?scrollParent.ownerDocument.defaultView:scrollParent;
target.addEventListener(event,callback,{passive:true});

if(!isBody){
attachToScrollParents(getScrollParent(target.parentNode),event,callback,scrollParents);
}
scrollParents.push(target);
}

/**
 * Setup needed event listeners used to update the popper position
 * @method
 * @memberof Popper.Utils
 * @private
 */
function setupEventListeners(reference,options,state,updateBound){
// Resize event listener on window
state.updateBound=updateBound;
getWindow(reference).addEventListener('resize',state.updateBound,{passive:true});

// Scroll event listener on scroll parents
var scrollElement=getScrollParent(reference);
attachToScrollParents(scrollElement,'scroll',state.updateBound,state.scrollParents);
state.scrollElement=scrollElement;
state.eventsEnabled=true;

return state;
}

/**
 * It will add resize/scroll events and start recalculating
 * position of the popper element when they are triggered.
 * @method
 * @memberof Popper
 */
function enableEventListeners(){
if(!this.state.eventsEnabled){
this.state=setupEventListeners(this.reference,this.options,this.state,this.scheduleUpdate);
}
}

/**
 * Remove event listeners used to update the popper position
 * @method
 * @memberof Popper.Utils
 * @private
 */
function removeEventListeners(reference,state){
// Remove resize event listener on window
getWindow(reference).removeEventListener('resize',state.updateBound);

// Remove scroll event listener on scroll parents
state.scrollParents.forEach(function(target){
target.removeEventListener('scroll',state.updateBound);
});

// Reset state
state.updateBound=null;
state.scrollParents=[];
state.scrollElement=null;
state.eventsEnabled=false;
return state;
}

/**
 * It will remove resize/scroll events and won't recalculate popper position
 * when they are triggered. It also won't trigger `onUpdate` callback anymore,
 * unless you call `update` method manually.
 * @method
 * @memberof Popper
 */
function disableEventListeners(){
if(this.state.eventsEnabled){
cancelAnimationFrame(this.scheduleUpdate);
this.state=removeEventListeners(this.reference,this.state);
}
}

/**
 * Tells if a given input is a number
 * @method
 * @memberof Popper.Utils
 * @param {*} input to check
 * @return {Boolean}
 */
function isNumeric(n){
return n!==''&&!isNaN(parseFloat(n))&&isFinite(n);
}

/**
 * Set the style to the given popper
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element - Element to apply the style to
 * @argument {Object} styles
 * Object with a list of properties and values which will be applied to the element
 */
function setStyles(element,styles){
Object.keys(styles).forEach(function(prop){
var unit='';
// add unit if the value is numeric and is one of the following
if(['width','height','top','right','bottom','left'].indexOf(prop)!==-1&&isNumeric(styles[prop])){
unit='px';
}
element.style[prop]=styles[prop]+unit;
});
}

/**
 * Set the attributes to the given popper
 * @method
 * @memberof Popper.Utils
 * @argument {Element} element - Element to apply the attributes to
 * @argument {Object} styles
 * Object with a list of properties and values which will be applied to the element
 */
function setAttributes(element,attributes){
Object.keys(attributes).forEach(function(prop){
var value=attributes[prop];
if(value!==false){
element.setAttribute(prop,attributes[prop]);
}else {
element.removeAttribute(prop);
}
});
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by `update` method
 * @argument {Object} data.styles - List of style properties - values to apply to popper element
 * @argument {Object} data.attributes - List of attribute properties - values to apply to popper element
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The same data object
 */
function applyStyle(data){
// any property present in `data.styles` will be applied to the popper,
// in this way we can make the 3rd party modifiers add custom styles to it
// Be aware, modifiers could override the properties defined in the previous
// lines of this modifier!
setStyles(data.instance.popper,data.styles);

// any property present in `data.attributes` will be applied to the popper,
// they will be set as HTML attributes of the element
setAttributes(data.instance.popper,data.attributes);

// if arrowElement is defined and arrowStyles has some properties
if(data.arrowElement&&Object.keys(data.arrowStyles).length){
setStyles(data.arrowElement,data.arrowStyles);
}

return data;
}

/**
 * Set the x-placement attribute before everything else because it could be used
 * to add margins to the popper margins needs to be calculated to get the
 * correct popper offsets.
 * @method
 * @memberof Popper.modifiers
 * @param {HTMLElement} reference - The reference element used to position the popper
 * @param {HTMLElement} popper - The HTML element used as popper
 * @param {Object} options - Popper.js options
 */
function applyStyleOnLoad(reference,popper,options,modifierOptions,state){
// compute reference element offsets
var referenceOffsets=getReferenceOffsets(state,popper,reference,options.positionFixed);

// compute auto placement, store placement inside the data object,
// modifiers will be able to edit `placement` if needed
// and refer to originalPlacement to know the original value
var placement=computeAutoPlacement(options.placement,referenceOffsets,popper,reference,options.modifiers.flip.boundariesElement,options.modifiers.flip.padding);

popper.setAttribute('x-placement',placement);

// Apply `position` to popper before anything else because
// without the position applied we can't guarantee correct computations
setStyles(popper,{position:options.positionFixed?'fixed':'absolute'});

return options;
}

/**
 * @function
 * @memberof Popper.Utils
 * @argument {Object} data - The data object generated by `update` method
 * @argument {Boolean} shouldRound - If the offsets should be rounded at all
 * @returns {Object} The popper's position offsets rounded
 *
 * The tale of pixel-perfect positioning. It's still not 100% perfect, but as
 * good as it can be within reason.
 * Discussion here: https://github.com/FezVrasta/popper.js/pull/715
 *
 * Low DPI screens cause a popper to be blurry if not using full pixels (Safari
 * as well on High DPI screens).
 *
 * Firefox prefers no rounding for positioning and does not have blurriness on
 * high DPI screens.
 *
 * Only horizontal placement and left/right values need to be considered.
 */
function getRoundedOffsets(data,shouldRound){
var _data$offsets=data.offsets,
popper=_data$offsets.popper,
reference=_data$offsets.reference;
var round=Math.round,
floor=Math.floor;

var noRound=function noRound(v){
return v;
};

var referenceWidth=round(reference.width);
var popperWidth=round(popper.width);

var isVertical=['left','right'].indexOf(data.placement)!==-1;
var isVariation=data.placement.indexOf('-')!==-1;
var sameWidthParity=referenceWidth%2===popperWidth%2;
var bothOddWidth=referenceWidth%2===1&&popperWidth%2===1;

var horizontalToInteger=!shouldRound?noRound:isVertical||isVariation||sameWidthParity?round:floor;
var verticalToInteger=!shouldRound?noRound:round;

return {
left:horizontalToInteger(bothOddWidth&&!isVariation&&shouldRound?popper.left-1:popper.left),
top:verticalToInteger(popper.top),
bottom:verticalToInteger(popper.bottom),
right:horizontalToInteger(popper.right)};

}

var isFirefox=isBrowser&&/Firefox/i.test(navigator.userAgent);

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by `update` method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function computeStyle(data,options){
var x=options.x,
y=options.y;
var popper=data.offsets.popper;

// Remove this legacy support in Popper.js v2

var legacyGpuAccelerationOption=find(data.instance.modifiers,function(modifier){
return modifier.name==='applyStyle';
}).gpuAcceleration;
if(legacyGpuAccelerationOption!==undefined){
console.warn('WARNING: `gpuAcceleration` option moved to `computeStyle` modifier and will not be supported in future versions of Popper.js!');
}
var gpuAcceleration=legacyGpuAccelerationOption!==undefined?legacyGpuAccelerationOption:options.gpuAcceleration;

var offsetParent=getOffsetParent(data.instance.popper);
var offsetParentRect=getBoundingClientRect(offsetParent);

// Styles
var styles={
position:popper.position};


var offsets=getRoundedOffsets(data,window.devicePixelRatio<2||!isFirefox);

var sideA=x==='bottom'?'top':'bottom';
var sideB=y==='right'?'left':'right';

// if gpuAcceleration is set to `true` and transform is supported,
//  we use `translate3d` to apply the position to the popper we
// automatically use the supported prefixed version if needed
var prefixedProperty=getSupportedPropertyName('transform');

// now, let's make a step back and look at this code closely (wtf?)
// If the content of the popper grows once it's been positioned, it
// may happen that the popper gets misplaced because of the new content
// overflowing its reference element
// To avoid this problem, we provide two options (x and y), which allow
// the consumer to define the offset origin.
// If we position a popper on top of a reference element, we can set
// `x` to `top` to make the popper grow towards its top instead of
// its bottom.
var left=void 0,
top=void 0;
if(sideA==='bottom'){
// when offsetParent is <html> the positioning is relative to the bottom of the screen (excluding the scrollbar)
// and not the bottom of the html element
if(offsetParent.nodeName==='HTML'){
top=-offsetParent.clientHeight+offsets.bottom;
}else {
top=-offsetParentRect.height+offsets.bottom;
}
}else {
top=offsets.top;
}
if(sideB==='right'){
if(offsetParent.nodeName==='HTML'){
left=-offsetParent.clientWidth+offsets.right;
}else {
left=-offsetParentRect.width+offsets.right;
}
}else {
left=offsets.left;
}
if(gpuAcceleration&&prefixedProperty){
styles[prefixedProperty]='translate3d('+left+'px, '+top+'px, 0)';
styles[sideA]=0;
styles[sideB]=0;
styles.willChange='transform';
}else {
// othwerise, we use the standard `top`, `left`, `bottom` and `right` properties
var invertTop=sideA==='bottom'?-1:1;
var invertLeft=sideB==='right'?-1:1;
styles[sideA]=top*invertTop;
styles[sideB]=left*invertLeft;
styles.willChange=sideA+', '+sideB;
}

// Attributes
var attributes={
'x-placement':data.placement};


// Update `data` attributes, styles and arrowStyles
data.attributes=_extends({},attributes,data.attributes);
data.styles=_extends({},styles,data.styles);
data.arrowStyles=_extends({},data.offsets.arrow,data.arrowStyles);

return data;
}

/**
 * Helper used to know if the given modifier depends from another one.<br />
 * It checks if the needed modifier is listed and enabled.
 * @method
 * @memberof Popper.Utils
 * @param {Array} modifiers - list of modifiers
 * @param {String} requestingName - name of requesting modifier
 * @param {String} requestedName - name of requested modifier
 * @returns {Boolean}
 */
function isModifierRequired(modifiers,requestingName,requestedName){
var requesting=find(modifiers,function(_ref){
var name=_ref.name;
return name===requestingName;
});

var isRequired=!!requesting&&modifiers.some(function(modifier){
return modifier.name===requestedName&&modifier.enabled&&modifier.order<requesting.order;
});

if(!isRequired){
var _requesting='`'+requestingName+'`';
var requested='`'+requestedName+'`';
console.warn(requested+' modifier is required by '+_requesting+' modifier in order to work, be sure to include it before '+_requesting+'!');
}
return isRequired;
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by update method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function arrow(data,options){
var _data$offsets$arrow;

// arrow depends on keepTogether in order to work
if(!isModifierRequired(data.instance.modifiers,'arrow','keepTogether')){
return data;
}

var arrowElement=options.element;

// if arrowElement is a string, suppose it's a CSS selector
if(typeof arrowElement==='string'){
arrowElement=data.instance.popper.querySelector(arrowElement);

// if arrowElement is not found, don't run the modifier
if(!arrowElement){
return data;
}
}else {
// if the arrowElement isn't a query selector we must check that the
// provided DOM node is child of its popper node
if(!data.instance.popper.contains(arrowElement)){
console.warn('WARNING: `arrow.element` must be child of its popper element!');
return data;
}
}

var placement=data.placement.split('-')[0];
var _data$offsets=data.offsets,
popper=_data$offsets.popper,
reference=_data$offsets.reference;

var isVertical=['left','right'].indexOf(placement)!==-1;

var len=isVertical?'height':'width';
var sideCapitalized=isVertical?'Top':'Left';
var side=sideCapitalized.toLowerCase();
var altSide=isVertical?'left':'top';
var opSide=isVertical?'bottom':'right';
var arrowElementSize=getOuterSizes(arrowElement)[len];

//
// extends keepTogether behavior making sure the popper and its
// reference have enough pixels in conjunction
//

// top/left side
if(reference[opSide]-arrowElementSize<popper[side]){
data.offsets.popper[side]-=popper[side]-(reference[opSide]-arrowElementSize);
}
// bottom/right side
if(reference[side]+arrowElementSize>popper[opSide]){
data.offsets.popper[side]+=reference[side]+arrowElementSize-popper[opSide];
}
data.offsets.popper=getClientRect(data.offsets.popper);

// compute center of the popper
var center=reference[side]+reference[len]/2-arrowElementSize/2;

// Compute the sideValue using the updated popper offsets
// take popper margin in account because we don't have this info available
var css=getStyleComputedProperty(data.instance.popper);
var popperMarginSide=parseFloat(css['margin'+sideCapitalized]);
var popperBorderSide=parseFloat(css['border'+sideCapitalized+'Width']);
var sideValue=center-data.offsets.popper[side]-popperMarginSide-popperBorderSide;

// prevent arrowElement from being placed not contiguously to its popper
sideValue=Math.max(Math.min(popper[len]-arrowElementSize,sideValue),0);

data.arrowElement=arrowElement;
data.offsets.arrow=(_data$offsets$arrow={},defineProperty(_data$offsets$arrow,side,Math.round(sideValue)),defineProperty(_data$offsets$arrow,altSide,''),_data$offsets$arrow);

return data;
}

/**
 * Get the opposite placement variation of the given one
 * @method
 * @memberof Popper.Utils
 * @argument {String} placement variation
 * @returns {String} flipped placement variation
 */
function getOppositeVariation(variation){
if(variation==='end'){
return 'start';
}else if(variation==='start'){
return 'end';
}
return variation;
}

/**
 * List of accepted placements to use as values of the `placement` option.<br />
 * Valid placements are:
 * - `auto`
 * - `top`
 * - `right`
 * - `bottom`
 * - `left`
 *
 * Each placement can have a variation from this list:
 * - `-start`
 * - `-end`
 *
 * Variations are interpreted easily if you think of them as the left to right
 * written languages. Horizontally (`top` and `bottom`), `start` is left and `end`
 * is right.<br />
 * Vertically (`left` and `right`), `start` is top and `end` is bottom.
 *
 * Some valid examples are:
 * - `top-end` (on top of reference, right aligned)
 * - `right-start` (on right of reference, top aligned)
 * - `bottom` (on bottom, centered)
 * - `auto-end` (on the side with more space available, alignment depends by placement)
 *
 * @static
 * @type {Array}
 * @enum {String}
 * @readonly
 * @method placements
 * @memberof Popper
 */
var placements=['auto-start','auto','auto-end','top-start','top','top-end','right-start','right','right-end','bottom-end','bottom','bottom-start','left-end','left','left-start'];

// Get rid of `auto` `auto-start` and `auto-end`
var validPlacements=placements.slice(3);

/**
 * Given an initial placement, returns all the subsequent placements
 * clockwise (or counter-clockwise).
 *
 * @method
 * @memberof Popper.Utils
 * @argument {String} placement - A valid placement (it accepts variations)
 * @argument {Boolean} counter - Set to true to walk the placements counterclockwise
 * @returns {Array} placements including their variations
 */
function clockwise(placement){
var counter=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;

var index=validPlacements.indexOf(placement);
var arr=validPlacements.slice(index+1).concat(validPlacements.slice(0,index));
return counter?arr.reverse():arr;
}

var BEHAVIORS={
FLIP:'flip',
CLOCKWISE:'clockwise',
COUNTERCLOCKWISE:'counterclockwise'};


/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by update method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function flip(data,options){
// if `inner` modifier is enabled, we can't use the `flip` modifier
if(isModifierEnabled(data.instance.modifiers,'inner')){
return data;
}

if(data.flipped&&data.placement===data.originalPlacement){
// seems like flip is trying to loop, probably there's not enough space on any of the flippable sides
return data;
}

var boundaries=getBoundaries(data.instance.popper,data.instance.reference,options.padding,options.boundariesElement,data.positionFixed);

var placement=data.placement.split('-')[0];
var placementOpposite=getOppositePlacement(placement);
var variation=data.placement.split('-')[1]||'';

var flipOrder=[];

switch(options.behavior){
case BEHAVIORS.FLIP:
flipOrder=[placement,placementOpposite];
break;
case BEHAVIORS.CLOCKWISE:
flipOrder=clockwise(placement);
break;
case BEHAVIORS.COUNTERCLOCKWISE:
flipOrder=clockwise(placement,true);
break;
default:
flipOrder=options.behavior;}


flipOrder.forEach(function(step,index){
if(placement!==step||flipOrder.length===index+1){
return data;
}

placement=data.placement.split('-')[0];
placementOpposite=getOppositePlacement(placement);

var popperOffsets=data.offsets.popper;
var refOffsets=data.offsets.reference;

// using floor because the reference offsets may contain decimals we are not going to consider here
var floor=Math.floor;
var overlapsRef=placement==='left'&&floor(popperOffsets.right)>floor(refOffsets.left)||placement==='right'&&floor(popperOffsets.left)<floor(refOffsets.right)||placement==='top'&&floor(popperOffsets.bottom)>floor(refOffsets.top)||placement==='bottom'&&floor(popperOffsets.top)<floor(refOffsets.bottom);

var overflowsLeft=floor(popperOffsets.left)<floor(boundaries.left);
var overflowsRight=floor(popperOffsets.right)>floor(boundaries.right);
var overflowsTop=floor(popperOffsets.top)<floor(boundaries.top);
var overflowsBottom=floor(popperOffsets.bottom)>floor(boundaries.bottom);

var overflowsBoundaries=placement==='left'&&overflowsLeft||placement==='right'&&overflowsRight||placement==='top'&&overflowsTop||placement==='bottom'&&overflowsBottom;

// flip the variation if required
var isVertical=['top','bottom'].indexOf(placement)!==-1;

// flips variation if reference element overflows boundaries
var flippedVariationByRef=!!options.flipVariations&&(isVertical&&variation==='start'&&overflowsLeft||isVertical&&variation==='end'&&overflowsRight||!isVertical&&variation==='start'&&overflowsTop||!isVertical&&variation==='end'&&overflowsBottom);

// flips variation if popper content overflows boundaries
var flippedVariationByContent=!!options.flipVariationsByContent&&(isVertical&&variation==='start'&&overflowsRight||isVertical&&variation==='end'&&overflowsLeft||!isVertical&&variation==='start'&&overflowsBottom||!isVertical&&variation==='end'&&overflowsTop);

var flippedVariation=flippedVariationByRef||flippedVariationByContent;

if(overlapsRef||overflowsBoundaries||flippedVariation){
// this boolean to detect any flip loop
data.flipped=true;

if(overlapsRef||overflowsBoundaries){
placement=flipOrder[index+1];
}

if(flippedVariation){
variation=getOppositeVariation(variation);
}

data.placement=placement+(variation?'-'+variation:'');

// this object contains `position`, we want to preserve it along with
// any additional property we may add in the future
data.offsets.popper=_extends({},data.offsets.popper,getPopperOffsets(data.instance.popper,data.offsets.reference,data.placement));

data=runModifiers(data.instance.modifiers,data,'flip');
}
});
return data;
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by update method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function keepTogether(data){
var _data$offsets=data.offsets,
popper=_data$offsets.popper,
reference=_data$offsets.reference;

var placement=data.placement.split('-')[0];
var floor=Math.floor;
var isVertical=['top','bottom'].indexOf(placement)!==-1;
var side=isVertical?'right':'bottom';
var opSide=isVertical?'left':'top';
var measurement=isVertical?'width':'height';

if(popper[side]<floor(reference[opSide])){
data.offsets.popper[opSide]=floor(reference[opSide])-popper[measurement];
}
if(popper[opSide]>floor(reference[side])){
data.offsets.popper[opSide]=floor(reference[side]);
}

return data;
}

/**
 * Converts a string containing value + unit into a px value number
 * @function
 * @memberof {modifiers~offset}
 * @private
 * @argument {String} str - Value + unit string
 * @argument {String} measurement - `height` or `width`
 * @argument {Object} popperOffsets
 * @argument {Object} referenceOffsets
 * @returns {Number|String}
 * Value in pixels, or original string if no values were extracted
 */
function toValue(str,measurement,popperOffsets,referenceOffsets){
// separate value from unit
var split=str.match(/((?:\-|\+)?\d*\.?\d*)(.*)/);
var value=+split[1];
var unit=split[2];

// If it's not a number it's an operator, I guess
if(!value){
return str;
}

if(unit.indexOf('%')===0){
var element=void 0;
switch(unit){
case'%p':
element=popperOffsets;
break;
case'%':
case'%r':
default:
element=referenceOffsets;}


var rect=getClientRect(element);
return rect[measurement]/100*value;
}else if(unit==='vh'||unit==='vw'){
// if is a vh or vw, we calculate the size based on the viewport
var size=void 0;
if(unit==='vh'){
size=Math.max(document.documentElement.clientHeight,window.innerHeight||0);
}else {
size=Math.max(document.documentElement.clientWidth,window.innerWidth||0);
}
return size/100*value;
}else {
// if is an explicit pixel unit, we get rid of the unit and keep the value
// if is an implicit unit, it's px, and we return just the value
return value;
}
}

/**
 * Parse an `offset` string to extrapolate `x` and `y` numeric offsets.
 * @function
 * @memberof {modifiers~offset}
 * @private
 * @argument {String} offset
 * @argument {Object} popperOffsets
 * @argument {Object} referenceOffsets
 * @argument {String} basePlacement
 * @returns {Array} a two cells array with x and y offsets in numbers
 */
function parseOffset(offset,popperOffsets,referenceOffsets,basePlacement){
var offsets=[0,0];

// Use height if placement is left or right and index is 0 otherwise use width
// in this way the first offset will use an axis and the second one
// will use the other one
var useHeight=['right','left'].indexOf(basePlacement)!==-1;

// Split the offset string to obtain a list of values and operands
// The regex addresses values with the plus or minus sign in front (+10, -20, etc)
var fragments=offset.split(/(\+|\-)/).map(function(frag){
return frag.trim();
});

// Detect if the offset string contains a pair of values or a single one
// they could be separated by comma or space
var divider=fragments.indexOf(find(fragments,function(frag){
return frag.search(/,|\s/)!==-1;
}));

if(fragments[divider]&&fragments[divider].indexOf(',')===-1){
console.warn('Offsets separated by white space(s) are deprecated, use a comma (,) instead.');
}

// If divider is found, we divide the list of values and operands to divide
// them by ofset X and Y.
var splitRegex=/\s*,\s*|\s+/;
var ops=divider!==-1?[fragments.slice(0,divider).concat([fragments[divider].split(splitRegex)[0]]),[fragments[divider].split(splitRegex)[1]].concat(fragments.slice(divider+1))]:[fragments];

// Convert the values with units to absolute pixels to allow our computations
ops=ops.map(function(op,index){
// Most of the units rely on the orientation of the popper
var measurement=(index===1?!useHeight:useHeight)?'height':'width';
var mergeWithPrevious=false;
return op
// This aggregates any `+` or `-` sign that aren't considered operators
// e.g.: 10 + +5 => [10, +, +5]
.reduce(function(a,b){
if(a[a.length-1]===''&&['+','-'].indexOf(b)!==-1){
a[a.length-1]=b;
mergeWithPrevious=true;
return a;
}else if(mergeWithPrevious){
a[a.length-1]+=b;
mergeWithPrevious=false;
return a;
}else {
return a.concat(b);
}
},[])
// Here we convert the string values into number values (in px)
.map(function(str){
return toValue(str,measurement,popperOffsets,referenceOffsets);
});
});

// Loop trough the offsets arrays and execute the operations
ops.forEach(function(op,index){
op.forEach(function(frag,index2){
if(isNumeric(frag)){
offsets[index]+=frag*(op[index2-1]==='-'?-1:1);
}
});
});
return offsets;
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by update method
 * @argument {Object} options - Modifiers configuration and options
 * @argument {Number|String} options.offset=0
 * The offset value as described in the modifier description
 * @returns {Object} The data object, properly modified
 */
function offset(data,_ref){
var offset=_ref.offset;
var placement=data.placement,
_data$offsets=data.offsets,
popper=_data$offsets.popper,
reference=_data$offsets.reference;

var basePlacement=placement.split('-')[0];

var offsets=void 0;
if(isNumeric(+offset)){
offsets=[+offset,0];
}else {
offsets=parseOffset(offset,popper,reference,basePlacement);
}

if(basePlacement==='left'){
popper.top+=offsets[0];
popper.left-=offsets[1];
}else if(basePlacement==='right'){
popper.top+=offsets[0];
popper.left+=offsets[1];
}else if(basePlacement==='top'){
popper.left+=offsets[0];
popper.top-=offsets[1];
}else if(basePlacement==='bottom'){
popper.left+=offsets[0];
popper.top+=offsets[1];
}

data.popper=popper;
return data;
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by `update` method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function preventOverflow(data,options){
var boundariesElement=options.boundariesElement||getOffsetParent(data.instance.popper);

// If offsetParent is the reference element, we really want to
// go one step up and use the next offsetParent as reference to
// avoid to make this modifier completely useless and look like broken
if(data.instance.reference===boundariesElement){
boundariesElement=getOffsetParent(boundariesElement);
}

// NOTE: DOM access here
// resets the popper's position so that the document size can be calculated excluding
// the size of the popper element itself
var transformProp=getSupportedPropertyName('transform');
var popperStyles=data.instance.popper.style;// assignment to help minification
var top=popperStyles.top,
left=popperStyles.left,
transform=popperStyles[transformProp];

popperStyles.top='';
popperStyles.left='';
popperStyles[transformProp]='';

var boundaries=getBoundaries(data.instance.popper,data.instance.reference,options.padding,boundariesElement,data.positionFixed);

// NOTE: DOM access here
// restores the original style properties after the offsets have been computed
popperStyles.top=top;
popperStyles.left=left;
popperStyles[transformProp]=transform;

options.boundaries=boundaries;

var order=options.priority;
var popper=data.offsets.popper;

var check={
primary:function primary(placement){
var value=popper[placement];
if(popper[placement]<boundaries[placement]&&!options.escapeWithReference){
value=Math.max(popper[placement],boundaries[placement]);
}
return defineProperty({},placement,value);
},
secondary:function secondary(placement){
var mainSide=placement==='right'?'left':'top';
var value=popper[mainSide];
if(popper[placement]>boundaries[placement]&&!options.escapeWithReference){
value=Math.min(popper[mainSide],boundaries[placement]-(placement==='right'?popper.width:popper.height));
}
return defineProperty({},mainSide,value);
}};


order.forEach(function(placement){
var side=['left','top'].indexOf(placement)!==-1?'primary':'secondary';
popper=_extends({},popper,check[side](placement));
});

data.offsets.popper=popper;

return data;
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by `update` method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function shift(data){
var placement=data.placement;
var basePlacement=placement.split('-')[0];
var shiftvariation=placement.split('-')[1];

// if shift shiftvariation is specified, run the modifier
if(shiftvariation){
var _data$offsets=data.offsets,
reference=_data$offsets.reference,
popper=_data$offsets.popper;

var isVertical=['bottom','top'].indexOf(basePlacement)!==-1;
var side=isVertical?'left':'top';
var measurement=isVertical?'width':'height';

var shiftOffsets={
start:defineProperty({},side,reference[side]),
end:defineProperty({},side,reference[side]+reference[measurement]-popper[measurement])};


data.offsets.popper=_extends({},popper,shiftOffsets[shiftvariation]);
}

return data;
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by update method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function hide(data){
if(!isModifierRequired(data.instance.modifiers,'hide','preventOverflow')){
return data;
}

var refRect=data.offsets.reference;
var bound=find(data.instance.modifiers,function(modifier){
return modifier.name==='preventOverflow';
}).boundaries;

if(refRect.bottom<bound.top||refRect.left>bound.right||refRect.top>bound.bottom||refRect.right<bound.left){
// Avoid unnecessary DOM access if visibility hasn't changed
if(data.hide===true){
return data;
}

data.hide=true;
data.attributes['x-out-of-boundaries']='';
}else {
// Avoid unnecessary DOM access if visibility hasn't changed
if(data.hide===false){
return data;
}

data.hide=false;
data.attributes['x-out-of-boundaries']=false;
}

return data;
}

/**
 * @function
 * @memberof Modifiers
 * @argument {Object} data - The data object generated by `update` method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {Object} The data object, properly modified
 */
function inner(data){
var placement=data.placement;
var basePlacement=placement.split('-')[0];
var _data$offsets=data.offsets,
popper=_data$offsets.popper,
reference=_data$offsets.reference;

var isHoriz=['left','right'].indexOf(basePlacement)!==-1;

var subtractLength=['top','left'].indexOf(basePlacement)===-1;

popper[isHoriz?'left':'top']=reference[basePlacement]-(subtractLength?popper[isHoriz?'width':'height']:0);

data.placement=getOppositePlacement(placement);
data.offsets.popper=getClientRect(popper);

return data;
}

/**
 * Modifier function, each modifier can have a function of this type assigned
 * to its `fn` property.<br />
 * These functions will be called on each update, this means that you must
 * make sure they are performant enough to avoid performance bottlenecks.
 *
 * @function ModifierFn
 * @argument {dataObject} data - The data object generated by `update` method
 * @argument {Object} options - Modifiers configuration and options
 * @returns {dataObject} The data object, properly modified
 */

/**
 * Modifiers are plugins used to alter the behavior of your poppers.<br />
 * Popper.js uses a set of 9 modifiers to provide all the basic functionalities
 * needed by the library.
 *
 * Usually you don't want to override the `order`, `fn` and `onLoad` props.
 * All the other properties are configurations that could be tweaked.
 * @namespace modifiers
 */
var modifiers={
/**
   * Modifier used to shift the popper on the start or end of its reference
   * element.<br />
   * It will read the variation of the `placement` property.<br />
   * It can be one either `-end` or `-start`.
   * @memberof modifiers
   * @inner
   */
shift:{
/** @prop {number} order=100 - Index used to define the order of execution */
order:100,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:shift},


/**
   * The `offset` modifier can shift your popper on both its axis.
   *
   * It accepts the following units:
   * - `px` or unit-less, interpreted as pixels
   * - `%` or `%r`, percentage relative to the length of the reference element
   * - `%p`, percentage relative to the length of the popper element
   * - `vw`, CSS viewport width unit
   * - `vh`, CSS viewport height unit
   *
   * For length is intended the main axis relative to the placement of the popper.<br />
   * This means that if the placement is `top` or `bottom`, the length will be the
   * `width`. In case of `left` or `right`, it will be the `height`.
   *
   * You can provide a single value (as `Number` or `String`), or a pair of values
   * as `String` divided by a comma or one (or more) white spaces.<br />
   * The latter is a deprecated method because it leads to confusion and will be
   * removed in v2.<br />
   * Additionally, it accepts additions and subtractions between different units.
   * Note that multiplications and divisions aren't supported.
   *
   * Valid examples are:
   * ```
   * 10
   * '10%'
   * '10, 10'
   * '10%, 10'
   * '10 + 10%'
   * '10 - 5vh + 3%'
   * '-10px + 5vh, 5px - 6%'
   * ```
   * > **NB**: If you desire to apply offsets to your poppers in a way that may make them overlap
   * > with their reference element, unfortunately, you will have to disable the `flip` modifier.
   * > You can read more on this at this [issue](https://github.com/FezVrasta/popper.js/issues/373).
   *
   * @memberof modifiers
   * @inner
   */
offset:{
/** @prop {number} order=200 - Index used to define the order of execution */
order:200,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:offset,
/** @prop {Number|String} offset=0
     * The offset value as described in the modifier description
     */
offset:0},


/**
   * Modifier used to prevent the popper from being positioned outside the boundary.
   *
   * A scenario exists where the reference itself is not within the boundaries.<br />
   * We can say it has "escaped the boundaries" — or just "escaped".<br />
   * In this case we need to decide whether the popper should either:
   *
   * - detach from the reference and remain "trapped" in the boundaries, or
   * - if it should ignore the boundary and "escape with its reference"
   *
   * When `escapeWithReference` is set to`true` and reference is completely
   * outside its boundaries, the popper will overflow (or completely leave)
   * the boundaries in order to remain attached to the edge of the reference.
   *
   * @memberof modifiers
   * @inner
   */
preventOverflow:{
/** @prop {number} order=300 - Index used to define the order of execution */
order:300,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:preventOverflow,
/**
     * @prop {Array} [priority=['left','right','top','bottom']]
     * Popper will try to prevent overflow following these priorities by default,
     * then, it could overflow on the left and on top of the `boundariesElement`
     */
priority:['left','right','top','bottom'],
/**
     * @prop {number} padding=5
     * Amount of pixel used to define a minimum distance between the boundaries
     * and the popper. This makes sure the popper always has a little padding
     * between the edges of its container
     */
padding:5,
/**
     * @prop {String|HTMLElement} boundariesElement='scrollParent'
     * Boundaries used by the modifier. Can be `scrollParent`, `window`,
     * `viewport` or any DOM element.
     */
boundariesElement:'scrollParent'},


/**
   * Modifier used to make sure the reference and its popper stay near each other
   * without leaving any gap between the two. Especially useful when the arrow is
   * enabled and you want to ensure that it points to its reference element.
   * It cares only about the first axis. You can still have poppers with margin
   * between the popper and its reference element.
   * @memberof modifiers
   * @inner
   */
keepTogether:{
/** @prop {number} order=400 - Index used to define the order of execution */
order:400,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:keepTogether},


/**
   * This modifier is used to move the `arrowElement` of the popper to make
   * sure it is positioned between the reference element and its popper element.
   * It will read the outer size of the `arrowElement` node to detect how many
   * pixels of conjunction are needed.
   *
   * It has no effect if no `arrowElement` is provided.
   * @memberof modifiers
   * @inner
   */
arrow:{
/** @prop {number} order=500 - Index used to define the order of execution */
order:500,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:arrow,
/** @prop {String|HTMLElement} element='[x-arrow]' - Selector or node used as arrow */
element:'[x-arrow]'},


/**
   * Modifier used to flip the popper's placement when it starts to overlap its
   * reference element.
   *
   * Requires the `preventOverflow` modifier before it in order to work.
   *
   * **NOTE:** this modifier will interrupt the current update cycle and will
   * restart it if it detects the need to flip the placement.
   * @memberof modifiers
   * @inner
   */
flip:{
/** @prop {number} order=600 - Index used to define the order of execution */
order:600,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:flip,
/**
     * @prop {String|Array} behavior='flip'
     * The behavior used to change the popper's placement. It can be one of
     * `flip`, `clockwise`, `counterclockwise` or an array with a list of valid
     * placements (with optional variations)
     */
behavior:'flip',
/**
     * @prop {number} padding=5
     * The popper will flip if it hits the edges of the `boundariesElement`
     */
padding:5,
/**
     * @prop {String|HTMLElement} boundariesElement='viewport'
     * The element which will define the boundaries of the popper position.
     * The popper will never be placed outside of the defined boundaries
     * (except if `keepTogether` is enabled)
     */
boundariesElement:'viewport',
/**
     * @prop {Boolean} flipVariations=false
     * The popper will switch placement variation between `-start` and `-end` when
     * the reference element overlaps its boundaries.
     *
     * The original placement should have a set variation.
     */
flipVariations:false,
/**
     * @prop {Boolean} flipVariationsByContent=false
     * The popper will switch placement variation between `-start` and `-end` when
     * the popper element overlaps its reference boundaries.
     *
     * The original placement should have a set variation.
     */
flipVariationsByContent:false},


/**
   * Modifier used to make the popper flow toward the inner of the reference element.
   * By default, when this modifier is disabled, the popper will be placed outside
   * the reference element.
   * @memberof modifiers
   * @inner
   */
inner:{
/** @prop {number} order=700 - Index used to define the order of execution */
order:700,
/** @prop {Boolean} enabled=false - Whether the modifier is enabled or not */
enabled:false,
/** @prop {ModifierFn} */
fn:inner},


/**
   * Modifier used to hide the popper when its reference element is outside of the
   * popper boundaries. It will set a `x-out-of-boundaries` attribute which can
   * be used to hide with a CSS selector the popper when its reference is
   * out of boundaries.
   *
   * Requires the `preventOverflow` modifier before it in order to work.
   * @memberof modifiers
   * @inner
   */
hide:{
/** @prop {number} order=800 - Index used to define the order of execution */
order:800,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:hide},


/**
   * Computes the style that will be applied to the popper element to gets
   * properly positioned.
   *
   * Note that this modifier will not touch the DOM, it just prepares the styles
   * so that `applyStyle` modifier can apply it. This separation is useful
   * in case you need to replace `applyStyle` with a custom implementation.
   *
   * This modifier has `850` as `order` value to maintain backward compatibility
   * with previous versions of Popper.js. Expect the modifiers ordering method
   * to change in future major versions of the library.
   *
   * @memberof modifiers
   * @inner
   */
computeStyle:{
/** @prop {number} order=850 - Index used to define the order of execution */
order:850,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:computeStyle,
/**
     * @prop {Boolean} gpuAcceleration=true
     * If true, it uses the CSS 3D transformation to position the popper.
     * Otherwise, it will use the `top` and `left` properties
     */
gpuAcceleration:true,
/**
     * @prop {string} [x='bottom']
     * Where to anchor the X axis (`bottom` or `top`). AKA X offset origin.
     * Change this if your popper should grow in a direction different from `bottom`
     */
x:'bottom',
/**
     * @prop {string} [x='left']
     * Where to anchor the Y axis (`left` or `right`). AKA Y offset origin.
     * Change this if your popper should grow in a direction different from `right`
     */
y:'right'},


/**
   * Applies the computed styles to the popper element.
   *
   * All the DOM manipulations are limited to this modifier. This is useful in case
   * you want to integrate Popper.js inside a framework or view library and you
   * want to delegate all the DOM manipulations to it.
   *
   * Note that if you disable this modifier, you must make sure the popper element
   * has its position set to `absolute` before Popper.js can do its work!
   *
   * Just disable this modifier and define your own to achieve the desired effect.
   *
   * @memberof modifiers
   * @inner
   */
applyStyle:{
/** @prop {number} order=900 - Index used to define the order of execution */
order:900,
/** @prop {Boolean} enabled=true - Whether the modifier is enabled or not */
enabled:true,
/** @prop {ModifierFn} */
fn:applyStyle,
/** @prop {Function} */
onLoad:applyStyleOnLoad,
/**
     * @deprecated since version 1.10.0, the property moved to `computeStyle` modifier
     * @prop {Boolean} gpuAcceleration=true
     * If true, it uses the CSS 3D transformation to position the popper.
     * Otherwise, it will use the `top` and `left` properties
     */
gpuAcceleration:undefined}};



/**
 * The `dataObject` is an object containing all the information used by Popper.js.
 * This object is passed to modifiers and to the `onCreate` and `onUpdate` callbacks.
 * @name dataObject
 * @property {Object} data.instance The Popper.js instance
 * @property {String} data.placement Placement applied to popper
 * @property {String} data.originalPlacement Placement originally defined on init
 * @property {Boolean} data.flipped True if popper has been flipped by flip modifier
 * @property {Boolean} data.hide True if the reference element is out of boundaries, useful to know when to hide the popper
 * @property {HTMLElement} data.arrowElement Node used as arrow by arrow modifier
 * @property {Object} data.styles Any CSS property defined here will be applied to the popper. It expects the JavaScript nomenclature (eg. `marginBottom`)
 * @property {Object} data.arrowStyles Any CSS property defined here will be applied to the popper arrow. It expects the JavaScript nomenclature (eg. `marginBottom`)
 * @property {Object} data.boundaries Offsets of the popper boundaries
 * @property {Object} data.offsets The measurements of popper, reference and arrow elements
 * @property {Object} data.offsets.popper `top`, `left`, `width`, `height` values
 * @property {Object} data.offsets.reference `top`, `left`, `width`, `height` values
 * @property {Object} data.offsets.arrow] `top` and `left` offsets, only one of them will be different from 0
 */

/**
 * Default options provided to Popper.js constructor.<br />
 * These can be overridden using the `options` argument of Popper.js.<br />
 * To override an option, simply pass an object with the same
 * structure of the `options` object, as the 3rd argument. For example:
 * ```
 * new Popper(ref, pop, {
 *   modifiers: {
 *     preventOverflow: { enabled: false }
 *   }
 * })
 * ```
 * @type {Object}
 * @static
 * @memberof Popper
 */
var Defaults={
/**
   * Popper's placement.
   * @prop {Popper.placements} placement='bottom'
   */
placement:'bottom',

/**
   * Set this to true if you want popper to position it self in 'fixed' mode
   * @prop {Boolean} positionFixed=false
   */
positionFixed:false,

/**
   * Whether events (resize, scroll) are initially enabled.
   * @prop {Boolean} eventsEnabled=true
   */
eventsEnabled:true,

/**
   * Set to true if you want to automatically remove the popper when
   * you call the `destroy` method.
   * @prop {Boolean} removeOnDestroy=false
   */
removeOnDestroy:false,

/**
   * Callback called when the popper is created.<br />
   * By default, it is set to no-op.<br />
   * Access Popper.js instance with `data.instance`.
   * @prop {onCreate}
   */
onCreate:function onCreate(){},

/**
   * Callback called when the popper is updated. This callback is not called
   * on the initialization/creation of the popper, but only on subsequent
   * updates.<br />
   * By default, it is set to no-op.<br />
   * Access Popper.js instance with `data.instance`.
   * @prop {onUpdate}
   */
onUpdate:function onUpdate(){},

/**
   * List of modifiers used to modify the offsets before they are applied to the popper.
   * They provide most of the functionalities of Popper.js.
   * @prop {modifiers}
   */
modifiers:modifiers};


/**
 * @callback onCreate
 * @param {dataObject} data
 */

/**
 * @callback onUpdate
 * @param {dataObject} data
 */

// Utils
// Methods
var Popper=function(){
/**
   * Creates a new Popper.js instance.
   * @class Popper
   * @param {Element|referenceObject} reference - The reference element used to position the popper
   * @param {Element} popper - The HTML / XML element used as the popper
   * @param {Object} options - Your custom options to override the ones defined in [Defaults](#defaults)
   * @return {Object} instance - The generated Popper.js instance
   */
function Popper(reference,popper){
var _this=this;

var options=arguments.length>2&&arguments[2]!==undefined?arguments[2]:{};
classCallCheck(this,Popper);

this.scheduleUpdate=function(){
return requestAnimationFrame(_this.update);
};

// make update() debounced, so that it only runs at most once-per-tick
this.update=debounce(this.update.bind(this));

// with {} we create a new object with the options inside it
this.options=_extends({},Popper.Defaults,options);

// init state
this.state={
isDestroyed:false,
isCreated:false,
scrollParents:[]};


// get reference and popper elements (allow jQuery wrappers)
this.reference=reference&&reference.jquery?reference[0]:reference;
this.popper=popper&&popper.jquery?popper[0]:popper;

// Deep merge modifiers options
this.options.modifiers={};
Object.keys(_extends({},Popper.Defaults.modifiers,options.modifiers)).forEach(function(name){
_this.options.modifiers[name]=_extends({},Popper.Defaults.modifiers[name]||{},options.modifiers?options.modifiers[name]:{});
});

// Refactoring modifiers' list (Object => Array)
this.modifiers=Object.keys(this.options.modifiers).map(function(name){
return _extends({
name:name},
_this.options.modifiers[name]);
})
// sort the modifiers by order
.sort(function(a,b){
return a.order-b.order;
});

// modifiers have the ability to execute arbitrary code when Popper.js get inited
// such code is executed in the same order of its modifier
// they could add new properties to their options configuration
// BE AWARE: don't add options to `options.modifiers.name` but to `modifierOptions`!
this.modifiers.forEach(function(modifierOptions){
if(modifierOptions.enabled&&isFunction(modifierOptions.onLoad)){
modifierOptions.onLoad(_this.reference,_this.popper,_this.options,modifierOptions,_this.state);
}
});

// fire the first update to position the popper in the right place
this.update();

var eventsEnabled=this.options.eventsEnabled;
if(eventsEnabled){
// setup event listeners, they will take care of update the position in specific situations
this.enableEventListeners();
}

this.state.eventsEnabled=eventsEnabled;
}

// We can't use class properties because they don't get listed in the
// class prototype and break stuff like Sinon stubs


createClass(Popper,[{
key:'update',
value:function update$$1(){
return update.call(this);
}},
{
key:'destroy',
value:function destroy$$1(){
return destroy.call(this);
}},
{
key:'enableEventListeners',
value:function enableEventListeners$$1(){
return enableEventListeners.call(this);
}},
{
key:'disableEventListeners',
value:function disableEventListeners$$1(){
return disableEventListeners.call(this);
}

/**
     * Schedules an update. It will run on the next UI update available.
     * @method scheduleUpdate
     * @memberof Popper
     */


/**
     * Collection of utilities useful when writing custom modifiers.
     * Starting from version 1.7, this method is available only if you
     * include `popper-utils.js` before `popper.js`.
     *
     * **DEPRECATION**: This way to access PopperUtils is deprecated
     * and will be removed in v2! Use the PopperUtils module directly instead.
     * Due to the high instability of the methods contained in Utils, we can't
     * guarantee them to follow semver. Use them at your own risk!
     * @static
     * @private
     * @type {Object}
     * @deprecated since version 1.8
     * @member Utils
     * @memberof Popper
     */}]);


return Popper;
}();

/**
 * The `referenceObject` is an object that provides an interface compatible with Popper.js
 * and lets you use it as replacement of a real DOM node.<br />
 * You can use this method to position a popper relatively to a set of coordinates
 * in case you don't have a DOM node to use as reference.
 *
 * ```
 * new Popper(referenceObject, popperNode);
 * ```
 *
 * NB: This feature isn't supported in Internet Explorer 10.
 * @name referenceObject
 * @property {Function} data.getBoundingClientRect
 * A function that returns a set of coordinates compatible with the native `getBoundingClientRect` method.
 * @property {number} data.clientWidth
 * An ES6 getter that will return the width of the virtual reference element.
 * @property {number} data.clientHeight
 * An ES6 getter that will return the height of the virtual reference element.
 */


Popper.Utils=(typeof window!=='undefined'?window:global).PopperUtils;
Popper.placements=placements;
Popper.Defaults=Defaults;

/* harmony default export */__webpack_exports__["default"]=Popper;


/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"));

/***/},

/***/"./node_modules/portal-vue/dist/portal-vue.common.js":
/*!***********************************************************!*\
  !*** ./node_modules/portal-vue/dist/portal-vue.common.js ***!
  \***********************************************************/
/*! no static exports found */
/***/function node_modulesPortalVueDistPortalVueCommonJs(module,exports,__webpack_require__){

/*! 
  * portal-vue © Thorsten Lünborg, 2019 
  * 
  * Version: 2.1.7
  * 
  * LICENCE: MIT 
  * 
  * https://github.com/linusborg/portal-vue
  * 
 */



Object.defineProperty(exports,'__esModule',{value:true});

function _interopDefault(ex){return ex&&typeof ex==='object'&&'default'in ex?ex['default']:ex;}

var Vue=_interopDefault(__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js"));

function _typeof(obj){
if(typeof Symbol==="function"&&typeof Symbol.iterator==="symbol"){
_typeof=function _typeof(obj){
return typeof obj;
};
}else {
_typeof=function _typeof(obj){
return obj&&typeof Symbol==="function"&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj;
};
}

return _typeof(obj);
}

function _toConsumableArray(arr){
return _arrayWithoutHoles(arr)||_iterableToArray(arr)||_nonIterableSpread();
}

function _arrayWithoutHoles(arr){
if(Array.isArray(arr)){
for(var i=0,arr2=new Array(arr.length);i<arr.length;i++){arr2[i]=arr[i];}

return arr2;
}
}

function _iterableToArray(iter){
if(Symbol.iterator in Object(iter)||Object.prototype.toString.call(iter)==="[object Arguments]")return Array.from(iter);
}

function _nonIterableSpread(){
throw new TypeError("Invalid attempt to spread non-iterable instance");
}

var inBrowser=typeof window!=='undefined';
function freeze(item){
if(Array.isArray(item)||_typeof(item)==='object'){
return Object.freeze(item);
}

return item;
}
function combinePassengers(transports){
var slotProps=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
return transports.reduce(function(passengers,transport){
var temp=transport.passengers[0];
var newPassengers=typeof temp==='function'?temp(slotProps):transport.passengers;
return passengers.concat(newPassengers);
},[]);
}
function stableSort(array,compareFn){
return array.map(function(v,idx){
return [idx,v];
}).sort(function(a,b){
return compareFn(a[1],b[1])||a[0]-b[0];
}).map(function(c){
return c[1];
});
}
function pick(obj,keys){
return keys.reduce(function(acc,key){
if(obj.hasOwnProperty(key)){
acc[key]=obj[key];
}

return acc;
},{});
}

var transports={};
var targets={};
var sources={};
var Wormhole=Vue.extend({
data:function data(){
return {
transports:transports,
targets:targets,
sources:sources,
trackInstances:inBrowser};

},
methods:{
open:function open(transport){
if(!inBrowser)return;
var to=transport.to,
from=transport.from,
passengers=transport.passengers,
_transport$order=transport.order,
order=_transport$order===void 0?Infinity:_transport$order;
if(!to||!from||!passengers)return;
var newTransport={
to:to,
from:from,
passengers:freeze(passengers),
order:order};

var keys=Object.keys(this.transports);

if(keys.indexOf(to)===-1){
Vue.set(this.transports,to,[]);
}

var currentIndex=this.$_getTransportIndex(newTransport);// Copying the array here so that the PortalTarget change event will actually contain two distinct arrays

var newTransports=this.transports[to].slice(0);

if(currentIndex===-1){
newTransports.push(newTransport);
}else {
newTransports[currentIndex]=newTransport;
}

this.transports[to]=stableSort(newTransports,function(a,b){
return a.order-b.order;
});
},
close:function close(transport){
var force=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;
var to=transport.to,
from=transport.from;
if(!to||!from&&force===false)return;

if(!this.transports[to]){
return;
}

if(force){
this.transports[to]=[];
}else {
var index=this.$_getTransportIndex(transport);

if(index>=0){
// Copying the array here so that the PortalTarget change event will actually contain two distinct arrays
var newTransports=this.transports[to].slice(0);
newTransports.splice(index,1);
this.transports[to]=newTransports;
}
}
},
registerTarget:function registerTarget(target,vm,force){
if(!inBrowser)return;

if(this.trackInstances&&!force&&this.targets[target]){
console.warn("[portal-vue]: Target ".concat(target," already exists"));
}

this.$set(this.targets,target,Object.freeze([vm]));
},
unregisterTarget:function unregisterTarget(target){
this.$delete(this.targets,target);
},
registerSource:function registerSource(source,vm,force){
if(!inBrowser)return;

if(this.trackInstances&&!force&&this.sources[source]){
console.warn("[portal-vue]: source ".concat(source," already exists"));
}

this.$set(this.sources,source,Object.freeze([vm]));
},
unregisterSource:function unregisterSource(source){
this.$delete(this.sources,source);
},
hasTarget:function hasTarget(to){
return !!(this.targets[to]&&this.targets[to][0]);
},
hasSource:function hasSource(to){
return !!(this.sources[to]&&this.sources[to][0]);
},
hasContentFor:function hasContentFor(to){
return !!this.transports[to]&&!!this.transports[to].length;
},
// Internal
$_getTransportIndex:function $_getTransportIndex(_ref){
var to=_ref.to,
from=_ref.from;

for(var i in this.transports[to]){
if(this.transports[to][i].from===from){
return +i;
}
}

return -1;
}}});


var wormhole=new Wormhole(transports);

var _id=1;
var Portal=Vue.extend({
name:'portal',
props:{
disabled:{
type:Boolean},

name:{
type:String,
default:function _default(){
return String(_id++);
}},

order:{
type:Number,
default:0},

slim:{
type:Boolean},

slotProps:{
type:Object,
default:function _default(){
return {};
}},

tag:{
type:String,
default:'DIV'},

to:{
type:String,
default:function _default(){
return String(Math.round(Math.random()*10000000));
}}},


created:function created(){
var _this=this;

this.$nextTick(function(){
wormhole.registerSource(_this.name,_this);
});
},
mounted:function mounted(){
if(!this.disabled){
this.sendUpdate();
}
},
updated:function updated(){
if(this.disabled){
this.clear();
}else {
this.sendUpdate();
}
},
beforeDestroy:function beforeDestroy(){
wormhole.unregisterSource(this.name);
this.clear();
},
watch:{
to:function to(newValue,oldValue){
oldValue&&oldValue!==newValue&&this.clear(oldValue);
this.sendUpdate();
}},

methods:{
clear:function clear(target){
var closer={
from:this.name,
to:target||this.to};

wormhole.close(closer);
},
normalizeSlots:function normalizeSlots(){
return this.$scopedSlots.default?[this.$scopedSlots.default]:this.$slots.default;
},
normalizeOwnChildren:function normalizeOwnChildren(children){
return typeof children==='function'?children(this.slotProps):children;
},
sendUpdate:function sendUpdate(){
var slotContent=this.normalizeSlots();

if(slotContent){
var transport={
from:this.name,
to:this.to,
passengers:_toConsumableArray(slotContent),
order:this.order};

wormhole.open(transport);
}else {
this.clear();
}
}},

render:function render(h){
var children=this.$slots.default||this.$scopedSlots.default||[];
var Tag=this.tag;

if(children&&this.disabled){
return children.length<=1&&this.slim?this.normalizeOwnChildren(children)[0]:h(Tag,[this.normalizeOwnChildren(children)]);
}else {
return this.slim?h():h(Tag,{
class:{
'v-portal':true},

style:{
display:'none'},

key:'v-portal-placeholder'});

}
}});


var PortalTarget=Vue.extend({
name:'portalTarget',
props:{
multiple:{
type:Boolean,
default:false},

name:{
type:String,
required:true},

slim:{
type:Boolean,
default:false},

slotProps:{
type:Object,
default:function _default(){
return {};
}},

tag:{
type:String,
default:'div'},

transition:{
type:[String,Object,Function]}},


data:function data(){
return {
transports:wormhole.transports,
firstRender:true};

},
created:function created(){
var _this=this;

this.$nextTick(function(){
wormhole.registerTarget(_this.name,_this);
});
},
watch:{
ownTransports:function ownTransports(){
this.$emit('change',this.children().length>0);
},
name:function name(newVal,oldVal){
/**
       * TODO
       * This should warn as well ...
       */
wormhole.unregisterTarget(oldVal);
wormhole.registerTarget(newVal,this);
}},

mounted:function mounted(){
var _this2=this;

if(this.transition){
this.$nextTick(function(){
// only when we have a transition, because it causes a re-render
_this2.firstRender=false;
});
}
},
beforeDestroy:function beforeDestroy(){
wormhole.unregisterTarget(this.name);
},
computed:{
ownTransports:function ownTransports(){
var transports=this.transports[this.name]||[];

if(this.multiple){
return transports;
}

return transports.length===0?[]:[transports[transports.length-1]];
},
passengers:function passengers(){
return combinePassengers(this.ownTransports,this.slotProps);
}},

methods:{
// can't be a computed prop because it has to "react" to $slot changes.
children:function children(){
return this.passengers.length!==0?this.passengers:this.$scopedSlots.default?this.$scopedSlots.default(this.slotProps):this.$slots.default||[];
},
// can't be a computed prop because it has to "react" to this.children().
noWrapper:function noWrapper(){
var noWrapper=this.slim&&!this.transition;

if(noWrapper&&this.children().length>1){
console.warn('[portal-vue]: PortalTarget with `slim` option received more than one child element.');
}

return noWrapper;
}},

render:function render(h){
var noWrapper=this.noWrapper();
var children=this.children();
var Tag=this.transition||this.tag;
return noWrapper?children[0]:this.slim&&!Tag?h():h(Tag,{
props:{
// if we have a transition component, pass the tag if it exists
tag:this.transition&&this.tag?this.tag:undefined},

class:{
'vue-portal-target':true}},

children);
}});


var _id$1=0;
var portalProps=['disabled','name','order','slim','slotProps','tag','to'];
var targetProps=['multiple','transition'];
var MountingPortal=Vue.extend({
name:'MountingPortal',
inheritAttrs:false,
props:{
append:{
type:[Boolean,String]},

bail:{
type:Boolean},

mountTo:{
type:String,
required:true},

// Portal
disabled:{
type:Boolean},

// name for the portal
name:{
type:String,
default:function _default(){
return 'mounted_'+String(_id$1++);
}},

order:{
type:Number,
default:0},

slim:{
type:Boolean},

slotProps:{
type:Object,
default:function _default(){
return {};
}},

tag:{
type:String,
default:'DIV'},

// name for the target
to:{
type:String,
default:function _default(){
return String(Math.round(Math.random()*10000000));
}},

// Target
multiple:{
type:Boolean,
default:false},

targetSlim:{
type:Boolean},

targetSlotProps:{
type:Object,
default:function _default(){
return {};
}},

targetTag:{
type:String,
default:'div'},

transition:{
type:[String,Object,Function]}},


created:function created(){
if(typeof document==='undefined')return;
var el=document.querySelector(this.mountTo);

if(!el){
console.error("[portal-vue]: Mount Point '".concat(this.mountTo,"' not found in document"));
return;
}

var props=this.$props;// Target already exists

if(wormhole.targets[props.name]){
if(props.bail){
console.warn("[portal-vue]: Target ".concat(props.name," is already mounted.\n        Aborting because 'bail: true' is set"));
}else {
this.portalTarget=wormhole.targets[props.name];
}

return;
}

var append=props.append;

if(append){
var type=typeof append==='string'?append:'DIV';
var mountEl=document.createElement(type);
el.appendChild(mountEl);
el=mountEl;
}// get props for target from $props
// we have to rename a few of them


var _props=pick(this.$props,targetProps);

_props.slim=this.targetSlim;
_props.tag=this.targetTag;
_props.slotProps=this.targetSlotProps;
_props.name=this.to;
this.portalTarget=new PortalTarget({
el:el,
parent:this.$parent||this,
propsData:_props});

},
beforeDestroy:function beforeDestroy(){
var target=this.portalTarget;

if(this.append){
var el=target.$el;
el.parentNode.removeChild(el);
}

target.$destroy();
},
render:function render(h){
if(!this.portalTarget){
console.warn("[portal-vue] Target wasn't mounted");
return h();
}// if there's no "manual" scoped slot, so we create a <Portal> ourselves


if(!this.$scopedSlots.manual){
var props=pick(this.$props,portalProps);
return h(Portal,{
props:props,
attrs:this.$attrs,
on:this.$listeners,
scopedSlots:this.$scopedSlots},
this.$slots.default);
}// else, we render the scoped slot


var content=this.$scopedSlots.manual({
to:this.to});
// if user used <template> for the scoped slot
// content will be an array

if(Array.isArray(content)){
content=content[0];
}

if(!content)return h();
return content;
}});


function install(Vue$$1){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
Vue$$1.component(options.portalName||'Portal',Portal);
Vue$$1.component(options.portalTargetName||'PortalTarget',PortalTarget);
Vue$$1.component(options.MountingPortalName||'MountingPortal',MountingPortal);
}

var index={
install:install};


exports.default=index;
exports.Portal=Portal;
exports.PortalTarget=PortalTarget;
exports.MountingPortal=MountingPortal;
exports.Wormhole=wormhole;



/***/},

/***/"./node_modules/process/browser.js":
/*!*****************************************!*\
  !*** ./node_modules/process/browser.js ***!
  \*****************************************/
/*! no static exports found */
/***/function node_modulesProcessBrowserJs(module,exports){

// shim for using process in browser
var process=module.exports={};

// cached from whatever global is present so that test runners that stub it
// don't break things.  But we need to wrap it in a try catch in case it is
// wrapped in strict mode code which doesn't define any globals.  It's inside a
// function because try/catches deoptimize in certain engines.

var cachedSetTimeout;
var cachedClearTimeout;

function defaultSetTimout(){
throw new Error('setTimeout has not been defined');
}
function defaultClearTimeout(){
throw new Error('clearTimeout has not been defined');
}
(function(){
try{
if(typeof setTimeout==='function'){
cachedSetTimeout=setTimeout;
}else {
cachedSetTimeout=defaultSetTimout;
}
}catch(e){
cachedSetTimeout=defaultSetTimout;
}
try{
if(typeof clearTimeout==='function'){
cachedClearTimeout=clearTimeout;
}else {
cachedClearTimeout=defaultClearTimeout;
}
}catch(e){
cachedClearTimeout=defaultClearTimeout;
}
})();
function runTimeout(fun){
if(cachedSetTimeout===setTimeout){
//normal enviroments in sane situations
return setTimeout(fun,0);
}
// if setTimeout wasn't available but was latter defined
if((cachedSetTimeout===defaultSetTimout||!cachedSetTimeout)&&setTimeout){
cachedSetTimeout=setTimeout;
return setTimeout(fun,0);
}
try{
// when when somebody has screwed with setTimeout but no I.E. maddness
return cachedSetTimeout(fun,0);
}catch(e){
try{
// When we are in I.E. but the script has been evaled so I.E. doesn't trust the global object when called normally
return cachedSetTimeout.call(null,fun,0);
}catch(e){
// same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error
return cachedSetTimeout.call(this,fun,0);
}
}


}
function runClearTimeout(marker){
if(cachedClearTimeout===clearTimeout){
//normal enviroments in sane situations
return clearTimeout(marker);
}
// if clearTimeout wasn't available but was latter defined
if((cachedClearTimeout===defaultClearTimeout||!cachedClearTimeout)&&clearTimeout){
cachedClearTimeout=clearTimeout;
return clearTimeout(marker);
}
try{
// when when somebody has screwed with setTimeout but no I.E. maddness
return cachedClearTimeout(marker);
}catch(e){
try{
// When we are in I.E. but the script has been evaled so I.E. doesn't  trust the global object when called normally
return cachedClearTimeout.call(null,marker);
}catch(e){
// same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error.
// Some versions of I.E. have different rules for clearTimeout vs setTimeout
return cachedClearTimeout.call(this,marker);
}
}



}
var queue=[];
var draining=false;
var currentQueue;
var queueIndex=-1;

function cleanUpNextTick(){
if(!draining||!currentQueue){
return;
}
draining=false;
if(currentQueue.length){
queue=currentQueue.concat(queue);
}else {
queueIndex=-1;
}
if(queue.length){
drainQueue();
}
}

function drainQueue(){
if(draining){
return;
}
var timeout=runTimeout(cleanUpNextTick);
draining=true;

var len=queue.length;
while(len){
currentQueue=queue;
queue=[];
while(++queueIndex<len){
if(currentQueue){
currentQueue[queueIndex].run();
}
}
queueIndex=-1;
len=queue.length;
}
currentQueue=null;
draining=false;
runClearTimeout(timeout);
}

process.nextTick=function(fun){
var args=new Array(arguments.length-1);
if(arguments.length>1){
for(var i=1;i<arguments.length;i++){
args[i-1]=arguments[i];
}
}
queue.push(new Item(fun,args));
if(queue.length===1&&!draining){
runTimeout(drainQueue);
}
};

// v8 likes predictible objects
function Item(fun,array){
this.fun=fun;
this.array=array;
}
Item.prototype.run=function(){
this.fun.apply(null,this.array);
};
process.title='browser';
process.browser=true;
process.env={};
process.argv=[];
process.version='';// empty string to avoid regexp issues
process.versions={};

function noop(){}

process.on=noop;
process.addListener=noop;
process.once=noop;
process.off=noop;
process.removeListener=noop;
process.removeAllListeners=noop;
process.emit=noop;
process.prependListener=noop;
process.prependOnceListener=noop;

process.listeners=function(name){return [];};

process.binding=function(name){
throw new Error('process.binding is not supported');
};

process.cwd=function(){return '/';};
process.chdir=function(dir){
throw new Error('process.chdir is not supported');
};
process.umask=function(){return 0;};


/***/},

/***/"./node_modules/setimmediate/setImmediate.js":
/*!***************************************************!*\
  !*** ./node_modules/setimmediate/setImmediate.js ***!
  \***************************************************/
/*! no static exports found */
/***/function node_modulesSetimmediateSetImmediateJs(module,exports,__webpack_require__){

/* WEBPACK VAR INJECTION */(function(global,process){(function(global,undefined$1){

if(global.setImmediate){
return;
}

var nextHandle=1;// Spec says greater than zero
var tasksByHandle={};
var currentlyRunningATask=false;
var doc=global.document;
var registerImmediate;

function setImmediate(callback){
// Callback can either be a function or a string
if(typeof callback!=="function"){
callback=new Function(""+callback);
}
// Copy function arguments
var args=new Array(arguments.length-1);
for(var i=0;i<args.length;i++){
args[i]=arguments[i+1];
}
// Store and register the task
var task={callback:callback,args:args};
tasksByHandle[nextHandle]=task;
registerImmediate(nextHandle);
return nextHandle++;
}

function clearImmediate(handle){
delete tasksByHandle[handle];
}

function run(task){
var callback=task.callback;
var args=task.args;
switch(args.length){
case 0:
callback();
break;
case 1:
callback(args[0]);
break;
case 2:
callback(args[0],args[1]);
break;
case 3:
callback(args[0],args[1],args[2]);
break;
default:
callback.apply(undefined$1,args);
break;}

}

function runIfPresent(handle){
// From the spec: "Wait until any invocations of this algorithm started before this one have completed."
// So if we're currently running a task, we'll need to delay this invocation.
if(currentlyRunningATask){
// Delay by doing a setTimeout. setImmediate was tried instead, but in Firefox 7 it generated a
// "too much recursion" error.
setTimeout(runIfPresent,0,handle);
}else {
var task=tasksByHandle[handle];
if(task){
currentlyRunningATask=true;
try{
run(task);
}finally{
clearImmediate(handle);
currentlyRunningATask=false;
}
}
}
}

function installNextTickImplementation(){
registerImmediate=function registerImmediate(handle){
process.nextTick(function(){runIfPresent(handle);});
};
}

function canUsePostMessage(){
// The test against `importScripts` prevents this implementation from being installed inside a web worker,
// where `global.postMessage` means something completely different and can't be used for this purpose.
if(global.postMessage&&!global.importScripts){
var postMessageIsAsynchronous=true;
var oldOnMessage=global.onmessage;
global.onmessage=function(){
postMessageIsAsynchronous=false;
};
global.postMessage("","*");
global.onmessage=oldOnMessage;
return postMessageIsAsynchronous;
}
}

function installPostMessageImplementation(){
// Installs an event handler on `global` for the `message` event: see
// * https://developer.mozilla.org/en/DOM/window.postMessage
// * http://www.whatwg.org/specs/web-apps/current-work/multipage/comms.html#crossDocumentMessages

var messagePrefix="setImmediate$"+Math.random()+"$";
var onGlobalMessage=function onGlobalMessage(event){
if(event.source===global&&
typeof event.data==="string"&&
event.data.indexOf(messagePrefix)===0){
runIfPresent(+event.data.slice(messagePrefix.length));
}
};

if(global.addEventListener){
global.addEventListener("message",onGlobalMessage,false);
}else {
global.attachEvent("onmessage",onGlobalMessage);
}

registerImmediate=function registerImmediate(handle){
global.postMessage(messagePrefix+handle,"*");
};
}

function installMessageChannelImplementation(){
var channel=new MessageChannel();
channel.port1.onmessage=function(event){
var handle=event.data;
runIfPresent(handle);
};

registerImmediate=function registerImmediate(handle){
channel.port2.postMessage(handle);
};
}

function installReadyStateChangeImplementation(){
var html=doc.documentElement;
registerImmediate=function registerImmediate(handle){
// Create a <script> element; its readystatechange event will be fired asynchronously once it is inserted
// into the document. Do so, thus queuing up the task. Remember to clean up once it's been called.
var script=doc.createElement("script");
script.onreadystatechange=function(){
runIfPresent(handle);
script.onreadystatechange=null;
html.removeChild(script);
script=null;
};
html.appendChild(script);
};
}

function installSetTimeoutImplementation(){
registerImmediate=function registerImmediate(handle){
setTimeout(runIfPresent,0,handle);
};
}

// If supported, we should attach to the prototype of global, since that is where setTimeout et al. live.
var attachTo=Object.getPrototypeOf&&Object.getPrototypeOf(global);
attachTo=attachTo&&attachTo.setTimeout?attachTo:global;

// Don't get fooled by e.g. browserify environments.
if({}.toString.call(global.process)==="[object process]"){
// For Node.js before 0.9
installNextTickImplementation();

}else if(canUsePostMessage()){
// For non-IE10 modern browsers
installPostMessageImplementation();

}else if(global.MessageChannel){
// For web workers, where supported
installMessageChannelImplementation();

}else if(doc&&"onreadystatechange"in doc.createElement("script")){
// For IE 6–8
installReadyStateChangeImplementation();

}else {
// For older browsers
installSetTimeoutImplementation();
}

attachTo.setImmediate=setImmediate;
attachTo.clearImmediate=clearImmediate;
})(typeof self==="undefined"?typeof global==="undefined"?this:global:self);

/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"),__webpack_require__(/*! ./../process/browser.js */"./node_modules/process/browser.js"));

/***/},

/***/"./node_modules/style-loader/lib/addStyles.js":
/*!****************************************************!*\
  !*** ./node_modules/style-loader/lib/addStyles.js ***!
  \****************************************************/
/*! no static exports found */
/***/function node_modulesStyleLoaderLibAddStylesJs(module,exports,__webpack_require__){

/*
	MIT License http://www.opensource.org/licenses/mit-license.php
	Author Tobias Koppers @sokra
*/

var stylesInDom={};

var memoize=function memoize(fn){
var memo;

return function(){
if(typeof memo==="undefined")memo=fn.apply(this,arguments);
return memo;
};
};

var isOldIE=memoize(function(){
// Test for IE <= 9 as proposed by Browserhacks
// @see http://browserhacks.com/#hack-e71d8692f65334173fee715c222cb805
// Tests for existence of standard globals is to allow style-loader
// to operate correctly into non-standard environments
// @see https://github.com/webpack-contrib/style-loader/issues/177
return window&&document&&document.all&&!window.atob;
});

var getTarget=function getTarget(target,parent){
if(parent){
return parent.querySelector(target);
}
return document.querySelector(target);
};

var getElement=function(fn){
var memo={};

return function(target,parent){
// If passing function in options, then use it for resolve "head" element.
// Useful for Shadow Root style i.e
// {
//   insertInto: function () { return document.querySelector("#foo").shadowRoot }
// }
if(typeof target==='function'){
return target();
}
if(typeof memo[target]==="undefined"){
var styleTarget=getTarget.call(this,target,parent);
// Special case to return head of iframe instead of iframe itself
if(window.HTMLIFrameElement&&styleTarget instanceof window.HTMLIFrameElement){
try{
// This will throw an exception if access to iframe is blocked
// due to cross-origin restrictions
styleTarget=styleTarget.contentDocument.head;
}catch(e){
styleTarget=null;
}
}
memo[target]=styleTarget;
}
return memo[target];
};
}();

var singleton=null;
var singletonCounter=0;
var stylesInsertedAtTop=[];

var fixUrls=__webpack_require__(/*! ./urls */"./node_modules/style-loader/lib/urls.js");

module.exports=function(list,options){
if(typeof DEBUG!=="undefined"&&DEBUG){
if(typeof document!=="object")throw new Error("The style-loader cannot be used in a non-browser environment");
}

options=options||{};

options.attrs=typeof options.attrs==="object"?options.attrs:{};

// Force single-tag solution on IE6-9, which has a hard limit on the # of <style>
// tags it will allow on a page
if(!options.singleton&&typeof options.singleton!=="boolean")options.singleton=isOldIE();

// By default, add <style> tags to the <head> element
if(!options.insertInto)options.insertInto="head";

// By default, add <style> tags to the bottom of the target
if(!options.insertAt)options.insertAt="bottom";

var styles=listToStyles(list,options);

addStylesToDom(styles,options);

return function update(newList){
var mayRemove=[];

for(var i=0;i<styles.length;i++){
var item=styles[i];
var domStyle=stylesInDom[item.id];

domStyle.refs--;
mayRemove.push(domStyle);
}

if(newList){
var newStyles=listToStyles(newList,options);
addStylesToDom(newStyles,options);
}

for(var i=0;i<mayRemove.length;i++){
var domStyle=mayRemove[i];

if(domStyle.refs===0){
for(var j=0;j<domStyle.parts.length;j++){domStyle.parts[j]();}

delete stylesInDom[domStyle.id];
}
}
};
};

function addStylesToDom(styles,options){
for(var i=0;i<styles.length;i++){
var item=styles[i];
var domStyle=stylesInDom[item.id];

if(domStyle){
domStyle.refs++;

for(var j=0;j<domStyle.parts.length;j++){
domStyle.parts[j](item.parts[j]);
}

for(;j<item.parts.length;j++){
domStyle.parts.push(addStyle(item.parts[j],options));
}
}else {
var parts=[];

for(var j=0;j<item.parts.length;j++){
parts.push(addStyle(item.parts[j],options));
}

stylesInDom[item.id]={id:item.id,refs:1,parts:parts};
}
}
}

function listToStyles(list,options){
var styles=[];
var newStyles={};

for(var i=0;i<list.length;i++){
var item=list[i];
var id=options.base?item[0]+options.base:item[0];
var css=item[1];
var media=item[2];
var sourceMap=item[3];
var part={css:css,media:media,sourceMap:sourceMap};

if(!newStyles[id])styles.push(newStyles[id]={id:id,parts:[part]});else
newStyles[id].parts.push(part);
}

return styles;
}

function insertStyleElement(options,style){
var target=getElement(options.insertInto);

if(!target){
throw new Error("Couldn't find a style target. This probably means that the value for the 'insertInto' parameter is invalid.");
}

var lastStyleElementInsertedAtTop=stylesInsertedAtTop[stylesInsertedAtTop.length-1];

if(options.insertAt==="top"){
if(!lastStyleElementInsertedAtTop){
target.insertBefore(style,target.firstChild);
}else if(lastStyleElementInsertedAtTop.nextSibling){
target.insertBefore(style,lastStyleElementInsertedAtTop.nextSibling);
}else {
target.appendChild(style);
}
stylesInsertedAtTop.push(style);
}else if(options.insertAt==="bottom"){
target.appendChild(style);
}else if(typeof options.insertAt==="object"&&options.insertAt.before){
var nextSibling=getElement(options.insertAt.before,target);
target.insertBefore(style,nextSibling);
}else {
throw new Error("[Style Loader]\n\n Invalid value for parameter 'insertAt' ('options.insertAt') found.\n Must be 'top', 'bottom', or Object.\n (https://github.com/webpack-contrib/style-loader#insertat)\n");
}
}

function removeStyleElement(style){
if(style.parentNode===null)return false;
style.parentNode.removeChild(style);

var idx=stylesInsertedAtTop.indexOf(style);
if(idx>=0){
stylesInsertedAtTop.splice(idx,1);
}
}

function createStyleElement(options){
var style=document.createElement("style");

if(options.attrs.type===undefined){
options.attrs.type="text/css";
}

if(options.attrs.nonce===undefined){
var nonce=getNonce();
if(nonce){
options.attrs.nonce=nonce;
}
}

addAttrs(style,options.attrs);
insertStyleElement(options,style);

return style;
}

function createLinkElement(options){
var link=document.createElement("link");

if(options.attrs.type===undefined){
options.attrs.type="text/css";
}
options.attrs.rel="stylesheet";

addAttrs(link,options.attrs);
insertStyleElement(options,link);

return link;
}

function addAttrs(el,attrs){
Object.keys(attrs).forEach(function(key){
el.setAttribute(key,attrs[key]);
});
}

function getNonce(){

return __webpack_require__.nc;
}

function addStyle(obj,options){
var style,update,remove,result;

// If a transform function was defined, run it on the css
if(options.transform&&obj.css){
result=typeof options.transform==='function'?
options.transform(obj.css):
options.transform.default(obj.css);

if(result){
// If transform returns a value, use that instead of the original css.
// This allows running runtime transformations on the css.
obj.css=result;
}else {
// If the transform function returns a falsy value, don't add this css.
// This allows conditional loading of css
return function(){
// noop
};
}
}

if(options.singleton){
var styleIndex=singletonCounter++;

style=singleton||(singleton=createStyleElement(options));

update=applyToSingletonTag.bind(null,style,styleIndex,false);
remove=applyToSingletonTag.bind(null,style,styleIndex,true);

}else if(
obj.sourceMap&&
typeof URL==="function"&&
typeof URL.createObjectURL==="function"&&
typeof URL.revokeObjectURL==="function"&&
typeof Blob==="function"&&
typeof btoa==="function")
{
style=createLinkElement(options);
update=updateLink.bind(null,style,options);
remove=function remove(){
removeStyleElement(style);

if(style.href)URL.revokeObjectURL(style.href);
};
}else {
style=createStyleElement(options);
update=applyToTag.bind(null,style);
remove=function remove(){
removeStyleElement(style);
};
}

update(obj);

return function updateStyle(newObj){
if(newObj){
if(
newObj.css===obj.css&&
newObj.media===obj.media&&
newObj.sourceMap===obj.sourceMap)
{
return;
}

update(obj=newObj);
}else {
remove();
}
};
}

var replaceText=function(){
var textStore=[];

return function(index,replacement){
textStore[index]=replacement;

return textStore.filter(Boolean).join('\n');
};
}();

function applyToSingletonTag(style,index,remove,obj){
var css=remove?"":obj.css;

if(style.styleSheet){
style.styleSheet.cssText=replaceText(index,css);
}else {
var cssNode=document.createTextNode(css);
var childNodes=style.childNodes;

if(childNodes[index])style.removeChild(childNodes[index]);

if(childNodes.length){
style.insertBefore(cssNode,childNodes[index]);
}else {
style.appendChild(cssNode);
}
}
}

function applyToTag(style,obj){
var css=obj.css;
var media=obj.media;

if(media){
style.setAttribute("media",media);
}

if(style.styleSheet){
style.styleSheet.cssText=css;
}else {
while(style.firstChild){
style.removeChild(style.firstChild);
}

style.appendChild(document.createTextNode(css));
}
}

function updateLink(link,options,obj){
var css=obj.css;
var sourceMap=obj.sourceMap;

/*
		If convertToAbsoluteUrls isn't defined, but sourcemaps are enabled
		and there is no publicPath defined then lets turn convertToAbsoluteUrls
		on by default.  Otherwise default to the convertToAbsoluteUrls option
		directly
	*/
var autoFixUrls=options.convertToAbsoluteUrls===undefined&&sourceMap;

if(options.convertToAbsoluteUrls||autoFixUrls){
css=fixUrls(css);
}

if(sourceMap){
// http://stackoverflow.com/a/26603875
css+="\n/*# sourceMappingURL=data:application/json;base64,"+btoa(unescape(encodeURIComponent(JSON.stringify(sourceMap))))+" */";
}

var blob=new Blob([css],{type:"text/css"});

var oldSrc=link.href;

link.href=URL.createObjectURL(blob);

if(oldSrc)URL.revokeObjectURL(oldSrc);
}


/***/},

/***/"./node_modules/style-loader/lib/urls.js":
/*!***********************************************!*\
  !*** ./node_modules/style-loader/lib/urls.js ***!
  \***********************************************/
/*! no static exports found */
/***/function node_modulesStyleLoaderLibUrlsJs(module,exports){


/**
 * When source maps are enabled, `style-loader` uses a link element with a data-uri to
 * embed the css on the page. This breaks all relative urls because now they are relative to a
 * bundle instead of the current page.
 *
 * One solution is to only use full urls, but that may be impossible.
 *
 * Instead, this function "fixes" the relative urls to be absolute according to the current page location.
 *
 * A rudimentary test suite is located at `test/fixUrls.js` and can be run via the `npm test` command.
 *
 */

module.exports=function(css){
// get current location
var location=typeof window!=="undefined"&&window.location;

if(!location){
throw new Error("fixUrls requires window.location");
}

// blank or null?
if(!css||typeof css!=="string"){
return css;
}

var baseUrl=location.protocol+"//"+location.host;
var currentDir=baseUrl+location.pathname.replace(/\/[^\/]*$/,"/");

// convert each url(...)
/*
	This regular expression is just a way to recursively match brackets within
	a string.

	 /url\s*\(  = Match on the word "url" with any whitespace after it and then a parens
	   (  = Start a capturing group
	     (?:  = Start a non-capturing group
	         [^)(]  = Match anything that isn't a parentheses
	         |  = OR
	         \(  = Match a start parentheses
	             (?:  = Start another non-capturing groups
	                 [^)(]+  = Match anything that isn't a parentheses
	                 |  = OR
	                 \(  = Match a start parentheses
	                     [^)(]*  = Match anything that isn't a parentheses
	                 \)  = Match a end parentheses
	             )  = End Group
              *\) = Match anything and then a close parens
          )  = Close non-capturing group
          *  = Match anything
       )  = Close capturing group
	 \)  = Match a close parens

	 /gi  = Get all matches, not the first.  Be case insensitive.
	 */
var fixedCss=css.replace(/url\s*\(((?:[^)(]|\((?:[^)(]+|\([^)(]*\))*\))*)\)/gi,function(fullMatch,origUrl){
// strip quotes (if they exist)
var unquotedOrigUrl=origUrl.
trim().
replace(/^"(.*)"$/,function(o,$1){return $1;}).
replace(/^'(.*)'$/,function(o,$1){return $1;});

// already a full url? no change
if(/^(#|data:|http:\/\/|https:\/\/|file:\/\/\/|\s*$)/i.test(unquotedOrigUrl)){
return fullMatch;
}

// convert the url to a full url
var newUrl;

if(unquotedOrigUrl.indexOf("//")===0){
//TODO: should we add protocol?
newUrl=unquotedOrigUrl;
}else if(unquotedOrigUrl.indexOf("/")===0){
// path should be relative to the base url
newUrl=baseUrl+unquotedOrigUrl;// already starts with '/'
}else {
// path should be relative to current directory
newUrl=currentDir+unquotedOrigUrl.replace(/^\.\//,"");// Strip leading './'
}

// send back the fixed url(...)
return "url("+JSON.stringify(newUrl)+")";
});

// send back the fixed css
return fixedCss;
};


/***/},

/***/"./node_modules/sweetalert2/dist/sweetalert2.all.js":
/*!**********************************************************!*\
  !*** ./node_modules/sweetalert2/dist/sweetalert2.all.js ***!
  \**********************************************************/
/*! no static exports found */
/***/function node_modulesSweetalert2DistSweetalert2AllJs(module,exports,__webpack_require__){

/*!
* sweetalert2 v9.17.2
* Released under the MIT License.
*/
(function(global,factory){
module.exports=factory();
})(this,function(){
function _typeof(obj){
"@babel/helpers - typeof";

if(typeof Symbol==="function"&&typeof Symbol.iterator==="symbol"){
_typeof=function _typeof(obj){
return typeof obj;
};
}else {
_typeof=function _typeof(obj){
return obj&&typeof Symbol==="function"&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj;
};
}

return _typeof(obj);
}

function _classCallCheck(instance,Constructor){
if(!(instance instanceof Constructor)){
throw new TypeError("Cannot call a class as a function");
}
}

function _defineProperties(target,props){
for(var i=0;i<props.length;i++){
var descriptor=props[i];
descriptor.enumerable=descriptor.enumerable||false;
descriptor.configurable=true;
if("value"in descriptor)descriptor.writable=true;
Object.defineProperty(target,descriptor.key,descriptor);
}
}

function _createClass(Constructor,protoProps,staticProps){
if(protoProps)_defineProperties(Constructor.prototype,protoProps);
if(staticProps)_defineProperties(Constructor,staticProps);
return Constructor;
}

function _extends(){
_extends=Object.assign||function(target){
for(var i=1;i<arguments.length;i++){
var source=arguments[i];

for(var key in source){
if(Object.prototype.hasOwnProperty.call(source,key)){
target[key]=source[key];
}
}
}

return target;
};

return _extends.apply(this,arguments);
}

function _inherits(subClass,superClass){
if(typeof superClass!=="function"&&superClass!==null){
throw new TypeError("Super expression must either be null or a function");
}

subClass.prototype=Object.create(superClass&&superClass.prototype,{
constructor:{
value:subClass,
writable:true,
configurable:true}});


if(superClass)_setPrototypeOf(subClass,superClass);
}

function _getPrototypeOf(o){
_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function _getPrototypeOf(o){
return o.__proto__||Object.getPrototypeOf(o);
};
return _getPrototypeOf(o);
}

function _setPrototypeOf(o,p){
_setPrototypeOf=Object.setPrototypeOf||function _setPrototypeOf(o,p){
o.__proto__=p;
return o;
};

return _setPrototypeOf(o,p);
}

function _isNativeReflectConstruct(){
if(typeof Reflect==="undefined"||!Reflect.construct)return false;
if(Reflect.construct.sham)return false;
if(typeof Proxy==="function")return true;

try{
Date.prototype.toString.call(Reflect.construct(Date,[],function(){}));
return true;
}catch(e){
return false;
}
}

function _construct(Parent,args,Class){
if(_isNativeReflectConstruct()){
_construct=Reflect.construct;
}else {
_construct=function _construct(Parent,args,Class){
var a=[null];
a.push.apply(a,args);
var Constructor=Function.bind.apply(Parent,a);
var instance=new Constructor();
if(Class)_setPrototypeOf(instance,Class.prototype);
return instance;
};
}

return _construct.apply(null,arguments);
}

function _assertThisInitialized(self){
if(self===void 0){
throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
}

return self;
}

function _possibleConstructorReturn(self,call){
if(call&&(typeof call==="object"||typeof call==="function")){
return call;
}

return _assertThisInitialized(self);
}

function _createSuper(Derived){
var hasNativeReflectConstruct=_isNativeReflectConstruct();

return function _createSuperInternal(){
var Super=_getPrototypeOf(Derived),
result;

if(hasNativeReflectConstruct){
var NewTarget=_getPrototypeOf(this).constructor;

result=Reflect.construct(Super,arguments,NewTarget);
}else {
result=Super.apply(this,arguments);
}

return _possibleConstructorReturn(this,result);
};
}

function _superPropBase(object,property){
while(!Object.prototype.hasOwnProperty.call(object,property)){
object=_getPrototypeOf(object);
if(object===null)break;
}

return object;
}

function _get(target,property,receiver){
if(typeof Reflect!=="undefined"&&Reflect.get){
_get=Reflect.get;
}else {
_get=function _get(target,property,receiver){
var base=_superPropBase(target,property);

if(!base)return;
var desc=Object.getOwnPropertyDescriptor(base,property);

if(desc.get){
return desc.get.call(receiver);
}

return desc.value;
};
}

return _get(target,property,receiver||target);
}

var consolePrefix='SweetAlert2:';
/**
   * Filter the unique values into a new array
   * @param arr
   */

var uniqueArray=function uniqueArray(arr){
var result=[];

for(var i=0;i<arr.length;i++){
if(result.indexOf(arr[i])===-1){
result.push(arr[i]);
}
}

return result;
};
/**
   * Capitalize the first letter of a string
   * @param str
   */

var capitalizeFirstLetter=function capitalizeFirstLetter(str){
return str.charAt(0).toUpperCase()+str.slice(1);
};
/**
   * Returns the array of object values (Object.values isn't supported in IE11)
   * @param obj
   */

var objectValues=function objectValues(obj){
return Object.keys(obj).map(function(key){
return obj[key];
});
};
/**
   * Convert NodeList to Array
   * @param nodeList
   */

var toArray=function toArray(nodeList){
return Array.prototype.slice.call(nodeList);
};
/**
   * Standardise console warnings
   * @param message
   */

var warn=function warn(message){
console.warn("".concat(consolePrefix," ").concat(message));
};
/**
   * Standardise console errors
   * @param message
   */

var error=function error(message){
console.error("".concat(consolePrefix," ").concat(message));
};
/**
   * Private global state for `warnOnce`
   * @type {Array}
   * @private
   */

var previousWarnOnceMessages=[];
/**
   * Show a console warning, but only if it hasn't already been shown
   * @param message
   */

var warnOnce=function warnOnce(message){
if(!(previousWarnOnceMessages.indexOf(message)!==-1)){
previousWarnOnceMessages.push(message);
warn(message);
}
};
/**
   * Show a one-time console warning about deprecated params/methods
   */

var warnAboutDepreation=function warnAboutDepreation(deprecatedParam,useInstead){
warnOnce("\"".concat(deprecatedParam,"\" is deprecated and will be removed in the next major release. Please use \"").concat(useInstead,"\" instead."));
};
/**
   * If `arg` is a function, call it (with no arguments or context) and return the result.
   * Otherwise, just pass the value through
   * @param arg
   */

var callIfFunction=function callIfFunction(arg){
return typeof arg==='function'?arg():arg;
};
var hasToPromiseFn=function hasToPromiseFn(arg){
return arg&&typeof arg.toPromise==='function';
};
var asPromise=function asPromise(arg){
return hasToPromiseFn(arg)?arg.toPromise():Promise.resolve(arg);
};
var isPromise=function isPromise(arg){
return arg&&Promise.resolve(arg)===arg;
};

var DismissReason=Object.freeze({
cancel:'cancel',
backdrop:'backdrop',
close:'close',
esc:'esc',
timer:'timer'});


var isJqueryElement=function isJqueryElement(elem){
return _typeof(elem)==='object'&&elem.jquery;
};

var isElement=function isElement(elem){
return elem instanceof Element||isJqueryElement(elem);
};

var argsToParams=function argsToParams(args){
var params={};

if(_typeof(args[0])==='object'&&!isElement(args[0])){
_extends(params,args[0]);
}else {
['title','html','icon'].forEach(function(name,index){
var arg=args[index];

if(typeof arg==='string'||isElement(arg)){
params[name]=arg;
}else if(arg!==undefined){
error("Unexpected type of ".concat(name,"! Expected \"string\" or \"Element\", got ").concat(_typeof(arg)));
}
});
}

return params;
};

var swalPrefix='swal2-';
var prefix=function prefix(items){
var result={};

for(var i in items){
result[items[i]]=swalPrefix+items[i];
}

return result;
};
var swalClasses=prefix(['container','shown','height-auto','iosfix','popup','modal','no-backdrop','no-transition','toast','toast-shown','toast-column','show','hide','close','title','header','content','html-container','actions','confirm','cancel','footer','icon','icon-content','image','input','file','range','select','radio','checkbox','label','textarea','inputerror','validation-message','progress-steps','active-progress-step','progress-step','progress-step-line','loading','styled','top','top-start','top-end','top-left','top-right','center','center-start','center-end','center-left','center-right','bottom','bottom-start','bottom-end','bottom-left','bottom-right','grow-row','grow-column','grow-fullscreen','rtl','timer-progress-bar','timer-progress-bar-container','scrollbar-measure','icon-success','icon-warning','icon-info','icon-question','icon-error']);
var iconTypes=prefix(['success','warning','info','question','error']);

var getContainer=function getContainer(){
return document.body.querySelector(".".concat(swalClasses.container));
};
var elementBySelector=function elementBySelector(selectorString){
var container=getContainer();
return container?container.querySelector(selectorString):null;
};

var elementByClass=function elementByClass(className){
return elementBySelector(".".concat(className));
};

var getPopup=function getPopup(){
return elementByClass(swalClasses.popup);
};
var getIcons=function getIcons(){
var popup=getPopup();
return toArray(popup.querySelectorAll(".".concat(swalClasses.icon)));
};
var getIcon=function getIcon(){
var visibleIcon=getIcons().filter(function(icon){
return isVisible(icon);
});
return visibleIcon.length?visibleIcon[0]:null;
};
var getTitle=function getTitle(){
return elementByClass(swalClasses.title);
};
var getContent=function getContent(){
return elementByClass(swalClasses.content);
};
var getHtmlContainer=function getHtmlContainer(){
return elementByClass(swalClasses['html-container']);
};
var getImage=function getImage(){
return elementByClass(swalClasses.image);
};
var getProgressSteps=function getProgressSteps(){
return elementByClass(swalClasses['progress-steps']);
};
var getValidationMessage=function getValidationMessage(){
return elementByClass(swalClasses['validation-message']);
};
var getConfirmButton=function getConfirmButton(){
return elementBySelector(".".concat(swalClasses.actions," .").concat(swalClasses.confirm));
};
var getCancelButton=function getCancelButton(){
return elementBySelector(".".concat(swalClasses.actions," .").concat(swalClasses.cancel));
};
var getActions=function getActions(){
return elementByClass(swalClasses.actions);
};
var getHeader=function getHeader(){
return elementByClass(swalClasses.header);
};
var getFooter=function getFooter(){
return elementByClass(swalClasses.footer);
};
var getTimerProgressBar=function getTimerProgressBar(){
return elementByClass(swalClasses['timer-progress-bar']);
};
var getCloseButton=function getCloseButton(){
return elementByClass(swalClasses.close);
};// https://github.com/jkup/focusable/blob/master/index.js

var focusable="\n  a[href],\n  area[href],\n  input:not([disabled]),\n  select:not([disabled]),\n  textarea:not([disabled]),\n  button:not([disabled]),\n  iframe,\n  object,\n  embed,\n  [tabindex=\"0\"],\n  [contenteditable],\n  audio[controls],\n  video[controls],\n  summary\n";
var getFocusableElements=function getFocusableElements(){
var focusableElementsWithTabindex=toArray(getPopup().querySelectorAll('[tabindex]:not([tabindex="-1"]):not([tabindex="0"])'))// sort according to tabindex
.sort(function(a,b){
a=parseInt(a.getAttribute('tabindex'));
b=parseInt(b.getAttribute('tabindex'));

if(a>b){
return 1;
}else if(a<b){
return -1;
}

return 0;
});
var otherFocusableElements=toArray(getPopup().querySelectorAll(focusable)).filter(function(el){
return el.getAttribute('tabindex')!=='-1';
});
return uniqueArray(focusableElementsWithTabindex.concat(otherFocusableElements)).filter(function(el){
return isVisible(el);
});
};
var isModal=function isModal(){
return !isToast()&&!document.body.classList.contains(swalClasses['no-backdrop']);
};
var isToast=function isToast(){
return document.body.classList.contains(swalClasses['toast-shown']);
};
var isLoading=function isLoading(){
return getPopup().hasAttribute('data-loading');
};

var states={
previousBodyPadding:null};

var setInnerHtml=function setInnerHtml(elem,html){
// #1926
elem.textContent='';

if(html){
var parser=new DOMParser();
var parsed=parser.parseFromString(html,"text/html");
toArray(parsed.querySelector('head').childNodes).forEach(function(child){
elem.appendChild(child);
});
toArray(parsed.querySelector('body').childNodes).forEach(function(child){
elem.appendChild(child);
});
}
};
var hasClass=function hasClass(elem,className){
if(!className){
return false;
}

var classList=className.split(/\s+/);

for(var i=0;i<classList.length;i++){
if(!elem.classList.contains(classList[i])){
return false;
}
}

return true;
};

var removeCustomClasses=function removeCustomClasses(elem,params){
toArray(elem.classList).forEach(function(className){
if(!(objectValues(swalClasses).indexOf(className)!==-1)&&!(objectValues(iconTypes).indexOf(className)!==-1)&&!(objectValues(params.showClass).indexOf(className)!==-1)){
elem.classList.remove(className);
}
});
};

var applyCustomClass=function applyCustomClass(elem,params,className){
removeCustomClasses(elem,params);

if(params.customClass&&params.customClass[className]){
if(typeof params.customClass[className]!=='string'&&!params.customClass[className].forEach){
return warn("Invalid type of customClass.".concat(className,"! Expected string or iterable object, got \"").concat(_typeof(params.customClass[className]),"\""));
}

addClass(elem,params.customClass[className]);
}
};
function getInput(content,inputType){
if(!inputType){
return null;
}

switch(inputType){
case'select':
case'textarea':
case'file':
return getChildByClass(content,swalClasses[inputType]);

case'checkbox':
return content.querySelector(".".concat(swalClasses.checkbox," input"));

case'radio':
return content.querySelector(".".concat(swalClasses.radio," input:checked"))||content.querySelector(".".concat(swalClasses.radio," input:first-child"));

case'range':
return content.querySelector(".".concat(swalClasses.range," input"));

default:
return getChildByClass(content,swalClasses.input);}

}
var focusInput=function focusInput(input){
input.focus();// place cursor at end of text in text input

if(input.type!=='file'){
// http://stackoverflow.com/a/2345915
var val=input.value;
input.value='';
input.value=val;
}
};
var toggleClass=function toggleClass(target,classList,condition){
if(!target||!classList){
return;
}

if(typeof classList==='string'){
classList=classList.split(/\s+/).filter(Boolean);
}

classList.forEach(function(className){
if(target.forEach){
target.forEach(function(elem){
condition?elem.classList.add(className):elem.classList.remove(className);
});
}else {
condition?target.classList.add(className):target.classList.remove(className);
}
});
};
var addClass=function addClass(target,classList){
toggleClass(target,classList,true);
};
var removeClass=function removeClass(target,classList){
toggleClass(target,classList,false);
};
var getChildByClass=function getChildByClass(elem,className){
for(var i=0;i<elem.childNodes.length;i++){
if(hasClass(elem.childNodes[i],className)){
return elem.childNodes[i];
}
}
};
var applyNumericalStyle=function applyNumericalStyle(elem,property,value){
if(value||parseInt(value)===0){
elem.style[property]=typeof value==='number'?"".concat(value,"px"):value;
}else {
elem.style.removeProperty(property);
}
};
var show=function show(elem){
var display=arguments.length>1&&arguments[1]!==undefined?arguments[1]:'flex';
elem.style.opacity='';
elem.style.display=display;
};
var hide=function hide(elem){
elem.style.opacity='';
elem.style.display='none';
};
var toggle=function toggle(elem,condition,display){
condition?show(elem,display):hide(elem);
};// borrowed from jquery $(elem).is(':visible') implementation

var isVisible=function isVisible(elem){
return !!(elem&&(elem.offsetWidth||elem.offsetHeight||elem.getClientRects().length));
};
/* istanbul ignore next */

var isScrollable=function isScrollable(elem){
return !!(elem.scrollHeight>elem.clientHeight);
};// borrowed from https://stackoverflow.com/a/46352119

var hasCssAnimation=function hasCssAnimation(elem){
var style=window.getComputedStyle(elem);
var animDuration=parseFloat(style.getPropertyValue('animation-duration')||'0');
var transDuration=parseFloat(style.getPropertyValue('transition-duration')||'0');
return animDuration>0||transDuration>0;
};
var contains=function contains(haystack,needle){
if(typeof haystack.contains==='function'){
return haystack.contains(needle);
}
};
var animateTimerProgressBar=function animateTimerProgressBar(timer){
var reset=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;
var timerProgressBar=getTimerProgressBar();

if(isVisible(timerProgressBar)){
if(reset){
timerProgressBar.style.transition='none';
timerProgressBar.style.width='100%';
}

setTimeout(function(){
timerProgressBar.style.transition="width ".concat(timer/1000,"s linear");
timerProgressBar.style.width='0%';
},10);
}
};
var stopTimerProgressBar=function stopTimerProgressBar(){
var timerProgressBar=getTimerProgressBar();
var timerProgressBarWidth=parseInt(window.getComputedStyle(timerProgressBar).width);
timerProgressBar.style.removeProperty('transition');
timerProgressBar.style.width='100%';
var timerProgressBarFullWidth=parseInt(window.getComputedStyle(timerProgressBar).width);
var timerProgressBarPercent=parseInt(timerProgressBarWidth/timerProgressBarFullWidth*100);
timerProgressBar.style.removeProperty('transition');
timerProgressBar.style.width="".concat(timerProgressBarPercent,"%");
};

// Detect Node env
var isNodeEnv=function isNodeEnv(){
return typeof window==='undefined'||typeof document==='undefined';
};

var sweetHTML="\n <div aria-labelledby=\"".concat(swalClasses.title,"\" aria-describedby=\"").concat(swalClasses.content,"\" class=\"").concat(swalClasses.popup,"\" tabindex=\"-1\">\n   <div class=\"").concat(swalClasses.header,"\">\n     <ul class=\"").concat(swalClasses['progress-steps'],"\"></ul>\n     <div class=\"").concat(swalClasses.icon," ").concat(iconTypes.error,"\"></div>\n     <div class=\"").concat(swalClasses.icon," ").concat(iconTypes.question,"\"></div>\n     <div class=\"").concat(swalClasses.icon," ").concat(iconTypes.warning,"\"></div>\n     <div class=\"").concat(swalClasses.icon," ").concat(iconTypes.info,"\"></div>\n     <div class=\"").concat(swalClasses.icon," ").concat(iconTypes.success,"\"></div>\n     <img class=\"").concat(swalClasses.image,"\" />\n     <h2 class=\"").concat(swalClasses.title,"\" id=\"").concat(swalClasses.title,"\"></h2>\n     <button type=\"button\" class=\"").concat(swalClasses.close,"\"></button>\n   </div>\n   <div class=\"").concat(swalClasses.content,"\">\n     <div id=\"").concat(swalClasses.content,"\" class=\"").concat(swalClasses['html-container'],"\"></div>\n     <input class=\"").concat(swalClasses.input,"\" />\n     <input type=\"file\" class=\"").concat(swalClasses.file,"\" />\n     <div class=\"").concat(swalClasses.range,"\">\n       <input type=\"range\" />\n       <output></output>\n     </div>\n     <select class=\"").concat(swalClasses.select,"\"></select>\n     <div class=\"").concat(swalClasses.radio,"\"></div>\n     <label for=\"").concat(swalClasses.checkbox,"\" class=\"").concat(swalClasses.checkbox,"\">\n       <input type=\"checkbox\" />\n       <span class=\"").concat(swalClasses.label,"\"></span>\n     </label>\n     <textarea class=\"").concat(swalClasses.textarea,"\"></textarea>\n     <div class=\"").concat(swalClasses['validation-message'],"\" id=\"").concat(swalClasses['validation-message'],"\"></div>\n   </div>\n   <div class=\"").concat(swalClasses.actions,"\">\n     <button type=\"button\" class=\"").concat(swalClasses.confirm,"\">OK</button>\n     <button type=\"button\" class=\"").concat(swalClasses.cancel,"\">Cancel</button>\n   </div>\n   <div class=\"").concat(swalClasses.footer,"\"></div>\n   <div class=\"").concat(swalClasses['timer-progress-bar-container'],"\">\n     <div class=\"").concat(swalClasses['timer-progress-bar'],"\"></div>\n   </div>\n </div>\n").replace(/(^|\n)\s*/g,'');

var resetOldContainer=function resetOldContainer(){
var oldContainer=getContainer();

if(!oldContainer){
return false;
}

oldContainer.parentNode.removeChild(oldContainer);
removeClass([document.documentElement,document.body],[swalClasses['no-backdrop'],swalClasses['toast-shown'],swalClasses['has-column']]);
return true;
};

var oldInputVal;// IE11 workaround, see #1109 for details

var resetValidationMessage=function resetValidationMessage(e){
if(Swal.isVisible()&&oldInputVal!==e.target.value){
Swal.resetValidationMessage();
}

oldInputVal=e.target.value;
};

var addInputChangeListeners=function addInputChangeListeners(){
var content=getContent();
var input=getChildByClass(content,swalClasses.input);
var file=getChildByClass(content,swalClasses.file);
var range=content.querySelector(".".concat(swalClasses.range," input"));
var rangeOutput=content.querySelector(".".concat(swalClasses.range," output"));
var select=getChildByClass(content,swalClasses.select);
var checkbox=content.querySelector(".".concat(swalClasses.checkbox," input"));
var textarea=getChildByClass(content,swalClasses.textarea);
input.oninput=resetValidationMessage;
file.onchange=resetValidationMessage;
select.onchange=resetValidationMessage;
checkbox.onchange=resetValidationMessage;
textarea.oninput=resetValidationMessage;

range.oninput=function(e){
resetValidationMessage(e);
rangeOutput.value=range.value;
};

range.onchange=function(e){
resetValidationMessage(e);
range.nextSibling.value=range.value;
};
};

var getTarget=function getTarget(target){
return typeof target==='string'?document.querySelector(target):target;
};

var setupAccessibility=function setupAccessibility(params){
var popup=getPopup();
popup.setAttribute('role',params.toast?'alert':'dialog');
popup.setAttribute('aria-live',params.toast?'polite':'assertive');

if(!params.toast){
popup.setAttribute('aria-modal','true');
}
};

var setupRTL=function setupRTL(targetElement){
if(window.getComputedStyle(targetElement).direction==='rtl'){
addClass(getContainer(),swalClasses.rtl);
}
};
/*
   * Add modal + backdrop to DOM
   */


var init=function init(params){
// Clean up the old popup container if it exists
var oldContainerExisted=resetOldContainer();
/* istanbul ignore if */

if(isNodeEnv()){
error('SweetAlert2 requires document to initialize');
return;
}

var container=document.createElement('div');
container.className=swalClasses.container;

if(oldContainerExisted){
addClass(container,swalClasses['no-transition']);
}

setInnerHtml(container,sweetHTML);
var targetElement=getTarget(params.target);
targetElement.appendChild(container);
setupAccessibility(params);
setupRTL(targetElement);
addInputChangeListeners();
};

var parseHtmlToContainer=function parseHtmlToContainer(param,target){
// DOM element
if(param instanceof HTMLElement){
target.appendChild(param);// Object
}else if(_typeof(param)==='object'){
handleObject(param,target);// Plain string
}else if(param){
setInnerHtml(target,param);
}
};

var handleObject=function handleObject(param,target){
// JQuery element(s)
if(param.jquery){
handleJqueryElem(target,param);// For other objects use their string representation
}else {
setInnerHtml(target,param.toString());
}
};

var handleJqueryElem=function handleJqueryElem(target,elem){
target.textContent='';

if(0 in elem){
for(var i=0;(i in elem);i++){
target.appendChild(elem[i].cloneNode(true));
}
}else {
target.appendChild(elem.cloneNode(true));
}
};

var animationEndEvent=function(){
// Prevent run in Node env

/* istanbul ignore if */
if(isNodeEnv()){
return false;
}

var testEl=document.createElement('div');
var transEndEventNames={
WebkitAnimation:'webkitAnimationEnd',
OAnimation:'oAnimationEnd oanimationend',
animation:'animationend'};


for(var i in transEndEventNames){
if(Object.prototype.hasOwnProperty.call(transEndEventNames,i)&&typeof testEl.style[i]!=='undefined'){
return transEndEventNames[i];
}
}

return false;
}();

// https://github.com/twbs/bootstrap/blob/master/js/src/modal.js

var measureScrollbar=function measureScrollbar(){
var scrollDiv=document.createElement('div');
scrollDiv.className=swalClasses['scrollbar-measure'];
document.body.appendChild(scrollDiv);
var scrollbarWidth=scrollDiv.getBoundingClientRect().width-scrollDiv.clientWidth;
document.body.removeChild(scrollDiv);
return scrollbarWidth;
};

var renderActions=function renderActions(instance,params){
var actions=getActions();
var confirmButton=getConfirmButton();
var cancelButton=getCancelButton();// Actions (buttons) wrapper

if(!params.showConfirmButton&&!params.showCancelButton){
hide(actions);
}// Custom class


applyCustomClass(actions,params,'actions');// Render confirm button

renderButton(confirmButton,'confirm',params);// render Cancel Button

renderButton(cancelButton,'cancel',params);

if(params.buttonsStyling){
handleButtonsStyling(confirmButton,cancelButton,params);
}else {
removeClass([confirmButton,cancelButton],swalClasses.styled);
confirmButton.style.backgroundColor=confirmButton.style.borderLeftColor=confirmButton.style.borderRightColor='';
cancelButton.style.backgroundColor=cancelButton.style.borderLeftColor=cancelButton.style.borderRightColor='';
}

if(params.reverseButtons){
confirmButton.parentNode.insertBefore(cancelButton,confirmButton);
}
};

function handleButtonsStyling(confirmButton,cancelButton,params){
addClass([confirmButton,cancelButton],swalClasses.styled);// Buttons background colors

if(params.confirmButtonColor){
confirmButton.style.backgroundColor=params.confirmButtonColor;
}

if(params.cancelButtonColor){
cancelButton.style.backgroundColor=params.cancelButtonColor;
}// Loading state


if(!isLoading()){
var confirmButtonBackgroundColor=window.getComputedStyle(confirmButton).getPropertyValue('background-color');
confirmButton.style.borderLeftColor=confirmButtonBackgroundColor;
confirmButton.style.borderRightColor=confirmButtonBackgroundColor;
}
}

function renderButton(button,buttonType,params){
toggle(button,params["show".concat(capitalizeFirstLetter(buttonType),"Button")],'inline-block');
setInnerHtml(button,params["".concat(buttonType,"ButtonText")]);// Set caption text

button.setAttribute('aria-label',params["".concat(buttonType,"ButtonAriaLabel")]);// ARIA label
// Add buttons custom classes

button.className=swalClasses[buttonType];
applyCustomClass(button,params,"".concat(buttonType,"Button"));
addClass(button,params["".concat(buttonType,"ButtonClass")]);
}

function handleBackdropParam(container,backdrop){
if(typeof backdrop==='string'){
container.style.background=backdrop;
}else if(!backdrop){
addClass([document.documentElement,document.body],swalClasses['no-backdrop']);
}
}

function handlePositionParam(container,position){
if(position in swalClasses){
addClass(container,swalClasses[position]);
}else {
warn('The "position" parameter is not valid, defaulting to "center"');
addClass(container,swalClasses.center);
}
}

function handleGrowParam(container,grow){
if(grow&&typeof grow==='string'){
var growClass="grow-".concat(grow);

if(growClass in swalClasses){
addClass(container,swalClasses[growClass]);
}
}
}

var renderContainer=function renderContainer(instance,params){
var container=getContainer();

if(!container){
return;
}

handleBackdropParam(container,params.backdrop);

if(!params.backdrop&&params.allowOutsideClick){
warn('"allowOutsideClick" parameter requires `backdrop` parameter to be set to `true`');
}

handlePositionParam(container,params.position);
handleGrowParam(container,params.grow);// Custom class

applyCustomClass(container,params,'container');// Set queue step attribute for getQueueStep() method

var queueStep=document.body.getAttribute('data-swal2-queue-step');

if(queueStep){
container.setAttribute('data-queue-step',queueStep);
document.body.removeAttribute('data-swal2-queue-step');
}
};

/**
   * This module containts `WeakMap`s for each effectively-"private  property" that a `Swal` has.
   * For example, to set the private property "foo" of `this` to "bar", you can `privateProps.foo.set(this, 'bar')`
   * This is the approach that Babel will probably take to implement private methods/fields
   *   https://github.com/tc39/proposal-private-methods
   *   https://github.com/babel/babel/pull/7555
   * Once we have the changes from that PR in Babel, and our core class fits reasonable in *one module*
   *   then we can use that language feature.
   */
var privateProps={
promise:new WeakMap(),
innerParams:new WeakMap(),
domCache:new WeakMap()};


var inputTypes=['input','file','range','select','radio','checkbox','textarea'];
var renderInput=function renderInput(instance,params){
var content=getContent();
var innerParams=privateProps.innerParams.get(instance);
var rerender=!innerParams||params.input!==innerParams.input;
inputTypes.forEach(function(inputType){
var inputClass=swalClasses[inputType];
var inputContainer=getChildByClass(content,inputClass);// set attributes

setAttributes(inputType,params.inputAttributes);// set class

inputContainer.className=inputClass;

if(rerender){
hide(inputContainer);
}
});

if(params.input){
if(rerender){
showInput(params);
}// set custom class


setCustomClass(params);
}
};

var showInput=function showInput(params){
if(!renderInputType[params.input]){
return error("Unexpected type of input! Expected \"text\", \"email\", \"password\", \"number\", \"tel\", \"select\", \"radio\", \"checkbox\", \"textarea\", \"file\" or \"url\", got \"".concat(params.input,"\""));
}

var inputContainer=getInputContainer(params.input);
var input=renderInputType[params.input](inputContainer,params);
show(input);// input autofocus

setTimeout(function(){
focusInput(input);
});
};

var removeAttributes=function removeAttributes(input){
for(var i=0;i<input.attributes.length;i++){
var attrName=input.attributes[i].name;

if(!(['type','value','style'].indexOf(attrName)!==-1)){
input.removeAttribute(attrName);
}
}
};

var setAttributes=function setAttributes(inputType,inputAttributes){
var input=getInput(getContent(),inputType);

if(!input){
return;
}

removeAttributes(input);

for(var attr in inputAttributes){
// Do not set a placeholder for <input type="range">
// it'll crash Edge, #1298
if(inputType==='range'&&attr==='placeholder'){
continue;
}

input.setAttribute(attr,inputAttributes[attr]);
}
};

var setCustomClass=function setCustomClass(params){
var inputContainer=getInputContainer(params.input);

if(params.customClass){
addClass(inputContainer,params.customClass.input);
}
};

var setInputPlaceholder=function setInputPlaceholder(input,params){
if(!input.placeholder||params.inputPlaceholder){
input.placeholder=params.inputPlaceholder;
}
};

var getInputContainer=function getInputContainer(inputType){
var inputClass=swalClasses[inputType]?swalClasses[inputType]:swalClasses.input;
return getChildByClass(getContent(),inputClass);
};

var renderInputType={};

renderInputType.text=renderInputType.email=renderInputType.password=renderInputType.number=renderInputType.tel=renderInputType.url=function(input,params){
if(typeof params.inputValue==='string'||typeof params.inputValue==='number'){
input.value=params.inputValue;
}else if(!isPromise(params.inputValue)){
warn("Unexpected type of inputValue! Expected \"string\", \"number\" or \"Promise\", got \"".concat(_typeof(params.inputValue),"\""));
}

setInputPlaceholder(input,params);
input.type=params.input;
return input;
};

renderInputType.file=function(input,params){
setInputPlaceholder(input,params);
return input;
};

renderInputType.range=function(range,params){
var rangeInput=range.querySelector('input');
var rangeOutput=range.querySelector('output');
rangeInput.value=params.inputValue;
rangeInput.type=params.input;
rangeOutput.value=params.inputValue;
return range;
};

renderInputType.select=function(select,params){
select.textContent='';

if(params.inputPlaceholder){
var placeholder=document.createElement('option');
setInnerHtml(placeholder,params.inputPlaceholder);
placeholder.value='';
placeholder.disabled=true;
placeholder.selected=true;
select.appendChild(placeholder);
}

return select;
};

renderInputType.radio=function(radio){
radio.textContent='';
return radio;
};

renderInputType.checkbox=function(checkboxContainer,params){
var checkbox=getInput(getContent(),'checkbox');
checkbox.value=1;
checkbox.id=swalClasses.checkbox;
checkbox.checked=Boolean(params.inputValue);
var label=checkboxContainer.querySelector('span');
setInnerHtml(label,params.inputPlaceholder);
return checkboxContainer;
};

renderInputType.textarea=function(textarea,params){
textarea.value=params.inputValue;
setInputPlaceholder(textarea,params);

if('MutationObserver'in window){
// #1699
var initialPopupWidth=parseInt(window.getComputedStyle(getPopup()).width);
var popupPadding=parseInt(window.getComputedStyle(getPopup()).paddingLeft)+parseInt(window.getComputedStyle(getPopup()).paddingRight);

var outputsize=function outputsize(){
var contentWidth=textarea.offsetWidth+popupPadding;

if(contentWidth>initialPopupWidth){
getPopup().style.width="".concat(contentWidth,"px");
}else {
getPopup().style.width=null;
}
};

new MutationObserver(outputsize).observe(textarea,{
attributes:true,
attributeFilter:['style']});

}

return textarea;
};

var renderContent=function renderContent(instance,params){
var content=getContent().querySelector("#".concat(swalClasses.content));// Content as HTML

if(params.html){
parseHtmlToContainer(params.html,content);
show(content,'block');// Content as plain text
}else if(params.text){
content.textContent=params.text;
show(content,'block');// No content
}else {
hide(content);
}

renderInput(instance,params);// Custom class

applyCustomClass(getContent(),params,'content');
};

var renderFooter=function renderFooter(instance,params){
var footer=getFooter();
toggle(footer,params.footer);

if(params.footer){
parseHtmlToContainer(params.footer,footer);
}// Custom class


applyCustomClass(footer,params,'footer');
};

var renderCloseButton=function renderCloseButton(instance,params){
var closeButton=getCloseButton();
setInnerHtml(closeButton,params.closeButtonHtml);// Custom class

applyCustomClass(closeButton,params,'closeButton');
toggle(closeButton,params.showCloseButton);
closeButton.setAttribute('aria-label',params.closeButtonAriaLabel);
};

var renderIcon=function renderIcon(instance,params){
var innerParams=privateProps.innerParams.get(instance);// if the give icon already rendered, apply the custom class without re-rendering the icon

if(innerParams&&params.icon===innerParams.icon&&getIcon()){
applyCustomClass(getIcon(),params,'icon');
return;
}

hideAllIcons();

if(!params.icon){
return;
}

if(Object.keys(iconTypes).indexOf(params.icon)!==-1){
var icon=elementBySelector(".".concat(swalClasses.icon,".").concat(iconTypes[params.icon]));
show(icon);// Custom or default content

setContent(icon,params);
adjustSuccessIconBackgoundColor();// Custom class

applyCustomClass(icon,params,'icon');// Animate icon

addClass(icon,params.showClass.icon);
}else {
error("Unknown icon! Expected \"success\", \"error\", \"warning\", \"info\" or \"question\", got \"".concat(params.icon,"\""));
}
};

var hideAllIcons=function hideAllIcons(){
var icons=getIcons();

for(var i=0;i<icons.length;i++){
hide(icons[i]);
}
};// Adjust success icon background color to match the popup background color


var adjustSuccessIconBackgoundColor=function adjustSuccessIconBackgoundColor(){
var popup=getPopup();
var popupBackgroundColor=window.getComputedStyle(popup).getPropertyValue('background-color');
var successIconParts=popup.querySelectorAll('[class^=swal2-success-circular-line], .swal2-success-fix');

for(var i=0;i<successIconParts.length;i++){
successIconParts[i].style.backgroundColor=popupBackgroundColor;
}
};

var setContent=function setContent(icon,params){
icon.textContent='';

if(params.iconHtml){
setInnerHtml(icon,iconContent(params.iconHtml));
}else if(params.icon==='success'){
setInnerHtml(icon,"\n      <div class=\"swal2-success-circular-line-left\"></div>\n      <span class=\"swal2-success-line-tip\"></span> <span class=\"swal2-success-line-long\"></span>\n      <div class=\"swal2-success-ring\"></div> <div class=\"swal2-success-fix\"></div>\n      <div class=\"swal2-success-circular-line-right\"></div>\n    ");
}else if(params.icon==='error'){
setInnerHtml(icon,"\n      <span class=\"swal2-x-mark\">\n        <span class=\"swal2-x-mark-line-left\"></span>\n        <span class=\"swal2-x-mark-line-right\"></span>\n      </span>\n    ");
}else {
var defaultIconHtml={
question:'?',
warning:'!',
info:'i'};

setInnerHtml(icon,iconContent(defaultIconHtml[params.icon]));
}
};

var iconContent=function iconContent(content){
return "<div class=\"".concat(swalClasses['icon-content'],"\">").concat(content,"</div>");
};

var renderImage=function renderImage(instance,params){
var image=getImage();

if(!params.imageUrl){
return hide(image);
}

show(image,'');// Src, alt

image.setAttribute('src',params.imageUrl);
image.setAttribute('alt',params.imageAlt);// Width, height

applyNumericalStyle(image,'width',params.imageWidth);
applyNumericalStyle(image,'height',params.imageHeight);// Class

image.className=swalClasses.image;
applyCustomClass(image,params,'image');
};

var currentSteps=[];
/*
   * Global function for chaining sweetAlert popups
   */

var queue=function queue(steps){
var Swal=this;
currentSteps=steps;

var resetAndResolve=function resetAndResolve(resolve,value){
currentSteps=[];
resolve(value);
};

var queueResult=[];
return new Promise(function(resolve){
(function step(i,callback){
if(i<currentSteps.length){
document.body.setAttribute('data-swal2-queue-step',i);
Swal.fire(currentSteps[i]).then(function(result){
if(typeof result.value!=='undefined'){
queueResult.push(result.value);
step(i+1);
}else {
resetAndResolve(resolve,{
dismiss:result.dismiss});

}
});
}else {
resetAndResolve(resolve,{
value:queueResult});

}
})(0);
});
};
/*
   * Global function for getting the index of current popup in queue
   */

var getQueueStep=function getQueueStep(){
return getContainer()&&getContainer().getAttribute('data-queue-step');
};
/*
   * Global function for inserting a popup to the queue
   */

var insertQueueStep=function insertQueueStep(step,index){
if(index&&index<currentSteps.length){
return currentSteps.splice(index,0,step);
}

return currentSteps.push(step);
};
/*
   * Global function for deleting a popup from the queue
   */

var deleteQueueStep=function deleteQueueStep(index){
if(typeof currentSteps[index]!=='undefined'){
currentSteps.splice(index,1);
}
};

var createStepElement=function createStepElement(step){
var stepEl=document.createElement('li');
addClass(stepEl,swalClasses['progress-step']);
setInnerHtml(stepEl,step);
return stepEl;
};

var createLineElement=function createLineElement(params){
var lineEl=document.createElement('li');
addClass(lineEl,swalClasses['progress-step-line']);

if(params.progressStepsDistance){
lineEl.style.width=params.progressStepsDistance;
}

return lineEl;
};

var renderProgressSteps=function renderProgressSteps(instance,params){
var progressStepsContainer=getProgressSteps();

if(!params.progressSteps||params.progressSteps.length===0){
return hide(progressStepsContainer);
}

show(progressStepsContainer);
progressStepsContainer.textContent='';
var currentProgressStep=parseInt(params.currentProgressStep===undefined?getQueueStep():params.currentProgressStep);

if(currentProgressStep>=params.progressSteps.length){
warn('Invalid currentProgressStep parameter, it should be less than progressSteps.length '+'(currentProgressStep like JS arrays starts from 0)');
}

params.progressSteps.forEach(function(step,index){
var stepEl=createStepElement(step);
progressStepsContainer.appendChild(stepEl);

if(index===currentProgressStep){
addClass(stepEl,swalClasses['active-progress-step']);
}

if(index!==params.progressSteps.length-1){
var lineEl=createLineElement(params);
progressStepsContainer.appendChild(lineEl);
}
});
};

var renderTitle=function renderTitle(instance,params){
var title=getTitle();
toggle(title,params.title||params.titleText);

if(params.title){
parseHtmlToContainer(params.title,title);
}

if(params.titleText){
title.innerText=params.titleText;
}// Custom class


applyCustomClass(title,params,'title');
};

var renderHeader=function renderHeader(instance,params){
var header=getHeader();// Custom class

applyCustomClass(header,params,'header');// Progress steps

renderProgressSteps(instance,params);// Icon

renderIcon(instance,params);// Image

renderImage(instance,params);// Title

renderTitle(instance,params);// Close button

renderCloseButton(instance,params);
};

var renderPopup=function renderPopup(instance,params){
var popup=getPopup();// Width

applyNumericalStyle(popup,'width',params.width);// Padding

applyNumericalStyle(popup,'padding',params.padding);// Background

if(params.background){
popup.style.background=params.background;
}// Classes


addClasses(popup,params);
};

var addClasses=function addClasses(popup,params){
// Default Class + showClass when updating Swal.update({})
popup.className="".concat(swalClasses.popup," ").concat(isVisible(popup)?params.showClass.popup:'');

if(params.toast){
addClass([document.documentElement,document.body],swalClasses['toast-shown']);
addClass(popup,swalClasses.toast);
}else {
addClass(popup,swalClasses.modal);
}// Custom class


applyCustomClass(popup,params,'popup');

if(typeof params.customClass==='string'){
addClass(popup,params.customClass);
}// Icon class (#1842)


if(params.icon){
addClass(popup,swalClasses["icon-".concat(params.icon)]);
}
};

var render=function render(instance,params){
renderPopup(instance,params);
renderContainer(instance,params);
renderHeader(instance,params);
renderContent(instance,params);
renderActions(instance,params);
renderFooter(instance,params);

if(typeof params.onRender==='function'){
params.onRender(getPopup());
}
};

/*
   * Global function to determine if SweetAlert2 popup is shown
   */

var isVisible$1=function isVisible$$1(){
return isVisible(getPopup());
};
/*
   * Global function to click 'Confirm' button
   */

var clickConfirm=function clickConfirm(){
return getConfirmButton()&&getConfirmButton().click();
};
/*
   * Global function to click 'Cancel' button
   */

var clickCancel=function clickCancel(){
return getCancelButton()&&getCancelButton().click();
};

function fire(){
var Swal=this;

for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){
args[_key]=arguments[_key];
}

return _construct(Swal,args);
}

/**
   * Returns an extended version of `Swal` containing `params` as defaults.
   * Useful for reusing Swal configuration.
   *
   * For example:
   *
   * Before:
   * const textPromptOptions = { input: 'text', showCancelButton: true }
   * const {value: firstName} = await Swal.fire({ ...textPromptOptions, title: 'What is your first name?' })
   * const {value: lastName} = await Swal.fire({ ...textPromptOptions, title: 'What is your last name?' })
   *
   * After:
   * const TextPrompt = Swal.mixin({ input: 'text', showCancelButton: true })
   * const {value: firstName} = await TextPrompt('What is your first name?')
   * const {value: lastName} = await TextPrompt('What is your last name?')
   *
   * @param mixinParams
   */
function mixin(mixinParams){
var MixinSwal=/*#__PURE__*/function(_this){
_inherits(MixinSwal,_this);

var _super=_createSuper(MixinSwal);

function MixinSwal(){
_classCallCheck(this,MixinSwal);

return _super.apply(this,arguments);
}

_createClass(MixinSwal,[{
key:"_main",
value:function _main(params){
return _get(_getPrototypeOf(MixinSwal.prototype),"_main",this).call(this,_extends({},mixinParams,params));
}}]);


return MixinSwal;
}(this);

return MixinSwal;
}

/**
   * Show spinner instead of Confirm button
   */

var showLoading=function showLoading(){
var popup=getPopup();

if(!popup){
Swal.fire();
}

popup=getPopup();
var actions=getActions();
var confirmButton=getConfirmButton();
show(actions);
show(confirmButton,'inline-block');
addClass([popup,actions],swalClasses.loading);
confirmButton.disabled=true;
popup.setAttribute('data-loading',true);
popup.setAttribute('aria-busy',true);
popup.focus();
};

var RESTORE_FOCUS_TIMEOUT=100;

var globalState={};

var focusPreviousActiveElement=function focusPreviousActiveElement(){
if(globalState.previousActiveElement&&globalState.previousActiveElement.focus){
globalState.previousActiveElement.focus();
globalState.previousActiveElement=null;
}else if(document.body){
document.body.focus();
}
};// Restore previous active (focused) element


var restoreActiveElement=function restoreActiveElement(){
return new Promise(function(resolve){
var x=window.scrollX;
var y=window.scrollY;
globalState.restoreFocusTimeout=setTimeout(function(){
focusPreviousActiveElement();
resolve();
},RESTORE_FOCUS_TIMEOUT);// issues/900

/* istanbul ignore if */

if(typeof x!=='undefined'&&typeof y!=='undefined'){
// IE doesn't have scrollX/scrollY support
window.scrollTo(x,y);
}
});
};

/**
   * If `timer` parameter is set, returns number of milliseconds of timer remained.
   * Otherwise, returns undefined.
   */

var getTimerLeft=function getTimerLeft(){
return globalState.timeout&&globalState.timeout.getTimerLeft();
};
/**
   * Stop timer. Returns number of milliseconds of timer remained.
   * If `timer` parameter isn't set, returns undefined.
   */

var stopTimer=function stopTimer(){
if(globalState.timeout){
stopTimerProgressBar();
return globalState.timeout.stop();
}
};
/**
   * Resume timer. Returns number of milliseconds of timer remained.
   * If `timer` parameter isn't set, returns undefined.
   */

var resumeTimer=function resumeTimer(){
if(globalState.timeout){
var remaining=globalState.timeout.start();
animateTimerProgressBar(remaining);
return remaining;
}
};
/**
   * Resume timer. Returns number of milliseconds of timer remained.
   * If `timer` parameter isn't set, returns undefined.
   */

var toggleTimer=function toggleTimer(){
var timer=globalState.timeout;
return timer&&(timer.running?stopTimer():resumeTimer());
};
/**
   * Increase timer. Returns number of milliseconds of an updated timer.
   * If `timer` parameter isn't set, returns undefined.
   */

var increaseTimer=function increaseTimer(n){
if(globalState.timeout){
var remaining=globalState.timeout.increase(n);
animateTimerProgressBar(remaining,true);
return remaining;
}
};
/**
   * Check if timer is running. Returns true if timer is running
   * or false if timer is paused or stopped.
   * If `timer` parameter isn't set, returns undefined
   */

var isTimerRunning=function isTimerRunning(){
return globalState.timeout&&globalState.timeout.isRunning();
};

var defaultParams={
title:'',
titleText:'',
text:'',
html:'',
footer:'',
icon:undefined,
iconHtml:undefined,
toast:false,
animation:true,
showClass:{
popup:'swal2-show',
backdrop:'swal2-backdrop-show',
icon:'swal2-icon-show'},

hideClass:{
popup:'swal2-hide',
backdrop:'swal2-backdrop-hide',
icon:'swal2-icon-hide'},

customClass:undefined,
target:'body',
backdrop:true,
heightAuto:true,
allowOutsideClick:true,
allowEscapeKey:true,
allowEnterKey:true,
stopKeydownPropagation:true,
keydownListenerCapture:false,
showConfirmButton:true,
showCancelButton:false,
preConfirm:undefined,
confirmButtonText:'OK',
confirmButtonAriaLabel:'',
confirmButtonColor:undefined,
cancelButtonText:'Cancel',
cancelButtonAriaLabel:'',
cancelButtonColor:undefined,
buttonsStyling:true,
reverseButtons:false,
focusConfirm:true,
focusCancel:false,
showCloseButton:false,
closeButtonHtml:'&times;',
closeButtonAriaLabel:'Close this dialog',
showLoaderOnConfirm:false,
imageUrl:undefined,
imageWidth:undefined,
imageHeight:undefined,
imageAlt:'',
timer:undefined,
timerProgressBar:false,
width:undefined,
padding:undefined,
background:undefined,
input:undefined,
inputPlaceholder:'',
inputValue:'',
inputOptions:{},
inputAutoTrim:true,
inputAttributes:{},
inputValidator:undefined,
validationMessage:undefined,
grow:false,
position:'center',
progressSteps:[],
currentProgressStep:undefined,
progressStepsDistance:undefined,
onBeforeOpen:undefined,
onOpen:undefined,
onRender:undefined,
onClose:undefined,
onAfterClose:undefined,
onDestroy:undefined,
scrollbarPadding:true};

var updatableParams=['allowEscapeKey','allowOutsideClick','buttonsStyling','cancelButtonAriaLabel','cancelButtonColor','cancelButtonText','closeButtonAriaLabel','closeButtonHtml','confirmButtonAriaLabel','confirmButtonColor','confirmButtonText','currentProgressStep','customClass','footer','hideClass','html','icon','imageAlt','imageHeight','imageUrl','imageWidth','onAfterClose','onClose','onDestroy','progressSteps','reverseButtons','showCancelButton','showCloseButton','showConfirmButton','text','title','titleText'];
var deprecatedParams={
animation:'showClass" and "hideClass'};

var toastIncompatibleParams=['allowOutsideClick','allowEnterKey','backdrop','focusConfirm','focusCancel','heightAuto','keydownListenerCapture'];
/**
   * Is valid parameter
   * @param {String} paramName
   */

var isValidParameter=function isValidParameter(paramName){
return Object.prototype.hasOwnProperty.call(defaultParams,paramName);
};
/**
   * Is valid parameter for Swal.update() method
   * @param {String} paramName
   */

var isUpdatableParameter=function isUpdatableParameter(paramName){
return updatableParams.indexOf(paramName)!==-1;
};
/**
   * Is deprecated parameter
   * @param {String} paramName
   */

var isDeprecatedParameter=function isDeprecatedParameter(paramName){
return deprecatedParams[paramName];
};

var checkIfParamIsValid=function checkIfParamIsValid(param){
if(!isValidParameter(param)){
warn("Unknown parameter \"".concat(param,"\""));
}
};

var checkIfToastParamIsValid=function checkIfToastParamIsValid(param){
if(toastIncompatibleParams.indexOf(param)!==-1){
warn("The parameter \"".concat(param,"\" is incompatible with toasts"));
}
};

var checkIfParamIsDeprecated=function checkIfParamIsDeprecated(param){
if(isDeprecatedParameter(param)){
warnAboutDepreation(param,isDeprecatedParameter(param));
}
};
/**
   * Show relevant warnings for given params
   *
   * @param params
   */


var showWarningsForParams=function showWarningsForParams(params){
for(var param in params){
checkIfParamIsValid(param);

if(params.toast){
checkIfToastParamIsValid(param);
}

checkIfParamIsDeprecated(param);
}
};



var staticMethods=/*#__PURE__*/Object.freeze({
isValidParameter:isValidParameter,
isUpdatableParameter:isUpdatableParameter,
isDeprecatedParameter:isDeprecatedParameter,
argsToParams:argsToParams,
isVisible:isVisible$1,
clickConfirm:clickConfirm,
clickCancel:clickCancel,
getContainer:getContainer,
getPopup:getPopup,
getTitle:getTitle,
getContent:getContent,
getHtmlContainer:getHtmlContainer,
getImage:getImage,
getIcon:getIcon,
getIcons:getIcons,
getCloseButton:getCloseButton,
getActions:getActions,
getConfirmButton:getConfirmButton,
getCancelButton:getCancelButton,
getHeader:getHeader,
getFooter:getFooter,
getTimerProgressBar:getTimerProgressBar,
getFocusableElements:getFocusableElements,
getValidationMessage:getValidationMessage,
isLoading:isLoading,
fire:fire,
mixin:mixin,
queue:queue,
getQueueStep:getQueueStep,
insertQueueStep:insertQueueStep,
deleteQueueStep:deleteQueueStep,
showLoading:showLoading,
enableLoading:showLoading,
getTimerLeft:getTimerLeft,
stopTimer:stopTimer,
resumeTimer:resumeTimer,
toggleTimer:toggleTimer,
increaseTimer:increaseTimer,
isTimerRunning:isTimerRunning});


/**
   * Enables buttons and hide loader.
   */

function hideLoading(){
// do nothing if popup is closed
var innerParams=privateProps.innerParams.get(this);

if(!innerParams){
return;
}

var domCache=privateProps.domCache.get(this);

if(!innerParams.showConfirmButton){
hide(domCache.confirmButton);

if(!innerParams.showCancelButton){
hide(domCache.actions);
}
}

removeClass([domCache.popup,domCache.actions],swalClasses.loading);
domCache.popup.removeAttribute('aria-busy');
domCache.popup.removeAttribute('data-loading');
domCache.confirmButton.disabled=false;
domCache.cancelButton.disabled=false;
}

function getInput$1(instance){
var innerParams=privateProps.innerParams.get(instance||this);
var domCache=privateProps.domCache.get(instance||this);

if(!domCache){
return null;
}

return getInput(domCache.content,innerParams.input);
}

var fixScrollbar=function fixScrollbar(){
// for queues, do not do this more than once
if(states.previousBodyPadding!==null){
return;
}// if the body has overflow


if(document.body.scrollHeight>window.innerHeight){
// add padding so the content doesn't shift after removal of scrollbar
states.previousBodyPadding=parseInt(window.getComputedStyle(document.body).getPropertyValue('padding-right'));
document.body.style.paddingRight="".concat(states.previousBodyPadding+measureScrollbar(),"px");
}
};
var undoScrollbar=function undoScrollbar(){
if(states.previousBodyPadding!==null){
document.body.style.paddingRight="".concat(states.previousBodyPadding,"px");
states.previousBodyPadding=null;
}
};

/* istanbul ignore file */

var iOSfix=function iOSfix(){
var iOS=/iPad|iPhone|iPod/.test(navigator.userAgent)&&!window.MSStream||navigator.platform==='MacIntel'&&navigator.maxTouchPoints>1;

if(iOS&&!hasClass(document.body,swalClasses.iosfix)){
var offset=document.body.scrollTop;
document.body.style.top="".concat(offset*-1,"px");
addClass(document.body,swalClasses.iosfix);
lockBodyScroll();
addBottomPaddingForTallPopups();// #1948
}
};

var addBottomPaddingForTallPopups=function addBottomPaddingForTallPopups(){
var safari=!navigator.userAgent.match(/(CriOS|FxiOS|EdgiOS|YaBrowser|UCBrowser)/i);

if(safari){
var bottomPanelHeight=44;

if(getPopup().scrollHeight>window.innerHeight-bottomPanelHeight){
getContainer().style.paddingBottom="".concat(bottomPanelHeight,"px");
}
}
};

var lockBodyScroll=function lockBodyScroll(){
// #1246
var container=getContainer();
var preventTouchMove;

container.ontouchstart=function(e){
preventTouchMove=shouldPreventTouchMove(e.target);
};

container.ontouchmove=function(e){
if(preventTouchMove){
e.preventDefault();
e.stopPropagation();
}
};
};

var shouldPreventTouchMove=function shouldPreventTouchMove(target){
var container=getContainer();

if(target===container){
return true;
}

if(!isScrollable(container)&&target.tagName!=='INPUT'&&// #1603
!(isScrollable(getContent())&&// #1944
getContent().contains(target))){
return true;
}

return false;
};

var undoIOSfix=function undoIOSfix(){
if(hasClass(document.body,swalClasses.iosfix)){
var offset=parseInt(document.body.style.top,10);
removeClass(document.body,swalClasses.iosfix);
document.body.style.top='';
document.body.scrollTop=offset*-1;
}
};

/* istanbul ignore file */

var isIE11=function isIE11(){
return !!window.MSInputMethodContext&&!!document.documentMode;
};// Fix IE11 centering sweetalert2/issues/933


var fixVerticalPositionIE=function fixVerticalPositionIE(){
var container=getContainer();
var popup=getPopup();
container.style.removeProperty('align-items');

if(popup.offsetTop<0){
container.style.alignItems='flex-start';
}
};

var IEfix=function IEfix(){
if(typeof window!=='undefined'&&isIE11()){
fixVerticalPositionIE();
window.addEventListener('resize',fixVerticalPositionIE);
}
};
var undoIEfix=function undoIEfix(){
if(typeof window!=='undefined'&&isIE11()){
window.removeEventListener('resize',fixVerticalPositionIE);
}
};

// Adding aria-hidden="true" to elements outside of the active modal dialog ensures that
// elements not within the active modal dialog will not be surfaced if a user opens a screen
// reader’s list of elements (headings, form controls, landmarks, etc.) in the document.

var setAriaHidden=function setAriaHidden(){
var bodyChildren=toArray(document.body.children);
bodyChildren.forEach(function(el){
if(el===getContainer()||contains(el,getContainer())){
return;
}

if(el.hasAttribute('aria-hidden')){
el.setAttribute('data-previous-aria-hidden',el.getAttribute('aria-hidden'));
}

el.setAttribute('aria-hidden','true');
});
};
var unsetAriaHidden=function unsetAriaHidden(){
var bodyChildren=toArray(document.body.children);
bodyChildren.forEach(function(el){
if(el.hasAttribute('data-previous-aria-hidden')){
el.setAttribute('aria-hidden',el.getAttribute('data-previous-aria-hidden'));
el.removeAttribute('data-previous-aria-hidden');
}else {
el.removeAttribute('aria-hidden');
}
});
};

/**
   * This module containts `WeakMap`s for each effectively-"private  property" that a `Swal` has.
   * For example, to set the private property "foo" of `this` to "bar", you can `privateProps.foo.set(this, 'bar')`
   * This is the approach that Babel will probably take to implement private methods/fields
   *   https://github.com/tc39/proposal-private-methods
   *   https://github.com/babel/babel/pull/7555
   * Once we have the changes from that PR in Babel, and our core class fits reasonable in *one module*
   *   then we can use that language feature.
   */
var privateMethods={
swalPromiseResolve:new WeakMap()};


/*
   * Instance method to close sweetAlert
   */

function removePopupAndResetState(instance,container,isToast$$1,onAfterClose){
if(isToast$$1){
triggerOnAfterCloseAndDispose(instance,onAfterClose);
}else {
restoreActiveElement().then(function(){
return triggerOnAfterCloseAndDispose(instance,onAfterClose);
});
globalState.keydownTarget.removeEventListener('keydown',globalState.keydownHandler,{
capture:globalState.keydownListenerCapture});

globalState.keydownHandlerAdded=false;
}

if(container.parentNode&&!document.body.getAttribute('data-swal2-queue-step')){
container.parentNode.removeChild(container);
}

if(isModal()){
undoScrollbar();
undoIOSfix();
undoIEfix();
unsetAriaHidden();
}

removeBodyClasses();
}

function removeBodyClasses(){
removeClass([document.documentElement,document.body],[swalClasses.shown,swalClasses['height-auto'],swalClasses['no-backdrop'],swalClasses['toast-shown'],swalClasses['toast-column']]);
}

function close(resolveValue){
var popup=getPopup();

if(!popup){
return;
}

var innerParams=privateProps.innerParams.get(this);

if(!innerParams||hasClass(popup,innerParams.hideClass.popup)){
return;
}

var swalPromiseResolve=privateMethods.swalPromiseResolve.get(this);
removeClass(popup,innerParams.showClass.popup);
addClass(popup,innerParams.hideClass.popup);
var backdrop=getContainer();
removeClass(backdrop,innerParams.showClass.backdrop);
addClass(backdrop,innerParams.hideClass.backdrop);
handlePopupAnimation(this,popup,innerParams);

if(typeof resolveValue!=='undefined'){
resolveValue.isDismissed=typeof resolveValue.dismiss!=='undefined';
resolveValue.isConfirmed=typeof resolveValue.dismiss==='undefined';
}else {
resolveValue={
isDismissed:true,
isConfirmed:false};

}// Resolve Swal promise


swalPromiseResolve(resolveValue||{});
}

var handlePopupAnimation=function handlePopupAnimation(instance,popup,innerParams){
var container=getContainer();// If animation is supported, animate

var animationIsSupported=animationEndEvent&&hasCssAnimation(popup);
var onClose=innerParams.onClose,
onAfterClose=innerParams.onAfterClose;

if(onClose!==null&&typeof onClose==='function'){
onClose(popup);
}

if(animationIsSupported){
animatePopup(instance,popup,container,onAfterClose);
}else {
// Otherwise, remove immediately
removePopupAndResetState(instance,container,isToast(),onAfterClose);
}
};

var animatePopup=function animatePopup(instance,popup,container,onAfterClose){
globalState.swalCloseEventFinishedCallback=removePopupAndResetState.bind(null,instance,container,isToast(),onAfterClose);
popup.addEventListener(animationEndEvent,function(e){
if(e.target===popup){
globalState.swalCloseEventFinishedCallback();
delete globalState.swalCloseEventFinishedCallback;
}
});
};

var triggerOnAfterCloseAndDispose=function triggerOnAfterCloseAndDispose(instance,onAfterClose){
setTimeout(function(){
if(typeof onAfterClose==='function'){
onAfterClose();
}

instance._destroy();
});
};

function setButtonsDisabled(instance,buttons,disabled){
var domCache=privateProps.domCache.get(instance);
buttons.forEach(function(button){
domCache[button].disabled=disabled;
});
}

function setInputDisabled(input,disabled){
if(!input){
return false;
}

if(input.type==='radio'){
var radiosContainer=input.parentNode.parentNode;
var radios=radiosContainer.querySelectorAll('input');

for(var i=0;i<radios.length;i++){
radios[i].disabled=disabled;
}
}else {
input.disabled=disabled;
}
}

function enableButtons(){
setButtonsDisabled(this,['confirmButton','cancelButton'],false);
}
function disableButtons(){
setButtonsDisabled(this,['confirmButton','cancelButton'],true);
}
function enableInput(){
return setInputDisabled(this.getInput(),false);
}
function disableInput(){
return setInputDisabled(this.getInput(),true);
}

function showValidationMessage(error){
var domCache=privateProps.domCache.get(this);
setInnerHtml(domCache.validationMessage,error);
var popupComputedStyle=window.getComputedStyle(domCache.popup);
domCache.validationMessage.style.marginLeft="-".concat(popupComputedStyle.getPropertyValue('padding-left'));
domCache.validationMessage.style.marginRight="-".concat(popupComputedStyle.getPropertyValue('padding-right'));
show(domCache.validationMessage);
var input=this.getInput();

if(input){
input.setAttribute('aria-invalid',true);
input.setAttribute('aria-describedBy',swalClasses['validation-message']);
focusInput(input);
addClass(input,swalClasses.inputerror);
}
}// Hide block with validation message

function resetValidationMessage$1(){
var domCache=privateProps.domCache.get(this);

if(domCache.validationMessage){
hide(domCache.validationMessage);
}

var input=this.getInput();

if(input){
input.removeAttribute('aria-invalid');
input.removeAttribute('aria-describedBy');
removeClass(input,swalClasses.inputerror);
}
}

function getProgressSteps$1(){
var domCache=privateProps.domCache.get(this);
return domCache.progressSteps;
}

var Timer=/*#__PURE__*/function(){
function Timer(callback,delay){
_classCallCheck(this,Timer);

this.callback=callback;
this.remaining=delay;
this.running=false;
this.start();
}

_createClass(Timer,[{
key:"start",
value:function start(){
if(!this.running){
this.running=true;
this.started=new Date();
this.id=setTimeout(this.callback,this.remaining);
}

return this.remaining;
}},
{
key:"stop",
value:function stop(){
if(this.running){
this.running=false;
clearTimeout(this.id);
this.remaining-=new Date()-this.started;
}

return this.remaining;
}},
{
key:"increase",
value:function increase(n){
var running=this.running;

if(running){
this.stop();
}

this.remaining+=n;

if(running){
this.start();
}

return this.remaining;
}},
{
key:"getTimerLeft",
value:function getTimerLeft(){
if(this.running){
this.stop();
this.start();
}

return this.remaining;
}},
{
key:"isRunning",
value:function isRunning(){
return this.running;
}}]);


return Timer;
}();

var defaultInputValidators={
email:function email(string,validationMessage){
return /^[a-zA-Z0-9.+_-]+@[a-zA-Z0-9.-]+\.[a-zA-Z0-9-]{2,24}$/.test(string)?Promise.resolve():Promise.resolve(validationMessage||'Invalid email address');
},
url:function url(string,validationMessage){
// taken from https://stackoverflow.com/a/3809435 with a small change from #1306 and #2013
return /^https?:\/\/(www\.)?[-a-zA-Z0-9@:%._+~#=]{1,256}\.[a-z]{2,63}\b([-a-zA-Z0-9@:%_+.~#?&/=]*)$/.test(string)?Promise.resolve():Promise.resolve(validationMessage||'Invalid URL');
}};


function setDefaultInputValidators(params){
// Use default `inputValidator` for supported input types if not provided
if(!params.inputValidator){
Object.keys(defaultInputValidators).forEach(function(key){
if(params.input===key){
params.inputValidator=defaultInputValidators[key];
}
});
}
}

function validateCustomTargetElement(params){
// Determine if the custom target element is valid
if(!params.target||typeof params.target==='string'&&!document.querySelector(params.target)||typeof params.target!=='string'&&!params.target.appendChild){
warn('Target parameter is not valid, defaulting to "body"');
params.target='body';
}
}
/**
   * Set type, text and actions on popup
   *
   * @param params
   * @returns {boolean}
   */


function setParameters(params){
setDefaultInputValidators(params);// showLoaderOnConfirm && preConfirm

if(params.showLoaderOnConfirm&&!params.preConfirm){
warn('showLoaderOnConfirm is set to true, but preConfirm is not defined.\n'+'showLoaderOnConfirm should be used together with preConfirm, see usage example:\n'+'https://sweetalert2.github.io/#ajax-request');
}// params.animation will be actually used in renderPopup.js
// but in case when params.animation is a function, we need to call that function
// before popup (re)initialization, so it'll be possible to check Swal.isVisible()
// inside the params.animation function


params.animation=callIfFunction(params.animation);
validateCustomTargetElement(params);// Replace newlines with <br> in title

if(typeof params.title==='string'){
params.title=params.title.split('\n').join('<br />');
}

init(params);
}

/**
   * Open popup, add necessary classes and styles, fix scrollbar
   *
   * @param {Array} params
   */

var openPopup=function openPopup(params){
var container=getContainer();
var popup=getPopup();

if(typeof params.onBeforeOpen==='function'){
params.onBeforeOpen(popup);
}

var bodyStyles=window.getComputedStyle(document.body);
var initialBodyOverflow=bodyStyles.overflowY;
addClasses$1(container,popup,params);// scrolling is 'hidden' until animation is done, after that 'auto'

setScrollingVisibility(container,popup);

if(isModal()){
fixScrollContainer(container,params.scrollbarPadding,initialBodyOverflow);
setAriaHidden();
}

if(!isToast()&&!globalState.previousActiveElement){
globalState.previousActiveElement=document.activeElement;
}

if(typeof params.onOpen==='function'){
setTimeout(function(){
return params.onOpen(popup);
});
}

removeClass(container,swalClasses['no-transition']);
};

function swalOpenAnimationFinished(event){
var popup=getPopup();

if(event.target!==popup){
return;
}

var container=getContainer();
popup.removeEventListener(animationEndEvent,swalOpenAnimationFinished);
container.style.overflowY='auto';
}

var setScrollingVisibility=function setScrollingVisibility(container,popup){
if(animationEndEvent&&hasCssAnimation(popup)){
container.style.overflowY='hidden';
popup.addEventListener(animationEndEvent,swalOpenAnimationFinished);
}else {
container.style.overflowY='auto';
}
};

var fixScrollContainer=function fixScrollContainer(container,scrollbarPadding,initialBodyOverflow){
iOSfix();
IEfix();

if(scrollbarPadding&&initialBodyOverflow!=='hidden'){
fixScrollbar();
}// sweetalert2/issues/1247


setTimeout(function(){
container.scrollTop=0;
});
};

var addClasses$1=function addClasses(container,popup,params){
addClass(container,params.showClass.backdrop);
show(popup);// Animate popup right after showing it

addClass(popup,params.showClass.popup);
addClass([document.documentElement,document.body],swalClasses.shown);

if(params.heightAuto&&params.backdrop&&!params.toast){
addClass([document.documentElement,document.body],swalClasses['height-auto']);
}
};

var handleInputOptionsAndValue=function handleInputOptionsAndValue(instance,params){
if(params.input==='select'||params.input==='radio'){
handleInputOptions(instance,params);
}else if(['text','email','number','tel','textarea'].indexOf(params.input)!==-1&&(hasToPromiseFn(params.inputValue)||isPromise(params.inputValue))){
handleInputValue(instance,params);
}
};
var getInputValue=function getInputValue(instance,innerParams){
var input=instance.getInput();

if(!input){
return null;
}

switch(innerParams.input){
case'checkbox':
return getCheckboxValue(input);

case'radio':
return getRadioValue(input);

case'file':
return getFileValue(input);

default:
return innerParams.inputAutoTrim?input.value.trim():input.value;}

};

var getCheckboxValue=function getCheckboxValue(input){
return input.checked?1:0;
};

var getRadioValue=function getRadioValue(input){
return input.checked?input.value:null;
};

var getFileValue=function getFileValue(input){
return input.files.length?input.getAttribute('multiple')!==null?input.files:input.files[0]:null;
};

var handleInputOptions=function handleInputOptions(instance,params){
var content=getContent();

var processInputOptions=function processInputOptions(inputOptions){
return populateInputOptions[params.input](content,formatInputOptions(inputOptions),params);
};

if(hasToPromiseFn(params.inputOptions)||isPromise(params.inputOptions)){
showLoading();
asPromise(params.inputOptions).then(function(inputOptions){
instance.hideLoading();
processInputOptions(inputOptions);
});
}else if(_typeof(params.inputOptions)==='object'){
processInputOptions(params.inputOptions);
}else {
error("Unexpected type of inputOptions! Expected object, Map or Promise, got ".concat(_typeof(params.inputOptions)));
}
};

var handleInputValue=function handleInputValue(instance,params){
var input=instance.getInput();
hide(input);
asPromise(params.inputValue).then(function(inputValue){
input.value=params.input==='number'?parseFloat(inputValue)||0:"".concat(inputValue);
show(input);
input.focus();
instance.hideLoading();
})["catch"](function(err){
error("Error in inputValue promise: ".concat(err));
input.value='';
show(input);
input.focus();
instance.hideLoading();
});
};

var populateInputOptions={
select:function select(content,inputOptions,params){
var select=getChildByClass(content,swalClasses.select);

var renderOption=function renderOption(parent,optionLabel,optionValue){
var option=document.createElement('option');
option.value=optionValue;
setInnerHtml(option,optionLabel);

if(params.inputValue.toString()===optionValue.toString()){
option.selected=true;
}

parent.appendChild(option);
};

inputOptions.forEach(function(inputOption){
var optionValue=inputOption[0];
var optionLabel=inputOption[1];// <optgroup> spec:
// https://www.w3.org/TR/html401/interact/forms.html#h-17.6
// "...all OPTGROUP elements must be specified directly within a SELECT element (i.e., groups may not be nested)..."
// check whether this is a <optgroup>

if(Array.isArray(optionLabel)){
// if it is an array, then it is an <optgroup>
var optgroup=document.createElement('optgroup');
optgroup.label=optionValue;
optgroup.disabled=false;// not configurable for now

select.appendChild(optgroup);
optionLabel.forEach(function(o){
return renderOption(optgroup,o[1],o[0]);
});
}else {
// case of <option>
renderOption(select,optionLabel,optionValue);
}
});
select.focus();
},
radio:function radio(content,inputOptions,params){
var radio=getChildByClass(content,swalClasses.radio);
inputOptions.forEach(function(inputOption){
var radioValue=inputOption[0];
var radioLabel=inputOption[1];
var radioInput=document.createElement('input');
var radioLabelElement=document.createElement('label');
radioInput.type='radio';
radioInput.name=swalClasses.radio;
radioInput.value=radioValue;

if(params.inputValue.toString()===radioValue.toString()){
radioInput.checked=true;
}

var label=document.createElement('span');
setInnerHtml(label,radioLabel);
label.className=swalClasses.label;
radioLabelElement.appendChild(radioInput);
radioLabelElement.appendChild(label);
radio.appendChild(radioLabelElement);
});
var radios=radio.querySelectorAll('input');

if(radios.length){
radios[0].focus();
}
}};

/**
   * Converts `inputOptions` into an array of `[value, label]`s
   * @param inputOptions
   */

var formatInputOptions=function formatInputOptions(inputOptions){
var result=[];

if(typeof Map!=='undefined'&&inputOptions instanceof Map){
inputOptions.forEach(function(value,key){
var valueFormatted=value;

if(_typeof(valueFormatted)==='object'){
// case of <optgroup>
valueFormatted=formatInputOptions(valueFormatted);
}

result.push([key,valueFormatted]);
});
}else {
Object.keys(inputOptions).forEach(function(key){
var valueFormatted=inputOptions[key];

if(_typeof(valueFormatted)==='object'){
// case of <optgroup>
valueFormatted=formatInputOptions(valueFormatted);
}

result.push([key,valueFormatted]);
});
}

return result;
};

var handleConfirmButtonClick=function handleConfirmButtonClick(instance,innerParams){
instance.disableButtons();

if(innerParams.input){
handleConfirmWithInput(instance,innerParams);
}else {
confirm(instance,innerParams,true);
}
};
var handleCancelButtonClick=function handleCancelButtonClick(instance,dismissWith){
instance.disableButtons();
dismissWith(DismissReason.cancel);
};

var handleConfirmWithInput=function handleConfirmWithInput(instance,innerParams){
var inputValue=getInputValue(instance,innerParams);

if(innerParams.inputValidator){
instance.disableInput();
var validationPromise=Promise.resolve().then(function(){
return asPromise(innerParams.inputValidator(inputValue,innerParams.validationMessage));
});
validationPromise.then(function(validationMessage){
instance.enableButtons();
instance.enableInput();

if(validationMessage){
instance.showValidationMessage(validationMessage);
}else {
confirm(instance,innerParams,inputValue);
}
});
}else if(!instance.getInput().checkValidity()){
instance.enableButtons();
instance.showValidationMessage(innerParams.validationMessage);
}else {
confirm(instance,innerParams,inputValue);
}
};

var succeedWith=function succeedWith(instance,value){
instance.closePopup({
value:value});

};

var confirm=function confirm(instance,innerParams,value){
if(innerParams.showLoaderOnConfirm){
showLoading();// TODO: make showLoading an *instance* method
}

if(innerParams.preConfirm){
instance.resetValidationMessage();
var preConfirmPromise=Promise.resolve().then(function(){
return asPromise(innerParams.preConfirm(value,innerParams.validationMessage));
});
preConfirmPromise.then(function(preConfirmValue){
if(isVisible(getValidationMessage())||preConfirmValue===false){
instance.hideLoading();
}else {
succeedWith(instance,typeof preConfirmValue==='undefined'?value:preConfirmValue);
}
});
}else {
succeedWith(instance,value);
}
};

var addKeydownHandler=function addKeydownHandler(instance,globalState,innerParams,dismissWith){
if(globalState.keydownTarget&&globalState.keydownHandlerAdded){
globalState.keydownTarget.removeEventListener('keydown',globalState.keydownHandler,{
capture:globalState.keydownListenerCapture});

globalState.keydownHandlerAdded=false;
}

if(!innerParams.toast){
globalState.keydownHandler=function(e){
return keydownHandler(instance,e,dismissWith);
};

globalState.keydownTarget=innerParams.keydownListenerCapture?window:getPopup();
globalState.keydownListenerCapture=innerParams.keydownListenerCapture;
globalState.keydownTarget.addEventListener('keydown',globalState.keydownHandler,{
capture:globalState.keydownListenerCapture});

globalState.keydownHandlerAdded=true;
}
};// Focus handling

var setFocus=function setFocus(innerParams,index,increment){
var focusableElements=getFocusableElements();// search for visible elements and select the next possible match

for(var i=0;i<focusableElements.length;i++){
index=index+increment;// rollover to first item

if(index===focusableElements.length){
index=0;// go to last item
}else if(index===-1){
index=focusableElements.length-1;
}

return focusableElements[index].focus();
}// no visible focusable elements, focus the popup


getPopup().focus();
};
var arrowKeys=['ArrowLeft','ArrowRight','ArrowUp','ArrowDown','Left','Right','Up','Down'// IE11
];
var escKeys=['Escape','Esc'// IE11
];

var keydownHandler=function keydownHandler(instance,e,dismissWith){
var innerParams=privateProps.innerParams.get(instance);

if(innerParams.stopKeydownPropagation){
e.stopPropagation();
}// ENTER


if(e.key==='Enter'){
handleEnter(instance,e,innerParams);// TAB
}else if(e.key==='Tab'){
handleTab(e,innerParams);// ARROWS - switch focus between buttons
}else if(arrowKeys.indexOf(e.key)!==-1){
handleArrows();// ESC
}else if(escKeys.indexOf(e.key)!==-1){
handleEsc(e,innerParams,dismissWith);
}
};

var handleEnter=function handleEnter(instance,e,innerParams){
// #720 #721
if(e.isComposing){
return;
}

if(e.target&&instance.getInput()&&e.target.outerHTML===instance.getInput().outerHTML){
if(['textarea','file'].indexOf(innerParams.input)!==-1){
return;// do not submit
}

clickConfirm();
e.preventDefault();
}
};

var handleTab=function handleTab(e,innerParams){
var targetElement=e.target;
var focusableElements=getFocusableElements();
var btnIndex=-1;

for(var i=0;i<focusableElements.length;i++){
if(targetElement===focusableElements[i]){
btnIndex=i;
break;
}
}

if(!e.shiftKey){
// Cycle to the next button
setFocus(innerParams,btnIndex,1);
}else {
// Cycle to the prev button
setFocus(innerParams,btnIndex,-1);
}

e.stopPropagation();
e.preventDefault();
};

var handleArrows=function handleArrows(){
var confirmButton=getConfirmButton();
var cancelButton=getCancelButton();// focus Cancel button if Confirm button is currently focused

if(document.activeElement===confirmButton&&isVisible(cancelButton)){
cancelButton.focus();// and vice versa
}else if(document.activeElement===cancelButton&&isVisible(confirmButton)){
confirmButton.focus();
}
};

var handleEsc=function handleEsc(e,innerParams,dismissWith){
if(callIfFunction(innerParams.allowEscapeKey)){
e.preventDefault();
dismissWith(DismissReason.esc);
}
};

var handlePopupClick=function handlePopupClick(instance,domCache,dismissWith){
var innerParams=privateProps.innerParams.get(instance);

if(innerParams.toast){
handleToastClick(instance,domCache,dismissWith);
}else {
// Ignore click events that had mousedown on the popup but mouseup on the container
// This can happen when the user drags a slider
handleModalMousedown(domCache);// Ignore click events that had mousedown on the container but mouseup on the popup

handleContainerMousedown(domCache);
handleModalClick(instance,domCache,dismissWith);
}
};

var handleToastClick=function handleToastClick(instance,domCache,dismissWith){
// Closing toast by internal click
domCache.popup.onclick=function(){
var innerParams=privateProps.innerParams.get(instance);

if(innerParams.showConfirmButton||innerParams.showCancelButton||innerParams.showCloseButton||innerParams.input){
return;
}

dismissWith(DismissReason.close);
};
};

var ignoreOutsideClick=false;

var handleModalMousedown=function handleModalMousedown(domCache){
domCache.popup.onmousedown=function(){
domCache.container.onmouseup=function(e){
domCache.container.onmouseup=undefined;// We only check if the mouseup target is the container because usually it doesn't
// have any other direct children aside of the popup

if(e.target===domCache.container){
ignoreOutsideClick=true;
}
};
};
};

var handleContainerMousedown=function handleContainerMousedown(domCache){
domCache.container.onmousedown=function(){
domCache.popup.onmouseup=function(e){
domCache.popup.onmouseup=undefined;// We also need to check if the mouseup target is a child of the popup

if(e.target===domCache.popup||domCache.popup.contains(e.target)){
ignoreOutsideClick=true;
}
};
};
};

var handleModalClick=function handleModalClick(instance,domCache,dismissWith){
domCache.container.onclick=function(e){
var innerParams=privateProps.innerParams.get(instance);

if(ignoreOutsideClick){
ignoreOutsideClick=false;
return;
}

if(e.target===domCache.container&&callIfFunction(innerParams.allowOutsideClick)){
dismissWith(DismissReason.backdrop);
}
};
};

function _main(userParams){
showWarningsForParams(userParams);

if(globalState.currentInstance){
globalState.currentInstance._destroy();
}

globalState.currentInstance=this;
var innerParams=prepareParams(userParams);
setParameters(innerParams);
Object.freeze(innerParams);// clear the previous timer

if(globalState.timeout){
globalState.timeout.stop();
delete globalState.timeout;
}// clear the restore focus timeout


clearTimeout(globalState.restoreFocusTimeout);
var domCache=populateDomCache(this);
render(this,innerParams);
privateProps.innerParams.set(this,innerParams);
return swalPromise(this,domCache,innerParams);
}

var prepareParams=function prepareParams(userParams){
var showClass=_extends({},defaultParams.showClass,userParams.showClass);

var hideClass=_extends({},defaultParams.hideClass,userParams.hideClass);

var params=_extends({},defaultParams,userParams);

params.showClass=showClass;
params.hideClass=hideClass;// @deprecated

if(userParams.animation===false){
params.showClass={
popup:'swal2-noanimation',
backdrop:'swal2-noanimation'};

params.hideClass={};
}

return params;
};

var swalPromise=function swalPromise(instance,domCache,innerParams){
return new Promise(function(resolve){
// functions to handle all closings/dismissals
var dismissWith=function dismissWith(dismiss){
instance.closePopup({
dismiss:dismiss});

};

privateMethods.swalPromiseResolve.set(instance,resolve);

domCache.confirmButton.onclick=function(){
return handleConfirmButtonClick(instance,innerParams);
};

domCache.cancelButton.onclick=function(){
return handleCancelButtonClick(instance,dismissWith);
};

domCache.closeButton.onclick=function(){
return dismissWith(DismissReason.close);
};

handlePopupClick(instance,domCache,dismissWith);
addKeydownHandler(instance,globalState,innerParams,dismissWith);

if(innerParams.toast&&(innerParams.input||innerParams.footer||innerParams.showCloseButton)){
addClass(document.body,swalClasses['toast-column']);
}else {
removeClass(document.body,swalClasses['toast-column']);
}

handleInputOptionsAndValue(instance,innerParams);
openPopup(innerParams);
setupTimer(globalState,innerParams,dismissWith);
initFocus(domCache,innerParams);// Scroll container to top on open (#1247, #1946)

setTimeout(function(){
domCache.container.scrollTop=0;
});
});
};

var populateDomCache=function populateDomCache(instance){
var domCache={
popup:getPopup(),
container:getContainer(),
content:getContent(),
actions:getActions(),
confirmButton:getConfirmButton(),
cancelButton:getCancelButton(),
closeButton:getCloseButton(),
validationMessage:getValidationMessage(),
progressSteps:getProgressSteps()};

privateProps.domCache.set(instance,domCache);
return domCache;
};

var setupTimer=function setupTimer(globalState$$1,innerParams,dismissWith){
var timerProgressBar=getTimerProgressBar();
hide(timerProgressBar);

if(innerParams.timer){
globalState$$1.timeout=new Timer(function(){
dismissWith('timer');
delete globalState$$1.timeout;
},innerParams.timer);

if(innerParams.timerProgressBar){
show(timerProgressBar);
setTimeout(function(){
if(globalState$$1.timeout.running){
// timer can be already stopped at this point
animateTimerProgressBar(innerParams.timer);
}
});
}
}
};

var initFocus=function initFocus(domCache,innerParams){
if(innerParams.toast){
return;
}

if(!callIfFunction(innerParams.allowEnterKey)){
return blurActiveElement();
}

if(innerParams.focusCancel&&isVisible(domCache.cancelButton)){
return domCache.cancelButton.focus();
}

if(innerParams.focusConfirm&&isVisible(domCache.confirmButton)){
return domCache.confirmButton.focus();
}

setFocus(innerParams,-1,1);
};

var blurActiveElement=function blurActiveElement(){
if(document.activeElement&&typeof document.activeElement.blur==='function'){
document.activeElement.blur();
}
};

/**
   * Updates popup parameters.
   */

function update(params){
var popup=getPopup();
var innerParams=privateProps.innerParams.get(this);

if(!popup||hasClass(popup,innerParams.hideClass.popup)){
return warn("You're trying to update the closed or closing popup, that won't work. Use the update() method in preConfirm parameter or show a new popup.");
}

var validUpdatableParams={};// assign valid params from `params` to `defaults`

Object.keys(params).forEach(function(param){
if(Swal.isUpdatableParameter(param)){
validUpdatableParams[param]=params[param];
}else {
warn("Invalid parameter to update: \"".concat(param,"\". Updatable params are listed here: https://github.com/sweetalert2/sweetalert2/blob/master/src/utils/params.js"));
}
});

var updatedParams=_extends({},innerParams,validUpdatableParams);

render(this,updatedParams);
privateProps.innerParams.set(this,updatedParams);
Object.defineProperties(this,{
params:{
value:_extends({},this.params,params),
writable:false,
enumerable:true}});


}

function _destroy(){
var domCache=privateProps.domCache.get(this);
var innerParams=privateProps.innerParams.get(this);

if(!innerParams){
return;// This instance has already been destroyed
}// Check if there is another Swal closing


if(domCache.popup&&globalState.swalCloseEventFinishedCallback){
globalState.swalCloseEventFinishedCallback();
delete globalState.swalCloseEventFinishedCallback;
}// Check if there is a swal disposal defer timer


if(globalState.deferDisposalTimer){
clearTimeout(globalState.deferDisposalTimer);
delete globalState.deferDisposalTimer;
}

if(typeof innerParams.onDestroy==='function'){
innerParams.onDestroy();
}

disposeSwal(this);
}

var disposeSwal=function disposeSwal(instance){
// Unset this.params so GC will dispose it (#1569)
delete instance.params;// Unset globalState props so GC will dispose globalState (#1569)

delete globalState.keydownHandler;
delete globalState.keydownTarget;// Unset WeakMaps so GC will be able to dispose them (#1569)

unsetWeakMaps(privateProps);
unsetWeakMaps(privateMethods);
};

var unsetWeakMaps=function unsetWeakMaps(obj){
for(var i in obj){
obj[i]=new WeakMap();
}
};



var instanceMethods=/*#__PURE__*/Object.freeze({
hideLoading:hideLoading,
disableLoading:hideLoading,
getInput:getInput$1,
close:close,
closePopup:close,
closeModal:close,
closeToast:close,
enableButtons:enableButtons,
disableButtons:disableButtons,
enableInput:enableInput,
disableInput:disableInput,
showValidationMessage:showValidationMessage,
resetValidationMessage:resetValidationMessage$1,
getProgressSteps:getProgressSteps$1,
_main:_main,
update:update,
_destroy:_destroy});


var currentInstance;

var SweetAlert=/*#__PURE__*/function(){
function SweetAlert(){
_classCallCheck(this,SweetAlert);

// Prevent run in Node env
if(typeof window==='undefined'){
return;
}// Check for the existence of Promise


if(typeof Promise==='undefined'){
error('This package requires a Promise library, please include a shim to enable it in this browser (See: https://github.com/sweetalert2/sweetalert2/wiki/Migration-from-SweetAlert-to-SweetAlert2#1-ie-support)');
}

currentInstance=this;

for(var _len=arguments.length,args=new Array(_len),_key=0;_key<_len;_key++){
args[_key]=arguments[_key];
}

var outerParams=Object.freeze(this.constructor.argsToParams(args));
Object.defineProperties(this,{
params:{
value:outerParams,
writable:false,
enumerable:true,
configurable:true}});



var promise=this._main(this.params);

privateProps.promise.set(this,promise);
}// `catch` cannot be the name of a module export, so we define our thenable methods here instead


_createClass(SweetAlert,[{
key:"then",
value:function then(onFulfilled){
var promise=privateProps.promise.get(this);
return promise.then(onFulfilled);
}},
{
key:"finally",
value:function _finally(onFinally){
var promise=privateProps.promise.get(this);
return promise["finally"](onFinally);
}}]);


return SweetAlert;
}();// Assign instance methods from src/instanceMethods/*.js to prototype


_extends(SweetAlert.prototype,instanceMethods);// Assign static methods from src/staticMethods/*.js to constructor


_extends(SweetAlert,staticMethods);// Proxy to instance methods to constructor, for now, for backwards compatibility


Object.keys(instanceMethods).forEach(function(key){
SweetAlert[key]=function(){
if(currentInstance){
var _currentInstance;

return (_currentInstance=currentInstance)[key].apply(_currentInstance,arguments);
}
};
});
SweetAlert.DismissReason=DismissReason;
SweetAlert.version='9.17.2';

var Swal=SweetAlert;
Swal["default"]=Swal;

return Swal;

});
if(typeof this!=='undefined'&&this.Sweetalert2){this.swal=this.sweetAlert=this.Swal=this.SweetAlert=this.Sweetalert2;}

"undefined"!=typeof document&&function(e,t){var n=e.createElement("style");if(e.getElementsByTagName("head")[0].appendChild(n),n.styleSheet)n.styleSheet.disabled||(n.styleSheet.cssText=t);else try{n.innerHTML=t;}catch(e){n.innerText=t;}}(document,".swal2-popup.swal2-toast{flex-direction:row;align-items:center;width:auto;padding:.625em;overflow-y:hidden;background:#fff;box-shadow:0 0 .625em #d9d9d9}.swal2-popup.swal2-toast .swal2-header{flex-direction:row;padding:0}.swal2-popup.swal2-toast .swal2-title{flex-grow:1;justify-content:flex-start;margin:0 .6em;font-size:1em}.swal2-popup.swal2-toast .swal2-footer{margin:.5em 0 0;padding:.5em 0 0;font-size:.8em}.swal2-popup.swal2-toast .swal2-close{position:static;width:.8em;height:.8em;line-height:.8}.swal2-popup.swal2-toast .swal2-content{justify-content:flex-start;padding:0;font-size:1em}.swal2-popup.swal2-toast .swal2-icon{width:2em;min-width:2em;height:2em;margin:0}.swal2-popup.swal2-toast .swal2-icon .swal2-icon-content{display:flex;align-items:center;font-size:1.8em;font-weight:700}@media all and (-ms-high-contrast:none),(-ms-high-contrast:active){.swal2-popup.swal2-toast .swal2-icon .swal2-icon-content{font-size:.25em}}.swal2-popup.swal2-toast .swal2-icon.swal2-success .swal2-success-ring{width:2em;height:2em}.swal2-popup.swal2-toast .swal2-icon.swal2-error [class^=swal2-x-mark-line]{top:.875em;width:1.375em}.swal2-popup.swal2-toast .swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=left]{left:.3125em}.swal2-popup.swal2-toast .swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=right]{right:.3125em}.swal2-popup.swal2-toast .swal2-actions{flex-basis:auto!important;width:auto;height:auto;margin:0 .3125em}.swal2-popup.swal2-toast .swal2-styled{margin:0 .3125em;padding:.3125em .625em;font-size:1em}.swal2-popup.swal2-toast .swal2-styled:focus{box-shadow:0 0 0 1px #fff,0 0 0 3px rgba(50,100,150,.4)}.swal2-popup.swal2-toast .swal2-success{border-color:#a5dc86}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-circular-line]{position:absolute;width:1.6em;height:3em;transform:rotate(45deg);border-radius:50%}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-circular-line][class$=left]{top:-.8em;left:-.5em;transform:rotate(-45deg);transform-origin:2em 2em;border-radius:4em 0 0 4em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-circular-line][class$=right]{top:-.25em;left:.9375em;transform-origin:0 1.5em;border-radius:0 4em 4em 0}.swal2-popup.swal2-toast .swal2-success .swal2-success-ring{width:2em;height:2em}.swal2-popup.swal2-toast .swal2-success .swal2-success-fix{top:0;left:.4375em;width:.4375em;height:2.6875em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-line]{height:.3125em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-line][class$=tip]{top:1.125em;left:.1875em;width:.75em}.swal2-popup.swal2-toast .swal2-success [class^=swal2-success-line][class$=long]{top:.9375em;right:.1875em;width:1.375em}.swal2-popup.swal2-toast .swal2-success.swal2-icon-show .swal2-success-line-tip{-webkit-animation:swal2-toast-animate-success-line-tip .75s;animation:swal2-toast-animate-success-line-tip .75s}.swal2-popup.swal2-toast .swal2-success.swal2-icon-show .swal2-success-line-long{-webkit-animation:swal2-toast-animate-success-line-long .75s;animation:swal2-toast-animate-success-line-long .75s}.swal2-popup.swal2-toast.swal2-show{-webkit-animation:swal2-toast-show .5s;animation:swal2-toast-show .5s}.swal2-popup.swal2-toast.swal2-hide{-webkit-animation:swal2-toast-hide .1s forwards;animation:swal2-toast-hide .1s forwards}.swal2-container{display:flex;position:fixed;z-index:1060;top:0;right:0;bottom:0;left:0;flex-direction:row;align-items:center;justify-content:center;padding:.625em;overflow-x:hidden;transition:background-color .1s;-webkit-overflow-scrolling:touch}.swal2-container.swal2-backdrop-show,.swal2-container.swal2-noanimation{background:rgba(0,0,0,.4)}.swal2-container.swal2-backdrop-hide{background:0 0!important}.swal2-container.swal2-top{align-items:flex-start}.swal2-container.swal2-top-left,.swal2-container.swal2-top-start{align-items:flex-start;justify-content:flex-start}.swal2-container.swal2-top-end,.swal2-container.swal2-top-right{align-items:flex-start;justify-content:flex-end}.swal2-container.swal2-center{align-items:center}.swal2-container.swal2-center-left,.swal2-container.swal2-center-start{align-items:center;justify-content:flex-start}.swal2-container.swal2-center-end,.swal2-container.swal2-center-right{align-items:center;justify-content:flex-end}.swal2-container.swal2-bottom{align-items:flex-end}.swal2-container.swal2-bottom-left,.swal2-container.swal2-bottom-start{align-items:flex-end;justify-content:flex-start}.swal2-container.swal2-bottom-end,.swal2-container.swal2-bottom-right{align-items:flex-end;justify-content:flex-end}.swal2-container.swal2-bottom-end>:first-child,.swal2-container.swal2-bottom-left>:first-child,.swal2-container.swal2-bottom-right>:first-child,.swal2-container.swal2-bottom-start>:first-child,.swal2-container.swal2-bottom>:first-child{margin-top:auto}.swal2-container.swal2-grow-fullscreen>.swal2-modal{display:flex!important;flex:1;align-self:stretch;justify-content:center}.swal2-container.swal2-grow-row>.swal2-modal{display:flex!important;flex:1;align-content:center;justify-content:center}.swal2-container.swal2-grow-column{flex:1;flex-direction:column}.swal2-container.swal2-grow-column.swal2-bottom,.swal2-container.swal2-grow-column.swal2-center,.swal2-container.swal2-grow-column.swal2-top{align-items:center}.swal2-container.swal2-grow-column.swal2-bottom-left,.swal2-container.swal2-grow-column.swal2-bottom-start,.swal2-container.swal2-grow-column.swal2-center-left,.swal2-container.swal2-grow-column.swal2-center-start,.swal2-container.swal2-grow-column.swal2-top-left,.swal2-container.swal2-grow-column.swal2-top-start{align-items:flex-start}.swal2-container.swal2-grow-column.swal2-bottom-end,.swal2-container.swal2-grow-column.swal2-bottom-right,.swal2-container.swal2-grow-column.swal2-center-end,.swal2-container.swal2-grow-column.swal2-center-right,.swal2-container.swal2-grow-column.swal2-top-end,.swal2-container.swal2-grow-column.swal2-top-right{align-items:flex-end}.swal2-container.swal2-grow-column>.swal2-modal{display:flex!important;flex:1;align-content:center;justify-content:center}.swal2-container.swal2-no-transition{transition:none!important}.swal2-container:not(.swal2-top):not(.swal2-top-start):not(.swal2-top-end):not(.swal2-top-left):not(.swal2-top-right):not(.swal2-center-start):not(.swal2-center-end):not(.swal2-center-left):not(.swal2-center-right):not(.swal2-bottom):not(.swal2-bottom-start):not(.swal2-bottom-end):not(.swal2-bottom-left):not(.swal2-bottom-right):not(.swal2-grow-fullscreen)>.swal2-modal{margin:auto}@media all and (-ms-high-contrast:none),(-ms-high-contrast:active){.swal2-container .swal2-modal{margin:0!important}}.swal2-popup{display:none;position:relative;box-sizing:border-box;flex-direction:column;justify-content:center;width:32em;max-width:100%;padding:1.25em;border:none;border-radius:.3125em;background:#fff;font-family:inherit;font-size:1rem}.swal2-popup:focus{outline:0}.swal2-popup.swal2-loading{overflow-y:hidden}.swal2-header{display:flex;flex-direction:column;align-items:center;padding:0 1.8em}.swal2-title{position:relative;max-width:100%;margin:0 0 .4em;padding:0;color:#595959;font-size:1.875em;font-weight:600;text-align:center;text-transform:none;word-wrap:break-word}.swal2-actions{display:flex;z-index:1;flex-wrap:wrap;align-items:center;justify-content:center;width:100%;margin:1.25em auto 0}.swal2-actions:not(.swal2-loading) .swal2-styled[disabled]{opacity:.4}.swal2-actions:not(.swal2-loading) .swal2-styled:hover{background-image:linear-gradient(rgba(0,0,0,.1),rgba(0,0,0,.1))}.swal2-actions:not(.swal2-loading) .swal2-styled:active{background-image:linear-gradient(rgba(0,0,0,.2),rgba(0,0,0,.2))}.swal2-actions.swal2-loading .swal2-styled.swal2-confirm{box-sizing:border-box;width:2.5em;height:2.5em;margin:.46875em;padding:0;-webkit-animation:swal2-rotate-loading 1.5s linear 0s infinite normal;animation:swal2-rotate-loading 1.5s linear 0s infinite normal;border:.25em solid transparent;border-radius:100%;border-color:transparent;background-color:transparent!important;color:transparent!important;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.swal2-actions.swal2-loading .swal2-styled.swal2-cancel{margin-right:30px;margin-left:30px}.swal2-actions.swal2-loading :not(.swal2-styled).swal2-confirm::after{content:\"\";display:inline-block;width:15px;height:15px;margin-left:5px;-webkit-animation:swal2-rotate-loading 1.5s linear 0s infinite normal;animation:swal2-rotate-loading 1.5s linear 0s infinite normal;border:3px solid #999;border-radius:50%;border-right-color:transparent;box-shadow:1px 1px 1px #fff}.swal2-styled{margin:.3125em;padding:.625em 2em;box-shadow:none;font-weight:500}.swal2-styled:not([disabled]){cursor:pointer}.swal2-styled.swal2-confirm{border:0;border-radius:.25em;background:initial;background-color:#3085d6;color:#fff;font-size:1.0625em}.swal2-styled.swal2-cancel{border:0;border-radius:.25em;background:initial;background-color:#aaa;color:#fff;font-size:1.0625em}.swal2-styled:focus{outline:0;box-shadow:0 0 0 1px #fff,0 0 0 3px rgba(50,100,150,.4)}.swal2-styled::-moz-focus-inner{border:0}.swal2-footer{justify-content:center;margin:1.25em 0 0;padding:1em 0 0;border-top:1px solid #eee;color:#545454;font-size:1em}.swal2-timer-progress-bar-container{position:absolute;right:0;bottom:0;left:0;height:.25em;overflow:hidden;border-bottom-right-radius:.3125em;border-bottom-left-radius:.3125em}.swal2-timer-progress-bar{width:100%;height:.25em;background:rgba(0,0,0,.2)}.swal2-image{max-width:100%;margin:1.25em auto}.swal2-close{position:absolute;z-index:2;top:0;right:0;align-items:center;justify-content:center;width:1.2em;height:1.2em;padding:0;overflow:hidden;transition:color .1s ease-out;border:none;border-radius:0;background:0 0;color:#ccc;font-family:serif;font-size:2.5em;line-height:1.2;cursor:pointer}.swal2-close:hover{transform:none;background:0 0;color:#f27474}.swal2-close::-moz-focus-inner{border:0}.swal2-content{z-index:1;justify-content:center;margin:0;padding:0 1.6em;color:#545454;font-size:1.125em;font-weight:400;line-height:normal;text-align:center;word-wrap:break-word}.swal2-checkbox,.swal2-file,.swal2-input,.swal2-radio,.swal2-select,.swal2-textarea{margin:1em auto}.swal2-file,.swal2-input,.swal2-textarea{box-sizing:border-box;width:100%;transition:border-color .3s,box-shadow .3s;border:1px solid #d9d9d9;border-radius:.1875em;background:inherit;box-shadow:inset 0 1px 1px rgba(0,0,0,.06);color:inherit;font-size:1.125em}.swal2-file.swal2-inputerror,.swal2-input.swal2-inputerror,.swal2-textarea.swal2-inputerror{border-color:#f27474!important;box-shadow:0 0 2px #f27474!important}.swal2-file:focus,.swal2-input:focus,.swal2-textarea:focus{border:1px solid #b4dbed;outline:0;box-shadow:0 0 3px #c4e6f5}.swal2-file::-moz-placeholder,.swal2-input::-moz-placeholder,.swal2-textarea::-moz-placeholder{color:#ccc}.swal2-file:-ms-input-placeholder,.swal2-input:-ms-input-placeholder,.swal2-textarea:-ms-input-placeholder{color:#ccc}.swal2-file::-ms-input-placeholder,.swal2-input::-ms-input-placeholder,.swal2-textarea::-ms-input-placeholder{color:#ccc}.swal2-file::placeholder,.swal2-input::placeholder,.swal2-textarea::placeholder{color:#ccc}.swal2-range{margin:1em auto;background:#fff}.swal2-range input{width:80%}.swal2-range output{width:20%;color:inherit;font-weight:600;text-align:center}.swal2-range input,.swal2-range output{height:2.625em;padding:0;font-size:1.125em;line-height:2.625em}.swal2-input{height:2.625em;padding:0 .75em}.swal2-input[type=number]{max-width:10em}.swal2-file{background:inherit;font-size:1.125em}.swal2-textarea{height:6.75em;padding:.75em}.swal2-select{min-width:50%;max-width:100%;padding:.375em .625em;background:inherit;color:inherit;font-size:1.125em}.swal2-checkbox,.swal2-radio{align-items:center;justify-content:center;background:#fff;color:inherit}.swal2-checkbox label,.swal2-radio label{margin:0 .6em;font-size:1.125em}.swal2-checkbox input,.swal2-radio input{margin:0 .4em}.swal2-validation-message{display:none;align-items:center;justify-content:center;padding:.625em;overflow:hidden;background:#f0f0f0;color:#666;font-size:1em;font-weight:300}.swal2-validation-message::before{content:\"!\";display:inline-block;width:1.5em;min-width:1.5em;height:1.5em;margin:0 .625em;border-radius:50%;background-color:#f27474;color:#fff;font-weight:600;line-height:1.5em;text-align:center}.swal2-icon{position:relative;box-sizing:content-box;justify-content:center;width:5em;height:5em;margin:1.25em auto 1.875em;border:.25em solid transparent;border-radius:50%;font-family:inherit;line-height:5em;cursor:default;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.swal2-icon .swal2-icon-content{display:flex;align-items:center;font-size:3.75em}.swal2-icon.swal2-error{border-color:#f27474;color:#f27474}.swal2-icon.swal2-error .swal2-x-mark{position:relative;flex-grow:1}.swal2-icon.swal2-error [class^=swal2-x-mark-line]{display:block;position:absolute;top:2.3125em;width:2.9375em;height:.3125em;border-radius:.125em;background-color:#f27474}.swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=left]{left:1.0625em;transform:rotate(45deg)}.swal2-icon.swal2-error [class^=swal2-x-mark-line][class$=right]{right:1em;transform:rotate(-45deg)}.swal2-icon.swal2-error.swal2-icon-show{-webkit-animation:swal2-animate-error-icon .5s;animation:swal2-animate-error-icon .5s}.swal2-icon.swal2-error.swal2-icon-show .swal2-x-mark{-webkit-animation:swal2-animate-error-x-mark .5s;animation:swal2-animate-error-x-mark .5s}.swal2-icon.swal2-warning{border-color:#facea8;color:#f8bb86}.swal2-icon.swal2-info{border-color:#9de0f6;color:#3fc3ee}.swal2-icon.swal2-question{border-color:#c9dae1;color:#87adbd}.swal2-icon.swal2-success{border-color:#a5dc86;color:#a5dc86}.swal2-icon.swal2-success [class^=swal2-success-circular-line]{position:absolute;width:3.75em;height:7.5em;transform:rotate(45deg);border-radius:50%}.swal2-icon.swal2-success [class^=swal2-success-circular-line][class$=left]{top:-.4375em;left:-2.0635em;transform:rotate(-45deg);transform-origin:3.75em 3.75em;border-radius:7.5em 0 0 7.5em}.swal2-icon.swal2-success [class^=swal2-success-circular-line][class$=right]{top:-.6875em;left:1.875em;transform:rotate(-45deg);transform-origin:0 3.75em;border-radius:0 7.5em 7.5em 0}.swal2-icon.swal2-success .swal2-success-ring{position:absolute;z-index:2;top:-.25em;left:-.25em;box-sizing:content-box;width:100%;height:100%;border:.25em solid rgba(165,220,134,.3);border-radius:50%}.swal2-icon.swal2-success .swal2-success-fix{position:absolute;z-index:1;top:.5em;left:1.625em;width:.4375em;height:5.625em;transform:rotate(-45deg)}.swal2-icon.swal2-success [class^=swal2-success-line]{display:block;position:absolute;z-index:2;height:.3125em;border-radius:.125em;background-color:#a5dc86}.swal2-icon.swal2-success [class^=swal2-success-line][class$=tip]{top:2.875em;left:.8125em;width:1.5625em;transform:rotate(45deg)}.swal2-icon.swal2-success [class^=swal2-success-line][class$=long]{top:2.375em;right:.5em;width:2.9375em;transform:rotate(-45deg)}.swal2-icon.swal2-success.swal2-icon-show .swal2-success-line-tip{-webkit-animation:swal2-animate-success-line-tip .75s;animation:swal2-animate-success-line-tip .75s}.swal2-icon.swal2-success.swal2-icon-show .swal2-success-line-long{-webkit-animation:swal2-animate-success-line-long .75s;animation:swal2-animate-success-line-long .75s}.swal2-icon.swal2-success.swal2-icon-show .swal2-success-circular-line-right{-webkit-animation:swal2-rotate-success-circular-line 4.25s ease-in;animation:swal2-rotate-success-circular-line 4.25s ease-in}.swal2-progress-steps{align-items:center;margin:0 0 1.25em;padding:0;background:inherit;font-weight:600}.swal2-progress-steps li{display:inline-block;position:relative}.swal2-progress-steps .swal2-progress-step{z-index:20;width:2em;height:2em;border-radius:2em;background:#3085d6;color:#fff;line-height:2em;text-align:center}.swal2-progress-steps .swal2-progress-step.swal2-active-progress-step{background:#3085d6}.swal2-progress-steps .swal2-progress-step.swal2-active-progress-step~.swal2-progress-step{background:#add8e6;color:#fff}.swal2-progress-steps .swal2-progress-step.swal2-active-progress-step~.swal2-progress-step-line{background:#add8e6}.swal2-progress-steps .swal2-progress-step-line{z-index:10;width:2.5em;height:.4em;margin:0 -1px;background:#3085d6}[class^=swal2]{-webkit-tap-highlight-color:transparent}.swal2-show{-webkit-animation:swal2-show .3s;animation:swal2-show .3s}.swal2-hide{-webkit-animation:swal2-hide .15s forwards;animation:swal2-hide .15s forwards}.swal2-noanimation{transition:none}.swal2-scrollbar-measure{position:absolute;top:-9999px;width:50px;height:50px;overflow:scroll}.swal2-rtl .swal2-close{right:auto;left:0}.swal2-rtl .swal2-timer-progress-bar{right:0;left:auto}@supports (-ms-accelerator:true){.swal2-range input{width:100%!important}.swal2-range output{display:none}}@media all and (-ms-high-contrast:none),(-ms-high-contrast:active){.swal2-range input{width:100%!important}.swal2-range output{display:none}}@-moz-document url-prefix(){.swal2-close:focus{outline:2px solid rgba(50,100,150,.4)}}@-webkit-keyframes swal2-toast-show{0%{transform:translateY(-.625em) rotateZ(2deg)}33%{transform:translateY(0) rotateZ(-2deg)}66%{transform:translateY(.3125em) rotateZ(2deg)}100%{transform:translateY(0) rotateZ(0)}}@keyframes swal2-toast-show{0%{transform:translateY(-.625em) rotateZ(2deg)}33%{transform:translateY(0) rotateZ(-2deg)}66%{transform:translateY(.3125em) rotateZ(2deg)}100%{transform:translateY(0) rotateZ(0)}}@-webkit-keyframes swal2-toast-hide{100%{transform:rotateZ(1deg);opacity:0}}@keyframes swal2-toast-hide{100%{transform:rotateZ(1deg);opacity:0}}@-webkit-keyframes swal2-toast-animate-success-line-tip{0%{top:.5625em;left:.0625em;width:0}54%{top:.125em;left:.125em;width:0}70%{top:.625em;left:-.25em;width:1.625em}84%{top:1.0625em;left:.75em;width:.5em}100%{top:1.125em;left:.1875em;width:.75em}}@keyframes swal2-toast-animate-success-line-tip{0%{top:.5625em;left:.0625em;width:0}54%{top:.125em;left:.125em;width:0}70%{top:.625em;left:-.25em;width:1.625em}84%{top:1.0625em;left:.75em;width:.5em}100%{top:1.125em;left:.1875em;width:.75em}}@-webkit-keyframes swal2-toast-animate-success-line-long{0%{top:1.625em;right:1.375em;width:0}65%{top:1.25em;right:.9375em;width:0}84%{top:.9375em;right:0;width:1.125em}100%{top:.9375em;right:.1875em;width:1.375em}}@keyframes swal2-toast-animate-success-line-long{0%{top:1.625em;right:1.375em;width:0}65%{top:1.25em;right:.9375em;width:0}84%{top:.9375em;right:0;width:1.125em}100%{top:.9375em;right:.1875em;width:1.375em}}@-webkit-keyframes swal2-show{0%{transform:scale(.7)}45%{transform:scale(1.05)}80%{transform:scale(.95)}100%{transform:scale(1)}}@keyframes swal2-show{0%{transform:scale(.7)}45%{transform:scale(1.05)}80%{transform:scale(.95)}100%{transform:scale(1)}}@-webkit-keyframes swal2-hide{0%{transform:scale(1);opacity:1}100%{transform:scale(.5);opacity:0}}@keyframes swal2-hide{0%{transform:scale(1);opacity:1}100%{transform:scale(.5);opacity:0}}@-webkit-keyframes swal2-animate-success-line-tip{0%{top:1.1875em;left:.0625em;width:0}54%{top:1.0625em;left:.125em;width:0}70%{top:2.1875em;left:-.375em;width:3.125em}84%{top:3em;left:1.3125em;width:1.0625em}100%{top:2.8125em;left:.8125em;width:1.5625em}}@keyframes swal2-animate-success-line-tip{0%{top:1.1875em;left:.0625em;width:0}54%{top:1.0625em;left:.125em;width:0}70%{top:2.1875em;left:-.375em;width:3.125em}84%{top:3em;left:1.3125em;width:1.0625em}100%{top:2.8125em;left:.8125em;width:1.5625em}}@-webkit-keyframes swal2-animate-success-line-long{0%{top:3.375em;right:2.875em;width:0}65%{top:3.375em;right:2.875em;width:0}84%{top:2.1875em;right:0;width:3.4375em}100%{top:2.375em;right:.5em;width:2.9375em}}@keyframes swal2-animate-success-line-long{0%{top:3.375em;right:2.875em;width:0}65%{top:3.375em;right:2.875em;width:0}84%{top:2.1875em;right:0;width:3.4375em}100%{top:2.375em;right:.5em;width:2.9375em}}@-webkit-keyframes swal2-rotate-success-circular-line{0%{transform:rotate(-45deg)}5%{transform:rotate(-45deg)}12%{transform:rotate(-405deg)}100%{transform:rotate(-405deg)}}@keyframes swal2-rotate-success-circular-line{0%{transform:rotate(-45deg)}5%{transform:rotate(-45deg)}12%{transform:rotate(-405deg)}100%{transform:rotate(-405deg)}}@-webkit-keyframes swal2-animate-error-x-mark{0%{margin-top:1.625em;transform:scale(.4);opacity:0}50%{margin-top:1.625em;transform:scale(.4);opacity:0}80%{margin-top:-.375em;transform:scale(1.15)}100%{margin-top:0;transform:scale(1);opacity:1}}@keyframes swal2-animate-error-x-mark{0%{margin-top:1.625em;transform:scale(.4);opacity:0}50%{margin-top:1.625em;transform:scale(.4);opacity:0}80%{margin-top:-.375em;transform:scale(1.15)}100%{margin-top:0;transform:scale(1);opacity:1}}@-webkit-keyframes swal2-animate-error-icon{0%{transform:rotateX(100deg);opacity:0}100%{transform:rotateX(0);opacity:1}}@keyframes swal2-animate-error-icon{0%{transform:rotateX(100deg);opacity:0}100%{transform:rotateX(0);opacity:1}}@-webkit-keyframes swal2-rotate-loading{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes swal2-rotate-loading{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown){overflow:hidden}body.swal2-height-auto{height:auto!important}body.swal2-no-backdrop .swal2-container{top:auto;right:auto;bottom:auto;left:auto;max-width:calc(100% - .625em * 2);background-color:transparent!important}body.swal2-no-backdrop .swal2-container>.swal2-modal{box-shadow:0 0 10px rgba(0,0,0,.4)}body.swal2-no-backdrop .swal2-container.swal2-top{top:0;left:50%;transform:translateX(-50%)}body.swal2-no-backdrop .swal2-container.swal2-top-left,body.swal2-no-backdrop .swal2-container.swal2-top-start{top:0;left:0}body.swal2-no-backdrop .swal2-container.swal2-top-end,body.swal2-no-backdrop .swal2-container.swal2-top-right{top:0;right:0}body.swal2-no-backdrop .swal2-container.swal2-center{top:50%;left:50%;transform:translate(-50%,-50%)}body.swal2-no-backdrop .swal2-container.swal2-center-left,body.swal2-no-backdrop .swal2-container.swal2-center-start{top:50%;left:0;transform:translateY(-50%)}body.swal2-no-backdrop .swal2-container.swal2-center-end,body.swal2-no-backdrop .swal2-container.swal2-center-right{top:50%;right:0;transform:translateY(-50%)}body.swal2-no-backdrop .swal2-container.swal2-bottom{bottom:0;left:50%;transform:translateX(-50%)}body.swal2-no-backdrop .swal2-container.swal2-bottom-left,body.swal2-no-backdrop .swal2-container.swal2-bottom-start{bottom:0;left:0}body.swal2-no-backdrop .swal2-container.swal2-bottom-end,body.swal2-no-backdrop .swal2-container.swal2-bottom-right{right:0;bottom:0}@media print{body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown){overflow-y:scroll!important}body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown)>[aria-hidden=true]{display:none}body.swal2-shown:not(.swal2-no-backdrop):not(.swal2-toast-shown) .swal2-container{position:static!important}}body.swal2-toast-shown .swal2-container{background-color:transparent}body.swal2-toast-shown .swal2-container.swal2-top{top:0;right:auto;bottom:auto;left:50%;transform:translateX(-50%)}body.swal2-toast-shown .swal2-container.swal2-top-end,body.swal2-toast-shown .swal2-container.swal2-top-right{top:0;right:0;bottom:auto;left:auto}body.swal2-toast-shown .swal2-container.swal2-top-left,body.swal2-toast-shown .swal2-container.swal2-top-start{top:0;right:auto;bottom:auto;left:0}body.swal2-toast-shown .swal2-container.swal2-center-left,body.swal2-toast-shown .swal2-container.swal2-center-start{top:50%;right:auto;bottom:auto;left:0;transform:translateY(-50%)}body.swal2-toast-shown .swal2-container.swal2-center{top:50%;right:auto;bottom:auto;left:50%;transform:translate(-50%,-50%)}body.swal2-toast-shown .swal2-container.swal2-center-end,body.swal2-toast-shown .swal2-container.swal2-center-right{top:50%;right:0;bottom:auto;left:auto;transform:translateY(-50%)}body.swal2-toast-shown .swal2-container.swal2-bottom-left,body.swal2-toast-shown .swal2-container.swal2-bottom-start{top:auto;right:auto;bottom:0;left:0}body.swal2-toast-shown .swal2-container.swal2-bottom{top:auto;right:auto;bottom:0;left:50%;transform:translateX(-50%)}body.swal2-toast-shown .swal2-container.swal2-bottom-end,body.swal2-toast-shown .swal2-container.swal2-bottom-right{top:auto;right:0;bottom:0;left:auto}body.swal2-toast-column .swal2-toast{flex-direction:column;align-items:stretch}body.swal2-toast-column .swal2-toast .swal2-actions{flex:1;align-self:stretch;height:2.2em;margin-top:.3125em}body.swal2-toast-column .swal2-toast .swal2-loading{justify-content:center}body.swal2-toast-column .swal2-toast .swal2-input{height:2em;margin:.3125em auto;font-size:1em}body.swal2-toast-column .swal2-toast .swal2-validation-message{font-size:1em}");

/***/},

/***/"./node_modules/sweetalert2/dist/sweetalert2.min.css":
/*!***********************************************************!*\
  !*** ./node_modules/sweetalert2/dist/sweetalert2.min.css ***!
  \***********************************************************/
/*! no static exports found */
/***/function node_modulesSweetalert2DistSweetalert2MinCss(module,exports,__webpack_require__){


var content=__webpack_require__(/*! !../../css-loader??ref--6-1!../../postcss-loader/src??ref--6-2!./sweetalert2.min.css */"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/sweetalert2/dist/sweetalert2.min.css");

if(typeof content==='string')content=[[module.i,content,'']];

var transform;



var options={"hmr":true};

options.transform=transform;
options.insertInto=undefined;

var update=__webpack_require__(/*! ../../style-loader/lib/addStyles.js */"./node_modules/style-loader/lib/addStyles.js")(content,options);

if(content.locals)module.exports=content.locals;

/***/},

/***/"./node_modules/timers-browserify/main.js":
/*!************************************************!*\
  !*** ./node_modules/timers-browserify/main.js ***!
  \************************************************/
/*! no static exports found */
/***/function node_modulesTimersBrowserifyMainJs(module,exports,__webpack_require__){

/* WEBPACK VAR INJECTION */(function(global){var scope=typeof global!=="undefined"&&global||
typeof self!=="undefined"&&self||
window;
var apply=Function.prototype.apply;

// DOM APIs, for completeness

exports.setTimeout=function(){
return new Timeout(apply.call(setTimeout,scope,arguments),clearTimeout);
};
exports.setInterval=function(){
return new Timeout(apply.call(setInterval,scope,arguments),clearInterval);
};
exports.clearTimeout=
exports.clearInterval=function(timeout){
if(timeout){
timeout.close();
}
};

function Timeout(id,clearFn){
this._id=id;
this._clearFn=clearFn;
}
Timeout.prototype.unref=Timeout.prototype.ref=function(){};
Timeout.prototype.close=function(){
this._clearFn.call(scope,this._id);
};

// Does not start the time, just sets up the members needed.
exports.enroll=function(item,msecs){
clearTimeout(item._idleTimeoutId);
item._idleTimeout=msecs;
};

exports.unenroll=function(item){
clearTimeout(item._idleTimeoutId);
item._idleTimeout=-1;
};

exports._unrefActive=exports.active=function(item){
clearTimeout(item._idleTimeoutId);

var msecs=item._idleTimeout;
if(msecs>=0){
item._idleTimeoutId=setTimeout(function onTimeout(){
if(item._onTimeout)
item._onTimeout();
},msecs);
}
};

// setimmediate attaches itself to the global object
__webpack_require__(/*! setimmediate */"./node_modules/setimmediate/setImmediate.js");
// On some exotic environments, it's not clear which object `setimmediate` was
// able to install onto.  Search each possibility in the same order as the
// `setimmediate` library.
exports.setImmediate=typeof self!=="undefined"&&self.setImmediate||
typeof global!=="undefined"&&global.setImmediate||
this&&this.setImmediate;
exports.clearImmediate=typeof self!=="undefined"&&self.clearImmediate||
typeof global!=="undefined"&&global.clearImmediate||
this&&this.clearImmediate;

/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"));

/***/},

/***/"./node_modules/tiny-cookie/tiny-cookie.js":
/*!*************************************************!*\
  !*** ./node_modules/tiny-cookie/tiny-cookie.js ***!
  \*************************************************/
/*! no static exports found */
/***/function node_modulesTinyCookieTinyCookieJs(module,exports,__webpack_require__){

var __WEBPACK_AMD_DEFINE_FACTORY__,__WEBPACK_AMD_DEFINE_RESULT__;/*!
 * tiny-cookie - A tiny cookie manipulation plugin
 * https://github.com/Alex1990/tiny-cookie
 * Under the MIT license | (c) Alex Chao
 */

!function(root,factory){

// Uses CommonJS, AMD or browser global to create a jQuery plugin.
// See: https://github.com/umdjs/umd
{
// Expose this plugin as an AMD module. Register an anonymous module.
!(__WEBPACK_AMD_DEFINE_FACTORY__=factory,
__WEBPACK_AMD_DEFINE_RESULT__=typeof __WEBPACK_AMD_DEFINE_FACTORY__==='function'?
__WEBPACK_AMD_DEFINE_FACTORY__.call(exports,__webpack_require__,exports,module):
__WEBPACK_AMD_DEFINE_FACTORY__,
__WEBPACK_AMD_DEFINE_RESULT__!==undefined&&(module.exports=__WEBPACK_AMD_DEFINE_RESULT__));
}

}(this,function(){

// The public function which can get/set/remove cookie.
function Cookie(key,value,opts){
if(value===void 0){
return Cookie.get(key);
}else if(value===null){
Cookie.remove(key);
}else {
Cookie.set(key,value,opts);
}
}

// Check if the cookie is enabled.
Cookie.enabled=function(){
var key='__test_key';
var enabled;

document.cookie=key+'=1';
enabled=!!document.cookie;

if(enabled)Cookie.remove(key);

return enabled;
};

// Get the cookie value by the key.
Cookie.get=function(key,raw){
if(typeof key!=='string'||!key)return null;

key='(?:^|; )'+escapeRe(key)+'(?:=([^;]*?))?(?:;|$)';

var reKey=new RegExp(key);
var res=reKey.exec(document.cookie);

return res!==null?raw?res[1]:decodeURIComponent(res[1]):null;
};

// Get the cookie's value without decoding.
Cookie.getRaw=function(key){
return Cookie.get(key,true);
};

// Set a cookie.
Cookie.set=function(key,value,raw,opts){
if(raw!==true){
opts=raw;
raw=false;
}
opts=opts?convert(opts):convert({});
var cookie=key+'='+(raw?value:encodeURIComponent(value))+opts;
document.cookie=cookie;
};

// Set a cookie without encoding the value.
Cookie.setRaw=function(key,value,opts){
Cookie.set(key,value,true,opts);
};

// Remove a cookie by the specified key.
Cookie.remove=function(key){
Cookie.set(key,'a',{expires:new Date()});
};

// Helper function
// ---------------

// Escape special characters.
function escapeRe(str){
return str.replace(/[.*+?^$|[\](){}\\-]/g,'\\$&');
}

// Convert an object to a cookie option string.
function convert(opts){
var res='';

for(var p in opts){
if(opts.hasOwnProperty(p)){

if(p==='expires'){
var expires=opts[p];
if(typeof expires!=='object'){
expires+=typeof expires==='number'?'D':'';
expires=computeExpires(expires);
}
opts[p]=expires.toUTCString();
}

if(p==='secure'){
if(opts[p]){
res+=';'+p;
}

continue;
}

res+=';'+p+'='+opts[p];
}
}

if(!opts.hasOwnProperty('path')){
res+=';path=/';
}

return res;
}

// Return a future date by the given string.
function computeExpires(str){
var expires=new Date();
var lastCh=str.charAt(str.length-1);
var value=parseInt(str,10);

switch(lastCh){
case'Y':expires.setFullYear(expires.getFullYear()+value);break;
case'M':expires.setMonth(expires.getMonth()+value);break;
case'D':expires.setDate(expires.getDate()+value);break;
case'h':expires.setHours(expires.getHours()+value);break;
case'm':expires.setMinutes(expires.getMinutes()+value);break;
case's':expires.setSeconds(expires.getSeconds()+value);break;
default:expires=new Date(str);}


return expires;
}

return Cookie;

});


/***/},

/***/"./node_modules/vee-validate/dist/rules.js":
/*!*************************************************!*\
  !*** ./node_modules/vee-validate/dist/rules.js ***!
  \*************************************************/
/*! exports provided: alpha, alpha_dash, alpha_num, alpha_spaces, between, confirmed, digits, dimensions, double, email, excluded, ext, image, integer, is, is_not, length, max, max_value, mimes, min, min_value, numeric, oneOf, regex, required, required_if, size */
/***/function node_modulesVeeValidateDistRulesJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"alpha",function(){return alpha$1;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"alpha_dash",function(){return alpha_dash;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"alpha_num",function(){return alpha_num;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"alpha_spaces",function(){return alpha_spaces;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"between",function(){return between;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"confirmed",function(){return confirmed;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"digits",function(){return digits;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"dimensions",function(){return dimensions;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"double",function(){return double;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"email",function(){return email;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"excluded",function(){return excluded;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ext",function(){return ext;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"image",function(){return image;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"integer",function(){return integer;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"is",function(){return is;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"is_not",function(){return is_not;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"length",function(){return length;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"max",function(){return max;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"max_value",function(){return max_value;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"mimes",function(){return mimes;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"min",function(){return min;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"min_value",function(){return min_value;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"numeric",function(){return numeric;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"oneOf",function(){return oneOf;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"regex",function(){return regex;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"required",function(){return required;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"required_if",function(){return required_if;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"size",function(){return size;});
/**
  * vee-validate v3.4.5
  * (c) 2020 Abdelrahman Awad
  * @license MIT
  */
/**
 * Some Alpha Regex helpers.
 * https://github.com/chriso/validator.js/blob/master/src/lib/alpha.js
 */
/* eslint-disable no-misleading-character-class */
var alpha={
en:/^[A-Z]*$/i,
cs:/^[A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ]*$/i,
da:/^[A-ZÆØÅ]*$/i,
de:/^[A-ZÄÖÜß]*$/i,
es:/^[A-ZÁÉÍÑÓÚÜ]*$/i,
fa:/^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰپژگچکی]*$/,
fr:/^[A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ]*$/i,
it:/^[A-Z\xC0-\xFF]*$/i,
lt:/^[A-ZĄČĘĖĮŠŲŪŽ]*$/i,
nl:/^[A-ZÉËÏÓÖÜ]*$/i,
hu:/^[A-ZÁÉÍÓÖŐÚÜŰ]*$/i,
pl:/^[A-ZĄĆĘŚŁŃÓŻŹ]*$/i,
pt:/^[A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ]*$/i,
ro:/^[A-ZĂÂÎŞŢ]*$/i,
ru:/^[А-ЯЁ]*$/i,
sk:/^[A-ZÁÄČĎÉÍĹĽŇÓŔŠŤÚÝŽ]*$/i,
sr:/^[A-ZČĆŽŠĐ]*$/i,
sv:/^[A-ZÅÄÖ]*$/i,
tr:/^[A-ZÇĞİıÖŞÜ]*$/i,
uk:/^[А-ЩЬЮЯЄІЇҐ]*$/i,
ar:/^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]*$/,
az:/^[A-ZÇƏĞİıÖŞÜ]*$/i,
el:/^[Α-ώ]*$/i};

var alphaSpaces={
en:/^[A-Z\s]*$/i,
cs:/^[A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ\s]*$/i,
da:/^[A-ZÆØÅ\s]*$/i,
de:/^[A-ZÄÖÜß\s]*$/i,
es:/^[A-ZÁÉÍÑÓÚÜ\s]*$/i,
fa:/^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰپژگچکی]*$/,
fr:/^[A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ\s]*$/i,
it:/^[A-Z\xC0-\xFF\s]*$/i,
lt:/^[A-ZĄČĘĖĮŠŲŪŽ\s]*$/i,
nl:/^[A-ZÉËÏÓÖÜ\s]*$/i,
hu:/^[A-ZÁÉÍÓÖŐÚÜŰ\s]*$/i,
pl:/^[A-ZĄĆĘŚŁŃÓŻŹ\s]*$/i,
pt:/^[A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ\s]*$/i,
ro:/^[A-ZĂÂÎŞŢ\s]*$/i,
ru:/^[А-ЯЁ\s]*$/i,
sk:/^[A-ZÁÄČĎÉÍĹĽŇÓŔŠŤÚÝŽ\s]*$/i,
sr:/^[A-ZČĆŽŠĐ\s]*$/i,
sv:/^[A-ZÅÄÖ\s]*$/i,
tr:/^[A-ZÇĞİıÖŞÜ\s]*$/i,
uk:/^[А-ЩЬЮЯЄІЇҐ\s]*$/i,
ar:/^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ\s]*$/,
az:/^[A-ZÇƏĞİıÖŞÜ\s]*$/i,
el:/^[Α-ώ\s]*$/i};

var alphanumeric={
en:/^[0-9A-Z]*$/i,
cs:/^[0-9A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ]*$/i,
da:/^[0-9A-ZÆØÅ]$/i,
de:/^[0-9A-ZÄÖÜß]*$/i,
es:/^[0-9A-ZÁÉÍÑÓÚÜ]*$/i,
fa:/^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰپژگچکی]*$/,
fr:/^[0-9A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ]*$/i,
it:/^[0-9A-Z\xC0-\xFF]*$/i,
lt:/^[0-9A-ZĄČĘĖĮŠŲŪŽ]*$/i,
hu:/^[0-9A-ZÁÉÍÓÖŐÚÜŰ]*$/i,
nl:/^[0-9A-ZÉËÏÓÖÜ]*$/i,
pl:/^[0-9A-ZĄĆĘŚŁŃÓŻŹ]*$/i,
pt:/^[0-9A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ]*$/i,
ro:/^[0-9A-ZĂÂÎŞŢ]*$/i,
ru:/^[0-9А-ЯЁ]*$/i,
sk:/^[0-9A-ZÁÄČĎÉÍĹĽŇÓŔŠŤÚÝŽ]*$/i,
sr:/^[0-9A-ZČĆŽŠĐ]*$/i,
sv:/^[0-9A-ZÅÄÖ]*$/i,
tr:/^[0-9A-ZÇĞİıÖŞÜ]*$/i,
uk:/^[0-9А-ЩЬЮЯЄІЇҐ]*$/i,
ar:/^[٠١٢٣٤٥٦٧٨٩0-9ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]*$/,
az:/^[0-9A-ZÇƏĞİıÖŞÜ]*$/i,
el:/^[0-9Α-ώ]*$/i};

var alphaDash={
en:/^[0-9A-Z_-]*$/i,
cs:/^[0-9A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ_-]*$/i,
da:/^[0-9A-ZÆØÅ_-]*$/i,
de:/^[0-9A-ZÄÖÜß_-]*$/i,
es:/^[0-9A-ZÁÉÍÑÓÚÜ_-]*$/i,
fa:/^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰپژگچکی]*$/,
fr:/^[0-9A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ_-]*$/i,
it:/^[0-9A-Z\xC0-\xFF_-]*$/i,
lt:/^[0-9A-ZĄČĘĖĮŠŲŪŽ_-]*$/i,
nl:/^[0-9A-ZÉËÏÓÖÜ_-]*$/i,
hu:/^[0-9A-ZÁÉÍÓÖŐÚÜŰ_-]*$/i,
pl:/^[0-9A-ZĄĆĘŚŁŃÓŻŹ_-]*$/i,
pt:/^[0-9A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ_-]*$/i,
ro:/^[0-9A-ZĂÂÎŞŢ_-]*$/i,
ru:/^[0-9А-ЯЁ_-]*$/i,
sk:/^[0-9A-ZÁÄČĎÉÍĹĽŇÓŔŠŤÚÝŽ_-]*$/i,
sr:/^[0-9A-ZČĆŽŠĐ_-]*$/i,
sv:/^[0-9A-ZÅÄÖ_-]*$/i,
tr:/^[0-9A-ZÇĞİıÖŞÜ_-]*$/i,
uk:/^[0-9А-ЩЬЮЯЄІЇҐ_-]*$/i,
ar:/^[٠١٢٣٤٥٦٧٨٩0-9ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ_-]*$/,
az:/^[0-9A-ZÇƏĞİıÖŞÜ_-]*$/i,
el:/^[0-9Α-ώ_-]*$/i};


var validate=function validate(value,_a){
var _b=(_a===void 0?{}:_a).locale,locale=_b===void 0?'':_b;
if(Array.isArray(value)){
return value.every(function(val){return validate(val,{locale:locale});});
}
// Match at least one locale.
if(!locale){
return Object.keys(alpha).some(function(loc){return alpha[loc].test(value);});
}
return (alpha[locale]||alpha.en).test(value);
};
var params=[
{
name:'locale'}];


var alpha$1={
validate:validate,
params:params};


var validate$1=function validate$1(value,_a){
var _b=(_a===void 0?{}:_a).locale,locale=_b===void 0?'':_b;
if(Array.isArray(value)){
return value.every(function(val){return validate$1(val,{locale:locale});});
}
// Match at least one locale.
if(!locale){
return Object.keys(alphaDash).some(function(loc){return alphaDash[loc].test(value);});
}
return (alphaDash[locale]||alphaDash.en).test(value);
};
var params$1=[
{
name:'locale'}];


var alpha_dash={
validate:validate$1,
params:params$1};


var validate$2=function validate$2(value,_a){
var _b=(_a===void 0?{}:_a).locale,locale=_b===void 0?'':_b;
if(Array.isArray(value)){
return value.every(function(val){return validate$2(val,{locale:locale});});
}
// Match at least one locale.
if(!locale){
return Object.keys(alphanumeric).some(function(loc){return alphanumeric[loc].test(value);});
}
return (alphanumeric[locale]||alphanumeric.en).test(value);
};
var params$2=[
{
name:'locale'}];


var alpha_num={
validate:validate$2,
params:params$2};


var validate$3=function validate$3(value,_a){
var _b=(_a===void 0?{}:_a).locale,locale=_b===void 0?'':_b;
if(Array.isArray(value)){
return value.every(function(val){return validate$3(val,{locale:locale});});
}
// Match at least one locale.
if(!locale){
return Object.keys(alphaSpaces).some(function(loc){return alphaSpaces[loc].test(value);});
}
return (alphaSpaces[locale]||alphaSpaces.en).test(value);
};
var params$3=[
{
name:'locale'}];


var alpha_spaces={
validate:validate$3,
params:params$3};


var validate$4=function validate$4(value,_a){
var _b=_a===void 0?{}:_a,min=_b.min,max=_b.max;
if(Array.isArray(value)){
return value.every(function(val){return !!validate$4(val,{min:min,max:max});});
}
return Number(min)<=value&&Number(max)>=value;
};
var params$4=[
{
name:'min'},

{
name:'max'}];


var between={
validate:validate$4,
params:params$4};


var validate$5=function validate$5(value,_a){
var target=_a.target;
return String(value)===String(target);
};
var params$5=[
{
name:'target',
isTarget:true}];


var confirmed={
validate:validate$5,
params:params$5};


var validate$6=function validate$6(value,_a){
var length=_a.length;
if(Array.isArray(value)){
return value.every(function(val){return validate$6(val,{length:length});});
}
var strVal=String(value);
return /^[0-9]*$/.test(strVal)&&strVal.length===length;
};
var params$6=[
{
name:'length',
cast:function cast(value){
return Number(value);
}}];


var digits={
validate:validate$6,
params:params$6};


var validateImage=function validateImage(file,width,height){
var URL=window.URL||window.webkitURL;
return new Promise(function(resolve){
var image=new Image();
image.onerror=function(){return resolve(false);};
image.onload=function(){return resolve(image.width===width&&image.height===height);};
image.src=URL.createObjectURL(file);
});
};
var validate$7=function validate$7(files,_a){
var width=_a.width,height=_a.height;
var list=[];
files=Array.isArray(files)?files:[files];
for(var i=0;i<files.length;i++){
// if file is not an image, reject.
if(!/\.(jpg|svg|jpeg|png|bmp|gif)$/i.test(files[i].name)){
return Promise.resolve(false);
}
list.push(files[i]);
}
return Promise.all(list.map(function(file){return validateImage(file,width,height);})).then(function(values){
return values.every(function(v){return v;});
});
};
var params$7=[
{
name:'width',
cast:function cast(value){
return Number(value);
}},

{
name:'height',
cast:function cast(value){
return Number(value);
}}];


var dimensions={
validate:validate$7,
params:params$7};


var validate$8=function validate$8(value,_a){
var multiple=(_a===void 0?{}:_a).multiple;
// eslint-disable-next-line
var re=/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
if(multiple&&!Array.isArray(value)){
value=String(value).
split(',').
map(function(emailStr){return emailStr.trim();});
}
if(Array.isArray(value)){
return value.every(function(val){return re.test(String(val));});
}
return re.test(String(value));
};
var params$8=[
{
name:'multiple',
default:false}];


var email={
validate:validate$8,
params:params$8};


function isNullOrUndefined(value){
return value===null||value===undefined;
}
function isEmptyArray(arr){
return Array.isArray(arr)&&arr.length===0;
}
function isCallable(fn){
return typeof fn==='function';
}

function includes(collection,item){
return collection.indexOf(item)!==-1;
}
/**
 * Converts an array-like object to array, provides a simple polyfill for Array.from
 */
function toArray(arrayLike){
if(isCallable(Array.from)){
return Array.from(arrayLike);
}
/* istanbul ignore next */
return _copyArray(arrayLike);
}
/* istanbul ignore next */
function _copyArray(arrayLike){
var array=[];
var length=arrayLike.length;
for(var i=0;i<length;i++){
array.push(arrayLike[i]);
}
return array;
}

var validate$9=function validate$9(value,options){
if(Array.isArray(value)){
return value.every(function(val){return validate$9(val,options);});
}
return toArray(options).some(function(item){
// eslint-disable-next-line
return item==value;
});
};
var oneOf={
validate:validate$9};


var validate$a=function validate$a(value,args){
return !validate$9(value,args);
};
var excluded={
validate:validate$a};


var validate$b=function validate$b(files,extensions){
var regex=new RegExp(".("+extensions.join('|')+")$",'i');
if(Array.isArray(files)){
return files.every(function(file){return regex.test(file.name);});
}
return regex.test(files.name);
};
var ext={
validate:validate$b};


var validate$c=function validate$c(files){
var regex=/\.(jpg|svg|jpeg|png|bmp|gif|webp)$/i;
if(Array.isArray(files)){
return files.every(function(file){return regex.test(file.name);});
}
return regex.test(files.name);
};
var image={
validate:validate$c};


var validate$d=function validate$d(value){
if(Array.isArray(value)){
return value.every(function(val){return /^-?[0-9]+$/.test(String(val));});
}
return /^-?[0-9]+$/.test(String(value));
};
var integer={
validate:validate$d};


var validate$e=function validate$e(value,_a){
var other=_a.other;
return value===other;
};
var params$9=[
{
name:'other'}];


var is={
validate:validate$e,
params:params$9};


var validate$f=function validate$f(value,_a){
var other=_a.other;
return value!==other;
};
var params$a=[
{
name:'other'}];


var is_not={
validate:validate$f,
params:params$a};


var validate$g=function validate$g(value,_a){
var length=_a.length;
if(isNullOrUndefined(value)){
return false;
}
if(typeof value==='string'){
value=toArray(value);
}
if(typeof value==='number'){
value=String(value);
}
if(!value.length){
value=toArray(value);
}
return value.length===length;
};
var params$b=[
{
name:'length',
cast:function cast(value){return Number(value);}}];


var length={
validate:validate$g,
params:params$b};


var validate$h=function validate$h(value,_a){
var length=_a.length;
if(isNullOrUndefined(value)){
return length>=0;
}
if(Array.isArray(value)){
return value.every(function(val){return validate$h(val,{length:length});});
}
return String(value).length<=length;
};
var params$c=[
{
name:'length',
cast:function cast(value){
return Number(value);
}}];


var max={
validate:validate$h,
params:params$c};


var validate$i=function validate$i(value,_a){
var max=_a.max;
if(isNullOrUndefined(value)||value===''){
return false;
}
if(Array.isArray(value)){
return value.length>0&&value.every(function(val){return validate$i(val,{max:max});});
}
return Number(value)<=max;
};
var params$d=[
{
name:'max',
cast:function cast(value){
return Number(value);
}}];


var max_value={
validate:validate$i,
params:params$d};


var validate$j=function validate$j(files,mimes){
var regex=new RegExp(mimes.join('|').replace('*','.+')+"$",'i');
if(Array.isArray(files)){
return files.every(function(file){return regex.test(file.type);});
}
return regex.test(files.type);
};
var mimes={
validate:validate$j};


var validate$k=function validate$k(value,_a){
var length=_a.length;
if(isNullOrUndefined(value)){
return false;
}
if(Array.isArray(value)){
return value.every(function(val){return validate$k(val,{length:length});});
}
return String(value).length>=length;
};
var params$e=[
{
name:'length',
cast:function cast(value){
return Number(value);
}}];


var min={
validate:validate$k,
params:params$e};


var validate$l=function validate$l(value,_a){
var min=_a.min;
if(isNullOrUndefined(value)||value===''){
return false;
}
if(Array.isArray(value)){
return value.length>0&&value.every(function(val){return validate$l(val,{min:min});});
}
return Number(value)>=min;
};
var params$f=[
{
name:'min',
cast:function cast(value){
return Number(value);
}}];


var min_value={
validate:validate$l,
params:params$f};


var ar=/^[٠١٢٣٤٥٦٧٨٩]+$/;
var en=/^[0-9]+$/;
var validate$m=function validate$m(value){
var testValue=function testValue(val){
var strValue=String(val);
return en.test(strValue)||ar.test(strValue);
};
if(Array.isArray(value)){
return value.every(testValue);
}
return testValue(value);
};
var numeric={
validate:validate$m};


var validate$n=function validate$n(value,_a){
var regex=_a.regex;
if(Array.isArray(value)){
return value.every(function(val){return validate$n(val,{regex:regex});});
}
return regex.test(String(value));
};
var params$g=[
{
name:'regex',
cast:function cast(value){
if(typeof value==='string'){
return new RegExp(value);
}
return value;
}}];


var regex={
validate:validate$n,
params:params$g};


var validate$o=function validate$o(value,_a){
var allowFalse=(_a===void 0?{allowFalse:true}:_a).allowFalse;
var result={
valid:false,
required:true};

if(isNullOrUndefined(value)||isEmptyArray(value)){
return result;
}
// incase a field considers `false` as an empty value like checkboxes.
if(value===false&&!allowFalse){
return result;
}
result.valid=!!String(value).trim().length;
return result;
};
var computesRequired=true;
var params$h=[
{
name:'allowFalse',
default:true}];


var required={
validate:validate$o,
params:params$h,
computesRequired:computesRequired};


var testEmpty=function testEmpty(value){
return isEmptyArray(value)||includes([false,null,undefined],value)||!String(value).trim().length;
};
var validate$p=function validate$p(value,_a){
var target=_a.target,values=_a.values;
var required;
if(values&&values.length){
if(!Array.isArray(values)&&typeof values==='string'){
values=[values];
}
// eslint-disable-next-line
required=values.some(function(val){return val==String(target).trim();});
}else
{
required=!testEmpty(target);
}
if(!required){
return {
valid:true,
required:required};

}
return {
valid:!testEmpty(value),
required:required};

};
var params$i=[
{
name:'target',
isTarget:true},

{
name:'values'}];


var computesRequired$1=true;
var required_if={
validate:validate$p,
params:params$i,
computesRequired:computesRequired$1};


var validate$q=function validate$q(files,_a){
var size=_a.size;
if(isNaN(size)){
return false;
}
var nSize=size*1024;
if(!Array.isArray(files)){
return files.size<=nSize;
}
for(var i=0;i<files.length;i++){
if(files[i].size>nSize){
return false;
}
}
return true;
};
var params$j=[
{
name:'size',
cast:function cast(value){
return Number(value);
}}];


var size={
validate:validate$q,
params:params$j};


var validate$r=function validate$r(value,params){
var _a=params||{},_b=_a.decimals,decimals=_b===void 0?0:_b,_c=_a.separator,separator=_c===void 0?'dot':_c;
var separators={
dot:'.',
comma:','};

var regexPart=+decimals===0?'+':"{"+decimals+"}";
var regex=new RegExp("^-?\\d+\\"+(separators[separator]||'.')+"\\d"+regexPart+"$");
return Array.isArray(value)?value.every(function(val){return regex.test(String(val));}):regex.test(String(value));
};
var params$k=[
{
name:'decimals',
default:0},

{
name:'separator',
default:'dot'}];


var double={
validate:validate$r,
params:params$k};





/***/},

/***/"./node_modules/vee-validate/dist/vee-validate.esm.js":
/*!************************************************************!*\
  !*** ./node_modules/vee-validate/dist/vee-validate.esm.js ***!
  \************************************************************/
/*! exports provided: ValidationObserver, ValidationProvider, configure, extend, localeChanged, localize, normalizeRules, setInteractionMode, validate, version, withValidation */
/***/function node_modulesVeeValidateDistVeeValidateEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ValidationObserver",function(){return ValidationObserver;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"ValidationProvider",function(){return ValidationProvider;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"configure",function(){return configure;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"extend",function(){return extend;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"localeChanged",function(){return localeChanged;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"localize",function(){return localize;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"normalizeRules",function(){return normalizeRules;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"setInteractionMode",function(){return setInteractionMode;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"validate",function(){return validate;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"version",function(){return version;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"withValidation",function(){return withValidation;});
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_0__);
/**
  * vee-validate v3.4.5
  * (c) 2020 Abdelrahman Awad
  * @license MIT
  */


/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var _assign=function __assign(){
_assign=Object.assign||function __assign(t){
for(var s,i=1,n=arguments.length;i<n;i++){
s=arguments[i];
for(var p in s){if(Object.prototype.hasOwnProperty.call(s,p))t[p]=s[p];}
}
return t;
};
return _assign.apply(this,arguments);
};

function __awaiter(thisArg,_arguments,P,generator){
function adopt(value){return value instanceof P?value:new P(function(resolve){resolve(value);});}
return new(P||(P=Promise))(function(resolve,reject){
function fulfilled(value){try{step(generator.next(value));}catch(e){reject(e);}}
function rejected(value){try{step(generator["throw"](value));}catch(e){reject(e);}}
function step(result){result.done?resolve(result.value):adopt(result.value).then(fulfilled,rejected);}
step((generator=generator.apply(thisArg,_arguments||[])).next());
});
}

function __generator(thisArg,body){
var _={label:0,sent:function sent(){if(t[0]&1)throw t[1];return t[1];},trys:[],ops:[]},f,y,t,g;
return g={next:verb(0),"throw":verb(1),"return":verb(2)},typeof Symbol==="function"&&(g[Symbol.iterator]=function(){return this;}),g;
function verb(n){return function(v){return step([n,v]);};}
function step(op){
if(f)throw new TypeError("Generator is already executing.");
while(_){try{
if(f=1,y&&(t=op[0]&2?y["return"]:op[0]?y["throw"]||((t=y["return"])&&t.call(y),0):y.next)&&!(t=t.call(y,op[1])).done)return t;
if(y=0,t)op=[op[0]&2,t.value];
switch(op[0]){
case 0:case 1:t=op;break;
case 4:_.label++;return {value:op[1],done:false};
case 5:_.label++;y=op[1];op=[0];continue;
case 7:op=_.ops.pop();_.trys.pop();continue;
default:
if(!(t=_.trys,t=t.length>0&&t[t.length-1])&&(op[0]===6||op[0]===2)){_=0;continue;}
if(op[0]===3&&(!t||op[1]>t[0]&&op[1]<t[3])){_.label=op[1];break;}
if(op[0]===6&&_.label<t[1]){_.label=t[1];t=op;break;}
if(t&&_.label<t[2]){_.label=t[2];_.ops.push(op);break;}
if(t[2])_.ops.pop();
_.trys.pop();continue;}

op=body.call(thisArg,_);
}catch(e){op=[6,e];y=0;}finally{f=t=0;}}
if(op[0]&5)throw op[1];return {value:op[0]?op[1]:void 0,done:true};
}
}

function __spreadArrays(){
for(var s=0,i=0,il=arguments.length;i<il;i++){s+=arguments[i].length;}
for(var r=Array(s),k=0,i=0;i<il;i++){
for(var a=arguments[i],j=0,jl=a.length;j<jl;j++,k++){
r[k]=a[j];}}
return r;
}

function isNaN(value){
// NaN is the one value that does not equal itself.
// eslint-disable-next-line
return value!==value;
}
function isNullOrUndefined(value){
return value===null||value===undefined;
}
function isEmptyArray(arr){
return Array.isArray(arr)&&arr.length===0;
}
var isObject=function isObject(obj){
return obj!==null&&obj&&typeof obj==='object'&&!Array.isArray(obj);
};
/**
 * A reference comparison function with NaN support
 */
function isRefEqual(lhs,rhs){
if(isNaN(lhs)&&isNaN(rhs)){
return true;
}
return lhs===rhs;
}
/**
 * Shallow object comparison.
 */
function isEqual(lhs,rhs){
if(lhs instanceof RegExp&&rhs instanceof RegExp){
return isEqual(lhs.source,rhs.source)&&isEqual(lhs.flags,rhs.flags);
}
if(Array.isArray(lhs)&&Array.isArray(rhs)){
if(lhs.length!==rhs.length)
return false;
for(var i=0;i<lhs.length;i++){
if(!isEqual(lhs[i],rhs[i])){
return false;
}
}
return true;
}
// if both are objects, compare each key recursively.
if(isObject(lhs)&&isObject(rhs)){
return Object.keys(lhs).every(function(key){
return isEqual(lhs[key],rhs[key]);
})&&
Object.keys(rhs).every(function(key){
return isEqual(lhs[key],rhs[key]);
});
}
return isRefEqual(lhs,rhs);
}
// Checks if a given value is not an empty string or null or undefined.
function isSpecified(val){
if(val===''){
return false;
}
return !isNullOrUndefined(val);
}
function isCallable(fn){
return typeof fn==='function';
}
function isLocator(value){
return isCallable(value)&&!!value.__locatorRef;
}

function findIndex(arrayLike,predicate){
var array=Array.isArray(arrayLike)?arrayLike:toArray(arrayLike);
if(isCallable(array.findIndex)){
return array.findIndex(predicate);
}
/* istanbul ignore next */
for(var i=0;i<array.length;i++){
if(predicate(array[i],i)){
return i;
}
}
/* istanbul ignore next */
return -1;
}
/**
 * finds the first element that satisfies the predicate callback, polyfills array.find
 */
function find(arrayLike,predicate){
var array=Array.isArray(arrayLike)?arrayLike:toArray(arrayLike);
var idx=findIndex(array,predicate);
return idx===-1?undefined:array[idx];
}
function includes(collection,item){
return collection.indexOf(item)!==-1;
}
/**
 * Converts an array-like object to array, provides a simple polyfill for Array.from
 */
function toArray(arrayLike){
if(isCallable(Array.from)){
return Array.from(arrayLike);
}
/* istanbul ignore next */
return _copyArray(arrayLike);
}
/* istanbul ignore next */
function _copyArray(arrayLike){
var array=[];
var length=arrayLike.length;
for(var i=0;i<length;i++){
array.push(arrayLike[i]);
}
return array;
}
function values(obj){
if(isCallable(Object.values)){
return Object.values(obj);
}
// fallback to keys()
/* istanbul ignore next */
return Object.keys(obj).map(function(k){return obj[k];});
}
function merge(target,source){
Object.keys(source).forEach(function(key){
if(isObject(source[key])){
if(!target[key]){
target[key]={};
}
merge(target[key],source[key]);
return;
}
target[key]=source[key];
});
return target;
}

function createFlags(){
return {
untouched:true,
touched:false,
dirty:false,
pristine:true,
valid:false,
invalid:false,
validated:false,
pending:false,
required:false,
changed:false,
passed:false,
failed:false};

}

function identity(x){
return x;
}
function debounce(fn,wait,token){
if(wait===void 0){wait=0;}
if(token===void 0){token={cancelled:false};}
if(wait===0){
return fn;
}
var timeout;
return function(){
var args=[];
for(var _i=0;_i<arguments.length;_i++){
args[_i]=arguments[_i];
}
var later=function later(){
timeout=undefined;
// check if the fn call was cancelled.
if(!token.cancelled)
fn.apply(void 0,args);
};
// because we might want to use Node.js setTimout for SSR.
clearTimeout(timeout);
timeout=setTimeout(later,wait);
};
}

/**
 * Emits a warning to the console
 */
function warn(message){
console.warn("[vee-validate] "+message);
}
/**
 * Replaces placeholder values in a string with their actual values
 */
function interpolate(template,values){
return template.replace(/{([^}]+)}/g,function(_,p){
return p in values?values[p]:"{"+p+"}";
});
}

var RULES={};
function normalizeSchema(schema){
var _a;
if((_a=schema.params)===null||_a===void 0?void 0:_a.length){
schema.params=schema.params.map(function(param){
if(typeof param==='string'){
return {name:param};
}
return param;
});
}
return schema;
}
var RuleContainer=/** @class */function(){
function RuleContainer(){
}
RuleContainer.extend=function(name,schema){
// if rule already exists, overwrite it.
var rule=normalizeSchema(schema);
if(RULES[name]){
RULES[name]=merge(RULES[name],schema);
return;
}
RULES[name]=_assign({lazy:false,computesRequired:false},rule);
};
RuleContainer.isLazy=function(name){
var _a;
return !!((_a=RULES[name])===null||_a===void 0?void 0:_a.lazy);
};
RuleContainer.isRequireRule=function(name){
var _a;
return !!((_a=RULES[name])===null||_a===void 0?void 0:_a.computesRequired);
};
RuleContainer.getRuleDefinition=function(ruleName){
return RULES[ruleName];
};
return RuleContainer;
}();
/**
 * Adds a custom validator to the list of validation rules.
 */
function extend(name,schema){
// makes sure new rules are properly formatted.
guardExtend(name,schema);
// Full schema object.
if(typeof schema==='object'){
RuleContainer.extend(name,schema);
return;
}
RuleContainer.extend(name,{
validate:schema});

}
/**
 * Guards from extension violations.
 */
function guardExtend(name,validator){
if(isCallable(validator)){
return;
}
if(isCallable(validator.validate)){
return;
}
if(RuleContainer.getRuleDefinition(name)){
return;
}
throw new Error("Extension Error: The validator '"+name+"' must be a function or have a 'validate' method.");
}

var DEFAULT_CONFIG={
defaultMessage:"{_field_} is not valid.",
skipOptional:true,
classes:{
touched:'touched',
untouched:'untouched',
valid:'valid',
invalid:'invalid',
pristine:'pristine',
dirty:'dirty'// control has been interacted with
},
bails:true,
mode:'aggressive',
useConstraintAttrs:true};

var currentConfig=_assign({},DEFAULT_CONFIG);
var getConfig=function getConfig(){return currentConfig;};
var setConfig=function setConfig(newConf){
currentConfig=_assign(_assign({},currentConfig),newConf);
};
var configure=function configure(cfg){
setConfig(cfg);
};

/**
 * Normalizes the given rules expression.
 */
function normalizeRules(rules){
// if falsy value return an empty object.
var acc={};
Object.defineProperty(acc,'_$$isNormalized',{
value:true,
writable:false,
enumerable:false,
configurable:false});

if(!rules){
return acc;
}
// Object is already normalized, skip.
if(isObject(rules)&&rules._$$isNormalized){
return rules;
}
if(isObject(rules)){
return Object.keys(rules).reduce(function(prev,curr){
var params=[];
if(rules[curr]===true){
params=[];
}else
if(Array.isArray(rules[curr])){
params=rules[curr];
}else
if(isObject(rules[curr])){
params=rules[curr];
}else
{
params=[rules[curr]];
}
if(rules[curr]!==false){
prev[curr]=buildParams(curr,params);
}
return prev;
},acc);
}
/* istanbul ignore if */
if(typeof rules!=='string'){
warn('rules must be either a string or an object.');
return acc;
}
return rules.split('|').reduce(function(prev,rule){
var parsedRule=parseRule(rule);
if(!parsedRule.name){
return prev;
}
prev[parsedRule.name]=buildParams(parsedRule.name,parsedRule.params);
return prev;
},acc);
}
function buildParams(ruleName,provided){
var ruleSchema=RuleContainer.getRuleDefinition(ruleName);
if(!ruleSchema){
return provided;
}
var params={};
if(!ruleSchema.params&&!Array.isArray(provided)){
throw new Error('You provided an object params to a rule that has no defined schema.');
}
// Rule probably uses an array for their args, keep it as is.
if(Array.isArray(provided)&&!ruleSchema.params){
return provided;
}
var definedParams;
// collect the params schema.
if(!ruleSchema.params||ruleSchema.params.length<provided.length&&Array.isArray(provided)){
var lastDefinedParam_1;
// collect any additional parameters in the last item.
definedParams=provided.map(function(_,idx){
var _a;
var param=(_a=ruleSchema.params)===null||_a===void 0?void 0:_a[idx];
lastDefinedParam_1=param||lastDefinedParam_1;
if(!param){
param=lastDefinedParam_1;
}
return param;
});
}else
{
definedParams=ruleSchema.params;
}
// Match the provided array length with a temporary schema.
for(var i=0;i<definedParams.length;i++){
var options=definedParams[i];
var value=options.default;
// if the provided is an array, map element value.
if(Array.isArray(provided)){
if(i in provided){
value=provided[i];
}
}else
{
// If the param exists in the provided object.
if(options.name in provided){
value=provided[options.name];
// if the provided is the first param value.
}else
if(definedParams.length===1){
value=provided;
}
}
// if the param is a target, resolve the target value.
if(options.isTarget){
value=createLocator(value,options.cast);
}
// A target param using interpolation
if(typeof value==='string'&&value[0]==='@'){
value=createLocator(value.slice(1),options.cast);
}
// If there is a transformer defined.
if(!isLocator(value)&&options.cast){
value=options.cast(value);
}
// already been set, probably multiple values.
if(params[options.name]){
params[options.name]=Array.isArray(params[options.name])?params[options.name]:[params[options.name]];
params[options.name].push(value);
}else
{
// set the value.
params[options.name]=value;
}
}
return params;
}
/**
 * Parses a rule string expression.
 */
var parseRule=function parseRule(rule){
var params=[];
var name=rule.split(':')[0];
if(includes(rule,':')){
params=rule.
split(':').
slice(1).
join(':').
split(',');
}
return {name:name,params:params};
};
function createLocator(value,castFn){
var locator=function locator(crossTable){
var val=crossTable[value];
return castFn?castFn(val):val;
};
locator.__locatorRef=value;
return locator;
}
function extractLocators(params){
if(Array.isArray(params)){
return params.filter(function(param){
return isLocator(param)||typeof param==='string'&&param[0]==='@';
});
}
return Object.keys(params).
filter(function(key){return isLocator(params[key]);}).
map(function(key){return params[key];});
}

/**
 * Validates a value against the rules.
 */
function validate(value,rules,options){
if(options===void 0){options={};}
return __awaiter(this,void 0,void 0,function(){
var shouldBail,skipIfEmpty,field,result,errors,failedRules,regenerateMap;
return __generator(this,function(_a){
switch(_a.label){
case 0:
shouldBail=options===null||options===void 0?void 0:options.bails;
skipIfEmpty=options===null||options===void 0?void 0:options.skipIfEmpty;
field={
name:(options===null||options===void 0?void 0:options.name)||'{field}',
rules:normalizeRules(rules),
bails:shouldBail!==null&&shouldBail!==void 0?shouldBail:true,
skipIfEmpty:skipIfEmpty!==null&&skipIfEmpty!==void 0?skipIfEmpty:true,
forceRequired:false,
crossTable:(options===null||options===void 0?void 0:options.values)||{},
names:(options===null||options===void 0?void 0:options.names)||{},
customMessages:(options===null||options===void 0?void 0:options.customMessages)||{}};

return [4/*yield*/,_validate(field,value,options)];
case 1:
result=_a.sent();
errors=[];
failedRules={};
regenerateMap={};
result.errors.forEach(function(e){
var msg=e.msg();
errors.push(msg);
failedRules[e.rule]=msg;
regenerateMap[e.rule]=e.msg;
});
return [2/*return*/,{
valid:result.valid,
errors:errors,
failedRules:failedRules,
regenerateMap:regenerateMap}];}


});
});
}
/**
 * Starts the validation process.
 */
function _validate(field,value,_a){
var _b=(_a===void 0?{}:_a).isInitial,isInitial=_b===void 0?false:_b;
return __awaiter(this,void 0,void 0,function(){
var _c,shouldSkip,errors,rules,length,i,rule,result;
return __generator(this,function(_d){
switch(_d.label){
case 0:return [4/*yield*/,_shouldSkip(field,value)];
case 1:
_c=_d.sent(),shouldSkip=_c.shouldSkip,errors=_c.errors;
if(shouldSkip){
return [2/*return*/,{
valid:!errors.length,
errors:errors}];

}
rules=Object.keys(field.rules).filter(function(rule){return !RuleContainer.isRequireRule(rule);});
length=rules.length;
i=0;
_d.label=2;
case 2:
if(!(i<length))return [3/*break*/,5];
if(isInitial&&RuleContainer.isLazy(rules[i])){
return [3/*break*/,4];
}
rule=rules[i];
return [4/*yield*/,_test(field,value,{
name:rule,
params:field.rules[rule]})];

case 3:
result=_d.sent();
if(!result.valid&&result.error){
errors.push(result.error);
if(field.bails){
return [2/*return*/,{
valid:false,
errors:errors}];

}
}
_d.label=4;
case 4:
i++;
return [3/*break*/,2];
case 5:return [2/*return*/,{
valid:!errors.length,
errors:errors}];}


});
});
}
function _shouldSkip(field,value){
return __awaiter(this,void 0,void 0,function(){
var requireRules,length,errors,isEmpty,isEmptyAndOptional,isRequired,i,rule,result;
return __generator(this,function(_a){
switch(_a.label){
case 0:
requireRules=Object.keys(field.rules).filter(RuleContainer.isRequireRule);
length=requireRules.length;
errors=[];
isEmpty=isNullOrUndefined(value)||value===''||isEmptyArray(value);
isEmptyAndOptional=isEmpty&&field.skipIfEmpty;
isRequired=false;
i=0;
_a.label=1;
case 1:
if(!(i<length))return [3/*break*/,4];
rule=requireRules[i];
return [4/*yield*/,_test(field,value,{
name:rule,
params:field.rules[rule]})];

case 2:
result=_a.sent();
if(!isObject(result)){
throw new Error('Require rules has to return an object (see docs)');
}
if(result.required){
isRequired=true;
}
if(!result.valid&&result.error){
errors.push(result.error);
// Exit early as the field is required and failed validation.
if(field.bails){
return [2/*return*/,{
shouldSkip:true,
errors:errors}];

}
}
_a.label=3;
case 3:
i++;
return [3/*break*/,1];
case 4:
if(isEmpty&&!isRequired&&!field.skipIfEmpty){
return [2/*return*/,{
shouldSkip:false,
errors:errors}];

}
// field is configured to run through the pipeline regardless
if(!field.bails&&!isEmptyAndOptional){
return [2/*return*/,{
shouldSkip:false,
errors:errors}];

}
// skip if the field is not required and has an empty value.
return [2/*return*/,{
shouldSkip:!isRequired&&isEmpty,
errors:errors}];}


});
});
}
/**
 * Tests a single input value against a rule.
 */
function _test(field,value,rule){
return __awaiter(this,void 0,void 0,function(){
var ruleSchema,normalizedValue,params,result,values_1;
return __generator(this,function(_a){
switch(_a.label){
case 0:
ruleSchema=RuleContainer.getRuleDefinition(rule.name);
if(!ruleSchema||!ruleSchema.validate){
throw new Error("No such validator '"+rule.name+"' exists.");
}
normalizedValue=ruleSchema.castValue?ruleSchema.castValue(value):value;
params=fillTargetValues(rule.params,field.crossTable);
return [4/*yield*/,ruleSchema.validate(normalizedValue,params)];
case 1:
result=_a.sent();
if(typeof result==='string'){
values_1=_assign(_assign({},params||{}),{_field_:field.name,_value_:value,_rule_:rule.name});
return [2/*return*/,{
valid:false,
error:{rule:rule.name,msg:function msg(){return interpolate(result,values_1);}}}];

}
if(!isObject(result)){
result={valid:result};
}
return [2/*return*/,{
valid:result.valid,
required:result.required,
error:result.valid?undefined:_generateFieldError(field,value,ruleSchema,rule.name,params)}];}


});
});
}
/**
 * Generates error messages.
 */
function _generateFieldError(field,value,ruleSchema,ruleName,params){
var _a;
var message=(_a=field.customMessages[ruleName])!==null&&_a!==void 0?_a:ruleSchema.message;
var ruleTargets=_getRuleTargets(field,ruleSchema,ruleName);
var _b=_getUserTargets(field,ruleSchema,ruleName,message),userTargets=_b.userTargets,userMessage=_b.userMessage;
var values=_assign(_assign(_assign(_assign({},params||{}),{_field_:field.name,_value_:value,_rule_:ruleName}),ruleTargets),userTargets);
return {
msg:function msg(){return _normalizeMessage(userMessage||getConfig().defaultMessage,field.name,values);},
rule:ruleName};

}
function _getRuleTargets(field,ruleSchema,ruleName){
var params=ruleSchema.params;
if(!params){
return {};
}
var numTargets=params.filter(function(param){return param.isTarget;}).length;
if(numTargets<=0){
return {};
}
var names={};
var ruleConfig=field.rules[ruleName];
if(!Array.isArray(ruleConfig)&&isObject(ruleConfig)){
ruleConfig=params.map(function(param){
return ruleConfig[param.name];
});
}
for(var index=0;index<params.length;index++){
var param=params[index];
var key=ruleConfig[index];
if(!isLocator(key)){
continue;
}
key=key.__locatorRef;
var name_1=field.names[key]||key;
names[param.name]=name_1;
names["_"+param.name+"_"]=field.crossTable[key];
}
return names;
}
function _getUserTargets(field,ruleSchema,ruleName,userMessage){
var userTargets={};
var rules=field.rules[ruleName];
var params=ruleSchema.params||[];
// early return if no rules
if(!rules){
return {};
}
// check all rules to convert targets
Object.keys(rules).forEach(function(key,index){
// get the rule
var rule=rules[key];
if(!isLocator(rule)){
return {};
}
// get associated parameter
var param=params[index];
if(!param){
return {};
}
// grab the name of the target
var name=rule.__locatorRef;
userTargets[param.name]=field.names[name]||name;
userTargets["_"+param.name+"_"]=field.crossTable[name];
});
return {
userTargets:userTargets,
userMessage:userMessage};

}
function _normalizeMessage(template,field,values){
if(typeof template==='function'){
return template(field,values);
}
return interpolate(template,_assign(_assign({},values),{_field_:field}));
}
function fillTargetValues(params,crossTable){
if(Array.isArray(params)){
return params.map(function(param){
var targetPart=typeof param==='string'&&param[0]==='@'?param.slice(1):param;
if(targetPart in crossTable){
return crossTable[targetPart];
}
return param;
});
}
var values={};
var normalize=function normalize(value){
if(isLocator(value)){
return value(crossTable);
}
return value;
};
Object.keys(params).forEach(function(param){
values[param]=normalize(params[param]);
});
return values;
}

var aggressive=function aggressive(){return {
on:['input','blur']};
};
var lazy=function lazy(){return {
on:['change','blur']};
};
var eager=function eager(_a){
var errors=_a.errors;
if(errors.length){
return {
on:['input','change']};

}
return {
on:['change','blur']};

};
var passive=function passive(){return {
on:[]};
};
var modes={
aggressive:aggressive,
eager:eager,
passive:passive,
lazy:lazy};

var setInteractionMode=function setInteractionMode(mode,implementation){
setConfig({mode:mode});
if(!implementation){
return;
}
if(!isCallable(implementation)){
throw new Error('A mode implementation must be a function');
}
modes[mode]=implementation;
};

var EVENT_BUS=new vue__WEBPACK_IMPORTED_MODULE_0___default.a();
function localeChanged(){
EVENT_BUS.$emit('change:locale');
}

var Dictionary=/** @class */function(){
function Dictionary(locale,dictionary){
this.container={};
this.locale=locale;
this.merge(dictionary);
}
Dictionary.prototype.resolve=function(field,rule,values){
return this.format(this.locale,field,rule,values);
};
Dictionary.prototype.format=function(locale,field,rule,values){
var _a,_b,_c,_d,_e,_f,_g,_h;
var message;
// find if specific message for that field was specified.
var fieldContainer=(_c=(_b=(_a=this.container[locale])===null||_a===void 0?void 0:_a.fields)===null||_b===void 0?void 0:_b[field])===null||_c===void 0?void 0:_c[rule];
var messageContainer=(_e=(_d=this.container[locale])===null||_d===void 0?void 0:_d.messages)===null||_e===void 0?void 0:_e[rule];
message=fieldContainer||messageContainer||'';
if(!message){
message='{_field_} is not valid';
}
field=(_h=(_g=(_f=this.container[locale])===null||_f===void 0?void 0:_f.names)===null||_g===void 0?void 0:_g[field])!==null&&_h!==void 0?_h:field;
return isCallable(message)?message(field,values):interpolate(message,_assign(_assign({},values),{_field_:field}));
};
Dictionary.prototype.merge=function(dictionary){
merge(this.container,dictionary);
};
Dictionary.prototype.hasRule=function(name){
var _a,_b;
return !!((_b=(_a=this.container[this.locale])===null||_a===void 0?void 0:_a.messages)===null||_b===void 0?void 0:_b[name]);
};
return Dictionary;
}();
var DICTIONARY;
function localize(locale,dictionary){
var _a;
if(!DICTIONARY){
DICTIONARY=new Dictionary('en',{});
setConfig({
defaultMessage:function defaultMessage(field,values){
return DICTIONARY.resolve(field,values===null||values===void 0?void 0:values._rule_,values||{});
}});

}
if(typeof locale==='string'){
DICTIONARY.locale=locale;
if(dictionary){
DICTIONARY.merge((_a={},_a[locale]=dictionary,_a));
}
localeChanged();
return;
}
DICTIONARY.merge(locale);
}

var isEvent=function isEvent(evt){
if(!evt){
return false;
}
if(typeof Event!=='undefined'&&isCallable(Event)&&evt instanceof Event){
return true;
}
// this is for IE
/* istanbul ignore next */
if(evt&&evt.srcElement){
return true;
}
return false;
};
function normalizeEventValue(value){
var _a,_b;
if(!isEvent(value)){
return value;
}
var input=value.target;
if(input.type==='file'&&input.files){
return toArray(input.files);
}
// If the input has a `v-model.number` modifier applied.
if((_a=input._vModifiers)===null||_a===void 0?void 0:_a.number){
// as per the spec the v-model.number uses parseFloat
var valueAsNumber=parseFloat(input.value);
if(isNaN(valueAsNumber)){
return input.value;
}
return valueAsNumber;
}
if((_b=input._vModifiers)===null||_b===void 0?void 0:_b.trim){
var trimmedValue=typeof input.value==='string'?input.value.trim():input.value;
return trimmedValue;
}
return input.value;
}

var isTextInput=function isTextInput(vnode){
var _a;
var attrs=((_a=vnode.data)===null||_a===void 0?void 0:_a.attrs)||vnode.elm;
// it will fallback to being a text input per browsers spec.
if(vnode.tag==='input'&&(!attrs||!attrs.type)){
return true;
}
if(vnode.tag==='textarea'){
return true;
}
return includes(['text','password','search','email','tel','url','number'],attrs===null||attrs===void 0?void 0:attrs.type);
};
// export const isCheckboxOrRadioInput = (vnode: VNode): boolean => {
//   const attrs = (vnode.data && vnode.data.attrs) || vnode.elm;
//   return includes(['radio', 'checkbox'], attrs && attrs.type);
// };
// Gets the model object on the vnode.
function findModel(vnode){
if(!vnode.data){
return undefined;
}
// Component Model
// THIS IS NOT TYPED IN OFFICIAL VUE TYPINGS
// eslint-disable-next-line
var nonStandardVNodeData=vnode.data;
if('model'in nonStandardVNodeData){
return nonStandardVNodeData.model;
}
if(!vnode.data.directives){
return undefined;
}
return find(vnode.data.directives,function(d){return d.name==='model';});
}
function findValue(vnode){
var _a,_b;
var model=findModel(vnode);
if(model){
return {value:model.value};
}
var config=findModelConfig(vnode);
var prop=(config===null||config===void 0?void 0:config.prop)||'value';
if(((_a=vnode.componentOptions)===null||_a===void 0?void 0:_a.propsData)&&prop in vnode.componentOptions.propsData){
var propsDataWithValue=vnode.componentOptions.propsData;
return {value:propsDataWithValue[prop]};
}
if(((_b=vnode.data)===null||_b===void 0?void 0:_b.domProps)&&'value'in vnode.data.domProps){
return {value:vnode.data.domProps.value};
}
return undefined;
}
function extractChildren(vnode){
if(Array.isArray(vnode)){
return vnode;
}
if(Array.isArray(vnode.children)){
return vnode.children;
}
/* istanbul ignore next */
if(vnode.componentOptions&&Array.isArray(vnode.componentOptions.children)){
return vnode.componentOptions.children;
}
return [];
}
function findInputNodes(vnode){
if(!Array.isArray(vnode)&&findValue(vnode)!==undefined){
return [vnode];
}
var children=extractChildren(vnode);
return children.reduce(function(nodes,node){
var candidates=findInputNodes(node);
if(candidates.length){
nodes.push.apply(nodes,candidates);
}
return nodes;
},[]);
}
// Resolves v-model config if exists.
function findModelConfig(vnode){
/* istanbul ignore next */
if(!vnode.componentOptions)
return null;
// This is also not typed in the standard Vue TS.
return vnode.componentOptions.Ctor.options.model;
}
// Adds a listener to vnode listener object.
function mergeVNodeListeners(obj,eventName,handler){
// no listener at all.
if(isNullOrUndefined(obj[eventName])){
obj[eventName]=[handler];
return;
}
// Is an invoker.
if(isCallable(obj[eventName])&&obj[eventName].fns){
var invoker=obj[eventName];
invoker.fns=Array.isArray(invoker.fns)?invoker.fns:[invoker.fns];
if(!includes(invoker.fns,handler)){
invoker.fns.push(handler);
}
return;
}
if(isCallable(obj[eventName])){
var prev=obj[eventName];
obj[eventName]=[prev];
}
if(Array.isArray(obj[eventName])&&!includes(obj[eventName],handler)){
obj[eventName].push(handler);
}
}
// Adds a listener to a native HTML vnode.
function addNativeNodeListener(node,eventName,handler){
/* istanbul ignore next */
if(!node.data){
node.data={};
}
if(isNullOrUndefined(node.data.on)){
node.data.on={};
}
mergeVNodeListeners(node.data.on,eventName,handler);
}
// Adds a listener to a Vue component vnode.
function addComponentNodeListener(node,eventName,handler){
/* istanbul ignore next */
if(!node.componentOptions){
return;
}
/* istanbul ignore next */
if(!node.componentOptions.listeners){
node.componentOptions.listeners={};
}
mergeVNodeListeners(node.componentOptions.listeners,eventName,handler);
}
function addVNodeListener(vnode,eventName,handler){
if(vnode.componentOptions){
addComponentNodeListener(vnode,eventName,handler);
return;
}
addNativeNodeListener(vnode,eventName,handler);
}
// Determines if `change` should be used over `input` for listeners.
function getInputEventName(vnode,model){
var _a;
// Is a component.
if(vnode.componentOptions){
var event_1=(findModelConfig(vnode)||{event:'input'}).event;
return event_1;
}
// Lazy Models typically use change event
if((_a=model===null||model===void 0?void 0:model.modifiers)===null||_a===void 0?void 0:_a.lazy){
return 'change';
}
// is a textual-type input.
if(isTextInput(vnode)){
return 'input';
}
return 'change';
}
function isHTMLNode(node){
return includes(['input','select','textarea'],node.tag);
}
// TODO: Type this one properly.
function normalizeSlots(slots,ctx){
var acc=[];
return Object.keys(slots).reduce(function(arr,key){
slots[key].forEach(function(vnode){
if(!vnode.context){
slots[key].context=ctx;
if(!vnode.data){
vnode.data={};
}
vnode.data.slot=key;
}
});
return arr.concat(slots[key]);
},acc);
}
function resolveTextualRules(vnode){
var _a;
var attrs=(_a=vnode.data)===null||_a===void 0?void 0:_a.attrs;
var rules={};
if(!attrs)
return rules;
if(attrs.type==='email'&&RuleContainer.getRuleDefinition('email')){
rules.email=['multiple'in attrs];
}
if(attrs.pattern&&RuleContainer.getRuleDefinition('regex')){
rules.regex=attrs.pattern;
}
if(attrs.maxlength>=0&&RuleContainer.getRuleDefinition('max')){
rules.max=attrs.maxlength;
}
if(attrs.minlength>=0&&RuleContainer.getRuleDefinition('min')){
rules.min=attrs.minlength;
}
if(attrs.type==='number'){
if(isSpecified(attrs.min)&&RuleContainer.getRuleDefinition('min_value')){
rules.min_value=Number(attrs.min);
}
if(isSpecified(attrs.max)&&RuleContainer.getRuleDefinition('max_value')){
rules.max_value=Number(attrs.max);
}
}
return rules;
}
function resolveRules(vnode){
var _a;
var htmlTags=['input','select','textarea'];
var attrs=(_a=vnode.data)===null||_a===void 0?void 0:_a.attrs;
if(!includes(htmlTags,vnode.tag)||!attrs){
return {};
}
var rules={};
if('required'in attrs&&attrs.required!==false&&RuleContainer.getRuleDefinition('required')){
rules.required=attrs.type==='checkbox'?[true]:true;
}
if(isTextInput(vnode)){
return normalizeRules(_assign(_assign({},rules),resolveTextualRules(vnode)));
}
return normalizeRules(rules);
}
function normalizeChildren(context,slotProps){
if(context.$scopedSlots.default){
return context.$scopedSlots.default(slotProps)||[];
}
return context.$slots.default||[];
}

/**
 * Determines if a provider needs to run validation.
 */
function shouldValidate(ctx,value){
// when an immediate/initial validation is needed and wasn't done before.
if(!ctx._ignoreImmediate&&ctx.immediate){
return true;
}
// when the value changes for whatever reason.
if(!isRefEqual(ctx.value,value)&&ctx.normalizedEvents.length){
return true;
}
// when it needs validation due to props/cross-fields changes.
if(ctx._needsValidation){
return true;
}
// when the initial value is undefined and the field wasn't rendered yet.
if(!ctx.initialized&&value===undefined){
return true;
}
return false;
}
function createValidationCtx(ctx){
return _assign(_assign({},ctx.flags),{errors:ctx.errors,classes:ctx.classes,failedRules:ctx.failedRules,reset:function reset(){return ctx.reset();},validate:function validate(){
var args=[];
for(var _i=0;_i<arguments.length;_i++){
args[_i]=arguments[_i];
}
return ctx.validate.apply(ctx,args);
},ariaInput:{
'aria-invalid':ctx.flags.invalid?'true':'false',
'aria-required':ctx.isRequired?'true':'false',
'aria-errormessage':"vee_"+ctx.id},
ariaMsg:{
id:"vee_"+ctx.id,
'aria-live':ctx.errors.length?'assertive':'off'}});

}
function onRenderUpdate(vm,value){
if(!vm.initialized){
vm.initialValue=value;
}
var validateNow=shouldValidate(vm,value);
vm._needsValidation=false;
vm.value=value;
vm._ignoreImmediate=true;
if(!validateNow){
return;
}
var validate=function validate(){
if(vm.immediate||vm.flags.validated){
return triggerThreadSafeValidation(vm);
}
vm.validateSilent();
};
if(vm.initialized){
validate();
return;
}
vm.$once('hook:mounted',function(){return validate();});
}
function computeModeSetting(ctx){
var compute=isCallable(ctx.mode)?ctx.mode:modes[ctx.mode];
return compute(ctx);
}
function triggerThreadSafeValidation(vm){
var pendingPromise=vm.validateSilent();
// avoids race conditions between successive validations.
vm._pendingValidation=pendingPromise;
return pendingPromise.then(function(result){
if(pendingPromise===vm._pendingValidation){
vm.applyResult(result);
vm._pendingValidation=undefined;
}
return result;
});
}
// Creates the common handlers for a validatable context.
function createCommonHandlers(vm){
if(!vm.$veeOnInput){
vm.$veeOnInput=function(e){
vm.syncValue(e);// track and keep the value updated.
vm.setFlags({dirty:true,pristine:false});
};
}
var onInput=vm.$veeOnInput;
if(!vm.$veeOnBlur){
vm.$veeOnBlur=function(){
vm.setFlags({touched:true,untouched:false});
};
}
// Blur event listener.
var onBlur=vm.$veeOnBlur;
var onValidate=vm.$veeHandler;
var mode=computeModeSetting(vm);
// Handle debounce changes.
if(!onValidate||vm.$veeDebounce!==vm.debounce){
onValidate=debounce(function(){
vm.$nextTick(function(){
if(!vm._pendingReset){
triggerThreadSafeValidation(vm);
}
vm._pendingReset=false;
});
},mode.debounce||vm.debounce);
// Cache the handler so we don't create it each time.
vm.$veeHandler=onValidate;
// cache the debounce value so we detect if it was changed.
vm.$veeDebounce=vm.debounce;
}
return {onInput:onInput,onBlur:onBlur,onValidate:onValidate};
}
// Adds all plugin listeners to the vnode.
function addListeners(vm,node){
var value=findValue(node);
// cache the input eventName.
vm._inputEventName=vm._inputEventName||getInputEventName(node,findModel(node));
onRenderUpdate(vm,value===null||value===void 0?void 0:value.value);
var _a=createCommonHandlers(vm),onInput=_a.onInput,onBlur=_a.onBlur,onValidate=_a.onValidate;
addVNodeListener(node,vm._inputEventName,onInput);
addVNodeListener(node,'blur',onBlur);
// add the validation listeners.
vm.normalizedEvents.forEach(function(evt){
addVNodeListener(node,evt,onValidate);
});
vm.initialized=true;
}

var PROVIDER_COUNTER=0;
function data(){
var errors=[];
var fieldName='';
var defaultValues={
errors:errors,
value:undefined,
initialized:false,
initialValue:undefined,
flags:createFlags(),
failedRules:{},
isActive:true,
fieldName:fieldName,
id:''};

return defaultValues;
}
var ValidationProvider=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
inject:{
$_veeObserver:{
from:'$_veeObserver',
default:function _default(){
if(!this.$vnode.context.$_veeObserver){
this.$vnode.context.$_veeObserver=createObserver();
}
return this.$vnode.context.$_veeObserver;
}}},


props:{
vid:{
type:String,
default:''},

name:{
type:String,
default:null},

mode:{
type:[String,Function],
default:function _default(){
return getConfig().mode;
}},

rules:{
type:[Object,String],
default:null},

immediate:{
type:Boolean,
default:false},

bails:{
type:Boolean,
default:function _default(){return getConfig().bails;}},

skipIfEmpty:{
type:Boolean,
default:function _default(){return getConfig().skipOptional;}},

debounce:{
type:Number,
default:0},

tag:{
type:String,
default:'span'},

slim:{
type:Boolean,
default:false},

disabled:{
type:Boolean,
default:false},

customMessages:{
type:Object,
default:function _default(){
return {};
}},

detectInput:{
type:Boolean,
default:true}},


watch:{
rules:{
deep:true,
handler:function handler(val,oldVal){
this._needsValidation=!isEqual(val,oldVal);
}}},


data:data,
computed:{
fieldDeps:function fieldDeps(){
var _this=this;
return Object.keys(this.normalizedRules).reduce(function(acc,rule){
var deps=extractLocators(_this.normalizedRules[rule]).map(function(dep){
return isLocator(dep)?dep.__locatorRef:dep.slice(1);
});
acc.push.apply(acc,deps);
deps.forEach(function(depName){
watchCrossFieldDep(_this,depName);
});
return acc;
},[]);
},
normalizedEvents:function normalizedEvents(){
var _this=this;
var on=computeModeSetting(this).on;
return (on||[]).map(function(e){
if(e==='input'){
return _this._inputEventName;
}
return e;
});
},
isRequired:function isRequired(){
var rules=_assign(_assign({},this._resolvedRules),this.normalizedRules);
var isRequired=Object.keys(rules).some(RuleContainer.isRequireRule);
this.flags.required=!!isRequired;
return isRequired;
},
classes:function classes(){
var names=getConfig().classes;
return computeClassObj(names,this.flags);
},
normalizedRules:function normalizedRules(){
return normalizeRules(this.rules);
}},

mounted:function mounted(){
var _this=this;
var onLocaleChanged=function onLocaleChanged(){
if(!_this.flags.validated){
return;
}
var regenerateMap=_this._regenerateMap;
if(regenerateMap){
var errors_1=[];
var failedRules_1={};
Object.keys(regenerateMap).forEach(function(rule){
var msg=regenerateMap[rule]();
errors_1.push(msg);
failedRules_1[rule]=msg;
});
_this.applyResult({errors:errors_1,failedRules:failedRules_1,regenerateMap:regenerateMap});
return;
}
_this.validate();
};
EVENT_BUS.$on('change:locale',onLocaleChanged);
this.$on('hook:beforeDestroy',function(){
EVENT_BUS.$off('change:locale',onLocaleChanged);
});
},
render:function render(h){
var _this=this;
this.registerField();
var ctx=createValidationCtx(this);
var children=normalizeChildren(this,ctx);
// Automatic v-model detection
if(this.detectInput){
var inputs=findInputNodes(children);
if(inputs.length){
inputs.forEach(function(input,idx){
var _a,_b,_c,_d,_e,_f;
// If the elements are not checkboxes and there are more input nodes
if(!includes(['checkbox','radio'],(_b=(_a=input.data)===null||_a===void 0?void 0:_a.attrs)===null||_b===void 0?void 0:_b.type)&&idx>0){
return;
}
var resolved=getConfig().useConstraintAttrs?resolveRules(input):{};
if(!isEqual(_this._resolvedRules,resolved)){
_this._needsValidation=true;
}
if(isHTMLNode(input)){
_this.fieldName=((_d=(_c=input.data)===null||_c===void 0?void 0:_c.attrs)===null||_d===void 0?void 0:_d.name)||((_f=(_e=input.data)===null||_e===void 0?void 0:_e.attrs)===null||_f===void 0?void 0:_f.id);
}
_this._resolvedRules=resolved;
addListeners(_this,input);
});
}
}
return this.slim&&children.length<=1?children[0]:h(this.tag,children);
},
beforeDestroy:function beforeDestroy(){
// cleanup reference.
this.$_veeObserver.unobserve(this.id);
},
activated:function activated(){
this.isActive=true;
},
deactivated:function deactivated(){
this.isActive=false;
},
methods:{
setFlags:function setFlags(flags){
var _this=this;
Object.keys(flags).forEach(function(flag){
_this.flags[flag]=flags[flag];
});
},
syncValue:function syncValue(v){
var value=normalizeEventValue(v);
this.value=value;
this.flags.changed=this.initialValue!==value;
},
reset:function reset(){
var _this=this;
this.errors=[];
this.initialValue=this.value;
var flags=createFlags();
flags.required=this.isRequired;
this.setFlags(flags);
this.failedRules={};
this.validateSilent();
this._pendingValidation=undefined;
this._pendingReset=true;
setTimeout(function(){
_this._pendingReset=false;
},this.debounce);
},
validate:function validate(){
var args=[];
for(var _i=0;_i<arguments.length;_i++){
args[_i]=arguments[_i];
}
return __awaiter(this,void 0,void 0,function(){
return __generator(this,function(_a){
if(args.length>0){
this.syncValue(args[0]);
}
return [2/*return*/,triggerThreadSafeValidation(this)];
});
});
},
validateSilent:function validateSilent(){
return __awaiter(this,void 0,void 0,function(){
var rules,result;
return __generator(this,function(_a){
switch(_a.label){
case 0:
this.setFlags({pending:true});
rules=_assign(_assign({},this._resolvedRules),this.normalizedRules);
Object.defineProperty(rules,'_$$isNormalized',{
value:true,
writable:false,
enumerable:false,
configurable:false});

return [4/*yield*/,validate(this.value,rules,_assign(_assign({name:this.name||this.fieldName},createLookup(this)),{bails:this.bails,skipIfEmpty:this.skipIfEmpty,isInitial:!this.initialized,customMessages:this.customMessages}))];
case 1:
result=_a.sent();
this.setFlags({
pending:false,
valid:result.valid,
invalid:!result.valid});

return [2/*return*/,result];}

});
});
},
setErrors:function setErrors(errors){
this.applyResult({errors:errors,failedRules:{}});
},
applyResult:function applyResult(_a){
var errors=_a.errors,failedRules=_a.failedRules,regenerateMap=_a.regenerateMap;
this.errors=errors;
this._regenerateMap=regenerateMap;
this.failedRules=_assign({},failedRules||{});
this.setFlags({
valid:!errors.length,
passed:!errors.length,
invalid:!!errors.length,
failed:!!errors.length,
validated:true,
changed:this.value!==this.initialValue});

},
registerField:function registerField(){
updateRenderingContextRefs(this);
}}});


function computeClassObj(names,flags){
var acc={};
var keys=Object.keys(flags);
var length=keys.length;
var _loop_1=function _loop_1(i){
var flag=keys[i];
var className=names&&names[flag]||flag;
var value=flags[flag];
if(isNullOrUndefined(value)){
return "continue";
}
if((flag==='valid'||flag==='invalid')&&!flags.validated){
return "continue";
}
if(typeof className==='string'){
acc[className]=value;
}else
if(Array.isArray(className)){
className.forEach(function(cls){
acc[cls]=value;
});
}
};
for(var i=0;i<length;i++){
_loop_1(i);
}
return acc;
}
function createLookup(vm){
var providers=vm.$_veeObserver.refs;
var reduced={
names:{},
values:{}};

return vm.fieldDeps.reduce(function(acc,depName){
if(!providers[depName]){
return acc;
}
acc.values[depName]=providers[depName].value;
acc.names[depName]=providers[depName].name;
return acc;
},reduced);
}
function extractId(vm){
if(vm.vid){
return vm.vid;
}
if(vm.name){
return vm.name;
}
if(vm.id){
return vm.id;
}
if(vm.fieldName){
return vm.fieldName;
}
PROVIDER_COUNTER++;
return "_vee_"+PROVIDER_COUNTER;
}
function updateRenderingContextRefs(vm){
var providedId=extractId(vm);
var id=vm.id;
// Nothing has changed.
if(!vm.isActive||id===providedId&&vm.$_veeObserver.refs[id]){
return;
}
// vid was changed.
if(id!==providedId&&vm.$_veeObserver.refs[id]===vm){
vm.$_veeObserver.unobserve(id);
}
vm.id=providedId;
vm.$_veeObserver.observe(vm);
}
function createObserver(){
return {
refs:{},
observe:function observe(vm){
this.refs[vm.id]=vm;
},
unobserve:function unobserve(id){
delete this.refs[id];
}};

}
function watchCrossFieldDep(ctx,depName,withHooks){
if(withHooks===void 0){withHooks=true;}
var providers=ctx.$_veeObserver.refs;
if(!ctx._veeWatchers){
ctx._veeWatchers={};
}
if(!providers[depName]&&withHooks){
return ctx.$once('hook:mounted',function(){
watchCrossFieldDep(ctx,depName,false);
});
}
if(!isCallable(ctx._veeWatchers[depName])&&providers[depName]){
ctx._veeWatchers[depName]=providers[depName].$watch('value',function(){
if(ctx.flags.validated){
ctx._needsValidation=true;
ctx.validate();
}
});
}
}

var FLAGS_STRATEGIES=[
['pristine','every'],
['dirty','some'],
['touched','some'],
['untouched','every'],
['valid','every'],
['invalid','some'],
['pending','some'],
['validated','every'],
['changed','some'],
['passed','every'],
['failed','some']];

var OBSERVER_COUNTER=0;
function data$1(){
var refs={};
var errors={};
var flags=createObserverFlags();
var fields={};
// FIXME: Not sure of this one can be typed, circular type reference.
var observers=[];
return {
id:'',
refs:refs,
observers:observers,
errors:errors,
flags:flags,
fields:fields};

}
function provideSelf(){
return {
$_veeObserver:this};

}
var ValidationObserver=vue__WEBPACK_IMPORTED_MODULE_0___default.a.extend({
name:'ValidationObserver',
provide:provideSelf,
inject:{
$_veeObserver:{
from:'$_veeObserver',
default:function _default(){
if(!this.$vnode.context.$_veeObserver){
return null;
}
return this.$vnode.context.$_veeObserver;
}}},


props:{
tag:{
type:String,
default:'span'},

vid:{
type:String,
default:function _default(){
return "obs_"+OBSERVER_COUNTER++;
}},

slim:{
type:Boolean,
default:false},

disabled:{
type:Boolean,
default:false}},


data:data$1,
created:function created(){
var _this=this;
this.id=this.vid;
register(this);
var onChange=debounce(function(_a){
var errors=_a.errors,flags=_a.flags,fields=_a.fields;
_this.errors=errors;
_this.flags=flags;
_this.fields=fields;
},16);
this.$watch(computeObserverState,onChange);
},
activated:function activated(){
register(this);
},
deactivated:function deactivated(){
unregister(this);
},
beforeDestroy:function beforeDestroy(){
unregister(this);
},
render:function render(h){
var children=normalizeChildren(this,prepareSlotProps(this));
return this.slim&&children.length<=1?children[0]:h(this.tag,{on:this.$listeners},children);
},
methods:{
observe:function observe(subscriber,kind){
var _a;
if(kind===void 0){kind='provider';}
if(kind==='observer'){
this.observers.push(subscriber);
return;
}
this.refs=_assign(_assign({},this.refs),(_a={},_a[subscriber.id]=subscriber,_a));
},
unobserve:function unobserve(id,kind){
if(kind===void 0){kind='provider';}
if(kind==='provider'){
var provider=this.refs[id];
if(!provider){
return;
}
this.$delete(this.refs,id);
return;
}
var idx=findIndex(this.observers,function(o){return o.id===id;});
if(idx!==-1){
this.observers.splice(idx,1);
}
},
validateWithInfo:function validateWithInfo(_a){
var _b=(_a===void 0?{}:_a).silent,silent=_b===void 0?false:_b;
return __awaiter(this,void 0,void 0,function(){
var results,isValid,_c,errors,flags,fields;
return __generator(this,function(_d){
switch(_d.label){
case 0:return [4/*yield*/,Promise.all(__spreadArrays(values(this.refs).
filter(function(r){return !r.disabled;}).
map(function(ref){return ref[silent?'validateSilent':'validate']().then(function(r){return r.valid;});}),this.observers.filter(function(o){return !o.disabled;}).map(function(obs){return obs.validate({silent:silent});})))];
case 1:
results=_d.sent();
isValid=results.every(function(r){return r;});
_c=computeObserverState.call(this),errors=_c.errors,flags=_c.flags,fields=_c.fields;
this.errors=errors;
this.flags=flags;
this.fields=fields;
return [2/*return*/,{
errors:errors,
flags:flags,
fields:fields,
isValid:isValid}];}


});
});
},
validate:function validate(_a){
var _b=(_a===void 0?{}:_a).silent,silent=_b===void 0?false:_b;
return __awaiter(this,void 0,void 0,function(){
var isValid;
return __generator(this,function(_c){
switch(_c.label){
case 0:return [4/*yield*/,this.validateWithInfo({silent:silent})];
case 1:
isValid=_c.sent().isValid;
return [2/*return*/,isValid];}

});
});
},
handleSubmit:function handleSubmit(cb){
return __awaiter(this,void 0,void 0,function(){
var isValid;
return __generator(this,function(_a){
switch(_a.label){
case 0:return [4/*yield*/,this.validate()];
case 1:
isValid=_a.sent();
if(!isValid||!cb){
return [2/*return*/];
}
return [2/*return*/,cb()];}

});
});
},
reset:function reset(){
return __spreadArrays(values(this.refs),this.observers).forEach(function(ref){return ref.reset();});
},
setErrors:function setErrors(errors){
var _this=this;
Object.keys(errors).forEach(function(key){
var provider=_this.refs[key];
if(!provider)
return;
var errorArr=errors[key]||[];
errorArr=typeof errorArr==='string'?[errorArr]:errorArr;
provider.setErrors(errorArr);
});
this.observers.forEach(function(observer){
observer.setErrors(errors);
});
}}});


function unregister(vm){
if(vm.$_veeObserver){
vm.$_veeObserver.unobserve(vm.id,'observer');
}
}
function register(vm){
if(vm.$_veeObserver){
vm.$_veeObserver.observe(vm,'observer');
}
}
function prepareSlotProps(vm){
return _assign(_assign({},vm.flags),{errors:vm.errors,fields:vm.fields,validate:vm.validate,validateWithInfo:vm.validateWithInfo,passes:vm.handleSubmit,handleSubmit:vm.handleSubmit,reset:vm.reset});
}
// Creates a modified version of validation flags
function createObserverFlags(){
return _assign(_assign({},createFlags()),{valid:true,invalid:false});
}
function computeObserverState(){
var vms=__spreadArrays(values(this.refs),this.observers.filter(function(o){return !o.disabled;}));
var errors={};
var flags=createObserverFlags();
var fields={};
var length=vms.length;
for(var i=0;i<length;i++){
var vm=vms[i];
// validation provider
if(Array.isArray(vm.errors)){
errors[vm.id]=vm.errors;
fields[vm.id]=_assign({id:vm.id,name:vm.name,failedRules:vm.failedRules},vm.flags);
continue;
}
// Nested observer, merge errors and fields
errors=_assign(_assign({},errors),vm.errors);
fields=_assign(_assign({},fields),vm.fields);
}
FLAGS_STRATEGIES.forEach(function(_a){
var flag=_a[0],method=_a[1];
flags[flag]=vms[method](function(vm){return vm.flags[flag];});
});
return {errors:errors,flags:flags,fields:fields};
}

function withValidation(component,mapProps){
var _a;
if(mapProps===void 0){mapProps=identity;}
var options='options'in component?component.options:component;
var providerOpts=ValidationProvider.options;
var hoc={
name:(options.name||'AnonymousHoc')+"WithValidation",
props:_assign({},providerOpts.props),
data:providerOpts.data,
computed:_assign({},providerOpts.computed),
methods:_assign({},providerOpts.methods),
beforeDestroy:providerOpts.beforeDestroy,
inject:providerOpts.inject};

var eventName=((_a=options===null||options===void 0?void 0:options.model)===null||_a===void 0?void 0:_a.event)||'input';
hoc.render=function(h){
var _a;
this.registerField();
var vctx=createValidationCtx(this);
var listeners=_assign({},this.$listeners);
var model=findModel(this.$vnode);
this._inputEventName=this._inputEventName||getInputEventName(this.$vnode,model);
var value=findValue(this.$vnode);
onRenderUpdate(this,value===null||value===void 0?void 0:value.value);
var _b=createCommonHandlers(this),onInput=_b.onInput,onBlur=_b.onBlur,onValidate=_b.onValidate;
mergeVNodeListeners(listeners,eventName,onInput);
mergeVNodeListeners(listeners,'blur',onBlur);
this.normalizedEvents.forEach(function(evt){
mergeVNodeListeners(listeners,evt,onValidate);
});
// Props are any attrs not associated with ValidationProvider Plus the model prop.
// WARNING: Accidental prop overwrite will probably happen.
var prop=(findModelConfig(this.$vnode)||{prop:'value'}).prop;
var props=_assign(_assign(_assign({},this.$attrs),(_a={},_a[prop]=model===null||model===void 0?void 0:model.value,_a)),mapProps(vctx));
return h(options,{
attrs:this.$attrs,
props:props,
on:listeners,
scopedSlots:this.$scopedSlots},
normalizeSlots(this.$slots,this.$vnode.context));
};
return hoc;
}

var version='3.4.5';




/***/},

/***/"./node_modules/vue-cookie/src/vue-cookie.js":
/*!***************************************************!*\
  !*** ./node_modules/vue-cookie/src/vue-cookie.js ***!
  \***************************************************/
/*! no static exports found */
/***/function node_modulesVueCookieSrcVueCookieJs(module,exports,__webpack_require__){

(function(){
Number.isInteger=Number.isInteger||function(value){
return typeof value==='number'&&
isFinite(value)&&
Math.floor(value)===value;
};
var Cookie=__webpack_require__(/*! tiny-cookie */"./node_modules/tiny-cookie/tiny-cookie.js");

var VueCookie={

install:function install(Vue){
Vue.prototype.$cookie=this;
Vue.cookie=this;
},
set:function set(name,value,daysOrOptions){
var opts=daysOrOptions;
if(Number.isInteger(daysOrOptions)){
opts={expires:daysOrOptions};
}
return Cookie.set(name,value,opts);
},

get:function get(name){
return Cookie.get(name);
},

delete:function _delete(name,options){
var opts={expires:-1};
if(options!==undefined){
opts=Object.assign(options,opts);
}
this.set(name,'',opts);
}};


{
module.exports=VueCookie;
}

})();


/***/},

/***/"./node_modules/vue-cookies/vue-cookies.js":
/*!*************************************************!*\
  !*** ./node_modules/vue-cookies/vue-cookies.js ***!
  \*************************************************/
/*! no static exports found */
/***/function node_modulesVueCookiesVueCookiesJs(module,exports,__webpack_require__){

/**
 * Vue Cookies v1.7.4
 * https://github.com/cmp-cc/vue-cookies
 *
 * Copyright 2016, cmp-cc
 * Released under the MIT license
 */

(function(){

var defaultConfig={
expires:'1d',
path:'; path=/',
domain:'',
secure:'',
sameSite:'; SameSite=Lax'};


var VueCookies={
// install of Vue
install:function install(Vue){
Vue.prototype.$cookies=this;
Vue.$cookies=this;
},
config:function config(expireTimes,path,domain,secure,sameSite){
defaultConfig.expires=expireTimes?expireTimes:'1d';
defaultConfig.path=path?'; path='+path:'; path=/';
defaultConfig.domain=domain?'; domain='+domain:'';
defaultConfig.secure=secure?'; Secure':'';
defaultConfig.sameSite=sameSite?'; SameSite='+sameSite:'; SameSite=Lax';
},
get:function get(key){
var value=decodeURIComponent(document.cookie.replace(new RegExp('(?:(?:^|.*;)\\s*'+encodeURIComponent(key).replace(/[\-\.\+\*]/g,'\\$&')+'\\s*\\=\\s*([^;]*).*$)|^.*$'),'$1'))||null;

if(value&&value.substring(0,1)==='{'&&value.substring(value.length-1,value.length)==='}'){
try{
value=JSON.parse(value);
}catch(e){
return value;
}
}
return value;
},
set:function set(key,value,expireTimes,path,domain,secure,sameSite){
if(!key){
throw new Error('Cookie name is not find in first argument.');
}else if(/^(?:expires|max\-age|path|domain|secure|SameSite)$/i.test(key)){
throw new Error('Cookie key name illegality, Cannot be set to ["expires","max-age","path","domain","secure","SameSite"]\t current key name: '+key);
}
// support json object
if(value&&value.constructor===Object){
value=JSON.stringify(value);
}
var _expires='';
expireTimes=expireTimes==undefined?defaultConfig.expires:expireTimes;
if(expireTimes&&expireTimes!=0){
switch(expireTimes.constructor){
case Number:
if(expireTimes===Infinity||expireTimes===-1)_expires='; expires=Fri, 31 Dec 9999 23:59:59 GMT';else
_expires='; max-age='+expireTimes;
break;
case String:
if(/^(?:\d+(y|m|d|h|min|s))$/i.test(expireTimes)){
// get capture number group
var _expireTime=expireTimes.replace(/^(\d+)(?:y|m|d|h|min|s)$/i,'$1');
// get capture type group , to lower case
switch(expireTimes.replace(/^(?:\d+)(y|m|d|h|min|s)$/i,'$1').toLowerCase()){
// Frequency sorting
case'm':
_expires='; max-age='+ +_expireTime*2592000;
break;// 60 * 60 * 24 * 30
case'd':
_expires='; max-age='+ +_expireTime*86400;
break;// 60 * 60 * 24
case'h':
_expires='; max-age='+ +_expireTime*3600;
break;// 60 * 60
case'min':
_expires='; max-age='+ +_expireTime*60;
break;// 60
case's':
_expires='; max-age='+_expireTime;
break;
case'y':
_expires='; max-age='+ +_expireTime*31104000;
break;// 60 * 60 * 24 * 30 * 12
}

}else {
_expires='; expires='+expireTimes;
}
break;
case Date:
_expires='; expires='+expireTimes.toUTCString();
break;}

}
document.cookie=
encodeURIComponent(key)+'='+encodeURIComponent(value)+
_expires+(
domain?'; domain='+domain:defaultConfig.domain)+(
path?'; path='+path:defaultConfig.path)+(
secure==undefined?defaultConfig.secure:secure?'; Secure':'')+(
sameSite==undefined?defaultConfig.sameSite:sameSite?'; SameSite='+sameSite:'');
return this;
},
remove:function remove(key,path,domain){
if(!key||!this.isKey(key)){
return false;
}
document.cookie=encodeURIComponent(key)+
'=; expires=Thu, 01 Jan 1970 00:00:00 GMT'+(
domain?'; domain='+domain:defaultConfig.domain)+(
path?'; path='+path:defaultConfig.path)+
'; SameSite=Lax';
return this;
},
isKey:function isKey(key){
return new RegExp('(?:^|;\\s*)'+encodeURIComponent(key).replace(/[\-\.\+\*]/g,'\\$&')+'\\s*\\=').test(document.cookie);
},
keys:function keys(){
if(!document.cookie)return [];
var _keys=document.cookie.replace(/((?:^|\s*;)[^\=]+)(?=;|$)|^\s*|\s*(?:\=[^;]*)?(?:\1|$)/g,'').split(/\s*(?:\=[^;]*)?;\s*/);
for(var _index=0;_index<_keys.length;_index++){
_keys[_index]=decodeURIComponent(_keys[_index]);
}
return _keys;
}};


{
module.exports=VueCookies;
}
// vue-cookies can exist independently,no dependencies library
if(typeof window!=='undefined'){
window.$cookies=VueCookies;
}

})();


/***/},

/***/"./node_modules/vue-functional-data-merge/dist/lib.esm.js":
/*!****************************************************************!*\
  !*** ./node_modules/vue-functional-data-merge/dist/lib.esm.js ***!
  \****************************************************************/
/*! exports provided: mergeData */
/***/function node_modulesVueFunctionalDataMergeDistLibEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"mergeData",function(){return a;});
var _e2=function e(){return (_e2=Object.assign||function(e){for(var t,r=1,s=arguments.length;r<s;r++){for(var a in t=arguments[r]){Object.prototype.hasOwnProperty.call(t,a)&&(e[a]=t[a]);}}return e;}).apply(this,arguments);},t={kebab:/-(\w)/g,styleProp:/:(.*)/,styleList:/;(?![^(]*\))/g};function r(e,t){return t?t.toUpperCase():"";}function s(e){for(var s,a={},c=0,o=e.split(t.styleList);c<o.length;c++){var n=o[c].split(t.styleProp),i=n[0],l=n[1];(i=i.trim())&&("string"==typeof l&&(l=l.trim()),a[(s=i,s.replace(t.kebab,r))]=l);}return a;}function a(){for(var t,r,a={},c=arguments.length;c--;){for(var o=0,n=Object.keys(arguments[c]);o<n.length;o++){switch(t=n[o]){case"class":case"style":case"directives":if(Array.isArray(a[t])||(a[t]=[]),"style"===t){var i=void 0;i=Array.isArray(arguments[c].style)?arguments[c].style:[arguments[c].style];for(var l=0;l<i.length;l++){var y=i[l];"string"==typeof y&&(i[l]=s(y));}arguments[c].style=i;}a[t]=a[t].concat(arguments[c][t]);break;case"staticClass":if(!arguments[c][t])break;void 0===a[t]&&(a[t]=""),a[t]&&(a[t]+=" "),a[t]+=arguments[c][t].trim();break;case"on":case"nativeOn":a[t]||(a[t]={});for(var p=0,f=Object.keys(arguments[c][t]||{});p<f.length;p++){r=f[p],a[t][r]?a[t][r]=[].concat(a[t][r],arguments[c][t][r]):a[t][r]=arguments[c][t][r];}break;case"attrs":case"props":case"domProps":case"scopedSlots":case"staticStyle":case"hook":case"transition":a[t]||(a[t]={}),a[t]=_e2({},arguments[c][t],a[t]);break;case"slot":case"key":case"ref":case"tag":case"show":case"keepAlive":default:a[t]||(a[t]=arguments[c][t]);}}}return a;}



/***/},

/***/"./node_modules/vue-good-table/dist/vue-good-table.esm.js":
/*!****************************************************************!*\
  !*** ./node_modules/vue-good-table/dist/vue-good-table.esm.js ***!
  \****************************************************************/
/*! exports provided: default, VueGoodTable */
/***/function node_modulesVueGoodTableDistVueGoodTableEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* WEBPACK VAR INJECTION */(function(global){/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"VueGoodTable",function(){return __vue_component__$6;});
/**
 * vue-good-table v2.21.10
 * (c) 2018-present xaksis <shay@crayonbits.com>
 * https://github.com/xaksis/vue-good-table
 * Released under the MIT License.
 */

function _typeof(obj){
"@babel/helpers - typeof";

if(typeof Symbol==="function"&&typeof Symbol.iterator==="symbol"){
_typeof=function _typeof(obj){
return typeof obj;
};
}else {
_typeof=function _typeof(obj){
return obj&&typeof Symbol==="function"&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj;
};
}

return _typeof(obj);
}

function _defineProperty(obj,key,value){
if(key in obj){
Object.defineProperty(obj,key,{
value:value,
enumerable:true,
configurable:true,
writable:true});

}else {
obj[key]=value;
}

return obj;
}

function _slicedToArray(arr,i){
return _arrayWithHoles(arr)||_iterableToArrayLimit(arr,i)||_unsupportedIterableToArray(arr,i)||_nonIterableRest();
}

function _toConsumableArray(arr){
return _arrayWithoutHoles(arr)||_iterableToArray(arr)||_unsupportedIterableToArray(arr)||_nonIterableSpread();
}

function _arrayWithoutHoles(arr){
if(Array.isArray(arr))return _arrayLikeToArray(arr);
}

function _arrayWithHoles(arr){
if(Array.isArray(arr))return arr;
}

function _iterableToArray(iter){
if(typeof Symbol!=="undefined"&&Symbol.iterator in Object(iter))return Array.from(iter);
}

function _iterableToArrayLimit(arr,i){
if(typeof Symbol==="undefined"||!(Symbol.iterator in Object(arr)))return;
var _arr=[];
var _n=true;
var _d=false;
var _e=undefined;

try{
for(var _i=arr[Symbol.iterator](),_s;!(_n=(_s=_i.next()).done);_n=true){
_arr.push(_s.value);

if(i&&_arr.length===i)break;
}
}catch(err){
_d=true;
_e=err;
}finally{
try{
if(!_n&&_i["return"]!=null)_i["return"]();
}finally{
if(_d)throw _e;
}
}

return _arr;
}

function _unsupportedIterableToArray(o,minLen){
if(!o)return;
if(typeof o==="string")return _arrayLikeToArray(o,minLen);
var n=Object.prototype.toString.call(o).slice(8,-1);
if(n==="Object"&&o.constructor)n=o.constructor.name;
if(n==="Map"||n==="Set")return Array.from(o);
if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return _arrayLikeToArray(o,minLen);
}

function _arrayLikeToArray(arr,len){
if(len==null||len>arr.length)len=arr.length;

for(var i=0,arr2=new Array(len);i<len;i++){arr2[i]=arr[i];}

return arr2;
}

function _nonIterableSpread(){
throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _nonIterableRest(){
throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var DEFAULT_SORT_TYPE='asc';
var SORT_TYPES={
Ascending:'asc',
Descending:'desc',
None:'none'};

var PAGINATION_MODES={
Pages:'pages',
Records:'records'};

var DEFAULT_ROWS_PER_PAGE_DROPDOWN=[10,20,30,40,50];

var commonjsGlobal=typeof globalThis!=='undefined'?globalThis:typeof window!=='undefined'?window:typeof global!=='undefined'?global:typeof self!=='undefined'?self:{};

function createCommonjsModule(fn,module){
return module={exports:{}},fn(module,module.exports),module.exports;
}

var lodash_isequal=createCommonjsModule(function(module,exports){
/**
 * Lodash (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright JS Foundation and other contributors <https://js.foundation/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE=200;

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED='__lodash_hash_undefined__';

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG=1,
COMPARE_UNORDERED_FLAG=2;

/** Used as references for various `Number` constants. */
var MAX_SAFE_INTEGER=9007199254740991;

/** `Object#toString` result references. */
var argsTag='[object Arguments]',
arrayTag='[object Array]',
asyncTag='[object AsyncFunction]',
boolTag='[object Boolean]',
dateTag='[object Date]',
errorTag='[object Error]',
funcTag='[object Function]',
genTag='[object GeneratorFunction]',
mapTag='[object Map]',
numberTag='[object Number]',
nullTag='[object Null]',
objectTag='[object Object]',
promiseTag='[object Promise]',
proxyTag='[object Proxy]',
regexpTag='[object RegExp]',
setTag='[object Set]',
stringTag='[object String]',
symbolTag='[object Symbol]',
undefinedTag='[object Undefined]',
weakMapTag='[object WeakMap]';

var arrayBufferTag='[object ArrayBuffer]',
dataViewTag='[object DataView]',
float32Tag='[object Float32Array]',
float64Tag='[object Float64Array]',
int8Tag='[object Int8Array]',
int16Tag='[object Int16Array]',
int32Tag='[object Int32Array]',
uint8Tag='[object Uint8Array]',
uint8ClampedTag='[object Uint8ClampedArray]',
uint16Tag='[object Uint16Array]',
uint32Tag='[object Uint32Array]';

/**
 * Used to match `RegExp`
 * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
 */
var reRegExpChar=/[\\^$.*+?()[\]{}|]/g;

/** Used to detect host constructors (Safari). */
var reIsHostCtor=/^\[object .+?Constructor\]$/;

/** Used to detect unsigned integer values. */
var reIsUint=/^(?:0|[1-9]\d*)$/;

/** Used to identify `toStringTag` values of typed arrays. */
var typedArrayTags={};
typedArrayTags[float32Tag]=typedArrayTags[float64Tag]=
typedArrayTags[int8Tag]=typedArrayTags[int16Tag]=
typedArrayTags[int32Tag]=typedArrayTags[uint8Tag]=
typedArrayTags[uint8ClampedTag]=typedArrayTags[uint16Tag]=
typedArrayTags[uint32Tag]=true;
typedArrayTags[argsTag]=typedArrayTags[arrayTag]=
typedArrayTags[arrayBufferTag]=typedArrayTags[boolTag]=
typedArrayTags[dataViewTag]=typedArrayTags[dateTag]=
typedArrayTags[errorTag]=typedArrayTags[funcTag]=
typedArrayTags[mapTag]=typedArrayTags[numberTag]=
typedArrayTags[objectTag]=typedArrayTags[regexpTag]=
typedArrayTags[setTag]=typedArrayTags[stringTag]=
typedArrayTags[weakMapTag]=false;

/** Detect free variable `global` from Node.js. */
var freeGlobal=typeof commonjsGlobal=='object'&&commonjsGlobal&&commonjsGlobal.Object===Object&&commonjsGlobal;

/** Detect free variable `self`. */
var freeSelf=typeof self=='object'&&self&&self.Object===Object&&self;

/** Used as a reference to the global object. */
var root=freeGlobal||freeSelf||Function('return this')();

/** Detect free variable `exports`. */
var freeExports=exports&&!exports.nodeType&&exports;

/** Detect free variable `module`. */
var freeModule=freeExports&&'object'=='object'&&module&&!module.nodeType&&module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports=freeModule&&freeModule.exports===freeExports;

/** Detect free variable `process` from Node.js. */
var freeProcess=moduleExports&&freeGlobal.process;

/** Used to access faster Node.js helpers. */
var nodeUtil=function(){
try{
return freeProcess&&freeProcess.binding&&freeProcess.binding('util');
}catch(e){}
}();

/* Node.js helper references. */
var nodeIsTypedArray=nodeUtil&&nodeUtil.isTypedArray;

/**
 * A specialized version of `_.filter` for arrays without support for
 * iteratee shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {Array} Returns the new filtered array.
 */
function arrayFilter(array,predicate){
var index=-1,
length=array==null?0:array.length,
resIndex=0,
result=[];

while(++index<length){
var value=array[index];
if(predicate(value,index,array)){
result[resIndex++]=value;
}
}
return result;
}

/**
 * Appends the elements of `values` to `array`.
 *
 * @private
 * @param {Array} array The array to modify.
 * @param {Array} values The values to append.
 * @returns {Array} Returns `array`.
 */
function arrayPush(array,values){
var index=-1,
length=values.length,
offset=array.length;

while(++index<length){
array[offset+index]=values[index];
}
return array;
}

/**
 * A specialized version of `_.some` for arrays without support for iteratee
 * shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {boolean} Returns `true` if any element passes the predicate check,
 *  else `false`.
 */
function arraySome(array,predicate){
var index=-1,
length=array==null?0:array.length;

while(++index<length){
if(predicate(array[index],index,array)){
return true;
}
}
return false;
}

/**
 * The base implementation of `_.times` without support for iteratee shorthands
 * or max array length checks.
 *
 * @private
 * @param {number} n The number of times to invoke `iteratee`.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the array of results.
 */
function baseTimes(n,iteratee){
var index=-1,
result=Array(n);

while(++index<n){
result[index]=iteratee(index);
}
return result;
}

/**
 * The base implementation of `_.unary` without support for storing metadata.
 *
 * @private
 * @param {Function} func The function to cap arguments for.
 * @returns {Function} Returns the new capped function.
 */
function baseUnary(func){
return function(value){
return func(value);
};
}

/**
 * Checks if a `cache` value for `key` exists.
 *
 * @private
 * @param {Object} cache The cache to query.
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function cacheHas(cache,key){
return cache.has(key);
}

/**
 * Gets the value at `key` of `object`.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */
function getValue(object,key){
return object==null?undefined:object[key];
}

/**
 * Converts `map` to its key-value pairs.
 *
 * @private
 * @param {Object} map The map to convert.
 * @returns {Array} Returns the key-value pairs.
 */
function mapToArray(map){
var index=-1,
result=Array(map.size);

map.forEach(function(value,key){
result[++index]=[key,value];
});
return result;
}

/**
 * Creates a unary function that invokes `func` with its argument transformed.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {Function} transform The argument transform.
 * @returns {Function} Returns the new function.
 */
function overArg(func,transform){
return function(arg){
return func(transform(arg));
};
}

/**
 * Converts `set` to an array of its values.
 *
 * @private
 * @param {Object} set The set to convert.
 * @returns {Array} Returns the values.
 */
function setToArray(set){
var index=-1,
result=Array(set.size);

set.forEach(function(value){
result[++index]=value;
});
return result;
}

/** Used for built-in method references. */
var arrayProto=Array.prototype,
funcProto=Function.prototype,
objectProto=Object.prototype;

/** Used to detect overreaching core-js shims. */
var coreJsData=root['__core-js_shared__'];

/** Used to resolve the decompiled source of functions. */
var funcToString=funcProto.toString;

/** Used to check objects for own properties. */
var hasOwnProperty=objectProto.hasOwnProperty;

/** Used to detect methods masquerading as native. */
var maskSrcKey=function(){
var uid=/[^.]+$/.exec(coreJsData&&coreJsData.keys&&coreJsData.keys.IE_PROTO||'');
return uid?'Symbol(src)_1.'+uid:'';
}();

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString=objectProto.toString;

/** Used to detect if a method is native. */
var reIsNative=RegExp('^'+
funcToString.call(hasOwnProperty).replace(reRegExpChar,'\\$&').
replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,'$1.*?')+'$');


/** Built-in value references. */
var Buffer=moduleExports?root.Buffer:undefined,
Symbol=root.Symbol,
Uint8Array=root.Uint8Array,
propertyIsEnumerable=objectProto.propertyIsEnumerable,
splice=arrayProto.splice,
symToStringTag=Symbol?Symbol.toStringTag:undefined;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeGetSymbols=Object.getOwnPropertySymbols,
nativeIsBuffer=Buffer?Buffer.isBuffer:undefined,
nativeKeys=overArg(Object.keys,Object);

/* Built-in method references that are verified to be native. */
var DataView=getNative(root,'DataView'),
Map=getNative(root,'Map'),
Promise=getNative(root,'Promise'),
Set=getNative(root,'Set'),
WeakMap=getNative(root,'WeakMap'),
nativeCreate=getNative(Object,'create');

/** Used to detect maps, sets, and weakmaps. */
var dataViewCtorString=toSource(DataView),
mapCtorString=toSource(Map),
promiseCtorString=toSource(Promise),
setCtorString=toSource(Set),
weakMapCtorString=toSource(WeakMap);

/** Used to convert symbols to primitives and strings. */
var symbolProto=Symbol?Symbol.prototype:undefined,
symbolValueOf=symbolProto?symbolProto.valueOf:undefined;

/**
 * Creates a hash object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Hash(entries){
var index=-1,
length=entries==null?0:entries.length;

this.clear();
while(++index<length){
var entry=entries[index];
this.set(entry[0],entry[1]);
}
}

/**
 * Removes all key-value entries from the hash.
 *
 * @private
 * @name clear
 * @memberOf Hash
 */
function hashClear(){
this.__data__=nativeCreate?nativeCreate(null):{};
this.size=0;
}

/**
 * Removes `key` and its value from the hash.
 *
 * @private
 * @name delete
 * @memberOf Hash
 * @param {Object} hash The hash to modify.
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function hashDelete(key){
var result=this.has(key)&&delete this.__data__[key];
this.size-=result?1:0;
return result;
}

/**
 * Gets the hash value for `key`.
 *
 * @private
 * @name get
 * @memberOf Hash
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function hashGet(key){
var data=this.__data__;
if(nativeCreate){
var result=data[key];
return result===HASH_UNDEFINED?undefined:result;
}
return hasOwnProperty.call(data,key)?data[key]:undefined;
}

/**
 * Checks if a hash value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Hash
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function hashHas(key){
var data=this.__data__;
return nativeCreate?data[key]!==undefined:hasOwnProperty.call(data,key);
}

/**
 * Sets the hash `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Hash
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the hash instance.
 */
function hashSet(key,value){
var data=this.__data__;
this.size+=this.has(key)?0:1;
data[key]=nativeCreate&&value===undefined?HASH_UNDEFINED:value;
return this;
}

// Add methods to `Hash`.
Hash.prototype.clear=hashClear;
Hash.prototype['delete']=hashDelete;
Hash.prototype.get=hashGet;
Hash.prototype.has=hashHas;
Hash.prototype.set=hashSet;

/**
 * Creates an list cache object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function ListCache(entries){
var index=-1,
length=entries==null?0:entries.length;

this.clear();
while(++index<length){
var entry=entries[index];
this.set(entry[0],entry[1]);
}
}

/**
 * Removes all key-value entries from the list cache.
 *
 * @private
 * @name clear
 * @memberOf ListCache
 */
function listCacheClear(){
this.__data__=[];
this.size=0;
}

/**
 * Removes `key` and its value from the list cache.
 *
 * @private
 * @name delete
 * @memberOf ListCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function listCacheDelete(key){
var data=this.__data__,
index=assocIndexOf(data,key);

if(index<0){
return false;
}
var lastIndex=data.length-1;
if(index==lastIndex){
data.pop();
}else {
splice.call(data,index,1);
}
--this.size;
return true;
}

/**
 * Gets the list cache value for `key`.
 *
 * @private
 * @name get
 * @memberOf ListCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function listCacheGet(key){
var data=this.__data__,
index=assocIndexOf(data,key);

return index<0?undefined:data[index][1];
}

/**
 * Checks if a list cache value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf ListCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function listCacheHas(key){
return assocIndexOf(this.__data__,key)>-1;
}

/**
 * Sets the list cache `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf ListCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the list cache instance.
 */
function listCacheSet(key,value){
var data=this.__data__,
index=assocIndexOf(data,key);

if(index<0){
++this.size;
data.push([key,value]);
}else {
data[index][1]=value;
}
return this;
}

// Add methods to `ListCache`.
ListCache.prototype.clear=listCacheClear;
ListCache.prototype['delete']=listCacheDelete;
ListCache.prototype.get=listCacheGet;
ListCache.prototype.has=listCacheHas;
ListCache.prototype.set=listCacheSet;

/**
 * Creates a map cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function MapCache(entries){
var index=-1,
length=entries==null?0:entries.length;

this.clear();
while(++index<length){
var entry=entries[index];
this.set(entry[0],entry[1]);
}
}

/**
 * Removes all key-value entries from the map.
 *
 * @private
 * @name clear
 * @memberOf MapCache
 */
function mapCacheClear(){
this.size=0;
this.__data__={
'hash':new Hash(),
'map':new(Map||ListCache)(),
'string':new Hash()};

}

/**
 * Removes `key` and its value from the map.
 *
 * @private
 * @name delete
 * @memberOf MapCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function mapCacheDelete(key){
var result=getMapData(this,key)['delete'](key);
this.size-=result?1:0;
return result;
}

/**
 * Gets the map value for `key`.
 *
 * @private
 * @name get
 * @memberOf MapCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function mapCacheGet(key){
return getMapData(this,key).get(key);
}

/**
 * Checks if a map value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf MapCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function mapCacheHas(key){
return getMapData(this,key).has(key);
}

/**
 * Sets the map `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf MapCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the map cache instance.
 */
function mapCacheSet(key,value){
var data=getMapData(this,key),
size=data.size;

data.set(key,value);
this.size+=data.size==size?0:1;
return this;
}

// Add methods to `MapCache`.
MapCache.prototype.clear=mapCacheClear;
MapCache.prototype['delete']=mapCacheDelete;
MapCache.prototype.get=mapCacheGet;
MapCache.prototype.has=mapCacheHas;
MapCache.prototype.set=mapCacheSet;

/**
 *
 * Creates an array cache object to store unique values.
 *
 * @private
 * @constructor
 * @param {Array} [values] The values to cache.
 */
function SetCache(values){
var index=-1,
length=values==null?0:values.length;

this.__data__=new MapCache();
while(++index<length){
this.add(values[index]);
}
}

/**
 * Adds `value` to the array cache.
 *
 * @private
 * @name add
 * @memberOf SetCache
 * @alias push
 * @param {*} value The value to cache.
 * @returns {Object} Returns the cache instance.
 */
function setCacheAdd(value){
this.__data__.set(value,HASH_UNDEFINED);
return this;
}

/**
 * Checks if `value` is in the array cache.
 *
 * @private
 * @name has
 * @memberOf SetCache
 * @param {*} value The value to search for.
 * @returns {number} Returns `true` if `value` is found, else `false`.
 */
function setCacheHas(value){
return this.__data__.has(value);
}

// Add methods to `SetCache`.
SetCache.prototype.add=SetCache.prototype.push=setCacheAdd;
SetCache.prototype.has=setCacheHas;

/**
 * Creates a stack cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Stack(entries){
var data=this.__data__=new ListCache(entries);
this.size=data.size;
}

/**
 * Removes all key-value entries from the stack.
 *
 * @private
 * @name clear
 * @memberOf Stack
 */
function stackClear(){
this.__data__=new ListCache();
this.size=0;
}

/**
 * Removes `key` and its value from the stack.
 *
 * @private
 * @name delete
 * @memberOf Stack
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function stackDelete(key){
var data=this.__data__,
result=data['delete'](key);

this.size=data.size;
return result;
}

/**
 * Gets the stack value for `key`.
 *
 * @private
 * @name get
 * @memberOf Stack
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function stackGet(key){
return this.__data__.get(key);
}

/**
 * Checks if a stack value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Stack
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function stackHas(key){
return this.__data__.has(key);
}

/**
 * Sets the stack `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Stack
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the stack cache instance.
 */
function stackSet(key,value){
var data=this.__data__;
if(data instanceof ListCache){
var pairs=data.__data__;
if(!Map||pairs.length<LARGE_ARRAY_SIZE-1){
pairs.push([key,value]);
this.size=++data.size;
return this;
}
data=this.__data__=new MapCache(pairs);
}
data.set(key,value);
this.size=data.size;
return this;
}

// Add methods to `Stack`.
Stack.prototype.clear=stackClear;
Stack.prototype['delete']=stackDelete;
Stack.prototype.get=stackGet;
Stack.prototype.has=stackHas;
Stack.prototype.set=stackSet;

/**
 * Creates an array of the enumerable property names of the array-like `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @param {boolean} inherited Specify returning inherited property names.
 * @returns {Array} Returns the array of property names.
 */
function arrayLikeKeys(value,inherited){
var isArr=isArray(value),
isArg=!isArr&&isArguments(value),
isBuff=!isArr&&!isArg&&isBuffer(value),
isType=!isArr&&!isArg&&!isBuff&&isTypedArray(value),
skipIndexes=isArr||isArg||isBuff||isType,
result=skipIndexes?baseTimes(value.length,String):[],
length=result.length;

for(var key in value){
if((inherited||hasOwnProperty.call(value,key))&&
!(skipIndexes&&(
// Safari 9 has enumerable `arguments.length` in strict mode.
key=='length'||
// Node.js 0.10 has enumerable non-index properties on buffers.
isBuff&&(key=='offset'||key=='parent')||
// PhantomJS 2 has enumerable non-index properties on typed arrays.
isType&&(key=='buffer'||key=='byteLength'||key=='byteOffset')||
// Skip index properties.
isIndex(key,length))))
{
result.push(key);
}
}
return result;
}

/**
 * Gets the index at which the `key` is found in `array` of key-value pairs.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {*} key The key to search for.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function assocIndexOf(array,key){
var length=array.length;
while(length--){
if(eq(array[length][0],key)){
return length;
}
}
return -1;
}

/**
 * The base implementation of `getAllKeys` and `getAllKeysIn` which uses
 * `keysFunc` and `symbolsFunc` to get the enumerable property names and
 * symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Function} keysFunc The function to get the keys of `object`.
 * @param {Function} symbolsFunc The function to get the symbols of `object`.
 * @returns {Array} Returns the array of property names and symbols.
 */
function baseGetAllKeys(object,keysFunc,symbolsFunc){
var result=keysFunc(object);
return isArray(object)?result:arrayPush(result,symbolsFunc(object));
}

/**
 * The base implementation of `getTag` without fallbacks for buggy environments.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
function baseGetTag(value){
if(value==null){
return value===undefined?undefinedTag:nullTag;
}
return symToStringTag&&symToStringTag in Object(value)?
getRawTag(value):
objectToString(value);
}

/**
 * The base implementation of `_.isArguments`.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 */
function baseIsArguments(value){
return isObjectLike(value)&&baseGetTag(value)==argsTag;
}

/**
 * The base implementation of `_.isEqual` which supports partial comparisons
 * and tracks traversed objects.
 *
 * @private
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @param {boolean} bitmask The bitmask flags.
 *  1 - Unordered comparison
 *  2 - Partial comparison
 * @param {Function} [customizer] The function to customize comparisons.
 * @param {Object} [stack] Tracks traversed `value` and `other` objects.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 */
function baseIsEqual(value,other,bitmask,customizer,stack){
if(value===other){
return true;
}
if(value==null||other==null||!isObjectLike(value)&&!isObjectLike(other)){
return value!==value&&other!==other;
}
return baseIsEqualDeep(value,other,bitmask,customizer,baseIsEqual,stack);
}

/**
 * A specialized version of `baseIsEqual` for arrays and objects which performs
 * deep comparisons and tracks traversed objects enabling objects with circular
 * references to be compared.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} [stack] Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function baseIsEqualDeep(object,other,bitmask,customizer,equalFunc,stack){
var objIsArr=isArray(object),
othIsArr=isArray(other),
objTag=objIsArr?arrayTag:getTag(object),
othTag=othIsArr?arrayTag:getTag(other);

objTag=objTag==argsTag?objectTag:objTag;
othTag=othTag==argsTag?objectTag:othTag;

var objIsObj=objTag==objectTag,
othIsObj=othTag==objectTag,
isSameTag=objTag==othTag;

if(isSameTag&&isBuffer(object)){
if(!isBuffer(other)){
return false;
}
objIsArr=true;
objIsObj=false;
}
if(isSameTag&&!objIsObj){
stack||(stack=new Stack());
return objIsArr||isTypedArray(object)?
equalArrays(object,other,bitmask,customizer,equalFunc,stack):
equalByTag(object,other,objTag,bitmask,customizer,equalFunc,stack);
}
if(!(bitmask&COMPARE_PARTIAL_FLAG)){
var objIsWrapped=objIsObj&&hasOwnProperty.call(object,'__wrapped__'),
othIsWrapped=othIsObj&&hasOwnProperty.call(other,'__wrapped__');

if(objIsWrapped||othIsWrapped){
var objUnwrapped=objIsWrapped?object.value():object,
othUnwrapped=othIsWrapped?other.value():other;

stack||(stack=new Stack());
return equalFunc(objUnwrapped,othUnwrapped,bitmask,customizer,stack);
}
}
if(!isSameTag){
return false;
}
stack||(stack=new Stack());
return equalObjects(object,other,bitmask,customizer,equalFunc,stack);
}

/**
 * The base implementation of `_.isNative` without bad shim checks.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a native function,
 *  else `false`.
 */
function baseIsNative(value){
if(!isObject(value)||isMasked(value)){
return false;
}
var pattern=isFunction(value)?reIsNative:reIsHostCtor;
return pattern.test(toSource(value));
}

/**
 * The base implementation of `_.isTypedArray` without Node.js optimizations.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 */
function baseIsTypedArray(value){
return isObjectLike(value)&&
isLength(value.length)&&!!typedArrayTags[baseGetTag(value)];
}

/**
 * The base implementation of `_.keys` which doesn't treat sparse arrays as dense.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */
function baseKeys(object){
if(!isPrototype(object)){
return nativeKeys(object);
}
var result=[];
for(var key in Object(object)){
if(hasOwnProperty.call(object,key)&&key!='constructor'){
result.push(key);
}
}
return result;
}

/**
 * A specialized version of `baseIsEqualDeep` for arrays with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Array} array The array to compare.
 * @param {Array} other The other array to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `array` and `other` objects.
 * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
 */
function equalArrays(array,other,bitmask,customizer,equalFunc,stack){
var isPartial=bitmask&COMPARE_PARTIAL_FLAG,
arrLength=array.length,
othLength=other.length;

if(arrLength!=othLength&&!(isPartial&&othLength>arrLength)){
return false;
}
// Assume cyclic values are equal.
var stacked=stack.get(array);
if(stacked&&stack.get(other)){
return stacked==other;
}
var index=-1,
result=true,
seen=bitmask&COMPARE_UNORDERED_FLAG?new SetCache():undefined;

stack.set(array,other);
stack.set(other,array);

// Ignore non-index properties.
while(++index<arrLength){
var arrValue=array[index],
othValue=other[index];

if(customizer){
var compared=isPartial?
customizer(othValue,arrValue,index,other,array,stack):
customizer(arrValue,othValue,index,array,other,stack);
}
if(compared!==undefined){
if(compared){
continue;
}
result=false;
break;
}
// Recursively compare arrays (susceptible to call stack limits).
if(seen){
if(!arraySome(other,function(othValue,othIndex){
if(!cacheHas(seen,othIndex)&&(
arrValue===othValue||equalFunc(arrValue,othValue,bitmask,customizer,stack))){
return seen.push(othIndex);
}
})){
result=false;
break;
}
}else if(!(
arrValue===othValue||
equalFunc(arrValue,othValue,bitmask,customizer,stack)))
{
result=false;
break;
}
}
stack['delete'](array);
stack['delete'](other);
return result;
}

/**
 * A specialized version of `baseIsEqualDeep` for comparing objects of
 * the same `toStringTag`.
 *
 * **Note:** This function only supports comparing values with tags of
 * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {string} tag The `toStringTag` of the objects to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalByTag(object,other,tag,bitmask,customizer,equalFunc,stack){
switch(tag){
case dataViewTag:
if(object.byteLength!=other.byteLength||
object.byteOffset!=other.byteOffset){
return false;
}
object=object.buffer;
other=other.buffer;

case arrayBufferTag:
if(object.byteLength!=other.byteLength||
!equalFunc(new Uint8Array(object),new Uint8Array(other))){
return false;
}
return true;

case boolTag:
case dateTag:
case numberTag:
// Coerce booleans to `1` or `0` and dates to milliseconds.
// Invalid dates are coerced to `NaN`.
return eq(+object,+other);

case errorTag:
return object.name==other.name&&object.message==other.message;

case regexpTag:
case stringTag:
// Coerce regexes to strings and treat strings, primitives and objects,
// as equal. See http://www.ecma-international.org/ecma-262/7.0/#sec-regexp.prototype.tostring
// for more details.
return object==other+'';

case mapTag:
var convert=mapToArray;

case setTag:
var isPartial=bitmask&COMPARE_PARTIAL_FLAG;
convert||(convert=setToArray);

if(object.size!=other.size&&!isPartial){
return false;
}
// Assume cyclic values are equal.
var stacked=stack.get(object);
if(stacked){
return stacked==other;
}
bitmask|=COMPARE_UNORDERED_FLAG;

// Recursively compare objects (susceptible to call stack limits).
stack.set(object,other);
var result=equalArrays(convert(object),convert(other),bitmask,customizer,equalFunc,stack);
stack['delete'](object);
return result;

case symbolTag:
if(symbolValueOf){
return symbolValueOf.call(object)==symbolValueOf.call(other);
}}

return false;
}

/**
 * A specialized version of `baseIsEqualDeep` for objects with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalObjects(object,other,bitmask,customizer,equalFunc,stack){
var isPartial=bitmask&COMPARE_PARTIAL_FLAG,
objProps=getAllKeys(object),
objLength=objProps.length,
othProps=getAllKeys(other),
othLength=othProps.length;

if(objLength!=othLength&&!isPartial){
return false;
}
var index=objLength;
while(index--){
var key=objProps[index];
if(!(isPartial?key in other:hasOwnProperty.call(other,key))){
return false;
}
}
// Assume cyclic values are equal.
var stacked=stack.get(object);
if(stacked&&stack.get(other)){
return stacked==other;
}
var result=true;
stack.set(object,other);
stack.set(other,object);

var skipCtor=isPartial;
while(++index<objLength){
key=objProps[index];
var objValue=object[key],
othValue=other[key];

if(customizer){
var compared=isPartial?
customizer(othValue,objValue,key,other,object,stack):
customizer(objValue,othValue,key,object,other,stack);
}
// Recursively compare objects (susceptible to call stack limits).
if(!(compared===undefined?
objValue===othValue||equalFunc(objValue,othValue,bitmask,customizer,stack):
compared))
{
result=false;
break;
}
skipCtor||(skipCtor=key=='constructor');
}
if(result&&!skipCtor){
var objCtor=object.constructor,
othCtor=other.constructor;

// Non `Object` object instances with different constructors are not equal.
if(objCtor!=othCtor&&
'constructor'in object&&'constructor'in other&&
!(typeof objCtor=='function'&&objCtor instanceof objCtor&&
typeof othCtor=='function'&&othCtor instanceof othCtor)){
result=false;
}
}
stack['delete'](object);
stack['delete'](other);
return result;
}

/**
 * Creates an array of own enumerable property names and symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names and symbols.
 */
function getAllKeys(object){
return baseGetAllKeys(object,keys,getSymbols);
}

/**
 * Gets the data for `map`.
 *
 * @private
 * @param {Object} map The map to query.
 * @param {string} key The reference key.
 * @returns {*} Returns the map data.
 */
function getMapData(map,key){
var data=map.__data__;
return isKeyable(key)?
data[typeof key=='string'?'string':'hash']:
data.map;
}

/**
 * Gets the native function at `key` of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {string} key The key of the method to get.
 * @returns {*} Returns the function if it's native, else `undefined`.
 */
function getNative(object,key){
var value=getValue(object,key);
return baseIsNative(value)?value:undefined;
}

/**
 * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the raw `toStringTag`.
 */
function getRawTag(value){
var isOwn=hasOwnProperty.call(value,symToStringTag),
tag=value[symToStringTag];

try{
value[symToStringTag]=undefined;
var unmasked=true;
}catch(e){}

var result=nativeObjectToString.call(value);
if(unmasked){
if(isOwn){
value[symToStringTag]=tag;
}else {
delete value[symToStringTag];
}
}
return result;
}

/**
 * Creates an array of the own enumerable symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of symbols.
 */
var getSymbols=!nativeGetSymbols?stubArray:function(object){
if(object==null){
return [];
}
object=Object(object);
return arrayFilter(nativeGetSymbols(object),function(symbol){
return propertyIsEnumerable.call(object,symbol);
});
};

/**
 * Gets the `toStringTag` of `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
var getTag=baseGetTag;

// Fallback for data views, maps, sets, and weak maps in IE 11 and promises in Node.js < 6.
if(DataView&&getTag(new DataView(new ArrayBuffer(1)))!=dataViewTag||
Map&&getTag(new Map())!=mapTag||
Promise&&getTag(Promise.resolve())!=promiseTag||
Set&&getTag(new Set())!=setTag||
WeakMap&&getTag(new WeakMap())!=weakMapTag){
getTag=function getTag(value){
var result=baseGetTag(value),
Ctor=result==objectTag?value.constructor:undefined,
ctorString=Ctor?toSource(Ctor):'';

if(ctorString){
switch(ctorString){
case dataViewCtorString:return dataViewTag;
case mapCtorString:return mapTag;
case promiseCtorString:return promiseTag;
case setCtorString:return setTag;
case weakMapCtorString:return weakMapTag;}

}
return result;
};
}

/**
 * Checks if `value` is a valid array-like index.
 *
 * @private
 * @param {*} value The value to check.
 * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
 */
function isIndex(value,length){
length=length==null?MAX_SAFE_INTEGER:length;
return !!length&&(
typeof value=='number'||reIsUint.test(value))&&
value>-1&&value%1==0&&value<length;
}

/**
 * Checks if `value` is suitable for use as unique object key.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
 */
function isKeyable(value){
var type=typeof value;
return type=='string'||type=='number'||type=='symbol'||type=='boolean'?
value!=='__proto__':
value===null;
}

/**
 * Checks if `func` has its source masked.
 *
 * @private
 * @param {Function} func The function to check.
 * @returns {boolean} Returns `true` if `func` is masked, else `false`.
 */
function isMasked(func){
return !!maskSrcKey&&maskSrcKey in func;
}

/**
 * Checks if `value` is likely a prototype object.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
 */
function isPrototype(value){
var Ctor=value&&value.constructor,
proto=typeof Ctor=='function'&&Ctor.prototype||objectProto;

return value===proto;
}

/**
 * Converts `value` to a string using `Object.prototype.toString`.
 *
 * @private
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 */
function objectToString(value){
return nativeObjectToString.call(value);
}

/**
 * Converts `func` to its source code.
 *
 * @private
 * @param {Function} func The function to convert.
 * @returns {string} Returns the source code.
 */
function toSource(func){
if(func!=null){
try{
return funcToString.call(func);
}catch(e){}
try{
return func+'';
}catch(e){}
}
return '';
}

/**
 * Performs a
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * comparison between two values to determine if they are equivalent.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.eq(object, object);
 * // => true
 *
 * _.eq(object, other);
 * // => false
 *
 * _.eq('a', 'a');
 * // => true
 *
 * _.eq('a', Object('a'));
 * // => false
 *
 * _.eq(NaN, NaN);
 * // => true
 */
function eq(value,other){
return value===other||value!==value&&other!==other;
}

/**
 * Checks if `value` is likely an `arguments` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 *  else `false`.
 * @example
 *
 * _.isArguments(function() { return arguments; }());
 * // => true
 *
 * _.isArguments([1, 2, 3]);
 * // => false
 */
var isArguments=baseIsArguments(function(){return arguments;}())?baseIsArguments:function(value){
return isObjectLike(value)&&hasOwnProperty.call(value,'callee')&&
!propertyIsEnumerable.call(value,'callee');
};

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */
var isArray=Array.isArray;

/**
 * Checks if `value` is array-like. A value is considered array-like if it's
 * not a function and has a `value.length` that's an integer greater than or
 * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
 * @example
 *
 * _.isArrayLike([1, 2, 3]);
 * // => true
 *
 * _.isArrayLike(document.body.children);
 * // => true
 *
 * _.isArrayLike('abc');
 * // => true
 *
 * _.isArrayLike(_.noop);
 * // => false
 */
function isArrayLike(value){
return value!=null&&isLength(value.length)&&!isFunction(value);
}

/**
 * Checks if `value` is a buffer.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
 * @example
 *
 * _.isBuffer(new Buffer(2));
 * // => true
 *
 * _.isBuffer(new Uint8Array(2));
 * // => false
 */
var isBuffer=nativeIsBuffer||stubFalse;

/**
 * Performs a deep comparison between two values to determine if they are
 * equivalent.
 *
 * **Note:** This method supports comparing arrays, array buffers, booleans,
 * date objects, error objects, maps, numbers, `Object` objects, regexes,
 * sets, strings, symbols, and typed arrays. `Object` objects are compared
 * by their own, not inherited, enumerable properties. Functions and DOM
 * nodes are compared by strict equality, i.e. `===`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.isEqual(object, other);
 * // => true
 *
 * object === other;
 * // => false
 */
function isEqual(value,other){
return baseIsEqual(value,other);
}

/**
 * Checks if `value` is classified as a `Function` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a function, else `false`.
 * @example
 *
 * _.isFunction(_);
 * // => true
 *
 * _.isFunction(/abc/);
 * // => false
 */
function isFunction(value){
if(!isObject(value)){
return false;
}
// The use of `Object#toString` avoids issues with the `typeof` operator
// in Safari 9 which returns 'object' for typed arrays and other constructors.
var tag=baseGetTag(value);
return tag==funcTag||tag==genTag||tag==asyncTag||tag==proxyTag;
}

/**
 * Checks if `value` is a valid array-like length.
 *
 * **Note:** This method is loosely based on
 * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
 * @example
 *
 * _.isLength(3);
 * // => true
 *
 * _.isLength(Number.MIN_VALUE);
 * // => false
 *
 * _.isLength(Infinity);
 * // => false
 *
 * _.isLength('3');
 * // => false
 */
function isLength(value){
return typeof value=='number'&&
value>-1&&value%1==0&&value<=MAX_SAFE_INTEGER;
}

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject(value){
var type=typeof value;
return value!=null&&(type=='object'||type=='function');
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value){
return value!=null&&typeof value=='object';
}

/**
 * Checks if `value` is classified as a typed array.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 * @example
 *
 * _.isTypedArray(new Uint8Array);
 * // => true
 *
 * _.isTypedArray([]);
 * // => false
 */
var isTypedArray=nodeIsTypedArray?baseUnary(nodeIsTypedArray):baseIsTypedArray;

/**
 * Creates an array of the own enumerable property names of `object`.
 *
 * **Note:** Non-object values are coerced to objects. See the
 * [ES spec](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
 * for more details.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.keys(new Foo);
 * // => ['a', 'b'] (iteration order is not guaranteed)
 *
 * _.keys('hi');
 * // => ['0', '1']
 */
function keys(object){
return isArrayLike(object)?arrayLikeKeys(object):baseKeys(object);
}

/**
 * This method returns a new empty array.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {Array} Returns the new empty array.
 * @example
 *
 * var arrays = _.times(2, _.stubArray);
 *
 * console.log(arrays);
 * // => [[], []]
 *
 * console.log(arrays[0] === arrays[1]);
 * // => false
 */
function stubArray(){
return [];
}

/**
 * This method returns `false`.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {boolean} Returns `false`.
 * @example
 *
 * _.times(2, _.stubFalse);
 * // => [false, false]
 */
function stubFalse(){
return false;
}

module.exports=isEqual;
});

// all diacritics
var diacritics={
a:["a","à","á","â","ã","ä","å","æ","ā","ă","ą","ǎ","ǟ","ǡ","ǻ","ȁ","ȃ","ȧ","ɐ","ɑ","ɒ","ͣ","а","ӑ","ӓ","ᵃ","ᵄ","ᶏ","ḁ","ẚ","ạ","ả","ấ","ầ","ẩ","ẫ","ậ","ắ","ằ","ẳ","ẵ","ặ","ₐ","ⱥ","ａ"],
b:["b","ƀ","ƃ","ɓ","ᖯ","ᵇ","ᵬ","ᶀ","ḃ","ḅ","ḇ","ｂ"],
c:["c","ç","ć","ĉ","ċ","č","ƈ","ȼ","ɕ","ͨ","ᴄ","ᶜ","ḉ","ↄ","ｃ"],
d:["d","ď","đ","Ƌ","ƌ","ȡ","ɖ","ɗ","ͩ","ᵈ","ᵭ","ᶁ","ᶑ","ḋ","ḍ","ḏ","ḑ","ḓ","ｄ"],
e:["e","è","é","ê","ë","ē","ĕ","ė","ę","ě","ǝ","ȅ","ȇ","ȩ","ɇ","ɘ","ͤ","ᵉ","ᶒ","ḕ","ḗ","ḙ","ḛ","ḝ","ẹ","ẻ","ẽ","ế","ề","ể","ễ","ệ","ₑ","ｅ"],
f:["f","ƒ","ᵮ","ᶂ","ᶠ","ḟ","ｆ"],
g:["g","ĝ","ğ","ġ","ģ","ǥ","ǧ","ǵ","ɠ","ɡ","ᵍ","ᵷ","ᵹ","ᶃ","ᶢ","ḡ","ｇ"],
h:["h","ĥ","ħ","ƕ","ȟ","ɥ","ɦ","ʮ","ʯ","ʰ","ʱ","ͪ","Һ","һ","ᑋ","ᶣ","ḣ","ḥ","ḧ","ḩ","ḫ","ⱨ","ｈ"],
i:["i","ì","í","î","ï","ĩ","ī","ĭ","į","ǐ","ȉ","ȋ","ɨ","ͥ","ᴉ","ᵎ","ᵢ","ᶖ","ᶤ","ḭ","ḯ","ỉ","ị","ｉ"],
j:["j","ĵ","ǰ","ɉ","ʝ","ʲ","ᶡ","ᶨ","ｊ"],
k:["k","ķ","ƙ","ǩ","ʞ","ᵏ","ᶄ","ḱ","ḳ","ḵ","ⱪ","ｋ"],
l:["l","ĺ","ļ","ľ","ŀ","ł","ƚ","ȴ","ɫ","ɬ","ɭ","ˡ","ᶅ","ᶩ","ᶪ","ḷ","ḹ","ḻ","ḽ","ℓ","ⱡ"],
m:["m","ɯ","ɰ","ɱ","ͫ","ᴟ","ᵐ","ᵚ","ᵯ","ᶆ","ᶬ","ᶭ","ḿ","ṁ","ṃ","㎡","㎥","ｍ"],
n:["n","ñ","ń","ņ","ň","ŉ","ƞ","ǹ","ȵ","ɲ","ɳ","ᵰ","ᶇ","ᶮ","ᶯ","ṅ","ṇ","ṉ","ṋ","ⁿ","ｎ"],
o:["o","ò","ó","ô","õ","ö","ø","ō","ŏ","ő","ơ","ǒ","ǫ","ǭ","ǿ","ȍ","ȏ","ȫ","ȭ","ȯ","ȱ","ɵ","ͦ","о","ӧ","ө","ᴏ","ᴑ","ᴓ","ᴼ","ᵒ","ᶱ","ṍ","ṏ","ṑ","ṓ","ọ","ỏ","ố","ồ","ổ","ỗ","ộ","ớ","ờ","ở","ỡ","ợ","ₒ","ｏ","𐐬"],
p:["p","ᵖ","ᵱ","ᵽ","ᶈ","ṕ","ṗ","ｐ"],
q:["q","ɋ","ʠ","ᛩ","ｑ"],
r:["r","ŕ","ŗ","ř","ȑ","ȓ","ɍ","ɹ","ɻ","ʳ","ʴ","ʵ","ͬ","ᵣ","ᵲ","ᶉ","ṙ","ṛ","ṝ","ṟ"],
s:["s","ś","ŝ","ş","š","ș","ʂ","ᔆ","ᶊ","ṡ","ṣ","ṥ","ṧ","ṩ","ｓ"],
t:["t","ţ","ť","ŧ","ƫ","ƭ","ț","ʇ","ͭ","ᵀ","ᵗ","ᵵ","ᶵ","ṫ","ṭ","ṯ","ṱ","ẗ","ｔ"],
u:["u","ù","ú","û","ü","ũ","ū","ŭ","ů","ű","ų","ư","ǔ","ǖ","ǘ","ǚ","ǜ","ȕ","ȗ","ͧ","ߎ","ᵘ","ᵤ","ṳ","ṵ","ṷ","ṹ","ṻ","ụ","ủ","ứ","ừ","ử","ữ","ự","ｕ"],
v:["v","ʋ","ͮ","ᵛ","ᵥ","ᶹ","ṽ","ṿ","ⱱ","ｖ","ⱴ"],
w:["w","ŵ","ʷ","ᵂ","ẁ","ẃ","ẅ","ẇ","ẉ","ẘ","ⱳ","ｗ"],
x:["x","̽","͓","ᶍ","ͯ","ẋ","ẍ","ₓ","ｘ"],
y:["y","ý","ÿ","ŷ","ȳ","ɏ","ʸ","ẏ","ỳ","ỵ","ỷ","ỹ","ｙ"],
z:["z","ź","ż","ž","ƶ","ȥ","ɀ","ʐ","ʑ","ᙆ","ᙇ","ᶻ","ᶼ","ᶽ","ẑ","ẓ","ẕ","ⱬ","ｚ"]};
// Precompiled Object with { key = Diacritic, value = real-Character }

var compiledDiactitics=function(){
var x={};

for(var key in diacritics){
var ok=diacritics[key];

for(var rval in ok){
var val=ok[rval];// Do not replace the char with itself

if(val!==key){
x[val]=key;
}
}
}

return x;
}();// Regex for detecting non-ASCII-Characters in String


var regexNonASCII=/[^a-z0-9\s,.-]/;
/*
 * Main function of the module which removes all diacritics from the received text
 */

var diacriticless=function diacriticless(text){
// When there are only ascii-Characters in the string, skip processing and return text right away
if(text.search(regexNonASCII)===-1){
return text;
}

var result="";
var len=text.length;

for(var i=0;i<len;i++){
var searchChar=text.charAt(i);// If applicable replace the diacritic character with the real one or use the original value

result+=searchChar in compiledDiactitics?compiledDiactitics[searchChar]:searchChar;
}

return result;
};

var escapeRegExp=function escapeRegExp(str){
return str.replace(/[\\^$*+?.()|[\]{}]/g,'\\$&');
};

var defaultType={
format:function format(x){
return x;
},
filterPredicate:function filterPredicate(rowval,filter){
var skipDiacritics=arguments.length>2&&arguments[2]!==undefined?arguments[2]:false;
var fromDropdown=arguments.length>3&&arguments[3]!==undefined?arguments[3]:false;

// take care of nulls
if(typeof rowval==='undefined'||rowval===null){
return false;
}// row value


var rowValue=skipDiacritics?String(rowval).toLowerCase():diacriticless(escapeRegExp(String(rowval)).toLowerCase());// search term

var searchTerm=skipDiacritics?filter.toLowerCase():diacriticless(escapeRegExp(filter).toLowerCase());// comparison

return fromDropdown?rowValue===searchTerm:rowValue.indexOf(searchTerm)>-1;
},
compare:function compare(x,y){
function cook(d){
if(typeof d==='undefined'||d===null)return '';
return diacriticless(String(d).toLowerCase());
}

x=cook(x);
y=cook(y);
if(x<y)return -1;
if(x>y)return 1;
return 0;
}};


//
var script={
name:'VgtPaginationPageInfo',
props:{
currentPage:{
"default":1},

lastPage:{
"default":1},

totalRecords:{
"default":0},

ofText:{
"default":'of',
type:String},

pageText:{
"default":'page',
type:String},

currentPerPage:{},
mode:{
"default":PAGINATION_MODES.Records},

infoFn:{
"default":null}},


data:function data(){
return {
id:this.getId()};

},
computed:{
pageInfo:function pageInfo(){
return "".concat(this.ofText," ").concat(this.lastPage);
},
firstRecordOnPage:function firstRecordOnPage(){
return (this.currentPage-1)*this.currentPerPage+1;
},
lastRecordOnPage:function lastRecordOnPage(){
return Math.min(this.totalRecords,this.currentPage*this.currentPerPage);
},
recordInfo:function recordInfo(){
var first=this.firstRecordOnPage;
var last=this.lastRecordOnPage;

if(last===0){
first=0;
}

return "".concat(first," - ").concat(last," ").concat(this.ofText," ").concat(this.totalRecords);
},
infoParams:function infoParams(){
var first=this.firstRecordOnPage;
var last=this.lastRecordOnPage;

if(last===0){
first=0;
}

return {
firstRecordOnPage:first,
lastRecordOnPage:last,
totalRecords:this.totalRecords,
currentPage:this.currentPage,
totalPages:this.lastPage};

}},

methods:{
getId:function getId(){
return "vgt-page-input-".concat(Math.floor(Math.random()*Date.now()));
},
changePage:function changePage(event){
var value=parseInt(event.target.value,10);//! invalid number

if(Number.isNaN(value)||value>this.lastPage||value<1){
event.target.value=this.currentPage;
return false;
}//* valid number


event.target.value=value;
this.$emit('page-changed',value);
}},

mounted:function mounted(){},
components:{}};


function normalizeComponent(template,style,script,scopeId,isFunctionalTemplate,moduleIdentifier/* server only */,shadowMode,createInjector,createInjectorSSR,createInjectorShadow){
if(typeof shadowMode!=='boolean'){
createInjectorSSR=createInjector;
createInjector=shadowMode;
shadowMode=false;
}
// Vue.extend constructor export interop.
var options=typeof script==='function'?script.options:script;
// render functions
if(template&&template.render){
options.render=template.render;
options.staticRenderFns=template.staticRenderFns;
options._compiled=true;
// functional template
if(isFunctionalTemplate){
options.functional=true;
}
}
// scopedId
if(scopeId){
options._scopeId=scopeId;
}
var hook;
if(moduleIdentifier){
// server build
hook=function hook(context){
// 2.3 injection
context=
context||// cached call
this.$vnode&&this.$vnode.ssrContext||// stateful
this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext;// functional
// 2.2 with runInNewContext: true
if(!context&&typeof __VUE_SSR_CONTEXT__!=='undefined'){
context=__VUE_SSR_CONTEXT__;
}
// inject component styles
if(style){
style.call(this,createInjectorSSR(context));
}
// register component module identifier for async chunk inference
if(context&&context._registeredComponents){
context._registeredComponents.add(moduleIdentifier);
}
};
// used by ssr in case component is cached and beforeCreate
// never gets called
options._ssrRegister=hook;
}else
if(style){
hook=shadowMode?
function(context){
style.call(this,createInjectorShadow(context,this.$root.$options.shadowRoot));
}:
function(context){
style.call(this,createInjector(context));
};
}
if(hook){
if(options.functional){
// register for functional component in vue file
var originalRender=options.render;
options.render=function renderWithStyleInjection(h,context){
hook.call(context);
return originalRender(h,context);
};
}else
{
// inject component registration as beforeCreate hook
var existing=options.beforeCreate;
options.beforeCreate=existing?[].concat(existing,hook):[hook];
}
}
return script;
}

/* script */
var __vue_script__=script;
/* template */

var __vue_render__=function __vue_render__(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _c('div',{
staticClass:"footer__navigation__page-info"},
[_vm.infoFn?_c('div',[_vm._v("\n    "+_vm._s(_vm.infoFn(_vm.infoParams))+"\n  ")]):_vm.mode==='pages'?_c('form',{
on:{
"submit":function submit($event){
$event.preventDefault();
}}},

[_c('label',{
staticClass:"page-info__label",
attrs:{
"for":_vm.id}},

[_c('span',[_vm._v(_vm._s(_vm.pageText))]),_vm._v(" "),_c('input',{
staticClass:"footer__navigation__page-info__current-entry",
attrs:{
"id":_vm.id,
"aria-describedby":"change-page-hint",
"aria-controls":"vgb-table",
"type":"text"},

domProps:{
"value":_vm.currentPage},

on:{
"keyup":function keyup($event){
if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"enter",13,$event.key,"Enter")){
return null;
}

$event.stopPropagation();
return _vm.changePage($event);
}}}),

_vm._v(" "),_c('span',[_vm._v(_vm._s(_vm.pageInfo))])]),_vm._v(" "),_c('span',{
staticStyle:{
"display":"none"},

attrs:{
"id":"change-page-hint"}},

[_vm._v("\n      Type a page number and press Enter to change the page.\n    ")])]):_c('div',[_vm._v("\n    "+_vm._s(_vm.recordInfo)+"\n  ")])]);
};

var __vue_staticRenderFns__=[];
/* style */

var __vue_inject_styles__=undefined;
/* scoped */

var __vue_scope_id__="data-v-3b496d41";
/* module identifier */

var __vue_module_identifier__=undefined;
/* functional template */

var __vue_is_functional_template__=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__=/*#__PURE__*/normalizeComponent({
render:__vue_render__,
staticRenderFns:__vue_staticRenderFns__},
__vue_inject_styles__,__vue_script__,__vue_scope_id__,__vue_is_functional_template__,__vue_module_identifier__,false,undefined,undefined,undefined);

//
var script$1={
name:'VgtPagination',
props:{
styleClass:{
"default":'table table-bordered'},

total:{
"default":null},

perPage:{},
rtl:{
"default":false},

perPageDropdownEnabled:{
"default":true},

customRowsPerPageDropdown:{
"default":function _default(){
return [];
}},

paginateDropdownAllowAll:{
"default":true},

mode:{
"default":PAGINATION_MODES.Records},

// text options
nextText:{
"default":'Next'},

prevText:{
"default":'Prev'},

rowsPerPageText:{
"default":'Rows per page:'},

ofText:{
"default":'of'},

pageText:{
"default":'page'},

allText:{
"default":'All'},

infoFn:{
"default":null}},


data:function data(){
return {
id:this.getId(),
currentPage:1,
prevPage:0,
currentPerPage:10,
rowsPerPageOptions:[]};

},
watch:{
perPage:{
handler:function handler(newValue,oldValue){
this.handlePerPage();
this.perPageChanged(oldValue);
},
immediate:true},

customRowsPerPageDropdown:function customRowsPerPageDropdown(){
this.handlePerPage();
},
total:{
handler:function handler(newValue,oldValue){
if(this.rowsPerPageOptions.indexOf(this.currentPerPage)===-1){
this.currentPerPage=newValue;
}
}}},


computed:{
// Number of pages
pagesCount:function pagesCount(){
var quotient=Math.floor(this.total/this.currentPerPage);
var remainder=this.total%this.currentPerPage;
return remainder===0?quotient:quotient+1;
},
// Can go to next page
nextIsPossible:function nextIsPossible(){
return this.currentPage<this.pagesCount;
},
// Can go to previous page
prevIsPossible:function prevIsPossible(){
return this.currentPage>1;
}},

methods:{
getId:function getId(){
return "vgt-select-rpp-".concat(Math.floor(Math.random()*Date.now()));
},
// Change current page
changePage:function changePage(pageNumber){
var emit=arguments.length>1&&arguments[1]!==undefined?arguments[1]:true;

if(pageNumber>0&&this.total>this.currentPerPage*(pageNumber-1)){
this.prevPage=this.currentPage;
this.currentPage=pageNumber;
this.pageChanged(emit);
}
},
// Go to next page
nextPage:function nextPage(){
if(this.nextIsPossible){
this.prevPage=this.currentPage;
++this.currentPage;
this.pageChanged();
}
},
// Go to previous page
previousPage:function previousPage(){
if(this.prevIsPossible){
this.prevPage=this.currentPage;
--this.currentPage;
this.pageChanged();
}
},
// Indicate page changing
pageChanged:function pageChanged(){
var emit=arguments.length>0&&arguments[0]!==undefined?arguments[0]:true;
var payload={
currentPage:this.currentPage,
prevPage:this.prevPage};

if(!emit)payload.noEmit=true;
this.$emit('page-changed',payload);
},
// Indicate per page changing
perPageChanged:function perPageChanged(oldValue){
// go back to first page
if(oldValue){
//* only emit if this isn't first initialization
this.$emit('per-page-changed',{
currentPerPage:this.currentPerPage});

}

this.changePage(1,false);
},
// Handle per page changing
handlePerPage:function handlePerPage(){
//* if there's a custom dropdown then we use that
if(this.customRowsPerPageDropdown!==null&&Array.isArray(this.customRowsPerPageDropdown)&&this.customRowsPerPageDropdown.length!==0){
this.rowsPerPageOptions=JSON.parse(JSON.stringify(this.customRowsPerPageDropdown));
}else {
//* otherwise we use the default rows per page dropdown
this.rowsPerPageOptions=JSON.parse(JSON.stringify(DEFAULT_ROWS_PER_PAGE_DROPDOWN));
}

if(this.perPage){
this.currentPerPage=this.perPage;// if perPage doesn't already exist, we add it

var found=false;

for(var i=0;i<this.rowsPerPageOptions.length;i++){
if(this.rowsPerPageOptions[i]===this.perPage){
found=true;
}
}

if(!found&&this.perPage!==-1){
this.rowsPerPageOptions.unshift(this.perPage);
}
}else {
// reset to default
this.currentPerPage=10;
}
}},

mounted:function mounted(){},
components:{
'pagination-page-info':__vue_component__}};



/* script */
var __vue_script__$1=script$1;
/* template */

var __vue_render__$1=function __vue_render__(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _c('div',{
staticClass:"vgt-wrap__footer vgt-clearfix"},
[_vm.perPageDropdownEnabled?_c('div',{
staticClass:"footer__row-count vgt-pull-left"},
[_c('form',[_c('label',{
staticClass:"footer__row-count__label",
attrs:{
"for":_vm.id}},

[_vm._v(_vm._s(_vm.rowsPerPageText)+":")]),_vm._v(" "),_c('select',{
directives:[{
name:"model",
rawName:"v-model",
value:_vm.currentPerPage,
expression:"currentPerPage"}],

staticClass:"footer__row-count__select",
attrs:{
"id":_vm.id,
"autocomplete":"off",
"name":"perPageSelect",
"aria-controls":"vgt-table"},

on:{
"change":[function($event){
var $$selectedVal=Array.prototype.filter.call($event.target.options,function(o){
return o.selected;
}).map(function(o){
var val="_value"in o?o._value:o.value;
return val;
});
_vm.currentPerPage=$event.target.multiple?$$selectedVal:$$selectedVal[0];
},_vm.perPageChanged]}},

[_vm._l(_vm.rowsPerPageOptions,function(option,idx){
return _c('option',{
key:idx,
domProps:{
"value":option}},

[_vm._v("\n          "+_vm._s(option)+"\n        ")]);
}),_vm._v(" "),_vm.paginateDropdownAllowAll?_c('option',{
domProps:{
"value":_vm.total}},

[_vm._v(_vm._s(_vm.allText))]):_vm._e()],2)])]):_vm._e(),_vm._v(" "),_c('div',{
staticClass:"footer__navigation vgt-pull-right"},
[_c('pagination-page-info',{
attrs:{
"total-records":_vm.total,
"last-page":_vm.pagesCount,
"current-page":_vm.currentPage,
"current-per-page":_vm.currentPerPage,
"of-text":_vm.ofText,
"page-text":_vm.pageText,
"info-fn":_vm.infoFn,
"mode":_vm.mode},

on:{
"page-changed":_vm.changePage}}),

_vm._v(" "),_c('button',{
staticClass:"footer__navigation__page-btn",
"class":{
disabled:!_vm.prevIsPossible},

attrs:{
"type":"button",
"aria-controls":"vgt-table"},

on:{
"click":function click($event){
$event.preventDefault();
$event.stopPropagation();
return _vm.previousPage($event);
}}},

[_c('span',{
staticClass:"chevron",
"class":{
'left':!_vm.rtl,
'right':_vm.rtl},

attrs:{
"aria-hidden":"true"}}),

_vm._v(" "),_c('span',[_vm._v(_vm._s(_vm.prevText))])]),_vm._v(" "),_c('button',{
staticClass:"footer__navigation__page-btn",
"class":{
disabled:!_vm.nextIsPossible},

attrs:{
"type":"button",
"aria-controls":"vgt-table"},

on:{
"click":function click($event){
$event.preventDefault();
$event.stopPropagation();
return _vm.nextPage($event);
}}},

[_c('span',[_vm._v(_vm._s(_vm.nextText))]),_vm._v(" "),_c('span',{
staticClass:"chevron",
"class":{
'right':!_vm.rtl,
'left':_vm.rtl},

attrs:{
"aria-hidden":"true"}})])],

1)]);
};

var __vue_staticRenderFns__$1=[];
/* style */

var __vue_inject_styles__$1=undefined;
/* scoped */

var __vue_scope_id__$1=undefined;
/* module identifier */

var __vue_module_identifier__$1=undefined;
/* functional template */

var __vue_is_functional_template__$1=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__$1=/*#__PURE__*/normalizeComponent({
render:__vue_render__$1,
staticRenderFns:__vue_staticRenderFns__$1},
__vue_inject_styles__$1,__vue_script__$1,__vue_scope_id__$1,__vue_is_functional_template__$1,__vue_module_identifier__$1,false,undefined,undefined,undefined);

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
var script$2={
name:'VgtGlobalSearch',
props:['value','searchEnabled','globalSearchPlaceholder'],
data:function data(){
return {
globalSearchTerm:null,
id:this.getId()};

},
computed:{
showControlBar:function showControlBar(){
if(this.searchEnabled)return true;
if(this.$slots&&this.$slots['internal-table-actions'])return true;
return false;
}},

methods:{
updateValue:function updateValue(value){
this.$emit('input',value);
this.$emit('on-keyup',value);
},
entered:function entered(value){
this.$emit('on-enter',value);
},
getId:function getId(){
return "vgt-search-".concat(Math.floor(Math.random()*Date.now()));
}}};



/* script */
var __vue_script__$2=script$2;
/* template */

var __vue_render__$2=function __vue_render__(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _vm.showControlBar?_c('div',{
staticClass:"vgt-global-search vgt-clearfix"},
[_c('div',{
staticClass:"vgt-global-search__input vgt-pull-left"},
[_vm.searchEnabled?_c('form',{
attrs:{
"role":"search"},

on:{
"submit":function submit($event){
$event.preventDefault();
}}},

[_c('label',{
attrs:{
"for":_vm.id}},

[_vm._m(0),_vm._v(" "),_c('span',{
staticClass:"sr-only"},
[_vm._v("Search")])]),_vm._v(" "),_c('input',{
staticClass:"vgt-input vgt-pull-left",
attrs:{
"id":_vm.id,
"type":"text",
"placeholder":_vm.globalSearchPlaceholder},

domProps:{
"value":_vm.value},

on:{
"input":function input($event){
return _vm.updateValue($event.target.value);
},
"keyup":function keyup($event){
if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"enter",13,$event.key,"Enter")){
return null;
}

return _vm.entered($event.target.value);
}}})]):

_vm._e()]),_vm._v(" "),_c('div',{
staticClass:"vgt-global-search__actions vgt-pull-right"},
[_vm._t("internal-table-actions")],2)]):_vm._e();
};

var __vue_staticRenderFns__$2=[function(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _c('span',{
staticClass:"input__icon",
attrs:{
"aria-hidden":"true"}},

[_c('div',{
staticClass:"magnifying-glass"})]);

}];
/* style */

var __vue_inject_styles__$2=undefined;
/* scoped */

var __vue_scope_id__$2=undefined;
/* module identifier */

var __vue_module_identifier__$2=undefined;
/* functional template */

var __vue_is_functional_template__$2=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__$2=/*#__PURE__*/normalizeComponent({
render:__vue_render__$2,
staticRenderFns:__vue_staticRenderFns__$2},
__vue_inject_styles__$2,__vue_script__$2,__vue_scope_id__$2,__vue_is_functional_template__$2,__vue_module_identifier__$2,false,undefined,undefined,undefined);

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
var script$3={
name:'VgtFilterRow',
props:['lineNumbers','columns','typedColumns','globalSearchEnabled','selectable','mode'],
watch:{
columns:{
handler:function handler(newValue,oldValue){
this.populateInitialFilters();
},
deep:true,
immediate:true}},


data:function data(){
return {
columnFilters:{},
timer:null};

},
computed:{
// to create a filter row, we need to
// make sure that there is atleast 1 column
// that requires filtering
hasFilterRow:function hasFilterRow(){
// if (this.mode === 'remote' || !this.globalSearchEnabled) {
for(var i=0;i<this.columns.length;i++){
var col=this.columns[i];

if(col.filterOptions&&col.filterOptions.enabled){
return true;
}
}// }


return false;
}},

methods:{
fieldKey:function fieldKey(field){
if(typeof field==='function'&&field.name){
return field.name;
}

return field;
},
reset:function reset(){
var emitEvent=arguments.length>0&&arguments[0]!==undefined?arguments[0]:false;
this.columnFilters={};

if(emitEvent){
this.$emit('filter-changed',this.columnFilters);
}
},
isFilterable:function isFilterable(column){
return column.filterOptions&&column.filterOptions.enabled;
},
isDropdown:function isDropdown(column){
return this.isFilterable(column)&&column.filterOptions.filterDropdownItems&&column.filterOptions.filterDropdownItems.length;
},
isDropdownObjects:function isDropdownObjects(column){
return this.isDropdown(column)&&_typeof(column.filterOptions.filterDropdownItems[0])==='object';
},
isDropdownArray:function isDropdownArray(column){
return this.isDropdown(column)&&_typeof(column.filterOptions.filterDropdownItems[0])!=='object';
},
getClasses:function getClasses(column){
var firstClass='filter-th';
return column.filterOptions&&column.filterOptions.styleClass?[firstClass].concat(_toConsumableArray(column.filterOptions.styleClass.split(' '))).join(' '):firstClass;
},
// get column's defined placeholder or default one
getPlaceholder:function getPlaceholder(column){
var placeholder=this.isFilterable(column)&&column.filterOptions.placeholder||"Filter ".concat(column.label);
return placeholder;
},
getName:function getName(column){
return "vgt-".concat(this.fieldKey(column.field));
},
updateFiltersOnEnter:function updateFiltersOnEnter(column,value){
if(this.timer)clearTimeout(this.timer);
this.updateFiltersImmediately(column.field,value);
},
updateFiltersOnKeyup:function updateFiltersOnKeyup(column,value){
// if the trigger is enter, we don't filter on keyup
if(column.filterOptions.trigger==='enter')return;
this.updateFilters(column,value);
},
updateSlotFilter:function updateSlotFilter(column,value){
var fieldToFilter=column.filterOptions.slotFilterField||column.field;

if(typeof column.filterOptions.formatValue==='function'){
value=column.filterOptions.formatValue(value);
}

this.updateFiltersImmediately(fieldToFilter,value);
},
// since vue doesn't detect property addition and deletion, we
// need to create helper function to set property etc
updateFilters:function updateFilters(column,value){
var _this=this;

if(this.timer)clearTimeout(this.timer);
this.timer=setTimeout(function(){
_this.updateFiltersImmediately(column.field,value);
},400);
},
updateFiltersImmediately:function updateFiltersImmediately(field,value){
this.$set(this.columnFilters,this.fieldKey(field),value);
this.$emit('filter-changed',this.columnFilters);
},
populateInitialFilters:function populateInitialFilters(){
for(var i=0;i<this.columns.length;i++){
var col=this.columns[i];// lets see if there are initial
// filters supplied by user

if(this.isFilterable(col)&&typeof col.filterOptions.filterValue!=='undefined'&&col.filterOptions.filterValue!==null){
this.$set(this.columnFilters,this.fieldKey(col.field),col.filterOptions.filterValue);// this.updateFilters(col, col.filterOptions.filterValue);
// this.$set(col.filterOptions, 'filterValue', undefined);
}
}//* lets emit event once all filters are set


this.$emit('filter-changed',this.columnFilters);
}}};



/* script */
var __vue_script__$3=script$3;
/* template */

var __vue_render__$3=function __vue_render__(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _vm.hasFilterRow?_c('tr',[_vm.lineNumbers?_c('th'):_vm._e(),_vm._v(" "),_vm.selectable?_c('th'):_vm._e(),_vm._v(" "),_vm._l(_vm.columns,function(column,index){
return !column.hidden?_c('th',{
key:index,
"class":_vm.getClasses(column)},
[_vm._t("column-filter",[_vm.isFilterable(column)?_c('div',[!_vm.isDropdown(column)?_c('input',{
staticClass:"vgt-input",
attrs:{
"name":_vm.getName(column),
"type":"text",
"placeholder":_vm.getPlaceholder(column)},

domProps:{
"value":_vm.columnFilters[_vm.fieldKey(column.field)]},

on:{
"keyup":function keyup($event){
if(!$event.type.indexOf('key')&&_vm._k($event.keyCode,"enter",13,$event.key,"Enter")){
return null;
}

return _vm.updateFiltersOnEnter(column,$event.target.value);
},
"input":function input($event){
return _vm.updateFiltersOnKeyup(column,$event.target.value);
}}}):

_vm._e(),_vm._v(" "),_vm.isDropdownArray(column)?_c('select',{
staticClass:"vgt-select",
attrs:{
"name":_vm.getName(column)},

domProps:{
"value":_vm.columnFilters[_vm.fieldKey(column.field)]},

on:{
"change":function change($event){
return _vm.updateFiltersImmediately(column.field,$event.target.value);
}}},

[_c('option',{
key:"-1",
attrs:{
"value":""}},

[_vm._v(_vm._s(_vm.getPlaceholder(column)))]),_vm._v(" "),_vm._l(column.filterOptions.filterDropdownItems,function(option,i){
return _c('option',{
key:i,
domProps:{
"value":option}},

[_vm._v("\n              "+_vm._s(option)+"\n            ")]);
})],2):_vm._e(),_vm._v(" "),_vm.isDropdownObjects(column)?_c('select',{
staticClass:"vgt-select",
attrs:{
"name":_vm.getName(column)},

domProps:{
"value":_vm.columnFilters[_vm.fieldKey(column.field)]},

on:{
"change":function change($event){
return _vm.updateFiltersImmediately(column.field,$event.target.value);
}}},

[_c('option',{
key:"-1",
attrs:{
"value":""}},

[_vm._v(_vm._s(_vm.getPlaceholder(column)))]),_vm._v(" "),_vm._l(column.filterOptions.filterDropdownItems,function(option,i){
return _c('option',{
key:i,
domProps:{
"value":option.value}},

[_vm._v(_vm._s(option.text))]);
})],2):_vm._e()]):_vm._e()],{
"column":column,
"updateFilters":_vm.updateSlotFilter})],
2):_vm._e();
})],2):_vm._e();
};

var __vue_staticRenderFns__$3=[];
/* style */

var __vue_inject_styles__$3=undefined;
/* scoped */

var __vue_scope_id__$3="data-v-6869bf1c";
/* module identifier */

var __vue_module_identifier__$3=undefined;
/* functional template */

var __vue_is_functional_template__$3=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__$3=/*#__PURE__*/normalizeComponent({
render:__vue_render__$3,
staticRenderFns:__vue_staticRenderFns__$3},
__vue_inject_styles__$3,__vue_script__$3,__vue_scope_id__$3,__vue_is_functional_template__$3,__vue_module_identifier__$3,false,undefined,undefined,undefined);

function getColumnFirstSortType(column){
return column.firstSortType||DEFAULT_SORT_TYPE;
}

function getCurrentPrimarySort(sortArray,column){
return sortArray.length===1&&sortArray[0].field===column.field?sortArray[0].type:undefined;
}

function getNextSort(currentSort,column){
if(SORT_TYPES.Descending===getColumnFirstSortType(column)&&currentSort===SORT_TYPES.Ascending){
return SORT_TYPES.None;
}else if(currentSort===SORT_TYPES.Ascending){
return SORT_TYPES.Descending;
}

if(SORT_TYPES.Descending===getColumnFirstSortType(column)&&currentSort===SORT_TYPES.Descending){
return SORT_TYPES.Ascending;
}else if(currentSort===SORT_TYPES.Descending){
return SORT_TYPES.None;
}

if(SORT_TYPES.Descending===getColumnFirstSortType(column)&&currentSort===SORT_TYPES.None){
return SORT_TYPES.Descending;
}else {
return SORT_TYPES.Ascending;
}
}

function getIndex(sortArray,column){
for(var i=0;i<sortArray.length;i++){
if(column.field===sortArray[i].field)return i;
}

return -1;
}

var primarySort=function primarySort(sortArray,column){
var currentPrimarySort=getCurrentPrimarySort(sortArray,column);
var nextPrimarySort=getNextSort(currentPrimarySort,column);
return [{
field:column.field,
type:currentPrimarySort?nextPrimarySort:getColumnFirstSortType(column)}];

};

var secondarySort=function secondarySort(sortArray,column){
var index=getIndex(sortArray,column);

if(index===-1){
sortArray.push({
field:column.field,
type:getColumnFirstSortType(column)});

}else {
sortArray[index].type=getNextSort(sortArray[index].type,column);
}

return sortArray;
};

//
var script$4={
name:'VgtTableHeader',
props:{
lineNumbers:{
"default":false,
type:Boolean},

selectable:{
"default":false,
type:Boolean},

allSelected:{
"default":false,
type:Boolean},

allSelectedIndeterminate:{
"default":false,
type:Boolean},

columns:{
type:Array},

mode:{
type:String},

typedColumns:{},
//* Sort related
sortable:{
type:Boolean},

multipleColumnSort:{
type:Boolean,
"default":true},

getClasses:{
type:Function},

//* search related
searchEnabled:{
type:Boolean},

tableRef:{},
paginated:{}},

watch:{
columns:{
handler:function handler(){
this.setColumnStyles();
},
immediate:true},

tableRef:{
handler:function handler(){
this.setColumnStyles();
},
immediate:true},

paginated:{
handler:function handler(){
if(this.tableRef){
this.setColumnStyles();
}
},
deep:true}},


data:function data(){
return {
checkBoxThStyle:{},
lineNumberThStyle:{},
columnStyles:[],
sorts:[],
ro:null};

},
computed:{},
methods:{
reset:function reset(){
this.$refs['filter-row'].reset(true);
},
toggleSelectAll:function toggleSelectAll(){
this.$emit('on-toggle-select-all');
},
isSortableColumn:function isSortableColumn(column){
var sortable=column.sortable;
var isSortable=typeof sortable==='boolean'?sortable:this.sortable;
return isSortable;
},
sort:function sort(e,column){
//* if column is not sortable, return right here
if(!this.isSortableColumn(column))return;

if(e.shiftKey&&this.multipleColumnSort){
this.sorts=secondarySort(this.sorts,column);
}else {
this.sorts=primarySort(this.sorts,column);
}

this.$emit('on-sort-change',this.sorts);
},
setInitialSort:function setInitialSort(sorts){
this.sorts=sorts;
this.$emit('on-sort-change',this.sorts);
},
getColumnSort:function getColumnSort(column){
for(var i=0;i<this.sorts.length;i+=1){
if(this.sorts[i].field===column.field){
return this.sorts[i].type||'asc';
}
}

return null;
},
getColumnSortLong:function getColumnSortLong(column){
return this.getColumnSort(column)==='asc'?'ascending':'descending';
},
getHeaderClasses:function getHeaderClasses(column,index){
var classes=Object.assign({},this.getClasses(index,'th'),{
sortable:this.isSortableColumn(column),
'sorting sorting-desc':this.getColumnSort(column)==='desc',
'sorting sorting-asc':this.getColumnSort(column)==='asc'});

return classes;
},
filterRows:function filterRows(columnFilters){
this.$emit('filter-changed',columnFilters);
},
getWidthStyle:function getWidthStyle(dom){
if(window&&window.getComputedStyle&&dom){
var cellStyle=window.getComputedStyle(dom,null);
return {
width:cellStyle.width};

}

return {
width:'auto'};

},
setColumnStyles:function setColumnStyles(){
var colStyles=[];

for(var i=0;i<this.columns.length;i++){
if(this.tableRef){
var skip=0;
if(this.selectable)skip++;
if(this.lineNumbers)skip++;
var cell=this.tableRef.rows[0].cells[i+skip];
colStyles.push(this.getWidthStyle(cell));
}else {
colStyles.push({
minWidth:this.columns[i].width?this.columns[i].width:'auto',
maxWidth:this.columns[i].width?this.columns[i].width:'auto',
width:this.columns[i].width?this.columns[i].width:'auto'});

}
}

this.columnStyles=colStyles;
},
getColumnStyle:function getColumnStyle(column,index){
var styleObject={
minWidth:column.width?column.width:'auto',
maxWidth:column.width?column.width:'auto',
width:column.width?column.width:'auto'};
//* if fixed header we need to get width from original table

if(this.tableRef){
if(this.selectable)index++;
if(this.lineNumbers)index++;
var cell=this.tableRef.rows[0].cells[index];
var cellStyle=window.getComputedStyle(cell,null);
styleObject.width=cellStyle.width;
}

return styleObject;
}},

mounted:function mounted(){
var _this=this;

this.$nextTick(function(){
// We're going to watch the parent element for resize events, and calculate column widths if it changes
if('ResizeObserver'in window){
_this.ro=new ResizeObserver(function(){
_this.setColumnStyles();
});

_this.ro.observe(_this.$parent.$el);// If this is a fixed-header table, we want to observe each column header from the non-fixed header.
// You can imagine two columns swapping widths, which wouldn't cause the above to trigger.
// This gets the first tr element of the primary table header, and iterates through its children (the th elements)


if(_this.tableRef){
Array.from(_this.$parent.$refs['table-header-primary'].$el.children[0].children).forEach(function(header){
_this.ro.observe(header);
});
}
}
});
},
beforeDestroy:function beforeDestroy(){
if(this.ro){
this.ro.disconnect();
}
},
components:{
'vgt-filter-row':__vue_component__$3}};



/* script */
var __vue_script__$4=script$4;
/* template */

var __vue_render__$4=function __vue_render__(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _c('thead',[_c('tr',[_vm.lineNumbers?_c('th',{
staticClass:"line-numbers",
attrs:{
"scope":"col"}}):

_vm._e(),_vm._v(" "),_vm.selectable?_c('th',{
staticClass:"vgt-checkbox-col",
attrs:{
"scope":"col"}},

[_c('input',{
attrs:{
"type":"checkbox"},

domProps:{
"checked":_vm.allSelected,
"indeterminate":_vm.allSelectedIndeterminate},

on:{
"change":_vm.toggleSelectAll}})]):

_vm._e(),_vm._v(" "),_vm._l(_vm.columns,function(column,index){
return !column.hidden?_c('th',{
key:index,
"class":_vm.getHeaderClasses(column,index),
style:_vm.columnStyles[index],
attrs:{
"scope":"col",
"title":column.tooltip,
"aria-sort":_vm.getColumnSortLong(column),
"aria-controls":"col-"+index}},

[_vm._t("table-column",[_vm._v("\n        "+_vm._s(column.label)+"\n      ")],{
"column":column}),
_vm._v(" "),_vm.isSortableColumn(column)?_c('button',{
on:{
"click":function click($event){
return _vm.sort($event,column);
}}},

[_c('span',{
staticClass:"sr-only"},
[_vm._v("\n          Sort table by "+_vm._s(column.label)+" in "+_vm._s(_vm.getColumnSortLong(column))+" order\n          ")])]):_vm._e()],2):_vm._e();
})],2),_vm._v(" "),_c("vgt-filter-row",{
ref:"filter-row",
tag:"tr",
attrs:{
"global-search-enabled":_vm.searchEnabled,
"line-numbers":_vm.lineNumbers,
"selectable":_vm.selectable,
"columns":_vm.columns,
"mode":_vm.mode,
"typed-columns":_vm.typedColumns},

on:{
"filter-changed":_vm.filterRows},

scopedSlots:_vm._u([{
key:"column-filter",
fn:function fn(props){
return [_vm._t("column-filter",null,{
"column":props.column,
"updateFilters":props.updateFilters})];

}}],
null,true)})],
1);
};

var __vue_staticRenderFns__$4=[];
/* style */

var __vue_inject_styles__$4=undefined;
/* scoped */

var __vue_scope_id__$4=undefined;
/* module identifier */

var __vue_module_identifier__$4=undefined;
/* functional template */

var __vue_is_functional_template__$4=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__$4=/*#__PURE__*/normalizeComponent({
render:__vue_render__$4,
staticRenderFns:__vue_staticRenderFns__$4},
__vue_inject_styles__$4,__vue_script__$4,__vue_scope_id__$4,__vue_is_functional_template__$4,__vue_module_identifier__$4,false,undefined,undefined,undefined);

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
var script$5={
name:'VgtHeaderRow',
props:{
headerRow:{
type:Object},

columns:{
type:Array},

lineNumbers:{
type:Boolean},

selectable:{
type:Boolean},

selectAllByGroup:{
type:Boolean},

collapsable:{
type:[Boolean,Number],
"default":false},

collectFormatted:{
type:Function},

formattedRow:{
type:Function},

getClasses:{
type:Function},

fullColspan:{
type:Number},

groupIndex:{
type:Number}},


data:function data(){
return {};
},
computed:{
allSelected:function allSelected(){
var headerRow=this.headerRow,
groupChildObject=this.groupChildObject;
return headerRow.children.filter(function(row){
return row.vgtSelected;
}).length===headerRow.children.length;
}},

methods:{
columnCollapsable:function columnCollapsable(currentIndex){
if(this.collapsable===true){
return currentIndex===0;
}

return currentIndex===this.collapsable;
},
toggleSelectGroup:function toggleSelectGroup(event){
this.$emit('on-select-group-change',{
groupIndex:this.groupIndex,
checked:event.target.checked});

}},

mounted:function mounted(){},
components:{}};


/* script */
var __vue_script__$5=script$5;
/* template */

var __vue_render__$5=function __vue_render__(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _c('tr',[_vm.headerRow.mode==='span'?_c('th',{
staticClass:"vgt-left-align vgt-row-header",
attrs:{
"colspan":_vm.fullColspan}},

[_vm.selectAllByGroup?[_vm._t("table-header-group-select",[_c('input',{
attrs:{
"type":"checkbox"},

domProps:{
"checked":_vm.allSelected},

on:{
"change":function change($event){
return _vm.toggleSelectGroup($event);
}}})],

{
"columns":_vm.columns,
"row":_vm.headerRow})]:
_vm._e(),_vm._v(" "),_c('span',{
on:{
"click":function click($event){
_vm.collapsable?_vm.$emit('vgtExpand',!_vm.headerRow.vgtIsExpanded):function(){};
}}},

[_vm.collapsable?_c('span',{
staticClass:"triangle",
"class":{
'expand':_vm.headerRow.vgtIsExpanded}}):

_vm._e(),_vm._v(" "),_vm._t("table-header-row",[_vm.headerRow.html?_c('span',{
domProps:{
"innerHTML":_vm._s(_vm.headerRow.label)}}):

_c('span',[_vm._v("\n          "+_vm._s(_vm.headerRow.label)+"\n        ")])],{
"row":_vm.headerRow})],
2)],2):_vm._e(),_vm._v(" "),_vm.headerRow.mode!=='span'&&_vm.lineNumbers?_c('th',{
staticClass:"vgt-row-header"}):
_vm._e(),_vm._v(" "),_vm.headerRow.mode!=='span'&&_vm.selectable?_c('th',{
staticClass:"vgt-row-header"},
[_vm.selectAllByGroup?[_vm._t("table-header-group-select",[_c('input',{
attrs:{
"type":"checkbox"},

domProps:{
"checked":_vm.allSelected},

on:{
"change":function change($event){
return _vm.toggleSelectGroup($event);
}}})],

{
"columns":_vm.columns,
"row":_vm.headerRow})]:
_vm._e()],2):_vm._e(),_vm._v(" "),_vm._l(_vm.columns,function(column,i){
return _vm.headerRow.mode!=='span'&&!column.hidden?_c('th',{
key:i,
staticClass:"vgt-row-header",
"class":_vm.getClasses(i,'td'),
on:{
"click":function click($event){
_vm.columnCollapsable(i)?_vm.$emit('vgtExpand',!_vm.headerRow.vgtIsExpanded):function(){};
}}},

[_vm.columnCollapsable(i)?_c('span',{
staticClass:"triangle",
"class":{
'expand':_vm.headerRow.vgtIsExpanded}}):

_vm._e(),_vm._v(" "),_vm._t("table-header-row",[!column.html?_c('span',[_vm._v("\n        "+_vm._s(_vm.collectFormatted(_vm.headerRow,column,true))+"\n      ")]):_vm._e(),_vm._v(" "),column.html?_c('span',{
domProps:{
"innerHTML":_vm._s(_vm.collectFormatted(_vm.headerRow,column,true))}}):

_vm._e()],{
"row":_vm.headerRow,
"column":column,
"formattedRow":_vm.formattedRow(_vm.headerRow,true)})],
2):_vm._e();
})],2);
};

var __vue_staticRenderFns__$5=[];
/* style */

var __vue_inject_styles__$5=undefined;
/* scoped */

var __vue_scope_id__$5=undefined;
/* module identifier */

var __vue_module_identifier__$5=undefined;
/* functional template */

var __vue_is_functional_template__$5=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__$5=/*#__PURE__*/normalizeComponent({
render:__vue_render__$5,
staticRenderFns:__vue_staticRenderFns__$5},
__vue_inject_styles__$5,__vue_script__$5,__vue_scope_id__$5,__vue_is_functional_template__$5,__vue_module_identifier__$5,false,undefined,undefined,undefined);

function toInteger(dirtyNumber){
if(dirtyNumber===null||dirtyNumber===true||dirtyNumber===false){
return NaN;
}

var number=Number(dirtyNumber);

if(isNaN(number)){
return number;
}

return number<0?Math.ceil(number):Math.floor(number);
}

function requiredArgs(required,args){
if(args.length<required){
throw new TypeError(required+' argument'+(required>1?'s':'')+' required, but only '+args.length+' present');
}
}

/**
 * @name toDate
 * @category Common Helpers
 * @summary Convert the given argument to an instance of Date.
 *
 * @description
 * Convert the given argument to an instance of Date.
 *
 * If the argument is an instance of Date, the function returns its clone.
 *
 * If the argument is a number, it is treated as a timestamp.
 *
 * If the argument is none of the above, the function returns Invalid Date.
 *
 * **Note**: *all* Date arguments passed to any *date-fns* function is processed by `toDate`.
 *
 * @param {Date|Number} argument - the value to convert
 * @returns {Date} the parsed date in the local time zone
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Clone the date:
 * const result = toDate(new Date(2014, 1, 11, 11, 30, 30))
 * //=> Tue Feb 11 2014 11:30:30
 *
 * @example
 * // Convert the timestamp to date:
 * const result = toDate(1392098430000)
 * //=> Tue Feb 11 2014 11:30:30
 */

function toDate(argument){
requiredArgs(1,arguments);
var argStr=Object.prototype.toString.call(argument);// Clone the date

if(argument instanceof Date||typeof argument==='object'&&argStr==='[object Date]'){
// Prevent the date to lose the milliseconds when passed to new Date() in IE10
return new Date(argument.getTime());
}else if(typeof argument==='number'||argStr==='[object Number]'){
return new Date(argument);
}else {
if((typeof argument==='string'||argStr==='[object String]')&&typeof console!=='undefined'){
// eslint-disable-next-line no-console
console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://git.io/fjule");// eslint-disable-next-line no-console

console.warn(new Error().stack);
}

return new Date(NaN);
}
}

/**
 * @name addMilliseconds
 * @category Millisecond Helpers
 * @summary Add the specified number of milliseconds to the given date.
 *
 * @description
 * Add the specified number of milliseconds to the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be added. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} the new date with the milliseconds added
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Add 750 milliseconds to 10 July 2014 12:45:30.000:
 * const result = addMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:30.750
 */

function addMilliseconds(dirtyDate,dirtyAmount){
requiredArgs(2,arguments);
var timestamp=toDate(dirtyDate).getTime();
var amount=toInteger(dirtyAmount);
return new Date(timestamp+amount);
}

var MILLISECONDS_IN_MINUTE=60000;

function getDateMillisecondsPart(date){
return date.getTime()%MILLISECONDS_IN_MINUTE;
}
/**
 * Google Chrome as of 67.0.3396.87 introduced timezones with offset that includes seconds.
 * They usually appear for dates that denote time before the timezones were introduced
 * (e.g. for 'Europe/Prague' timezone the offset is GMT+00:57:44 before 1 October 1891
 * and GMT+01:00:00 after that date)
 *
 * Date#getTimezoneOffset returns the offset in minutes and would return 57 for the example above,
 * which would lead to incorrect calculations.
 *
 * This function returns the timezone offset in milliseconds that takes seconds in account.
 */


function getTimezoneOffsetInMilliseconds(dirtyDate){
var date=new Date(dirtyDate.getTime());
var baseTimezoneOffset=Math.ceil(date.getTimezoneOffset());
date.setSeconds(0,0);
var hasNegativeUTCOffset=baseTimezoneOffset>0;
var millisecondsPartOfTimezoneOffset=hasNegativeUTCOffset?(MILLISECONDS_IN_MINUTE+getDateMillisecondsPart(date))%MILLISECONDS_IN_MINUTE:getDateMillisecondsPart(date);
return baseTimezoneOffset*MILLISECONDS_IN_MINUTE+millisecondsPartOfTimezoneOffset;
}

/**
 * @name compareAsc
 * @category Common Helpers
 * @summary Compare the two dates and return -1, 0 or 1.
 *
 * @description
 * Compare the two dates and return 1 if the first date is after the second,
 * -1 if the first date is before the second or 0 if dates are equal.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} dateLeft - the first date to compare
 * @param {Date|Number} dateRight - the second date to compare
 * @returns {Number} the result of the comparison
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Compare 11 February 1987 and 10 July 1989:
 * const result = compareAsc(new Date(1987, 1, 11), new Date(1989, 6, 10))
 * //=> -1
 *
 * @example
 * // Sort the array of dates:
 * const result = [
 *   new Date(1995, 6, 2),
 *   new Date(1987, 1, 11),
 *   new Date(1989, 6, 10)
 * ].sort(compareAsc)
 * //=> [
 * //   Wed Feb 11 1987 00:00:00,
 * //   Mon Jul 10 1989 00:00:00,
 * //   Sun Jul 02 1995 00:00:00
 * // ]
 */

function compareAsc(dirtyDateLeft,dirtyDateRight){
requiredArgs(2,arguments);
var dateLeft=toDate(dirtyDateLeft);
var dateRight=toDate(dirtyDateRight);
var diff=dateLeft.getTime()-dateRight.getTime();

if(diff<0){
return -1;
}else if(diff>0){
return 1;// Return 0 if diff is 0; return NaN if diff is NaN
}else {
return diff;
}
}

/**
 * @name isValid
 * @category Common Helpers
 * @summary Is the given date valid?
 *
 * @description
 * Returns false if argument is Invalid Date and true otherwise.
 * Argument is converted to Date using `toDate`. See [toDate]{@link https://date-fns.org/docs/toDate}
 * Invalid Date is a Date, whose time value is NaN.
 *
 * Time value of Date: http://es5.github.io/#x15.9.1.1
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - Now `isValid` doesn't throw an exception
 *   if the first argument is not an instance of Date.
 *   Instead, argument is converted beforehand using `toDate`.
 *
 *   Examples:
 *
 *   | `isValid` argument        | Before v2.0.0 | v2.0.0 onward |
 *   |---------------------------|---------------|---------------|
 *   | `new Date()`              | `true`        | `true`        |
 *   | `new Date('2016-01-01')`  | `true`        | `true`        |
 *   | `new Date('')`            | `false`       | `false`       |
 *   | `new Date(1488370835081)` | `true`        | `true`        |
 *   | `new Date(NaN)`           | `false`       | `false`       |
 *   | `'2016-01-01'`            | `TypeError`   | `false`       |
 *   | `''`                      | `TypeError`   | `false`       |
 *   | `1488370835081`           | `TypeError`   | `true`        |
 *   | `NaN`                     | `TypeError`   | `false`       |
 *
 *   We introduce this change to make *date-fns* consistent with ECMAScript behavior
 *   that try to coerce arguments to the expected type
 *   (which is also the case with other *date-fns* functions).
 *
 * @param {*} date - the date to check
 * @returns {Boolean} the date is valid
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // For the valid date:
 * var result = isValid(new Date(2014, 1, 31))
 * //=> true
 *
 * @example
 * // For the value, convertable into a date:
 * var result = isValid(1393804800000)
 * //=> true
 *
 * @example
 * // For the invalid date:
 * var result = isValid(new Date(''))
 * //=> false
 */

function isValid(dirtyDate){
requiredArgs(1,arguments);
var date=toDate(dirtyDate);
return !isNaN(date);
}

var formatDistanceLocale={
lessThanXSeconds:{
one:'less than a second',
other:'less than {{count}} seconds'},

xSeconds:{
one:'1 second',
other:'{{count}} seconds'},

halfAMinute:'half a minute',
lessThanXMinutes:{
one:'less than a minute',
other:'less than {{count}} minutes'},

xMinutes:{
one:'1 minute',
other:'{{count}} minutes'},

aboutXHours:{
one:'about 1 hour',
other:'about {{count}} hours'},

xHours:{
one:'1 hour',
other:'{{count}} hours'},

xDays:{
one:'1 day',
other:'{{count}} days'},

aboutXWeeks:{
one:'about 1 week',
other:'about {{count}} weeks'},

xWeeks:{
one:'1 week',
other:'{{count}} weeks'},

aboutXMonths:{
one:'about 1 month',
other:'about {{count}} months'},

xMonths:{
one:'1 month',
other:'{{count}} months'},

aboutXYears:{
one:'about 1 year',
other:'about {{count}} years'},

xYears:{
one:'1 year',
other:'{{count}} years'},

overXYears:{
one:'over 1 year',
other:'over {{count}} years'},

almostXYears:{
one:'almost 1 year',
other:'almost {{count}} years'}};


function formatDistance(token,count,options){
options=options||{};
var result;

if(typeof formatDistanceLocale[token]==='string'){
result=formatDistanceLocale[token];
}else if(count===1){
result=formatDistanceLocale[token].one;
}else {
result=formatDistanceLocale[token].other.replace('{{count}}',count);
}

if(options.addSuffix){
if(options.comparison>0){
return 'in '+result;
}else {
return result+' ago';
}
}

return result;
}

function buildFormatLongFn(args){
return function(dirtyOptions){
var options=dirtyOptions||{};
var width=options.width?String(options.width):args.defaultWidth;
var format=args.formats[width]||args.formats[args.defaultWidth];
return format;
};
}

var dateFormats={
full:'EEEE, MMMM do, y',
long:'MMMM do, y',
medium:'MMM d, y',
short:'MM/dd/yyyy'};

var timeFormats={
full:'h:mm:ss a zzzz',
long:'h:mm:ss a z',
medium:'h:mm:ss a',
short:'h:mm a'};

var dateTimeFormats={
full:"{{date}} 'at' {{time}}",
long:"{{date}} 'at' {{time}}",
medium:'{{date}}, {{time}}',
short:'{{date}}, {{time}}'};

var formatLong={
date:buildFormatLongFn({
formats:dateFormats,
defaultWidth:'full'}),

time:buildFormatLongFn({
formats:timeFormats,
defaultWidth:'full'}),

dateTime:buildFormatLongFn({
formats:dateTimeFormats,
defaultWidth:'full'})};



var formatRelativeLocale={
lastWeek:"'last' eeee 'at' p",
yesterday:"'yesterday at' p",
today:"'today at' p",
tomorrow:"'tomorrow at' p",
nextWeek:"eeee 'at' p",
other:'P'};

function formatRelative(token,_date,_baseDate,_options){
return formatRelativeLocale[token];
}

function buildLocalizeFn(args){
return function(dirtyIndex,dirtyOptions){
var options=dirtyOptions||{};
var context=options.context?String(options.context):'standalone';
var valuesArray;

if(context==='formatting'&&args.formattingValues){
var defaultWidth=args.defaultFormattingWidth||args.defaultWidth;
var width=options.width?String(options.width):defaultWidth;
valuesArray=args.formattingValues[width]||args.formattingValues[defaultWidth];
}else {
var _defaultWidth=args.defaultWidth;

var _width=options.width?String(options.width):args.defaultWidth;

valuesArray=args.values[_width]||args.values[_defaultWidth];
}

var index=args.argumentCallback?args.argumentCallback(dirtyIndex):dirtyIndex;
return valuesArray[index];
};
}

var eraValues={
narrow:['B','A'],
abbreviated:['BC','AD'],
wide:['Before Christ','Anno Domini']};

var quarterValues={
narrow:['1','2','3','4'],
abbreviated:['Q1','Q2','Q3','Q4'],
wide:['1st quarter','2nd quarter','3rd quarter','4th quarter']// Note: in English, the names of days of the week and months are capitalized.
// If you are making a new locale based on this one, check if the same is true for the language you're working on.
// Generally, formatted dates should look like they are in the middle of a sentence,
// e.g. in Spanish language the weekdays and months should be in the lowercase.
};

var monthValues={
narrow:['J','F','M','A','M','J','J','A','S','O','N','D'],
abbreviated:['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'],
wide:['January','February','March','April','May','June','July','August','September','October','November','December']};

var dayValues={
narrow:['S','M','T','W','T','F','S'],
short:['Su','Mo','Tu','We','Th','Fr','Sa'],
abbreviated:['Sun','Mon','Tue','Wed','Thu','Fri','Sat'],
wide:['Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday']};

var dayPeriodValues={
narrow:{
am:'a',
pm:'p',
midnight:'mi',
noon:'n',
morning:'morning',
afternoon:'afternoon',
evening:'evening',
night:'night'},

abbreviated:{
am:'AM',
pm:'PM',
midnight:'midnight',
noon:'noon',
morning:'morning',
afternoon:'afternoon',
evening:'evening',
night:'night'},

wide:{
am:'a.m.',
pm:'p.m.',
midnight:'midnight',
noon:'noon',
morning:'morning',
afternoon:'afternoon',
evening:'evening',
night:'night'}};


var formattingDayPeriodValues={
narrow:{
am:'a',
pm:'p',
midnight:'mi',
noon:'n',
morning:'in the morning',
afternoon:'in the afternoon',
evening:'in the evening',
night:'at night'},

abbreviated:{
am:'AM',
pm:'PM',
midnight:'midnight',
noon:'noon',
morning:'in the morning',
afternoon:'in the afternoon',
evening:'in the evening',
night:'at night'},

wide:{
am:'a.m.',
pm:'p.m.',
midnight:'midnight',
noon:'noon',
morning:'in the morning',
afternoon:'in the afternoon',
evening:'in the evening',
night:'at night'}};



function ordinalNumber(dirtyNumber,_dirtyOptions){
var number=Number(dirtyNumber);// If ordinal numbers depend on context, for example,
// if they are different for different grammatical genders,
// use `options.unit`:
//
//   var options = dirtyOptions || {}
//   var unit = String(options.unit)
//
// where `unit` can be 'year', 'quarter', 'month', 'week', 'date', 'dayOfYear',
// 'day', 'hour', 'minute', 'second'

var rem100=number%100;

if(rem100>20||rem100<10){
switch(rem100%10){
case 1:
return number+'st';

case 2:
return number+'nd';

case 3:
return number+'rd';}

}

return number+'th';
}

var localize={
ordinalNumber:ordinalNumber,
era:buildLocalizeFn({
values:eraValues,
defaultWidth:'wide'}),

quarter:buildLocalizeFn({
values:quarterValues,
defaultWidth:'wide',
argumentCallback:function argumentCallback(quarter){
return Number(quarter)-1;
}}),

month:buildLocalizeFn({
values:monthValues,
defaultWidth:'wide'}),

day:buildLocalizeFn({
values:dayValues,
defaultWidth:'wide'}),

dayPeriod:buildLocalizeFn({
values:dayPeriodValues,
defaultWidth:'wide',
formattingValues:formattingDayPeriodValues,
defaultFormattingWidth:'wide'})};



function buildMatchPatternFn(args){
return function(dirtyString,dirtyOptions){
var string=String(dirtyString);
var options=dirtyOptions||{};
var matchResult=string.match(args.matchPattern);

if(!matchResult){
return null;
}

var matchedString=matchResult[0];
var parseResult=string.match(args.parsePattern);

if(!parseResult){
return null;
}

var value=args.valueCallback?args.valueCallback(parseResult[0]):parseResult[0];
value=options.valueCallback?options.valueCallback(value):value;
return {
value:value,
rest:string.slice(matchedString.length)};

};
}

function buildMatchFn(args){
return function(dirtyString,dirtyOptions){
var string=String(dirtyString);
var options=dirtyOptions||{};
var width=options.width;
var matchPattern=width&&args.matchPatterns[width]||args.matchPatterns[args.defaultMatchWidth];
var matchResult=string.match(matchPattern);

if(!matchResult){
return null;
}

var matchedString=matchResult[0];
var parsePatterns=width&&args.parsePatterns[width]||args.parsePatterns[args.defaultParseWidth];
var value;

if(Object.prototype.toString.call(parsePatterns)==='[object Array]'){
value=findIndex(parsePatterns,function(pattern){
return pattern.test(matchedString);
});
}else {
value=findKey(parsePatterns,function(pattern){
return pattern.test(matchedString);
});
}

value=args.valueCallback?args.valueCallback(value):value;
value=options.valueCallback?options.valueCallback(value):value;
return {
value:value,
rest:string.slice(matchedString.length)};

};
}

function findKey(object,predicate){
for(var key in object){
if(object.hasOwnProperty(key)&&predicate(object[key])){
return key;
}
}
}

function findIndex(array,predicate){
for(var key=0;key<array.length;key++){
if(predicate(array[key])){
return key;
}
}
}

var matchOrdinalNumberPattern=/^(\d+)(th|st|nd|rd)?/i;
var parseOrdinalNumberPattern=/\d+/i;
var matchEraPatterns={
narrow:/^(b|a)/i,
abbreviated:/^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,
wide:/^(before christ|before common era|anno domini|common era)/i};

var parseEraPatterns={
any:[/^b/i,/^(a|c)/i]};

var matchQuarterPatterns={
narrow:/^[1234]/i,
abbreviated:/^q[1234]/i,
wide:/^[1234](th|st|nd|rd)? quarter/i};

var parseQuarterPatterns={
any:[/1/i,/2/i,/3/i,/4/i]};

var matchMonthPatterns={
narrow:/^[jfmasond]/i,
abbreviated:/^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,
wide:/^(january|february|march|april|may|june|july|august|september|october|november|december)/i};

var parseMonthPatterns={
narrow:[/^j/i,/^f/i,/^m/i,/^a/i,/^m/i,/^j/i,/^j/i,/^a/i,/^s/i,/^o/i,/^n/i,/^d/i],
any:[/^ja/i,/^f/i,/^mar/i,/^ap/i,/^may/i,/^jun/i,/^jul/i,/^au/i,/^s/i,/^o/i,/^n/i,/^d/i]};

var matchDayPatterns={
narrow:/^[smtwf]/i,
short:/^(su|mo|tu|we|th|fr|sa)/i,
abbreviated:/^(sun|mon|tue|wed|thu|fri|sat)/i,
wide:/^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i};

var parseDayPatterns={
narrow:[/^s/i,/^m/i,/^t/i,/^w/i,/^t/i,/^f/i,/^s/i],
any:[/^su/i,/^m/i,/^tu/i,/^w/i,/^th/i,/^f/i,/^sa/i]};

var matchDayPeriodPatterns={
narrow:/^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,
any:/^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i};

var parseDayPeriodPatterns={
any:{
am:/^a/i,
pm:/^p/i,
midnight:/^mi/i,
noon:/^no/i,
morning:/morning/i,
afternoon:/afternoon/i,
evening:/evening/i,
night:/night/i}};


var match={
ordinalNumber:buildMatchPatternFn({
matchPattern:matchOrdinalNumberPattern,
parsePattern:parseOrdinalNumberPattern,
valueCallback:function valueCallback(value){
return parseInt(value,10);
}}),

era:buildMatchFn({
matchPatterns:matchEraPatterns,
defaultMatchWidth:'wide',
parsePatterns:parseEraPatterns,
defaultParseWidth:'any'}),

quarter:buildMatchFn({
matchPatterns:matchQuarterPatterns,
defaultMatchWidth:'wide',
parsePatterns:parseQuarterPatterns,
defaultParseWidth:'any',
valueCallback:function valueCallback(index){
return index+1;
}}),

month:buildMatchFn({
matchPatterns:matchMonthPatterns,
defaultMatchWidth:'wide',
parsePatterns:parseMonthPatterns,
defaultParseWidth:'any'}),

day:buildMatchFn({
matchPatterns:matchDayPatterns,
defaultMatchWidth:'wide',
parsePatterns:parseDayPatterns,
defaultParseWidth:'any'}),

dayPeriod:buildMatchFn({
matchPatterns:matchDayPeriodPatterns,
defaultMatchWidth:'any',
parsePatterns:parseDayPeriodPatterns,
defaultParseWidth:'any'})};



/**
 * @type {Locale}
 * @category Locales
 * @summary English locale (United States).
 * @language English
 * @iso-639-2 eng
 * @author Sasha Koss [@kossnocorp]{@link https://github.com/kossnocorp}
 * @author Lesha Koss [@leshakoss]{@link https://github.com/leshakoss}
 */

var locale={
code:'en-US',
formatDistance:formatDistance,
formatLong:formatLong,
formatRelative:formatRelative,
localize:localize,
match:match,
options:{
weekStartsOn:0
/* Sunday */,

firstWeekContainsDate:1}};



/**
 * @name subMilliseconds
 * @category Millisecond Helpers
 * @summary Subtract the specified number of milliseconds from the given date.
 *
 * @description
 * Subtract the specified number of milliseconds from the given date.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be subtracted. Positive decimals will be rounded using `Math.floor`, decimals less than zero will be rounded using `Math.ceil`.
 * @returns {Date} the new date with the milliseconds subtracted
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Subtract 750 milliseconds from 10 July 2014 12:45:30.000:
 * const result = subMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:29.250
 */

function subMilliseconds(dirtyDate,dirtyAmount){
requiredArgs(2,arguments);
var amount=toInteger(dirtyAmount);
return addMilliseconds(dirtyDate,-amount);
}

function addLeadingZeros(number,targetLength){
var sign=number<0?'-':'';
var output=Math.abs(number).toString();

while(output.length<targetLength){
output='0'+output;
}

return sign+output;
}

/*
 * |     | Unit                           |     | Unit                           |
 * |-----|--------------------------------|-----|--------------------------------|
 * |  a  | AM, PM                         |  A* |                                |
 * |  d  | Day of month                   |  D  |                                |
 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
 * |  m  | Minute                         |  M  | Month                          |
 * |  s  | Second                         |  S  | Fraction of second             |
 * |  y  | Year (abs)                     |  Y  |                                |
 *
 * Letters marked by * are not implemented but reserved by Unicode standard.
 */

var formatters={
// Year
y:function y(date,token){
// From http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_tokens
// | Year     |     y | yy |   yyy |  yyyy | yyyyy |
// |----------|-------|----|-------|-------|-------|
// | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
// | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
// | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
// | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
// | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |
var signedYear=date.getUTCFullYear();// Returns 1 for 1 BC (which is year 0 in JavaScript)

var year=signedYear>0?signedYear:1-signedYear;
return addLeadingZeros(token==='yy'?year%100:year,token.length);
},
// Month
M:function M(date,token){
var month=date.getUTCMonth();
return token==='M'?String(month+1):addLeadingZeros(month+1,2);
},
// Day of the month
d:function d(date,token){
return addLeadingZeros(date.getUTCDate(),token.length);
},
// AM or PM
a:function a(date,token){
var dayPeriodEnumValue=date.getUTCHours()/12>=1?'pm':'am';

switch(token){
case'a':
case'aa':
return dayPeriodEnumValue.toUpperCase();

case'aaa':
return dayPeriodEnumValue;

case'aaaaa':
return dayPeriodEnumValue[0];

case'aaaa':
default:
return dayPeriodEnumValue==='am'?'a.m.':'p.m.';}

},
// Hour [1-12]
h:function h(date,token){
return addLeadingZeros(date.getUTCHours()%12||12,token.length);
},
// Hour [0-23]
H:function H(date,token){
return addLeadingZeros(date.getUTCHours(),token.length);
},
// Minute
m:function m(date,token){
return addLeadingZeros(date.getUTCMinutes(),token.length);
},
// Second
s:function s(date,token){
return addLeadingZeros(date.getUTCSeconds(),token.length);
},
// Fraction of second
S:function S(date,token){
var numberOfDigits=token.length;
var milliseconds=date.getUTCMilliseconds();
var fractionalSeconds=Math.floor(milliseconds*Math.pow(10,numberOfDigits-3));
return addLeadingZeros(fractionalSeconds,token.length);
}};


var MILLISECONDS_IN_DAY=86400000;// This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCDayOfYear(dirtyDate){
requiredArgs(1,arguments);
var date=toDate(dirtyDate);
var timestamp=date.getTime();
date.setUTCMonth(0,1);
date.setUTCHours(0,0,0,0);
var startOfYearTimestamp=date.getTime();
var difference=timestamp-startOfYearTimestamp;
return Math.floor(difference/MILLISECONDS_IN_DAY)+1;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCISOWeek(dirtyDate){
requiredArgs(1,arguments);
var weekStartsOn=1;
var date=toDate(dirtyDate);
var day=date.getUTCDay();
var diff=(day<weekStartsOn?7:0)+day-weekStartsOn;
date.setUTCDate(date.getUTCDate()-diff);
date.setUTCHours(0,0,0,0);
return date;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCISOWeekYear(dirtyDate){
requiredArgs(1,arguments);
var date=toDate(dirtyDate);
var year=date.getUTCFullYear();
var fourthOfJanuaryOfNextYear=new Date(0);
fourthOfJanuaryOfNextYear.setUTCFullYear(year+1,0,4);
fourthOfJanuaryOfNextYear.setUTCHours(0,0,0,0);
var startOfNextYear=startOfUTCISOWeek(fourthOfJanuaryOfNextYear);
var fourthOfJanuaryOfThisYear=new Date(0);
fourthOfJanuaryOfThisYear.setUTCFullYear(year,0,4);
fourthOfJanuaryOfThisYear.setUTCHours(0,0,0,0);
var startOfThisYear=startOfUTCISOWeek(fourthOfJanuaryOfThisYear);

if(date.getTime()>=startOfNextYear.getTime()){
return year+1;
}else if(date.getTime()>=startOfThisYear.getTime()){
return year;
}else {
return year-1;
}
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCISOWeekYear(dirtyDate){
requiredArgs(1,arguments);
var year=getUTCISOWeekYear(dirtyDate);
var fourthOfJanuary=new Date(0);
fourthOfJanuary.setUTCFullYear(year,0,4);
fourthOfJanuary.setUTCHours(0,0,0,0);
var date=startOfUTCISOWeek(fourthOfJanuary);
return date;
}

var MILLISECONDS_IN_WEEK=604800000;// This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCISOWeek(dirtyDate){
requiredArgs(1,arguments);
var date=toDate(dirtyDate);
var diff=startOfUTCISOWeek(date).getTime()-startOfUTCISOWeekYear(date).getTime();// Round the number of days to the nearest integer
// because the number of milliseconds in a week is not constant
// (e.g. it's different in the week of the daylight saving time clock shift)

return Math.round(diff/MILLISECONDS_IN_WEEK)+1;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCWeek(dirtyDate,dirtyOptions){
requiredArgs(1,arguments);
var options=dirtyOptions||{};
var locale=options.locale;
var localeWeekStartsOn=locale&&locale.options&&locale.options.weekStartsOn;
var defaultWeekStartsOn=localeWeekStartsOn==null?0:toInteger(localeWeekStartsOn);
var weekStartsOn=options.weekStartsOn==null?defaultWeekStartsOn:toInteger(options.weekStartsOn);// Test if weekStartsOn is between 0 and 6 _and_ is not NaN

if(!(weekStartsOn>=0&&weekStartsOn<=6)){
throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
}

var date=toDate(dirtyDate);
var day=date.getUTCDay();
var diff=(day<weekStartsOn?7:0)+day-weekStartsOn;
date.setUTCDate(date.getUTCDate()-diff);
date.setUTCHours(0,0,0,0);
return date;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCWeekYear(dirtyDate,dirtyOptions){
requiredArgs(1,arguments);
var date=toDate(dirtyDate,dirtyOptions);
var year=date.getUTCFullYear();
var options=dirtyOptions||{};
var locale=options.locale;
var localeFirstWeekContainsDate=locale&&locale.options&&locale.options.firstWeekContainsDate;
var defaultFirstWeekContainsDate=localeFirstWeekContainsDate==null?1:toInteger(localeFirstWeekContainsDate);
var firstWeekContainsDate=options.firstWeekContainsDate==null?defaultFirstWeekContainsDate:toInteger(options.firstWeekContainsDate);// Test if weekStartsOn is between 1 and 7 _and_ is not NaN

if(!(firstWeekContainsDate>=1&&firstWeekContainsDate<=7)){
throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
}

var firstWeekOfNextYear=new Date(0);
firstWeekOfNextYear.setUTCFullYear(year+1,0,firstWeekContainsDate);
firstWeekOfNextYear.setUTCHours(0,0,0,0);
var startOfNextYear=startOfUTCWeek(firstWeekOfNextYear,dirtyOptions);
var firstWeekOfThisYear=new Date(0);
firstWeekOfThisYear.setUTCFullYear(year,0,firstWeekContainsDate);
firstWeekOfThisYear.setUTCHours(0,0,0,0);
var startOfThisYear=startOfUTCWeek(firstWeekOfThisYear,dirtyOptions);

if(date.getTime()>=startOfNextYear.getTime()){
return year+1;
}else if(date.getTime()>=startOfThisYear.getTime()){
return year;
}else {
return year-1;
}
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function startOfUTCWeekYear(dirtyDate,dirtyOptions){
requiredArgs(1,arguments);
var options=dirtyOptions||{};
var locale=options.locale;
var localeFirstWeekContainsDate=locale&&locale.options&&locale.options.firstWeekContainsDate;
var defaultFirstWeekContainsDate=localeFirstWeekContainsDate==null?1:toInteger(localeFirstWeekContainsDate);
var firstWeekContainsDate=options.firstWeekContainsDate==null?defaultFirstWeekContainsDate:toInteger(options.firstWeekContainsDate);
var year=getUTCWeekYear(dirtyDate,dirtyOptions);
var firstWeek=new Date(0);
firstWeek.setUTCFullYear(year,0,firstWeekContainsDate);
firstWeek.setUTCHours(0,0,0,0);
var date=startOfUTCWeek(firstWeek,dirtyOptions);
return date;
}

var MILLISECONDS_IN_WEEK$1=604800000;// This function will be a part of public API when UTC function will be implemented.
// See issue: https://github.com/date-fns/date-fns/issues/376

function getUTCWeek(dirtyDate,options){
requiredArgs(1,arguments);
var date=toDate(dirtyDate);
var diff=startOfUTCWeek(date,options).getTime()-startOfUTCWeekYear(date,options).getTime();// Round the number of days to the nearest integer
// because the number of milliseconds in a week is not constant
// (e.g. it's different in the week of the daylight saving time clock shift)

return Math.round(diff/MILLISECONDS_IN_WEEK$1)+1;
}

var dayPeriodEnum={
am:'am',
pm:'pm',
midnight:'midnight',
noon:'noon',
morning:'morning',
afternoon:'afternoon',
evening:'evening',
night:'night'
/*
   * |     | Unit                           |     | Unit                           |
   * |-----|--------------------------------|-----|--------------------------------|
   * |  a  | AM, PM                         |  A* | Milliseconds in day            |
   * |  b  | AM, PM, noon, midnight         |  B  | Flexible day period            |
   * |  c  | Stand-alone local day of week  |  C* | Localized hour w/ day period   |
   * |  d  | Day of month                   |  D  | Day of year                    |
   * |  e  | Local day of week              |  E  | Day of week                    |
   * |  f  |                                |  F* | Day of week in month           |
   * |  g* | Modified Julian day            |  G  | Era                            |
   * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
   * |  i! | ISO day of week                |  I! | ISO week of year               |
   * |  j* | Localized hour w/ day period   |  J* | Localized hour w/o day period  |
   * |  k  | Hour [1-24]                    |  K  | Hour [0-11]                    |
   * |  l* | (deprecated)                   |  L  | Stand-alone month              |
   * |  m  | Minute                         |  M  | Month                          |
   * |  n  |                                |  N  |                                |
   * |  o! | Ordinal number modifier        |  O  | Timezone (GMT)                 |
   * |  p! | Long localized time            |  P! | Long localized date            |
   * |  q  | Stand-alone quarter            |  Q  | Quarter                        |
   * |  r* | Related Gregorian year         |  R! | ISO week-numbering year        |
   * |  s  | Second                         |  S  | Fraction of second             |
   * |  t! | Seconds timestamp              |  T! | Milliseconds timestamp         |
   * |  u  | Extended year                  |  U* | Cyclic year                    |
   * |  v* | Timezone (generic non-locat.)  |  V* | Timezone (location)            |
   * |  w  | Local week of year             |  W* | Week of month                  |
   * |  x  | Timezone (ISO-8601 w/o Z)      |  X  | Timezone (ISO-8601)            |
   * |  y  | Year (abs)                     |  Y  | Local week-numbering year      |
   * |  z  | Timezone (specific non-locat.) |  Z* | Timezone (aliases)             |
   *
   * Letters marked by * are not implemented but reserved by Unicode standard.
   *
   * Letters marked by ! are non-standard, but implemented by date-fns:
   * - `o` modifies the previous token to turn it into an ordinal (see `format` docs)
   * - `i` is ISO day of week. For `i` and `ii` is returns numeric ISO week days,
   *   i.e. 7 for Sunday, 1 for Monday, etc.
   * - `I` is ISO week of year, as opposed to `w` which is local week of year.
   * - `R` is ISO week-numbering year, as opposed to `Y` which is local week-numbering year.
   *   `R` is supposed to be used in conjunction with `I` and `i`
   *   for universal ISO week-numbering date, whereas
   *   `Y` is supposed to be used in conjunction with `w` and `e`
   *   for week-numbering date specific to the locale.
   * - `P` is long localized date format
   * - `p` is long localized time format
   */};


var formatters$1={
// Era
G:function G(date,token,localize){
var era=date.getUTCFullYear()>0?1:0;

switch(token){
// AD, BC
case'G':
case'GG':
case'GGG':
return localize.era(era,{
width:'abbreviated'});

// A, B

case'GGGGG':
return localize.era(era,{
width:'narrow'});

// Anno Domini, Before Christ

case'GGGG':
default:
return localize.era(era,{
width:'wide'});}


},
// Year
y:function y(date,token,localize){
// Ordinal number
if(token==='yo'){
var signedYear=date.getUTCFullYear();// Returns 1 for 1 BC (which is year 0 in JavaScript)

var year=signedYear>0?signedYear:1-signedYear;
return localize.ordinalNumber(year,{
unit:'year'});

}

return formatters.y(date,token);
},
// Local week-numbering year
Y:function Y(date,token,localize,options){
var signedWeekYear=getUTCWeekYear(date,options);// Returns 1 for 1 BC (which is year 0 in JavaScript)

var weekYear=signedWeekYear>0?signedWeekYear:1-signedWeekYear;// Two digit year

if(token==='YY'){
var twoDigitYear=weekYear%100;
return addLeadingZeros(twoDigitYear,2);
}// Ordinal number


if(token==='Yo'){
return localize.ordinalNumber(weekYear,{
unit:'year'});

}// Padding


return addLeadingZeros(weekYear,token.length);
},
// ISO week-numbering year
R:function R(date,token){
var isoWeekYear=getUTCISOWeekYear(date);// Padding

return addLeadingZeros(isoWeekYear,token.length);
},
// Extended year. This is a single number designating the year of this calendar system.
// The main difference between `y` and `u` localizers are B.C. years:
// | Year | `y` | `u` |
// |------|-----|-----|
// | AC 1 |   1 |   1 |
// | BC 1 |   1 |   0 |
// | BC 2 |   2 |  -1 |
// Also `yy` always returns the last two digits of a year,
// while `uu` pads single digit years to 2 characters and returns other years unchanged.
u:function u(date,token){
var year=date.getUTCFullYear();
return addLeadingZeros(year,token.length);
},
// Quarter
Q:function Q(date,token,localize){
var quarter=Math.ceil((date.getUTCMonth()+1)/3);

switch(token){
// 1, 2, 3, 4
case'Q':
return String(quarter);
// 01, 02, 03, 04

case'QQ':
return addLeadingZeros(quarter,2);
// 1st, 2nd, 3rd, 4th

case'Qo':
return localize.ordinalNumber(quarter,{
unit:'quarter'});

// Q1, Q2, Q3, Q4

case'QQQ':
return localize.quarter(quarter,{
width:'abbreviated',
context:'formatting'});

// 1, 2, 3, 4 (narrow quarter; could be not numerical)

case'QQQQQ':
return localize.quarter(quarter,{
width:'narrow',
context:'formatting'});

// 1st quarter, 2nd quarter, ...

case'QQQQ':
default:
return localize.quarter(quarter,{
width:'wide',
context:'formatting'});}


},
// Stand-alone quarter
q:function q(date,token,localize){
var quarter=Math.ceil((date.getUTCMonth()+1)/3);

switch(token){
// 1, 2, 3, 4
case'q':
return String(quarter);
// 01, 02, 03, 04

case'qq':
return addLeadingZeros(quarter,2);
// 1st, 2nd, 3rd, 4th

case'qo':
return localize.ordinalNumber(quarter,{
unit:'quarter'});

// Q1, Q2, Q3, Q4

case'qqq':
return localize.quarter(quarter,{
width:'abbreviated',
context:'standalone'});

// 1, 2, 3, 4 (narrow quarter; could be not numerical)

case'qqqqq':
return localize.quarter(quarter,{
width:'narrow',
context:'standalone'});

// 1st quarter, 2nd quarter, ...

case'qqqq':
default:
return localize.quarter(quarter,{
width:'wide',
context:'standalone'});}


},
// Month
M:function M(date,token,localize){
var month=date.getUTCMonth();

switch(token){
case'M':
case'MM':
return formatters.M(date,token);
// 1st, 2nd, ..., 12th

case'Mo':
return localize.ordinalNumber(month+1,{
unit:'month'});

// Jan, Feb, ..., Dec

case'MMM':
return localize.month(month,{
width:'abbreviated',
context:'formatting'});

// J, F, ..., D

case'MMMMM':
return localize.month(month,{
width:'narrow',
context:'formatting'});

// January, February, ..., December

case'MMMM':
default:
return localize.month(month,{
width:'wide',
context:'formatting'});}


},
// Stand-alone month
L:function L(date,token,localize){
var month=date.getUTCMonth();

switch(token){
// 1, 2, ..., 12
case'L':
return String(month+1);
// 01, 02, ..., 12

case'LL':
return addLeadingZeros(month+1,2);
// 1st, 2nd, ..., 12th

case'Lo':
return localize.ordinalNumber(month+1,{
unit:'month'});

// Jan, Feb, ..., Dec

case'LLL':
return localize.month(month,{
width:'abbreviated',
context:'standalone'});

// J, F, ..., D

case'LLLLL':
return localize.month(month,{
width:'narrow',
context:'standalone'});

// January, February, ..., December

case'LLLL':
default:
return localize.month(month,{
width:'wide',
context:'standalone'});}


},
// Local week of year
w:function w(date,token,localize,options){
var week=getUTCWeek(date,options);

if(token==='wo'){
return localize.ordinalNumber(week,{
unit:'week'});

}

return addLeadingZeros(week,token.length);
},
// ISO week of year
I:function I(date,token,localize){
var isoWeek=getUTCISOWeek(date);

if(token==='Io'){
return localize.ordinalNumber(isoWeek,{
unit:'week'});

}

return addLeadingZeros(isoWeek,token.length);
},
// Day of the month
d:function d(date,token,localize){
if(token==='do'){
return localize.ordinalNumber(date.getUTCDate(),{
unit:'date'});

}

return formatters.d(date,token);
},
// Day of year
D:function D(date,token,localize){
var dayOfYear=getUTCDayOfYear(date);

if(token==='Do'){
return localize.ordinalNumber(dayOfYear,{
unit:'dayOfYear'});

}

return addLeadingZeros(dayOfYear,token.length);
},
// Day of week
E:function E(date,token,localize){
var dayOfWeek=date.getUTCDay();

switch(token){
// Tue
case'E':
case'EE':
case'EEE':
return localize.day(dayOfWeek,{
width:'abbreviated',
context:'formatting'});

// T

case'EEEEE':
return localize.day(dayOfWeek,{
width:'narrow',
context:'formatting'});

// Tu

case'EEEEEE':
return localize.day(dayOfWeek,{
width:'short',
context:'formatting'});

// Tuesday

case'EEEE':
default:
return localize.day(dayOfWeek,{
width:'wide',
context:'formatting'});}


},
// Local day of week
e:function e(date,token,localize,options){
var dayOfWeek=date.getUTCDay();
var localDayOfWeek=(dayOfWeek-options.weekStartsOn+8)%7||7;

switch(token){
// Numerical value (Nth day of week with current locale or weekStartsOn)
case'e':
return String(localDayOfWeek);
// Padded numerical value

case'ee':
return addLeadingZeros(localDayOfWeek,2);
// 1st, 2nd, ..., 7th

case'eo':
return localize.ordinalNumber(localDayOfWeek,{
unit:'day'});


case'eee':
return localize.day(dayOfWeek,{
width:'abbreviated',
context:'formatting'});

// T

case'eeeee':
return localize.day(dayOfWeek,{
width:'narrow',
context:'formatting'});

// Tu

case'eeeeee':
return localize.day(dayOfWeek,{
width:'short',
context:'formatting'});

// Tuesday

case'eeee':
default:
return localize.day(dayOfWeek,{
width:'wide',
context:'formatting'});}


},
// Stand-alone local day of week
c:function c(date,token,localize,options){
var dayOfWeek=date.getUTCDay();
var localDayOfWeek=(dayOfWeek-options.weekStartsOn+8)%7||7;

switch(token){
// Numerical value (same as in `e`)
case'c':
return String(localDayOfWeek);
// Padded numerical value

case'cc':
return addLeadingZeros(localDayOfWeek,token.length);
// 1st, 2nd, ..., 7th

case'co':
return localize.ordinalNumber(localDayOfWeek,{
unit:'day'});


case'ccc':
return localize.day(dayOfWeek,{
width:'abbreviated',
context:'standalone'});

// T

case'ccccc':
return localize.day(dayOfWeek,{
width:'narrow',
context:'standalone'});

// Tu

case'cccccc':
return localize.day(dayOfWeek,{
width:'short',
context:'standalone'});

// Tuesday

case'cccc':
default:
return localize.day(dayOfWeek,{
width:'wide',
context:'standalone'});}


},
// ISO day of week
i:function i(date,token,localize){
var dayOfWeek=date.getUTCDay();
var isoDayOfWeek=dayOfWeek===0?7:dayOfWeek;

switch(token){
// 2
case'i':
return String(isoDayOfWeek);
// 02

case'ii':
return addLeadingZeros(isoDayOfWeek,token.length);
// 2nd

case'io':
return localize.ordinalNumber(isoDayOfWeek,{
unit:'day'});

// Tue

case'iii':
return localize.day(dayOfWeek,{
width:'abbreviated',
context:'formatting'});

// T

case'iiiii':
return localize.day(dayOfWeek,{
width:'narrow',
context:'formatting'});

// Tu

case'iiiiii':
return localize.day(dayOfWeek,{
width:'short',
context:'formatting'});

// Tuesday

case'iiii':
default:
return localize.day(dayOfWeek,{
width:'wide',
context:'formatting'});}


},
// AM or PM
a:function a(date,token,localize){
var hours=date.getUTCHours();
var dayPeriodEnumValue=hours/12>=1?'pm':'am';

switch(token){
case'a':
case'aa':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'abbreviated',
context:'formatting'});


case'aaa':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'abbreviated',
context:'formatting'}).
toLowerCase();

case'aaaaa':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'narrow',
context:'formatting'});


case'aaaa':
default:
return localize.dayPeriod(dayPeriodEnumValue,{
width:'wide',
context:'formatting'});}


},
// AM, PM, midnight, noon
b:function b(date,token,localize){
var hours=date.getUTCHours();
var dayPeriodEnumValue;

if(hours===12){
dayPeriodEnumValue=dayPeriodEnum.noon;
}else if(hours===0){
dayPeriodEnumValue=dayPeriodEnum.midnight;
}else {
dayPeriodEnumValue=hours/12>=1?'pm':'am';
}

switch(token){
case'b':
case'bb':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'abbreviated',
context:'formatting'});


case'bbb':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'abbreviated',
context:'formatting'}).
toLowerCase();

case'bbbbb':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'narrow',
context:'formatting'});


case'bbbb':
default:
return localize.dayPeriod(dayPeriodEnumValue,{
width:'wide',
context:'formatting'});}


},
// in the morning, in the afternoon, in the evening, at night
B:function B(date,token,localize){
var hours=date.getUTCHours();
var dayPeriodEnumValue;

if(hours>=17){
dayPeriodEnumValue=dayPeriodEnum.evening;
}else if(hours>=12){
dayPeriodEnumValue=dayPeriodEnum.afternoon;
}else if(hours>=4){
dayPeriodEnumValue=dayPeriodEnum.morning;
}else {
dayPeriodEnumValue=dayPeriodEnum.night;
}

switch(token){
case'B':
case'BB':
case'BBB':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'abbreviated',
context:'formatting'});


case'BBBBB':
return localize.dayPeriod(dayPeriodEnumValue,{
width:'narrow',
context:'formatting'});


case'BBBB':
default:
return localize.dayPeriod(dayPeriodEnumValue,{
width:'wide',
context:'formatting'});}


},
// Hour [1-12]
h:function h(date,token,localize){
if(token==='ho'){
var hours=date.getUTCHours()%12;
if(hours===0)hours=12;
return localize.ordinalNumber(hours,{
unit:'hour'});

}

return formatters.h(date,token);
},
// Hour [0-23]
H:function H(date,token,localize){
if(token==='Ho'){
return localize.ordinalNumber(date.getUTCHours(),{
unit:'hour'});

}

return formatters.H(date,token);
},
// Hour [0-11]
K:function K(date,token,localize){
var hours=date.getUTCHours()%12;

if(token==='Ko'){
return localize.ordinalNumber(hours,{
unit:'hour'});

}

return addLeadingZeros(hours,token.length);
},
// Hour [1-24]
k:function k(date,token,localize){
var hours=date.getUTCHours();
if(hours===0)hours=24;

if(token==='ko'){
return localize.ordinalNumber(hours,{
unit:'hour'});

}

return addLeadingZeros(hours,token.length);
},
// Minute
m:function m(date,token,localize){
if(token==='mo'){
return localize.ordinalNumber(date.getUTCMinutes(),{
unit:'minute'});

}

return formatters.m(date,token);
},
// Second
s:function s(date,token,localize){
if(token==='so'){
return localize.ordinalNumber(date.getUTCSeconds(),{
unit:'second'});

}

return formatters.s(date,token);
},
// Fraction of second
S:function S(date,token){
return formatters.S(date,token);
},
// Timezone (ISO-8601. If offset is 0, output is always `'Z'`)
X:function X(date,token,_localize,options){
var originalDate=options._originalDate||date;
var timezoneOffset=originalDate.getTimezoneOffset();

if(timezoneOffset===0){
return 'Z';
}

switch(token){
// Hours and optional minutes
case'X':
return formatTimezoneWithOptionalMinutes(timezoneOffset);
// Hours, minutes and optional seconds without `:` delimiter
// Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
// so this token always has the same output as `XX`

case'XXXX':
case'XX':
// Hours and minutes without `:` delimiter
return formatTimezone(timezoneOffset);
// Hours, minutes and optional seconds with `:` delimiter
// Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
// so this token always has the same output as `XXX`

case'XXXXX':
case'XXX':// Hours and minutes with `:` delimiter

default:
return formatTimezone(timezoneOffset,':');}

},
// Timezone (ISO-8601. If offset is 0, output is `'+00:00'` or equivalent)
x:function x(date,token,_localize,options){
var originalDate=options._originalDate||date;
var timezoneOffset=originalDate.getTimezoneOffset();

switch(token){
// Hours and optional minutes
case'x':
return formatTimezoneWithOptionalMinutes(timezoneOffset);
// Hours, minutes and optional seconds without `:` delimiter
// Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
// so this token always has the same output as `xx`

case'xxxx':
case'xx':
// Hours and minutes without `:` delimiter
return formatTimezone(timezoneOffset);
// Hours, minutes and optional seconds with `:` delimiter
// Note: neither ISO-8601 nor JavaScript supports seconds in timezone offsets
// so this token always has the same output as `xxx`

case'xxxxx':
case'xxx':// Hours and minutes with `:` delimiter

default:
return formatTimezone(timezoneOffset,':');}

},
// Timezone (GMT)
O:function O(date,token,_localize,options){
var originalDate=options._originalDate||date;
var timezoneOffset=originalDate.getTimezoneOffset();

switch(token){
// Short
case'O':
case'OO':
case'OOO':
return 'GMT'+formatTimezoneShort(timezoneOffset,':');
// Long

case'OOOO':
default:
return 'GMT'+formatTimezone(timezoneOffset,':');}

},
// Timezone (specific non-location)
z:function z(date,token,_localize,options){
var originalDate=options._originalDate||date;
var timezoneOffset=originalDate.getTimezoneOffset();

switch(token){
// Short
case'z':
case'zz':
case'zzz':
return 'GMT'+formatTimezoneShort(timezoneOffset,':');
// Long

case'zzzz':
default:
return 'GMT'+formatTimezone(timezoneOffset,':');}

},
// Seconds timestamp
t:function t(date,token,_localize,options){
var originalDate=options._originalDate||date;
var timestamp=Math.floor(originalDate.getTime()/1000);
return addLeadingZeros(timestamp,token.length);
},
// Milliseconds timestamp
T:function T(date,token,_localize,options){
var originalDate=options._originalDate||date;
var timestamp=originalDate.getTime();
return addLeadingZeros(timestamp,token.length);
}};


function formatTimezoneShort(offset,dirtyDelimiter){
var sign=offset>0?'-':'+';
var absOffset=Math.abs(offset);
var hours=Math.floor(absOffset/60);
var minutes=absOffset%60;

if(minutes===0){
return sign+String(hours);
}

var delimiter=dirtyDelimiter||'';
return sign+String(hours)+delimiter+addLeadingZeros(minutes,2);
}

function formatTimezoneWithOptionalMinutes(offset,dirtyDelimiter){
if(offset%60===0){
var sign=offset>0?'-':'+';
return sign+addLeadingZeros(Math.abs(offset)/60,2);
}

return formatTimezone(offset,dirtyDelimiter);
}

function formatTimezone(offset,dirtyDelimiter){
var delimiter=dirtyDelimiter||'';
var sign=offset>0?'-':'+';
var absOffset=Math.abs(offset);
var hours=addLeadingZeros(Math.floor(absOffset/60),2);
var minutes=addLeadingZeros(absOffset%60,2);
return sign+hours+delimiter+minutes;
}

function dateLongFormatter(pattern,formatLong){
switch(pattern){
case'P':
return formatLong.date({
width:'short'});


case'PP':
return formatLong.date({
width:'medium'});


case'PPP':
return formatLong.date({
width:'long'});


case'PPPP':
default:
return formatLong.date({
width:'full'});}


}

function timeLongFormatter(pattern,formatLong){
switch(pattern){
case'p':
return formatLong.time({
width:'short'});


case'pp':
return formatLong.time({
width:'medium'});


case'ppp':
return formatLong.time({
width:'long'});


case'pppp':
default:
return formatLong.time({
width:'full'});}


}

function dateTimeLongFormatter(pattern,formatLong){
var matchResult=pattern.match(/(P+)(p+)?/);
var datePattern=matchResult[1];
var timePattern=matchResult[2];

if(!timePattern){
return dateLongFormatter(pattern,formatLong);
}

var dateTimeFormat;

switch(datePattern){
case'P':
dateTimeFormat=formatLong.dateTime({
width:'short'});

break;

case'PP':
dateTimeFormat=formatLong.dateTime({
width:'medium'});

break;

case'PPP':
dateTimeFormat=formatLong.dateTime({
width:'long'});

break;

case'PPPP':
default:
dateTimeFormat=formatLong.dateTime({
width:'full'});

break;}


return dateTimeFormat.replace('{{date}}',dateLongFormatter(datePattern,formatLong)).replace('{{time}}',timeLongFormatter(timePattern,formatLong));
}

var longFormatters={
p:timeLongFormatter,
P:dateTimeLongFormatter};


var protectedDayOfYearTokens=['D','DD'];
var protectedWeekYearTokens=['YY','YYYY'];
function isProtectedDayOfYearToken(token){
return protectedDayOfYearTokens.indexOf(token)!==-1;
}
function isProtectedWeekYearToken(token){
return protectedWeekYearTokens.indexOf(token)!==-1;
}
function throwProtectedError(token,format,input){
if(token==='YYYY'){
throw new RangeError("Use `yyyy` instead of `YYYY` (in `".concat(format,"`) for formatting years to the input `").concat(input,"`; see: https://git.io/fxCyr"));
}else if(token==='YY'){
throw new RangeError("Use `yy` instead of `YY` (in `".concat(format,"`) for formatting years to the input `").concat(input,"`; see: https://git.io/fxCyr"));
}else if(token==='D'){
throw new RangeError("Use `d` instead of `D` (in `".concat(format,"`) for formatting days of the month to the input `").concat(input,"`; see: https://git.io/fxCyr"));
}else if(token==='DD'){
throw new RangeError("Use `dd` instead of `DD` (in `".concat(format,"`) for formatting days of the month to the input `").concat(input,"`; see: https://git.io/fxCyr"));
}
}

// - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
//   (one of the certain letters followed by `o`)
// - (\w)\1* matches any sequences of the same letter
// - '' matches two quote characters in a row
// - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
//   except a single quote symbol, which ends the sequence.
//   Two quote characters do not end the sequence.
//   If there is no matching single quote
//   then the sequence will continue until the end of the string.
// - . matches any single character unmatched by previous parts of the RegExps

var formattingTokensRegExp=/[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g;// This RegExp catches symbols escaped by quotes, and also
// sequences of symbols P, p, and the combinations like `PPPPPPPppppp`

var longFormattingTokensRegExp=/P+p+|P+|p+|''|'(''|[^'])+('|$)|./g;
var escapedStringRegExp=/^'([^]*?)'?$/;
var doubleQuoteRegExp=/''/g;
var unescapedLatinCharacterRegExp=/[a-zA-Z]/;
/**
 * @name format
 * @category Common Helpers
 * @summary Format the date.
 *
 * @description
 * Return the formatted date string in the given format. The result may vary by locale.
 *
 * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
 * > See: https://git.io/fxCyr
 *
 * The characters wrapped between two single quotes characters (') are escaped.
 * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
 * (see the last example)
 *
 * Format of the string is based on Unicode Technical Standard #35:
 * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
 * with a few additions (see note 7 below the table).
 *
 * Accepted patterns:
 * | Unit                            | Pattern | Result examples                   | Notes |
 * |---------------------------------|---------|-----------------------------------|-------|
 * | Era                             | G..GGG  | AD, BC                            |       |
 * |                                 | GGGG    | Anno Domini, Before Christ        | 2     |
 * |                                 | GGGGG   | A, B                              |       |
 * | Calendar year                   | y       | 44, 1, 1900, 2017                 | 5     |
 * |                                 | yo      | 44th, 1st, 0th, 17th              | 5,7   |
 * |                                 | yy      | 44, 01, 00, 17                    | 5     |
 * |                                 | yyy     | 044, 001, 1900, 2017              | 5     |
 * |                                 | yyyy    | 0044, 0001, 1900, 2017            | 5     |
 * |                                 | yyyyy   | ...                               | 3,5   |
 * | Local week-numbering year       | Y       | 44, 1, 1900, 2017                 | 5     |
 * |                                 | Yo      | 44th, 1st, 1900th, 2017th         | 5,7   |
 * |                                 | YY      | 44, 01, 00, 17                    | 5,8   |
 * |                                 | YYY     | 044, 001, 1900, 2017              | 5     |
 * |                                 | YYYY    | 0044, 0001, 1900, 2017            | 5,8   |
 * |                                 | YYYYY   | ...                               | 3,5   |
 * | ISO week-numbering year         | R       | -43, 0, 1, 1900, 2017             | 5,7   |
 * |                                 | RR      | -43, 00, 01, 1900, 2017           | 5,7   |
 * |                                 | RRR     | -043, 000, 001, 1900, 2017        | 5,7   |
 * |                                 | RRRR    | -0043, 0000, 0001, 1900, 2017     | 5,7   |
 * |                                 | RRRRR   | ...                               | 3,5,7 |
 * | Extended year                   | u       | -43, 0, 1, 1900, 2017             | 5     |
 * |                                 | uu      | -43, 01, 1900, 2017               | 5     |
 * |                                 | uuu     | -043, 001, 1900, 2017             | 5     |
 * |                                 | uuuu    | -0043, 0001, 1900, 2017           | 5     |
 * |                                 | uuuuu   | ...                               | 3,5   |
 * | Quarter (formatting)            | Q       | 1, 2, 3, 4                        |       |
 * |                                 | Qo      | 1st, 2nd, 3rd, 4th                | 7     |
 * |                                 | QQ      | 01, 02, 03, 04                    |       |
 * |                                 | QQQ     | Q1, Q2, Q3, Q4                    |       |
 * |                                 | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 | QQQQQ   | 1, 2, 3, 4                        | 4     |
 * | Quarter (stand-alone)           | q       | 1, 2, 3, 4                        |       |
 * |                                 | qo      | 1st, 2nd, 3rd, 4th                | 7     |
 * |                                 | qq      | 01, 02, 03, 04                    |       |
 * |                                 | qqq     | Q1, Q2, Q3, Q4                    |       |
 * |                                 | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 | qqqqq   | 1, 2, 3, 4                        | 4     |
 * | Month (formatting)              | M       | 1, 2, ..., 12                     |       |
 * |                                 | Mo      | 1st, 2nd, ..., 12th               | 7     |
 * |                                 | MM      | 01, 02, ..., 12                   |       |
 * |                                 | MMM     | Jan, Feb, ..., Dec                |       |
 * |                                 | MMMM    | January, February, ..., December  | 2     |
 * |                                 | MMMMM   | J, F, ..., D                      |       |
 * | Month (stand-alone)             | L       | 1, 2, ..., 12                     |       |
 * |                                 | Lo      | 1st, 2nd, ..., 12th               | 7     |
 * |                                 | LL      | 01, 02, ..., 12                   |       |
 * |                                 | LLL     | Jan, Feb, ..., Dec                |       |
 * |                                 | LLLL    | January, February, ..., December  | 2     |
 * |                                 | LLLLL   | J, F, ..., D                      |       |
 * | Local week of year              | w       | 1, 2, ..., 53                     |       |
 * |                                 | wo      | 1st, 2nd, ..., 53th               | 7     |
 * |                                 | ww      | 01, 02, ..., 53                   |       |
 * | ISO week of year                | I       | 1, 2, ..., 53                     | 7     |
 * |                                 | Io      | 1st, 2nd, ..., 53th               | 7     |
 * |                                 | II      | 01, 02, ..., 53                   | 7     |
 * | Day of month                    | d       | 1, 2, ..., 31                     |       |
 * |                                 | do      | 1st, 2nd, ..., 31st               | 7     |
 * |                                 | dd      | 01, 02, ..., 31                   |       |
 * | Day of year                     | D       | 1, 2, ..., 365, 366               | 9     |
 * |                                 | Do      | 1st, 2nd, ..., 365th, 366th       | 7     |
 * |                                 | DD      | 01, 02, ..., 365, 366             | 9     |
 * |                                 | DDD     | 001, 002, ..., 365, 366           |       |
 * |                                 | DDDD    | ...                               | 3     |
 * | Day of week (formatting)        | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | EEEEE   | M, T, W, T, F, S, S               |       |
 * |                                 | EEEEEE  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
 * | ISO day of week (formatting)    | i       | 1, 2, 3, ..., 7                   | 7     |
 * |                                 | io      | 1st, 2nd, ..., 7th                | 7     |
 * |                                 | ii      | 01, 02, ..., 07                   | 7     |
 * |                                 | iii     | Mon, Tue, Wed, ..., Sun           | 7     |
 * |                                 | iiii    | Monday, Tuesday, ..., Sunday      | 2,7   |
 * |                                 | iiiii   | M, T, W, T, F, S, S               | 7     |
 * |                                 | iiiiii  | Mo, Tu, We, Th, Fr, Su, Sa        | 7     |
 * | Local day of week (formatting)  | e       | 2, 3, 4, ..., 1                   |       |
 * |                                 | eo      | 2nd, 3rd, ..., 1st                | 7     |
 * |                                 | ee      | 02, 03, ..., 01                   |       |
 * |                                 | eee     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | eeeee   | M, T, W, T, F, S, S               |       |
 * |                                 | eeeeee  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
 * | Local day of week (stand-alone) | c       | 2, 3, 4, ..., 1                   |       |
 * |                                 | co      | 2nd, 3rd, ..., 1st                | 7     |
 * |                                 | cc      | 02, 03, ..., 01                   |       |
 * |                                 | ccc     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 | ccccc   | M, T, W, T, F, S, S               |       |
 * |                                 | cccccc  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
 * | AM, PM                          | a..aa   | AM, PM                            |       |
 * |                                 | aaa     | am, pm                            |       |
 * |                                 | aaaa    | a.m., p.m.                        | 2     |
 * |                                 | aaaaa   | a, p                              |       |
 * | AM, PM, noon, midnight          | b..bb   | AM, PM, noon, midnight            |       |
 * |                                 | bbb     | am, pm, noon, midnight            |       |
 * |                                 | bbbb    | a.m., p.m., noon, midnight        | 2     |
 * |                                 | bbbbb   | a, p, n, mi                       |       |
 * | Flexible day period             | B..BBB  | at night, in the morning, ...     |       |
 * |                                 | BBBB    | at night, in the morning, ...     | 2     |
 * |                                 | BBBBB   | at night, in the morning, ...     |       |
 * | Hour [1-12]                     | h       | 1, 2, ..., 11, 12                 |       |
 * |                                 | ho      | 1st, 2nd, ..., 11th, 12th         | 7     |
 * |                                 | hh      | 01, 02, ..., 11, 12               |       |
 * | Hour [0-23]                     | H       | 0, 1, 2, ..., 23                  |       |
 * |                                 | Ho      | 0th, 1st, 2nd, ..., 23rd          | 7     |
 * |                                 | HH      | 00, 01, 02, ..., 23               |       |
 * | Hour [0-11]                     | K       | 1, 2, ..., 11, 0                  |       |
 * |                                 | Ko      | 1st, 2nd, ..., 11th, 0th          | 7     |
 * |                                 | KK      | 01, 02, ..., 11, 00               |       |
 * | Hour [1-24]                     | k       | 24, 1, 2, ..., 23                 |       |
 * |                                 | ko      | 24th, 1st, 2nd, ..., 23rd         | 7     |
 * |                                 | kk      | 24, 01, 02, ..., 23               |       |
 * | Minute                          | m       | 0, 1, ..., 59                     |       |
 * |                                 | mo      | 0th, 1st, ..., 59th               | 7     |
 * |                                 | mm      | 00, 01, ..., 59                   |       |
 * | Second                          | s       | 0, 1, ..., 59                     |       |
 * |                                 | so      | 0th, 1st, ..., 59th               | 7     |
 * |                                 | ss      | 00, 01, ..., 59                   |       |
 * | Fraction of second              | S       | 0, 1, ..., 9                      |       |
 * |                                 | SS      | 00, 01, ..., 99                   |       |
 * |                                 | SSS     | 000, 0001, ..., 999               |       |
 * |                                 | SSSS    | ...                               | 3     |
 * | Timezone (ISO-8601 w/ Z)        | X       | -08, +0530, Z                     |       |
 * |                                 | XX      | -0800, +0530, Z                   |       |
 * |                                 | XXX     | -08:00, +05:30, Z                 |       |
 * |                                 | XXXX    | -0800, +0530, Z, +123456          | 2     |
 * |                                 | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
 * | Timezone (ISO-8601 w/o Z)       | x       | -08, +0530, +00                   |       |
 * |                                 | xx      | -0800, +0530, +0000               |       |
 * |                                 | xxx     | -08:00, +05:30, +00:00            | 2     |
 * |                                 | xxxx    | -0800, +0530, +0000, +123456      |       |
 * |                                 | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
 * | Timezone (GMT)                  | O...OOO | GMT-8, GMT+5:30, GMT+0            |       |
 * |                                 | OOOO    | GMT-08:00, GMT+05:30, GMT+00:00   | 2     |
 * | Timezone (specific non-locat.)  | z...zzz | GMT-8, GMT+5:30, GMT+0            | 6     |
 * |                                 | zzzz    | GMT-08:00, GMT+05:30, GMT+00:00   | 2,6   |
 * | Seconds timestamp               | t       | 512969520                         | 7     |
 * |                                 | tt      | ...                               | 3,7   |
 * | Milliseconds timestamp          | T       | 512969520900                      | 7     |
 * |                                 | TT      | ...                               | 3,7   |
 * | Long localized date             | P       | 04/29/1453                        | 7     |
 * |                                 | PP      | Apr 29, 1453                      | 7     |
 * |                                 | PPP     | April 29th, 1453                  | 7     |
 * |                                 | PPPP    | Friday, April 29th, 1453          | 2,7   |
 * | Long localized time             | p       | 12:00 AM                          | 7     |
 * |                                 | pp      | 12:00:00 AM                       | 7     |
 * |                                 | ppp     | 12:00:00 AM GMT+2                 | 7     |
 * |                                 | pppp    | 12:00:00 AM GMT+02:00             | 2,7   |
 * | Combination of date and time    | Pp      | 04/29/1453, 12:00 AM              | 7     |
 * |                                 | PPpp    | Apr 29, 1453, 12:00:00 AM         | 7     |
 * |                                 | PPPppp  | April 29th, 1453 at ...           | 7     |
 * |                                 | PPPPpppp| Friday, April 29th, 1453 at ...   | 2,7   |
 * Notes:
 * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
 *    are the same as "stand-alone" units, but are different in some languages.
 *    "Formatting" units are declined according to the rules of the language
 *    in the context of a date. "Stand-alone" units are always nominative singular:
 *
 *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
 *
 *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
 *
 * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
 *    the single quote characters (see below).
 *    If the sequence is longer than listed in table (e.g. `EEEEEEEEEEE`)
 *    the output will be the same as default pattern for this unit, usually
 *    the longest one (in case of ISO weekdays, `EEEE`). Default patterns for units
 *    are marked with "2" in the last column of the table.
 *
 *    `format(new Date(2017, 10, 6), 'MMM') //=> 'Nov'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMM') //=> 'November'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMM') //=> 'N'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMMM') //=> 'November'`
 *
 *    `format(new Date(2017, 10, 6), 'MMMMMMM') //=> 'November'`
 *
 * 3. Some patterns could be unlimited length (such as `yyyyyyyy`).
 *    The output will be padded with zeros to match the length of the pattern.
 *
 *    `format(new Date(2017, 10, 6), 'yyyyyyyy') //=> '00002017'`
 *
 * 4. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
 *    These tokens represent the shortest form of the quarter.
 *
 * 5. The main difference between `y` and `u` patterns are B.C. years:
 *
 *    | Year | `y` | `u` |
 *    |------|-----|-----|
 *    | AC 1 |   1 |   1 |
 *    | BC 1 |   1 |   0 |
 *    | BC 2 |   2 |  -1 |
 *
 *    Also `yy` always returns the last two digits of a year,
 *    while `uu` pads single digit years to 2 characters and returns other years unchanged:
 *
 *    | Year | `yy` | `uu` |
 *    |------|------|------|
 *    | 1    |   01 |   01 |
 *    | 14   |   14 |   14 |
 *    | 376  |   76 |  376 |
 *    | 1453 |   53 | 1453 |
 *
 *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
 *    except local week-numbering years are dependent on `options.weekStartsOn`
 *    and `options.firstWeekContainsDate` (compare [getISOWeekYear]{@link https://date-fns.org/docs/getISOWeekYear}
 *    and [getWeekYear]{@link https://date-fns.org/docs/getWeekYear}).
 *
 * 6. Specific non-location timezones are currently unavailable in `date-fns`,
 *    so right now these tokens fall back to GMT timezones.
 *
 * 7. These patterns are not in the Unicode Technical Standard #35:
 *    - `i`: ISO day of week
 *    - `I`: ISO week of year
 *    - `R`: ISO week-numbering year
 *    - `t`: seconds timestamp
 *    - `T`: milliseconds timestamp
 *    - `o`: ordinal number modifier
 *    - `P`: long localized date
 *    - `p`: long localized time
 *
 * 8. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
 *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://git.io/fxCyr
 *
 * 9. `D` and `DD` tokens represent days of the year but they are ofthen confused with days of the month.
 *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://git.io/fxCyr
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - The second argument is now required for the sake of explicitness.
 *
 *   ```javascript
 *   // Before v2.0.0
 *   format(new Date(2016, 0, 1))
 *
 *   // v2.0.0 onward
 *   format(new Date(2016, 0, 1), "yyyy-MM-dd'T'HH:mm:ss.SSSxxx")
 *   ```
 *
 * - New format string API for `format` function
 *   which is based on [Unicode Technical Standard #35](https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table).
 *   See [this post](https://blog.date-fns.org/post/unicode-tokens-in-date-fns-v2-sreatyki91jg) for more details.
 *
 * - Characters are now escaped using single quote symbols (`'`) instead of square brackets.
 *
 * @param {Date|Number} date - the original date
 * @param {String} format - the string of tokens
 * @param {Object} [options] - an object with options.
 * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @param {Number} [options.firstWeekContainsDate=1] - the day of January, which is
 * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
 *   see: https://git.io/fxCyr
 * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
 *   see: https://git.io/fxCyr
 * @returns {String} the formatted date string
 * @throws {TypeError} 2 arguments required
 * @throws {RangeError} `date` must not be Invalid Date
 * @throws {RangeError} `options.locale` must contain `localize` property
 * @throws {RangeError} `options.locale` must contain `formatLong` property
 * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
 * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
 * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} format string contains an unescaped latin alphabet character
 *
 * @example
 * // Represent 11 February 2014 in middle-endian format:
 * var result = format(new Date(2014, 1, 11), 'MM/dd/yyyy')
 * //=> '02/11/2014'
 *
 * @example
 * // Represent 2 July 2014 in Esperanto:
 * import { eoLocale } from 'date-fns/locale/eo'
 * var result = format(new Date(2014, 6, 2), "do 'de' MMMM yyyy", {
 *   locale: eoLocale
 * })
 * //=> '2-a de julio 2014'
 *
 * @example
 * // Escape string by single quote characters:
 * var result = format(new Date(2014, 6, 2, 15), "h 'o''clock'")
 * //=> "3 o'clock"
 */

function format(dirtyDate,dirtyFormatStr,dirtyOptions){
requiredArgs(2,arguments);
var formatStr=String(dirtyFormatStr);
var options=dirtyOptions||{};
var locale$1=options.locale||locale;
var localeFirstWeekContainsDate=locale$1.options&&locale$1.options.firstWeekContainsDate;
var defaultFirstWeekContainsDate=localeFirstWeekContainsDate==null?1:toInteger(localeFirstWeekContainsDate);
var firstWeekContainsDate=options.firstWeekContainsDate==null?defaultFirstWeekContainsDate:toInteger(options.firstWeekContainsDate);// Test if weekStartsOn is between 1 and 7 _and_ is not NaN

if(!(firstWeekContainsDate>=1&&firstWeekContainsDate<=7)){
throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
}

var localeWeekStartsOn=locale$1.options&&locale$1.options.weekStartsOn;
var defaultWeekStartsOn=localeWeekStartsOn==null?0:toInteger(localeWeekStartsOn);
var weekStartsOn=options.weekStartsOn==null?defaultWeekStartsOn:toInteger(options.weekStartsOn);// Test if weekStartsOn is between 0 and 6 _and_ is not NaN

if(!(weekStartsOn>=0&&weekStartsOn<=6)){
throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
}

if(!locale$1.localize){
throw new RangeError('locale must contain localize property');
}

if(!locale$1.formatLong){
throw new RangeError('locale must contain formatLong property');
}

var originalDate=toDate(dirtyDate);

if(!isValid(originalDate)){
throw new RangeError('Invalid time value');
}// Convert the date in system timezone to the same date in UTC+00:00 timezone.
// This ensures that when UTC functions will be implemented, locales will be compatible with them.
// See an issue about UTC functions: https://github.com/date-fns/date-fns/issues/376


var timezoneOffset=getTimezoneOffsetInMilliseconds(originalDate);
var utcDate=subMilliseconds(originalDate,timezoneOffset);
var formatterOptions={
firstWeekContainsDate:firstWeekContainsDate,
weekStartsOn:weekStartsOn,
locale:locale$1,
_originalDate:originalDate};

var result=formatStr.match(longFormattingTokensRegExp).map(function(substring){
var firstCharacter=substring[0];

if(firstCharacter==='p'||firstCharacter==='P'){
var longFormatter=longFormatters[firstCharacter];
return longFormatter(substring,locale$1.formatLong,formatterOptions);
}

return substring;
}).join('').match(formattingTokensRegExp).map(function(substring){
// Replace two single quote characters with one single quote character
if(substring==="''"){
return "'";
}

var firstCharacter=substring[0];

if(firstCharacter==="'"){
return cleanEscapedString(substring);
}

var formatter=formatters$1[firstCharacter];

if(formatter){
if(!options.useAdditionalWeekYearTokens&&isProtectedWeekYearToken(substring)){
throwProtectedError(substring,dirtyFormatStr,dirtyDate);
}

if(!options.useAdditionalDayOfYearTokens&&isProtectedDayOfYearToken(substring)){
throwProtectedError(substring,dirtyFormatStr,dirtyDate);
}

return formatter(utcDate,substring,locale$1.localize,formatterOptions);
}

if(firstCharacter.match(unescapedLatinCharacterRegExp)){
throw new RangeError('Format string contains an unescaped latin alphabet character `'+firstCharacter+'`');
}

return substring;
}).join('');
return result;
}

function cleanEscapedString(input){
return input.match(escapedStringRegExp)[1].replace(doubleQuoteRegExp,"'");
}

function assign(target,dirtyObject){
if(target==null){
throw new TypeError('assign requires that input parameter not be null or undefined');
}

dirtyObject=dirtyObject||{};

for(var property in dirtyObject){
if(dirtyObject.hasOwnProperty(property)){
target[property]=dirtyObject[property];
}
}

return target;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCDay(dirtyDate,dirtyDay,dirtyOptions){
requiredArgs(2,arguments);
var options=dirtyOptions||{};
var locale=options.locale;
var localeWeekStartsOn=locale&&locale.options&&locale.options.weekStartsOn;
var defaultWeekStartsOn=localeWeekStartsOn==null?0:toInteger(localeWeekStartsOn);
var weekStartsOn=options.weekStartsOn==null?defaultWeekStartsOn:toInteger(options.weekStartsOn);// Test if weekStartsOn is between 0 and 6 _and_ is not NaN

if(!(weekStartsOn>=0&&weekStartsOn<=6)){
throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
}

var date=toDate(dirtyDate);
var day=toInteger(dirtyDay);
var currentDay=date.getUTCDay();
var remainder=day%7;
var dayIndex=(remainder+7)%7;
var diff=(dayIndex<weekStartsOn?7:0)+day-currentDay;
date.setUTCDate(date.getUTCDate()+diff);
return date;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCISODay(dirtyDate,dirtyDay){
requiredArgs(2,arguments);
var day=toInteger(dirtyDay);

if(day%7===0){
day=day-7;
}

var weekStartsOn=1;
var date=toDate(dirtyDate);
var currentDay=date.getUTCDay();
var remainder=day%7;
var dayIndex=(remainder+7)%7;
var diff=(dayIndex<weekStartsOn?7:0)+day-currentDay;
date.setUTCDate(date.getUTCDate()+diff);
return date;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCISOWeek(dirtyDate,dirtyISOWeek){
requiredArgs(2,arguments);
var date=toDate(dirtyDate);
var isoWeek=toInteger(dirtyISOWeek);
var diff=getUTCISOWeek(date)-isoWeek;
date.setUTCDate(date.getUTCDate()-diff*7);
return date;
}

// See issue: https://github.com/date-fns/date-fns/issues/376

function setUTCWeek(dirtyDate,dirtyWeek,options){
requiredArgs(2,arguments);
var date=toDate(dirtyDate);
var week=toInteger(dirtyWeek);
var diff=getUTCWeek(date,options)-week;
date.setUTCDate(date.getUTCDate()-diff*7);
return date;
}

var MILLISECONDS_IN_HOUR=3600000;
var MILLISECONDS_IN_MINUTE$1=60000;
var MILLISECONDS_IN_SECOND=1000;
var numericPatterns={
month:/^(1[0-2]|0?\d)/,
// 0 to 12
date:/^(3[0-1]|[0-2]?\d)/,
// 0 to 31
dayOfYear:/^(36[0-6]|3[0-5]\d|[0-2]?\d?\d)/,
// 0 to 366
week:/^(5[0-3]|[0-4]?\d)/,
// 0 to 53
hour23h:/^(2[0-3]|[0-1]?\d)/,
// 0 to 23
hour24h:/^(2[0-4]|[0-1]?\d)/,
// 0 to 24
hour11h:/^(1[0-1]|0?\d)/,
// 0 to 11
hour12h:/^(1[0-2]|0?\d)/,
// 0 to 12
minute:/^[0-5]?\d/,
// 0 to 59
second:/^[0-5]?\d/,
// 0 to 59
singleDigit:/^\d/,
// 0 to 9
twoDigits:/^\d{1,2}/,
// 0 to 99
threeDigits:/^\d{1,3}/,
// 0 to 999
fourDigits:/^\d{1,4}/,
// 0 to 9999
anyDigitsSigned:/^-?\d+/,
singleDigitSigned:/^-?\d/,
// 0 to 9, -0 to -9
twoDigitsSigned:/^-?\d{1,2}/,
// 0 to 99, -0 to -99
threeDigitsSigned:/^-?\d{1,3}/,
// 0 to 999, -0 to -999
fourDigitsSigned:/^-?\d{1,4}/ // 0 to 9999, -0 to -9999
};

var timezonePatterns={
basicOptionalMinutes:/^([+-])(\d{2})(\d{2})?|Z/,
basic:/^([+-])(\d{2})(\d{2})|Z/,
basicOptionalSeconds:/^([+-])(\d{2})(\d{2})((\d{2}))?|Z/,
extended:/^([+-])(\d{2}):(\d{2})|Z/,
extendedOptionalSeconds:/^([+-])(\d{2}):(\d{2})(:(\d{2}))?|Z/};


function parseNumericPattern(pattern,string,valueCallback){
var matchResult=string.match(pattern);

if(!matchResult){
return null;
}

var value=parseInt(matchResult[0],10);
return {
value:valueCallback?valueCallback(value):value,
rest:string.slice(matchResult[0].length)};

}

function parseTimezonePattern(pattern,string){
var matchResult=string.match(pattern);

if(!matchResult){
return null;
}// Input is 'Z'


if(matchResult[0]==='Z'){
return {
value:0,
rest:string.slice(1)};

}

var sign=matchResult[1]==='+'?1:-1;
var hours=matchResult[2]?parseInt(matchResult[2],10):0;
var minutes=matchResult[3]?parseInt(matchResult[3],10):0;
var seconds=matchResult[5]?parseInt(matchResult[5],10):0;
return {
value:sign*(hours*MILLISECONDS_IN_HOUR+minutes*MILLISECONDS_IN_MINUTE$1+seconds*MILLISECONDS_IN_SECOND),
rest:string.slice(matchResult[0].length)};

}

function parseAnyDigitsSigned(string,valueCallback){
return parseNumericPattern(numericPatterns.anyDigitsSigned,string,valueCallback);
}

function parseNDigits(n,string,valueCallback){
switch(n){
case 1:
return parseNumericPattern(numericPatterns.singleDigit,string,valueCallback);

case 2:
return parseNumericPattern(numericPatterns.twoDigits,string,valueCallback);

case 3:
return parseNumericPattern(numericPatterns.threeDigits,string,valueCallback);

case 4:
return parseNumericPattern(numericPatterns.fourDigits,string,valueCallback);

default:
return parseNumericPattern(new RegExp('^\\d{1,'+n+'}'),string,valueCallback);}

}

function parseNDigitsSigned(n,string,valueCallback){
switch(n){
case 1:
return parseNumericPattern(numericPatterns.singleDigitSigned,string,valueCallback);

case 2:
return parseNumericPattern(numericPatterns.twoDigitsSigned,string,valueCallback);

case 3:
return parseNumericPattern(numericPatterns.threeDigitsSigned,string,valueCallback);

case 4:
return parseNumericPattern(numericPatterns.fourDigitsSigned,string,valueCallback);

default:
return parseNumericPattern(new RegExp('^-?\\d{1,'+n+'}'),string,valueCallback);}

}

function dayPeriodEnumToHours(enumValue){
switch(enumValue){
case'morning':
return 4;

case'evening':
return 17;

case'pm':
case'noon':
case'afternoon':
return 12;

case'am':
case'midnight':
case'night':
default:
return 0;}

}

function normalizeTwoDigitYear(twoDigitYear,currentYear){
var isCommonEra=currentYear>0;// Absolute number of the current year:
// 1 -> 1 AC
// 0 -> 1 BC
// -1 -> 2 BC

var absCurrentYear=isCommonEra?currentYear:1-currentYear;
var result;

if(absCurrentYear<=50){
result=twoDigitYear||100;
}else {
var rangeEnd=absCurrentYear+50;
var rangeEndCentury=Math.floor(rangeEnd/100)*100;
var isPreviousCentury=twoDigitYear>=rangeEnd%100;
result=twoDigitYear+rangeEndCentury-(isPreviousCentury?100:0);
}

return isCommonEra?result:1-result;
}

var DAYS_IN_MONTH=[31,28,31,30,31,30,31,31,30,31,30,31];
var DAYS_IN_MONTH_LEAP_YEAR=[31,29,31,30,31,30,31,31,30,31,30,31];// User for validation

function isLeapYearIndex(year){
return year%400===0||year%4===0&&year%100!==0;
}
/*
 * |     | Unit                           |     | Unit                           |
 * |-----|--------------------------------|-----|--------------------------------|
 * |  a  | AM, PM                         |  A* | Milliseconds in day            |
 * |  b  | AM, PM, noon, midnight         |  B  | Flexible day period            |
 * |  c  | Stand-alone local day of week  |  C* | Localized hour w/ day period   |
 * |  d  | Day of month                   |  D  | Day of year                    |
 * |  e  | Local day of week              |  E  | Day of week                    |
 * |  f  |                                |  F* | Day of week in month           |
 * |  g* | Modified Julian day            |  G  | Era                            |
 * |  h  | Hour [1-12]                    |  H  | Hour [0-23]                    |
 * |  i! | ISO day of week                |  I! | ISO week of year               |
 * |  j* | Localized hour w/ day period   |  J* | Localized hour w/o day period  |
 * |  k  | Hour [1-24]                    |  K  | Hour [0-11]                    |
 * |  l* | (deprecated)                   |  L  | Stand-alone month              |
 * |  m  | Minute                         |  M  | Month                          |
 * |  n  |                                |  N  |                                |
 * |  o! | Ordinal number modifier        |  O* | Timezone (GMT)                 |
 * |  p  |                                |  P  |                                |
 * |  q  | Stand-alone quarter            |  Q  | Quarter                        |
 * |  r* | Related Gregorian year         |  R! | ISO week-numbering year        |
 * |  s  | Second                         |  S  | Fraction of second             |
 * |  t! | Seconds timestamp              |  T! | Milliseconds timestamp         |
 * |  u  | Extended year                  |  U* | Cyclic year                    |
 * |  v* | Timezone (generic non-locat.)  |  V* | Timezone (location)            |
 * |  w  | Local week of year             |  W* | Week of month                  |
 * |  x  | Timezone (ISO-8601 w/o Z)      |  X  | Timezone (ISO-8601)            |
 * |  y  | Year (abs)                     |  Y  | Local week-numbering year      |
 * |  z* | Timezone (specific non-locat.) |  Z* | Timezone (aliases)             |
 *
 * Letters marked by * are not implemented but reserved by Unicode standard.
 *
 * Letters marked by ! are non-standard, but implemented by date-fns:
 * - `o` modifies the previous token to turn it into an ordinal (see `parse` docs)
 * - `i` is ISO day of week. For `i` and `ii` is returns numeric ISO week days,
 *   i.e. 7 for Sunday, 1 for Monday, etc.
 * - `I` is ISO week of year, as opposed to `w` which is local week of year.
 * - `R` is ISO week-numbering year, as opposed to `Y` which is local week-numbering year.
 *   `R` is supposed to be used in conjunction with `I` and `i`
 *   for universal ISO week-numbering date, whereas
 *   `Y` is supposed to be used in conjunction with `w` and `e`
 *   for week-numbering date specific to the locale.
 */


var parsers={
// Era
G:{
priority:140,
parse:function parse(string,token,match,_options){
switch(token){
// AD, BC
case'G':
case'GG':
case'GGG':
return match.era(string,{
width:'abbreviated'})||
match.era(string,{
width:'narrow'});

// A, B

case'GGGGG':
return match.era(string,{
width:'narrow'});

// Anno Domini, Before Christ

case'GGGG':
default:
return match.era(string,{
width:'wide'})||
match.era(string,{
width:'abbreviated'})||
match.era(string,{
width:'narrow'});}


},
set:function set(date,flags,value,_options){
flags.era=value;
date.setUTCFullYear(value,0,1);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['R','u','t','T']},

// Year
y:{
// From http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_Patterns
// | Year     |     y | yy |   yyy |  yyyy | yyyyy |
// |----------|-------|----|-------|-------|-------|
// | AD 1     |     1 | 01 |   001 |  0001 | 00001 |
// | AD 12    |    12 | 12 |   012 |  0012 | 00012 |
// | AD 123   |   123 | 23 |   123 |  0123 | 00123 |
// | AD 1234  |  1234 | 34 |  1234 |  1234 | 01234 |
// | AD 12345 | 12345 | 45 | 12345 | 12345 | 12345 |
priority:130,
parse:function parse(string,token,match,_options){
var valueCallback=function valueCallback(year){
return {
year:year,
isTwoDigitYear:token==='yy'};

};

switch(token){
case'y':
return parseNDigits(4,string,valueCallback);

case'yo':
return match.ordinalNumber(string,{
unit:'year',
valueCallback:valueCallback});


default:
return parseNDigits(token.length,string,valueCallback);}

},
validate:function validate(_date,value,_options){
return value.isTwoDigitYear||value.year>0;
},
set:function set(date,flags,value,_options){
var currentYear=date.getUTCFullYear();

if(value.isTwoDigitYear){
var normalizedTwoDigitYear=normalizeTwoDigitYear(value.year,currentYear);
date.setUTCFullYear(normalizedTwoDigitYear,0,1);
date.setUTCHours(0,0,0,0);
return date;
}

var year=!('era'in flags)||flags.era===1?value.year:1-value.year;
date.setUTCFullYear(year,0,1);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['Y','R','u','w','I','i','e','c','t','T']},

// Local week-numbering year
Y:{
priority:130,
parse:function parse(string,token,match,_options){
var valueCallback=function valueCallback(year){
return {
year:year,
isTwoDigitYear:token==='YY'};

};

switch(token){
case'Y':
return parseNDigits(4,string,valueCallback);

case'Yo':
return match.ordinalNumber(string,{
unit:'year',
valueCallback:valueCallback});


default:
return parseNDigits(token.length,string,valueCallback);}

},
validate:function validate(_date,value,_options){
return value.isTwoDigitYear||value.year>0;
},
set:function set(date,flags,value,options){
var currentYear=getUTCWeekYear(date,options);

if(value.isTwoDigitYear){
var normalizedTwoDigitYear=normalizeTwoDigitYear(value.year,currentYear);
date.setUTCFullYear(normalizedTwoDigitYear,0,options.firstWeekContainsDate);
date.setUTCHours(0,0,0,0);
return startOfUTCWeek(date,options);
}

var year=!('era'in flags)||flags.era===1?value.year:1-value.year;
date.setUTCFullYear(year,0,options.firstWeekContainsDate);
date.setUTCHours(0,0,0,0);
return startOfUTCWeek(date,options);
},
incompatibleTokens:['y','R','u','Q','q','M','L','I','d','D','i','t','T']},

// ISO week-numbering year
R:{
priority:130,
parse:function parse(string,token,_match,_options){
if(token==='R'){
return parseNDigitsSigned(4,string);
}

return parseNDigitsSigned(token.length,string);
},
set:function set(_date,_flags,value,_options){
var firstWeekOfYear=new Date(0);
firstWeekOfYear.setUTCFullYear(value,0,4);
firstWeekOfYear.setUTCHours(0,0,0,0);
return startOfUTCISOWeek(firstWeekOfYear);
},
incompatibleTokens:['G','y','Y','u','Q','q','M','L','w','d','D','e','c','t','T']},

// Extended year
u:{
priority:130,
parse:function parse(string,token,_match,_options){
if(token==='u'){
return parseNDigitsSigned(4,string);
}

return parseNDigitsSigned(token.length,string);
},
set:function set(date,_flags,value,_options){
date.setUTCFullYear(value,0,1);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['G','y','Y','R','w','I','i','e','c','t','T']},

// Quarter
Q:{
priority:120,
parse:function parse(string,token,match,_options){
switch(token){
// 1, 2, 3, 4
case'Q':
case'QQ':
// 01, 02, 03, 04
return parseNDigits(token.length,string);
// 1st, 2nd, 3rd, 4th

case'Qo':
return match.ordinalNumber(string,{
unit:'quarter'});

// Q1, Q2, Q3, Q4

case'QQQ':
return match.quarter(string,{
width:'abbreviated',
context:'formatting'})||
match.quarter(string,{
width:'narrow',
context:'formatting'});

// 1, 2, 3, 4 (narrow quarter; could be not numerical)

case'QQQQQ':
return match.quarter(string,{
width:'narrow',
context:'formatting'});

// 1st quarter, 2nd quarter, ...

case'QQQQ':
default:
return match.quarter(string,{
width:'wide',
context:'formatting'})||
match.quarter(string,{
width:'abbreviated',
context:'formatting'})||
match.quarter(string,{
width:'narrow',
context:'formatting'});}


},
validate:function validate(_date,value,_options){
return value>=1&&value<=4;
},
set:function set(date,_flags,value,_options){
date.setUTCMonth((value-1)*3,1);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['Y','R','q','M','L','w','I','d','D','i','e','c','t','T']},

// Stand-alone quarter
q:{
priority:120,
parse:function parse(string,token,match,_options){
switch(token){
// 1, 2, 3, 4
case'q':
case'qq':
// 01, 02, 03, 04
return parseNDigits(token.length,string);
// 1st, 2nd, 3rd, 4th

case'qo':
return match.ordinalNumber(string,{
unit:'quarter'});

// Q1, Q2, Q3, Q4

case'qqq':
return match.quarter(string,{
width:'abbreviated',
context:'standalone'})||
match.quarter(string,{
width:'narrow',
context:'standalone'});

// 1, 2, 3, 4 (narrow quarter; could be not numerical)

case'qqqqq':
return match.quarter(string,{
width:'narrow',
context:'standalone'});

// 1st quarter, 2nd quarter, ...

case'qqqq':
default:
return match.quarter(string,{
width:'wide',
context:'standalone'})||
match.quarter(string,{
width:'abbreviated',
context:'standalone'})||
match.quarter(string,{
width:'narrow',
context:'standalone'});}


},
validate:function validate(_date,value,_options){
return value>=1&&value<=4;
},
set:function set(date,_flags,value,_options){
date.setUTCMonth((value-1)*3,1);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['Y','R','Q','M','L','w','I','d','D','i','e','c','t','T']},

// Month
M:{
priority:110,
parse:function parse(string,token,match,_options){
var valueCallback=function valueCallback(value){
return value-1;
};

switch(token){
// 1, 2, ..., 12
case'M':
return parseNumericPattern(numericPatterns.month,string,valueCallback);
// 01, 02, ..., 12

case'MM':
return parseNDigits(2,string,valueCallback);
// 1st, 2nd, ..., 12th

case'Mo':
return match.ordinalNumber(string,{
unit:'month',
valueCallback:valueCallback});

// Jan, Feb, ..., Dec

case'MMM':
return match.month(string,{
width:'abbreviated',
context:'formatting'})||
match.month(string,{
width:'narrow',
context:'formatting'});

// J, F, ..., D

case'MMMMM':
return match.month(string,{
width:'narrow',
context:'formatting'});

// January, February, ..., December

case'MMMM':
default:
return match.month(string,{
width:'wide',
context:'formatting'})||
match.month(string,{
width:'abbreviated',
context:'formatting'})||
match.month(string,{
width:'narrow',
context:'formatting'});}


},
validate:function validate(_date,value,_options){
return value>=0&&value<=11;
},
set:function set(date,_flags,value,_options){
date.setUTCMonth(value,1);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['Y','R','q','Q','L','w','I','D','i','e','c','t','T']},

// Stand-alone month
L:{
priority:110,
parse:function parse(string,token,match,_options){
var valueCallback=function valueCallback(value){
return value-1;
};

switch(token){
// 1, 2, ..., 12
case'L':
return parseNumericPattern(numericPatterns.month,string,valueCallback);
// 01, 02, ..., 12

case'LL':
return parseNDigits(2,string,valueCallback);
// 1st, 2nd, ..., 12th

case'Lo':
return match.ordinalNumber(string,{
unit:'month',
valueCallback:valueCallback});

// Jan, Feb, ..., Dec

case'LLL':
return match.month(string,{
width:'abbreviated',
context:'standalone'})||
match.month(string,{
width:'narrow',
context:'standalone'});

// J, F, ..., D

case'LLLLL':
return match.month(string,{
width:'narrow',
context:'standalone'});

// January, February, ..., December

case'LLLL':
default:
return match.month(string,{
width:'wide',
context:'standalone'})||
match.month(string,{
width:'abbreviated',
context:'standalone'})||
match.month(string,{
width:'narrow',
context:'standalone'});}


},
validate:function validate(_date,value,_options){
return value>=0&&value<=11;
},
set:function set(date,_flags,value,_options){
date.setUTCMonth(value,1);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['Y','R','q','Q','M','w','I','D','i','e','c','t','T']},

// Local week of year
w:{
priority:100,
parse:function parse(string,token,match,_options){
switch(token){
case'w':
return parseNumericPattern(numericPatterns.week,string);

case'wo':
return match.ordinalNumber(string,{
unit:'week'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=1&&value<=53;
},
set:function set(date,_flags,value,options){
return startOfUTCWeek(setUTCWeek(date,value,options),options);
},
incompatibleTokens:['y','R','u','q','Q','M','L','I','d','D','i','t','T']},

// ISO week of year
I:{
priority:100,
parse:function parse(string,token,match,_options){
switch(token){
case'I':
return parseNumericPattern(numericPatterns.week,string);

case'Io':
return match.ordinalNumber(string,{
unit:'week'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=1&&value<=53;
},
set:function set(date,_flags,value,options){
return startOfUTCISOWeek(setUTCISOWeek(date,value,options),options);
},
incompatibleTokens:['y','Y','u','q','Q','M','L','w','d','D','e','c','t','T']},

// Day of the month
d:{
priority:90,
subPriority:1,
parse:function parse(string,token,match,_options){
switch(token){
case'd':
return parseNumericPattern(numericPatterns.date,string);

case'do':
return match.ordinalNumber(string,{
unit:'date'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(date,value,_options){
var year=date.getUTCFullYear();
var isLeapYear=isLeapYearIndex(year);
var month=date.getUTCMonth();

if(isLeapYear){
return value>=1&&value<=DAYS_IN_MONTH_LEAP_YEAR[month];
}else {
return value>=1&&value<=DAYS_IN_MONTH[month];
}
},
set:function set(date,_flags,value,_options){
date.setUTCDate(value);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['Y','R','q','Q','w','I','D','i','e','c','t','T']},

// Day of year
D:{
priority:90,
subPriority:1,
parse:function parse(string,token,match,_options){
switch(token){
case'D':
case'DD':
return parseNumericPattern(numericPatterns.dayOfYear,string);

case'Do':
return match.ordinalNumber(string,{
unit:'date'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(date,value,_options){
var year=date.getUTCFullYear();
var isLeapYear=isLeapYearIndex(year);

if(isLeapYear){
return value>=1&&value<=366;
}else {
return value>=1&&value<=365;
}
},
set:function set(date,_flags,value,_options){
date.setUTCMonth(0,value);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['Y','R','q','Q','M','L','w','I','d','E','i','e','c','t','T']},

// Day of week
E:{
priority:90,
parse:function parse(string,token,match,_options){
switch(token){
// Tue
case'E':
case'EE':
case'EEE':
return match.day(string,{
width:'abbreviated',
context:'formatting'})||
match.day(string,{
width:'short',
context:'formatting'})||
match.day(string,{
width:'narrow',
context:'formatting'});

// T

case'EEEEE':
return match.day(string,{
width:'narrow',
context:'formatting'});

// Tu

case'EEEEEE':
return match.day(string,{
width:'short',
context:'formatting'})||
match.day(string,{
width:'narrow',
context:'formatting'});

// Tuesday

case'EEEE':
default:
return match.day(string,{
width:'wide',
context:'formatting'})||
match.day(string,{
width:'abbreviated',
context:'formatting'})||
match.day(string,{
width:'short',
context:'formatting'})||
match.day(string,{
width:'narrow',
context:'formatting'});}


},
validate:function validate(_date,value,_options){
return value>=0&&value<=6;
},
set:function set(date,_flags,value,options){
date=setUTCDay(date,value,options);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['D','i','e','c','t','T']},

// Local day of week
e:{
priority:90,
parse:function parse(string,token,match,options){
var valueCallback=function valueCallback(value){
var wholeWeekDays=Math.floor((value-1)/7)*7;
return (value+options.weekStartsOn+6)%7+wholeWeekDays;
};

switch(token){
// 3
case'e':
case'ee':
// 03
return parseNDigits(token.length,string,valueCallback);
// 3rd

case'eo':
return match.ordinalNumber(string,{
unit:'day',
valueCallback:valueCallback});

// Tue

case'eee':
return match.day(string,{
width:'abbreviated',
context:'formatting'})||
match.day(string,{
width:'short',
context:'formatting'})||
match.day(string,{
width:'narrow',
context:'formatting'});

// T

case'eeeee':
return match.day(string,{
width:'narrow',
context:'formatting'});

// Tu

case'eeeeee':
return match.day(string,{
width:'short',
context:'formatting'})||
match.day(string,{
width:'narrow',
context:'formatting'});

// Tuesday

case'eeee':
default:
return match.day(string,{
width:'wide',
context:'formatting'})||
match.day(string,{
width:'abbreviated',
context:'formatting'})||
match.day(string,{
width:'short',
context:'formatting'})||
match.day(string,{
width:'narrow',
context:'formatting'});}


},
validate:function validate(_date,value,_options){
return value>=0&&value<=6;
},
set:function set(date,_flags,value,options){
date=setUTCDay(date,value,options);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['y','R','u','q','Q','M','L','I','d','D','E','i','c','t','T']},

// Stand-alone local day of week
c:{
priority:90,
parse:function parse(string,token,match,options){
var valueCallback=function valueCallback(value){
var wholeWeekDays=Math.floor((value-1)/7)*7;
return (value+options.weekStartsOn+6)%7+wholeWeekDays;
};

switch(token){
// 3
case'c':
case'cc':
// 03
return parseNDigits(token.length,string,valueCallback);
// 3rd

case'co':
return match.ordinalNumber(string,{
unit:'day',
valueCallback:valueCallback});

// Tue

case'ccc':
return match.day(string,{
width:'abbreviated',
context:'standalone'})||
match.day(string,{
width:'short',
context:'standalone'})||
match.day(string,{
width:'narrow',
context:'standalone'});

// T

case'ccccc':
return match.day(string,{
width:'narrow',
context:'standalone'});

// Tu

case'cccccc':
return match.day(string,{
width:'short',
context:'standalone'})||
match.day(string,{
width:'narrow',
context:'standalone'});

// Tuesday

case'cccc':
default:
return match.day(string,{
width:'wide',
context:'standalone'})||
match.day(string,{
width:'abbreviated',
context:'standalone'})||
match.day(string,{
width:'short',
context:'standalone'})||
match.day(string,{
width:'narrow',
context:'standalone'});}


},
validate:function validate(_date,value,_options){
return value>=0&&value<=6;
},
set:function set(date,_flags,value,options){
date=setUTCDay(date,value,options);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['y','R','u','q','Q','M','L','I','d','D','E','i','e','t','T']},

// ISO day of week
i:{
priority:90,
parse:function parse(string,token,match,_options){
var valueCallback=function valueCallback(value){
if(value===0){
return 7;
}

return value;
};

switch(token){
// 2
case'i':
case'ii':
// 02
return parseNDigits(token.length,string);
// 2nd

case'io':
return match.ordinalNumber(string,{
unit:'day'});

// Tue

case'iii':
return match.day(string,{
width:'abbreviated',
context:'formatting',
valueCallback:valueCallback})||
match.day(string,{
width:'short',
context:'formatting',
valueCallback:valueCallback})||
match.day(string,{
width:'narrow',
context:'formatting',
valueCallback:valueCallback});

// T

case'iiiii':
return match.day(string,{
width:'narrow',
context:'formatting',
valueCallback:valueCallback});

// Tu

case'iiiiii':
return match.day(string,{
width:'short',
context:'formatting',
valueCallback:valueCallback})||
match.day(string,{
width:'narrow',
context:'formatting',
valueCallback:valueCallback});

// Tuesday

case'iiii':
default:
return match.day(string,{
width:'wide',
context:'formatting',
valueCallback:valueCallback})||
match.day(string,{
width:'abbreviated',
context:'formatting',
valueCallback:valueCallback})||
match.day(string,{
width:'short',
context:'formatting',
valueCallback:valueCallback})||
match.day(string,{
width:'narrow',
context:'formatting',
valueCallback:valueCallback});}


},
validate:function validate(_date,value,_options){
return value>=1&&value<=7;
},
set:function set(date,_flags,value,options){
date=setUTCISODay(date,value,options);
date.setUTCHours(0,0,0,0);
return date;
},
incompatibleTokens:['y','Y','u','q','Q','M','L','w','d','D','E','e','c','t','T']},

// AM or PM
a:{
priority:80,
parse:function parse(string,token,match,_options){
switch(token){
case'a':
case'aa':
case'aaa':
return match.dayPeriod(string,{
width:'abbreviated',
context:'formatting'})||
match.dayPeriod(string,{
width:'narrow',
context:'formatting'});


case'aaaaa':
return match.dayPeriod(string,{
width:'narrow',
context:'formatting'});


case'aaaa':
default:
return match.dayPeriod(string,{
width:'wide',
context:'formatting'})||
match.dayPeriod(string,{
width:'abbreviated',
context:'formatting'})||
match.dayPeriod(string,{
width:'narrow',
context:'formatting'});}


},
set:function set(date,_flags,value,_options){
date.setUTCHours(dayPeriodEnumToHours(value),0,0,0);
return date;
},
incompatibleTokens:['b','B','H','K','k','t','T']},

// AM, PM, midnight
b:{
priority:80,
parse:function parse(string,token,match,_options){
switch(token){
case'b':
case'bb':
case'bbb':
return match.dayPeriod(string,{
width:'abbreviated',
context:'formatting'})||
match.dayPeriod(string,{
width:'narrow',
context:'formatting'});


case'bbbbb':
return match.dayPeriod(string,{
width:'narrow',
context:'formatting'});


case'bbbb':
default:
return match.dayPeriod(string,{
width:'wide',
context:'formatting'})||
match.dayPeriod(string,{
width:'abbreviated',
context:'formatting'})||
match.dayPeriod(string,{
width:'narrow',
context:'formatting'});}


},
set:function set(date,_flags,value,_options){
date.setUTCHours(dayPeriodEnumToHours(value),0,0,0);
return date;
},
incompatibleTokens:['a','B','H','K','k','t','T']},

// in the morning, in the afternoon, in the evening, at night
B:{
priority:80,
parse:function parse(string,token,match,_options){
switch(token){
case'B':
case'BB':
case'BBB':
return match.dayPeriod(string,{
width:'abbreviated',
context:'formatting'})||
match.dayPeriod(string,{
width:'narrow',
context:'formatting'});


case'BBBBB':
return match.dayPeriod(string,{
width:'narrow',
context:'formatting'});


case'BBBB':
default:
return match.dayPeriod(string,{
width:'wide',
context:'formatting'})||
match.dayPeriod(string,{
width:'abbreviated',
context:'formatting'})||
match.dayPeriod(string,{
width:'narrow',
context:'formatting'});}


},
set:function set(date,_flags,value,_options){
date.setUTCHours(dayPeriodEnumToHours(value),0,0,0);
return date;
},
incompatibleTokens:['a','b','t','T']},

// Hour [1-12]
h:{
priority:70,
parse:function parse(string,token,match,_options){
switch(token){
case'h':
return parseNumericPattern(numericPatterns.hour12h,string);

case'ho':
return match.ordinalNumber(string,{
unit:'hour'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=1&&value<=12;
},
set:function set(date,_flags,value,_options){
var isPM=date.getUTCHours()>=12;

if(isPM&&value<12){
date.setUTCHours(value+12,0,0,0);
}else if(!isPM&&value===12){
date.setUTCHours(0,0,0,0);
}else {
date.setUTCHours(value,0,0,0);
}

return date;
},
incompatibleTokens:['H','K','k','t','T']},

// Hour [0-23]
H:{
priority:70,
parse:function parse(string,token,match,_options){
switch(token){
case'H':
return parseNumericPattern(numericPatterns.hour23h,string);

case'Ho':
return match.ordinalNumber(string,{
unit:'hour'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=0&&value<=23;
},
set:function set(date,_flags,value,_options){
date.setUTCHours(value,0,0,0);
return date;
},
incompatibleTokens:['a','b','h','K','k','t','T']},

// Hour [0-11]
K:{
priority:70,
parse:function parse(string,token,match,_options){
switch(token){
case'K':
return parseNumericPattern(numericPatterns.hour11h,string);

case'Ko':
return match.ordinalNumber(string,{
unit:'hour'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=0&&value<=11;
},
set:function set(date,_flags,value,_options){
var isPM=date.getUTCHours()>=12;

if(isPM&&value<12){
date.setUTCHours(value+12,0,0,0);
}else {
date.setUTCHours(value,0,0,0);
}

return date;
},
incompatibleTokens:['a','b','h','H','k','t','T']},

// Hour [1-24]
k:{
priority:70,
parse:function parse(string,token,match,_options){
switch(token){
case'k':
return parseNumericPattern(numericPatterns.hour24h,string);

case'ko':
return match.ordinalNumber(string,{
unit:'hour'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=1&&value<=24;
},
set:function set(date,_flags,value,_options){
var hours=value<=24?value%24:value;
date.setUTCHours(hours,0,0,0);
return date;
},
incompatibleTokens:['a','b','h','H','K','t','T']},

// Minute
m:{
priority:60,
parse:function parse(string,token,match,_options){
switch(token){
case'm':
return parseNumericPattern(numericPatterns.minute,string);

case'mo':
return match.ordinalNumber(string,{
unit:'minute'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=0&&value<=59;
},
set:function set(date,_flags,value,_options){
date.setUTCMinutes(value,0,0);
return date;
},
incompatibleTokens:['t','T']},

// Second
s:{
priority:50,
parse:function parse(string,token,match,_options){
switch(token){
case's':
return parseNumericPattern(numericPatterns.second,string);

case'so':
return match.ordinalNumber(string,{
unit:'second'});


default:
return parseNDigits(token.length,string);}

},
validate:function validate(_date,value,_options){
return value>=0&&value<=59;
},
set:function set(date,_flags,value,_options){
date.setUTCSeconds(value,0);
return date;
},
incompatibleTokens:['t','T']},

// Fraction of second
S:{
priority:30,
parse:function parse(string,token,_match,_options){
var valueCallback=function valueCallback(value){
return Math.floor(value*Math.pow(10,-token.length+3));
};

return parseNDigits(token.length,string,valueCallback);
},
set:function set(date,_flags,value,_options){
date.setUTCMilliseconds(value);
return date;
},
incompatibleTokens:['t','T']},

// Timezone (ISO-8601. +00:00 is `'Z'`)
X:{
priority:10,
parse:function parse(string,token,_match,_options){
switch(token){
case'X':
return parseTimezonePattern(timezonePatterns.basicOptionalMinutes,string);

case'XX':
return parseTimezonePattern(timezonePatterns.basic,string);

case'XXXX':
return parseTimezonePattern(timezonePatterns.basicOptionalSeconds,string);

case'XXXXX':
return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds,string);

case'XXX':
default:
return parseTimezonePattern(timezonePatterns.extended,string);}

},
set:function set(date,flags,value,_options){
if(flags.timestampIsSet){
return date;
}

return new Date(date.getTime()-value);
},
incompatibleTokens:['t','T','x']},

// Timezone (ISO-8601)
x:{
priority:10,
parse:function parse(string,token,_match,_options){
switch(token){
case'x':
return parseTimezonePattern(timezonePatterns.basicOptionalMinutes,string);

case'xx':
return parseTimezonePattern(timezonePatterns.basic,string);

case'xxxx':
return parseTimezonePattern(timezonePatterns.basicOptionalSeconds,string);

case'xxxxx':
return parseTimezonePattern(timezonePatterns.extendedOptionalSeconds,string);

case'xxx':
default:
return parseTimezonePattern(timezonePatterns.extended,string);}

},
set:function set(date,flags,value,_options){
if(flags.timestampIsSet){
return date;
}

return new Date(date.getTime()-value);
},
incompatibleTokens:['t','T','X']},

// Seconds timestamp
t:{
priority:40,
parse:function parse(string,_token,_match,_options){
return parseAnyDigitsSigned(string);
},
set:function set(_date,_flags,value,_options){
return [new Date(value*1000),{
timestampIsSet:true}];

},
incompatibleTokens:'*'},

// Milliseconds timestamp
T:{
priority:20,
parse:function parse(string,_token,_match,_options){
return parseAnyDigitsSigned(string);
},
set:function set(_date,_flags,value,_options){
return [new Date(value),{
timestampIsSet:true}];

},
incompatibleTokens:'*'}};



var TIMEZONE_UNIT_PRIORITY=10;// This RegExp consists of three parts separated by `|`:
// - [yYQqMLwIdDecihHKkms]o matches any available ordinal number token
//   (one of the certain letters followed by `o`)
// - (\w)\1* matches any sequences of the same letter
// - '' matches two quote characters in a row
// - '(''|[^'])+('|$) matches anything surrounded by two quote characters ('),
//   except a single quote symbol, which ends the sequence.
//   Two quote characters do not end the sequence.
//   If there is no matching single quote
//   then the sequence will continue until the end of the string.
// - . matches any single character unmatched by previous parts of the RegExps

var formattingTokensRegExp$1=/[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g;// This RegExp catches symbols escaped by quotes, and also
// sequences of symbols P, p, and the combinations like `PPPPPPPppppp`

var longFormattingTokensRegExp$1=/P+p+|P+|p+|''|'(''|[^'])+('|$)|./g;
var escapedStringRegExp$1=/^'([^]*?)'?$/;
var doubleQuoteRegExp$1=/''/g;
var notWhitespaceRegExp=/\S/;
var unescapedLatinCharacterRegExp$1=/[a-zA-Z]/;
/**
 * @name parse
 * @category Common Helpers
 * @summary Parse the date.
 *
 * @description
 * Return the date parsed from string using the given format string.
 *
 * > ⚠️ Please note that the `format` tokens differ from Moment.js and other libraries.
 * > See: https://git.io/fxCyr
 *
 * The characters in the format string wrapped between two single quotes characters (') are escaped.
 * Two single quotes in a row, whether inside or outside a quoted sequence, represent a 'real' single quote.
 *
 * Format of the format string is based on Unicode Technical Standard #35:
 * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
 * with a few additions (see note 5 below the table).
 *
 * Not all tokens are compatible. Combinations that don't make sense or could lead to bugs are prohibited
 * and will throw `RangeError`. For example usage of 24-hour format token with AM/PM token will throw an exception:
 *
 * ```javascript
 * parse('23 AM', 'HH a', new Date())
 * //=> RangeError: The format string mustn't contain `HH` and `a` at the same time
 * ```
 *
 * See the compatibility table: https://docs.google.com/spreadsheets/d/e/2PACX-1vQOPU3xUhplll6dyoMmVUXHKl_8CRDs6_ueLmex3SoqwhuolkuN3O05l4rqx5h1dKX8eb46Ul-CCSrq/pubhtml?gid=0&single=true
 *
 * Accepted format string patterns:
 * | Unit                            |Prior| Pattern | Result examples                   | Notes |
 * |---------------------------------|-----|---------|-----------------------------------|-------|
 * | Era                             | 140 | G..GGG  | AD, BC                            |       |
 * |                                 |     | GGGG    | Anno Domini, Before Christ        | 2     |
 * |                                 |     | GGGGG   | A, B                              |       |
 * | Calendar year                   | 130 | y       | 44, 1, 1900, 2017, 9999           | 4     |
 * |                                 |     | yo      | 44th, 1st, 1900th, 9999999th      | 4,5   |
 * |                                 |     | yy      | 44, 01, 00, 17                    | 4     |
 * |                                 |     | yyy     | 044, 001, 123, 999                | 4     |
 * |                                 |     | yyyy    | 0044, 0001, 1900, 2017            | 4     |
 * |                                 |     | yyyyy   | ...                               | 2,4   |
 * | Local week-numbering year       | 130 | Y       | 44, 1, 1900, 2017, 9000           | 4     |
 * |                                 |     | Yo      | 44th, 1st, 1900th, 9999999th      | 4,5   |
 * |                                 |     | YY      | 44, 01, 00, 17                    | 4,6   |
 * |                                 |     | YYY     | 044, 001, 123, 999                | 4     |
 * |                                 |     | YYYY    | 0044, 0001, 1900, 2017            | 4,6   |
 * |                                 |     | YYYYY   | ...                               | 2,4   |
 * | ISO week-numbering year         | 130 | R       | -43, 1, 1900, 2017, 9999, -9999   | 4,5   |
 * |                                 |     | RR      | -43, 01, 00, 17                   | 4,5   |
 * |                                 |     | RRR     | -043, 001, 123, 999, -999         | 4,5   |
 * |                                 |     | RRRR    | -0043, 0001, 2017, 9999, -9999    | 4,5   |
 * |                                 |     | RRRRR   | ...                               | 2,4,5 |
 * | Extended year                   | 130 | u       | -43, 1, 1900, 2017, 9999, -999    | 4     |
 * |                                 |     | uu      | -43, 01, 99, -99                  | 4     |
 * |                                 |     | uuu     | -043, 001, 123, 999, -999         | 4     |
 * |                                 |     | uuuu    | -0043, 0001, 2017, 9999, -9999    | 4     |
 * |                                 |     | uuuuu   | ...                               | 2,4   |
 * | Quarter (formatting)            | 120 | Q       | 1, 2, 3, 4                        |       |
 * |                                 |     | Qo      | 1st, 2nd, 3rd, 4th                | 5     |
 * |                                 |     | QQ      | 01, 02, 03, 04                    |       |
 * |                                 |     | QQQ     | Q1, Q2, Q3, Q4                    |       |
 * |                                 |     | QQQQ    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 |     | QQQQQ   | 1, 2, 3, 4                        | 4     |
 * | Quarter (stand-alone)           | 120 | q       | 1, 2, 3, 4                        |       |
 * |                                 |     | qo      | 1st, 2nd, 3rd, 4th                | 5     |
 * |                                 |     | qq      | 01, 02, 03, 04                    |       |
 * |                                 |     | qqq     | Q1, Q2, Q3, Q4                    |       |
 * |                                 |     | qqqq    | 1st quarter, 2nd quarter, ...     | 2     |
 * |                                 |     | qqqqq   | 1, 2, 3, 4                        | 3     |
 * | Month (formatting)              | 110 | M       | 1, 2, ..., 12                     |       |
 * |                                 |     | Mo      | 1st, 2nd, ..., 12th               | 5     |
 * |                                 |     | MM      | 01, 02, ..., 12                   |       |
 * |                                 |     | MMM     | Jan, Feb, ..., Dec                |       |
 * |                                 |     | MMMM    | January, February, ..., December  | 2     |
 * |                                 |     | MMMMM   | J, F, ..., D                      |       |
 * | Month (stand-alone)             | 110 | L       | 1, 2, ..., 12                     |       |
 * |                                 |     | Lo      | 1st, 2nd, ..., 12th               | 5     |
 * |                                 |     | LL      | 01, 02, ..., 12                   |       |
 * |                                 |     | LLL     | Jan, Feb, ..., Dec                |       |
 * |                                 |     | LLLL    | January, February, ..., December  | 2     |
 * |                                 |     | LLLLL   | J, F, ..., D                      |       |
 * | Local week of year              | 100 | w       | 1, 2, ..., 53                     |       |
 * |                                 |     | wo      | 1st, 2nd, ..., 53th               | 5     |
 * |                                 |     | ww      | 01, 02, ..., 53                   |       |
 * | ISO week of year                | 100 | I       | 1, 2, ..., 53                     | 5     |
 * |                                 |     | Io      | 1st, 2nd, ..., 53th               | 5     |
 * |                                 |     | II      | 01, 02, ..., 53                   | 5     |
 * | Day of month                    |  90 | d       | 1, 2, ..., 31                     |       |
 * |                                 |     | do      | 1st, 2nd, ..., 31st               | 5     |
 * |                                 |     | dd      | 01, 02, ..., 31                   |       |
 * | Day of year                     |  90 | D       | 1, 2, ..., 365, 366               | 7     |
 * |                                 |     | Do      | 1st, 2nd, ..., 365th, 366th       | 5     |
 * |                                 |     | DD      | 01, 02, ..., 365, 366             | 7     |
 * |                                 |     | DDD     | 001, 002, ..., 365, 366           |       |
 * |                                 |     | DDDD    | ...                               | 2     |
 * | Day of week (formatting)        |  90 | E..EEE  | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 |     | EEEE    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 |     | EEEEE   | M, T, W, T, F, S, S               |       |
 * |                                 |     | EEEEEE  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
 * | ISO day of week (formatting)    |  90 | i       | 1, 2, 3, ..., 7                   | 5     |
 * |                                 |     | io      | 1st, 2nd, ..., 7th                | 5     |
 * |                                 |     | ii      | 01, 02, ..., 07                   | 5     |
 * |                                 |     | iii     | Mon, Tue, Wed, ..., Sun           | 5     |
 * |                                 |     | iiii    | Monday, Tuesday, ..., Sunday      | 2,5   |
 * |                                 |     | iiiii   | M, T, W, T, F, S, S               | 5     |
 * |                                 |     | iiiiii  | Mo, Tu, We, Th, Fr, Su, Sa        | 5     |
 * | Local day of week (formatting)  |  90 | e       | 2, 3, 4, ..., 1                   |       |
 * |                                 |     | eo      | 2nd, 3rd, ..., 1st                | 5     |
 * |                                 |     | ee      | 02, 03, ..., 01                   |       |
 * |                                 |     | eee     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 |     | eeee    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 |     | eeeee   | M, T, W, T, F, S, S               |       |
 * |                                 |     | eeeeee  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
 * | Local day of week (stand-alone) |  90 | c       | 2, 3, 4, ..., 1                   |       |
 * |                                 |     | co      | 2nd, 3rd, ..., 1st                | 5     |
 * |                                 |     | cc      | 02, 03, ..., 01                   |       |
 * |                                 |     | ccc     | Mon, Tue, Wed, ..., Sun           |       |
 * |                                 |     | cccc    | Monday, Tuesday, ..., Sunday      | 2     |
 * |                                 |     | ccccc   | M, T, W, T, F, S, S               |       |
 * |                                 |     | cccccc  | Mo, Tu, We, Th, Fr, Su, Sa        |       |
 * | AM, PM                          |  80 | a..aaa  | AM, PM                            |       |
 * |                                 |     | aaaa    | a.m., p.m.                        | 2     |
 * |                                 |     | aaaaa   | a, p                              |       |
 * | AM, PM, noon, midnight          |  80 | b..bbb  | AM, PM, noon, midnight            |       |
 * |                                 |     | bbbb    | a.m., p.m., noon, midnight        | 2     |
 * |                                 |     | bbbbb   | a, p, n, mi                       |       |
 * | Flexible day period             |  80 | B..BBB  | at night, in the morning, ...     |       |
 * |                                 |     | BBBB    | at night, in the morning, ...     | 2     |
 * |                                 |     | BBBBB   | at night, in the morning, ...     |       |
 * | Hour [1-12]                     |  70 | h       | 1, 2, ..., 11, 12                 |       |
 * |                                 |     | ho      | 1st, 2nd, ..., 11th, 12th         | 5     |
 * |                                 |     | hh      | 01, 02, ..., 11, 12               |       |
 * | Hour [0-23]                     |  70 | H       | 0, 1, 2, ..., 23                  |       |
 * |                                 |     | Ho      | 0th, 1st, 2nd, ..., 23rd          | 5     |
 * |                                 |     | HH      | 00, 01, 02, ..., 23               |       |
 * | Hour [0-11]                     |  70 | K       | 1, 2, ..., 11, 0                  |       |
 * |                                 |     | Ko      | 1st, 2nd, ..., 11th, 0th          | 5     |
 * |                                 |     | KK      | 01, 02, ..., 11, 00               |       |
 * | Hour [1-24]                     |  70 | k       | 24, 1, 2, ..., 23                 |       |
 * |                                 |     | ko      | 24th, 1st, 2nd, ..., 23rd         | 5     |
 * |                                 |     | kk      | 24, 01, 02, ..., 23               |       |
 * | Minute                          |  60 | m       | 0, 1, ..., 59                     |       |
 * |                                 |     | mo      | 0th, 1st, ..., 59th               | 5     |
 * |                                 |     | mm      | 00, 01, ..., 59                   |       |
 * | Second                          |  50 | s       | 0, 1, ..., 59                     |       |
 * |                                 |     | so      | 0th, 1st, ..., 59th               | 5     |
 * |                                 |     | ss      | 00, 01, ..., 59                   |       |
 * | Seconds timestamp               |  40 | t       | 512969520                         |       |
 * |                                 |     | tt      | ...                               | 2     |
 * | Fraction of second              |  30 | S       | 0, 1, ..., 9                      |       |
 * |                                 |     | SS      | 00, 01, ..., 99                   |       |
 * |                                 |     | SSS     | 000, 0001, ..., 999               |       |
 * |                                 |     | SSSS    | ...                               | 2     |
 * | Milliseconds timestamp          |  20 | T       | 512969520900                      |       |
 * |                                 |     | TT      | ...                               | 2     |
 * | Timezone (ISO-8601 w/ Z)        |  10 | X       | -08, +0530, Z                     |       |
 * |                                 |     | XX      | -0800, +0530, Z                   |       |
 * |                                 |     | XXX     | -08:00, +05:30, Z                 |       |
 * |                                 |     | XXXX    | -0800, +0530, Z, +123456          | 2     |
 * |                                 |     | XXXXX   | -08:00, +05:30, Z, +12:34:56      |       |
 * | Timezone (ISO-8601 w/o Z)       |  10 | x       | -08, +0530, +00                   |       |
 * |                                 |     | xx      | -0800, +0530, +0000               |       |
 * |                                 |     | xxx     | -08:00, +05:30, +00:00            | 2     |
 * |                                 |     | xxxx    | -0800, +0530, +0000, +123456      |       |
 * |                                 |     | xxxxx   | -08:00, +05:30, +00:00, +12:34:56 |       |
 * | Long localized date             |  NA | P       | 05/29/1453                        | 5,8   |
 * |                                 |     | PP      | May 29, 1453                      |       |
 * |                                 |     | PPP     | May 29th, 1453                    |       |
 * |                                 |     | PPPP    | Sunday, May 29th, 1453            | 2,5,8 |
 * | Long localized time             |  NA | p       | 12:00 AM                          | 5,8   |
 * |                                 |     | pp      | 12:00:00 AM                       |       |
 * | Combination of date and time    |  NA | Pp      | 05/29/1453, 12:00 AM              |       |
 * |                                 |     | PPpp    | May 29, 1453, 12:00:00 AM         |       |
 * |                                 |     | PPPpp   | May 29th, 1453 at ...             |       |
 * |                                 |     | PPPPpp  | Sunday, May 29th, 1453 at ...     | 2,5,8 |
 * Notes:
 * 1. "Formatting" units (e.g. formatting quarter) in the default en-US locale
 *    are the same as "stand-alone" units, but are different in some languages.
 *    "Formatting" units are declined according to the rules of the language
 *    in the context of a date. "Stand-alone" units are always nominative singular.
 *    In `format` function, they will produce different result:
 *
 *    `format(new Date(2017, 10, 6), 'do LLLL', {locale: cs}) //=> '6. listopad'`
 *
 *    `format(new Date(2017, 10, 6), 'do MMMM', {locale: cs}) //=> '6. listopadu'`
 *
 *    `parse` will try to match both formatting and stand-alone units interchangably.
 *
 * 2. Any sequence of the identical letters is a pattern, unless it is escaped by
 *    the single quote characters (see below).
 *    If the sequence is longer than listed in table:
 *    - for numerical units (`yyyyyyyy`) `parse` will try to match a number
 *      as wide as the sequence
 *    - for text units (`MMMMMMMM`) `parse` will try to match the widest variation of the unit.
 *      These variations are marked with "2" in the last column of the table.
 *
 * 3. `QQQQQ` and `qqqqq` could be not strictly numerical in some locales.
 *    These tokens represent the shortest form of the quarter.
 *
 * 4. The main difference between `y` and `u` patterns are B.C. years:
 *
 *    | Year | `y` | `u` |
 *    |------|-----|-----|
 *    | AC 1 |   1 |   1 |
 *    | BC 1 |   1 |   0 |
 *    | BC 2 |   2 |  -1 |
 *
 *    Also `yy` will try to guess the century of two digit year by proximity with `referenceDate`:
 *
 *    `parse('50', 'yy', new Date(2018, 0, 1)) //=> Sat Jan 01 2050 00:00:00`
 *
 *    `parse('75', 'yy', new Date(2018, 0, 1)) //=> Wed Jan 01 1975 00:00:00`
 *
 *    while `uu` will just assign the year as is:
 *
 *    `parse('50', 'uu', new Date(2018, 0, 1)) //=> Sat Jan 01 0050 00:00:00`
 *
 *    `parse('75', 'uu', new Date(2018, 0, 1)) //=> Tue Jan 01 0075 00:00:00`
 *
 *    The same difference is true for local and ISO week-numbering years (`Y` and `R`),
 *    except local week-numbering years are dependent on `options.weekStartsOn`
 *    and `options.firstWeekContainsDate` (compare [setISOWeekYear]{@link https://date-fns.org/docs/setISOWeekYear}
 *    and [setWeekYear]{@link https://date-fns.org/docs/setWeekYear}).
 *
 * 5. These patterns are not in the Unicode Technical Standard #35:
 *    - `i`: ISO day of week
 *    - `I`: ISO week of year
 *    - `R`: ISO week-numbering year
 *    - `o`: ordinal number modifier
 *    - `P`: long localized date
 *    - `p`: long localized time
 *
 * 6. `YY` and `YYYY` tokens represent week-numbering years but they are often confused with years.
 *    You should enable `options.useAdditionalWeekYearTokens` to use them. See: https://git.io/fxCyr
 *
 * 7. `D` and `DD` tokens represent days of the year but they are ofthen confused with days of the month.
 *    You should enable `options.useAdditionalDayOfYearTokens` to use them. See: https://git.io/fxCyr
 *
 * 8. `P+` tokens do not have a defined priority since they are merely aliases to other tokens based
 *    on the given locale.
 *
 *    using `en-US` locale: `P` => `MM/dd/yyyy`
 *    using `en-US` locale: `p` => `hh:mm a`
 *    using `pt-BR` locale: `P` => `dd/MM/yyyy`
 *    using `pt-BR` locale: `p` => `HH:mm`
 *
 * Values will be assigned to the date in the descending order of its unit's priority.
 * Units of an equal priority overwrite each other in the order of appearance.
 *
 * If no values of higher priority are parsed (e.g. when parsing string 'January 1st' without a year),
 * the values will be taken from 3rd argument `referenceDate` which works as a context of parsing.
 *
 * `referenceDate` must be passed for correct work of the function.
 * If you're not sure which `referenceDate` to supply, create a new instance of Date:
 * `parse('02/11/2014', 'MM/dd/yyyy', new Date())`
 * In this case parsing will be done in the context of the current date.
 * If `referenceDate` is `Invalid Date` or a value not convertible to valid `Date`,
 * then `Invalid Date` will be returned.
 *
 * The result may vary by locale.
 *
 * If `formatString` matches with `dateString` but does not provides tokens, `referenceDate` will be returned.
 *
 * If parsing failed, `Invalid Date` will be returned.
 * Invalid Date is a Date, whose time value is NaN.
 * Time value of Date: http://es5.github.io/#x15.9.1.1
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * - Old `parse` was renamed to `toDate`.
 *   Now `parse` is a new function which parses a string using a provided format.
 *
 *   ```javascript
 *   // Before v2.0.0
 *   parse('2016-01-01')
 *
 *   // v2.0.0 onward (toDate no longer accepts a string)
 *   toDate(1392098430000) // Unix to timestamp
 *   toDate(new Date(2014, 1, 11, 11, 30, 30)) // Cloning the date
 *   parse('2016-01-01', 'yyyy-MM-dd', new Date())
 *   ```
 *
 * @param {String} dateString - the string to parse
 * @param {String} formatString - the string of tokens
 * @param {Date|Number} referenceDate - defines values missing from the parsed dateString
 * @param {Object} [options] - an object with options.
 * @param {Locale} [options.locale=defaultLocale] - the locale object. See [Locale]{@link https://date-fns.org/docs/Locale}
 * @param {0|1|2|3|4|5|6} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @param {1|2|3|4|5|6|7} [options.firstWeekContainsDate=1] - the day of January, which is always in the first week of the year
 * @param {Boolean} [options.useAdditionalWeekYearTokens=false] - if true, allows usage of the week-numbering year tokens `YY` and `YYYY`;
 *   see: https://git.io/fxCyr
 * @param {Boolean} [options.useAdditionalDayOfYearTokens=false] - if true, allows usage of the day of year tokens `D` and `DD`;
 *   see: https://git.io/fxCyr
 * @returns {Date} the parsed date
 * @throws {TypeError} 3 arguments required
 * @throws {RangeError} `options.weekStartsOn` must be between 0 and 6
 * @throws {RangeError} `options.firstWeekContainsDate` must be between 1 and 7
 * @throws {RangeError} `options.locale` must contain `match` property
 * @throws {RangeError} use `yyyy` instead of `YYYY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `yy` instead of `YY` for formatting years using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `d` instead of `D` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} use `dd` instead of `DD` for formatting days of the month using [format provided] to the input [input provided]; see: https://git.io/fxCyr
 * @throws {RangeError} format string contains an unescaped latin alphabet character
 *
 * @example
 * // Parse 11 February 2014 from middle-endian format:
 * var result = parse('02/11/2014', 'MM/dd/yyyy', new Date())
 * //=> Tue Feb 11 2014 00:00:00
 *
 * @example
 * // Parse 28th of February in Esperanto locale in the context of 2010 year:
 * import eo from 'date-fns/locale/eo'
 * var result = parse('28-a de februaro', "do 'de' MMMM", new Date(2010, 0, 1), {
 *   locale: eo
 * })
 * //=> Sun Feb 28 2010 00:00:00
 */

function parse(dirtyDateString,dirtyFormatString,dirtyReferenceDate,dirtyOptions){
requiredArgs(3,arguments);
var dateString=String(dirtyDateString);
var formatString=String(dirtyFormatString);
var options=dirtyOptions||{};
var locale$1=options.locale||locale;

if(!locale$1.match){
throw new RangeError('locale must contain match property');
}

var localeFirstWeekContainsDate=locale$1.options&&locale$1.options.firstWeekContainsDate;
var defaultFirstWeekContainsDate=localeFirstWeekContainsDate==null?1:toInteger(localeFirstWeekContainsDate);
var firstWeekContainsDate=options.firstWeekContainsDate==null?defaultFirstWeekContainsDate:toInteger(options.firstWeekContainsDate);// Test if weekStartsOn is between 1 and 7 _and_ is not NaN

if(!(firstWeekContainsDate>=1&&firstWeekContainsDate<=7)){
throw new RangeError('firstWeekContainsDate must be between 1 and 7 inclusively');
}

var localeWeekStartsOn=locale$1.options&&locale$1.options.weekStartsOn;
var defaultWeekStartsOn=localeWeekStartsOn==null?0:toInteger(localeWeekStartsOn);
var weekStartsOn=options.weekStartsOn==null?defaultWeekStartsOn:toInteger(options.weekStartsOn);// Test if weekStartsOn is between 0 and 6 _and_ is not NaN

if(!(weekStartsOn>=0&&weekStartsOn<=6)){
throw new RangeError('weekStartsOn must be between 0 and 6 inclusively');
}

if(formatString===''){
if(dateString===''){
return toDate(dirtyReferenceDate);
}else {
return new Date(NaN);
}
}

var subFnOptions={
firstWeekContainsDate:firstWeekContainsDate,
weekStartsOn:weekStartsOn,
locale:locale$1// If timezone isn't specified, it will be set to the system timezone
};

var setters=[{
priority:TIMEZONE_UNIT_PRIORITY,
subPriority:-1,
set:dateToSystemTimezone,
index:0}];

var i;
var tokens=formatString.match(longFormattingTokensRegExp$1).map(function(substring){
var firstCharacter=substring[0];

if(firstCharacter==='p'||firstCharacter==='P'){
var longFormatter=longFormatters[firstCharacter];
return longFormatter(substring,locale$1.formatLong,subFnOptions);
}

return substring;
}).join('').match(formattingTokensRegExp$1);
var usedTokens=[];

for(i=0;i<tokens.length;i++){
var token=tokens[i];

if(!options.useAdditionalWeekYearTokens&&isProtectedWeekYearToken(token)){
throwProtectedError(token,formatString,dirtyDateString);
}

if(!options.useAdditionalDayOfYearTokens&&isProtectedDayOfYearToken(token)){
throwProtectedError(token,formatString,dirtyDateString);
}

var firstCharacter=token[0];
var parser=parsers[firstCharacter];

if(parser){
var incompatibleTokens=parser.incompatibleTokens;

if(Array.isArray(incompatibleTokens)){
var incompatibleToken=void 0;

for(var _i=0;_i<usedTokens.length;_i++){
var usedToken=usedTokens[_i].token;

if(incompatibleTokens.indexOf(usedToken)!==-1||usedToken===firstCharacter){
incompatibleToken=usedTokens[_i];
break;
}
}

if(incompatibleToken){
throw new RangeError("The format string mustn't contain `".concat(incompatibleToken.fullToken,"` and `").concat(token,"` at the same time"));
}
}else if(parser.incompatibleTokens==='*'&&usedTokens.length){
throw new RangeError("The format string mustn't contain `".concat(token,"` and any other token at the same time"));
}

usedTokens.push({
token:firstCharacter,
fullToken:token});

var parseResult=parser.parse(dateString,token,locale$1.match,subFnOptions);

if(!parseResult){
return new Date(NaN);
}

setters.push({
priority:parser.priority,
subPriority:parser.subPriority||0,
set:parser.set,
validate:parser.validate,
value:parseResult.value,
index:setters.length});

dateString=parseResult.rest;
}else {
if(firstCharacter.match(unescapedLatinCharacterRegExp$1)){
throw new RangeError('Format string contains an unescaped latin alphabet character `'+firstCharacter+'`');
}// Replace two single quote characters with one single quote character


if(token==="''"){
token="'";
}else if(firstCharacter==="'"){
token=cleanEscapedString$1(token);
}// Cut token from string, or, if string doesn't match the token, return Invalid Date


if(dateString.indexOf(token)===0){
dateString=dateString.slice(token.length);
}else {
return new Date(NaN);
}
}
}// Check if the remaining input contains something other than whitespace


if(dateString.length>0&&notWhitespaceRegExp.test(dateString)){
return new Date(NaN);
}

var uniquePrioritySetters=setters.map(function(setter){
return setter.priority;
}).sort(function(a,b){
return b-a;
}).filter(function(priority,index,array){
return array.indexOf(priority)===index;
}).map(function(priority){
return setters.filter(function(setter){
return setter.priority===priority;
}).sort(function(a,b){
return b.subPriority-a.subPriority;
});
}).map(function(setterArray){
return setterArray[0];
});
var date=toDate(dirtyReferenceDate);

if(isNaN(date)){
return new Date(NaN);
}// Convert the date in system timezone to the same date in UTC+00:00 timezone.
// This ensures that when UTC functions will be implemented, locales will be compatible with them.
// See an issue about UTC functions: https://github.com/date-fns/date-fns/issues/37


var utcDate=subMilliseconds(date,getTimezoneOffsetInMilliseconds(date));
var flags={};

for(i=0;i<uniquePrioritySetters.length;i++){
var setter=uniquePrioritySetters[i];

if(setter.validate&&!setter.validate(utcDate,setter.value,subFnOptions)){
return new Date(NaN);
}

var result=setter.set(utcDate,flags,setter.value,subFnOptions);// Result is tuple (date, flags)

if(result[0]){
utcDate=result[0];
assign(flags,result[1]);// Result is date
}else {
utcDate=result;
}
}

return utcDate;
}

function dateToSystemTimezone(date,flags){
if(flags.timestampIsSet){
return date;
}

var convertedDate=new Date(0);
convertedDate.setFullYear(date.getUTCFullYear(),date.getUTCMonth(),date.getUTCDate());
convertedDate.setHours(date.getUTCHours(),date.getUTCMinutes(),date.getUTCSeconds(),date.getUTCMilliseconds());
return convertedDate;
}

function cleanEscapedString$1(input){
return input.match(escapedStringRegExp$1)[1].replace(doubleQuoteRegExp$1,"'");
}

var date=Object.assign({},defaultType);
date.isRight=true;

date.compare=function(x,y,column){
function cook(d){
if(column&&column.dateInputFormat){
return parse("".concat(d),"".concat(column.dateInputFormat),new Date());
}

return d;
}

x=cook(x);
y=cook(y);

if(!isValid(x)){
return -1;
}

if(!isValid(y)){
return 1;
}

return compareAsc(x,y);
};

date.format=function(v,column){
if(v===undefined||v===null)return '';// convert to date

var date=parse(v,column.dateInputFormat,new Date());

if(isValid(date)){
return format(date,column.dateOutputFormat);
}

console.error("Not a valid date: \"".concat(v,"\""));
return null;
};

var date$1=/*#__PURE__*/Object.freeze({
__proto__:null,
'default':date});


var number=Object.assign({},defaultType);
number.isRight=true;

number.filterPredicate=function(rowval,filter){
return number.compare(rowval,filter)===0;
};

number.compare=function(x,y){
function cook(d){
// if d is null or undefined we give it the smallest
// possible value
if(d===undefined||d===null)return -Infinity;
return d.indexOf('.')>=0?parseFloat(d):parseInt(d,10);
}

x=typeof x==='number'?x:cook(x);
y=typeof y==='number'?y:cook(y);
if(x<y)return -1;
if(x>y)return 1;
return 0;
};

var number$1=/*#__PURE__*/Object.freeze({
__proto__:null,
'default':number});


var decimal=Object.assign({},number);

decimal.format=function(v){
if(v===undefined||v===null)return '';
return parseFloat(Math.round(v*100)/100).toFixed(2);
};

var decimal$1=/*#__PURE__*/Object.freeze({
__proto__:null,
'default':decimal});


var percentage=Object.assign({},number);

percentage.format=function(v){
if(v===undefined||v===null)return '';
return "".concat(parseFloat(v*100).toFixed(2),"%");
};

var percentage$1=/*#__PURE__*/Object.freeze({
__proto__:null,
'default':percentage});


var _boolean=Object.assign({},defaultType);

_boolean.isRight=true;

_boolean.filterPredicate=function(rowval,filter){
return _boolean.compare(rowval,filter)===0;
};

_boolean.compare=function(x,y){
function cook(d){
if(typeof d==='boolean')return d?1:0;
if(typeof d==='string')return d==='true'?1:0;
return -Infinity;
}

x=cook(x);
y=cook(y);
if(x<y)return -1;
if(x>y)return 1;
return 0;
};

var _boolean$1=/*#__PURE__*/Object.freeze({
__proto__:null,
'default':_boolean});


var index={
date:date$1,
decimal:decimal$1,
number:number$1,
percentage:percentage$1,
"boolean":_boolean$1};


var dataTypes={};
var coreDataTypes=index;
Object.keys(coreDataTypes).forEach(function(key){
var compName=key.replace(/^\.\//,'').replace(/\.js/,'');
dataTypes[compName]=coreDataTypes[key]["default"];
});
var script$6={
name:'vue-good-table',
props:{
isLoading:{
"default":null,
type:Boolean},

maxHeight:{
"default":null,
type:String},

fixedHeader:Boolean,
theme:{
"default":''},

mode:{
"default":'local'},

// could be remote
totalRows:{},
// required if mode = 'remote'
styleClass:{
"default":'vgt-table bordered'},

columns:{},
rows:{},
lineNumbers:Boolean,
responsive:{
"default":true,
type:Boolean},

rtl:Boolean,
rowStyleClass:{
"default":null,
type:[Function,String]},

compactMode:Boolean,
groupOptions:{
"default":function _default(){
return {
enabled:false,
collapsable:false,
rowKey:null};

}},

selectOptions:{
"default":function _default(){
return {
enabled:false,
selectionInfoClass:'',
selectionText:'rows selected',
clearSelectionText:'clear',
disableSelectInfo:false,
selectAllByGroup:false};

}},

// sort
sortOptions:{
"default":function _default(){
return {
enabled:true,
multipleColumns:true,
initialSortBy:{}};

}},

// pagination
paginationOptions:{
"default":function _default(){
var _ref;

return _ref={
enabled:false,
position:'bottom',
perPage:10,
perPageDropdown:null,
perPageDropdownEnabled:true},
_defineProperty(_ref,"position",'bottom'),_defineProperty(_ref,"dropdownAllowAll",true),_defineProperty(_ref,"mode",'records'),_defineProperty(_ref,"infoFn",null),_ref;
}},

searchOptions:{
"default":function _default(){
return {
enabled:false,
trigger:null,
externalQuery:null,
searchFn:null,
placeholder:'Search Table'};

}}},


data:function data(){
return {
// loading state for remote mode
tableLoading:false,
// text options
nextText:'Next',
prevText:'Previous',
rowsPerPageText:'Rows per page',
ofText:'of',
allText:'All',
pageText:'page',
// internal select options
selectable:false,
selectOnCheckboxOnly:false,
selectAllByPage:true,
disableSelectInfo:false,
selectionInfoClass:'',
selectionText:'rows selected',
clearSelectionText:'clear',
// keys for rows that are currently expanded
maintainExpanded:true,
expandedRowKeys:new Set(),
// internal sort options
sortable:true,
defaultSortBy:null,
multipleColumnSort:true,
// internal search options
searchEnabled:false,
searchTrigger:null,
externalSearchQuery:null,
searchFn:null,
searchPlaceholder:'Search Table',
searchSkipDiacritics:false,
// internal pagination options
perPage:null,
paginate:false,
paginateOnTop:false,
paginateOnBottom:true,
customRowsPerPageDropdown:[],
paginateDropdownAllowAll:true,
paginationMode:'records',
paginationInfoFn:null,
currentPage:1,
currentPerPage:10,
sorts:[],
globalSearchTerm:'',
filteredRows:[],
columnFilters:{},
forceSearch:false,
sortChanged:false,
dataTypes:dataTypes||{}};

},
watch:{
rows:{
handler:function handler(){
this.$emit('update:isLoading',false);
this.filterRows(this.columnFilters,false);
},
deep:true,
immediate:true},

selectOptions:{
handler:function handler(){
this.initializeSelect();
},
deep:true,
immediate:true},

paginationOptions:{
handler:function handler(newValue,oldValue){
if(!lodash_isequal(newValue,oldValue)){
this.initializePagination();
}
},
deep:true,
immediate:true},

searchOptions:{
handler:function handler(){
if(this.searchOptions.externalQuery!==undefined&&this.searchOptions.externalQuery!==this.searchTerm){
//* we need to set searchTerm to externalQuery first.
this.externalSearchQuery=this.searchOptions.externalQuery;
this.handleSearch();
}

this.initializeSearch();
},
deep:true,
immediate:true},

sortOptions:{
handler:function handler(newValue,oldValue){
if(!lodash_isequal(newValue,oldValue)){
this.initializeSort();
}
},
deep:true},

selectedRows:function selectedRows(newValue,oldValue){
if(!lodash_isequal(newValue,oldValue)){
this.$emit('on-selected-rows-change',{
selectedRows:this.selectedRows});

}
}},

computed:{
tableStyles:function tableStyles(){
if(this.compactMode)return this.tableStyleClasses+'vgt-compact';else return this.tableStyleClasses;
},
hasFooterSlot:function hasFooterSlot(){
return !!this.$slots['table-actions-bottom'];
},
wrapperStyles:function wrapperStyles(){
return {
overflow:'scroll-y',
maxHeight:this.maxHeight?this.maxHeight:'auto'};

},
rowKeyField:function rowKeyField(){
return this.groupOptions.rowKey||'vgt_header_id';
},
hasHeaderRowTemplate:function hasHeaderRowTemplate(){
return !!this.$slots['table-header-row']||!!this.$scopedSlots['table-header-row'];
},
showEmptySlot:function showEmptySlot(){
if(!this.paginated.length)return true;

if(this.paginated[0].label==='no groups'&&!this.paginated[0].children.length){
return true;
}

return false;
},
allSelected:function allSelected(){
return this.selectedRowCount>0&&(this.selectAllByPage&&this.selectedPageRowsCount===this.totalPageRowCount||!this.selectAllByPage&&this.selectedRowCount===this.totalRowCount);
},
allSelectedIndeterminate:function allSelectedIndeterminate(){
return !this.allSelected&&(this.selectAllByPage&&this.selectedPageRowsCount>0||!this.selectAllByPage&&this.selectedRowCount>0);
},
selectionInfo:function selectionInfo(){
return "".concat(this.selectedRowCount," ").concat(this.selectionText);
},
selectedRowCount:function selectedRowCount(){
return this.selectedRows.length;
},
selectedPageRowsCount:function selectedPageRowsCount(){
return this.selectedPageRows.length;
},
selectedPageRows:function selectedPageRows(){
var selectedRows=[];
this.paginated.forEach(function(headerRow){
headerRow.children.forEach(function(row){
if(row.vgtSelected){
selectedRows.push(row);
}
});
});
return selectedRows;
},
selectedRows:function selectedRows(){
var selectedRows=[];
this.processedRows.forEach(function(headerRow){
headerRow.children.forEach(function(row){
if(row.vgtSelected){
selectedRows.push(row);
}
});
});
return selectedRows.sort(function(r1,r2){
return r1.originalIndex-r2.originalIndex;
});
},
fullColspan:function fullColspan(){
var fullColspan=0;

for(var i=0;i<this.columns.length;i+=1){
if(!this.columns[i].hidden){
fullColspan+=1;
}
}

if(this.lineNumbers)fullColspan++;
if(this.selectable)fullColspan++;
return fullColspan;
},
groupHeaderOnTop:function groupHeaderOnTop(){
if(this.groupOptions&&this.groupOptions.enabled&&this.groupOptions.headerPosition&&this.groupOptions.headerPosition==='bottom'){
return false;
}

if(this.groupOptions&&this.groupOptions.enabled)return true;// will only get here if groupOptions is false

return false;
},
groupHeaderOnBottom:function groupHeaderOnBottom(){
if(this.groupOptions&&this.groupOptions.enabled&&this.groupOptions.headerPosition&&this.groupOptions.headerPosition==='bottom'){
return true;
}

return false;
},
totalRowCount:function totalRowCount(){
var total=this.processedRows.reduce(function(total,headerRow){
var childrenCount=headerRow.children?headerRow.children.length:0;
return total+childrenCount;
},0);
return total;
},
totalPageRowCount:function totalPageRowCount(){
var total=this.paginated.reduce(function(total,headerRow){
var childrenCount=headerRow.children?headerRow.children.length:0;
return total+childrenCount;
},0);
return total;
},
wrapStyleClasses:function wrapStyleClasses(){
var classes='vgt-wrap';
if(this.rtl)classes+=' rtl';
classes+=" ".concat(this.theme);
return classes;
},
tableStyleClasses:function tableStyleClasses(){
var classes=this.styleClass;
classes+=" ".concat(this.theme);
return classes;
},
searchTerm:function searchTerm(){
return this.externalSearchQuery!=null?this.externalSearchQuery:this.globalSearchTerm;
},
//
globalSearchAllowed:function globalSearchAllowed(){
if(this.searchEnabled&&!!this.globalSearchTerm&&this.searchTrigger!=='enter'){
return true;
}

if(this.externalSearchQuery!=null&&this.searchTrigger!=='enter'){
return true;
}

if(this.forceSearch){
this.forceSearch=false;
return true;
}

return false;
},
// this is done everytime sortColumn
// or sort type changes
//----------------------------------------
processedRows:function processedRows(){
var _this=this;

// we only process rows when mode is local
var computedRows=this.filteredRows;

if(this.mode==='remote'){
return computedRows;
}// take care of the global filter here also


if(this.globalSearchAllowed){
// here also we need to de-construct and then
// re-construct the rows.
var allRows=[];
this.filteredRows.forEach(function(headerRow){
allRows.push.apply(allRows,_toConsumableArray(headerRow.children));
});
var filteredRows=[];
allRows.forEach(function(row){
for(var i=0;i<_this.columns.length;i+=1){
var col=_this.columns[i];// if col does not have search disabled,

if(!col.globalSearchDisabled){
// if a search function is provided,
// use that for searching, otherwise,
// use the default search behavior
if(_this.searchFn){
var foundMatch=_this.searchFn(row,col,_this.collectFormatted(row,col),_this.searchTerm);

if(foundMatch){
filteredRows.push(row);
break;// break the loop
}
}else {
// comparison
var matched=defaultType.filterPredicate(_this.collectFormatted(row,col),_this.searchTerm,_this.searchSkipDiacritics);

if(matched){
filteredRows.push(row);
break;// break loop
}
}
}
}
});// this is where we emit on search

this.$emit('on-search',{
searchTerm:this.searchTerm,
rowCount:filteredRows.length});
// here we need to reconstruct the nested structure
// of rows

computedRows=[];
this.filteredRows.forEach(function(headerRow){
var i=headerRow.vgt_header_id;
var children=filteredRows.filter(function(r){
return r.vgt_id===i;
});

if(children.length){
var newHeaderRow=JSON.parse(JSON.stringify(headerRow));
newHeaderRow.children=children;
computedRows.push(newHeaderRow);
}
});
}

if(this.sorts.length){
//* we need to sort
computedRows.forEach(function(cRows){
cRows.children.sort(function(xRow,yRow){
//* we need to get column for each sort
var sortValue;

for(var i=0;i<_this.sorts.length;i+=1){
var srt=_this.sorts[i];

if(srt.type===SORT_TYPES.None){
//* if no sort, we need to use the original index to sort.
sortValue=sortValue||xRow.originalIndex-yRow.originalIndex;
}else {
var column=_this.getColumnForField(srt.field);

var xvalue=_this.collect(xRow,srt.field);

var yvalue=_this.collect(yRow,srt.field);//* if a custom sort function has been provided we use that


var sortFn=column.sortFn;

if(sortFn&&typeof sortFn==='function'){
sortValue=sortValue||sortFn(xvalue,yvalue,column,xRow,yRow)*(srt.type===SORT_TYPES.Descending?-1:1);
}else {
//* else we use our own sort
sortValue=sortValue||column.typeDef.compare(xvalue,yvalue,column)*(srt.type===SORT_TYPES.Descending?-1:1);
}
}
}

return sortValue;
});
});
}// if the filtering is event based, we need to maintain filter
// rows


if(this.searchTrigger==='enter'){
this.filteredRows=computedRows;
}

return computedRows;
},
paginated:function paginated(){
var _this2=this;

if(!this.processedRows.length)return [];

if(this.mode==='remote'){
return this.processedRows;
}//* flatten the rows for paging.


var paginatedRows=[];
this.processedRows.forEach(function(childRows){
var _paginatedRows;

//* only add headers when group options are enabled.
if(_this2.groupOptions.enabled){
paginatedRows.push(childRows);
}

(_paginatedRows=paginatedRows).push.apply(_paginatedRows,_toConsumableArray(childRows.children));
});

if(this.paginate){
var pageStart=(this.currentPage-1)*this.currentPerPage;// in case of filtering we might be on a page that is
// not relevant anymore
// also, if setting to all, current page will not be valid

if(pageStart>=paginatedRows.length||this.currentPerPage===-1){
this.currentPage=1;
pageStart=0;
}// calculate page end now


var pageEnd=paginatedRows.length+1;// if the setting is set to 'all'

if(this.currentPerPage!==-1){
pageEnd=this.currentPage*this.currentPerPage;
}

paginatedRows=paginatedRows.slice(pageStart,pageEnd);
}// reconstruct paginated rows here


var reconstructedRows=[];
paginatedRows.forEach(function(flatRow){
//* header row?
if(flatRow.vgt_header_id!==undefined){
_this2.handleExpanded(flatRow);

var newHeaderRow=JSON.parse(JSON.stringify(flatRow));
newHeaderRow.children=[];
reconstructedRows.push(newHeaderRow);
}else {
//* child row
var hRow=reconstructedRows.find(function(r){
return r.vgt_header_id===flatRow.vgt_id;
});

if(!hRow){
hRow=_this2.processedRows.find(function(r){
return r.vgt_header_id===flatRow.vgt_id;
});

if(hRow){
hRow=JSON.parse(JSON.stringify(hRow));
hRow.children=[];
reconstructedRows.push(hRow);
}
}

hRow.children.push(flatRow);
}
});
return reconstructedRows;
},
originalRows:function originalRows(){
var rows=JSON.parse(JSON.stringify(this.rows));
var nestedRows=[];

if(!this.groupOptions.enabled){
nestedRows=this.handleGrouped([{
label:'no groups',
children:rows}]);

}else {
nestedRows=this.handleGrouped(rows);
}// we need to preserve the original index of
// rows so lets do that


var index=0;
nestedRows.forEach(function(headerRow){
headerRow.children.forEach(function(row){
row.originalIndex=index++;
});
});
return nestedRows;
},
typedColumns:function typedColumns(){
var columns=this.columns;

for(var i=0;i<this.columns.length;i++){
var column=columns[i];
column.typeDef=this.dataTypes[column.type]||defaultType;
}

return columns;
},
hasRowClickListener:function hasRowClickListener(){
return this.$listeners&&this.$listeners['on-row-click'];
}},

methods:{
//* we need to check for expanded row state here
//* to maintain it when sorting/filtering
handleExpanded:function handleExpanded(headerRow){
if(this.maintainExpanded&&this.expandedRowKeys.has(headerRow[this.rowKeyField])){
this.$set(headerRow,'vgtIsExpanded',true);
}else {
this.$set(headerRow,'vgtIsExpanded',false);
}
},
toggleExpand:function toggleExpand(id){
var _this3=this;

var headerRow=this.filteredRows.find(function(r){
return r[_this3.rowKeyField]===id;
});

if(headerRow){
this.$set(headerRow,'vgtIsExpanded',!headerRow.vgtIsExpanded);
}

if(this.maintainExpanded&&headerRow.vgtIsExpanded){
this.expandedRowKeys.add(headerRow[this.rowKeyField]);
}else {
this.expandedRowKeys["delete"](headerRow[this.rowKeyField]);
}
},
expandAll:function expandAll(){
var _this4=this;

this.filteredRows.forEach(function(row){
_this4.$set(row,'vgtIsExpanded',true);

if(_this4.maintainExpanded){
_this4.expandedRowKeys.add(row[_this4.rowKeyField]);
}
});
},
collapseAll:function collapseAll(){
var _this5=this;

this.filteredRows.forEach(function(row){
_this5.$set(row,'vgtIsExpanded',false);

_this5.expandedRowKeys.clear();
});
},
getColumnForField:function getColumnForField(field){
for(var i=0;i<this.typedColumns.length;i+=1){
if(this.typedColumns[i].field===field)return this.typedColumns[i];
}
},
handleSearch:function handleSearch(){
this.resetTable();// for remote mode, we need to emit on-search

if(this.mode==='remote'){
this.$emit('on-search',{
searchTerm:this.searchTerm});

}
},
reset:function reset(){
this.initializeSort();
this.changePage(1);
this.$refs['table-header-primary'].reset(true);

if(this.$refs['table-header-secondary']){
this.$refs['table-header-secondary'].reset(true);
}
},
emitSelectedRows:function emitSelectedRows(){
this.$emit('on-select-all',{
selected:this.selectedRowCount===this.totalRowCount,
selectedRows:this.selectedRows});

},
unselectAllInternal:function unselectAllInternal(forceAll){
var _this6=this;

var rows=this.selectAllByPage&&!forceAll?this.paginated:this.filteredRows;
rows.forEach(function(headerRow,i){
headerRow.children.forEach(function(row,j){
_this6.$set(row,'vgtSelected',false);
});
});
this.emitSelectedRows();
},
toggleSelectAll:function toggleSelectAll(){
var _this7=this;

if(this.allSelected){
this.unselectAllInternal();
return;
}

var rows=this.selectAllByPage?this.paginated:this.filteredRows;
rows.forEach(function(headerRow){
headerRow.children.forEach(function(row){
_this7.$set(row,'vgtSelected',true);
});
});
this.emitSelectedRows();
},
toggleSelectGroup:function toggleSelectGroup(event,headerRow){
var _this8=this;

headerRow.children.forEach(function(row){
_this8.$set(row,'vgtSelected',event.checked);
});
},
changePage:function changePage(value){
var enabled=this.paginate;
var _this$$refs=this.$refs,
paginationBottom=_this$$refs.paginationBottom,
paginationTop=_this$$refs.paginationTop;

if(enabled){
if(this.paginateOnTop&&paginationTop){
paginationTop.currentPage=value;
}

if(this.paginateOnBottom&&paginationBottom){
paginationBottom.currentPage=value;
}// we also need to set the currentPage
// for table.


this.currentPage=value;
}
},
pageChangedEvent:function pageChangedEvent(){
return {
currentPage:this.currentPage,
currentPerPage:this.currentPerPage,
total:Math.floor(this.totalRowCount/this.currentPerPage)};

},
pageChanged:function pageChanged(pagination){
this.currentPage=pagination.currentPage;

if(!pagination.noEmit){
var pageChangedEvent=this.pageChangedEvent();
pageChangedEvent.prevPage=pagination.prevPage;
this.$emit('on-page-change',pageChangedEvent);

if(this.mode==='remote'){
this.$emit('update:isLoading',true);
}
}
},
perPageChanged:function perPageChanged(pagination){
this.currentPerPage=pagination.currentPerPage;// ensure that both sides of pagination are in agreement
// this fixes changes during position = 'both'

var paginationPosition=this.paginationOptions.position;

if(this.$refs.paginationTop&&(paginationPosition==='top'||paginationPosition==='both')){
this.$refs.paginationTop.currentPerPage=this.currentPerPage;
}

if(this.$refs.paginationBottom&&(paginationPosition==='bottom'||paginationPosition==='both')){
this.$refs.paginationBottom.currentPerPage=this.currentPerPage;
}//* update perPage also


var perPageChangedEvent=this.pageChangedEvent();
this.$emit('on-per-page-change',perPageChangedEvent);

if(this.mode==='remote'){
this.$emit('update:isLoading',true);
}
},
changeSort:function changeSort(sorts){
this.sorts=sorts;
this.$emit('on-sort-change',sorts);// every time we change sort we need to reset to page 1

this.changePage(1);// if the mode is remote, we don't need to do anything
// after this. just set table loading to true

if(this.mode==='remote'){
this.$emit('update:isLoading',true);
return;
}

this.sortChanged=true;
},
// checkbox click should always do the following
onCheckboxClicked:function onCheckboxClicked(row,index,event){
this.$set(row,'vgtSelected',!row.vgtSelected);
this.$emit('on-row-click',{
row:row,
pageIndex:index,
selected:!!row.vgtSelected,
event:event});

},
onRowDoubleClicked:function onRowDoubleClicked(row,index,event){
this.$emit('on-row-dblclick',{
row:row,
pageIndex:index,
selected:!!row.vgtSelected,
event:event});

},
onRowClicked:function onRowClicked(row,index,event){
if(this.selectable&&!this.selectOnCheckboxOnly){
this.$set(row,'vgtSelected',!row.vgtSelected);
}

this.$emit('on-row-click',{
row:row,
pageIndex:index,
selected:!!row.vgtSelected,
event:event});

},
onRowAuxClicked:function onRowAuxClicked(row,index,event){
this.$emit('on-row-aux-click',{
row:row,
pageIndex:index,
selected:!!row.vgtSelected,
event:event});

},
onCellClicked:function onCellClicked(row,column,rowIndex,event){
this.$emit('on-cell-click',{
row:row,
column:column,
rowIndex:rowIndex,
event:event});

},
onMouseenter:function onMouseenter(row,index){
this.$emit('on-row-mouseenter',{
row:row,
pageIndex:index});

},
onMouseleave:function onMouseleave(row,index){
this.$emit('on-row-mouseleave',{
row:row,
pageIndex:index});

},
searchTableOnEnter:function searchTableOnEnter(){
if(this.searchTrigger==='enter'){
this.handleSearch();// we reset the filteredRows here because
// we want to search across everything.

this.filteredRows=JSON.parse(JSON.stringify(this.originalRows));
this.forceSearch=true;
this.sortChanged=true;
}
},
searchTableOnKeyUp:function searchTableOnKeyUp(){
if(this.searchTrigger!=='enter'){
this.handleSearch();
}
},
resetTable:function resetTable(){
this.unselectAllInternal(true);// every time we searchTable

this.changePage(1);
},
// field can be:
// 1. function (passed as a string using function.name. For example: 'bound myFunction')
// 2. regular property - ex: 'prop'
// 3. nested property path - ex: 'nested.prop'
collect:function collect(obj,field){
// utility function to get nested property
function dig(obj,selector){
var result=obj;
var splitter=selector.split('.');

for(var i=0;i<splitter.length;i++){
if(typeof result==='undefined'||result===null){
return undefined;
}

result=result[splitter[i]];
}

return result;
}

if(typeof field==='function')return field(obj);
if(typeof field==='string')return dig(obj,field);
return undefined;
},
collectFormatted:function collectFormatted(obj,column){
var headerRow=arguments.length>2&&arguments[2]!==undefined?arguments[2]:false;
var value;

if(headerRow&&column.headerField){
value=this.collect(obj,column.headerField);
}else {
value=this.collect(obj,column.field);
}

if(value===undefined)return '';// if user has supplied custom formatter,
// use that here

if(column.formatFn&&typeof column.formatFn==='function'){
return column.formatFn(value,obj);
}// lets format the resultant data


var type=column.typeDef;// this will only happen if we try to collect formatted
// before types have been initialized. for example: on
// load when external query is specified.

if(!type){
type=this.dataTypes[column.type]||defaultType;
}

var result=type.format(value,column);// we must have some values in compact mode

if(this.compactMode&&(result==''||result==null))return '-';
return result;
},
formattedRow:function formattedRow(row){
var isHeaderRow=arguments.length>1&&arguments[1]!==undefined?arguments[1]:false;
var formattedRow={};

for(var i=0;i<this.typedColumns.length;i++){
var col=this.typedColumns[i];// what happens if field is

if(col.field){
formattedRow[col.field]=this.collectFormatted(row,col,isHeaderRow);
}
}

return formattedRow;
},
// Get classes for the given column index & element.
getClasses:function getClasses(index,element,row){
var _this$typedColumns$in=this.typedColumns[index],
typeDef=_this$typedColumns$in.typeDef,
custom=_this$typedColumns$in["".concat(element,"Class")];

var isRight=typeDef.isRight;
if(this.rtl)isRight=true;
var classes={
'vgt-right-align':isRight,
'vgt-left-align':!isRight};
// for td we need to check if value is
// a function.

if(typeof custom==='function'){
classes[custom(row)]=true;
}else if(typeof custom==='string'){
classes[custom]=true;
}

return classes;
},
// method to filter rows
filterRows:function filterRows(columnFilters){
var _this9=this;

var fromFilter=arguments.length>1&&arguments[1]!==undefined?arguments[1]:true;
// if (!this.rows.length) return;
// this is invoked either as a result of changing filters
// or as a result of modifying rows.
this.columnFilters=columnFilters;
var computedRows=JSON.parse(JSON.stringify(this.originalRows));
var instancesOfFiltering=false;// do we have a filter to care about?
// if not we don't need to do anything

if(this.columnFilters&&Object.keys(this.columnFilters).length){
var _ret=function(){
// every time we filter rows, we need to set current page
// to 1
// if the mode is remote, we only need to reset, if this is
// being called from filter, not when rows are changing
if(_this9.mode!=='remote'||fromFilter){
_this9.changePage(1);
}// we need to emit an event and that's that.
// but this only needs to be invoked if filter is changing
// not when row object is modified.


if(fromFilter){
_this9.$emit('on-column-filter',{
columnFilters:_this9.columnFilters});

}// if mode is remote, we don't do any filtering here.


if(_this9.mode==='remote'){
if(fromFilter){
_this9.$emit('update:isLoading',true);
}else {
// if remote filtering has already been taken care of.
_this9.filteredRows=computedRows;
}

return {
v:void 0};

}

var fieldKey=function fieldKey(field){
if(typeof field==='function'&&field.name){
return field.name;
}

return field;
};

var _loop=function _loop(i){
var col=_this9.typedColumns[i];

if(_this9.columnFilters[fieldKey(col.field)]){
instancesOfFiltering=true;
computedRows.forEach(function(headerRow){
var newChildren=headerRow.children.filter(function(row){
// If column has a custom filter, use that.
if(col.filterOptions&&typeof col.filterOptions.filterFn==='function'){
return col.filterOptions.filterFn(_this9.collect(row,col.field),_this9.columnFilters[fieldKey(col.field)]);
}// Otherwise Use default filters


var typeDef=col.typeDef;
return typeDef.filterPredicate(_this9.collect(row,col.field),_this9.columnFilters[fieldKey(col.field)],false,col.filterOptions&&_typeof(col.filterOptions.filterDropdownItems)==='object');
});// should we remove the header?

headerRow.children=newChildren;
});
}
};

for(var i=0;i<_this9.typedColumns.length;i++){
_loop(i);
}
}();

if(_typeof(_ret)==="object")return _ret.v;
}

if(instancesOfFiltering){
this.filteredRows=computedRows.filter(function(h){
return h.children&&h.children.length;
});
}else {
this.filteredRows=computedRows;
}
},
getCurrentIndex:function getCurrentIndex(rowId){
var index=0;
var found=false;

for(var i=0;i<this.paginated.length;i+=1){
var headerRow=this.paginated[i];
var children=headerRow.children;

if(children&&children.length){
for(var j=0;j<children.length;j+=1){
var c=children[j];

if(c.originalIndex===rowId){
found=true;
break;
}

index+=1;
}
}

if(found)break;
}

return (this.currentPage-1)*this.currentPerPage+index+1;
},
getRowStyleClass:function getRowStyleClass(row){
var classes='';
if(this.hasRowClickListener)classes+='clickable';
var rowStyleClasses;

if(typeof this.rowStyleClass==='function'){
rowStyleClasses=this.rowStyleClass(row);
}else {
rowStyleClasses=this.rowStyleClass;
}

if(rowStyleClasses){
classes+=" ".concat(rowStyleClasses);
}

return classes;
},
handleGrouped:function handleGrouped(originalRows){
var _this10=this;

originalRows.forEach(function(headerRow,i){
headerRow.vgt_header_id=i;

if(_this10.groupOptions.maintainExpanded&&_this10.expandedRowKeys.has(headerRow[_this10.groupOptions.rowKey])){
_this10.$set(headerRow,'vgtIsExpanded',true);
}

headerRow.children.forEach(function(childRow){
childRow.vgt_id=i;
});
});
return originalRows;
},
initializePagination:function initializePagination(){
var _this11=this;

var _this$paginationOptio=this.paginationOptions,
enabled=_this$paginationOptio.enabled,
perPage=_this$paginationOptio.perPage,
position=_this$paginationOptio.position,
perPageDropdown=_this$paginationOptio.perPageDropdown,
perPageDropdownEnabled=_this$paginationOptio.perPageDropdownEnabled,
dropdownAllowAll=_this$paginationOptio.dropdownAllowAll,
nextLabel=_this$paginationOptio.nextLabel,
prevLabel=_this$paginationOptio.prevLabel,
rowsPerPageLabel=_this$paginationOptio.rowsPerPageLabel,
ofLabel=_this$paginationOptio.ofLabel,
pageLabel=_this$paginationOptio.pageLabel,
allLabel=_this$paginationOptio.allLabel,
setCurrentPage=_this$paginationOptio.setCurrentPage,
mode=_this$paginationOptio.mode,
infoFn=_this$paginationOptio.infoFn;

if(typeof enabled==='boolean'){
this.paginate=enabled;
}

if(typeof perPage==='number'){
this.perPage=perPage;
}

if(position==='top'){
this.paginateOnTop=true;// default is false

this.paginateOnBottom=false;// default is true
}else if(position==='both'){
this.paginateOnTop=true;
this.paginateOnBottom=true;
}

if(Array.isArray(perPageDropdown)&&perPageDropdown.length){
this.customRowsPerPageDropdown=perPageDropdown;

if(!this.perPage){
var _perPageDropdown=_slicedToArray(perPageDropdown,1);

this.perPage=_perPageDropdown[0];
}
}

if(typeof perPageDropdownEnabled==='boolean'){
this.perPageDropdownEnabled=perPageDropdownEnabled;
}

if(typeof dropdownAllowAll==='boolean'){
this.paginateDropdownAllowAll=dropdownAllowAll;
}

if(typeof mode==='string'){
this.paginationMode=mode;
}

if(typeof nextLabel==='string'){
this.nextText=nextLabel;
}

if(typeof prevLabel==='string'){
this.prevText=prevLabel;
}

if(typeof rowsPerPageLabel==='string'){
this.rowsPerPageText=rowsPerPageLabel;
}

if(typeof ofLabel==='string'){
this.ofText=ofLabel;
}

if(typeof pageLabel==='string'){
this.pageText=pageLabel;
}

if(typeof allLabel==='string'){
this.allText=allLabel;
}

if(typeof setCurrentPage==='number'){
setTimeout(function(){
_this11.changePage(setCurrentPage);
},500);
}

if(typeof infoFn==='function'){
this.paginationInfoFn=infoFn;
}
},
initializeSearch:function initializeSearch(){
var _this$searchOptions=this.searchOptions,
enabled=_this$searchOptions.enabled,
trigger=_this$searchOptions.trigger,
externalQuery=_this$searchOptions.externalQuery,
searchFn=_this$searchOptions.searchFn,
placeholder=_this$searchOptions.placeholder,
skipDiacritics=_this$searchOptions.skipDiacritics;

if(typeof enabled==='boolean'){
this.searchEnabled=enabled;
}

if(trigger==='enter'){
this.searchTrigger=trigger;
}

if(typeof externalQuery==='string'){
this.externalSearchQuery=externalQuery;
}

if(typeof searchFn==='function'){
this.searchFn=searchFn;
}

if(typeof placeholder==='string'){
this.searchPlaceholder=placeholder;
}

if(typeof skipDiacritics==='boolean'){
this.searchSkipDiacritics=skipDiacritics;
}
},
initializeSort:function initializeSort(){
var _this$sortOptions=this.sortOptions,
enabled=_this$sortOptions.enabled,
initialSortBy=_this$sortOptions.initialSortBy,
multipleColumns=_this$sortOptions.multipleColumns;
var initSortBy=JSON.parse(JSON.stringify(initialSortBy||{}));

if(typeof enabled==='boolean'){
this.sortable=enabled;
}

if(typeof multipleColumns==='boolean'){
this.multipleColumnSort=multipleColumns;
}//* initialSortBy can be an array or an object


if(_typeof(initSortBy)==='object'){
var ref=this.fixedHeader?this.$refs['table-header-secondary']:this.$refs['table-header-primary'];

if(Array.isArray(initSortBy)){
ref.setInitialSort(initSortBy);
}else {
var hasField=Object.prototype.hasOwnProperty.call(initSortBy,'field');
if(hasField)ref.setInitialSort([initSortBy]);
}
}
},
initializeSelect:function initializeSelect(){
var _this$selectOptions=this.selectOptions,
enabled=_this$selectOptions.enabled,
selectionInfoClass=_this$selectOptions.selectionInfoClass,
selectionText=_this$selectOptions.selectionText,
clearSelectionText=_this$selectOptions.clearSelectionText,
selectOnCheckboxOnly=_this$selectOptions.selectOnCheckboxOnly,
selectAllByPage=_this$selectOptions.selectAllByPage,
disableSelectInfo=_this$selectOptions.disableSelectInfo,
selectAllByGroup=_this$selectOptions.selectAllByGroup;

if(typeof enabled==='boolean'){
this.selectable=enabled;
}

if(typeof selectOnCheckboxOnly==='boolean'){
this.selectOnCheckboxOnly=selectOnCheckboxOnly;
}

if(typeof selectAllByPage==='boolean'){
this.selectAllByPage=selectAllByPage;
}

if(typeof selectAllByGroup==='boolean'){
this.selectAllByGroup=selectAllByGroup;
}

if(typeof disableSelectInfo==='boolean'){
this.disableSelectInfo=disableSelectInfo;
}

if(typeof selectionInfoClass==='string'){
this.selectionInfoClass=selectionInfoClass;
}

if(typeof selectionText==='string'){
this.selectionText=selectionText;
}

if(typeof clearSelectionText==='string'){
this.clearSelectionText=clearSelectionText;
}
}},

mounted:function mounted(){
if(this.perPage){
this.currentPerPage=this.perPage;
}

this.initializeSort();
},
components:{
'vgt-pagination':__vue_component__$1,
'vgt-global-search':__vue_component__$2,
'vgt-header-row':__vue_component__$5,
'vgt-table-header':__vue_component__$4}};



/* script */
var __vue_script__$6=script$6;
/* template */

var __vue_render__$6=function __vue_render__(){
var _vm=this;

var _h=_vm.$createElement;

var _c=_vm._self._c||_h;

return _c('div',{
"class":_vm.wrapStyleClasses},
[_vm.isLoading?_c('div',{
staticClass:"vgt-loading vgt-center-align"},
[_vm._t("loadingContent",[_c('span',{
staticClass:"vgt-loading__content"},
[_vm._v("\n        Loading...\n      ")])])],2):_vm._e(),_vm._v(" "),_c('div',{
staticClass:"vgt-inner-wrap",
"class":{
'is-loading':_vm.isLoading}},

[_vm.paginate&&_vm.paginateOnTop?_vm._t("pagination-top",[_c('vgt-pagination',{
ref:"paginationTop",
attrs:{
"perPage":_vm.perPage,
"rtl":_vm.rtl,
"total":_vm.totalRows||_vm.totalRowCount,
"mode":_vm.paginationMode,
"nextText":_vm.nextText,
"prevText":_vm.prevText,
"rowsPerPageText":_vm.rowsPerPageText,
"perPageDropdownEnabled":_vm.paginationOptions.perPageDropdownEnabled,
"customRowsPerPageDropdown":_vm.customRowsPerPageDropdown,
"paginateDropdownAllowAll":_vm.paginateDropdownAllowAll,
"ofText":_vm.ofText,
"pageText":_vm.pageText,
"allText":_vm.allText,
"info-fn":_vm.paginationInfoFn},

on:{
"page-changed":_vm.pageChanged,
"per-page-changed":_vm.perPageChanged}})],

{
"pageChanged":_vm.pageChanged,
"perPageChanged":_vm.perPageChanged,
"total":_vm.totalRows||_vm.totalRowCount}):
_vm._e(),_vm._v(" "),_c('vgt-global-search',{
attrs:{
"search-enabled":_vm.searchEnabled&&_vm.externalSearchQuery==null,
"global-search-placeholder":_vm.searchPlaceholder},

on:{
"on-keyup":_vm.searchTableOnKeyUp,
"on-enter":_vm.searchTableOnEnter},

model:{
value:_vm.globalSearchTerm,
callback:function callback($$v){
_vm.globalSearchTerm=$$v;
},
expression:"globalSearchTerm"}},

[_c('template',{
slot:"internal-table-actions"},
[_vm._t("table-actions")],2)],2),_vm._v(" "),_vm.selectedRowCount&&!_vm.disableSelectInfo?_c('div',{
staticClass:"vgt-selection-info-row clearfix",
"class":_vm.selectionInfoClass},
[_vm._v("\n      "+_vm._s(_vm.selectionInfo)+"\n      "),_c('a',{
attrs:{
"href":""},

on:{
"click":function click($event){
$event.preventDefault();
return _vm.unselectAllInternal(true);
}}},

[_vm._v("\n        "+_vm._s(_vm.clearSelectionText)+"\n      ")]),_vm._v(" "),_c('div',{
staticClass:"vgt-selection-info-row__actions vgt-pull-right"},
[_vm._t("selected-row-actions")],2)]):_vm._e(),_vm._v(" "),_c('div',{
staticClass:"vgt-fixed-header"},
[_vm.fixedHeader?_c('table',{
"class":_vm.tableStyleClasses,
attrs:{
"id":"vgt-table"}},

[_c('colgroup',_vm._l(_vm.columns,function(column,index){
return _c('col',{
key:index,
attrs:{
"id":"col-"+index}});


}),0),_vm._v(" "),_c("vgt-table-header",{
ref:"table-header-secondary",
tag:"thead",
attrs:{
"columns":_vm.columns,
"line-numbers":_vm.lineNumbers,
"selectable":_vm.selectable,
"all-selected":_vm.allSelected,
"all-selected-indeterminate":_vm.allSelectedIndeterminate,
"mode":_vm.mode,
"sortable":_vm.sortable,
"multiple-column-sort":_vm.multipleColumnSort,
"typed-columns":_vm.typedColumns,
"getClasses":_vm.getClasses,
"searchEnabled":_vm.searchEnabled,
"paginated":_vm.paginated,
"table-ref":_vm.$refs.table},

on:{
"on-toggle-select-all":_vm.toggleSelectAll,
"on-sort-change":_vm.changeSort,
"filter-changed":_vm.filterRows},

scopedSlots:_vm._u([{
key:"table-column",
fn:function fn(props){
return [_vm._t("table-column",[_c('span',[_vm._v(_vm._s(props.column.label))])],{
"column":props.column})];

}},
{
key:"column-filter",
fn:function fn(props){
return [_vm._t("column-filter",null,{
"column":props.column,
"updateFilters":props.updateFilters})];

}}],
null,true)})],
1):_vm._e()]),_vm._v(" "),_c('div',{
"class":{
'vgt-responsive':_vm.responsive},

style:_vm.wrapperStyles},
[_c('table',{
ref:"table",
"class":_vm.tableStyles,
attrs:{
"id":"vgt-table"}},

[_c('colgroup',_vm._l(_vm.columns,function(column,index){
return _c('col',{
key:index,
attrs:{
"id":"col-"+index}});


}),0),_vm._v(" "),_c("vgt-table-header",{
ref:"table-header-primary",
tag:"thead",
attrs:{
"columns":_vm.columns,
"line-numbers":_vm.lineNumbers,
"selectable":_vm.selectable,
"all-selected":_vm.allSelected,
"all-selected-indeterminate":_vm.allSelectedIndeterminate,
"mode":_vm.mode,
"sortable":_vm.sortable,
"multiple-column-sort":_vm.multipleColumnSort,
"typed-columns":_vm.typedColumns,
"getClasses":_vm.getClasses,
"searchEnabled":_vm.searchEnabled},

on:{
"on-toggle-select-all":_vm.toggleSelectAll,
"on-sort-change":_vm.changeSort,
"filter-changed":_vm.filterRows},

scopedSlots:_vm._u([{
key:"table-column",
fn:function fn(props){
return [_vm._t("table-column",[_c('span',[_vm._v(_vm._s(props.column.label))])],{
"column":props.column})];

}},
{
key:"column-filter",
fn:function fn(props){
return [_vm._t("column-filter",null,{
"column":props.column,
"updateFilters":props.updateFilters})];

}}],
null,true)}),
_vm._v(" "),_vm._l(_vm.paginated,function(headerRow,hIndex){
return _c('tbody',{
key:hIndex},
[_vm.groupHeaderOnTop?_c('vgt-header-row',{
"class":_vm.getRowStyleClass(headerRow),
attrs:{
"header-row":headerRow,
"columns":_vm.columns,
"line-numbers":_vm.lineNumbers,
"selectable":_vm.selectable,
"select-all-by-group":_vm.selectAllByGroup,
"collapsable":_vm.groupOptions.collapsable,
"collect-formatted":_vm.collectFormatted,
"formatted-row":_vm.formattedRow,
"get-classes":_vm.getClasses,
"full-colspan":_vm.fullColspan,
"groupIndex":hIndex},

on:{
"vgtExpand":function vgtExpand($event){
return _vm.toggleExpand(headerRow[_vm.rowKeyField]);
},
"on-select-group-change":function onSelectGroupChange($event){
return _vm.toggleSelectGroup($event,headerRow);
}},

scopedSlots:_vm._u([{
key:"table-header-row",
fn:function fn(props){
return _vm.hasHeaderRowTemplate?[_vm._t("table-header-row",null,{
"column":props.column,
"formattedRow":props.formattedRow,
"row":props.row})]:
undefined;
}}],
null,true)}):
_vm._e(),_vm._v(" "),_vm._l(headerRow.children,function(row,index){
return (_vm.groupOptions.collapsable?headerRow.vgtIsExpanded:true)?_c('tr',{
key:row.originalIndex,
"class":_vm.getRowStyleClass(row),
on:{
"mouseenter":function mouseenter($event){
return _vm.onMouseenter(row,index);
},
"mouseleave":function mouseleave($event){
return _vm.onMouseleave(row,index);
},
"dblclick":function dblclick($event){
return _vm.onRowDoubleClicked(row,index,$event);
},
"click":function click($event){
return _vm.onRowClicked(row,index,$event);
},
"auxclick":function auxclick($event){
return _vm.onRowAuxClicked(row,index,$event);
}}},

[_vm.lineNumbers?_c('th',{
staticClass:"line-numbers"},
[_vm._v("\n              "+_vm._s(_vm.getCurrentIndex(row.originalIndex))+"\n            ")]):_vm._e(),_vm._v(" "),_vm.selectable?_c('th',{
staticClass:"vgt-checkbox-col",
on:{
"click":function click($event){
$event.stopPropagation();
return _vm.onCheckboxClicked(row,index,$event);
}}},

[_c('input',{
attrs:{
"type":"checkbox",
"disabled":row.vgtDisabled},

domProps:{
"checked":row.vgtSelected}})]):

_vm._e(),_vm._v(" "),_vm._l(_vm.columns,function(column,i){
return !column.hidden&&column.field?_c('td',{
key:i,
"class":_vm.getClasses(i,'td',row),
attrs:{
"data-label":_vm.compactMode?column.label:undefined},

on:{
"click":function click($event){
return _vm.onCellClicked(row,column,index,$event);
}}},

[_vm._t("table-row",[!column.html?_c('span',[_vm._v("\n                  "+_vm._s(_vm.collectFormatted(row,column))+"\n                ")]):_c('span',{
domProps:{
"innerHTML":_vm._s(_vm.collect(row,column.field))}})],

{
"row":row,
"column":column,
"formattedRow":_vm.formattedRow(row),
"index":index})],
2):_vm._e();
})],2):_vm._e();
}),_vm._v(" "),_vm.groupHeaderOnBottom?_c('vgt-header-row',{
attrs:{
"header-row":headerRow,
"columns":_vm.columns,
"line-numbers":_vm.lineNumbers,
"selectable":_vm.selectable,
"select-all-by-group":_vm.selectAllByGroup,
"collect-formatted":_vm.collectFormatted,
"formatted-row":_vm.formattedRow,
"get-classes":_vm.getClasses,
"full-colspan":_vm.fullColspan,
"groupIndex":_vm.index},

on:{
"on-select-group-change":function onSelectGroupChange($event){
return _vm.toggleSelectGroup($event,headerRow);
}},

scopedSlots:_vm._u([{
key:"table-header-row",
fn:function fn(props){
return _vm.hasHeaderRowTemplate?[_vm._t("table-header-row",null,{
"column":props.column,
"formattedRow":props.formattedRow,
"row":props.row})]:
undefined;
}}],
null,true)}):
_vm._e()],2);
}),_vm._v(" "),_vm.showEmptySlot?_c('tbody',[_c('tr',[_c('td',{
attrs:{
"colspan":_vm.fullColspan}},

[_vm._t("emptystate",[_c('div',{
staticClass:"vgt-center-align vgt-text-disabled"},
[_vm._v("\n                  No data for table\n                ")])])],2)])]):_vm._e()],2)]),_vm._v(" "),_vm.hasFooterSlot?_c('div',{
staticClass:"vgt-wrap__actions-footer"},
[_vm._t("table-actions-bottom")],2):_vm._e(),_vm._v(" "),_vm.paginate&&_vm.paginateOnBottom?_vm._t("pagination-bottom",[_c('vgt-pagination',{
ref:"paginationBottom",
attrs:{
"perPage":_vm.perPage,
"rtl":_vm.rtl,
"total":_vm.totalRows||_vm.totalRowCount,
"mode":_vm.paginationMode,
"nextText":_vm.nextText,
"prevText":_vm.prevText,
"rowsPerPageText":_vm.rowsPerPageText,
"perPageDropdownEnabled":_vm.paginationOptions.perPageDropdownEnabled,
"customRowsPerPageDropdown":_vm.customRowsPerPageDropdown,
"paginateDropdownAllowAll":_vm.paginateDropdownAllowAll,
"ofText":_vm.ofText,
"pageText":_vm.pageText,
"allText":_vm.allText,
"info-fn":_vm.paginationInfoFn},

on:{
"page-changed":_vm.pageChanged,
"per-page-changed":_vm.perPageChanged}})],

{
"pageChanged":_vm.pageChanged,
"perPageChanged":_vm.perPageChanged,
"total":_vm.totalRows||_vm.totalRowCount}):
_vm._e()],2)]);
};

var __vue_staticRenderFns__$6=[];
/* style */

var __vue_inject_styles__$6=undefined;
/* scoped */

var __vue_scope_id__$6=undefined;
/* module identifier */

var __vue_module_identifier__$6=undefined;
/* functional template */

var __vue_is_functional_template__$6=false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__$6=/*#__PURE__*/normalizeComponent({
render:__vue_render__$6,
staticRenderFns:__vue_staticRenderFns__$6},
__vue_inject_styles__$6,__vue_script__$6,__vue_scope_id__$6,__vue_is_functional_template__$6,__vue_module_identifier__$6,false,undefined,undefined,undefined);

var VueGoodTablePlugin={
install:function install(Vue,options){
Vue.component(__vue_component__$6.name,__vue_component__$6);
}};
// Automatic installation if Vue has been added to the global scope.

if(typeof window!=='undefined'&&window.Vue){
window.Vue.use(VueGoodTablePlugin);
}

/* harmony default export */__webpack_exports__["default"]=VueGoodTablePlugin;


/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"));

/***/},

/***/"./node_modules/vue-i18n/dist/vue-i18n.esm.js":
/*!****************************************************!*\
  !*** ./node_modules/vue-i18n/dist/vue-i18n.esm.js ***!
  \****************************************************/
/*! exports provided: default */
/***/function node_modulesVueI18nDistVueI18nEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/*!
 * vue-i18n v8.24.3 
 * (c) 2021 kazuya kawaguchi
 * Released under the MIT License.
 */
/*  */

/**
 * constants
 */

var numberFormatKeys=[
'compactDisplay',
'currency',
'currencyDisplay',
'currencySign',
'localeMatcher',
'notation',
'numberingSystem',
'signDisplay',
'style',
'unit',
'unitDisplay',
'useGrouping',
'minimumIntegerDigits',
'minimumFractionDigits',
'maximumFractionDigits',
'minimumSignificantDigits',
'maximumSignificantDigits'];


/**
 * utilities
 */

function warn(msg,err){
if(typeof console!=='undefined'){
console.warn('[vue-i18n] '+msg);
/* istanbul ignore if */
if(err){
console.warn(err.stack);
}
}
}

function error(msg,err){
if(typeof console!=='undefined'){
console.error('[vue-i18n] '+msg);
/* istanbul ignore if */
if(err){
console.error(err.stack);
}
}
}

var isArray=Array.isArray;

function isObject(obj){
return obj!==null&&typeof obj==='object';
}

function isBoolean(val){
return typeof val==='boolean';
}

function isString(val){
return typeof val==='string';
}

var toString=Object.prototype.toString;
var OBJECT_STRING='[object Object]';
function isPlainObject(obj){
return toString.call(obj)===OBJECT_STRING;
}

function isNull(val){
return val===null||val===undefined;
}

function isFunction(val){
return typeof val==='function';
}

function parseArgs(){
var args=[],len=arguments.length;
while(len--){args[len]=arguments[len];}

var locale=null;
var params=null;
if(args.length===1){
if(isObject(args[0])||isArray(args[0])){
params=args[0];
}else if(typeof args[0]==='string'){
locale=args[0];
}
}else if(args.length===2){
if(typeof args[0]==='string'){
locale=args[0];
}
/* istanbul ignore if */
if(isObject(args[1])||isArray(args[1])){
params=args[1];
}
}

return {locale:locale,params:params};
}

function looseClone(obj){
return JSON.parse(JSON.stringify(obj));
}

function remove(arr,item){
if(arr.delete(item)){
return arr;
}
}

function includes(arr,item){
return !!~arr.indexOf(item);
}

var hasOwnProperty=Object.prototype.hasOwnProperty;
function hasOwn(obj,key){
return hasOwnProperty.call(obj,key);
}

function merge(target){
var arguments$1=arguments;

var output=Object(target);
for(var i=1;i<arguments.length;i++){
var source=arguments$1[i];
if(source!==undefined&&source!==null){
var key=void 0;
for(key in source){
if(hasOwn(source,key)){
if(isObject(source[key])){
output[key]=merge(output[key],source[key]);
}else {
output[key]=source[key];
}
}
}
}
}
return output;
}

function looseEqual(a,b){
if(a===b){return true;}
var isObjectA=isObject(a);
var isObjectB=isObject(b);
if(isObjectA&&isObjectB){
try{
var isArrayA=isArray(a);
var isArrayB=isArray(b);
if(isArrayA&&isArrayB){
return a.length===b.length&&a.every(function(e,i){
return looseEqual(e,b[i]);
});
}else if(!isArrayA&&!isArrayB){
var keysA=Object.keys(a);
var keysB=Object.keys(b);
return keysA.length===keysB.length&&keysA.every(function(key){
return looseEqual(a[key],b[key]);
});
}else {
/* istanbul ignore next */
return false;
}
}catch(e){
/* istanbul ignore next */
return false;
}
}else if(!isObjectA&&!isObjectB){
return String(a)===String(b);
}else {
return false;
}
}

/**
 * Sanitizes html special characters from input strings. For mitigating risk of XSS attacks.
 * @param rawText The raw input from the user that should be escaped.
 */
function escapeHtml(rawText){
return rawText.
replace(/</g,'&lt;').
replace(/>/g,'&gt;').
replace(/"/g,'&quot;').
replace(/'/g,'&apos;');
}

/**
 * Escapes html tags and special symbols from all provided params which were returned from parseArgs().params.
 * This method performs an in-place operation on the params object.
 *
 * @param {any} params Parameters as provided from `parseArgs().params`.
 *                     May be either an array of strings or a string->any map.
 *
 * @returns The manipulated `params` object.
 */
function escapeParams(params){
if(params!=null){
Object.keys(params).forEach(function(key){
if(typeof params[key]=='string'){
params[key]=escapeHtml(params[key]);
}
});
}
return params;
}

/*  */

function extend(Vue){
if(!Vue.prototype.hasOwnProperty('$i18n')){
// $FlowFixMe
Object.defineProperty(Vue.prototype,'$i18n',{
get:function get(){return this._i18n;}});

}

Vue.prototype.$t=function(key){
var values=[],len=arguments.length-1;
while(len-->0){values[len]=arguments[len+1];}

var i18n=this.$i18n;
return i18n._t.apply(i18n,[key,i18n.locale,i18n._getMessages(),this].concat(values));
};

Vue.prototype.$tc=function(key,choice){
var values=[],len=arguments.length-2;
while(len-->0){values[len]=arguments[len+2];}

var i18n=this.$i18n;
return i18n._tc.apply(i18n,[key,i18n.locale,i18n._getMessages(),this,choice].concat(values));
};

Vue.prototype.$te=function(key,locale){
var i18n=this.$i18n;
return i18n._te(key,i18n.locale,i18n._getMessages(),locale);
};

Vue.prototype.$d=function(value){
var ref;

var args=[],len=arguments.length-1;
while(len-->0){args[len]=arguments[len+1];}
return (ref=this.$i18n).d.apply(ref,[value].concat(args));
};

Vue.prototype.$n=function(value){
var ref;

var args=[],len=arguments.length-1;
while(len-->0){args[len]=arguments[len+1];}
return (ref=this.$i18n).n.apply(ref,[value].concat(args));
};
}

/*  */

var mixin={
beforeCreate:function beforeCreate(){
var options=this.$options;
options.i18n=options.i18n||(options.__i18n?{}:null);

if(options.i18n){
if(options.i18n instanceof VueI18n){
// init locale messages via custom blocks
if(options.__i18n){
try{
var localeMessages=options.i18n&&options.i18n.messages?options.i18n.messages:{};
options.__i18n.forEach(function(resource){
localeMessages=merge(localeMessages,JSON.parse(resource));
});
Object.keys(localeMessages).forEach(function(locale){
options.i18n.mergeLocaleMessage(locale,localeMessages[locale]);
});
}catch(e){
{
error("Cannot parse locale messages via custom blocks.",e);
}
}
}
this._i18n=options.i18n;
this._i18nWatcher=this._i18n.watchI18nData();
}else if(isPlainObject(options.i18n)){
var rootI18n=this.$root&&this.$root.$i18n&&this.$root.$i18n instanceof VueI18n?
this.$root.$i18n:
null;
// component local i18n
if(rootI18n){
options.i18n.root=this.$root;
options.i18n.formatter=rootI18n.formatter;
options.i18n.fallbackLocale=rootI18n.fallbackLocale;
options.i18n.formatFallbackMessages=rootI18n.formatFallbackMessages;
options.i18n.silentTranslationWarn=rootI18n.silentTranslationWarn;
options.i18n.silentFallbackWarn=rootI18n.silentFallbackWarn;
options.i18n.pluralizationRules=rootI18n.pluralizationRules;
options.i18n.preserveDirectiveContent=rootI18n.preserveDirectiveContent;
this.$root.$once('hook:beforeDestroy',function(){
options.i18n.root=null;
options.i18n.formatter=null;
options.i18n.fallbackLocale=null;
options.i18n.formatFallbackMessages=null;
options.i18n.silentTranslationWarn=null;
options.i18n.silentFallbackWarn=null;
options.i18n.pluralizationRules=null;
options.i18n.preserveDirectiveContent=null;
});
}

// init locale messages via custom blocks
if(options.__i18n){
try{
var localeMessages$1=options.i18n&&options.i18n.messages?options.i18n.messages:{};
options.__i18n.forEach(function(resource){
localeMessages$1=merge(localeMessages$1,JSON.parse(resource));
});
options.i18n.messages=localeMessages$1;
}catch(e){
{
warn("Cannot parse locale messages via custom blocks.",e);
}
}
}

var ref=options.i18n;
var sharedMessages=ref.sharedMessages;
if(sharedMessages&&isPlainObject(sharedMessages)){
options.i18n.messages=merge(options.i18n.messages,sharedMessages);
}

this._i18n=new VueI18n(options.i18n);
this._i18nWatcher=this._i18n.watchI18nData();

if(options.i18n.sync===undefined||!!options.i18n.sync){
this._localeWatcher=this.$i18n.watchLocale();
}

if(rootI18n){
rootI18n.onComponentInstanceCreated(this._i18n);
}
}else {
{
warn("Cannot be interpreted 'i18n' option.");
}
}
}else if(this.$root&&this.$root.$i18n&&this.$root.$i18n instanceof VueI18n){
// root i18n
this._i18n=this.$root.$i18n;
}else if(options.parent&&options.parent.$i18n&&options.parent.$i18n instanceof VueI18n){
// parent i18n
this._i18n=options.parent.$i18n;
}
},

beforeMount:function beforeMount(){
var options=this.$options;
options.i18n=options.i18n||(options.__i18n?{}:null);

if(options.i18n){
if(options.i18n instanceof VueI18n){
// init locale messages via custom blocks
this._i18n.subscribeDataChanging(this);
this._subscribing=true;
}else if(isPlainObject(options.i18n)){
this._i18n.subscribeDataChanging(this);
this._subscribing=true;
}else {
{
warn("Cannot be interpreted 'i18n' option.");
}
}
}else if(this.$root&&this.$root.$i18n&&this.$root.$i18n instanceof VueI18n){
this._i18n.subscribeDataChanging(this);
this._subscribing=true;
}else if(options.parent&&options.parent.$i18n&&options.parent.$i18n instanceof VueI18n){
this._i18n.subscribeDataChanging(this);
this._subscribing=true;
}
},

mounted:function mounted(){
if(this!==this.$root&&this.$options.__INTLIFY_META__&&this.$el){
this.$el.setAttribute('data-intlify',this.$options.__INTLIFY_META__);
}
},

beforeDestroy:function beforeDestroy(){
if(!this._i18n){return;}

var self=this;
this.$nextTick(function(){
if(self._subscribing){
self._i18n.unsubscribeDataChanging(self);
delete self._subscribing;
}

if(self._i18nWatcher){
self._i18nWatcher();
self._i18n.destroyVM();
delete self._i18nWatcher;
}

if(self._localeWatcher){
self._localeWatcher();
delete self._localeWatcher;
}
});
}};


/*  */

var interpolationComponent={
name:'i18n',
functional:true,
props:{
tag:{
type:[String,Boolean,Object],
default:'span'},

path:{
type:String,
required:true},

locale:{
type:String},

places:{
type:[Array,Object]}},


render:function render(h,ref){
var data=ref.data;
var parent=ref.parent;
var props=ref.props;
var slots=ref.slots;

var $i18n=parent.$i18n;
if(!$i18n){
{
warn('Cannot find VueI18n instance!');
}
return;
}

var path=props.path;
var locale=props.locale;
var places=props.places;
var params=slots();
var children=$i18n.i(
path,
locale,
onlyHasDefaultPlace(params)||places?
useLegacyPlaces(params.default,places):
params);


var tag=!!props.tag&&props.tag!==true||props.tag===false?props.tag:'span';
return tag?h(tag,data,children):children;
}};


function onlyHasDefaultPlace(params){
var prop;
for(prop in params){
if(prop!=='default'){return false;}
}
return Boolean(prop);
}

function useLegacyPlaces(children,places){
var params=places?createParamsFromPlaces(places):{};

if(!children){return params;}

// Filter empty text nodes
children=children.filter(function(child){
return child.tag||child.text.trim()!=='';
});

var everyPlace=children.every(vnodeHasPlaceAttribute);
if(everyPlace){
warn('`place` attribute is deprecated in next major version. Please switch to Vue slots.');
}

return children.reduce(
everyPlace?assignChildPlace:assignChildIndex,
params);

}

function createParamsFromPlaces(places){
{
warn('`places` prop is deprecated in next major version. Please switch to Vue slots.');
}

return Array.isArray(places)?
places.reduce(assignChildIndex,{}):
Object.assign({},places);
}

function assignChildPlace(params,child){
if(child.data&&child.data.attrs&&child.data.attrs.place){
params[child.data.attrs.place]=child;
}
return params;
}

function assignChildIndex(params,child,index){
params[index]=child;
return params;
}

function vnodeHasPlaceAttribute(vnode){
return Boolean(vnode.data&&vnode.data.attrs&&vnode.data.attrs.place);
}

/*  */

var numberComponent={
name:'i18n-n',
functional:true,
props:{
tag:{
type:[String,Boolean,Object],
default:'span'},

value:{
type:Number,
required:true},

format:{
type:[String,Object]},

locale:{
type:String}},


render:function render(h,ref){
var props=ref.props;
var parent=ref.parent;
var data=ref.data;

var i18n=parent.$i18n;

if(!i18n){
{
warn('Cannot find VueI18n instance!');
}
return null;
}

var key=null;
var options=null;

if(isString(props.format)){
key=props.format;
}else if(isObject(props.format)){
if(props.format.key){
key=props.format.key;
}

// Filter out number format options only
options=Object.keys(props.format).reduce(function(acc,prop){
var obj;

if(includes(numberFormatKeys,prop)){
return Object.assign({},acc,(obj={},obj[prop]=props.format[prop],obj));
}
return acc;
},null);
}

var locale=props.locale||i18n.locale;
var parts=i18n._ntp(props.value,locale,key,options);

var values=parts.map(function(part,index){
var obj;

var slot=data.scopedSlots&&data.scopedSlots[part.type];
return slot?slot((obj={},obj[part.type]=part.value,obj.index=index,obj.parts=parts,obj)):part.value;
});

var tag=!!props.tag&&props.tag!==true||props.tag===false?props.tag:'span';
return tag?
h(tag,{
attrs:data.attrs,
'class':data['class'],
staticClass:data.staticClass},
values):
values;
}};


/*  */

function bind(el,binding,vnode){
if(!assert(el,vnode)){return;}

t(el,binding,vnode);
}

function update(el,binding,vnode,oldVNode){
if(!assert(el,vnode)){return;}

var i18n=vnode.context.$i18n;
if(localeEqual(el,vnode)&&
looseEqual(binding.value,binding.oldValue)&&
looseEqual(el._localeMessage,i18n.getLocaleMessage(i18n.locale))){return;}

t(el,binding,vnode);
}

function unbind(el,binding,vnode,oldVNode){
var vm=vnode.context;
if(!vm){
warn('Vue instance does not exists in VNode context');
return;
}

var i18n=vnode.context.$i18n||{};
if(!binding.modifiers.preserve&&!i18n.preserveDirectiveContent){
el.textContent='';
}
el._vt=undefined;
delete el['_vt'];
el._locale=undefined;
delete el['_locale'];
el._localeMessage=undefined;
delete el['_localeMessage'];
}

function assert(el,vnode){
var vm=vnode.context;
if(!vm){
warn('Vue instance does not exists in VNode context');
return false;
}

if(!vm.$i18n){
warn('VueI18n instance does not exists in Vue instance');
return false;
}

return true;
}

function localeEqual(el,vnode){
var vm=vnode.context;
return el._locale===vm.$i18n.locale;
}

function t(el,binding,vnode){
var ref$1,ref$2;

var value=binding.value;

var ref=parseValue(value);
var path=ref.path;
var locale=ref.locale;
var args=ref.args;
var choice=ref.choice;
if(!path&&!locale&&!args){
warn('value type not supported');
return;
}

if(!path){
warn('`path` is required in v-t directive');
return;
}

var vm=vnode.context;
if(choice!=null){
el._vt=el.textContent=(ref$1=vm.$i18n).tc.apply(ref$1,[path,choice].concat(makeParams(locale,args)));
}else {
el._vt=el.textContent=(ref$2=vm.$i18n).t.apply(ref$2,[path].concat(makeParams(locale,args)));
}
el._locale=vm.$i18n.locale;
el._localeMessage=vm.$i18n.getLocaleMessage(vm.$i18n.locale);
}

function parseValue(value){
var path;
var locale;
var args;
var choice;

if(isString(value)){
path=value;
}else if(isPlainObject(value)){
path=value.path;
locale=value.locale;
args=value.args;
choice=value.choice;
}

return {path:path,locale:locale,args:args,choice:choice};
}

function makeParams(locale,args){
var params=[];

locale&&params.push(locale);
if(args&&(Array.isArray(args)||isPlainObject(args))){
params.push(args);
}

return params;
}

var Vue;

function install(_Vue){
/* istanbul ignore if */
if(install.installed&&_Vue===Vue){
warn('already installed.');
return;
}
install.installed=true;

Vue=_Vue;

var version=Vue.version&&Number(Vue.version.split('.')[0])||-1;
/* istanbul ignore if */
if(version<2){
warn("vue-i18n ("+install.version+") need to use Vue 2.0 or later (Vue: "+Vue.version+").");
return;
}

extend(Vue);
Vue.mixin(mixin);
Vue.directive('t',{bind:bind,update:update,unbind:unbind});
Vue.component(interpolationComponent.name,interpolationComponent);
Vue.component(numberComponent.name,numberComponent);

// use simple mergeStrategies to prevent i18n instance lose '__proto__'
var strats=Vue.config.optionMergeStrategies;
strats.i18n=function(parentVal,childVal){
return childVal===undefined?
parentVal:
childVal;
};
}

/*  */

var BaseFormatter=function BaseFormatter(){
this._caches=Object.create(null);
};

BaseFormatter.prototype.interpolate=function interpolate(message,values){
if(!values){
return [message];
}
var tokens=this._caches[message];
if(!tokens){
tokens=parse(message);
this._caches[message]=tokens;
}
return compile(tokens,values);
};



var RE_TOKEN_LIST_VALUE=/^(?:\d)+/;
var RE_TOKEN_NAMED_VALUE=/^(?:\w)+/;

function parse(format){
var tokens=[];
var position=0;

var text='';
while(position<format.length){
var char=format[position++];
if(char==='{'){
if(text){
tokens.push({type:'text',value:text});
}

text='';
var sub='';
char=format[position++];
while(char!==undefined&&char!=='}'){
sub+=char;
char=format[position++];
}
var isClosed=char==='}';

var type=RE_TOKEN_LIST_VALUE.test(sub)?
'list':
isClosed&&RE_TOKEN_NAMED_VALUE.test(sub)?
'named':
'unknown';
tokens.push({value:sub,type:type});
}else if(char==='%'){
// when found rails i18n syntax, skip text capture
if(format[position]!=='{'){
text+=char;
}
}else {
text+=char;
}
}

text&&tokens.push({type:'text',value:text});

return tokens;
}

function compile(tokens,values){
var compiled=[];
var index=0;

var mode=Array.isArray(values)?
'list':
isObject(values)?
'named':
'unknown';
if(mode==='unknown'){return compiled;}

while(index<tokens.length){
var token=tokens[index];
switch(token.type){
case'text':
compiled.push(token.value);
break;
case'list':
compiled.push(values[parseInt(token.value,10)]);
break;
case'named':
if(mode==='named'){
compiled.push(values[token.value]);
}else {
{
warn("Type of token '"+token.type+"' and format of value '"+mode+"' don't match!");
}
}
break;
case'unknown':
{
warn("Detect 'unknown' type of token!");
}
break;}

index++;
}

return compiled;
}

/*  */

/**
 *  Path parser
 *  - Inspired:
 *    Vue.js Path parser
 */

// actions
var APPEND=0;
var PUSH=1;
var INC_SUB_PATH_DEPTH=2;
var PUSH_SUB_PATH=3;

// states
var BEFORE_PATH=0;
var IN_PATH=1;
var BEFORE_IDENT=2;
var IN_IDENT=3;
var IN_SUB_PATH=4;
var IN_SINGLE_QUOTE=5;
var IN_DOUBLE_QUOTE=6;
var AFTER_PATH=7;
var ERROR=8;

var pathStateMachine=[];

pathStateMachine[BEFORE_PATH]={
'ws':[BEFORE_PATH],
'ident':[IN_IDENT,APPEND],
'[':[IN_SUB_PATH],
'eof':[AFTER_PATH]};


pathStateMachine[IN_PATH]={
'ws':[IN_PATH],
'.':[BEFORE_IDENT],
'[':[IN_SUB_PATH],
'eof':[AFTER_PATH]};


pathStateMachine[BEFORE_IDENT]={
'ws':[BEFORE_IDENT],
'ident':[IN_IDENT,APPEND],
'0':[IN_IDENT,APPEND],
'number':[IN_IDENT,APPEND]};


pathStateMachine[IN_IDENT]={
'ident':[IN_IDENT,APPEND],
'0':[IN_IDENT,APPEND],
'number':[IN_IDENT,APPEND],
'ws':[IN_PATH,PUSH],
'.':[BEFORE_IDENT,PUSH],
'[':[IN_SUB_PATH,PUSH],
'eof':[AFTER_PATH,PUSH]};


pathStateMachine[IN_SUB_PATH]={
"'":[IN_SINGLE_QUOTE,APPEND],
'"':[IN_DOUBLE_QUOTE,APPEND],
'[':[IN_SUB_PATH,INC_SUB_PATH_DEPTH],
']':[IN_PATH,PUSH_SUB_PATH],
'eof':ERROR,
'else':[IN_SUB_PATH,APPEND]};


pathStateMachine[IN_SINGLE_QUOTE]={
"'":[IN_SUB_PATH,APPEND],
'eof':ERROR,
'else':[IN_SINGLE_QUOTE,APPEND]};


pathStateMachine[IN_DOUBLE_QUOTE]={
'"':[IN_SUB_PATH,APPEND],
'eof':ERROR,
'else':[IN_DOUBLE_QUOTE,APPEND]};


/**
 * Check if an expression is a literal value.
 */

var literalValueRE=/^\s?(?:true|false|-?[\d.]+|'[^']*'|"[^"]*")\s?$/;
function isLiteral(exp){
return literalValueRE.test(exp);
}

/**
 * Strip quotes from a string
 */

function stripQuotes(str){
var a=str.charCodeAt(0);
var b=str.charCodeAt(str.length-1);
return a===b&&(a===0x22||a===0x27)?
str.slice(1,-1):
str;
}

/**
 * Determine the type of a character in a keypath.
 */

function getPathCharType(ch){
if(ch===undefined||ch===null){return 'eof';}

var code=ch.charCodeAt(0);

switch(code){
case 0x5B:// [
case 0x5D:// ]
case 0x2E:// .
case 0x22:// "
case 0x27:// '
return ch;

case 0x5F:// _
case 0x24:// $
case 0x2D:// -
return 'ident';

case 0x09:// Tab
case 0x0A:// Newline
case 0x0D:// Return
case 0xA0:// No-break space
case 0xFEFF:// Byte Order Mark
case 0x2028:// Line Separator
case 0x2029:// Paragraph Separator
return 'ws';}


return 'ident';
}

/**
 * Format a subPath, return its plain form if it is
 * a literal string or number. Otherwise prepend the
 * dynamic indicator (*).
 */

function formatSubPath(path){
var trimmed=path.trim();
// invalid leading 0
if(path.charAt(0)==='0'&&isNaN(path)){return false;}

return isLiteral(trimmed)?stripQuotes(trimmed):'*'+trimmed;
}

/**
 * Parse a string path into an array of segments
 */

function parse$1(path){
var keys=[];
var index=-1;
var mode=BEFORE_PATH;
var subPathDepth=0;
var c;
var key;
var newChar;
var type;
var transition;
var action;
var typeMap;
var actions=[];

actions[PUSH]=function(){
if(key!==undefined){
keys.push(key);
key=undefined;
}
};

actions[APPEND]=function(){
if(key===undefined){
key=newChar;
}else {
key+=newChar;
}
};

actions[INC_SUB_PATH_DEPTH]=function(){
actions[APPEND]();
subPathDepth++;
};

actions[PUSH_SUB_PATH]=function(){
if(subPathDepth>0){
subPathDepth--;
mode=IN_SUB_PATH;
actions[APPEND]();
}else {
subPathDepth=0;
if(key===undefined){return false;}
key=formatSubPath(key);
if(key===false){
return false;
}else {
actions[PUSH]();
}
}
};

function maybeUnescapeQuote(){
var nextChar=path[index+1];
if(mode===IN_SINGLE_QUOTE&&nextChar==="'"||
mode===IN_DOUBLE_QUOTE&&nextChar==='"'){
index++;
newChar='\\'+nextChar;
actions[APPEND]();
return true;
}
}

while(mode!==null){
index++;
c=path[index];

if(c==='\\'&&maybeUnescapeQuote()){
continue;
}

type=getPathCharType(c);
typeMap=pathStateMachine[mode];
transition=typeMap[type]||typeMap['else']||ERROR;

if(transition===ERROR){
return;// parse error
}

mode=transition[0];
action=actions[transition[1]];
if(action){
newChar=transition[2];
newChar=newChar===undefined?
c:
newChar;
if(action()===false){
return;
}
}

if(mode===AFTER_PATH){
return keys;
}
}
}





var I18nPath=function I18nPath(){
this._cache=Object.create(null);
};

/**
 * External parse that check for a cache hit first
 */
I18nPath.prototype.parsePath=function parsePath(path){
var hit=this._cache[path];
if(!hit){
hit=parse$1(path);
if(hit){
this._cache[path]=hit;
}
}
return hit||[];
};

/**
 * Get path value from path string
 */
I18nPath.prototype.getPathValue=function getPathValue(obj,path){
if(!isObject(obj)){return null;}

var paths=this.parsePath(path);
if(paths.length===0){
return null;
}else {
var length=paths.length;
var last=obj;
var i=0;
while(i<length){
var value=last[paths[i]];
if(value===undefined||value===null){
return null;
}
last=value;
i++;
}

return last;
}
};

/*  */



var htmlTagMatcher=/<\/?[\w\s="/.':;#-\/]+>/;
var linkKeyMatcher=/(?:@(?:\.[a-z]+)?:(?:[\w\-_|.]+|\([\w\-_|.]+\)))/g;
var linkKeyPrefixMatcher=/^@(?:\.([a-z]+))?:/;
var bracketsMatcher=/[()]/g;
var defaultModifiers={
'upper':function upper(str){return str.toLocaleUpperCase();},
'lower':function lower(str){return str.toLocaleLowerCase();},
'capitalize':function capitalize(str){return ""+str.charAt(0).toLocaleUpperCase()+str.substr(1);}};


var defaultFormatter=new BaseFormatter();

var VueI18n=function VueI18n(options){
var this$1=this;
if(options===void 0)options={};

// Auto install if it is not done yet and `window` has `Vue`.
// To allow users to avoid auto-installation in some cases,
// this code should be placed here. See #290
/* istanbul ignore if */
if(!Vue&&typeof window!=='undefined'&&window.Vue){
install(window.Vue);
}

var locale=options.locale||'en-US';
var fallbackLocale=options.fallbackLocale===false?
false:
options.fallbackLocale||'en-US';
var messages=options.messages||{};
var dateTimeFormats=options.dateTimeFormats||{};
var numberFormats=options.numberFormats||{};

this._vm=null;
this._formatter=options.formatter||defaultFormatter;
this._modifiers=options.modifiers||{};
this._missing=options.missing||null;
this._root=options.root||null;
this._sync=options.sync===undefined?true:!!options.sync;
this._fallbackRoot=options.fallbackRoot===undefined?
true:
!!options.fallbackRoot;
this._formatFallbackMessages=options.formatFallbackMessages===undefined?
false:
!!options.formatFallbackMessages;
this._silentTranslationWarn=options.silentTranslationWarn===undefined?
false:
options.silentTranslationWarn;
this._silentFallbackWarn=options.silentFallbackWarn===undefined?
false:
!!options.silentFallbackWarn;
this._dateTimeFormatters={};
this._numberFormatters={};
this._path=new I18nPath();
this._dataListeners=new Set();
this._componentInstanceCreatedListener=options.componentInstanceCreatedListener||null;
this._preserveDirectiveContent=options.preserveDirectiveContent===undefined?
false:
!!options.preserveDirectiveContent;
this.pluralizationRules=options.pluralizationRules||{};
this._warnHtmlInMessage=options.warnHtmlInMessage||'off';
this._postTranslation=options.postTranslation||null;
this._escapeParameterHtml=options.escapeParameterHtml||false;

/**
   * @param choice {number} a choice index given by the input to $tc: `$tc('path.to.rule', choiceIndex)`
   * @param choicesLength {number} an overall amount of available choices
   * @returns a final choice index
  */
this.getChoiceIndex=function(choice,choicesLength){
var thisPrototype=Object.getPrototypeOf(this$1);
if(thisPrototype&&thisPrototype.getChoiceIndex){
var prototypeGetChoiceIndex=thisPrototype.getChoiceIndex;
return prototypeGetChoiceIndex.call(this$1,choice,choicesLength);
}

// Default (old) getChoiceIndex implementation - english-compatible
var defaultImpl=function defaultImpl(_choice,_choicesLength){
_choice=Math.abs(_choice);

if(_choicesLength===2){
return _choice?
_choice>1?
1:
0:
1;
}

return _choice?Math.min(_choice,2):0;
};

if(this$1.locale in this$1.pluralizationRules){
return this$1.pluralizationRules[this$1.locale].apply(this$1,[choice,choicesLength]);
}else {
return defaultImpl(choice,choicesLength);
}
};


this._exist=function(message,key){
if(!message||!key){return false;}
if(!isNull(this$1._path.getPathValue(message,key))){return true;}
// fallback for flat key
if(message[key]){return true;}
return false;
};

if(this._warnHtmlInMessage==='warn'||this._warnHtmlInMessage==='error'){
Object.keys(messages).forEach(function(locale){
this$1._checkLocaleMessage(locale,this$1._warnHtmlInMessage,messages[locale]);
});
}

this._initVM({
locale:locale,
fallbackLocale:fallbackLocale,
messages:messages,
dateTimeFormats:dateTimeFormats,
numberFormats:numberFormats});

};

var prototypeAccessors={vm:{configurable:true},messages:{configurable:true},dateTimeFormats:{configurable:true},numberFormats:{configurable:true},availableLocales:{configurable:true},locale:{configurable:true},fallbackLocale:{configurable:true},formatFallbackMessages:{configurable:true},missing:{configurable:true},formatter:{configurable:true},silentTranslationWarn:{configurable:true},silentFallbackWarn:{configurable:true},preserveDirectiveContent:{configurable:true},warnHtmlInMessage:{configurable:true},postTranslation:{configurable:true}};

VueI18n.prototype._checkLocaleMessage=function _checkLocaleMessage(locale,level,message){
var paths=[];

var fn=function fn(level,locale,message,paths){
if(isPlainObject(message)){
Object.keys(message).forEach(function(key){
var val=message[key];
if(isPlainObject(val)){
paths.push(key);
paths.push('.');
fn(level,locale,val,paths);
paths.pop();
paths.pop();
}else {
paths.push(key);
fn(level,locale,val,paths);
paths.pop();
}
});
}else if(isArray(message)){
message.forEach(function(item,index){
if(isPlainObject(item)){
paths.push("["+index+"]");
paths.push('.');
fn(level,locale,item,paths);
paths.pop();
paths.pop();
}else {
paths.push("["+index+"]");
fn(level,locale,item,paths);
paths.pop();
}
});
}else if(isString(message)){
var ret=htmlTagMatcher.test(message);
if(ret){
var msg="Detected HTML in message '"+message+"' of keypath '"+paths.join('')+"' at '"+locale+"'. Consider component interpolation with '<i18n>' to avoid XSS. See https://bit.ly/2ZqJzkp";
if(level==='warn'){
warn(msg);
}else if(level==='error'){
error(msg);
}
}
}
};

fn(level,locale,message,paths);
};

VueI18n.prototype._initVM=function _initVM(data){
var silent=Vue.config.silent;
Vue.config.silent=true;
this._vm=new Vue({data:data});
Vue.config.silent=silent;
};

VueI18n.prototype.destroyVM=function destroyVM(){
this._vm.$destroy();
};

VueI18n.prototype.subscribeDataChanging=function subscribeDataChanging(vm){
this._dataListeners.add(vm);
};

VueI18n.prototype.unsubscribeDataChanging=function unsubscribeDataChanging(vm){
remove(this._dataListeners,vm);
};

VueI18n.prototype.watchI18nData=function watchI18nData(){
var self=this;
return this._vm.$watch('$data',function(){
self._dataListeners.forEach(function(e){
Vue.nextTick(function(){
e&&e.$forceUpdate();
});
});
},{deep:true});
};

VueI18n.prototype.watchLocale=function watchLocale(){
/* istanbul ignore if */
if(!this._sync||!this._root){return null;}
var target=this._vm;
return this._root.$i18n.vm.$watch('locale',function(val){
target.$set(target,'locale',val);
target.$forceUpdate();
},{immediate:true});
};

VueI18n.prototype.onComponentInstanceCreated=function onComponentInstanceCreated(newI18n){
if(this._componentInstanceCreatedListener){
this._componentInstanceCreatedListener(newI18n,this);
}
};

prototypeAccessors.vm.get=function(){return this._vm;};

prototypeAccessors.messages.get=function(){return looseClone(this._getMessages());};
prototypeAccessors.dateTimeFormats.get=function(){return looseClone(this._getDateTimeFormats());};
prototypeAccessors.numberFormats.get=function(){return looseClone(this._getNumberFormats());};
prototypeAccessors.availableLocales.get=function(){return Object.keys(this.messages).sort();};

prototypeAccessors.locale.get=function(){return this._vm.locale;};
prototypeAccessors.locale.set=function(locale){
this._vm.$set(this._vm,'locale',locale);
};

prototypeAccessors.fallbackLocale.get=function(){return this._vm.fallbackLocale;};
prototypeAccessors.fallbackLocale.set=function(locale){
this._localeChainCache={};
this._vm.$set(this._vm,'fallbackLocale',locale);
};

prototypeAccessors.formatFallbackMessages.get=function(){return this._formatFallbackMessages;};
prototypeAccessors.formatFallbackMessages.set=function(fallback){this._formatFallbackMessages=fallback;};

prototypeAccessors.missing.get=function(){return this._missing;};
prototypeAccessors.missing.set=function(handler){this._missing=handler;};

prototypeAccessors.formatter.get=function(){return this._formatter;};
prototypeAccessors.formatter.set=function(formatter){this._formatter=formatter;};

prototypeAccessors.silentTranslationWarn.get=function(){return this._silentTranslationWarn;};
prototypeAccessors.silentTranslationWarn.set=function(silent){this._silentTranslationWarn=silent;};

prototypeAccessors.silentFallbackWarn.get=function(){return this._silentFallbackWarn;};
prototypeAccessors.silentFallbackWarn.set=function(silent){this._silentFallbackWarn=silent;};

prototypeAccessors.preserveDirectiveContent.get=function(){return this._preserveDirectiveContent;};
prototypeAccessors.preserveDirectiveContent.set=function(preserve){this._preserveDirectiveContent=preserve;};

prototypeAccessors.warnHtmlInMessage.get=function(){return this._warnHtmlInMessage;};
prototypeAccessors.warnHtmlInMessage.set=function(level){
var this$1=this;

var orgLevel=this._warnHtmlInMessage;
this._warnHtmlInMessage=level;
if(orgLevel!==level&&(level==='warn'||level==='error')){
var messages=this._getMessages();
Object.keys(messages).forEach(function(locale){
this$1._checkLocaleMessage(locale,this$1._warnHtmlInMessage,messages[locale]);
});
}
};

prototypeAccessors.postTranslation.get=function(){return this._postTranslation;};
prototypeAccessors.postTranslation.set=function(handler){this._postTranslation=handler;};

VueI18n.prototype._getMessages=function _getMessages(){return this._vm.messages;};
VueI18n.prototype._getDateTimeFormats=function _getDateTimeFormats(){return this._vm.dateTimeFormats;};
VueI18n.prototype._getNumberFormats=function _getNumberFormats(){return this._vm.numberFormats;};

VueI18n.prototype._warnDefault=function _warnDefault(locale,key,result,vm,values,interpolateMode){
if(!isNull(result)){return result;}
if(this._missing){
var missingRet=this._missing.apply(null,[locale,key,vm,values]);
if(isString(missingRet)){
return missingRet;
}
}else {
if(!this._isSilentTranslationWarn(key)){
warn(
"Cannot translate the value of keypath '"+key+"'. "+
'Use the value of keypath as default.');

}
}

if(this._formatFallbackMessages){
var parsedArgs=parseArgs.apply(void 0,values);
return this._render(key,interpolateMode,parsedArgs.params,key);
}else {
return key;
}
};

VueI18n.prototype._isFallbackRoot=function _isFallbackRoot(val){
return !val&&!isNull(this._root)&&this._fallbackRoot;
};

VueI18n.prototype._isSilentFallbackWarn=function _isSilentFallbackWarn(key){
return this._silentFallbackWarn instanceof RegExp?
this._silentFallbackWarn.test(key):
this._silentFallbackWarn;
};

VueI18n.prototype._isSilentFallback=function _isSilentFallback(locale,key){
return this._isSilentFallbackWarn(key)&&(this._isFallbackRoot()||locale!==this.fallbackLocale);
};

VueI18n.prototype._isSilentTranslationWarn=function _isSilentTranslationWarn(key){
return this._silentTranslationWarn instanceof RegExp?
this._silentTranslationWarn.test(key):
this._silentTranslationWarn;
};

VueI18n.prototype._interpolate=function _interpolate(
locale,
message,
key,
host,
interpolateMode,
values,
visitedLinkStack)
{
if(!message){return null;}

var pathRet=this._path.getPathValue(message,key);
if(isArray(pathRet)||isPlainObject(pathRet)){return pathRet;}

var ret;
if(isNull(pathRet)){
/* istanbul ignore else */
if(isPlainObject(message)){
ret=message[key];
if(!(isString(ret)||isFunction(ret))){
if(!this._isSilentTranslationWarn(key)&&!this._isSilentFallback(locale,key)){
warn("Value of key '"+key+"' is not a string or function !");
}
return null;
}
}else {
return null;
}
}else {
/* istanbul ignore else */
if(isString(pathRet)||isFunction(pathRet)){
ret=pathRet;
}else {
if(!this._isSilentTranslationWarn(key)&&!this._isSilentFallback(locale,key)){
warn("Value of key '"+key+"' is not a string or function!");
}
return null;
}
}

// Check for the existence of links within the translated string
if(isString(ret)&&(ret.indexOf('@:')>=0||ret.indexOf('@.')>=0)){
ret=this._link(locale,message,ret,host,'raw',values,visitedLinkStack);
}

return this._render(ret,interpolateMode,values,key);
};

VueI18n.prototype._link=function _link(
locale,
message,
str,
host,
interpolateMode,
values,
visitedLinkStack)
{
var ret=str;

// Match all the links within the local
// We are going to replace each of
// them with its translation
var matches=ret.match(linkKeyMatcher);
for(var idx in matches){
// ie compatible: filter custom array
// prototype method
if(!matches.hasOwnProperty(idx)){
continue;
}
var link=matches[idx];
var linkKeyPrefixMatches=link.match(linkKeyPrefixMatcher);
var linkPrefix=linkKeyPrefixMatches[0];
var formatterName=linkKeyPrefixMatches[1];

// Remove the leading @:, @.case: and the brackets
var linkPlaceholder=link.replace(linkPrefix,'').replace(bracketsMatcher,'');

if(includes(visitedLinkStack,linkPlaceholder)){
{
warn("Circular reference found. \""+link+"\" is already visited in the chain of "+visitedLinkStack.reverse().join(' <- '));
}
return ret;
}
visitedLinkStack.push(linkPlaceholder);

// Translate the link
var translated=this._interpolate(
locale,message,linkPlaceholder,host,
interpolateMode==='raw'?'string':interpolateMode,
interpolateMode==='raw'?undefined:values,
visitedLinkStack);


if(this._isFallbackRoot(translated)){
if(!this._isSilentTranslationWarn(linkPlaceholder)){
warn("Fall back to translate the link placeholder '"+linkPlaceholder+"' with root locale.");
}
/* istanbul ignore if */
if(!this._root){throw Error('unexpected error');}
var root=this._root.$i18n;
translated=root._translate(
root._getMessages(),root.locale,root.fallbackLocale,
linkPlaceholder,host,interpolateMode,values);

}
translated=this._warnDefault(
locale,linkPlaceholder,translated,host,
isArray(values)?values:[values],
interpolateMode);


if(this._modifiers.hasOwnProperty(formatterName)){
translated=this._modifiers[formatterName](translated);
}else if(defaultModifiers.hasOwnProperty(formatterName)){
translated=defaultModifiers[formatterName](translated);
}

visitedLinkStack.pop();

// Replace the link with the translated
ret=!translated?ret:ret.replace(link,translated);
}

return ret;
};

VueI18n.prototype._createMessageContext=function _createMessageContext(values){
var _list=isArray(values)?values:[];
var _named=isObject(values)?values:{};
var list=function list(index){return _list[index];};
var named=function named(key){return _named[key];};
return {
list:list,
named:named};

};

VueI18n.prototype._render=function _render(message,interpolateMode,values,path){
if(isFunction(message)){
return message(this._createMessageContext(values));
}

var ret=this._formatter.interpolate(message,values,path);

// If the custom formatter refuses to work - apply the default one
if(!ret){
ret=defaultFormatter.interpolate(message,values,path);
}

// if interpolateMode is **not** 'string' ('row'),
// return the compiled data (e.g. ['foo', VNode, 'bar']) with formatter
return interpolateMode==='string'&&!isString(ret)?ret.join(''):ret;
};

VueI18n.prototype._appendItemToChain=function _appendItemToChain(chain,item,blocks){
var follow=false;
if(!includes(chain,item)){
follow=true;
if(item){
follow=item[item.length-1]!=='!';
item=item.replace(/!/g,'');
chain.push(item);
if(blocks&&blocks[item]){
follow=blocks[item];
}
}
}
return follow;
};

VueI18n.prototype._appendLocaleToChain=function _appendLocaleToChain(chain,locale,blocks){
var follow;
var tokens=locale.split('-');
do{
var item=tokens.join('-');
follow=this._appendItemToChain(chain,item,blocks);
tokens.splice(-1,1);
}while(tokens.length&&follow===true);
return follow;
};

VueI18n.prototype._appendBlockToChain=function _appendBlockToChain(chain,block,blocks){
var follow=true;
for(var i=0;i<block.length&&isBoolean(follow);i++){
var locale=block[i];
if(isString(locale)){
follow=this._appendLocaleToChain(chain,locale,blocks);
}
}
return follow;
};

VueI18n.prototype._getLocaleChain=function _getLocaleChain(start,fallbackLocale){
if(start===''){return [];}

if(!this._localeChainCache){
this._localeChainCache={};
}

var chain=this._localeChainCache[start];
if(!chain){
if(!fallbackLocale){
fallbackLocale=this.fallbackLocale;
}
chain=[];

// first block defined by start
var block=[start];

// while any intervening block found
while(isArray(block)){
block=this._appendBlockToChain(
chain,
block,
fallbackLocale);

}

// last block defined by default
var defaults;
if(isArray(fallbackLocale)){
defaults=fallbackLocale;
}else if(isObject(fallbackLocale)){
/* $FlowFixMe */
if(fallbackLocale['default']){
defaults=fallbackLocale['default'];
}else {
defaults=null;
}
}else {
defaults=fallbackLocale;
}

// convert defaults to array
if(isString(defaults)){
block=[defaults];
}else {
block=defaults;
}
if(block){
this._appendBlockToChain(
chain,
block,
null);

}
this._localeChainCache[start]=chain;
}
return chain;
};

VueI18n.prototype._translate=function _translate(
messages,
locale,
fallback,
key,
host,
interpolateMode,
args)
{
var chain=this._getLocaleChain(locale,fallback);
var res;
for(var i=0;i<chain.length;i++){
var step=chain[i];
res=
this._interpolate(step,messages[step],key,host,interpolateMode,args,[key]);
if(!isNull(res)){
if(step!==locale&&"development"!=='production'&&!this._isSilentTranslationWarn(key)&&!this._isSilentFallbackWarn(key)){
warn("Fall back to translate the keypath '"+key+"' with '"+step+"' locale.");
}
return res;
}
}
return null;
};

VueI18n.prototype._t=function _t(key,_locale,messages,host){
var ref;

var values=[],len=arguments.length-4;
while(len-->0){values[len]=arguments[len+4];}
if(!key){return '';}

var parsedArgs=parseArgs.apply(void 0,values);
if(this._escapeParameterHtml){
parsedArgs.params=escapeParams(parsedArgs.params);
}

var locale=parsedArgs.locale||_locale;

var ret=this._translate(
messages,locale,this.fallbackLocale,key,
host,'string',parsedArgs.params);

if(this._isFallbackRoot(ret)){
if(!this._isSilentTranslationWarn(key)&&!this._isSilentFallbackWarn(key)){
warn("Fall back to translate the keypath '"+key+"' with root locale.");
}
/* istanbul ignore if */
if(!this._root){throw Error('unexpected error');}
return (ref=this._root).$t.apply(ref,[key].concat(values));
}else {
ret=this._warnDefault(locale,key,ret,host,values,'string');
if(this._postTranslation&&ret!==null&&ret!==undefined){
ret=this._postTranslation(ret,key);
}
return ret;
}
};

VueI18n.prototype.t=function t(key){
var ref;

var values=[],len=arguments.length-1;
while(len-->0){values[len]=arguments[len+1];}
return (ref=this)._t.apply(ref,[key,this.locale,this._getMessages(),null].concat(values));
};

VueI18n.prototype._i=function _i(key,locale,messages,host,values){
var ret=
this._translate(messages,locale,this.fallbackLocale,key,host,'raw',values);
if(this._isFallbackRoot(ret)){
if(!this._isSilentTranslationWarn(key)){
warn("Fall back to interpolate the keypath '"+key+"' with root locale.");
}
if(!this._root){throw Error('unexpected error');}
return this._root.$i18n.i(key,locale,values);
}else {
return this._warnDefault(locale,key,ret,host,[values],'raw');
}
};

VueI18n.prototype.i=function i(key,locale,values){
/* istanbul ignore if */
if(!key){return '';}

if(!isString(locale)){
locale=this.locale;
}

return this._i(key,locale,this._getMessages(),null,values);
};

VueI18n.prototype._tc=function _tc(
key,
_locale,
messages,
host,
choice)
{
var ref;

var values=[],len=arguments.length-5;
while(len-->0){values[len]=arguments[len+5];}
if(!key){return '';}
if(choice===undefined){
choice=1;
}

var predefined={'count':choice,'n':choice};
var parsedArgs=parseArgs.apply(void 0,values);
parsedArgs.params=Object.assign(predefined,parsedArgs.params);
values=parsedArgs.locale===null?[parsedArgs.params]:[parsedArgs.locale,parsedArgs.params];
return this.fetchChoice((ref=this)._t.apply(ref,[key,_locale,messages,host].concat(values)),choice);
};

VueI18n.prototype.fetchChoice=function fetchChoice(message,choice){
/* istanbul ignore if */
if(!message||!isString(message)){return null;}
var choices=message.split('|');

choice=this.getChoiceIndex(choice,choices.length);
if(!choices[choice]){return message;}
return choices[choice].trim();
};

VueI18n.prototype.tc=function tc(key,choice){
var ref;

var values=[],len=arguments.length-2;
while(len-->0){values[len]=arguments[len+2];}
return (ref=this)._tc.apply(ref,[key,this.locale,this._getMessages(),null,choice].concat(values));
};

VueI18n.prototype._te=function _te(key,locale,messages){
var args=[],len=arguments.length-3;
while(len-->0){args[len]=arguments[len+3];}

var _locale=parseArgs.apply(void 0,args).locale||locale;
return this._exist(messages[_locale],key);
};

VueI18n.prototype.te=function te(key,locale){
return this._te(key,this.locale,this._getMessages(),locale);
};

VueI18n.prototype.getLocaleMessage=function getLocaleMessage(locale){
return looseClone(this._vm.messages[locale]||{});
};

VueI18n.prototype.setLocaleMessage=function setLocaleMessage(locale,message){
if(this._warnHtmlInMessage==='warn'||this._warnHtmlInMessage==='error'){
this._checkLocaleMessage(locale,this._warnHtmlInMessage,message);
}
this._vm.$set(this._vm.messages,locale,message);
};

VueI18n.prototype.mergeLocaleMessage=function mergeLocaleMessage(locale,message){
if(this._warnHtmlInMessage==='warn'||this._warnHtmlInMessage==='error'){
this._checkLocaleMessage(locale,this._warnHtmlInMessage,message);
}
this._vm.$set(this._vm.messages,locale,merge(
typeof this._vm.messages[locale]!=='undefined'&&Object.keys(this._vm.messages[locale]).length?
this._vm.messages[locale]:
{},
message));

};

VueI18n.prototype.getDateTimeFormat=function getDateTimeFormat(locale){
return looseClone(this._vm.dateTimeFormats[locale]||{});
};

VueI18n.prototype.setDateTimeFormat=function setDateTimeFormat(locale,format){
this._vm.$set(this._vm.dateTimeFormats,locale,format);
this._clearDateTimeFormat(locale,format);
};

VueI18n.prototype.mergeDateTimeFormat=function mergeDateTimeFormat(locale,format){
this._vm.$set(this._vm.dateTimeFormats,locale,merge(this._vm.dateTimeFormats[locale]||{},format));
this._clearDateTimeFormat(locale,format);
};

VueI18n.prototype._clearDateTimeFormat=function _clearDateTimeFormat(locale,format){
for(var key in format){
var id=locale+"__"+key;

if(!this._dateTimeFormatters.hasOwnProperty(id)){
continue;
}

delete this._dateTimeFormatters[id];
}
};

VueI18n.prototype._localizeDateTime=function _localizeDateTime(
value,
locale,
fallback,
dateTimeFormats,
key)
{
var _locale=locale;
var formats=dateTimeFormats[_locale];

var chain=this._getLocaleChain(locale,fallback);
for(var i=0;i<chain.length;i++){
var current=_locale;
var step=chain[i];
formats=dateTimeFormats[step];
_locale=step;
// fallback locale
if(isNull(formats)||isNull(formats[key])){
if(step!==locale&&"development"!=='production'&&!this._isSilentTranslationWarn(key)&&!this._isSilentFallbackWarn(key)){
warn("Fall back to '"+step+"' datetime formats from '"+current+"' datetime formats.");
}
}else {
break;
}
}

if(isNull(formats)||isNull(formats[key])){
return null;
}else {
var format=formats[key];
var id=_locale+"__"+key;
var formatter=this._dateTimeFormatters[id];
if(!formatter){
formatter=this._dateTimeFormatters[id]=new Intl.DateTimeFormat(_locale,format);
}
return formatter.format(value);
}
};

VueI18n.prototype._d=function _d(value,locale,key){
/* istanbul ignore if */
if(!VueI18n.availabilities.dateTimeFormat){
warn('Cannot format a Date value due to not supported Intl.DateTimeFormat.');
return '';
}

if(!key){
return new Intl.DateTimeFormat(locale).format(value);
}

var ret=
this._localizeDateTime(value,locale,this.fallbackLocale,this._getDateTimeFormats(),key);
if(this._isFallbackRoot(ret)){
if(!this._isSilentTranslationWarn(key)&&!this._isSilentFallbackWarn(key)){
warn("Fall back to datetime localization of root: key '"+key+"'.");
}
/* istanbul ignore if */
if(!this._root){throw Error('unexpected error');}
return this._root.$i18n.d(value,key,locale);
}else {
return ret||'';
}
};

VueI18n.prototype.d=function d(value){
var args=[],len=arguments.length-1;
while(len-->0){args[len]=arguments[len+1];}

var locale=this.locale;
var key=null;

if(args.length===1){
if(isString(args[0])){
key=args[0];
}else if(isObject(args[0])){
if(args[0].locale){
locale=args[0].locale;
}
if(args[0].key){
key=args[0].key;
}
}
}else if(args.length===2){
if(isString(args[0])){
key=args[0];
}
if(isString(args[1])){
locale=args[1];
}
}

return this._d(value,locale,key);
};

VueI18n.prototype.getNumberFormat=function getNumberFormat(locale){
return looseClone(this._vm.numberFormats[locale]||{});
};

VueI18n.prototype.setNumberFormat=function setNumberFormat(locale,format){
this._vm.$set(this._vm.numberFormats,locale,format);
this._clearNumberFormat(locale,format);
};

VueI18n.prototype.mergeNumberFormat=function mergeNumberFormat(locale,format){
this._vm.$set(this._vm.numberFormats,locale,merge(this._vm.numberFormats[locale]||{},format));
this._clearNumberFormat(locale,format);
};

VueI18n.prototype._clearNumberFormat=function _clearNumberFormat(locale,format){
for(var key in format){
var id=locale+"__"+key;

if(!this._numberFormatters.hasOwnProperty(id)){
continue;
}

delete this._numberFormatters[id];
}
};

VueI18n.prototype._getNumberFormatter=function _getNumberFormatter(
value,
locale,
fallback,
numberFormats,
key,
options)
{
var _locale=locale;
var formats=numberFormats[_locale];

var chain=this._getLocaleChain(locale,fallback);
for(var i=0;i<chain.length;i++){
var current=_locale;
var step=chain[i];
formats=numberFormats[step];
_locale=step;
// fallback locale
if(isNull(formats)||isNull(formats[key])){
if(step!==locale&&"development"!=='production'&&!this._isSilentTranslationWarn(key)&&!this._isSilentFallbackWarn(key)){
warn("Fall back to '"+step+"' number formats from '"+current+"' number formats.");
}
}else {
break;
}
}

if(isNull(formats)||isNull(formats[key])){
return null;
}else {
var format=formats[key];

var formatter;
if(options){
// If options specified - create one time number formatter
formatter=new Intl.NumberFormat(_locale,Object.assign({},format,options));
}else {
var id=_locale+"__"+key;
formatter=this._numberFormatters[id];
if(!formatter){
formatter=this._numberFormatters[id]=new Intl.NumberFormat(_locale,format);
}
}
return formatter;
}
};

VueI18n.prototype._n=function _n(value,locale,key,options){
/* istanbul ignore if */
if(!VueI18n.availabilities.numberFormat){
{
warn('Cannot format a Number value due to not supported Intl.NumberFormat.');
}
return '';
}

if(!key){
var nf=!options?new Intl.NumberFormat(locale):new Intl.NumberFormat(locale,options);
return nf.format(value);
}

var formatter=this._getNumberFormatter(value,locale,this.fallbackLocale,this._getNumberFormats(),key,options);
var ret=formatter&&formatter.format(value);
if(this._isFallbackRoot(ret)){
if(!this._isSilentTranslationWarn(key)&&!this._isSilentFallbackWarn(key)){
warn("Fall back to number localization of root: key '"+key+"'.");
}
/* istanbul ignore if */
if(!this._root){throw Error('unexpected error');}
return this._root.$i18n.n(value,Object.assign({},{key:key,locale:locale},options));
}else {
return ret||'';
}
};

VueI18n.prototype.n=function n(value){
var args=[],len=arguments.length-1;
while(len-->0){args[len]=arguments[len+1];}

var locale=this.locale;
var key=null;
var options=null;

if(args.length===1){
if(isString(args[0])){
key=args[0];
}else if(isObject(args[0])){
if(args[0].locale){
locale=args[0].locale;
}
if(args[0].key){
key=args[0].key;
}

// Filter out number format options only
options=Object.keys(args[0]).reduce(function(acc,key){
var obj;

if(includes(numberFormatKeys,key)){
return Object.assign({},acc,(obj={},obj[key]=args[0][key],obj));
}
return acc;
},null);
}
}else if(args.length===2){
if(isString(args[0])){
key=args[0];
}
if(isString(args[1])){
locale=args[1];
}
}

return this._n(value,locale,key,options);
};

VueI18n.prototype._ntp=function _ntp(value,locale,key,options){
/* istanbul ignore if */
if(!VueI18n.availabilities.numberFormat){
{
warn('Cannot format to parts a Number value due to not supported Intl.NumberFormat.');
}
return [];
}

if(!key){
var nf=!options?new Intl.NumberFormat(locale):new Intl.NumberFormat(locale,options);
return nf.formatToParts(value);
}

var formatter=this._getNumberFormatter(value,locale,this.fallbackLocale,this._getNumberFormats(),key,options);
var ret=formatter&&formatter.formatToParts(value);
if(this._isFallbackRoot(ret)){
if(!this._isSilentTranslationWarn(key)){
warn("Fall back to format number to parts of root: key '"+key+"' .");
}
/* istanbul ignore if */
if(!this._root){throw Error('unexpected error');}
return this._root.$i18n._ntp(value,locale,key,options);
}else {
return ret||[];
}
};

Object.defineProperties(VueI18n.prototype,prototypeAccessors);

var availabilities;
// $FlowFixMe
Object.defineProperty(VueI18n,'availabilities',{
get:function get(){
if(!availabilities){
var intlDefined=typeof Intl!=='undefined';
availabilities={
dateTimeFormat:intlDefined&&typeof Intl.DateTimeFormat!=='undefined',
numberFormat:intlDefined&&typeof Intl.NumberFormat!=='undefined'};

}

return availabilities;
}});


VueI18n.install=install;
VueI18n.version='8.24.3';

/* harmony default export */__webpack_exports__["default"]=VueI18n;


/***/},

/***/"./node_modules/vue-loader/lib/loaders/templateLoader.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/App.vue?vue&type=template&id=ab9f5064&":
/*!********************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-loader/lib/loaders/templateLoader.js??vue-loader-options!./node_modules/vue-loader/lib??vue-loader-options!./resources/src/App.vue?vue&type=template&id=ab9f5064& ***!
  \********************************************************************************************************************************************************************************************/
/*! exports provided: render, staticRenderFns */
/***/function node_modulesVueLoaderLibLoadersTemplateLoaderJsNode_modulesVueLoaderLibIndexJsResourcesSrcAppVueVueTypeTemplateIdAb9f5064(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"render",function(){return render;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"staticRenderFns",function(){return staticRenderFns;});
var render=function render(){
var _vm=this;
var _h=_vm.$createElement;
var _c=_vm._self._c||_h;
return _vm.Loading?
_c("div",[_c("router-view"),_vm._v(" "),_c("customizer")],1):
_vm._e();
};
var staticRenderFns=[];
render._withStripped=true;



/***/},

/***/"./node_modules/vue-loader/lib/loaders/templateLoader.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/components/breadcumb.vue?vue&type=template&id=630e5b49&":
/*!*************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-loader/lib/loaders/templateLoader.js??vue-loader-options!./node_modules/vue-loader/lib??vue-loader-options!./resources/src/components/breadcumb.vue?vue&type=template&id=630e5b49& ***!
  \*************************************************************************************************************************************************************************************************************/
/*! exports provided: render, staticRenderFns */
/***/function node_modulesVueLoaderLibLoadersTemplateLoaderJsNode_modulesVueLoaderLibIndexJsResourcesSrcComponentsBreadcumbVueVueTypeTemplateId630e5b49(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"render",function(){return render;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"staticRenderFns",function(){return staticRenderFns;});
var render=function render(){
var _vm=this;
var _h=_vm.$createElement;
var _c=_vm._self._c||_h;
return _c("div",[
_c(
"div",
{staticClass:"breadcrumb"},
[
_vm._t("header",[
_c("h1",[_vm._v(_vm._s(_vm.page))]),
_vm._v(" "),
_c("ul",[
_c("li",[
_c("a",{attrs:{href:""}},[
_vm._v(" "+_vm._s(_vm.folder)+" ")])]),


_vm._v(" "),
_c("li",[_vm._v(" "+_vm._s(_vm.page)+" ")])])])],



2),

_vm._v(" "),
_c("div",{staticClass:"separator-breadcrumb border-top"})]);

};
var staticRenderFns=[];
render._withStripped=true;



/***/},

/***/"./node_modules/vue-loader/lib/runtime/componentNormalizer.js":
/*!********************************************************************!*\
  !*** ./node_modules/vue-loader/lib/runtime/componentNormalizer.js ***!
  \********************************************************************/
/*! exports provided: default */
/***/function node_modulesVueLoaderLibRuntimeComponentNormalizerJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"default",function(){return normalizeComponent;});
/* globals __VUE_SSR_CONTEXT__ */

// IMPORTANT: Do NOT use ES2015 features in this file (except for modules).
// This module is a runtime utility for cleaner component module output and will
// be included in the final webpack user bundle.

function normalizeComponent(
scriptExports,
render,
staticRenderFns,
functionalTemplate,
injectStyles,
scopeId,
moduleIdentifier,/* server only */
shadowMode/* vue-cli only */)
{
// Vue.extend constructor export interop
var options=typeof scriptExports==='function'?
scriptExports.options:
scriptExports;

// render functions
if(render){
options.render=render;
options.staticRenderFns=staticRenderFns;
options._compiled=true;
}

// functional template
if(functionalTemplate){
options.functional=true;
}

// scopedId
if(scopeId){
options._scopeId='data-v-'+scopeId;
}

var hook;
if(moduleIdentifier){// server build
hook=function hook(context){
// 2.3 injection
context=
context||// cached call
this.$vnode&&this.$vnode.ssrContext||// stateful
this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext;// functional
// 2.2 with runInNewContext: true
if(!context&&typeof __VUE_SSR_CONTEXT__!=='undefined'){
context=__VUE_SSR_CONTEXT__;
}
// inject component styles
if(injectStyles){
injectStyles.call(this,context);
}
// register component module identifier for async chunk inferrence
if(context&&context._registeredComponents){
context._registeredComponents.add(moduleIdentifier);
}
};
// used by ssr in case component is cached and beforeCreate
// never gets called
options._ssrRegister=hook;
}else if(injectStyles){
hook=shadowMode?
function(){
injectStyles.call(
this,
(options.functional?this.parent:this).$root.$options.shadowRoot);

}:
injectStyles;
}

if(hook){
if(options.functional){
// for template-only hot-reload because in that case the render fn doesn't
// go through the normalizer
options._injectStyles=hook;
// register for functional component in vue file
var originalRender=options.render;
options.render=function renderWithStyleInjection(h,context){
hook.call(context);
return originalRender(h,context);
};
}else {
// inject component registration as beforeCreate hook
var existing=options.beforeCreate;
options.beforeCreate=existing?
[].concat(existing,hook):
[hook];
}
}

return {
exports:scriptExports,
options:options};

}


/***/},

/***/"./node_modules/vue-localstorage/dist/vue-local-storage.js":
/*!*****************************************************************!*\
  !*** ./node_modules/vue-localstorage/dist/vue-local-storage.js ***!
  \*****************************************************************/
/*! no static exports found */
/***/function node_modulesVueLocalstorageDistVueLocalStorageJs(module,exports,__webpack_require__){

/* WEBPACK VAR INJECTION */(function(process){/**
 * vue-local-storage v0.6.0
 * (c) 2017 Alexander Avakov
 * @license MIT
 */
(function(global,factory){
module.exports=factory();
})(this,function(){
var VueLocalStorage=function VueLocalStorage(){
this._properties={};
this._namespace='';
this._isSupported=true;
};

var prototypeAccessors={namespace:{}};

/**
 * Namespace getter.
 *
 * @returns {string}
 */
prototypeAccessors.namespace.get=function(){
return this._namespace;
};

/**
 * Namespace setter.
 *
 * @param {string} value
 */
prototypeAccessors.namespace.set=function(value){
this._namespace=value?value+".":'';
};

/**
 * Concatenates localStorage key with namespace prefix.
 *
 * @param {string} lsKey
 * @returns {string}
 * @private
 */
VueLocalStorage.prototype._getLsKey=function _getLsKey(lsKey){
return ""+this._namespace+lsKey;
};

/**
 * Set a value to localStorage giving respect to the namespace.
 *
 * @param {string} lsKey
 * @param {*} rawValue
 * @param {*} type
 * @private
 */
VueLocalStorage.prototype._lsSet=function _lsSet(lsKey,rawValue,type){
var key=this._getLsKey(lsKey);
var value=type&&[Array,Object].includes(type)?
JSON.stringify(rawValue):
rawValue;

window.localStorage.setItem(key,value);
};

/**
 * Get value from localStorage giving respect to the namespace.
 *
 * @param {string} lsKey
 * @returns {any}
 * @private
 */
VueLocalStorage.prototype._lsGet=function _lsGet(lsKey){
var key=this._getLsKey(lsKey);

return window.localStorage[key];
};

/**
 * Get value from localStorage
 *
 * @param {String} lsKey
 * @param {*} defaultValue
 * @param {*} defaultType
 * @returns {*}
 */
VueLocalStorage.prototype.get=function get(lsKey,defaultValue,defaultType){
var this$1=this;
if(defaultValue===void 0)defaultValue=null;
if(defaultType===void 0)defaultType=String;

if(!this._isSupported){
return null;
}

if(this._lsGet(lsKey)){
var type=defaultType;

for(var key in this$1._properties){
if(key===lsKey){
type=this$1._properties[key].type;
break;
}
}

return this._process(type,this._lsGet(lsKey));
}

return defaultValue!==null?defaultValue:null;
};

/**
 * Set localStorage value
 *
 * @param {String} lsKey
 * @param {*} value
 * @returns {*}
 */
VueLocalStorage.prototype.set=function set(lsKey,value){
var this$1=this;

if(!this._isSupported){
return null;
}

for(var key in this$1._properties){
var type=this$1._properties[key].type;

if(key===lsKey){
this$1._lsSet(lsKey,value,type);

return value;
}
}

this._lsSet(lsKey,value);

return value;
};

/**
 * Remove value from localStorage
 *
 * @param {String} lsKey
 */
VueLocalStorage.prototype.remove=function remove(lsKey){
if(!this._isSupported){
return null;
}

return window.localStorage.removeItem(lsKey);
};

/**
 * Add new property to localStorage
 *
 * @param {String} key
 * @param {function} type
 * @param {*} defaultValue
 */
VueLocalStorage.prototype.addProperty=function addProperty(key,type,defaultValue){
if(defaultValue===void 0)defaultValue=undefined;

type=type||String;

this._properties[key]={type:type};

if(!this._lsGet(key)&&defaultValue!==null){
this._lsSet(key,defaultValue,type);
}
};

/**
 * Process the value before return it from localStorage
 *
 * @param {String} type
 * @param {*} value
 * @returns {*}
 * @private
 */
VueLocalStorage.prototype._process=function _process(type,value){
switch(type){
case Boolean:
return value==='true';
case Number:
return parseFloat(value);
case Array:
try{
var array=JSON.parse(value);

return Array.isArray(array)?array:[];
}catch(e){
return [];
}
case Object:
try{
return JSON.parse(value);
}catch(e){
return {};
}
default:
return value;}

};

Object.defineProperties(VueLocalStorage.prototype,prototypeAccessors);

var vueLocalStorage=new VueLocalStorage();

var index={
/**
   * Install vue-local-storage plugin
   *
   * @param {Vue} Vue
   * @param {Object} options
   */
install:function install(Vue,options){
if(options===void 0)options={};

if(typeof process!=='undefined'&&(

process.server||
process.SERVER_BUILD||
process.env&&process.env.VUE_ENV==='server'))

{
return;
}

var isSupported=true;

try{
var test='__vue-localstorage-test__';

window.localStorage.setItem(test,test);
window.localStorage.removeItem(test);
}catch(e){
isSupported=false;
vueLocalStorage._isSupported=false;

console.error('Local storage is not supported');
}

var name=options.name||'localStorage';
var bind=options.bind;

if(options.namespace){
vueLocalStorage.namespace=options.namespace;
}

Vue.mixin({
beforeCreate:function beforeCreate(){
var this$1=this;

if(!isSupported){
return;
}

if(this.$options[name]){
Object.keys(this.$options[name]).forEach(function(key){
var config=this$1.$options[name][key];
var ref=[config.type,config.default];
var type=ref[0];
var defaultValue=ref[1];

vueLocalStorage.addProperty(key,type,defaultValue);

var existingProp=Object.getOwnPropertyDescriptor(vueLocalStorage,key);

if(!existingProp){
var prop={
get:function get(){return Vue.localStorage.get(key,defaultValue);},
set:function set(val){return Vue.localStorage.set(key,val);},
configurable:true};


Object.defineProperty(vueLocalStorage,key,prop);
Vue.util.defineReactive(vueLocalStorage,key,defaultValue);
}else if(!Vue.config.silent){
console.log(key+": is already defined and will be reused");
}

if((bind||config.bind)&&config.bind!==false){
this$1.$options.computed=this$1.$options.computed||{};

if(!this$1.$options.computed[key]){
this$1.$options.computed[key]={
get:function get(){return Vue.localStorage[key];},
set:function set(val){Vue.localStorage[key]=val;}};

}
}
});
}
}});


Vue[name]=vueLocalStorage;
Vue.prototype["$"+name]=vueLocalStorage;
}};


return index;

});

/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../process/browser.js */"./node_modules/process/browser.js"));

/***/},

/***/"./node_modules/vue-meta/dist/vue-meta.esm.js":
/*!****************************************************!*\
  !*** ./node_modules/vue-meta/dist/vue-meta.esm.js ***!
  \****************************************************/
/*! exports provided: default */
/***/function node_modulesVueMetaDistVueMetaEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* WEBPACK VAR INJECTION */(function(global){/* harmony import */var deepmerge__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! deepmerge */"./node_modules/vue-meta/node_modules/deepmerge/dist/cjs.js");
/* harmony import */var deepmerge__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(deepmerge__WEBPACK_IMPORTED_MODULE_0__);
/**
 * vue-meta v2.4.0
 * (c) 2020
 * - Declan de Wet
 * - Sébastien Chopin (@Atinux)
 * - Pim (@pimlie)
 * - All the amazing contributors
 * @license MIT
 */



var version="2.4.0";

function _typeof(obj){
"@babel/helpers - typeof";

if(typeof Symbol==="function"&&typeof Symbol.iterator==="symbol"){
_typeof=function _typeof(obj){
return typeof obj;
};
}else {
_typeof=function _typeof(obj){
return obj&&typeof Symbol==="function"&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj;
};
}

return _typeof(obj);
}

function _defineProperty(obj,key,value){
if(key in obj){
Object.defineProperty(obj,key,{
value:value,
enumerable:true,
configurable:true,
writable:true});

}else {
obj[key]=value;
}

return obj;
}

function ownKeys(object,enumerableOnly){
var keys=Object.keys(object);

if(Object.getOwnPropertySymbols){
var symbols=Object.getOwnPropertySymbols(object);
if(enumerableOnly)symbols=symbols.filter(function(sym){
return Object.getOwnPropertyDescriptor(object,sym).enumerable;
});
keys.push.apply(keys,symbols);
}

return keys;
}

function _objectSpread2(target){
for(var i=1;i<arguments.length;i++){
var source=arguments[i]!=null?arguments[i]:{};

if(i%2){
ownKeys(Object(source),true).forEach(function(key){
_defineProperty(target,key,source[key]);
});
}else if(Object.getOwnPropertyDescriptors){
Object.defineProperties(target,Object.getOwnPropertyDescriptors(source));
}else {
ownKeys(Object(source)).forEach(function(key){
Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key));
});
}
}

return target;
}

function _toConsumableArray(arr){
return _arrayWithoutHoles(arr)||_iterableToArray(arr)||_unsupportedIterableToArray(arr)||_nonIterableSpread();
}

function _arrayWithoutHoles(arr){
if(Array.isArray(arr))return _arrayLikeToArray(arr);
}

function _iterableToArray(iter){
if(typeof Symbol!=="undefined"&&Symbol.iterator in Object(iter))return Array.from(iter);
}

function _unsupportedIterableToArray(o,minLen){
if(!o)return;
if(typeof o==="string")return _arrayLikeToArray(o,minLen);
var n=Object.prototype.toString.call(o).slice(8,-1);
if(n==="Object"&&o.constructor)n=o.constructor.name;
if(n==="Map"||n==="Set")return Array.from(o);
if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return _arrayLikeToArray(o,minLen);
}

function _arrayLikeToArray(arr,len){
if(len==null||len>arr.length)len=arr.length;

for(var i=0,arr2=new Array(len);i<len;i++){arr2[i]=arr[i];}

return arr2;
}

function _nonIterableSpread(){
throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _createForOfIteratorHelper(o,allowArrayLike){
var it;

if(typeof Symbol==="undefined"||o[Symbol.iterator]==null){
if(Array.isArray(o)||(it=_unsupportedIterableToArray(o))||allowArrayLike&&o&&typeof o.length==="number"){
if(it)o=it;
var i=0;

var F=function F(){};

return {
s:F,
n:function n(){
if(i>=o.length)return {
done:true};

return {
done:false,
value:o[i++]};

},
e:function e(_e3){
throw _e3;
},
f:F};

}

throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var normalCompletion=true,
didErr=false,
err;
return {
s:function s(){
it=o[Symbol.iterator]();
},
n:function n(){
var step=it.next();
normalCompletion=step.done;
return step;
},
e:function e(_e4){
didErr=true;
err=_e4;
},
f:function f(){
try{
if(!normalCompletion&&it.return!=null)it.return();
}finally{
if(didErr)throw err;
}
}};

}

/**
 * checks if passed argument is an array
 * @param  {any}  arg - the object to check
 * @return {Boolean} - true if `arg` is an array
 */
function isArray(arg){
return Array.isArray(arg);
}
function isUndefined(arg){
return typeof arg==='undefined';
}
function isObject(arg){
return _typeof(arg)==='object';
}
function isPureObject(arg){
return _typeof(arg)==='object'&&arg!==null;
}
function isFunction(arg){
return typeof arg==='function';
}
function isString(arg){
return typeof arg==='string';
}

function hasGlobalWindowFn(){
try{
return !isUndefined(window);
}catch(e){
return false;
}
}
var hasGlobalWindow=hasGlobalWindowFn();

var _global=hasGlobalWindow?window:global;

var console=_global.console||{};
function warn(str){
/* istanbul ignore next */
if(!console||!console.warn){
return;
}

console.warn(str);
}
var showWarningNotSupported=function showWarningNotSupported(){
return warn('This vue app/component has no vue-meta configuration');
};

/**
 * These are constant variables used throughout the application.
 */
// set some sane defaults
var defaultInfo={
title:undefined,
titleChunk:'',
titleTemplate:'%s',
htmlAttrs:{},
bodyAttrs:{},
headAttrs:{},
base:[],
link:[],
meta:[],
style:[],
script:[],
noscript:[],
__dangerouslyDisableSanitizers:[],
__dangerouslyDisableSanitizersByTagID:{}};

var rootConfigKey='_vueMeta';// This is the name of the component option that contains all the information that
// gets converted to the various meta tags & attributes for the page.

var keyName='metaInfo';// This is the attribute vue-meta arguments on elements to know which it should
// manage and which it should ignore.

var attribute='data-vue-meta';// This is the attribute that goes on the `html` tag to inform `vue-meta`
// that the server has already generated the meta tags for the initial render.

var ssrAttribute='data-vue-meta-server-rendered';// This is the property that tells vue-meta to overwrite (instead of append)
// an item in a tag list. For example, if you have two `meta` tag list items
// that both have `vmid` of "description", then vue-meta will overwrite the
// shallowest one with the deepest one.

var tagIDKeyName='vmid';// This is the key name for possible meta templates

var metaTemplateKeyName='template';// This is the key name for the content-holding property

var contentKeyName='content';// The id used for the ssr app

var ssrAppId='ssr';// How long meta update

var debounceWait=10;// How long meta update

var waitOnDestroyed=true;
var defaultOptions={
keyName:keyName,
attribute:attribute,
ssrAttribute:ssrAttribute,
tagIDKeyName:tagIDKeyName,
contentKeyName:contentKeyName,
metaTemplateKeyName:metaTemplateKeyName,
waitOnDestroyed:waitOnDestroyed,
debounceWait:debounceWait,
ssrAppId:ssrAppId};
// might be a bit ugly, but minimizes the browser bundles a bit

var defaultInfoKeys=Object.keys(defaultInfo);// The metaInfo property keys which are used to disable escaping

var disableOptionKeys=[defaultInfoKeys[12],defaultInfoKeys[13]];// List of metaInfo property keys which are configuration options (and dont generate html)

var metaInfoOptionKeys=[defaultInfoKeys[1],defaultInfoKeys[2],'changed'].concat(disableOptionKeys);// List of metaInfo property keys which only generates attributes and no tags

var metaInfoAttributeKeys=[defaultInfoKeys[3],defaultInfoKeys[4],defaultInfoKeys[5]];// HTML elements which support the onload event

var tagsSupportingOnload=['link','style','script'];// HTML elements which dont have a head tag (shortened to our needs)
// see: https://www.w3.org/TR/html52/document-metadata.html

var tagsWithoutEndTag=['base','meta','link'];// HTML elements which can have inner content (shortened to our needs)

var tagsWithInnerContent=['noscript','script','style'];// Attributes which are inserted as childNodes instead of HTMLAttribute

var tagAttributeAsInnerContent=['innerHTML','cssText','json'];
var tagProperties=['once','skip','template'];// Attributes which should be added with data- prefix

var commonDataAttributes=['body','pbody'];// from: https://github.com/kangax/html-minifier/blob/gh-pages/src/htmlminifier.js#L202

var booleanHtmlAttributes=['allowfullscreen','amp','amp-boilerplate','async','autofocus','autoplay','checked','compact','controls','declare','default','defaultchecked','defaultmuted','defaultselected','defer','disabled','enabled','formnovalidate','hidden','indeterminate','inert','ismap','itemscope','loop','multiple','muted','nohref','noresize','noshade','novalidate','nowrap','open','pauseonexit','readonly','required','reversed','scoped','seamless','selected','sortable','truespeed','typemustmatch','visible'];

var batchId=null;
function triggerUpdate(_ref,rootVm,hookName){
var debounceWait=_ref.debounceWait;

// if an update was triggered during initialization or when an update was triggered by the
// metaInfo watcher, set initialized to null
// then we keep falsy value but know we need to run a triggerUpdate after initialization
if(!rootVm[rootConfigKey].initialized&&(rootVm[rootConfigKey].initializing||hookName==='watcher')){
rootVm[rootConfigKey].initialized=null;
}

if(rootVm[rootConfigKey].initialized&&!rootVm[rootConfigKey].pausing){
// batch potential DOM updates to prevent extraneous re-rendering
// eslint-disable-next-line no-void
batchUpdate(function(){
return void rootVm.$meta().refresh();
},debounceWait);
}
}
/**
 * Performs a batched update.
 *
 * @param  {(null|Number)} id - the ID of this update
 * @param  {Function} callback - the update to perform
 * @return {Number} id - a new ID
 */

function batchUpdate(callback,timeout){
timeout=timeout===undefined?10:timeout;

if(!timeout){
callback();
return;
}

clearTimeout(batchId);
batchId=setTimeout(function(){
callback();
},timeout);
return batchId;
}

/*
 * To reduce build size, this file provides simple polyfills without
 * overly excessive type checking and without modifying
 * the global Array.prototype
 * The polyfills are automatically removed in the commonjs build
 * Also, only files in client/ & shared/ should use these functions
 * files in server/ still use normal js function
 */
function find(array,predicate,thisArg){
if(!Array.prototype.find){
// idx needs to be a Number, for..in returns string
for(var idx=0;idx<array.length;idx++){
if(predicate.call(thisArg,array[idx],idx,array)){
return array[idx];
}
}

return;
}

return array.find(predicate,thisArg);
}
function findIndex(array,predicate,thisArg){
if(!Array.prototype.findIndex){
// idx needs to be a Number, for..in returns string
for(var idx=0;idx<array.length;idx++){
if(predicate.call(thisArg,array[idx],idx,array)){
return idx;
}
}

return -1;
}

return array.findIndex(predicate,thisArg);
}
function toArray(arg){
if(!Array.from){
return Array.prototype.slice.call(arg);
}

return Array.from(arg);
}
function includes(array,value){
if(!Array.prototype.includes){
for(var idx in array){
if(array[idx]===value){
return true;
}
}

return false;
}

return array.includes(value);
}

var querySelector=function querySelector(arg,el){
return (el||document).querySelectorAll(arg);
};
function getTag(tags,tag){
if(!tags[tag]){
tags[tag]=document.getElementsByTagName(tag)[0];
}

return tags[tag];
}
function getElementsKey(_ref){
var body=_ref.body,
pbody=_ref.pbody;
return body?'body':pbody?'pbody':'head';
}
function queryElements(parentNode,_ref2,attributes){
var appId=_ref2.appId,
attribute=_ref2.attribute,
type=_ref2.type,
tagIDKeyName=_ref2.tagIDKeyName;
attributes=attributes||{};
var queries=["".concat(type,"[").concat(attribute,"=\"").concat(appId,"\"]"),"".concat(type,"[data-").concat(tagIDKeyName,"]")].map(function(query){
for(var key in attributes){
var val=attributes[key];
var attributeValue=val&&val!==true?"=\"".concat(val,"\""):'';
query+="[data-".concat(key).concat(attributeValue,"]");
}

return query;
});
return toArray(querySelector(queries.join(', '),parentNode));
}
function removeElementsByAppId(_ref3,appId){
var attribute=_ref3.attribute;
toArray(querySelector("[".concat(attribute,"=\"").concat(appId,"\"]"))).map(function(el){
return el.remove();
});
}
function removeAttribute(el,attributeName){
el.removeAttribute(attributeName);
}

function hasMetaInfo(vm){
vm=vm||this;
return vm&&(vm[rootConfigKey]===true||isObject(vm[rootConfigKey]));
}// a component is in a metaInfo branch when itself has meta info or one of its (grand-)children has

function inMetaInfoBranch(vm){
vm=vm||this;
return vm&&!isUndefined(vm[rootConfigKey]);
}

function pause(rootVm,refresh){
rootVm[rootConfigKey].pausing=true;
return function(){
return resume(rootVm,refresh);
};
}
function resume(rootVm,refresh){
rootVm[rootConfigKey].pausing=false;

if(refresh||refresh===undefined){
return rootVm.$meta().refresh();
}
}

function addNavGuards(rootVm){
var router=rootVm.$router;// return when nav guards already added or no router exists

if(rootVm[rootConfigKey].navGuards||!router){
/* istanbul ignore next */
return;
}

rootVm[rootConfigKey].navGuards=true;
router.beforeEach(function(to,from,next){
pause(rootVm);
next();
});
router.afterEach(function(){
rootVm.$nextTick(function(){
var _resume=resume(rootVm),
metaInfo=_resume.metaInfo;

if(metaInfo&&isFunction(metaInfo.afterNavigation)){
metaInfo.afterNavigation(metaInfo);
}
});
});
}

var appId=1;
function createMixin(Vue,options){
// for which Vue lifecycle hooks should the metaInfo be refreshed
var updateOnLifecycleHook=['activated','deactivated','beforeMount'];
var wasServerRendered=false;// watch for client side component updates

return {
beforeCreate:function beforeCreate(){
var _this2=this;

var rootKey='$root';
var $root=this[rootKey];
var $options=this.$options;
var devtoolsEnabled=Vue.config.devtools;
Object.defineProperty(this,'_hasMetaInfo',{
configurable:true,
get:function get(){
// Show deprecation warning once when devtools enabled
if(devtoolsEnabled&&!$root[rootConfigKey].deprecationWarningShown){
warn('VueMeta DeprecationWarning: _hasMetaInfo has been deprecated and will be removed in a future version. Please use hasMetaInfo(vm) instead');
$root[rootConfigKey].deprecationWarningShown=true;
}

return hasMetaInfo(this);
}});


if(this===$root){
$root.$once('hook:beforeMount',function(){
wasServerRendered=this.$el&&this.$el.nodeType===1&&this.$el.hasAttribute('data-server-rendered');// In most cases when you have a SSR app it will be the first app thats gonna be
// initiated, if we cant detect the data-server-rendered attribute from Vue but we
// do see our own ssrAttribute then _assume_ the Vue app with appId 1 is the ssr app
// attempted fix for #404 & #562, but we rly need to refactor how we pass appIds from
// ssr to the client

if(!wasServerRendered&&$root[rootConfigKey]&&$root[rootConfigKey].appId===1){
var htmlTag=getTag({},'html');
wasServerRendered=htmlTag&&htmlTag.hasAttribute(options.ssrAttribute);
}
});
}// Add a marker to know if it uses metaInfo
// _vnode is used to know that it's attached to a real component
// useful if we use some mixin to add some meta tags (like nuxt-i18n)


if(isUndefined($options[options.keyName])||$options[options.keyName]===null){
return;
}

if(!$root[rootConfigKey]){
$root[rootConfigKey]={
appId:appId};

appId++;

if(devtoolsEnabled&&$root.$options[options.keyName]){
// use nextTick so the children should be added to $root
this.$nextTick(function(){
// find the first child that lists fnOptions
var child=find($root.$children,function(c){
return c.$vnode&&c.$vnode.fnOptions;
});

if(child&&child.$vnode.fnOptions[options.keyName]){
warn("VueMeta has detected a possible global mixin which adds a ".concat(options.keyName," property to all Vue components on the page. This could cause severe performance issues. If possible, use $meta().addApp to add meta information instead"));
}
});
}
}// to speed up updates we keep track of branches which have a component with vue-meta info defined
// if _vueMeta = true it has info, if _vueMeta = false a child has info


if(!this[rootConfigKey]){
this[rootConfigKey]=true;
var parent=this.$parent;

while(parent&&parent!==$root){
if(isUndefined(parent[rootConfigKey])){
parent[rootConfigKey]=false;
}

parent=parent.$parent;
}
}// coerce function-style metaInfo to a computed prop so we can observe
// it on creation


if(isFunction($options[options.keyName])){
$options.computed=$options.computed||{};
$options.computed.$metaInfo=$options[options.keyName];

if(!this.$isServer){
// if computed $metaInfo exists, watch it for updates & trigger a refresh
// when it changes (i.e. automatically handle async actions that affect metaInfo)
// credit for this suggestion goes to [Sébastien Chopin](https://github.com/Atinux)
this.$on('hook:created',function(){
this.$watch('$metaInfo',function(){
triggerUpdate(options,this[rootKey],'watcher');
});
});
}
}// force an initial refresh on page load and prevent other lifecycleHooks
// to triggerUpdate until this initial refresh is finished
// this is to make sure that when a page is opened in an inactive tab which
// has throttled rAF/timers we still immediately set the page title


if(isUndefined($root[rootConfigKey].initialized)){
$root[rootConfigKey].initialized=this.$isServer;

if(!$root[rootConfigKey].initialized){
if(!$root[rootConfigKey].initializedSsr){
$root[rootConfigKey].initializedSsr=true;
this.$on('hook:beforeMount',function(){
var $root=this[rootKey];// if this Vue-app was server rendered, set the appId to 'ssr'
// only one SSR app per page is supported

if(wasServerRendered){
$root[rootConfigKey].appId=options.ssrAppId;
}
});
}// we use the mounted hook here as on page load


this.$on('hook:mounted',function(){
var $root=this[rootKey];

if($root[rootConfigKey].initialized){
return;
}// used in triggerUpdate to check if a change was triggered
// during initialization


$root[rootConfigKey].initializing=true;// refresh meta in nextTick so all child components have loaded

this.$nextTick(function(){
var _$root$$meta$refresh=$root.$meta().refresh(),
tags=_$root$$meta$refresh.tags,
metaInfo=_$root$$meta$refresh.metaInfo;// After ssr hydration (identifier by tags === false) check
// if initialized was set to null in triggerUpdate. That'd mean
// that during initilazation changes where triggered which need
// to be applied OR a metaInfo watcher was triggered before the
// current hook was called
// (during initialization all changes are blocked)


if(tags===false&&$root[rootConfigKey].initialized===null){
this.$nextTick(function(){
return triggerUpdate(options,$root,'init');
});
}

$root[rootConfigKey].initialized=true;
delete $root[rootConfigKey].initializing;// add the navigation guards if they havent been added yet
// they are needed for the afterNavigation callback

if(!options.refreshOnceOnNavigation&&metaInfo.afterNavigation){
addNavGuards($root);
}
});
});// add the navigation guards if requested

if(options.refreshOnceOnNavigation){
addNavGuards($root);
}
}
}

this.$on('hook:destroyed',function(){
var _this=this;

// do not trigger refresh:
// - when user configured to not wait for transitions on destroyed
// - when the component doesnt have a parent
// - doesnt have metaInfo defined
if(!this.$parent||!hasMetaInfo(this)){
return;
}

delete this._hasMetaInfo;
this.$nextTick(function(){
if(!options.waitOnDestroyed||!_this.$el||!_this.$el.offsetParent){
triggerUpdate(options,_this.$root,'destroyed');
return;
}// Wait that element is hidden before refreshing meta tags (to support animations)


var interval=setInterval(function(){
if(_this.$el&&_this.$el.offsetParent!==null){
/* istanbul ignore next line */
return;
}

clearInterval(interval);
triggerUpdate(options,_this.$root,'destroyed');
},50);
});
});// do not trigger refresh on the server side

if(this.$isServer){
/* istanbul ignore next */
return;
}// no need to add this hooks on server side


updateOnLifecycleHook.forEach(function(lifecycleHook){
_this2.$on("hook:".concat(lifecycleHook),function(){
triggerUpdate(options,this[rootKey],lifecycleHook);
});
});
}};

}

function setOptions(options){
// combine options
options=isObject(options)?options:{};// The options are set like this so they can
// be minified by terser while keeping the
// user api intact
// terser --mangle-properties keep_quoted=strict

/* eslint-disable dot-notation */

return {
keyName:options['keyName']||defaultOptions.keyName,
attribute:options['attribute']||defaultOptions.attribute,
ssrAttribute:options['ssrAttribute']||defaultOptions.ssrAttribute,
tagIDKeyName:options['tagIDKeyName']||defaultOptions.tagIDKeyName,
contentKeyName:options['contentKeyName']||defaultOptions.contentKeyName,
metaTemplateKeyName:options['metaTemplateKeyName']||defaultOptions.metaTemplateKeyName,
debounceWait:isUndefined(options['debounceWait'])?defaultOptions.debounceWait:options['debounceWait'],
waitOnDestroyed:isUndefined(options['waitOnDestroyed'])?defaultOptions.waitOnDestroyed:options['waitOnDestroyed'],
ssrAppId:options['ssrAppId']||defaultOptions.ssrAppId,
refreshOnceOnNavigation:!!options['refreshOnceOnNavigation']};

/* eslint-enable dot-notation */
}
function getOptions(options){
var optionsCopy={};

for(var key in options){
optionsCopy[key]=options[key];
}

return optionsCopy;
}

function ensureIsArray(arg,key){
if(!key||!isObject(arg)){
return isArray(arg)?arg:[];
}

if(!isArray(arg[key])){
arg[key]=[];
}

return arg;
}

var serverSequences=[[/&/g,'&amp;'],[/</g,'&lt;'],[/>/g,'&gt;'],[/"/g,'&quot;'],[/'/g,'&#x27;']];
var clientSequences=[[/&/g,"&"],[/</g,"<"],[/>/g,">"],[/"/g,"\""],[/'/g,"'"]];// sanitizes potentially dangerous characters

function escape(info,options,escapeOptions,escapeKeys){
var tagIDKeyName=options.tagIDKeyName;
var _escapeOptions$doEsca=escapeOptions.doEscape,
doEscape=_escapeOptions$doEsca===void 0?function(v){
return v;
}:_escapeOptions$doEsca;
var escaped={};

for(var key in info){
var value=info[key];// no need to escape configuration options

if(includes(metaInfoOptionKeys,key)){
escaped[key]=value;
continue;
}// do not use destructuring for disableOptionKeys, it increases transpiled size
// due to var checks while we are guaranteed the structure of the cb


var disableKey=disableOptionKeys[0];

if(escapeOptions[disableKey]&&includes(escapeOptions[disableKey],key)){
// this info[key] doesnt need to escaped if the option is listed in __dangerouslyDisableSanitizers
escaped[key]=value;
continue;
}

var tagId=info[tagIDKeyName];

if(tagId){
disableKey=disableOptionKeys[1];// keys which are listed in __dangerouslyDisableSanitizersByTagID for the current vmid do not need to be escaped

if(escapeOptions[disableKey]&&escapeOptions[disableKey][tagId]&&includes(escapeOptions[disableKey][tagId],key)){
escaped[key]=value;
continue;
}
}

if(isString(value)){
escaped[key]=doEscape(value);
}else if(isArray(value)){
escaped[key]=value.map(function(v){
if(isPureObject(v)){
return escape(v,options,escapeOptions,true);
}

return doEscape(v);
});
}else if(isPureObject(value)){
escaped[key]=escape(value,options,escapeOptions,true);
}else {
escaped[key]=value;
}

if(escapeKeys){
var escapedKey=doEscape(key);

if(key!==escapedKey){
escaped[escapedKey]=escaped[key];
delete escaped[key];
}
}
}

return escaped;
}
function escapeMetaInfo(options,info,escapeSequences){
escapeSequences=escapeSequences||[];// do not use destructuring for seq, it increases transpiled size
// due to var checks while we are guaranteed the structure of the cb

var escapeOptions={
doEscape:function doEscape(value){
return escapeSequences.reduce(function(val,seq){
return val.replace(seq[0],seq[1]);
},value);
}};

disableOptionKeys.forEach(function(disableKey,index){
if(index===0){
ensureIsArray(info,disableKey);
}else if(index===1){
for(var key in info[disableKey]){
ensureIsArray(info[disableKey],key);
}
}

escapeOptions[disableKey]=info[disableKey];
});// begin sanitization

return escape(info,options,escapeOptions);
}

function applyTemplate(_ref,headObject,template,chunk){
var component=_ref.component,
metaTemplateKeyName=_ref.metaTemplateKeyName,
contentKeyName=_ref.contentKeyName;

if(template===true||headObject[metaTemplateKeyName]===true){
// abort, template was already applied
return false;
}

if(isUndefined(template)&&headObject[metaTemplateKeyName]){
template=headObject[metaTemplateKeyName];
headObject[metaTemplateKeyName]=true;
}// return early if no template defined


if(!template){
// cleanup faulty template properties
delete headObject[metaTemplateKeyName];
return false;
}

if(isUndefined(chunk)){
chunk=headObject[contentKeyName];
}

headObject[contentKeyName]=isFunction(template)?template.call(component,chunk):template.replace(/%s/g,chunk);
return true;
}

function _arrayMerge(_ref,target,source){
var component=_ref.component,
tagIDKeyName=_ref.tagIDKeyName,
metaTemplateKeyName=_ref.metaTemplateKeyName,
contentKeyName=_ref.contentKeyName;
// we concat the arrays without merging objects contained in,
// but we check for a `vmid` property on each object in the array
// using an O(1) lookup associative array exploit
var destination=[];

if(!target.length&&!source.length){
return destination;
}

target.forEach(function(targetItem,targetIndex){
// no tagID so no need to check for duplicity
if(!targetItem[tagIDKeyName]){
destination.push(targetItem);
return;
}

var sourceIndex=findIndex(source,function(item){
return item[tagIDKeyName]===targetItem[tagIDKeyName];
});
var sourceItem=source[sourceIndex];// source doesnt contain any duplicate vmid's, we can keep targetItem

if(sourceIndex===-1){
destination.push(targetItem);
return;
}// when sourceItem explictly defines contentKeyName or innerHTML as undefined, its
// an indication that we need to skip the default behaviour or child has preference over parent
// which means we keep the targetItem and ignore/remove the sourceItem


if(contentKeyName in sourceItem&&sourceItem[contentKeyName]===undefined||'innerHTML'in sourceItem&&sourceItem.innerHTML===undefined){
destination.push(targetItem);// remove current index from source array so its not concatenated to destination below

source.splice(sourceIndex,1);
return;
}// we now know that targetItem is a duplicate and we should ignore it in favor of sourceItem
// if source specifies null as content then ignore both the target as the source


if(sourceItem[contentKeyName]===null||sourceItem.innerHTML===null){
// remove current index from source array so its not concatenated to destination below
source.splice(sourceIndex,1);
return;
}// now we only need to check if the target has a template to combine it with the source


var targetTemplate=targetItem[metaTemplateKeyName];

if(!targetTemplate){
return;
}

var sourceTemplate=sourceItem[metaTemplateKeyName];

if(!sourceTemplate){
// use parent template and child content
applyTemplate({
component:component,
metaTemplateKeyName:metaTemplateKeyName,
contentKeyName:contentKeyName},
sourceItem,targetTemplate);// set template to true to indicate template was already applied

sourceItem.template=true;
return;
}

if(!sourceItem[contentKeyName]){
// use parent content and child template
applyTemplate({
component:component,
metaTemplateKeyName:metaTemplateKeyName,
contentKeyName:contentKeyName},
sourceItem,undefined,targetItem[contentKeyName]);
}
});
return destination.concat(source);
}
var warningShown=false;
function merge(target,source,options){
options=options||{};// remove properties explicitly set to false so child components can
// optionally _not_ overwrite the parents content
// (for array properties this is checked in arrayMerge)

if(source.title===undefined){
delete source.title;
}

metaInfoAttributeKeys.forEach(function(attrKey){
if(!source[attrKey]){
return;
}

for(var key in source[attrKey]){
if(key in source[attrKey]&&source[attrKey][key]===undefined){
if(includes(booleanHtmlAttributes,key)&&!warningShown){
warn('VueMeta: Please note that since v2 the value undefined is not used to indicate boolean attributes anymore, see migration guide for details');
warningShown=true;
}

delete source[attrKey][key];
}
}
});
return deepmerge__WEBPACK_IMPORTED_MODULE_0___default()(target,source,{
arrayMerge:function arrayMerge(t,s){
return _arrayMerge(options,t,s);
}});

}

function getComponentMetaInfo(options,component){
return getComponentOption(options||{},component,defaultInfo);
}
/**
 * Returns the `opts.option` $option value of the given `opts.component`.
 * If methods are encountered, they will be bound to the component context.
 * If `opts.deep` is true, will recursively merge all child component
 * `opts.option` $option values into the returned result.
 *
 * @param  {Object} opts - options
 * @param  {Object} opts.component - Vue component to fetch option data from
 * @param  {Boolean} opts.deep - look for data in child components as well?
 * @param  {Function} opts.arrayMerge - how should arrays be merged?
 * @param  {String} opts.keyName - the name of the option to look for
 * @param  {Object} [result={}] - result so far
 * @return {Object} result - final aggregated result
 */

function getComponentOption(options,component,result){
result=result||{};

if(component._inactive){
return result;
}

options=options||{};
var _options=options,
keyName=_options.keyName;
var $metaInfo=component.$metaInfo,
$options=component.$options,
$children=component.$children;// only collect option data if it exists

if($options[keyName]){
// if $metaInfo exists then [keyName] was defined as a function
// and set to the computed prop $metaInfo in the mixin
// using the computed prop should be a small performance increase
// because Vue caches those internally
var data=$metaInfo||$options[keyName];// only merge data with result when its an object
// eg it could be a function when metaInfo() returns undefined
// dueo to the or statement above

if(isObject(data)){
result=merge(result,data,options);
}
}// collect & aggregate child options if deep = true


if($children.length){
$children.forEach(function(childComponent){
// check if the childComponent is in a branch
// return otherwise so we dont walk all component branches unnecessarily
if(!inMetaInfoBranch(childComponent)){
return;
}

result=getComponentOption(options,childComponent,result);
});
}

return result;
}

var callbacks=[];
function isDOMComplete(d){
return (d||document).readyState==='complete';
}
function addCallback(query,callback){
if(arguments.length===1){
callback=query;
query='';
}

callbacks.push([query,callback]);
}
function addCallbacks(_ref,type,tags,autoAddListeners){
var tagIDKeyName=_ref.tagIDKeyName;
var hasAsyncCallback=false;
tags.forEach(function(tag){
if(!tag[tagIDKeyName]||!tag.callback){
return;
}

hasAsyncCallback=true;
addCallback("".concat(type,"[data-").concat(tagIDKeyName,"=\"").concat(tag[tagIDKeyName],"\"]"),tag.callback);
});

if(!autoAddListeners||!hasAsyncCallback){
return hasAsyncCallback;
}

return addListeners();
}
function addListeners(){
if(isDOMComplete()){
applyCallbacks();
return;
}// Instead of using a MutationObserver, we just apply

/* istanbul ignore next */


document.onreadystatechange=function(){
applyCallbacks();
};
}
function applyCallbacks(matchElement){
callbacks.forEach(function(args){
// do not use destructuring for args, it increases transpiled size
// due to var checks while we are guaranteed the structure of the cb
var query=args[0];
var callback=args[1];
var selector="".concat(query,"[onload=\"this.__vm_l=1\"]");
var elements=[];

if(!matchElement){
elements=toArray(querySelector(selector));
}

if(matchElement&&matchElement.matches(selector)){
elements=[matchElement];
}

elements.forEach(function(element){
/* __vm_cb: whether the load callback has been called
       * __vm_l: set by onload attribute, whether the element was loaded
       * __vm_ev: whether the event listener was added or not
       */
if(element.__vm_cb){
return;
}

var onload=function onload(){
/* Mark that the callback for this element has already been called,
         * this prevents the callback to run twice in some (rare) conditions
         */
element.__vm_cb=true;
/* onload needs to be removed because we only need the
         * attribute after ssr and if we dont remove it the node
         * will fail isEqualNode on the client
         */

removeAttribute(element,'onload');
callback(element);
};
/* IE9 doesnt seem to load scripts synchronously,
       * causing a script sometimes/often already to be loaded
       * when we add the event listener below (thus adding an onload event
       * listener has no use because it will never be triggered).
       * Therefore we add the onload attribute during ssr, and
       * check here if it was already loaded or not
       */


if(element.__vm_l){
onload();
return;
}

if(!element.__vm_ev){
element.__vm_ev=true;
element.addEventListener('load',onload);
}
});
});
}

// instead of adding it to the html

var attributeMap={};
/**
 * Updates the document's html tag attributes
 *
 * @param  {Object} attrs - the new document html attributes
 * @param  {HTMLElement} tag - the HTMLElement tag to update with new attrs
 */

function updateAttribute(appId,options,type,attrs,tag){
var _ref=options||{},
attribute=_ref.attribute;

var vueMetaAttrString=tag.getAttribute(attribute);

if(vueMetaAttrString){
attributeMap[type]=JSON.parse(decodeURI(vueMetaAttrString));
removeAttribute(tag,attribute);
}

var data=attributeMap[type]||{};
var toUpdate=[];// remove attributes from the map
// which have been removed for this appId

for(var attr in data){
if(data[attr]!==undefined&&appId in data[attr]){
toUpdate.push(attr);

if(!attrs[attr]){
delete data[attr][appId];
}
}
}

for(var _attr in attrs){
var attrData=data[_attr];

if(!attrData||attrData[appId]!==attrs[_attr]){
toUpdate.push(_attr);

if(attrs[_attr]!==undefined){
data[_attr]=data[_attr]||{};
data[_attr][appId]=attrs[_attr];
}
}
}

for(var _i=0,_toUpdate=toUpdate;_i<_toUpdate.length;_i++){
var _attr2=_toUpdate[_i];
var _attrData=data[_attr2];
var attrValues=[];

for(var _appId in _attrData){
Array.prototype.push.apply(attrValues,[].concat(_attrData[_appId]));
}

if(attrValues.length){
var attrValue=includes(booleanHtmlAttributes,_attr2)&&attrValues.some(Boolean)?'':attrValues.filter(function(v){
return v!==undefined;
}).join(' ');
tag.setAttribute(_attr2,attrValue);
}else {
removeAttribute(tag,_attr2);
}
}

attributeMap[type]=data;
}

/**
 * Updates the document title
 *
 * @param  {String} title - the new title of the document
 */
function updateTitle(title){
if(!title&&title!==''){
return;
}

document.title=title;
}

/**
 * Updates meta tags inside <head> and <body> on the client. Borrowed from `react-helmet`:
 * https://github.com/nfl/react-helmet/blob/004d448f8de5f823d10f838b02317521180f34da/src/Helmet.js#L195-L245
 *
 * @param  {('meta'|'base'|'link'|'style'|'script'|'noscript')} type - the name of the tag
 * @param  {(Array<Object>|Object)} tags - an array of tag objects or a single object in case of base
 * @return {Object} - a representation of what tags changed
 */

function updateTag(appId,options,type,tags,head,body){
var _ref=options||{},
attribute=_ref.attribute,
tagIDKeyName=_ref.tagIDKeyName;

var dataAttributes=commonDataAttributes.slice();
dataAttributes.push(tagIDKeyName);
var newElements=[];
var queryOptions={
appId:appId,
attribute:attribute,
type:type,
tagIDKeyName:tagIDKeyName};

var currentElements={
head:queryElements(head,queryOptions),
pbody:queryElements(body,queryOptions,{
pbody:true}),

body:queryElements(body,queryOptions,{
body:true})};



if(tags.length>1){
// remove duplicates that could have been found by merging tags
// which include a mixin with metaInfo and that mixin is used
// by multiple components on the same page
var found=[];
tags=tags.filter(function(x){
var k=JSON.stringify(x);
var res=!includes(found,k);
found.push(k);
return res;
});
}

tags.forEach(function(tag){
if(tag.skip){
return;
}

var newElement=document.createElement(type);

if(!tag.once){
newElement.setAttribute(attribute,appId);
}

Object.keys(tag).forEach(function(attr){
/* istanbul ignore next */
if(includes(tagProperties,attr)){
return;
}

if(attr==='innerHTML'){
newElement.innerHTML=tag.innerHTML;
return;
}

if(attr==='json'){
newElement.innerHTML=JSON.stringify(tag.json);
return;
}

if(attr==='cssText'){
if(newElement.styleSheet){
/* istanbul ignore next */
newElement.styleSheet.cssText=tag.cssText;
}else {
newElement.appendChild(document.createTextNode(tag.cssText));
}

return;
}

if(attr==='callback'){
newElement.onload=function(){
return tag[attr](newElement);
};

return;
}

var _attr=includes(dataAttributes,attr)?"data-".concat(attr):attr;

var isBooleanAttribute=includes(booleanHtmlAttributes,attr);

if(isBooleanAttribute&&!tag[attr]){
return;
}

var value=isBooleanAttribute?'':tag[attr];
newElement.setAttribute(_attr,value);
});
var oldElements=currentElements[getElementsKey(tag)];// Remove a duplicate tag from domTagstoRemove, so it isn't cleared.

var indexToDelete;
var hasEqualElement=oldElements.some(function(existingTag,index){
indexToDelete=index;
return newElement.isEqualNode(existingTag);
});

if(hasEqualElement&&(indexToDelete||indexToDelete===0)){
oldElements.splice(indexToDelete,1);
}else {
newElements.push(newElement);
}
});
var oldElements=[];

for(var _type in currentElements){
Array.prototype.push.apply(oldElements,currentElements[_type]);
}// remove old elements


oldElements.forEach(function(element){
element.parentNode.removeChild(element);
});// insert new elements

newElements.forEach(function(element){
if(element.hasAttribute('data-body')){
body.appendChild(element);
return;
}

if(element.hasAttribute('data-pbody')){
body.insertBefore(element,body.firstChild);
return;
}

head.appendChild(element);
});
return {
oldTags:oldElements,
newTags:newElements};

}

/**
 * Performs client-side updates when new meta info is received
 *
 * @param  {Object} newInfo - the meta info to update to
 */

function updateClientMetaInfo(appId,options,newInfo){
options=options||{};
var _options=options,
ssrAttribute=_options.ssrAttribute,
ssrAppId=_options.ssrAppId;// only cache tags for current update

var tags={};
var htmlTag=getTag(tags,'html');// if this is a server render, then dont update

if(appId===ssrAppId&&htmlTag.hasAttribute(ssrAttribute)){
// remove the server render attribute so we can update on (next) changes
removeAttribute(htmlTag,ssrAttribute);// add load callbacks if the

var addLoadListeners=false;
tagsSupportingOnload.forEach(function(type){
if(newInfo[type]&&addCallbacks(options,type,newInfo[type])){
addLoadListeners=true;
}
});

if(addLoadListeners){
addListeners();
}

return false;
}// initialize tracked changes


var tagsAdded={};
var tagsRemoved={};

for(var type in newInfo){
// ignore these
if(includes(metaInfoOptionKeys,type)){
continue;
}

if(type==='title'){
// update the title
updateTitle(newInfo.title);
continue;
}

if(includes(metaInfoAttributeKeys,type)){
var tagName=type.substr(0,4);
updateAttribute(appId,options,type,newInfo[type],getTag(tags,tagName));
continue;
}// tags should always be an array, ignore if it isnt


if(!isArray(newInfo[type])){
continue;
}

var _updateTag=updateTag(appId,options,type,newInfo[type],getTag(tags,'head'),getTag(tags,'body')),
oldTags=_updateTag.oldTags,
newTags=_updateTag.newTags;

if(newTags.length){
tagsAdded[type]=newTags;
tagsRemoved[type]=oldTags;
}
}

return {
tagsAdded:tagsAdded,
tagsRemoved:tagsRemoved};

}

var appsMetaInfo;
function addApp(rootVm,appId,options){
return {
set:function set(metaInfo){
return setMetaInfo(rootVm,appId,options,metaInfo);
},
remove:function remove(){
return removeMetaInfo(rootVm,appId,options);
}};

}
function setMetaInfo(rootVm,appId,options,metaInfo){
// if a vm exists _and_ its mounted then immediately update
if(rootVm&&rootVm.$el){
return updateClientMetaInfo(appId,options,metaInfo);
}// store for later, the info
// will be set on the first refresh


appsMetaInfo=appsMetaInfo||{};
appsMetaInfo[appId]=metaInfo;
}
function removeMetaInfo(rootVm,appId,options){
if(rootVm&&rootVm.$el){
var tags={};

var _iterator=_createForOfIteratorHelper(metaInfoAttributeKeys),
_step;

try{
for(_iterator.s();!(_step=_iterator.n()).done;){
var type=_step.value;
var tagName=type.substr(0,4);
updateAttribute(appId,options,type,{},getTag(tags,tagName));
}
}catch(err){
_iterator.e(err);
}finally{
_iterator.f();
}

return removeElementsByAppId(options,appId);
}

if(appsMetaInfo[appId]){
delete appsMetaInfo[appId];
clearAppsMetaInfo();
}
}
function getAppsMetaInfo(){
return appsMetaInfo;
}
function clearAppsMetaInfo(force){
if(force||!Object.keys(appsMetaInfo).length){
appsMetaInfo=undefined;
}
}

/**
 * Returns the correct meta info for the given component
 * (child components will overwrite parent meta info)
 *
 * @param  {Object} component - the Vue instance to get meta info from
 * @return {Object} - returned meta info
 */

function getMetaInfo(options,info,escapeSequences,component){
options=options||{};
escapeSequences=escapeSequences||[];
var _options=options,
tagIDKeyName=_options.tagIDKeyName;// Remove all "template" tags from meta
// backup the title chunk in case user wants access to it

if(info.title){
info.titleChunk=info.title;
}// replace title with populated template


if(info.titleTemplate&&info.titleTemplate!=='%s'){
applyTemplate({
component:component,
contentKeyName:'title'},
info,info.titleTemplate,info.titleChunk||'');
}// convert base tag to an array so it can be handled the same way
// as the other tags


if(info.base){
info.base=Object.keys(info.base).length?[info.base]:[];
}

if(info.meta){
// remove meta items with duplicate vmid's
info.meta=info.meta.filter(function(metaItem,index,arr){
var hasVmid=!!metaItem[tagIDKeyName];

if(!hasVmid){
return true;
}

var isFirstItemForVmid=index===findIndex(arr,function(item){
return item[tagIDKeyName]===metaItem[tagIDKeyName];
});
return isFirstItemForVmid;
});// apply templates if needed

info.meta.forEach(function(metaObject){
return applyTemplate(options,metaObject);
});
}

return escapeMetaInfo(options,info,escapeSequences);
}

/**
 * When called, will update the current meta info with new meta info.
 * Useful when updating meta info as the result of an asynchronous
 * action that resolves after the initial render takes place.
 *
 * Credit to [Sébastien Chopin](https://github.com/Atinux) for the suggestion
 * to implement this method.
 *
 * @return {Object} - new meta info
 */

function refresh(rootVm,options){
options=options||{};// make sure vue-meta was initiated

if(!rootVm[rootConfigKey]){
showWarningNotSupported();
return {};
}// collect & aggregate all metaInfo $options


var rawInfo=getComponentMetaInfo(options,rootVm);
var metaInfo=getMetaInfo(options,rawInfo,clientSequences,rootVm);
var appId=rootVm[rootConfigKey].appId;
var tags=updateClientMetaInfo(appId,options,metaInfo);// emit "event" with new info

if(tags&&isFunction(metaInfo.changed)){
metaInfo.changed(metaInfo,tags.tagsAdded,tags.tagsRemoved);
tags={
addedTags:tags.tagsAdded,
removedTags:tags.tagsRemoved};

}

var appsMetaInfo=getAppsMetaInfo();

if(appsMetaInfo){
for(var additionalAppId in appsMetaInfo){
updateClientMetaInfo(additionalAppId,options,appsMetaInfo[additionalAppId]);
delete appsMetaInfo[additionalAppId];
}

clearAppsMetaInfo(true);
}

return {
vm:rootVm,
metaInfo:metaInfo,
// eslint-disable-line object-shorthand
tags:tags};

}

/**
 * Generates tag attributes for use on the server.
 *
 * @param  {('bodyAttrs'|'htmlAttrs'|'headAttrs')} type - the type of attributes to generate
 * @param  {Object} data - the attributes to generate
 * @return {Object} - the attribute generator
 */

function attributeGenerator(options,type,data,_ref){
var addSsrAttribute=_ref.addSsrAttribute;

var _ref2=options||{},
attribute=_ref2.attribute,
ssrAttribute=_ref2.ssrAttribute;

var attributeStr='';

for(var attr in data){
var attrData=data[attr];
var attrValues=[];

for(var appId in attrData){
attrValues.push.apply(attrValues,_toConsumableArray([].concat(attrData[appId])));
}

if(attrValues.length){
attributeStr+=booleanHtmlAttributes.includes(attr)&&attrValues.some(Boolean)?"".concat(attr):"".concat(attr,"=\"").concat(attrValues.join(' '),"\"");
attributeStr+=' ';
}
}

if(attributeStr){
attributeStr+="".concat(attribute,"=\"").concat(encodeURI(JSON.stringify(data)),"\"");
}

if(type==='htmlAttrs'&&addSsrAttribute){
return "".concat(ssrAttribute).concat(attributeStr?' ':'').concat(attributeStr);
}

return attributeStr;
}

/**
 * Generates title output for the server
 *
 * @param  {'title'} type - the string "title"
 * @param  {String} data - the title text
 * @return {Object} - the title generator
 */
function titleGenerator(options,type,data,generatorOptions){
var _ref=generatorOptions||{},
ln=_ref.ln;

if(!data){
return '';
}

return "<".concat(type,">").concat(data,"</").concat(type,">").concat(ln?'\n':'');
}

/**
 * Generates meta, base, link, style, script, noscript tags for use on the server
 *
 * @param  {('meta'|'base'|'link'|'style'|'script'|'noscript')} the name of the tag
 * @param  {(Array<Object>|Object)} tags - an array of tag objects or a single object in case of base
 * @return {Object} - the tag generator
 */

function tagGenerator(options,type,tags,generatorOptions){
var _ref=options||{},
ssrAppId=_ref.ssrAppId,
attribute=_ref.attribute,
tagIDKeyName=_ref.tagIDKeyName;

var _ref2=generatorOptions||{},
appId=_ref2.appId,
_ref2$isSSR=_ref2.isSSR,
isSSR=_ref2$isSSR===void 0?true:_ref2$isSSR,
_ref2$body=_ref2.body,
body=_ref2$body===void 0?false:_ref2$body,
_ref2$pbody=_ref2.pbody,
pbody=_ref2$pbody===void 0?false:_ref2$pbody,
_ref2$ln=_ref2.ln,
ln=_ref2$ln===void 0?false:_ref2$ln;

var dataAttributes=[tagIDKeyName].concat(_toConsumableArray(commonDataAttributes));

if(!tags||!tags.length){
return '';
}// build a string containing all tags of this type


return tags.reduce(function(tagsStr,tag){
if(tag.skip){
return tagsStr;
}

var tagKeys=Object.keys(tag);

if(tagKeys.length===0){
return tagsStr;// Bail on empty tag object
}

if(Boolean(tag.body)!==body||Boolean(tag.pbody)!==pbody){
return tagsStr;
}

var attrs=tag.once?'':" ".concat(attribute,"=\"").concat(appId||(isSSR===false?'1':ssrAppId),"\"");// build a string containing all attributes of this tag

for(var attr in tag){
// these attributes are treated as children on the tag
if(tagAttributeAsInnerContent.includes(attr)||tagProperties.includes(attr)){
continue;
}

if(attr==='callback'){
attrs+=' onload="this.__vm_l=1"';
continue;
}// these form the attribute list for this tag


var prefix='';

if(dataAttributes.includes(attr)){
prefix='data-';
}

var isBooleanAttr=!prefix&&booleanHtmlAttributes.includes(attr);

if(isBooleanAttr&&!tag[attr]){
continue;
}

attrs+=" ".concat(prefix).concat(attr)+(isBooleanAttr?'':"=\"".concat(tag[attr],"\""));
}

var json='';

if(tag.json){
json=JSON.stringify(tag.json);
}// grab child content from one of these attributes, if possible


var content=tag.innerHTML||tag.cssText||json;// generate tag exactly without any other redundant attribute
// these tags have no end tag

var hasEndTag=!tagsWithoutEndTag.includes(type);// these tag types will have content inserted

var hasContent=hasEndTag&&tagsWithInnerContent.includes(type);// the final string for this specific tag

return "".concat(tagsStr,"<").concat(type).concat(attrs).concat(!hasContent&&hasEndTag?'/':'',">")+(hasContent?"".concat(content,"</").concat(type,">"):'')+(ln?'\n':'');
},'');
}

/**
 * Converts a meta info property to one that can be stringified on the server
 *
 * @param  {String} type - the type of data to convert
 * @param  {(String|Object|Array<Object>)} data - the data value
 * @return {Object} - the new injector
 */

function generateServerInjector(options,metaInfo,globalInjectOptions){
var serverInjector={
data:metaInfo,
extraData:undefined,
addInfo:function addInfo(appId,metaInfo){
this.extraData=this.extraData||{};
this.extraData[appId]=metaInfo;
},
callInjectors:function callInjectors(opts){
var m=this.injectors;// only call title for the head

return (opts.body||opts.pbody?'':m.title.text(opts))+m.meta.text(opts)+m.base.text(opts)+m.link.text(opts)+m.style.text(opts)+m.script.text(opts)+m.noscript.text(opts);
},
injectors:{
head:function head(ln){
return serverInjector.callInjectors(_objectSpread2(_objectSpread2({},globalInjectOptions),{},{
ln:ln}));

},
bodyPrepend:function bodyPrepend(ln){
return serverInjector.callInjectors(_objectSpread2(_objectSpread2({},globalInjectOptions),{},{
ln:ln,
pbody:true}));

},
bodyAppend:function bodyAppend(ln){
return serverInjector.callInjectors(_objectSpread2(_objectSpread2({},globalInjectOptions),{},{
ln:ln,
body:true}));

}}};



var _loop=function _loop(type){
if(metaInfoOptionKeys.includes(type)){
return "continue";
}

serverInjector.injectors[type]={
text:function text(injectOptions){
var addSsrAttribute=injectOptions===true;
injectOptions=_objectSpread2(_objectSpread2({
addSsrAttribute:addSsrAttribute},
globalInjectOptions),injectOptions);

if(type==='title'){
return titleGenerator(options,type,serverInjector.data[type],injectOptions);
}

if(metaInfoAttributeKeys.includes(type)){
var attributeData={};
var data=serverInjector.data[type];

if(data){
var appId=injectOptions.isSSR===false?'1':options.ssrAppId;

for(var attr in data){
attributeData[attr]=_defineProperty({},appId,data[attr]);
}
}

if(serverInjector.extraData){
for(var _appId in serverInjector.extraData){
var _data=serverInjector.extraData[_appId][type];

if(_data){
for(var _attr in _data){
attributeData[_attr]=_objectSpread2(_objectSpread2({},attributeData[_attr]),{},_defineProperty({},_appId,_data[_attr]));
}
}
}
}

return attributeGenerator(options,type,attributeData,injectOptions);
}

var str=tagGenerator(options,type,serverInjector.data[type],injectOptions);

if(serverInjector.extraData){
for(var _appId2 in serverInjector.extraData){
var _data2=serverInjector.extraData[_appId2][type];
var extraStr=tagGenerator(options,type,_data2,_objectSpread2({
appId:_appId2},
injectOptions));
str="".concat(str).concat(extraStr);
}
}

return str;
}};

};

for(var type in defaultInfo){
var _ret=_loop(type);

if(_ret==="continue")continue;
}

return serverInjector;
}

/**
 * Converts the state of the meta info object such that each item
 * can be compiled to a tag string on the server
 *
 * @vm {Object} - Vue instance - ideally the root component
 * @return {Object} - server meta info with `toString` methods
 */

function inject(rootVm,options,injectOptions){
// make sure vue-meta was initiated
if(!rootVm[rootConfigKey]){
showWarningNotSupported();
return {};
}// collect & aggregate all metaInfo $options


var rawInfo=getComponentMetaInfo(options,rootVm);
var metaInfo=getMetaInfo(options,rawInfo,serverSequences,rootVm);// generate server injector

var serverInjector=generateServerInjector(options,metaInfo,injectOptions);// add meta info from additional apps

var appsMetaInfo=getAppsMetaInfo();

if(appsMetaInfo){
for(var additionalAppId in appsMetaInfo){
serverInjector.addInfo(additionalAppId,appsMetaInfo[additionalAppId]);
delete appsMetaInfo[additionalAppId];
}

clearAppsMetaInfo(true);
}

return serverInjector.injectors;
}

function $meta(options){
options=options||{};
/**
   * Returns an injector for server-side rendering.
   * @this {Object} - the Vue instance (a root component)
   * @return {Object} - injector
   */

var $root=this.$root;
return {
getOptions:function getOptions$1(){
return getOptions(options);
},
setOptions:function setOptions(newOptions){
var refreshNavKey='refreshOnceOnNavigation';

if(newOptions&&newOptions[refreshNavKey]){
options.refreshOnceOnNavigation=!!newOptions[refreshNavKey];
addNavGuards($root);
}

var debounceWaitKey='debounceWait';

if(newOptions&&debounceWaitKey in newOptions){
var debounceWait=parseInt(newOptions[debounceWaitKey]);

if(!isNaN(debounceWait)){
options.debounceWait=debounceWait;
}
}

var waitOnDestroyedKey='waitOnDestroyed';

if(newOptions&&waitOnDestroyedKey in newOptions){
options.waitOnDestroyed=!!newOptions[waitOnDestroyedKey];
}
},
refresh:function refresh$1(){
return refresh($root,options);
},
inject:function inject$1(injectOptions){
return inject($root,options,injectOptions);
},
pause:function pause$1(){
return pause($root);
},
resume:function resume$1(){
return resume($root);
},
addApp:function addApp$1(appId){
return addApp($root,appId,options);
}};

}

function generate(rawInfo,options){
options=setOptions(options);
var metaInfo=getMetaInfo(options,rawInfo,serverSequences);
var serverInjector=generateServerInjector(options,metaInfo);
return serverInjector.injectors;
}

/**
 * Plugin install function.
 * @param {Function} Vue - the Vue constructor.
 */

function install(Vue,options){
if(Vue.__vuemeta_installed){
return;
}

Vue.__vuemeta_installed=true;
options=setOptions(options);

Vue.prototype.$meta=function(){
return $meta.call(this,options);
};

Vue.mixin(createMixin(Vue,options));
}

var index={
version:version,
install:install,
generate:function generate$1(metaInfo,options){
return generate(metaInfo,options);
},
hasMetaInfo:hasMetaInfo};


/* harmony default export */__webpack_exports__["default"]=index;

/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"));

/***/},

/***/"./node_modules/vue-meta/node_modules/deepmerge/dist/cjs.js":
/*!******************************************************************!*\
  !*** ./node_modules/vue-meta/node_modules/deepmerge/dist/cjs.js ***!
  \******************************************************************/
/*! no static exports found */
/***/function node_modulesVueMetaNode_modulesDeepmergeDistCjsJs(module,exports,__webpack_require__){


var isMergeableObject=function isMergeableObject(value){
return isNonNullObject(value)&&
!isSpecial(value);
};

function isNonNullObject(value){
return !!value&&typeof value==='object';
}

function isSpecial(value){
var stringValue=Object.prototype.toString.call(value);

return stringValue==='[object RegExp]'||
stringValue==='[object Date]'||
isReactElement(value);
}

// see https://github.com/facebook/react/blob/b5ac963fb791d1298e7f396236383bc955f916c1/src/isomorphic/classic/element/ReactElement.js#L21-L25
var canUseSymbol=typeof Symbol==='function'&&Symbol.for;
var REACT_ELEMENT_TYPE=canUseSymbol?Symbol.for('react.element'):0xeac7;

function isReactElement(value){
return value.$$typeof===REACT_ELEMENT_TYPE;
}

function emptyTarget(val){
return Array.isArray(val)?[]:{};
}

function cloneUnlessOtherwiseSpecified(value,options){
return options.clone!==false&&options.isMergeableObject(value)?
deepmerge(emptyTarget(value),value,options):
value;
}

function defaultArrayMerge(target,source,options){
return target.concat(source).map(function(element){
return cloneUnlessOtherwiseSpecified(element,options);
});
}

function getMergeFunction(key,options){
if(!options.customMerge){
return deepmerge;
}
var customMerge=options.customMerge(key);
return typeof customMerge==='function'?customMerge:deepmerge;
}

function getEnumerableOwnPropertySymbols(target){
return Object.getOwnPropertySymbols?
Object.getOwnPropertySymbols(target).filter(function(symbol){
return target.propertyIsEnumerable(symbol);
}):
[];
}

function getKeys(target){
return Object.keys(target).concat(getEnumerableOwnPropertySymbols(target));
}

function propertyIsOnObject(object,property){
try{
return property in object;
}catch(_){
return false;
}
}

// Protects from prototype poisoning and unexpected merging up the prototype chain.
function propertyIsUnsafe(target,key){
return propertyIsOnObject(target,key)// Properties are safe to merge if they don't exist in the target yet,
&&!(Object.hasOwnProperty.call(target,key)// unsafe if they exist up the prototype chain,
&&Object.propertyIsEnumerable.call(target,key));// and also unsafe if they're nonenumerable.
}

function mergeObject(target,source,options){
var destination={};
if(options.isMergeableObject(target)){
getKeys(target).forEach(function(key){
destination[key]=cloneUnlessOtherwiseSpecified(target[key],options);
});
}
getKeys(source).forEach(function(key){
if(propertyIsUnsafe(target,key)){
return;
}

if(propertyIsOnObject(target,key)&&options.isMergeableObject(source[key])){
destination[key]=getMergeFunction(key,options)(target[key],source[key],options);
}else {
destination[key]=cloneUnlessOtherwiseSpecified(source[key],options);
}
});
return destination;
}

function deepmerge(target,source,options){
options=options||{};
options.arrayMerge=options.arrayMerge||defaultArrayMerge;
options.isMergeableObject=options.isMergeableObject||isMergeableObject;
// cloneUnlessOtherwiseSpecified is added to `options` so that custom arrayMerge()
// implementations can use it. The caller may not replace it.
options.cloneUnlessOtherwiseSpecified=cloneUnlessOtherwiseSpecified;

var sourceIsArray=Array.isArray(source);
var targetIsArray=Array.isArray(target);
var sourceAndTargetTypesMatch=sourceIsArray===targetIsArray;

if(!sourceAndTargetTypesMatch){
return cloneUnlessOtherwiseSpecified(source,options);
}else if(sourceIsArray){
return options.arrayMerge(target,source,options);
}else {
return mergeObject(target,source,options);
}
}

deepmerge.all=function deepmergeAll(array,options){
if(!Array.isArray(array)){
throw new Error('first argument should be an array');
}

return array.reduce(function(prev,next){
return deepmerge(prev,next,options);
},{});
};

var deepmerge_1=deepmerge;

module.exports=deepmerge_1;


/***/},

/***/"./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.common.js":
/*!***********************************************************************************!*\
  !*** ./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.common.js ***!
  \***********************************************************************************/
/*! no static exports found */
/***/function node_modulesVueMjDaterangepickerDistVueMjDaterangepickerCommonJs(module,exports,__webpack_require__){

module.exports=
/******/function(modules){// webpackBootstrap
/******/ // The module cache
/******/var installedModules={};
/******/
/******/ // The require function
/******/function __webpack_require__(moduleId){
/******/
/******/ // Check if module is in cache
/******/if(installedModules[moduleId]){
/******/return installedModules[moduleId].exports;
/******/}
/******/ // Create a new module (and put it into the cache)
/******/var module=installedModules[moduleId]={
/******/i:moduleId,
/******/l:false,
/******/exports:{}
/******/};
/******/
/******/ // Execute the module function
/******/modules[moduleId].call(module.exports,module,module.exports,__webpack_require__);
/******/
/******/ // Flag the module as loaded
/******/module.l=true;
/******/
/******/ // Return the exports of the module
/******/return module.exports;
/******/}
/******/
/******/
/******/ // expose the modules object (__webpack_modules__)
/******/__webpack_require__.m=modules;
/******/
/******/ // expose the module cache
/******/__webpack_require__.c=installedModules;
/******/
/******/ // define getter function for harmony exports
/******/__webpack_require__.d=function(exports,name,getter){
/******/if(!__webpack_require__.o(exports,name)){
/******/Object.defineProperty(exports,name,{enumerable:true,get:getter});
/******/}
/******/};
/******/
/******/ // define __esModule on exports
/******/__webpack_require__.r=function(exports){
/******/if(typeof Symbol!=='undefined'&&Symbol.toStringTag){
/******/Object.defineProperty(exports,Symbol.toStringTag,{value:'Module'});
/******/}
/******/Object.defineProperty(exports,'__esModule',{value:true});
/******/};
/******/
/******/ // create a fake namespace object
/******/ // mode & 1: value is a module id, require it
/******/ // mode & 2: merge all properties of value into the ns
/******/ // mode & 4: return value when already ns object
/******/ // mode & 8|1: behave like require
/******/__webpack_require__.t=function(value,mode){
/******/if(mode&1)value=__webpack_require__(value);
/******/if(mode&8)return value;
/******/if(mode&4&&typeof value==='object'&&value&&value.__esModule)return value;
/******/var ns=Object.create(null);
/******/__webpack_require__.r(ns);
/******/Object.defineProperty(ns,'default',{enumerable:true,value:value});
/******/if(mode&2&&typeof value!='string')for(var key in value){__webpack_require__.d(ns,key,function(key){return value[key];}.bind(null,key));}
/******/return ns;
/******/};
/******/
/******/ // getDefaultExport function for compatibility with non-harmony modules
/******/__webpack_require__.n=function(module){
/******/var getter=module&&module.__esModule?
/******/function getDefault(){return module['default'];}:
/******/function getModuleExports(){return module;};
/******/__webpack_require__.d(getter,'a',getter);
/******/return getter;
/******/};
/******/
/******/ // Object.prototype.hasOwnProperty.call
/******/__webpack_require__.o=function(object,property){return Object.prototype.hasOwnProperty.call(object,property);};
/******/
/******/ // __webpack_public_path__
/******/__webpack_require__.p="";
/******/
/******/
/******/ // Load entry module and return exports
/******/return __webpack_require__(__webpack_require__.s="fb15");
/******/}(
/************************************************************************/
/******/{

/***/"014b":
/***/function b(module,exports,__webpack_require__){

// ECMAScript 6 symbols shim
var global=__webpack_require__("e53d");
var has=__webpack_require__("07e3");
var DESCRIPTORS=__webpack_require__("8e60");
var $export=__webpack_require__("63b6");
var redefine=__webpack_require__("9138");
var META=__webpack_require__("ebfd").KEY;
var $fails=__webpack_require__("294c");
var shared=__webpack_require__("dbdb");
var setToStringTag=__webpack_require__("45f2");
var uid=__webpack_require__("62a0");
var wks=__webpack_require__("5168");
var wksExt=__webpack_require__("ccb9");
var wksDefine=__webpack_require__("6718");
var enumKeys=__webpack_require__("47ee");
var isArray=__webpack_require__("9003");
var anObject=__webpack_require__("e4ae");
var isObject=__webpack_require__("f772");
var toObject=__webpack_require__("241e");
var toIObject=__webpack_require__("36c3");
var toPrimitive=__webpack_require__("1bc3");
var createDesc=__webpack_require__("aebd");
var _create=__webpack_require__("a159");
var gOPNExt=__webpack_require__("0395");
var $GOPD=__webpack_require__("bf0b");
var $GOPS=__webpack_require__("9aa9");
var $DP=__webpack_require__("d9f6");
var $keys=__webpack_require__("c3a1");
var gOPD=$GOPD.f;
var dP=$DP.f;
var gOPN=gOPNExt.f;
var $Symbol=global.Symbol;
var $JSON=global.JSON;
var _stringify=$JSON&&$JSON.stringify;
var PROTOTYPE='prototype';
var HIDDEN=wks('_hidden');
var TO_PRIMITIVE=wks('toPrimitive');
var isEnum={}.propertyIsEnumerable;
var SymbolRegistry=shared('symbol-registry');
var AllSymbols=shared('symbols');
var OPSymbols=shared('op-symbols');
var ObjectProto=Object[PROTOTYPE];
var USE_NATIVE=typeof $Symbol=='function'&&!!$GOPS.f;
var QObject=global.QObject;
// Don't use setters in Qt Script, https://github.com/zloirock/core-js/issues/173
var setter=!QObject||!QObject[PROTOTYPE]||!QObject[PROTOTYPE].findChild;

// fallback for old Android, https://code.google.com/p/v8/issues/detail?id=687
var setSymbolDesc=DESCRIPTORS&&$fails(function(){
return _create(dP({},'a',{
get:function get(){return dP(this,'a',{value:7}).a;}})).
a!=7;
})?function(it,key,D){
var protoDesc=gOPD(ObjectProto,key);
if(protoDesc)delete ObjectProto[key];
dP(it,key,D);
if(protoDesc&&it!==ObjectProto)dP(ObjectProto,key,protoDesc);
}:dP;

var wrap=function wrap(tag){
var sym=AllSymbols[tag]=_create($Symbol[PROTOTYPE]);
sym._k=tag;
return sym;
};

var isSymbol=USE_NATIVE&&typeof $Symbol.iterator=='symbol'?function(it){
return typeof it=='symbol';
}:function(it){
return it instanceof $Symbol;
};

var $defineProperty=function defineProperty(it,key,D){
if(it===ObjectProto)$defineProperty(OPSymbols,key,D);
anObject(it);
key=toPrimitive(key,true);
anObject(D);
if(has(AllSymbols,key)){
if(!D.enumerable){
if(!has(it,HIDDEN))dP(it,HIDDEN,createDesc(1,{}));
it[HIDDEN][key]=true;
}else {
if(has(it,HIDDEN)&&it[HIDDEN][key])it[HIDDEN][key]=false;
D=_create(D,{enumerable:createDesc(0,false)});
}return setSymbolDesc(it,key,D);
}return dP(it,key,D);
};
var $defineProperties=function defineProperties(it,P){
anObject(it);
var keys=enumKeys(P=toIObject(P));
var i=0;
var l=keys.length;
var key;
while(l>i){$defineProperty(it,key=keys[i++],P[key]);}
return it;
};
var $create=function create(it,P){
return P===undefined?_create(it):$defineProperties(_create(it),P);
};
var $propertyIsEnumerable=function propertyIsEnumerable(key){
var E=isEnum.call(this,key=toPrimitive(key,true));
if(this===ObjectProto&&has(AllSymbols,key)&&!has(OPSymbols,key))return false;
return E||!has(this,key)||!has(AllSymbols,key)||has(this,HIDDEN)&&this[HIDDEN][key]?E:true;
};
var $getOwnPropertyDescriptor=function getOwnPropertyDescriptor(it,key){
it=toIObject(it);
key=toPrimitive(key,true);
if(it===ObjectProto&&has(AllSymbols,key)&&!has(OPSymbols,key))return;
var D=gOPD(it,key);
if(D&&has(AllSymbols,key)&&!(has(it,HIDDEN)&&it[HIDDEN][key]))D.enumerable=true;
return D;
};
var $getOwnPropertyNames=function getOwnPropertyNames(it){
var names=gOPN(toIObject(it));
var result=[];
var i=0;
var key;
while(names.length>i){
if(!has(AllSymbols,key=names[i++])&&key!=HIDDEN&&key!=META)result.push(key);
}return result;
};
var $getOwnPropertySymbols=function getOwnPropertySymbols(it){
var IS_OP=it===ObjectProto;
var names=gOPN(IS_OP?OPSymbols:toIObject(it));
var result=[];
var i=0;
var key;
while(names.length>i){
if(has(AllSymbols,key=names[i++])&&(IS_OP?has(ObjectProto,key):true))result.push(AllSymbols[key]);
}return result;
};

// 19.4.1.1 Symbol([description])
if(!USE_NATIVE){
$Symbol=function Symbol(){
if(this instanceof $Symbol)throw TypeError('Symbol is not a constructor!');
var tag=uid(arguments.length>0?arguments[0]:undefined);
var $set=function $set(value){
if(this===ObjectProto)$set.call(OPSymbols,value);
if(has(this,HIDDEN)&&has(this[HIDDEN],tag))this[HIDDEN][tag]=false;
setSymbolDesc(this,tag,createDesc(1,value));
};
if(DESCRIPTORS&&setter)setSymbolDesc(ObjectProto,tag,{configurable:true,set:$set});
return wrap(tag);
};
redefine($Symbol[PROTOTYPE],'toString',function toString(){
return this._k;
});

$GOPD.f=$getOwnPropertyDescriptor;
$DP.f=$defineProperty;
__webpack_require__("6abf").f=gOPNExt.f=$getOwnPropertyNames;
__webpack_require__("355d").f=$propertyIsEnumerable;
$GOPS.f=$getOwnPropertySymbols;

if(DESCRIPTORS&&!__webpack_require__("b8e3")){
redefine(ObjectProto,'propertyIsEnumerable',$propertyIsEnumerable,true);
}

wksExt.f=function(name){
return wrap(wks(name));
};
}

$export($export.G+$export.W+$export.F*!USE_NATIVE,{Symbol:$Symbol});

for(var es6Symbols=
// 19.4.2.2, 19.4.2.3, 19.4.2.4, 19.4.2.6, 19.4.2.8, 19.4.2.9, 19.4.2.10, 19.4.2.11, 19.4.2.12, 19.4.2.13, 19.4.2.14
'hasInstance,isConcatSpreadable,iterator,match,replace,search,species,split,toPrimitive,toStringTag,unscopables'.
split(','),j=0;es6Symbols.length>j;){wks(es6Symbols[j++]);}

for(var wellKnownSymbols=$keys(wks.store),k=0;wellKnownSymbols.length>k;){wksDefine(wellKnownSymbols[k++]);}

$export($export.S+$export.F*!USE_NATIVE,'Symbol',{
// 19.4.2.1 Symbol.for(key)
'for':function _for(key){
return has(SymbolRegistry,key+='')?
SymbolRegistry[key]:
SymbolRegistry[key]=$Symbol(key);
},
// 19.4.2.5 Symbol.keyFor(sym)
keyFor:function keyFor(sym){
if(!isSymbol(sym))throw TypeError(sym+' is not a symbol!');
for(var key in SymbolRegistry){if(SymbolRegistry[key]===sym)return key;}
},
useSetter:function useSetter(){setter=true;},
useSimple:function useSimple(){setter=false;}});


$export($export.S+$export.F*!USE_NATIVE,'Object',{
// 19.1.2.2 Object.create(O [, Properties])
create:$create,
// 19.1.2.4 Object.defineProperty(O, P, Attributes)
defineProperty:$defineProperty,
// 19.1.2.3 Object.defineProperties(O, Properties)
defineProperties:$defineProperties,
// 19.1.2.6 Object.getOwnPropertyDescriptor(O, P)
getOwnPropertyDescriptor:$getOwnPropertyDescriptor,
// 19.1.2.7 Object.getOwnPropertyNames(O)
getOwnPropertyNames:$getOwnPropertyNames,
// 19.1.2.8 Object.getOwnPropertySymbols(O)
getOwnPropertySymbols:$getOwnPropertySymbols});


// Chrome 38 and 39 `Object.getOwnPropertySymbols` fails on primitives
// https://bugs.chromium.org/p/v8/issues/detail?id=3443
var FAILS_ON_PRIMITIVES=$fails(function(){$GOPS.f(1);});

$export($export.S+$export.F*FAILS_ON_PRIMITIVES,'Object',{
getOwnPropertySymbols:function getOwnPropertySymbols(it){
return $GOPS.f(toObject(it));
}});


// 24.3.2 JSON.stringify(value [, replacer [, space]])
$JSON&&$export($export.S+$export.F*(!USE_NATIVE||$fails(function(){
var S=$Symbol();
// MS Edge converts symbol values to JSON as {}
// WebKit converts symbol values to JSON as null
// V8 throws on boxed symbols
return _stringify([S])!='[null]'||_stringify({a:S})!='{}'||_stringify(Object(S))!='{}';
})),'JSON',{
stringify:function stringify(it){
var args=[it];
var i=1;
var replacer,$replacer;
while(arguments.length>i){args.push(arguments[i++]);}
$replacer=replacer=args[1];
if(!isObject(replacer)&&it===undefined||isSymbol(it))return;// IE8 returns string on undefined
if(!isArray(replacer))replacer=function replacer(key,value){
if(typeof $replacer=='function')value=$replacer.call(this,key,value);
if(!isSymbol(value))return value;
};
args[1]=replacer;
return _stringify.apply($JSON,args);
}});


// 19.4.3.4 Symbol.prototype[@@toPrimitive](hint)
$Symbol[PROTOTYPE][TO_PRIMITIVE]||__webpack_require__("35e8")($Symbol[PROTOTYPE],TO_PRIMITIVE,$Symbol[PROTOTYPE].valueOf);
// 19.4.3.5 Symbol.prototype[@@toStringTag]
setToStringTag($Symbol,'Symbol');
// 20.2.1.9 Math[@@toStringTag]
setToStringTag(Math,'Math',true);
// 24.3.3 JSON[@@toStringTag]
setToStringTag(global.JSON,'JSON',true);


/***/},

/***/"0157":
/***/function _(module,exports,__webpack_require__){

var isSameHour=__webpack_require__("662a");

/**
 * @category Hour Helpers
 * @summary Is the given date in the same hour as the current date?
 *
 * @description
 * Is the given date in the same hour as the current date?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this hour
 *
 * @example
 * // If now is 25 September 2014 18:30:15.500,
 * // is 25 September 2014 18:00:00 in this hour?
 * var result = isThisHour(new Date(2014, 8, 25, 18))
 * //=> true
 */
function isThisHour(dirtyDate){
return isSameHour(new Date(),dirtyDate);
}

module.exports=isThisHour;


/***/},

/***/"01f9":
/***/function f9(module,exports,__webpack_require__){

var LIBRARY=__webpack_require__("2d00");
var $export=__webpack_require__("5ca1");
var redefine=__webpack_require__("2aba");
var hide=__webpack_require__("32e9");
var Iterators=__webpack_require__("84f2");
var $iterCreate=__webpack_require__("41a0");
var setToStringTag=__webpack_require__("7f20");
var getPrototypeOf=__webpack_require__("38fd");
var ITERATOR=__webpack_require__("2b4c")('iterator');
var BUGGY=!([].keys&&'next'in[].keys());// Safari has buggy iterators w/o `next`
var FF_ITERATOR='@@iterator';
var KEYS='keys';
var VALUES='values';

var returnThis=function returnThis(){return this;};

module.exports=function(Base,NAME,Constructor,next,DEFAULT,IS_SET,FORCED){
$iterCreate(Constructor,NAME,next);
var getMethod=function getMethod(kind){
if(!BUGGY&&kind in proto)return proto[kind];
switch(kind){
case KEYS:return function keys(){return new Constructor(this,kind);};
case VALUES:return function values(){return new Constructor(this,kind);};}
return function entries(){return new Constructor(this,kind);};
};
var TAG=NAME+' Iterator';
var DEF_VALUES=DEFAULT==VALUES;
var VALUES_BUG=false;
var proto=Base.prototype;
var $native=proto[ITERATOR]||proto[FF_ITERATOR]||DEFAULT&&proto[DEFAULT];
var $default=$native||getMethod(DEFAULT);
var $entries=DEFAULT?!DEF_VALUES?$default:getMethod('entries'):undefined;
var $anyNative=NAME=='Array'?proto.entries||$native:$native;
var methods,key,IteratorPrototype;
// Fix native
if($anyNative){
IteratorPrototype=getPrototypeOf($anyNative.call(new Base()));
if(IteratorPrototype!==Object.prototype&&IteratorPrototype.next){
// Set @@toStringTag to native iterators
setToStringTag(IteratorPrototype,TAG,true);
// fix for some old engines
if(!LIBRARY&&typeof IteratorPrototype[ITERATOR]!='function')hide(IteratorPrototype,ITERATOR,returnThis);
}
}
// fix Array#{values, @@iterator}.name in V8 / FF
if(DEF_VALUES&&$native&&$native.name!==VALUES){
VALUES_BUG=true;
$default=function values(){return $native.call(this);};
}
// Define iterator
if((!LIBRARY||FORCED)&&(BUGGY||VALUES_BUG||!proto[ITERATOR])){
hide(proto,ITERATOR,$default);
}
// Plug for library
Iterators[NAME]=$default;
Iterators[TAG]=returnThis;
if(DEFAULT){
methods={
values:DEF_VALUES?$default:getMethod(VALUES),
keys:IS_SET?$default:getMethod(KEYS),
entries:$entries};

if(FORCED)for(key in methods){
if(!(key in proto))redefine(proto,key,methods[key]);
}else $export($export.P+$export.F*(BUGGY||VALUES_BUG),NAME,methods);
}
return methods;
};


/***/},

/***/"0293":
/***/function _(module,exports,__webpack_require__){

// 19.1.2.9 Object.getPrototypeOf(O)
var toObject=__webpack_require__("241e");
var $getPrototypeOf=__webpack_require__("53e2");

__webpack_require__("ce7e")('getPrototypeOf',function(){
return function getPrototypeOf(it){
return $getPrototypeOf(toObject(it));
};
});


/***/},

/***/"038a":
/***/function a(module,exports){

module.exports=
/******/function(modules){// webpackBootstrap
/******/ // The module cache
/******/var installedModules={};
/******/
/******/ // The require function
/******/function __webpack_require__(moduleId){
/******/
/******/ // Check if module is in cache
/******/if(installedModules[moduleId]){
/******/return installedModules[moduleId].exports;
/******/}
/******/ // Create a new module (and put it into the cache)
/******/var module=installedModules[moduleId]={
/******/i:moduleId,
/******/l:false,
/******/exports:{}
/******/};
/******/
/******/ // Execute the module function
/******/modules[moduleId].call(module.exports,module,module.exports,__webpack_require__);
/******/
/******/ // Flag the module as loaded
/******/module.l=true;
/******/
/******/ // Return the exports of the module
/******/return module.exports;
/******/}
/******/
/******/
/******/ // expose the modules object (__webpack_modules__)
/******/__webpack_require__.m=modules;
/******/
/******/ // expose the module cache
/******/__webpack_require__.c=installedModules;
/******/
/******/ // define getter function for harmony exports
/******/__webpack_require__.d=function(exports,name,getter){
/******/if(!__webpack_require__.o(exports,name)){
/******/Object.defineProperty(exports,name,{enumerable:true,get:getter});
/******/}
/******/};
/******/
/******/ // define __esModule on exports
/******/__webpack_require__.r=function(exports){
/******/if(typeof Symbol!=='undefined'&&Symbol.toStringTag){
/******/Object.defineProperty(exports,Symbol.toStringTag,{value:'Module'});
/******/}
/******/Object.defineProperty(exports,'__esModule',{value:true});
/******/};
/******/
/******/ // create a fake namespace object
/******/ // mode & 1: value is a module id, require it
/******/ // mode & 2: merge all properties of value into the ns
/******/ // mode & 4: return value when already ns object
/******/ // mode & 8|1: behave like require
/******/__webpack_require__.t=function(value,mode){
/******/if(mode&1)value=__webpack_require__(value);
/******/if(mode&8)return value;
/******/if(mode&4&&typeof value==='object'&&value&&value.__esModule)return value;
/******/var ns=Object.create(null);
/******/__webpack_require__.r(ns);
/******/Object.defineProperty(ns,'default',{enumerable:true,value:value});
/******/if(mode&2&&typeof value!='string')for(var key in value){__webpack_require__.d(ns,key,function(key){return value[key];}.bind(null,key));}
/******/return ns;
/******/};
/******/
/******/ // getDefaultExport function for compatibility with non-harmony modules
/******/__webpack_require__.n=function(module){
/******/var getter=module&&module.__esModule?
/******/function getDefault(){return module['default'];}:
/******/function getModuleExports(){return module;};
/******/__webpack_require__.d(getter,'a',getter);
/******/return getter;
/******/};
/******/
/******/ // Object.prototype.hasOwnProperty.call
/******/__webpack_require__.o=function(object,property){return Object.prototype.hasOwnProperty.call(object,property);};
/******/
/******/ // __webpack_public_path__
/******/__webpack_require__.p="";
/******/
/******/
/******/ // Load entry module and return exports
/******/return __webpack_require__(__webpack_require__.s="fb15");
/******/}(
/************************************************************************/
/******/{

/***/"1eb2":
/***/function eb2(module,exports,__webpack_require__){

// This file is imported into lib/wc client bundles.

if(typeof window!=='undefined'){
var i;
if((i=window.document.currentScript)&&(i=i.src.match(/(.+\/)[^/]+\.js$/))){
__webpack_require__.p=i[1];// eslint-disable-line
}
}


/***/},

/***/"fb15":
/***/function fb15(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);

// EXTERNAL MODULE: ./node_modules/@vue/cli-service/lib/commands/build/setPublicPath.js
var setPublicPath=__webpack_require__("1eb2");

// CONCATENATED MODULE: ./node_modules/cache-loader/dist/cjs.js?{"cacheDirectory":"node_modules/.cache/vue-loader","cacheIdentifier":"02e834b4-vue-loader-template"}!./node_modules/vue-loader/lib/loaders/templateLoader.js??vue-loader-options!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader/lib??vue-loader-options!./src/components/SvgIcon.vue?vue&type=template&id=03042cba&
var render=function render(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('svg',{class:_vm.clazz,style:_vm.style,attrs:{"version":"1.1","viewBox":_vm.box},domProps:{"innerHTML":_vm._s(_vm.path)},on:{"click":_vm.onClick}});};
var staticRenderFns=[];


// CONCATENATED MODULE: ./src/components/SvgIcon.vue?vue&type=template&id=03042cba&

// CONCATENATED MODULE: ./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/thread-loader/dist/cjs.js!./node_modules/babel-loader/lib!./node_modules/vue-loader/lib??vue-loader-options!./src/components/SvgIcon.vue?vue&type=script&lang=js&
//
//
//
//
var icons={};
var notLoadedIcons=[];
var defaultWidth='';
var defaultHeight='';
var classPrefix='svg';
var isStroke=false;
var isOriginalDefault=false;
/* harmony default export */var SvgIconvue_type_script_lang_js_={
data:function data(){
return {
loaded:false};

},
props:{
icon:String,
name:String,
width:{
type:String,
default:''},

height:{
type:String,
default:''},

scale:String,
dir:String,
fill:{
type:Boolean,
default:function _default(){
return !isStroke;
}},

color:String,
original:{
type:Boolean,
default:function _default(){
return isOriginalDefault;
}},

title:String},

computed:{
clazz:function clazz(){
var clazz="".concat(classPrefix,"-icon");

if(this.fill){
clazz+=" ".concat(classPrefix,"-fill");
}

if(this.dir){
clazz+=" ".concat(classPrefix,"-").concat(this.dir);
}

return clazz;
},
iconName:function iconName(){
return this.name||this.icon;
},
iconData:function iconData(){
var iconData=icons[this.iconName];

if(iconData||this.loaded){
return iconData;
}

return null;
},
colors:function colors(){
if(this.color){
return this.color.split(' ');
}

return [];
},
path:function path(){
var pathData='';

if(this.iconData){
pathData=this.iconData.data;
pathData=this.setTitle(pathData);// use original color

if(this.original){
pathData=this.addOriginalColor(pathData);
}

if(this.colors.length>0){
pathData=this.addColor(pathData);
}
}else {
// if no iconData, push to notLoadedIcons
notLoadedIcons.push({
name:this.iconName,
component:this});

}

return this.getValidPathData(pathData);
},
box:function box(){
var width=this.width||16;
var height=this.width||16;

if(this.iconData){
if(this.iconData.viewBox){
return this.iconData.viewBox;
}

return "0 0 ".concat(this.iconData.width," ").concat(this.iconData.height);
}

return "0 0 ".concat(parseFloat(width)," ").concat(parseFloat(height));
},
style:function style(){
var digitReg=/^\d+$/;
var scale=Number(this.scale);
var width;
var height;// apply scale

if(!isNaN(scale)&&this.iconData){
width=Number(this.iconData.width)*scale+'px';
height=Number(this.iconData.height)*scale+'px';
}else {
width=digitReg.test(this.width)?this.width+'px':this.width||defaultWidth;
height=digitReg.test(this.height)?this.height+'px':this.height||defaultWidth;
}

var style={};

if(width){
style.width=width;
}

if(height){
style.height=height;
}

return style;
}},

created:function created(){
if(icons[this.iconName]){
this.loaded=true;
}
},
methods:{
addColor:function addColor(data){
var _this=this;

var reg=/<(path|rect|circle|polygon|line|polyline|ellipse)\s/gi;
var i=0;
return data.replace(reg,function(match){
var color=_this.colors[i++]||_this.colors[_this.colors.length-1];
var fill=_this.fill;// if color is '_', ignore it

if(color&&color==='_'){
return match;
}// if color start with 'r-', reverse the fill value


if(color&&color.indexOf('r-')===0){
fill=!fill;
color=color.split('r-')[1];
}

var style=fill?'fill':'stroke';
var reverseStyle=fill?'stroke':'fill';
return match+"".concat(style,"=\"").concat(color,"\" ").concat(reverseStyle,"=\"none\" ");
});
},
addOriginalColor:function addOriginalColor(data){
var styleReg=/_fill="|_stroke="/gi;
return data.replace(styleReg,function(styleName){
return styleName&&styleName.slice(1);
});
},
getValidPathData:function getValidPathData(pathData){
// If use original and colors, clear double fill or stroke
if(this.original&&this.colors.length>0){
var reg=/<(path|rect|circle|polygon|line|polyline|ellipse)(\sfill|\sstroke)([="\w\s\.\-\+#\$\&>]+)(fill|stroke)/gi;
pathData=pathData.replace(reg,function(match,p1,p2,p3,p4){
return "<".concat(p1).concat(p2).concat(p3,"_").concat(p4);
});
}

return pathData;
},
setTitle:function setTitle(pathData){
if(this.title){
var title=this.title.replace(/\</gi,'&lt;').replace(/>/gi,'&gt;').replace(/&/g,'&amp;');
return "<title>".concat(title,"</title>")+pathData;
}

return pathData;
},
onClick:function onClick(e){
this.$emit('click',e);
}},

install:function install(Vue){
var options=arguments.length>1&&arguments[1]!==undefined?arguments[1]:{};
var tagName=options.tagName||'svgicon';

if(options.classPrefix){
classPrefix=options.classPrefix;
}

isStroke=!!options.isStroke;
isOriginalDefault=!!options.isOriginalDefault;// default size

options.defaultWidth&&(defaultWidth=options.defaultWidth);
options.defaultHeight&&(defaultHeight=options.defaultHeight);
Vue.component(tagName,this);
},
// register icons
register:function register(data){
var _loop=function _loop(name){
if(!icons[name]){
icons[name]=data[name];
}// check new register icon is not loaded, and set loaded to true


notLoadedIcons=notLoadedIcons.filter(function(v,ix){
if(v.name===name){
v.component.$set(v.component,'loaded',true);
}

return v.name!==name;
});
};

for(var name in data){
_loop(name);
}
},
icons:icons};

// CONCATENATED MODULE: ./src/components/SvgIcon.vue?vue&type=script&lang=js&
/* harmony default export */var components_SvgIconvue_type_script_lang_js_=SvgIconvue_type_script_lang_js_;
// CONCATENATED MODULE: ./node_modules/vue-loader/lib/runtime/componentNormalizer.js
/* globals __VUE_SSR_CONTEXT__ */

// IMPORTANT: Do NOT use ES2015 features in this file (except for modules).
// This module is a runtime utility for cleaner component module output and will
// be included in the final webpack user bundle.

function normalizeComponent(
scriptExports,
render,
staticRenderFns,
functionalTemplate,
injectStyles,
scopeId,
moduleIdentifier,/* server only */
shadowMode/* vue-cli only */)
{
// Vue.extend constructor export interop
var options=typeof scriptExports==='function'?
scriptExports.options:
scriptExports;

// render functions
if(render){
options.render=render;
options.staticRenderFns=staticRenderFns;
options._compiled=true;
}

// functional template
if(functionalTemplate){
options.functional=true;
}

// scopedId
if(scopeId){
options._scopeId='data-v-'+scopeId;
}

var hook;
if(moduleIdentifier){// server build
hook=function hook(context){
// 2.3 injection
context=
context||// cached call
this.$vnode&&this.$vnode.ssrContext||// stateful
this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext;// functional
// 2.2 with runInNewContext: true
if(!context&&typeof __VUE_SSR_CONTEXT__!=='undefined'){
context=__VUE_SSR_CONTEXT__;
}
// inject component styles
if(injectStyles){
injectStyles.call(this,context);
}
// register component module identifier for async chunk inferrence
if(context&&context._registeredComponents){
context._registeredComponents.add(moduleIdentifier);
}
};
// used by ssr in case component is cached and beforeCreate
// never gets called
options._ssrRegister=hook;
}else if(injectStyles){
hook=shadowMode?
function(){injectStyles.call(this,this.$root.$options.shadowRoot);}:
injectStyles;
}

if(hook){
if(options.functional){
// for template-only hot-reload because in that case the render fn doesn't
// go through the normalizer
options._injectStyles=hook;
// register for functioal component in vue file
var originalRender=options.render;
options.render=function renderWithStyleInjection(h,context){
hook.call(context);
return originalRender(h,context);
};
}else {
// inject component registration as beforeCreate hook
var existing=options.beforeCreate;
options.beforeCreate=existing?
[].concat(existing,hook):
[hook];
}
}

return {
exports:scriptExports,
options:options};

}

// CONCATENATED MODULE: ./src/components/SvgIcon.vue





/* normalize component */

var component=normalizeComponent(
components_SvgIconvue_type_script_lang_js_,
render,
staticRenderFns,
false,
null,
null,
null);



component.options.__file="SvgIcon.vue";
/* harmony default export */var SvgIcon=component.exports;
// CONCATENATED MODULE: ./node_modules/@vue/cli-service/lib/commands/build/entry-lib.js


/* harmony default export */var entry_lib=__webpack_exports__["default"]=SvgIcon;



/***/}

/******/})["default"];


/***/},

/***/"0395":
/***/function _(module,exports,__webpack_require__){

// fallback for IE11 buggy Object.getOwnPropertyNames with iframe and window
var toIObject=__webpack_require__("36c3");
var gOPN=__webpack_require__("6abf").f;
var toString={}.toString;

var windowNames=typeof window=='object'&&window&&Object.getOwnPropertyNames?
Object.getOwnPropertyNames(window):[];

var getWindowNames=function getWindowNames(it){
try{
return gOPN(it);
}catch(e){
return windowNames.slice();
}
};

module.exports.f=function getOwnPropertyNames(it){
return windowNames&&toString.call(it)=='[object Window]'?getWindowNames(it):gOPN(toIObject(it));
};


/***/},

/***/"061b":
/***/function b(module,exports,__webpack_require__){

module.exports=__webpack_require__("fa99");

/***/},

/***/"07e3":
/***/function e3(module,exports){

var hasOwnProperty={}.hasOwnProperty;
module.exports=function(it,key){
return hasOwnProperty.call(it,key);
};


/***/},

/***/"0978":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Day Helpers
 * @summary Return the start of a day for the given date.
 *
 * @description
 * Return the start of a day for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of a day
 *
 * @example
 * // The start of a day for 2 September 2014 11:55:00:
 * var result = startOfDay(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 02 2014 00:00:00
 */
function startOfDay(dirtyDate){
var date=parse(dirtyDate);
date.setHours(0,0,0,0);
return date;
}

module.exports=startOfDay;


/***/},

/***/"0d3e":
/***/function d3e(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Compare the two dates and return -1, 0 or 1.
 *
 * @description
 * Compare the two dates and return 1 if the first date is after the second,
 * -1 if the first date is before the second or 0 if dates are equal.
 *
 * @param {Date|String|Number} dateLeft - the first date to compare
 * @param {Date|String|Number} dateRight - the second date to compare
 * @returns {Number} the result of the comparison
 *
 * @example
 * // Compare 11 February 1987 and 10 July 1989:
 * var result = compareAsc(
 *   new Date(1987, 1, 11),
 *   new Date(1989, 6, 10)
 * )
 * //=> -1
 *
 * @example
 * // Sort the array of dates:
 * var result = [
 *   new Date(1995, 6, 2),
 *   new Date(1987, 1, 11),
 *   new Date(1989, 6, 10)
 * ].sort(compareAsc)
 * //=> [
 * //   Wed Feb 11 1987 00:00:00,
 * //   Mon Jul 10 1989 00:00:00,
 * //   Sun Jul 02 1995 00:00:00
 * // ]
 */
function compareAsc(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var timeLeft=dateLeft.getTime();
var dateRight=parse(dirtyDateRight);
var timeRight=dateRight.getTime();

if(timeLeft<timeRight){
return -1;
}else if(timeLeft>timeRight){
return 1;
}else {
return 0;
}
}

module.exports=compareAsc;


/***/},

/***/"0d58":
/***/function d58(module,exports,__webpack_require__){

// 19.1.2.14 / 15.2.3.14 Object.keys(O)
var $keys=__webpack_require__("ce10");
var enumBugKeys=__webpack_require__("e11e");

module.exports=Object.keys||function keys(O){
return $keys(O,enumBugKeys);
};


/***/},

/***/"0e58":
/***/function e58(module,__webpack_exports__,__webpack_require__){
/* harmony import */var _node_modules_mini_css_extract_plugin_dist_loader_js_ref_8_oneOf_1_0_node_modules_css_loader_index_js_ref_8_oneOf_1_1_node_modules_vue_loader_lib_loaders_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_lib_index_js_vue_loader_options_DateRangePicker_vue_vue_type_style_index_0_lang_scss___WEBPACK_IMPORTED_MODULE_0__=__webpack_require__("1854");
/* harmony import */var _node_modules_mini_css_extract_plugin_dist_loader_js_ref_8_oneOf_1_0_node_modules_css_loader_index_js_ref_8_oneOf_1_1_node_modules_vue_loader_lib_loaders_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_lib_index_js_vue_loader_options_DateRangePicker_vue_vue_type_style_index_0_lang_scss___WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(_node_modules_mini_css_extract_plugin_dist_loader_js_ref_8_oneOf_1_0_node_modules_css_loader_index_js_ref_8_oneOf_1_1_node_modules_vue_loader_lib_loaders_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_lib_index_js_vue_loader_options_DateRangePicker_vue_vue_type_style_index_0_lang_scss___WEBPACK_IMPORTED_MODULE_0__);
/* unused harmony reexport * */
/* unused harmony default export */var _unused_webpack_default_export=_node_modules_mini_css_extract_plugin_dist_loader_js_ref_8_oneOf_1_0_node_modules_css_loader_index_js_ref_8_oneOf_1_1_node_modules_vue_loader_lib_loaders_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_lib_index_js_vue_loader_options_DateRangePicker_vue_vue_type_style_index_0_lang_scss___WEBPACK_IMPORTED_MODULE_0___default.a;

/***/},

/***/"0fc9":
/***/function fc9(module,exports,__webpack_require__){

var toInteger=__webpack_require__("3a38");
var max=Math.max;
var min=Math.min;
module.exports=function(index,length){
index=toInteger(index);
return index<0?max(index+length,0):min(index,length);
};


/***/},

/***/"10c8":
/***/function c8(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Get the year of the given date.
 *
 * @description
 * Get the year of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the year
 *
 * @example
 * // Which year is 2 July 2014?
 * var result = getYear(new Date(2014, 6, 2))
 * //=> 2014
 */
function getYear(dirtyDate){
var date=parse(dirtyDate);
var year=date.getFullYear();
return year;
}

module.exports=getYear;


/***/},

/***/"1169":
/***/function _(module,exports,__webpack_require__){

// 7.2.2 IsArray(argument)
var cof=__webpack_require__("2d95");
module.exports=Array.isArray||function isArray(arg){
return cof(arg)=='Array';
};


/***/},

/***/"11e9":
/***/function e9(module,exports,__webpack_require__){

var pIE=__webpack_require__("52a7");
var createDesc=__webpack_require__("4630");
var toIObject=__webpack_require__("6821");
var toPrimitive=__webpack_require__("6a99");
var has=__webpack_require__("69a8");
var IE8_DOM_DEFINE=__webpack_require__("c69a");
var gOPD=Object.getOwnPropertyDescriptor;

exports.f=__webpack_require__("9e1e")?gOPD:function getOwnPropertyDescriptor(O,P){
O=toIObject(O);
P=toPrimitive(P,true);
if(IE8_DOM_DEFINE)try{
return gOPD(O,P);
}catch(e){/* empty */}
if(has(O,P))return createDesc(!pIE.f.call(O,P),O[P]);
};


/***/},

/***/"12fd":
/***/function fd(module,exports,__webpack_require__){

var addMonths=__webpack_require__("6665");

/**
 * @category Month Helpers
 * @summary Subtract the specified number of months from the given date.
 *
 * @description
 * Subtract the specified number of months from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of months to be subtracted
 * @returns {Date} the new date with the months subtracted
 *
 * @example
 * // Subtract 5 months from 1 February 2015:
 * var result = subMonths(new Date(2015, 1, 1), 5)
 * //=> Mon Sep 01 2014 00:00:00
 */
function subMonths(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addMonths(dirtyDate,-amount);
}

module.exports=subMonths;


/***/},

/***/"145e":
/***/function e(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Second Helpers
 * @summary Return the end of a second for the given date.
 *
 * @description
 * Return the end of a second for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of a second
 *
 * @example
 * // The end of a second for 1 December 2014 22:15:45.400:
 * var result = endOfSecond(new Date(2014, 11, 1, 22, 15, 45, 400))
 * //=> Mon Dec 01 2014 22:15:45.999
 */
function endOfSecond(dirtyDate){
var date=parse(dirtyDate);
date.setMilliseconds(999);
return date;
}

module.exports=endOfSecond;


/***/},

/***/"1495":
/***/function _(module,exports,__webpack_require__){

var dP=__webpack_require__("86cc");
var anObject=__webpack_require__("cb7c");
var getKeys=__webpack_require__("0d58");

module.exports=__webpack_require__("9e1e")?Object.defineProperties:function defineProperties(O,Properties){
anObject(O);
var keys=getKeys(Properties);
var length=keys.length;
var i=0;
var P;
while(length>i){dP.f(O,P=keys[i++],Properties[P]);}
return O;
};


/***/},

/***/"158b":
/***/function b(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var setMonth=__webpack_require__("3814");

/**
 * @category Quarter Helpers
 * @summary Set the year quarter to the given date.
 *
 * @description
 * Set the year quarter to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} quarter - the quarter of the new date
 * @returns {Date} the new date with the quarter setted
 *
 * @example
 * // Set the 2nd quarter to 2 July 2014:
 * var result = setQuarter(new Date(2014, 6, 2), 2)
 * //=> Wed Apr 02 2014 00:00:00
 */
function setQuarter(dirtyDate,dirtyQuarter){
var date=parse(dirtyDate);
var quarter=Number(dirtyQuarter);
var oldQuarter=Math.floor(date.getMonth()/3)+1;
var diff=quarter-oldQuarter;
return setMonth(date,date.getMonth()+diff*3);
}

module.exports=setQuarter;


/***/},

/***/"1654":
/***/function _(module,exports,__webpack_require__){

var $at=__webpack_require__("71c1")(true);

// 21.1.3.27 String.prototype[@@iterator]()
__webpack_require__("30f1")(String,'String',function(iterated){
this._t=String(iterated);// target
this._i=0;// next index
// 21.1.5.2.1 %StringIteratorPrototype%.next()
},function(){
var O=this._t;
var index=this._i;
var point;
if(index>=O.length)return {value:undefined,done:true};
point=$at(O,index);
this._i+=point.length;
return {value:point,done:false};
});


/***/},

/***/"1691":
/***/function _(module,exports){

// IE 8- don't enum bug keys
module.exports=
'constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf'.
split(',');


/***/},

/***/"17cd":
/***/function cd(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var differenceInCalendarMonths=__webpack_require__("b2e9");
var compareAsc=__webpack_require__("0d3e");

/**
 * @category Month Helpers
 * @summary Get the number of full months between the given dates.
 *
 * @description
 * Get the number of full months between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of full months
 *
 * @example
 * // How many full months are between 31 January 2014 and 1 September 2014?
 * var result = differenceInMonths(
 *   new Date(2014, 8, 1),
 *   new Date(2014, 0, 31)
 * )
 * //=> 7
 */
function differenceInMonths(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);

var sign=compareAsc(dateLeft,dateRight);
var difference=Math.abs(differenceInCalendarMonths(dateLeft,dateRight));
dateLeft.setMonth(dateLeft.getMonth()-sign*difference);

// Math.abs(diff in full months - diff in calendar months) === 1 if last calendar month is not full
// If so, result must be decreased by 1 in absolute value
var isLastMonthNotFull=compareAsc(dateLeft,dateRight)===-sign;
return sign*(difference-isLastMonthNotFull);
}

module.exports=differenceInMonths;


/***/},

/***/"1847":
/***/function _(module,exports){

function buildDistanceInWordsLocale(){
var distanceInWordsLocale={
lessThanXSeconds:{
one:'menos de un segundo',
other:'menos de {{count}} segundos'},


xSeconds:{
one:'1 segundo',
other:'{{count}} segundos'},


halfAMinute:'medio minuto',

lessThanXMinutes:{
one:'menos de un minuto',
other:'menos de {{count}} minutos'},


xMinutes:{
one:'1 minuto',
other:'{{count}} minutos'},


aboutXHours:{
one:'alrededor de 1 hora',
other:'alrededor de {{count}} horas'},


xHours:{
one:'1 hora',
other:'{{count}} horas'},


xDays:{
one:'1 día',
other:'{{count}} días'},


aboutXMonths:{
one:'alrededor de 1 mes',
other:'alrededor de {{count}} meses'},


xMonths:{
one:'1 mes',
other:'{{count}} meses'},


aboutXYears:{
one:'alrededor de 1 año',
other:'alrededor de {{count}} años'},


xYears:{
one:'1 año',
other:'{{count}} años'},


overXYears:{
one:'más de 1 año',
other:'más de {{count}} años'},


almostXYears:{
one:'casi 1 año',
other:'casi {{count}} años'}};



function localize(token,count,options){
options=options||{};

var result;
if(typeof distanceInWordsLocale[token]==='string'){
result=distanceInWordsLocale[token];
}else if(count===1){
result=distanceInWordsLocale[token].one;
}else {
result=distanceInWordsLocale[token].other.replace('{{count}}',count);
}

if(options.addSuffix){
if(options.comparison>0){
return 'en '+result;
}else {
return 'hace '+result;
}
}

return result;
}

return {
localize:localize};

}

module.exports=buildDistanceInWordsLocale;


/***/},

/***/"1854":
/***/function _(module,exports,__webpack_require__){

// extracted by mini-css-extract-plugin

/***/},

/***/"18b7":
/***/function b7(module,exports,__webpack_require__){

var addMinutes=__webpack_require__("72b7");

/**
 * @category Minute Helpers
 * @summary Subtract the specified number of minutes from the given date.
 *
 * @description
 * Subtract the specified number of minutes from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of minutes to be subtracted
 * @returns {Date} the new date with the mintues subtracted
 *
 * @example
 * // Subtract 30 minutes from 10 July 2014 12:00:00:
 * var result = subMinutes(new Date(2014, 6, 10, 12, 0), 30)
 * //=> Thu Jul 10 2014 11:30:00
 */
function subMinutes(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addMinutes(dirtyDate,-amount);
}

module.exports=subMinutes;


/***/},

/***/"1a84":
/***/function a84(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Return the earliest of the given dates.
 *
 * @description
 * Return the earliest of the given dates.
 *
 * @param {...(Date|String|Number)} dates - the dates to compare
 * @returns {Date} the earliest of the dates
 *
 * @example
 * // Which of these dates is the earliest?
 * var result = min(
 *   new Date(1989, 6, 10),
 *   new Date(1987, 1, 11),
 *   new Date(1995, 6, 2),
 *   new Date(1990, 0, 1)
 * )
 * //=> Wed Feb 11 1987 00:00:00
 */
function min(){
var dirtyDates=Array.prototype.slice.call(arguments);
var dates=dirtyDates.map(function(dirtyDate){
return parse(dirtyDate);
});
var earliestTimestamp=Math.min.apply(null,dates);
return new Date(earliestTimestamp);
}

module.exports=min;


/***/},

/***/"1af6":
/***/function af6(module,exports,__webpack_require__){

// 22.1.2.2 / 15.4.3.2 Array.isArray(arg)
var $export=__webpack_require__("63b6");

$export($export.S,'Array',{isArray:__webpack_require__("9003")});


/***/},

/***/"1baf":
/***/function baf(module,exports,__webpack_require__){

var startOfWeek=__webpack_require__("c7ce");

/**
 * @category Week Helpers
 * @summary Are the given dates in the same week?
 *
 * @description
 * Are the given dates in the same week?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @param {Object} [options] - the object with options
 * @param {Number} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @returns {Boolean} the dates are in the same week
 *
 * @example
 * // Are 31 August 2014 and 4 September 2014 in the same week?
 * var result = isSameWeek(
 *   new Date(2014, 7, 31),
 *   new Date(2014, 8, 4)
 * )
 * //=> true
 *
 * @example
 * // If week starts with Monday,
 * // are 31 August 2014 and 4 September 2014 in the same week?
 * var result = isSameWeek(
 *   new Date(2014, 7, 31),
 *   new Date(2014, 8, 4),
 *   {weekStartsOn: 1}
 * )
 * //=> false
 */
function isSameWeek(dirtyDateLeft,dirtyDateRight,dirtyOptions){
var dateLeftStartOfWeek=startOfWeek(dirtyDateLeft,dirtyOptions);
var dateRightStartOfWeek=startOfWeek(dirtyDateRight,dirtyOptions);

return dateLeftStartOfWeek.getTime()===dateRightStartOfWeek.getTime();
}

module.exports=isSameWeek;


/***/},

/***/"1bc3":
/***/function bc3(module,exports,__webpack_require__){

// 7.1.1 ToPrimitive(input [, PreferredType])
var isObject=__webpack_require__("f772");
// instead of the ES6 spec version, we didn't implement @@toPrimitive case
// and the second argument - flag - preferred type is a string
module.exports=function(it,S){
if(!isObject(it))return it;
var fn,val;
if(S&&typeof(fn=it.toString)=='function'&&!isObject(val=fn.call(it)))return val;
if(typeof(fn=it.valueOf)=='function'&&!isObject(val=fn.call(it)))return val;
if(!S&&typeof(fn=it.toString)=='function'&&!isObject(val=fn.call(it)))return val;
throw TypeError("Can't convert object to primitive value");
};


/***/},

/***/"1cc6":
/***/function cc6(module,exports,__webpack_require__){

var addMilliseconds=__webpack_require__("ec1f");

var MILLISECONDS_IN_HOUR=3600000;

/**
 * @category Hour Helpers
 * @summary Add the specified number of hours to the given date.
 *
 * @description
 * Add the specified number of hours to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of hours to be added
 * @returns {Date} the new date with the hours added
 *
 * @example
 * // Add 2 hours to 10 July 2014 23:00:00:
 * var result = addHours(new Date(2014, 6, 10, 23, 0), 2)
 * //=> Fri Jul 11 2014 01:00:00
 */
function addHours(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addMilliseconds(dirtyDate,amount*MILLISECONDS_IN_HOUR);
}

module.exports=addHours;


/***/},

/***/"1df8":
/***/function df8(module,exports,__webpack_require__){

// 19.1.3.19 Object.setPrototypeOf(O, proto)
var $export=__webpack_require__("63b6");
$export($export.S,'Object',{setPrototypeOf:__webpack_require__("ead6").set});


/***/},

/***/"1ec9":
/***/function ec9(module,exports,__webpack_require__){

var isObject=__webpack_require__("f772");
var document=__webpack_require__("e53d").document;
// typeof document.createElement is 'object' in old IE
var is=isObject(document)&&isObject(document.createElement);
module.exports=function(it){
return is?document.createElement(it):{};
};


/***/},

/***/"20b1":
/***/function b1(module,exports,__webpack_require__){

var startOfDay=__webpack_require__("0978");

/**
 * @category Day Helpers
 * @summary Is the given date tomorrow?
 *
 * @description
 * Is the given date tomorrow?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is tomorrow
 *
 * @example
 * // If today is 6 October 2014, is 7 October 14:00:00 tomorrow?
 * var result = isTomorrow(new Date(2014, 9, 7, 14, 0))
 * //=> true
 */
function isTomorrow(dirtyDate){
var tomorrow=new Date();
tomorrow.setDate(tomorrow.getDate()+1);
return startOfDay(dirtyDate).getTime()===startOfDay(tomorrow).getTime();
}

module.exports=isTomorrow;


/***/},

/***/"2299":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Second Helpers
 * @summary Return the start of a second for the given date.
 *
 * @description
 * Return the start of a second for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of a second
 *
 * @example
 * // The start of a second for 1 December 2014 22:15:45.400:
 * var result = startOfSecond(new Date(2014, 11, 1, 22, 15, 45, 400))
 * //=> Mon Dec 01 2014 22:15:45.000
 */
function startOfSecond(dirtyDate){
var date=parse(dirtyDate);
date.setMilliseconds(0);
return date;
}

module.exports=startOfSecond;


/***/},

/***/"230e":
/***/function e(module,exports,__webpack_require__){

var isObject=__webpack_require__("d3f4");
var document=__webpack_require__("7726").document;
// typeof document.createElement is 'object' in old IE
var is=isObject(document)&&isObject(document.createElement);
module.exports=function(it){
return is?document.createElement(it):{};
};


/***/},

/***/"231c":
/***/function c(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Second Helpers
 * @summary Get the seconds of the given date.
 *
 * @description
 * Get the seconds of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the seconds
 *
 * @example
 * // Get the seconds of 29 February 2012 11:45:05.123:
 * var result = getSeconds(new Date(2012, 1, 29, 11, 45, 5, 123))
 * //=> 5
 */
function getSeconds(dirtyDate){
var date=parse(dirtyDate);
var seconds=date.getSeconds();
return seconds;
}

module.exports=getSeconds;


/***/},

/***/"2333":
/***/function _(module,exports){

function buildDistanceInWordsLocale(){
var distanceInWordsLocale={
lessThanXSeconds:{
one:'moins d’une seconde',
other:'moins de {{count}} secondes'},


xSeconds:{
one:'1 seconde',
other:'{{count}} secondes'},


halfAMinute:'30 secondes',

lessThanXMinutes:{
one:'moins d’une minute',
other:'moins de {{count}} minutes'},


xMinutes:{
one:'1 minute',
other:'{{count}} minutes'},


aboutXHours:{
one:'environ 1 heure',
other:'environ {{count}} heures'},


xHours:{
one:'1 heure',
other:'{{count}} heures'},


xDays:{
one:'1 jour',
other:'{{count}} jours'},


aboutXMonths:{
one:'environ 1 mois',
other:'environ {{count}} mois'},


xMonths:{
one:'1 mois',
other:'{{count}} mois'},


aboutXYears:{
one:'environ 1 an',
other:'environ {{count}} ans'},


xYears:{
one:'1 an',
other:'{{count}} ans'},


overXYears:{
one:'plus d’un an',
other:'plus de {{count}} ans'},


almostXYears:{
one:'presqu’un an',
other:'presque {{count}} ans'}};



function localize(token,count,options){
options=options||{};

var result;
if(typeof distanceInWordsLocale[token]==='string'){
result=distanceInWordsLocale[token];
}else if(count===1){
result=distanceInWordsLocale[token].one;
}else {
result=distanceInWordsLocale[token].other.replace('{{count}}',count);
}

if(options.addSuffix){
if(options.comparison>0){
return 'dans '+result;
}else {
return 'il y a '+result;
}
}

return result;
}

return {
localize:localize};

}

module.exports=buildDistanceInWordsLocale;


/***/},

/***/"2376":
/***/function _(module,exports,__webpack_require__){

var buildFormattingTokensRegExp=__webpack_require__("90e5");

function buildFormatLocale(){
var months3char=['janv.','févr.','mars','avr.','mai','juin','juill.','août','sept.','oct.','nov.','déc.'];
var monthsFull=['janvier','février','mars','avril','mai','juin','juillet','août','septembre','octobre','novembre','décembre'];
var weekdays2char=['di','lu','ma','me','je','ve','sa'];
var weekdays3char=['dim.','lun.','mar.','mer.','jeu.','ven.','sam.'];
var weekdaysFull=['dimanche','lundi','mardi','mercredi','jeudi','vendredi','samedi'];
var meridiemUppercase=['AM','PM'];
var meridiemLowercase=['am','pm'];
var meridiemFull=['du matin','de l’après-midi','du soir'];

var formatters={
// Month: Jan, Feb, …, Dec
'MMM':function MMM(date){
return months3char[date.getMonth()];
},

// Month: January, February, …, December
'MMMM':function MMMM(date){
return monthsFull[date.getMonth()];
},

// Day of week: Su, Mo, …, Sa
'dd':function dd(date){
return weekdays2char[date.getDay()];
},

// Day of week: Sun, Mon, …, Sat
'ddd':function ddd(date){
return weekdays3char[date.getDay()];
},

// Day of week: Sunday, Monday, …, Saturday
'dddd':function dddd(date){
return weekdaysFull[date.getDay()];
},

// AM, PM
'A':function A(date){
return date.getHours()/12>=1?meridiemUppercase[1]:meridiemUppercase[0];
},

// am, pm
'a':function a(date){
return date.getHours()/12>=1?meridiemLowercase[1]:meridiemLowercase[0];
},

// a.m., p.m.
'aa':function aa(date){
var hours=date.getHours();

if(hours<=12){
return meridiemFull[0];
}

if(hours<=16){
return meridiemFull[1];
}

return meridiemFull[2];
},

// ISO week, ordinal version: 1st, 2nd, …, 53rd
// NOTE: Week has feminine grammatical gender in French: semaine
'Wo':function Wo(date,formatters){
return feminineOrdinal(formatters.W(date));
}};


// Generate ordinal version of formatters: M → Mo, D → Do, etc.
// NOTE: For words with masculine grammatical gender in French: mois, jour, trimestre
var formatterTokens=['M','D','DDD','d','Q'];
formatterTokens.forEach(function(formatterToken){
formatters[formatterToken+'o']=function(date,formatters){
return masculineOrdinal(formatters[formatterToken](date));
};
});

// Special case for day of month ordinals in long date format context:
// 1er mars, 2 mars, 3 mars, …
// See https://github.com/date-fns/date-fns/issues/437
//
// NOTE: The below implementation works because parsing of tokens inside a
// format string is done by a greedy regular expression, i.e. longer tokens
// have priority. E.g. formatter for "Do MMMM" has priority over individual
// formatters for "Do" and "MMMM".
var monthsTokens=['MMM','MMMM'];
monthsTokens.forEach(function(monthToken){
formatters['Do '+monthToken]=function(date,commonFormatters){
var dayOfMonthToken=date.getDate()===1?
'Do':
'D';
var dayOfMonthFormatter=formatters[dayOfMonthToken]||commonFormatters[dayOfMonthToken];

return dayOfMonthFormatter(date,commonFormatters)+' '+formatters[monthToken](date);
};
});

return {
formatters:formatters,
formattingTokensRegExp:buildFormattingTokensRegExp(formatters)};

}

function masculineOrdinal(number){
if(number===1){
return '1er';
}

return number+'e';
}

function feminineOrdinal(number){
if(number===1){
return '1re';
}

return number+'e';
}

module.exports=buildFormatLocale;


/***/},

/***/"241e":
/***/function e(module,exports,__webpack_require__){

// 7.1.13 ToObject(argument)
var defined=__webpack_require__("25eb");
module.exports=function(it){
return Object(defined(it));
};


/***/},

/***/"2507":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Is the given date Monday?
 *
 * @description
 * Is the given date Monday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is Monday
 *
 * @example
 * // Is 22 September 2014 Monday?
 * var result = isMonday(new Date(2014, 8, 22))
 * //=> true
 */
function isMonday(dirtyDate){
return parse(dirtyDate).getDay()===1;
}

module.exports=isMonday;


/***/},

/***/"25b0":
/***/function b0(module,exports,__webpack_require__){

__webpack_require__("1df8");
module.exports=__webpack_require__("584a").Object.setPrototypeOf;


/***/},

/***/"25eb":
/***/function eb(module,exports){

// 7.2.1 RequireObjectCoercible(argument)
module.exports=function(it){
if(it==undefined)throw TypeError("Can't call method on  "+it);
return it;
};


/***/},

/***/"2621":
/***/function _(module,exports){

exports.f=Object.getOwnPropertySymbols;


/***/},

/***/"26d5":
/***/function d5(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Are the given dates in the same year?
 *
 * @description
 * Are the given dates in the same year?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same year
 *
 * @example
 * // Are 2 September 2014 and 25 September 2014 in the same year?
 * var result = isSameYear(
 *   new Date(2014, 8, 2),
 *   new Date(2014, 8, 25)
 * )
 * //=> true
 */
function isSameYear(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);
return dateLeft.getFullYear()===dateRight.getFullYear();
}

module.exports=isSameYear;


/***/},

/***/"271a":
/***/function a(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Hour Helpers
 * @summary Return the end of an hour for the given date.
 *
 * @description
 * Return the end of an hour for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of an hour
 *
 * @example
 * // The end of an hour for 2 September 2014 11:55:00:
 * var result = endOfHour(new Date(2014, 8, 2, 11, 55))
 * //=> Tue Sep 02 2014 11:59:59.999
 */
function endOfHour(dirtyDate){
var date=parse(dirtyDate);
date.setMinutes(59,59,999);
return date;
}

module.exports=endOfHour;


/***/},

/***/"27a1":
/***/function a1(module,exports,__webpack_require__){

var getISOYear=__webpack_require__("8964");
var setISOYear=__webpack_require__("9706");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Add the specified number of ISO week-numbering years to the given date.
 *
 * @description
 * Add the specified number of ISO week-numbering years to the given date.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of ISO week-numbering years to be added
 * @returns {Date} the new date with the ISO week-numbering years added
 *
 * @example
 * // Add 5 ISO week-numbering years to 2 July 2010:
 * var result = addISOYears(new Date(2010, 6, 2), 5)
 * //=> Fri Jun 26 2015 00:00:00
 */
function addISOYears(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return setISOYear(dirtyDate,getISOYear(dirtyDate)+amount);
}

module.exports=addISOYears;


/***/},

/***/"294c":
/***/function c(module,exports){

module.exports=function(exec){
try{
return !!exec();
}catch(e){
return true;
}
};


/***/},

/***/"2a63":
/***/function a63(module,exports){

function declension(scheme,count){
// scheme for count=1 exists
if(scheme.one!==undefined&&count===1){
return scheme.one;
}

var rem10=count%10;
var rem100=count%100;

// 1, 21, 31, ...
if(rem10===1&&rem100!==11){
return scheme.singularNominative.replace('{{count}}',count);

// 2, 3, 4, 22, 23, 24, 32 ...
}else if(rem10>=2&&rem10<=4&&(rem100<10||rem100>20)){
return scheme.singularGenitive.replace('{{count}}',count);

// 5, 6, 7, 8, 9, 10, 11, ...
}else {
return scheme.pluralGenitive.replace('{{count}}',count);
}
}

function buildLocalizeTokenFn(scheme){
return function(count,options){
if(options.addSuffix){
if(options.comparison>0){
if(scheme.future){
return declension(scheme.future,count);
}else {
return 'через '+declension(scheme.regular,count);
}
}else {
if(scheme.past){
return declension(scheme.past,count);
}else {
return declension(scheme.regular,count)+' назад';
}
}
}else {
return declension(scheme.regular,count);
}
};
}

function buildDistanceInWordsLocale(){
var distanceInWordsLocale={
lessThanXSeconds:buildLocalizeTokenFn({
regular:{
one:'меньше секунды',
singularNominative:'меньше {{count}} секунды',
singularGenitive:'меньше {{count}} секунд',
pluralGenitive:'меньше {{count}} секунд'},

future:{
one:'меньше, чем через секунду',
singularNominative:'меньше, чем через {{count}} секунду',
singularGenitive:'меньше, чем через {{count}} секунды',
pluralGenitive:'меньше, чем через {{count}} секунд'}}),



xSeconds:buildLocalizeTokenFn({
regular:{
singularNominative:'{{count}} секунда',
singularGenitive:'{{count}} секунды',
pluralGenitive:'{{count}} секунд'},

past:{
singularNominative:'{{count}} секунду назад',
singularGenitive:'{{count}} секунды назад',
pluralGenitive:'{{count}} секунд назад'},

future:{
singularNominative:'через {{count}} секунду',
singularGenitive:'через {{count}} секунды',
pluralGenitive:'через {{count}} секунд'}}),



halfAMinute:function halfAMinute(_,options){
if(options.addSuffix){
if(options.comparison>0){
return 'через полминуты';
}else {
return 'полминуты назад';
}
}

return 'полминуты';
},

lessThanXMinutes:buildLocalizeTokenFn({
regular:{
one:'меньше минуты',
singularNominative:'меньше {{count}} минуты',
singularGenitive:'меньше {{count}} минут',
pluralGenitive:'меньше {{count}} минут'},

future:{
one:'меньше, чем через минуту',
singularNominative:'меньше, чем через {{count}} минуту',
singularGenitive:'меньше, чем через {{count}} минуты',
pluralGenitive:'меньше, чем через {{count}} минут'}}),



xMinutes:buildLocalizeTokenFn({
regular:{
singularNominative:'{{count}} минута',
singularGenitive:'{{count}} минуты',
pluralGenitive:'{{count}} минут'},

past:{
singularNominative:'{{count}} минуту назад',
singularGenitive:'{{count}} минуты назад',
pluralGenitive:'{{count}} минут назад'},

future:{
singularNominative:'через {{count}} минуту',
singularGenitive:'через {{count}} минуты',
pluralGenitive:'через {{count}} минут'}}),



aboutXHours:buildLocalizeTokenFn({
regular:{
singularNominative:'около {{count}} часа',
singularGenitive:'около {{count}} часов',
pluralGenitive:'около {{count}} часов'},

future:{
singularNominative:'приблизительно через {{count}} час',
singularGenitive:'приблизительно через {{count}} часа',
pluralGenitive:'приблизительно через {{count}} часов'}}),



xHours:buildLocalizeTokenFn({
regular:{
singularNominative:'{{count}} час',
singularGenitive:'{{count}} часа',
pluralGenitive:'{{count}} часов'}}),



xDays:buildLocalizeTokenFn({
regular:{
singularNominative:'{{count}} день',
singularGenitive:'{{count}} дня',
pluralGenitive:'{{count}} дней'}}),



aboutXMonths:buildLocalizeTokenFn({
regular:{
singularNominative:'около {{count}} месяца',
singularGenitive:'около {{count}} месяцев',
pluralGenitive:'около {{count}} месяцев'},

future:{
singularNominative:'приблизительно через {{count}} месяц',
singularGenitive:'приблизительно через {{count}} месяца',
pluralGenitive:'приблизительно через {{count}} месяцев'}}),



xMonths:buildLocalizeTokenFn({
regular:{
singularNominative:'{{count}} месяц',
singularGenitive:'{{count}} месяца',
pluralGenitive:'{{count}} месяцев'}}),



aboutXYears:buildLocalizeTokenFn({
regular:{
singularNominative:'около {{count}} года',
singularGenitive:'около {{count}} лет',
pluralGenitive:'около {{count}} лет'},

future:{
singularNominative:'приблизительно через {{count}} год',
singularGenitive:'приблизительно через {{count}} года',
pluralGenitive:'приблизительно через {{count}} лет'}}),



xYears:buildLocalizeTokenFn({
regular:{
singularNominative:'{{count}} год',
singularGenitive:'{{count}} года',
pluralGenitive:'{{count}} лет'}}),



overXYears:buildLocalizeTokenFn({
regular:{
singularNominative:'больше {{count}} года',
singularGenitive:'больше {{count}} лет',
pluralGenitive:'больше {{count}} лет'},

future:{
singularNominative:'больше, чем через {{count}} год',
singularGenitive:'больше, чем через {{count}} года',
pluralGenitive:'больше, чем через {{count}} лет'}}),



almostXYears:buildLocalizeTokenFn({
regular:{
singularNominative:'почти {{count}} год',
singularGenitive:'почти {{count}} года',
pluralGenitive:'почти {{count}} лет'},

future:{
singularNominative:'почти через {{count}} год',
singularGenitive:'почти через {{count}} года',
pluralGenitive:'почти через {{count}} лет'}})};




function localize(token,count,options){
options=options||{};
return distanceInWordsLocale[token](count,options);
}

return {
localize:localize};

}

module.exports=buildDistanceInWordsLocale;


/***/},

/***/"2a80":
/***/function a80(module,exports,__webpack_require__){

var isSameQuarter=__webpack_require__("9aaa");

/**
 * @category Quarter Helpers
 * @summary Is the given date in the same quarter as the current date?
 *
 * @description
 * Is the given date in the same quarter as the current date?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this quarter
 *
 * @example
 * // If today is 25 September 2014, is 2 July 2014 in this quarter?
 * var result = isThisQuarter(new Date(2014, 6, 2))
 * //=> true
 */
function isThisQuarter(dirtyDate){
return isSameQuarter(new Date(),dirtyDate);
}

module.exports=isThisQuarter;


/***/},

/***/"2a9c":
/***/function a9c(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Get the number of calendar years between the given dates.
 *
 * @description
 * Get the number of calendar years between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of calendar years
 *
 * @example
 * // How many calendar years are between 31 December 2013 and 11 February 2015?
 * var result = differenceInCalendarYears(
 *   new Date(2015, 1, 11),
 *   new Date(2013, 11, 31)
 * )
 * //=> 2
 */
function differenceInCalendarYears(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);

return dateLeft.getFullYear()-dateRight.getFullYear();
}

module.exports=differenceInCalendarYears;


/***/},

/***/"2aba":
/***/function aba(module,exports,__webpack_require__){

var global=__webpack_require__("7726");
var hide=__webpack_require__("32e9");
var has=__webpack_require__("69a8");
var SRC=__webpack_require__("ca5a")('src');
var $toString=__webpack_require__("fa5b");
var TO_STRING='toString';
var TPL=(''+$toString).split(TO_STRING);

__webpack_require__("8378").inspectSource=function(it){
return $toString.call(it);
};

(module.exports=function(O,key,val,safe){
var isFunction=typeof val=='function';
if(isFunction)has(val,'name')||hide(val,'name',key);
if(O[key]===val)return;
if(isFunction)has(val,SRC)||hide(val,SRC,O[key]?''+O[key]:TPL.join(String(key)));
if(O===global){
O[key]=val;
}else if(!safe){
delete O[key];
hide(O,key,val);
}else if(O[key]){
O[key]=val;
}else {
hide(O,key,val);
}
// add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative
})(Function.prototype,TO_STRING,function toString(){
return typeof this=='function'&&this[SRC]||$toString.call(this);
});


/***/},

/***/"2aeb":
/***/function aeb(module,exports,__webpack_require__){

// 19.1.2.2 / 15.2.3.5 Object.create(O [, Properties])
var anObject=__webpack_require__("cb7c");
var dPs=__webpack_require__("1495");
var enumBugKeys=__webpack_require__("e11e");
var IE_PROTO=__webpack_require__("613b")('IE_PROTO');
var Empty=function Empty(){/* empty */};
var PROTOTYPE='prototype';

// Create object with fake `null` prototype: use iframe Object with cleared prototype
var _createDict=function createDict(){
// Thrash, waste and sodomy: IE GC bug
var iframe=__webpack_require__("230e")('iframe');
var i=enumBugKeys.length;
var lt='<';
var gt='>';
var iframeDocument;
iframe.style.display='none';
__webpack_require__("fab2").appendChild(iframe);
iframe.src='javascript:';// eslint-disable-line no-script-url
// createDict = iframe.contentWindow.Object;
// html.removeChild(iframe);
iframeDocument=iframe.contentWindow.document;
iframeDocument.open();
iframeDocument.write(lt+'script'+gt+'document.F=Object'+lt+'/script'+gt);
iframeDocument.close();
_createDict=iframeDocument.F;
while(i--){delete _createDict[PROTOTYPE][enumBugKeys[i]];}
return _createDict();
};

module.exports=Object.create||function create(O,Properties){
var result;
if(O!==null){
Empty[PROTOTYPE]=anObject(O);
result=new Empty();
Empty[PROTOTYPE]=null;
// add "__proto__" for Object.getPrototypeOf polyfill
result[IE_PROTO]=O;
}else result=_createDict();
return Properties===undefined?result:dPs(result,Properties);
};


/***/},

/***/"2b4c":
/***/function b4c(module,exports,__webpack_require__){

var store=__webpack_require__("5537")('wks');
var uid=__webpack_require__("ca5a");
var Symbol=__webpack_require__("7726").Symbol;
var USE_SYMBOL=typeof Symbol=='function';

var $exports=module.exports=function(name){
return store[name]||(store[name]=
USE_SYMBOL&&Symbol[name]||(USE_SYMBOL?Symbol:uid)('Symbol.'+name));
};

$exports.store=store;


/***/},

/***/"2b57":
/***/function b57(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Is the given date Sunday?
 *
 * @description
 * Is the given date Sunday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is Sunday
 *
 * @example
 * // Is 21 September 2014 Sunday?
 * var result = isSunday(new Date(2014, 8, 21))
 * //=> true
 */
function isSunday(dirtyDate){
return parse(dirtyDate).getDay()===0;
}

module.exports=isSunday;


/***/},

/***/"2b67":
/***/function b67(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Is the given date in the future?
 *
 * @description
 * Is the given date in the future?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in the future
 *
 * @example
 * // If today is 6 October 2014, is 31 December 2014 in the future?
 * var result = isFuture(new Date(2014, 11, 31))
 * //=> true
 */
function isFuture(dirtyDate){
return parse(dirtyDate).getTime()>new Date().getTime();
}

module.exports=isFuture;


/***/},

/***/"2ca0":
/***/function ca0(module,exports,__webpack_require__){

var buildDistanceInWordsLocale=__webpack_require__("2333");
var buildFormatLocale=__webpack_require__("2376");

/**
 * @category Locales
 * @summary French locale.
 * @author Jean Dupouy [@izeau]{@link https://github.com/izeau}
 * @author François B [@fbonzon]{@link https://github.com/fbonzon}
 */
module.exports={
distanceInWords:buildDistanceInWordsLocale(),
format:buildFormatLocale()};



/***/},

/***/"2d00":
/***/function d00(module,exports){

module.exports=false;


/***/},

/***/"2d23":
/***/function d23(module,exports,__webpack_require__){

var isSameWeek=__webpack_require__("1baf");

/**
 * @category Week Helpers
 * @summary Is the given date in the same week as the current date?
 *
 * @description
 * Is the given date in the same week as the current date?
 *
 * @param {Date|String|Number} date - the date to check
 * @param {Object} [options] - the object with options
 * @param {Number} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @returns {Boolean} the date is in this week
 *
 * @example
 * // If today is 25 September 2014, is 21 September 2014 in this week?
 * var result = isThisWeek(new Date(2014, 8, 21))
 * //=> true
 *
 * @example
 * // If today is 25 September 2014 and week starts with Monday
 * // is 21 September 2014 in this week?
 * var result = isThisWeek(new Date(2014, 8, 21), {weekStartsOn: 1})
 * //=> false
 */
function isThisWeek(dirtyDate,dirtyOptions){
return isSameWeek(new Date(),dirtyDate,dirtyOptions);
}

module.exports=isThisWeek;


/***/},

/***/"2d95":
/***/function d95(module,exports){

var toString={}.toString;

module.exports=function(it){
return toString.call(it).slice(8,-1);
};


/***/},

/***/"2d96":
/***/function d96(module,exports){

function buildDistanceInWordsLocale(){
var distanceInWordsLocale={
lessThanXSeconds:{
one:'less than a second',
other:'less than {{count}} seconds'},


xSeconds:{
one:'1 second',
other:'{{count}} seconds'},


halfAMinute:'half a minute',

lessThanXMinutes:{
one:'less than a minute',
other:'less than {{count}} minutes'},


xMinutes:{
one:'1 minute',
other:'{{count}} minutes'},


aboutXHours:{
one:'about 1 hour',
other:'about {{count}} hours'},


xHours:{
one:'1 hour',
other:'{{count}} hours'},


xDays:{
one:'1 day',
other:'{{count}} days'},


aboutXMonths:{
one:'about 1 month',
other:'about {{count}} months'},


xMonths:{
one:'1 month',
other:'{{count}} months'},


aboutXYears:{
one:'about 1 year',
other:'about {{count}} years'},


xYears:{
one:'1 year',
other:'{{count}} years'},


overXYears:{
one:'over 1 year',
other:'over {{count}} years'},


almostXYears:{
one:'almost 1 year',
other:'almost {{count}} years'}};



function localize(token,count,options){
options=options||{};

var result;
if(typeof distanceInWordsLocale[token]==='string'){
result=distanceInWordsLocale[token];
}else if(count===1){
result=distanceInWordsLocale[token].one;
}else {
result=distanceInWordsLocale[token].other.replace('{{count}}',count);
}

if(options.addSuffix){
if(options.comparison>0){
return 'in '+result;
}else {
return result+' ago';
}
}

return result;
}

return {
localize:localize};

}

module.exports=buildDistanceInWordsLocale;


/***/},

/***/"2f1a":
/***/function f1a(module,exports,__webpack_require__){

var startOfWeek=__webpack_require__("c7ce");

var MILLISECONDS_IN_MINUTE=60000;
var MILLISECONDS_IN_WEEK=604800000;

/**
 * @category Week Helpers
 * @summary Get the number of calendar weeks between the given dates.
 *
 * @description
 * Get the number of calendar weeks between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @param {Object} [options] - the object with options
 * @param {Number} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @returns {Number} the number of calendar weeks
 *
 * @example
 * // How many calendar weeks are between 5 July 2014 and 20 July 2014?
 * var result = differenceInCalendarWeeks(
 *   new Date(2014, 6, 20),
 *   new Date(2014, 6, 5)
 * )
 * //=> 3
 *
 * @example
 * // If the week starts on Monday,
 * // how many calendar weeks are between 5 July 2014 and 20 July 2014?
 * var result = differenceInCalendarWeeks(
 *   new Date(2014, 6, 20),
 *   new Date(2014, 6, 5),
 *   {weekStartsOn: 1}
 * )
 * //=> 2
 */
function differenceInCalendarWeeks(dirtyDateLeft,dirtyDateRight,dirtyOptions){
var startOfWeekLeft=startOfWeek(dirtyDateLeft,dirtyOptions);
var startOfWeekRight=startOfWeek(dirtyDateRight,dirtyOptions);

var timestampLeft=startOfWeekLeft.getTime()-
startOfWeekLeft.getTimezoneOffset()*MILLISECONDS_IN_MINUTE;
var timestampRight=startOfWeekRight.getTime()-
startOfWeekRight.getTimezoneOffset()*MILLISECONDS_IN_MINUTE;

// Round the number of days to the nearest integer
// because the number of milliseconds in a week is not constant
// (e.g. it's different in the week of the daylight saving time clock shift)
return Math.round((timestampLeft-timestampRight)/MILLISECONDS_IN_WEEK);
}

module.exports=differenceInCalendarWeeks;


/***/},

/***/"2f8f":
/***/function f8f(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Set the year to the given date.
 *
 * @description
 * Set the year to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} year - the year of the new date
 * @returns {Date} the new date with the year setted
 *
 * @example
 * // Set year 2013 to 1 September 2014:
 * var result = setYear(new Date(2014, 8, 1), 2013)
 * //=> Sun Sep 01 2013 00:00:00
 */
function setYear(dirtyDate,dirtyYear){
var date=parse(dirtyDate);
var year=Number(dirtyYear);
date.setFullYear(year);
return date;
}

module.exports=setYear;


/***/},

/***/"2fff":
/***/function fff(module,exports,__webpack_require__){

var startOfISOYear=__webpack_require__("4497");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Are the given dates in the same ISO week-numbering year?
 *
 * @description
 * Are the given dates in the same ISO week-numbering year?
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same ISO week-numbering year
 *
 * @example
 * // Are 29 December 2003 and 2 January 2005 in the same ISO week-numbering year?
 * var result = isSameISOYear(
 *   new Date(2003, 11, 29),
 *   new Date(2005, 0, 2)
 * )
 * //=> true
 */
function isSameISOYear(dirtyDateLeft,dirtyDateRight){
var dateLeftStartOfYear=startOfISOYear(dirtyDateLeft);
var dateRightStartOfYear=startOfISOYear(dirtyDateRight);

return dateLeftStartOfYear.getTime()===dateRightStartOfYear.getTime();
}

module.exports=isSameISOYear;


/***/},

/***/"30d1":
/***/function d1(module,exports,__webpack_require__){

var startOfDay=__webpack_require__("0978");

/**
 * @category Day Helpers
 * @summary Is the given date today?
 *
 * @description
 * Is the given date today?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is today
 *
 * @example
 * // If today is 6 October 2014, is 6 October 14:00:00 today?
 * var result = isToday(new Date(2014, 9, 6, 14, 0))
 * //=> true
 */
function isToday(dirtyDate){
return startOfDay(dirtyDate).getTime()===startOfDay(new Date()).getTime();
}

module.exports=isToday;


/***/},

/***/"30f1":
/***/function f1(module,exports,__webpack_require__){

var LIBRARY=__webpack_require__("b8e3");
var $export=__webpack_require__("63b6");
var redefine=__webpack_require__("9138");
var hide=__webpack_require__("35e8");
var Iterators=__webpack_require__("481b");
var $iterCreate=__webpack_require__("8f60");
var setToStringTag=__webpack_require__("45f2");
var getPrototypeOf=__webpack_require__("53e2");
var ITERATOR=__webpack_require__("5168")('iterator');
var BUGGY=!([].keys&&'next'in[].keys());// Safari has buggy iterators w/o `next`
var FF_ITERATOR='@@iterator';
var KEYS='keys';
var VALUES='values';

var returnThis=function returnThis(){return this;};

module.exports=function(Base,NAME,Constructor,next,DEFAULT,IS_SET,FORCED){
$iterCreate(Constructor,NAME,next);
var getMethod=function getMethod(kind){
if(!BUGGY&&kind in proto)return proto[kind];
switch(kind){
case KEYS:return function keys(){return new Constructor(this,kind);};
case VALUES:return function values(){return new Constructor(this,kind);};}
return function entries(){return new Constructor(this,kind);};
};
var TAG=NAME+' Iterator';
var DEF_VALUES=DEFAULT==VALUES;
var VALUES_BUG=false;
var proto=Base.prototype;
var $native=proto[ITERATOR]||proto[FF_ITERATOR]||DEFAULT&&proto[DEFAULT];
var $default=$native||getMethod(DEFAULT);
var $entries=DEFAULT?!DEF_VALUES?$default:getMethod('entries'):undefined;
var $anyNative=NAME=='Array'?proto.entries||$native:$native;
var methods,key,IteratorPrototype;
// Fix native
if($anyNative){
IteratorPrototype=getPrototypeOf($anyNative.call(new Base()));
if(IteratorPrototype!==Object.prototype&&IteratorPrototype.next){
// Set @@toStringTag to native iterators
setToStringTag(IteratorPrototype,TAG,true);
// fix for some old engines
if(!LIBRARY&&typeof IteratorPrototype[ITERATOR]!='function')hide(IteratorPrototype,ITERATOR,returnThis);
}
}
// fix Array#{values, @@iterator}.name in V8 / FF
if(DEF_VALUES&&$native&&$native.name!==VALUES){
VALUES_BUG=true;
$default=function values(){return $native.call(this);};
}
// Define iterator
if((!LIBRARY||FORCED)&&(BUGGY||VALUES_BUG||!proto[ITERATOR])){
hide(proto,ITERATOR,$default);
}
// Plug for library
Iterators[NAME]=$default;
Iterators[TAG]=returnThis;
if(DEFAULT){
methods={
values:DEF_VALUES?$default:getMethod(VALUES),
keys:IS_SET?$default:getMethod(KEYS),
entries:$entries};

if(FORCED)for(key in methods){
if(!(key in proto))redefine(proto,key,methods[key]);
}else $export($export.P+$export.F*(BUGGY||VALUES_BUG),NAME,methods);
}
return methods;
};


/***/},

/***/"32e9":
/***/function e9(module,exports,__webpack_require__){

var dP=__webpack_require__("86cc");
var createDesc=__webpack_require__("4630");
module.exports=__webpack_require__("9e1e")?function(object,key,value){
return dP.f(object,key,createDesc(1,value));
}:function(object,key,value){
object[key]=value;
return object;
};


/***/},

/***/"32fc":
/***/function fc(module,exports,__webpack_require__){

var document=__webpack_require__("e53d").document;
module.exports=document&&document.documentElement;


/***/},

/***/"335c":
/***/function c(module,exports,__webpack_require__){

// fallback for non-array-like ES3 and non-enumerable old V8 strings
var cof=__webpack_require__("6b4c");
// eslint-disable-next-line no-prototype-builtins
module.exports=Object('z').propertyIsEnumerable(0)?Object:function(it){
return cof(it)=='String'?it.split(''):Object(it);
};


/***/},

/***/"340b":
/***/function b(module,exports,__webpack_require__){

module.exports={
addDays:__webpack_require__("8946"),
addHours:__webpack_require__("1cc6"),
addISOYears:__webpack_require__("27a1"),
addMilliseconds:__webpack_require__("ec1f"),
addMinutes:__webpack_require__("72b7"),
addMonths:__webpack_require__("6665"),
addQuarters:__webpack_require__("f5dd"),
addSeconds:__webpack_require__("af1b"),
addWeeks:__webpack_require__("7a83"),
addYears:__webpack_require__("fcb3"),
areRangesOverlapping:__webpack_require__("eaa5"),
closestIndexTo:__webpack_require__("7fd8"),
closestTo:__webpack_require__("4f67"),
compareAsc:__webpack_require__("0d3e"),
compareDesc:__webpack_require__("c873"),
differenceInCalendarDays:__webpack_require__("d420"),
differenceInCalendarISOWeeks:__webpack_require__("82dc"),
differenceInCalendarISOYears:__webpack_require__("f9ff"),
differenceInCalendarMonths:__webpack_require__("b2e9"),
differenceInCalendarQuarters:__webpack_require__("fb36"),
differenceInCalendarWeeks:__webpack_require__("2f1a"),
differenceInCalendarYears:__webpack_require__("2a9c"),
differenceInDays:__webpack_require__("3bc7"),
differenceInHours:__webpack_require__("d2ed"),
differenceInISOYears:__webpack_require__("b3f5"),
differenceInMilliseconds:__webpack_require__("e785"),
differenceInMinutes:__webpack_require__("6570"),
differenceInMonths:__webpack_require__("17cd"),
differenceInQuarters:__webpack_require__("8301"),
differenceInSeconds:__webpack_require__("e13a"),
differenceInWeeks:__webpack_require__("ee91"),
differenceInYears:__webpack_require__("6fcc"),
distanceInWords:__webpack_require__("366b"),
distanceInWordsStrict:__webpack_require__("bb7c"),
distanceInWordsToNow:__webpack_require__("6254"),
eachDay:__webpack_require__("c4c2"),
endOfDay:__webpack_require__("9744"),
endOfHour:__webpack_require__("271a"),
endOfISOWeek:__webpack_require__("4175"),
endOfISOYear:__webpack_require__("861d"),
endOfMinute:__webpack_require__("3ac3"),
endOfMonth:__webpack_require__("d6f8"),
endOfQuarter:__webpack_require__("3691"),
endOfSecond:__webpack_require__("145e"),
endOfToday:__webpack_require__("7443"),
endOfTomorrow:__webpack_require__("6f4e"),
endOfWeek:__webpack_require__("7494"),
endOfYear:__webpack_require__("d975"),
endOfYesterday:__webpack_require__("e51d"),
format:__webpack_require__("70f2"),
getDate:__webpack_require__("b60f"),
getDay:__webpack_require__("c2b5"),
getDayOfYear:__webpack_require__("580f"),
getDaysInMonth:__webpack_require__("5416"),
getDaysInYear:__webpack_require__("dddf"),
getHours:__webpack_require__("5d95"),
getISODay:__webpack_require__("84b9"),
getISOWeek:__webpack_require__("81fc"),
getISOWeeksInYear:__webpack_require__("3b7b"),
getISOYear:__webpack_require__("8964"),
getMilliseconds:__webpack_require__("8c81"),
getMinutes:__webpack_require__("c589"),
getMonth:__webpack_require__("7338"),
getOverlappingDaysInRanges:__webpack_require__("6337"),
getQuarter:__webpack_require__("b8f9"),
getSeconds:__webpack_require__("231c"),
getTime:__webpack_require__("902e"),
getYear:__webpack_require__("10c8"),
isAfter:__webpack_require__("a431"),
isBefore:__webpack_require__("6b8f"),
isDate:__webpack_require__("a735"),
isEqual:__webpack_require__("abd4"),
isFirstDayOfMonth:__webpack_require__("353e"),
isFriday:__webpack_require__("a852"),
isFuture:__webpack_require__("2b67"),
isLastDayOfMonth:__webpack_require__("3eee"),
isLeapYear:__webpack_require__("acc4"),
isMonday:__webpack_require__("2507"),
isPast:__webpack_require__("a935"),
isSameDay:__webpack_require__("fd39"),
isSameHour:__webpack_require__("662a"),
isSameISOWeek:__webpack_require__("ccce"),
isSameISOYear:__webpack_require__("2fff"),
isSameMinute:__webpack_require__("f564"),
isSameMonth:__webpack_require__("5a60"),
isSameQuarter:__webpack_require__("9aaa"),
isSameSecond:__webpack_require__("c6ae"),
isSameWeek:__webpack_require__("1baf"),
isSameYear:__webpack_require__("26d5"),
isSaturday:__webpack_require__("48a6"),
isSunday:__webpack_require__("2b57"),
isThisHour:__webpack_require__("0157"),
isThisISOWeek:__webpack_require__("cc64"),
isThisISOYear:__webpack_require__("97af"),
isThisMinute:__webpack_require__("3ef9"),
isThisMonth:__webpack_require__("9bb9"),
isThisQuarter:__webpack_require__("2a80"),
isThisSecond:__webpack_require__("e620"),
isThisWeek:__webpack_require__("2d23"),
isThisYear:__webpack_require__("f66d"),
isThursday:__webpack_require__("5a38"),
isToday:__webpack_require__("30d1"),
isTomorrow:__webpack_require__("20b1"),
isTuesday:__webpack_require__("7606"),
isValid:__webpack_require__("7eea"),
isWednesday:__webpack_require__("c980"),
isWeekend:__webpack_require__("9ad8"),
isWithinRange:__webpack_require__("f56a"),
isYesterday:__webpack_require__("c4f9"),
lastDayOfISOWeek:__webpack_require__("5292"),
lastDayOfISOYear:__webpack_require__("de13"),
lastDayOfMonth:__webpack_require__("eca2"),
lastDayOfQuarter:__webpack_require__("ce3d"),
lastDayOfWeek:__webpack_require__("cb96"),
lastDayOfYear:__webpack_require__("b8a7"),
max:__webpack_require__("95ea"),
min:__webpack_require__("1a84"),
parse:__webpack_require__("c8d5"),
setDate:__webpack_require__("957f"),
setDay:__webpack_require__("b78a"),
setDayOfYear:__webpack_require__("9530"),
setHours:__webpack_require__("6f00"),
setISODay:__webpack_require__("fa76"),
setISOWeek:__webpack_require__("e73d"),
setISOYear:__webpack_require__("9706"),
setMilliseconds:__webpack_require__("d473"),
setMinutes:__webpack_require__("8aed"),
setMonth:__webpack_require__("3814"),
setQuarter:__webpack_require__("158b"),
setSeconds:__webpack_require__("9113"),
setYear:__webpack_require__("2f8f"),
startOfDay:__webpack_require__("0978"),
startOfHour:__webpack_require__("fbaf"),
startOfISOWeek:__webpack_require__("b4c7"),
startOfISOYear:__webpack_require__("4497"),
startOfMinute:__webpack_require__("e96b"),
startOfMonth:__webpack_require__("942b"),
startOfQuarter:__webpack_require__("4399"),
startOfSecond:__webpack_require__("2299"),
startOfToday:__webpack_require__("3cae"),
startOfTomorrow:__webpack_require__("8148"),
startOfWeek:__webpack_require__("c7ce"),
startOfYear:__webpack_require__("a4b7"),
startOfYesterday:__webpack_require__("693a"),
subDays:__webpack_require__("e2ff"),
subHours:__webpack_require__("fb98"),
subISOYears:__webpack_require__("df35"),
subMilliseconds:__webpack_require__("badb"),
subMinutes:__webpack_require__("18b7"),
subMonths:__webpack_require__("12fd"),
subQuarters:__webpack_require__("d4ae"),
subSeconds:__webpack_require__("83f0"),
subWeeks:__webpack_require__("e1ca"),
subYears:__webpack_require__("8902")};



/***/},

/***/"353e":
/***/function e(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Is the given date the first day of a month?
 *
 * @description
 * Is the given date the first day of a month?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is the first day of a month
 *
 * @example
 * // Is 1 September 2014 the first day of a month?
 * var result = isFirstDayOfMonth(new Date(2014, 8, 1))
 * //=> true
 */
function isFirstDayOfMonth(dirtyDate){
return parse(dirtyDate).getDate()===1;
}

module.exports=isFirstDayOfMonth;


/***/},

/***/"355d":
/***/function d(module,exports){

exports.f={}.propertyIsEnumerable;


/***/},

/***/"35e8":
/***/function e8(module,exports,__webpack_require__){

var dP=__webpack_require__("d9f6");
var createDesc=__webpack_require__("aebd");
module.exports=__webpack_require__("8e60")?function(object,key,value){
return dP.f(object,key,createDesc(1,value));
}:function(object,key,value){
object[key]=value;
return object;
};


/***/},

/***/"366b":
/***/function b(module,exports,__webpack_require__){

var compareDesc=__webpack_require__("c873");
var parse=__webpack_require__("c8d5");
var differenceInSeconds=__webpack_require__("e13a");
var differenceInMonths=__webpack_require__("17cd");
var enLocale=__webpack_require__("52cf");

var MINUTES_IN_DAY=1440;
var MINUTES_IN_ALMOST_TWO_DAYS=2520;
var MINUTES_IN_MONTH=43200;
var MINUTES_IN_TWO_MONTHS=86400;

/**
 * @category Common Helpers
 * @summary Return the distance between the given dates in words.
 *
 * @description
 * Return the distance between the given dates in words.
 *
 * | Distance between dates                                            | Result              |
 * |-------------------------------------------------------------------|---------------------|
 * | 0 ... 30 secs                                                     | less than a minute  |
 * | 30 secs ... 1 min 30 secs                                         | 1 minute            |
 * | 1 min 30 secs ... 44 mins 30 secs                                 | [2..44] minutes     |
 * | 44 mins ... 30 secs ... 89 mins 30 secs                           | about 1 hour        |
 * | 89 mins 30 secs ... 23 hrs 59 mins 30 secs                        | about [2..24] hours |
 * | 23 hrs 59 mins 30 secs ... 41 hrs 59 mins 30 secs                 | 1 day               |
 * | 41 hrs 59 mins 30 secs ... 29 days 23 hrs 59 mins 30 secs         | [2..30] days        |
 * | 29 days 23 hrs 59 mins 30 secs ... 44 days 23 hrs 59 mins 30 secs | about 1 month       |
 * | 44 days 23 hrs 59 mins 30 secs ... 59 days 23 hrs 59 mins 30 secs | about 2 months      |
 * | 59 days 23 hrs 59 mins 30 secs ... 1 yr                           | [2..12] months      |
 * | 1 yr ... 1 yr 3 months                                            | about 1 year        |
 * | 1 yr 3 months ... 1 yr 9 month s                                  | over 1 year         |
 * | 1 yr 9 months ... 2 yrs                                           | almost 2 years      |
 * | N yrs ... N yrs 3 months                                          | about N years       |
 * | N yrs 3 months ... N yrs 9 months                                 | over N years        |
 * | N yrs 9 months ... N+1 yrs                                        | almost N+1 years    |
 *
 * With `options.includeSeconds == true`:
 * | Distance between dates | Result               |
 * |------------------------|----------------------|
 * | 0 secs ... 5 secs      | less than 5 seconds  |
 * | 5 secs ... 10 secs     | less than 10 seconds |
 * | 10 secs ... 20 secs    | less than 20 seconds |
 * | 20 secs ... 40 secs    | half a minute        |
 * | 40 secs ... 60 secs    | less than a minute   |
 * | 60 secs ... 90 secs    | 1 minute             |
 *
 * @param {Date|String|Number} dateToCompare - the date to compare with
 * @param {Date|String|Number} date - the other date
 * @param {Object} [options] - the object with options
 * @param {Boolean} [options.includeSeconds=false] - distances less than a minute are more detailed
 * @param {Boolean} [options.addSuffix=false] - result indicates if the second date is earlier or later than the first
 * @param {Object} [options.locale=enLocale] - the locale object
 * @returns {String} the distance in words
 *
 * @example
 * // What is the distance between 2 July 2014 and 1 January 2015?
 * var result = distanceInWords(
 *   new Date(2014, 6, 2),
 *   new Date(2015, 0, 1)
 * )
 * //=> '6 months'
 *
 * @example
 * // What is the distance between 1 January 2015 00:00:15
 * // and 1 January 2015 00:00:00, including seconds?
 * var result = distanceInWords(
 *   new Date(2015, 0, 1, 0, 0, 15),
 *   new Date(2015, 0, 1, 0, 0, 0),
 *   {includeSeconds: true}
 * )
 * //=> 'less than 20 seconds'
 *
 * @example
 * // What is the distance from 1 January 2016
 * // to 1 January 2015, with a suffix?
 * var result = distanceInWords(
 *   new Date(2016, 0, 1),
 *   new Date(2015, 0, 1),
 *   {addSuffix: true}
 * )
 * //=> 'about 1 year ago'
 *
 * @example
 * // What is the distance between 1 August 2016 and 1 January 2015 in Esperanto?
 * var eoLocale = require('date-fns/locale/eo')
 * var result = distanceInWords(
 *   new Date(2016, 7, 1),
 *   new Date(2015, 0, 1),
 *   {locale: eoLocale}
 * )
 * //=> 'pli ol 1 jaro'
 */
function distanceInWords(dirtyDateToCompare,dirtyDate,dirtyOptions){
var options=dirtyOptions||{};

var comparison=compareDesc(dirtyDateToCompare,dirtyDate);

var locale=options.locale;
var localize=enLocale.distanceInWords.localize;
if(locale&&locale.distanceInWords&&locale.distanceInWords.localize){
localize=locale.distanceInWords.localize;
}

var localizeOptions={
addSuffix:Boolean(options.addSuffix),
comparison:comparison};


var dateLeft,dateRight;
if(comparison>0){
dateLeft=parse(dirtyDateToCompare);
dateRight=parse(dirtyDate);
}else {
dateLeft=parse(dirtyDate);
dateRight=parse(dirtyDateToCompare);
}

var seconds=differenceInSeconds(dateRight,dateLeft);
var offset=dateRight.getTimezoneOffset()-dateLeft.getTimezoneOffset();
var minutes=Math.round(seconds/60)-offset;
var months;

// 0 up to 2 mins
if(minutes<2){
if(options.includeSeconds){
if(seconds<5){
return localize('lessThanXSeconds',5,localizeOptions);
}else if(seconds<10){
return localize('lessThanXSeconds',10,localizeOptions);
}else if(seconds<20){
return localize('lessThanXSeconds',20,localizeOptions);
}else if(seconds<40){
return localize('halfAMinute',null,localizeOptions);
}else if(seconds<60){
return localize('lessThanXMinutes',1,localizeOptions);
}else {
return localize('xMinutes',1,localizeOptions);
}
}else {
if(minutes===0){
return localize('lessThanXMinutes',1,localizeOptions);
}else {
return localize('xMinutes',minutes,localizeOptions);
}
}

// 2 mins up to 0.75 hrs
}else if(minutes<45){
return localize('xMinutes',minutes,localizeOptions);

// 0.75 hrs up to 1.5 hrs
}else if(minutes<90){
return localize('aboutXHours',1,localizeOptions);

// 1.5 hrs up to 24 hrs
}else if(minutes<MINUTES_IN_DAY){
var hours=Math.round(minutes/60);
return localize('aboutXHours',hours,localizeOptions);

// 1 day up to 1.75 days
}else if(minutes<MINUTES_IN_ALMOST_TWO_DAYS){
return localize('xDays',1,localizeOptions);

// 1.75 days up to 30 days
}else if(minutes<MINUTES_IN_MONTH){
var days=Math.round(minutes/MINUTES_IN_DAY);
return localize('xDays',days,localizeOptions);

// 1 month up to 2 months
}else if(minutes<MINUTES_IN_TWO_MONTHS){
months=Math.round(minutes/MINUTES_IN_MONTH);
return localize('aboutXMonths',months,localizeOptions);
}

months=differenceInMonths(dateRight,dateLeft);

// 2 months up to 12 months
if(months<12){
var nearestMonth=Math.round(minutes/MINUTES_IN_MONTH);
return localize('xMonths',nearestMonth,localizeOptions);

// 1 year up to max Date
}else {
var monthsSinceStartOfYear=months%12;
var years=Math.floor(months/12);

// N years up to 1 years 3 months
if(monthsSinceStartOfYear<3){
return localize('aboutXYears',years,localizeOptions);

// N years 3 months up to N years 9 months
}else if(monthsSinceStartOfYear<9){
return localize('overXYears',years,localizeOptions);

// N years 9 months up to N year 12 months
}else {
return localize('almostXYears',years+1,localizeOptions);
}
}
}

module.exports=distanceInWords;


/***/},

/***/"3691":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Quarter Helpers
 * @summary Return the end of a year quarter for the given date.
 *
 * @description
 * Return the end of a year quarter for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of a quarter
 *
 * @example
 * // The end of a quarter for 2 September 2014 11:55:00:
 * var result = endOfQuarter(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 30 2014 23:59:59.999
 */
function endOfQuarter(dirtyDate){
var date=parse(dirtyDate);
var currentMonth=date.getMonth();
var month=currentMonth-currentMonth%3+3;
date.setMonth(month,0);
date.setHours(23,59,59,999);
return date;
}

module.exports=endOfQuarter;


/***/},

/***/"36bd":
/***/function bd(module,exports,__webpack_require__){
// 22.1.3.6 Array.prototype.fill(value, start = 0, end = this.length)

var toObject=__webpack_require__("4bf8");
var toAbsoluteIndex=__webpack_require__("77f1");
var toLength=__webpack_require__("9def");
module.exports=function fill(value/* , start = 0, end = @length */){
var O=toObject(this);
var length=toLength(O.length);
var aLen=arguments.length;
var index=toAbsoluteIndex(aLen>1?arguments[1]:undefined,length);
var end=aLen>2?arguments[2]:undefined;
var endPos=end===undefined?length:toAbsoluteIndex(end,length);
while(endPos>index){O[index++]=value;}
return O;
};


/***/},

/***/"36c3":
/***/function c3(module,exports,__webpack_require__){

// to indexed object, toObject with fallback for non-array-like ES3 strings
var IObject=__webpack_require__("335c");
var defined=__webpack_require__("25eb");
module.exports=function(it){
return IObject(defined(it));
};


/***/},

/***/"37c8":
/***/function c8(module,exports,__webpack_require__){

exports.f=__webpack_require__("2b4c");


/***/},

/***/"3814":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var getDaysInMonth=__webpack_require__("5416");

/**
 * @category Month Helpers
 * @summary Set the month to the given date.
 *
 * @description
 * Set the month to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} month - the month of the new date
 * @returns {Date} the new date with the month setted
 *
 * @example
 * // Set February to 1 September 2014:
 * var result = setMonth(new Date(2014, 8, 1), 1)
 * //=> Sat Feb 01 2014 00:00:00
 */
function setMonth(dirtyDate,dirtyMonth){
var date=parse(dirtyDate);
var month=Number(dirtyMonth);
var year=date.getFullYear();
var day=date.getDate();

var dateWithDesiredMonth=new Date(0);
dateWithDesiredMonth.setFullYear(year,month,15);
dateWithDesiredMonth.setHours(0,0,0,0);
var daysInMonth=getDaysInMonth(dateWithDesiredMonth);
// Set the last day of the new month
// if the original date was the last day of the longer month
date.setMonth(month,Math.min(day,daysInMonth));
return date;
}

module.exports=setMonth;


/***/},

/***/"38fd":
/***/function fd(module,exports,__webpack_require__){

// 19.1.2.9 / 15.2.3.2 Object.getPrototypeOf(O)
var has=__webpack_require__("69a8");
var toObject=__webpack_require__("4bf8");
var IE_PROTO=__webpack_require__("613b")('IE_PROTO');
var ObjectProto=Object.prototype;

module.exports=Object.getPrototypeOf||function(O){
O=toObject(O);
if(has(O,IE_PROTO))return O[IE_PROTO];
if(typeof O.constructor=='function'&&O instanceof O.constructor){
return O.constructor.prototype;
}return O instanceof Object?ObjectProto:null;
};


/***/},

/***/"3a38":
/***/function a38(module,exports){

// 7.1.4 ToInteger
var ceil=Math.ceil;
var floor=Math.floor;
module.exports=function(it){
return isNaN(it=+it)?0:(it>0?floor:ceil)(it);
};


/***/},

/***/"3a72":
/***/function a72(module,exports,__webpack_require__){

var global=__webpack_require__("7726");
var core=__webpack_require__("8378");
var LIBRARY=__webpack_require__("2d00");
var wksExt=__webpack_require__("37c8");
var defineProperty=__webpack_require__("86cc").f;
module.exports=function(name){
var $Symbol=core.Symbol||(core.Symbol=LIBRARY?{}:global.Symbol||{});
if(name.charAt(0)!='_'&&!(name in $Symbol))defineProperty($Symbol,name,{value:wksExt.f(name)});
};


/***/},

/***/"3ac3":
/***/function ac3(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Minute Helpers
 * @summary Return the end of a minute for the given date.
 *
 * @description
 * Return the end of a minute for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of a minute
 *
 * @example
 * // The end of a minute for 1 December 2014 22:15:45.400:
 * var result = endOfMinute(new Date(2014, 11, 1, 22, 15, 45, 400))
 * //=> Mon Dec 01 2014 22:15:59.999
 */
function endOfMinute(dirtyDate){
var date=parse(dirtyDate);
date.setSeconds(59,999);
return date;
}

module.exports=endOfMinute;


/***/},

/***/"3b7b":
/***/function b7b(module,exports,__webpack_require__){

var startOfISOYear=__webpack_require__("4497");
var addWeeks=__webpack_require__("7a83");

var MILLISECONDS_IN_WEEK=604800000;

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Get the number of weeks in an ISO week-numbering year of the given date.
 *
 * @description
 * Get the number of weeks in an ISO week-numbering year of the given date.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the number of ISO weeks in a year
 *
 * @example
 * // How many weeks are in ISO week-numbering year 2015?
 * var result = getISOWeeksInYear(new Date(2015, 1, 11))
 * //=> 53
 */
function getISOWeeksInYear(dirtyDate){
var thisYear=startOfISOYear(dirtyDate);
var nextYear=startOfISOYear(addWeeks(thisYear,60));
var diff=nextYear.valueOf()-thisYear.valueOf();
// Round the number of weeks to the nearest integer
// because the number of milliseconds in a week is not constant
// (e.g. it's different in the week of the daylight saving time clock shift)
return Math.round(diff/MILLISECONDS_IN_WEEK);
}

module.exports=getISOWeeksInYear;


/***/},

/***/"3bc7":
/***/function bc7(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var differenceInCalendarDays=__webpack_require__("d420");
var compareAsc=__webpack_require__("0d3e");

/**
 * @category Day Helpers
 * @summary Get the number of full days between the given dates.
 *
 * @description
 * Get the number of full days between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of full days
 *
 * @example
 * // How many full days are between
 * // 2 July 2011 23:00:00 and 2 July 2012 00:00:00?
 * var result = differenceInDays(
 *   new Date(2012, 6, 2, 0, 0),
 *   new Date(2011, 6, 2, 23, 0)
 * )
 * //=> 365
 */
function differenceInDays(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);

var sign=compareAsc(dateLeft,dateRight);
var difference=Math.abs(differenceInCalendarDays(dateLeft,dateRight));
dateLeft.setDate(dateLeft.getDate()-sign*difference);

// Math.abs(diff in full days - diff in calendar days) === 1 if last calendar day is not full
// If so, result must be decreased by 1 in absolute value
var isLastDayNotFull=compareAsc(dateLeft,dateRight)===-sign;
return sign*(difference-isLastDayNotFull);
}

module.exports=differenceInDays;


/***/},

/***/"3bec":
/***/function bec(module,exports,__webpack_require__){

var buildFormattingTokensRegExp=__webpack_require__("90e5");

function buildFormatLocale(){
var months3char=['ene','feb','mar','abr','may','jun','jul','ago','sep','oct','nov','dic'];
var monthsFull=['enero','febrero','marzo','abril','mayo','junio','julio','agosto','septiembre','octubre','noviembre','diciembre'];
var weekdays2char=['do','lu','ma','mi','ju','vi','sa'];
var weekdays3char=['dom','lun','mar','mié','jue','vie','sáb'];
var weekdaysFull=['domingo','lunes','martes','miércoles','jueves','viernes','sábado'];
var meridiemUppercase=['AM','PM'];
var meridiemLowercase=['am','pm'];
var meridiemFull=['a.m.','p.m.'];

var formatters={
// Month: Jan, Feb, ..., Dec
'MMM':function MMM(date){
return months3char[date.getMonth()];
},

// Month: January, February, ..., December
'MMMM':function MMMM(date){
return monthsFull[date.getMonth()];
},

// Day of week: Su, Mo, ..., Sa
'dd':function dd(date){
return weekdays2char[date.getDay()];
},

// Day of week: Sun, Mon, ..., Sat
'ddd':function ddd(date){
return weekdays3char[date.getDay()];
},

// Day of week: Sunday, Monday, ..., Saturday
'dddd':function dddd(date){
return weekdaysFull[date.getDay()];
},

// AM, PM
'A':function A(date){
return date.getHours()/12>=1?meridiemUppercase[1]:meridiemUppercase[0];
},

// am, pm
'a':function a(date){
return date.getHours()/12>=1?meridiemLowercase[1]:meridiemLowercase[0];
},

// a.m., p.m.
'aa':function aa(date){
return date.getHours()/12>=1?meridiemFull[1]:meridiemFull[0];
}};


// Generate ordinal version of formatters: M -> Mo, D -> Do, etc.
var ordinalFormatters=['M','D','DDD','d','Q','W'];
ordinalFormatters.forEach(function(formatterToken){
formatters[formatterToken+'o']=function(date,formatters){
return ordinal(formatters[formatterToken](date));
};
});

return {
formatters:formatters,
formattingTokensRegExp:buildFormattingTokensRegExp(formatters)};

}

function ordinal(number){
return number+'º';
}

module.exports=buildFormatLocale;


/***/},

/***/"3cae":
/***/function cae(module,exports,__webpack_require__){

var startOfDay=__webpack_require__("0978");

/**
 * @category Day Helpers
 * @summary Return the start of today.
 *
 * @description
 * Return the start of today.
 *
 * @returns {Date} the start of today
 *
 * @example
 * // If today is 6 October 2014:
 * var result = startOfToday()
 * //=> Mon Oct 6 2014 00:00:00
 */
function startOfToday(){
return startOfDay(new Date());
}

module.exports=startOfToday;


/***/},

/***/"3eee":
/***/function eee(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var endOfDay=__webpack_require__("9744");
var endOfMonth=__webpack_require__("d6f8");

/**
 * @category Month Helpers
 * @summary Is the given date the last day of a month?
 *
 * @description
 * Is the given date the last day of a month?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is the last day of a month
 *
 * @example
 * // Is 28 February 2014 the last day of a month?
 * var result = isLastDayOfMonth(new Date(2014, 1, 28))
 * //=> true
 */
function isLastDayOfMonth(dirtyDate){
var date=parse(dirtyDate);
return endOfDay(date).getTime()===endOfMonth(date).getTime();
}

module.exports=isLastDayOfMonth;


/***/},

/***/"3ef9":
/***/function ef9(module,exports,__webpack_require__){

var isSameMinute=__webpack_require__("f564");

/**
 * @category Minute Helpers
 * @summary Is the given date in the same minute as the current date?
 *
 * @description
 * Is the given date in the same minute as the current date?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this minute
 *
 * @example
 * // If now is 25 September 2014 18:30:15.500,
 * // is 25 September 2014 18:30:00 in this minute?
 * var result = isThisMinute(new Date(2014, 8, 25, 18, 30))
 * //=> true
 */
function isThisMinute(dirtyDate){
return isSameMinute(new Date(),dirtyDate);
}

module.exports=isThisMinute;


/***/},

/***/"40c3":
/***/function c3(module,exports,__webpack_require__){

// getting tag from 19.1.3.6 Object.prototype.toString()
var cof=__webpack_require__("6b4c");
var TAG=__webpack_require__("5168")('toStringTag');
// ES3 wrong here
var ARG=cof(function(){return arguments;}())=='Arguments';

// fallback for IE11 Script Access Denied error
var tryGet=function tryGet(it,key){
try{
return it[key];
}catch(e){/* empty */}
};

module.exports=function(it){
var O,T,B;
return it===undefined?'Undefined':it===null?'Null'
// @@toStringTag case
:typeof(T=tryGet(O=Object(it),TAG))=='string'?T
// builtinTag case
:ARG?cof(O)
// ES3 arguments fallback
:(B=cof(O))=='Object'&&typeof O.callee=='function'?'Arguments':B;
};


/***/},

/***/"4175":
/***/function _(module,exports,__webpack_require__){

var endOfWeek=__webpack_require__("7494");

/**
 * @category ISO Week Helpers
 * @summary Return the end of an ISO week for the given date.
 *
 * @description
 * Return the end of an ISO week for the given date.
 * The result will be in the local timezone.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of an ISO week
 *
 * @example
 * // The end of an ISO week for 2 September 2014 11:55:00:
 * var result = endOfISOWeek(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Sun Sep 07 2014 23:59:59.999
 */
function endOfISOWeek(dirtyDate){
return endOfWeek(dirtyDate,{weekStartsOn:1});
}

module.exports=endOfISOWeek;


/***/},

/***/"41a0":
/***/function a0(module,exports,__webpack_require__){

var create=__webpack_require__("2aeb");
var descriptor=__webpack_require__("4630");
var setToStringTag=__webpack_require__("7f20");
var IteratorPrototype={};

// 25.1.2.1.1 %IteratorPrototype%[@@iterator]()
__webpack_require__("32e9")(IteratorPrototype,__webpack_require__("2b4c")('iterator'),function(){return this;});

module.exports=function(Constructor,NAME,next){
Constructor.prototype=create(IteratorPrototype,{next:descriptor(1,next)});
setToStringTag(Constructor,NAME+' Iterator');
};


/***/},

/***/"4399":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Quarter Helpers
 * @summary Return the start of a year quarter for the given date.
 *
 * @description
 * Return the start of a year quarter for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of a quarter
 *
 * @example
 * // The start of a quarter for 2 September 2014 11:55:00:
 * var result = startOfQuarter(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Jul 01 2014 00:00:00
 */
function startOfQuarter(dirtyDate){
var date=parse(dirtyDate);
var currentMonth=date.getMonth();
var month=currentMonth-currentMonth%3;
date.setMonth(month,1);
date.setHours(0,0,0,0);
return date;
}

module.exports=startOfQuarter;


/***/},

/***/"4497":
/***/function _(module,exports,__webpack_require__){

var getISOYear=__webpack_require__("8964");
var startOfISOWeek=__webpack_require__("b4c7");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Return the start of an ISO week-numbering year for the given date.
 *
 * @description
 * Return the start of an ISO week-numbering year,
 * which always starts 3 days before the year's first Thursday.
 * The result will be in the local timezone.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of an ISO year
 *
 * @example
 * // The start of an ISO week-numbering year for 2 July 2005:
 * var result = startOfISOYear(new Date(2005, 6, 2))
 * //=> Mon Jan 03 2005 00:00:00
 */
function startOfISOYear(dirtyDate){
var year=getISOYear(dirtyDate);
var fourthOfJanuary=new Date(0);
fourthOfJanuary.setFullYear(year,0,4);
fourthOfJanuary.setHours(0,0,0,0);
var date=startOfISOWeek(fourthOfJanuary);
return date;
}

module.exports=startOfISOYear;


/***/},

/***/"454f":
/***/function f(module,exports,__webpack_require__){

__webpack_require__("46a7");
var $Object=__webpack_require__("584a").Object;
module.exports=function defineProperty(it,key,desc){
return $Object.defineProperty(it,key,desc);
};


/***/},

/***/"456d":
/***/function d(module,exports,__webpack_require__){

// 19.1.2.14 Object.keys(O)
var toObject=__webpack_require__("4bf8");
var $keys=__webpack_require__("0d58");

__webpack_require__("5eda")('keys',function(){
return function keys(it){
return $keys(toObject(it));
};
});


/***/},

/***/"4588":
/***/function _(module,exports){

// 7.1.4 ToInteger
var ceil=Math.ceil;
var floor=Math.floor;
module.exports=function(it){
return isNaN(it=+it)?0:(it>0?floor:ceil)(it);
};


/***/},

/***/"45f2":
/***/function f2(module,exports,__webpack_require__){

var def=__webpack_require__("d9f6").f;
var has=__webpack_require__("07e3");
var TAG=__webpack_require__("5168")('toStringTag');

module.exports=function(it,tag,stat){
if(it&&!has(it=stat?it:it.prototype,TAG))def(it,TAG,{configurable:true,value:tag});
};


/***/},

/***/"4630":
/***/function _(module,exports){

module.exports=function(bitmap,value){
return {
enumerable:!(bitmap&1),
configurable:!(bitmap&2),
writable:!(bitmap&4),
value:value};

};


/***/},

/***/"469f":
/***/function f(module,exports,__webpack_require__){

__webpack_require__("6c1c");
__webpack_require__("1654");
module.exports=__webpack_require__("7d7b");


/***/},

/***/"46a7":
/***/function a7(module,exports,__webpack_require__){

var $export=__webpack_require__("63b6");
// 19.1.2.4 / 15.2.3.6 Object.defineProperty(O, P, Attributes)
$export($export.S+$export.F*!__webpack_require__("8e60"),'Object',{defineProperty:__webpack_require__("d9f6").f});


/***/},

/***/"47ee":
/***/function ee(module,exports,__webpack_require__){

// all enumerable object keys, includes symbols
var getKeys=__webpack_require__("c3a1");
var gOPS=__webpack_require__("9aa9");
var pIE=__webpack_require__("355d");
module.exports=function(it){
var result=getKeys(it);
var getSymbols=gOPS.f;
if(getSymbols){
var symbols=getSymbols(it);
var isEnum=pIE.f;
var i=0;
var key;
while(symbols.length>i){if(isEnum.call(it,key=symbols[i++]))result.push(key);}
}return result;
};


/***/},

/***/"481b":
/***/function b(module,exports){

module.exports={};


/***/},

/***/"48a6":
/***/function a6(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Is the given date Saturday?
 *
 * @description
 * Is the given date Saturday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is Saturday
 *
 * @example
 * // Is 27 September 2014 Saturday?
 * var result = isSaturday(new Date(2014, 8, 27))
 * //=> true
 */
function isSaturday(dirtyDate){
return parse(dirtyDate).getDay()===6;
}

module.exports=isSaturday;


/***/},

/***/"4aa6":
/***/function aa6(module,exports,__webpack_require__){

module.exports=__webpack_require__("dc62");

/***/},

/***/"4bf8":
/***/function bf8(module,exports,__webpack_require__){

// 7.1.13 ToObject(argument)
var defined=__webpack_require__("be13");
module.exports=function(it){
return Object(defined(it));
};


/***/},

/***/"4c70":
/***/function c70(module,exports,__webpack_require__){

var buildFormattingTokensRegExp=__webpack_require__("90e5");

function buildFormatLocale(){
// Note: in German, the names of days of the week and months are capitalized.
// If you are making a new locale based on this one, check if the same is true for the language you're working on.
// Generally, formatted dates should look like they are in the middle of a sentence,
// e.g. in Spanish language the weekdays and months should be in the lowercase.
var months3char=['Jan','Feb','Mär','Apr','Mai','Jun','Jul','Aug','Sep','Okt','Nov','Dez'];
var monthsFull=['Januar','Februar','März','April','Mai','Juni','Juli','August','September','Oktober','November','Dezember'];
var weekdays2char=['So','Mo','Di','Mi','Do','Fr','Sa'];
var weekdays3char=['Son','Mon','Die','Mit','Don','Fre','Sam'];
var weekdaysFull=['Sonntag','Montag','Dienstag','Mittwoch','Donnerstag','Freitag','Samstag'];
var meridiemUppercase=['AM','PM'];
var meridiemLowercase=['am','pm'];
var meridiemFull=['a.m.','p.m.'];

var formatters={
// Month: Jan, Feb, ..., Dec
'MMM':function MMM(date){
return months3char[date.getMonth()];
},

// Month: January, February, ..., December
'MMMM':function MMMM(date){
return monthsFull[date.getMonth()];
},

// Day of week: Su, Mo, ..., Sa
'dd':function dd(date){
return weekdays2char[date.getDay()];
},

// Day of week: Sun, Mon, ..., Sat
'ddd':function ddd(date){
return weekdays3char[date.getDay()];
},

// Day of week: Sunday, Monday, ..., Saturday
'dddd':function dddd(date){
return weekdaysFull[date.getDay()];
},

// AM, PM
'A':function A(date){
return date.getHours()/12>=1?meridiemUppercase[1]:meridiemUppercase[0];
},

// am, pm
'a':function a(date){
return date.getHours()/12>=1?meridiemLowercase[1]:meridiemLowercase[0];
},

// a.m., p.m.
'aa':function aa(date){
return date.getHours()/12>=1?meridiemFull[1]:meridiemFull[0];
}};


// Generate ordinal version of formatters: M -> Mo, D -> Do, etc.
var ordinalFormatters=['M','D','DDD','d','Q','W'];
ordinalFormatters.forEach(function(formatterToken){
formatters[formatterToken+'o']=function(date,formatters){
return ordinal(formatters[formatterToken](date));
};
});

return {
formatters:formatters,
formattingTokensRegExp:buildFormattingTokensRegExp(formatters)};

}

function ordinal(number){
return number+'.';
}

module.exports=buildFormatLocale;


/***/},

/***/"4c9f":
/***/function c9f(module,exports,__webpack_require__){

var formatDate=__webpack_require__("70f2");

function createDateFilter(defaultFormat,defaultOptions){
return function dateFilter(date,format,opts){
if(!date){
return "";
}
return formatDate(date,format||defaultFormat,Object.assign(defaultOptions||{},opts));
};
}

function install(Vue,defaultFormat,defaultOptions,globalFilterName){
var dateFilter=createDateFilter(defaultFormat,defaultOptions);
globalFilterName=globalFilterName||"date";

Vue.filter(globalFilterName,dateFilter);

var methods={};
methods["$"+globalFilterName]=dateFilter;

Vue.mixin({methods:methods});
}

module.exports=install;

module.exports.createDateFilter=createDateFilter;

module.exports.dateFilter=createDateFilter();


/***/},

/***/"4d16":
/***/function d16(module,exports,__webpack_require__){

module.exports=__webpack_require__("25b0");

/***/},

/***/"4f67":
/***/function f67(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Return a date from the array closest to the given date.
 *
 * @description
 * Return a date from the array closest to the given date.
 *
 * @param {Date|String|Number} dateToCompare - the date to compare with
 * @param {Date[]|String[]|Number[]} datesArray - the array to search
 * @returns {Date} the date from the array closest to the given date
 * @throws {TypeError} the second argument must be an instance of Array
 *
 * @example
 * // Which date is closer to 6 September 2015: 1 January 2000 or 1 January 2030?
 * var dateToCompare = new Date(2015, 8, 6)
 * var result = closestTo(dateToCompare, [
 *   new Date(2000, 0, 1),
 *   new Date(2030, 0, 1)
 * ])
 * //=> Tue Jan 01 2030 00:00:00
 */
function closestTo(dirtyDateToCompare,dirtyDatesArray){
if(!(dirtyDatesArray instanceof Array)){
throw new TypeError(toString.call(dirtyDatesArray)+' is not an instance of Array');
}

var dateToCompare=parse(dirtyDateToCompare);
var timeToCompare=dateToCompare.getTime();

var result;
var minDistance;

dirtyDatesArray.forEach(function(dirtyDate){
var currentDate=parse(dirtyDate);
var distance=Math.abs(timeToCompare-currentDate.getTime());
if(result===undefined||distance<minDistance){
result=currentDate;
minDistance=distance;
}
});

return result;
}

module.exports=closestTo;


/***/},

/***/"50ed":
/***/function ed(module,exports){

module.exports=function(done,value){
return {value:value,done:!!done};
};


/***/},

/***/"5140":
/***/function _(module,exports,__webpack_require__){

var buildFormattingTokensRegExp=__webpack_require__("90e5");

function buildFormatLocale(){
// http://new.gramota.ru/spravka/buro/search-answer?s=242637
var monthsShort=['янв.','фев.','март','апр.','май','июнь','июль','авг.','сент.','окт.','нояб.','дек.'];
var monthsFull=['январь','февраль','март','апрель','май','июнь','июль','август','сентябрь','октябрь','ноябрь','декабрь'];
var monthsGenitive=['января','февраля','марта','апреля','мая','июня','июля','августа','сентября','октября','ноября','декабря'];
var weekdays2char=['вс','пн','вт','ср','чт','пт','сб'];
var weekdays3char=['вск','пнд','втр','срд','чтв','птн','суб'];
var weekdaysFull=['воскресенье','понедельник','вторник','среда','четверг','пятница','суббота'];
var meridiem=['ночи','утра','дня','вечера'];

var formatters={
// Month: янв., фев., ..., дек.
'MMM':function MMM(date){
return monthsShort[date.getMonth()];
},

// Month: январь, февраль, ..., декабрь
'MMMM':function MMMM(date){
return monthsFull[date.getMonth()];
},

// Day of week: вс, пн, ..., сб
'dd':function dd(date){
return weekdays2char[date.getDay()];
},

// Day of week: вск, пнд, ..., суб
'ddd':function ddd(date){
return weekdays3char[date.getDay()];
},

// Day of week: воскресенье, понедельник, ..., суббота
'dddd':function dddd(date){
return weekdaysFull[date.getDay()];
},

// Time of day: ночи, утра, дня, вечера
'A':function A(date){
var hours=date.getHours();
if(hours>=17){
return meridiem[3];
}else if(hours>=12){
return meridiem[2];
}else if(hours>=4){
return meridiem[1];
}else {
return meridiem[0];
}
},

'Do':function Do(date,formatters){
return formatters.D(date)+'-е';
},

'Wo':function Wo(date,formatters){
return formatters.W(date)+'-я';
}};


formatters.a=formatters.A;
formatters.aa=formatters.A;

// Generate ordinal version of formatters: M -> Mo, DDD -> DDDo, etc.
var ordinalFormatters=['M','DDD','d','Q'];
ordinalFormatters.forEach(function(formatterToken){
formatters[formatterToken+'o']=function(date,formatters){
return formatters[formatterToken](date)+'-й';
};
});

// Generate formatters like 'D MMMM',
// where month is in the genitive case: января, февраля, ..., декабря
var monthsGenitiveFormatters=['D','Do','DD'];
monthsGenitiveFormatters.forEach(function(formatterToken){
formatters[formatterToken+' MMMM']=function(date,commonFormatters){
var formatter=formatters[formatterToken]||commonFormatters[formatterToken];
return formatter(date,commonFormatters)+' '+monthsGenitive[date.getMonth()];
};
});

return {
formatters:formatters,
formattingTokensRegExp:buildFormattingTokensRegExp(formatters)};

}

module.exports=buildFormatLocale;


/***/},

/***/"5168":
/***/function _(module,exports,__webpack_require__){

var store=__webpack_require__("dbdb")('wks');
var uid=__webpack_require__("62a0");
var Symbol=__webpack_require__("e53d").Symbol;
var USE_SYMBOL=typeof Symbol=='function';

var $exports=module.exports=function(name){
return store[name]||(store[name]=
USE_SYMBOL&&Symbol[name]||(USE_SYMBOL?Symbol:uid)('Symbol.'+name));
};

$exports.store=store;


/***/},

/***/"5292":
/***/function _(module,exports,__webpack_require__){

var lastDayOfWeek=__webpack_require__("cb96");

/**
 * @category ISO Week Helpers
 * @summary Return the last day of an ISO week for the given date.
 *
 * @description
 * Return the last day of an ISO week for the given date.
 * The result will be in the local timezone.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the last day of an ISO week
 *
 * @example
 * // The last day of an ISO week for 2 September 2014 11:55:00:
 * var result = lastDayOfISOWeek(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Sun Sep 07 2014 00:00:00
 */
function lastDayOfISOWeek(dirtyDate){
return lastDayOfWeek(dirtyDate,{weekStartsOn:1});
}

module.exports=lastDayOfISOWeek;


/***/},

/***/"52a7":
/***/function a7(module,exports){

exports.f={}.propertyIsEnumerable;


/***/},

/***/"52cf":
/***/function cf(module,exports,__webpack_require__){

var buildDistanceInWordsLocale=__webpack_require__("2d96");
var buildFormatLocale=__webpack_require__("e830");

/**
 * @category Locales
 * @summary English locale.
 */
module.exports={
distanceInWords:buildDistanceInWordsLocale(),
format:buildFormatLocale()};



/***/},

/***/"53e2":
/***/function e2(module,exports,__webpack_require__){

// 19.1.2.9 / 15.2.3.2 Object.getPrototypeOf(O)
var has=__webpack_require__("07e3");
var toObject=__webpack_require__("241e");
var IE_PROTO=__webpack_require__("5559")('IE_PROTO');
var ObjectProto=Object.prototype;

module.exports=Object.getPrototypeOf||function(O){
O=toObject(O);
if(has(O,IE_PROTO))return O[IE_PROTO];
if(typeof O.constructor=='function'&&O instanceof O.constructor){
return O.constructor.prototype;
}return O instanceof Object?ObjectProto:null;
};


/***/},

/***/"5416":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Get the number of days in a month of the given date.
 *
 * @description
 * Get the number of days in a month of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the number of days in a month
 *
 * @example
 * // How many days are in February 2000?
 * var result = getDaysInMonth(new Date(2000, 1))
 * //=> 29
 */
function getDaysInMonth(dirtyDate){
var date=parse(dirtyDate);
var year=date.getFullYear();
var monthIndex=date.getMonth();
var lastDayOfMonth=new Date(0);
lastDayOfMonth.setFullYear(year,monthIndex+1,0);
lastDayOfMonth.setHours(0,0,0,0);
return lastDayOfMonth.getDate();
}

module.exports=getDaysInMonth;


/***/},

/***/"5465":
/***/function _(module,exports){

var MILLISECONDS_IN_MINUTE=60000;

/**
 * Google Chrome as of 67.0.3396.87 introduced timezones with offset that includes seconds.
 * They usually appear for dates that denote time before the timezones were introduced
 * (e.g. for 'Europe/Prague' timezone the offset is GMT+00:57:44 before 1 October 1891
 * and GMT+01:00:00 after that date)
 *
 * Date#getTimezoneOffset returns the offset in minutes and would return 57 for the example above,
 * which would lead to incorrect calculations.
 *
 * This function returns the timezone offset in milliseconds that takes seconds in account.
 */
module.exports=function getTimezoneOffsetInMilliseconds(dirtyDate){
var date=new Date(dirtyDate.getTime());
var baseTimezoneOffset=date.getTimezoneOffset();
date.setSeconds(0,0);
var millisecondsPartOfTimezoneOffset=date.getTime()%MILLISECONDS_IN_MINUTE;

return baseTimezoneOffset*MILLISECONDS_IN_MINUTE+millisecondsPartOfTimezoneOffset;
};


/***/},

/***/"54a1":
/***/function a1(module,exports,__webpack_require__){

__webpack_require__("6c1c");
__webpack_require__("1654");
module.exports=__webpack_require__("95d5");


/***/},

/***/"5537":
/***/function _(module,exports,__webpack_require__){

var core=__webpack_require__("8378");
var global=__webpack_require__("7726");
var SHARED='__core-js_shared__';
var store=global[SHARED]||(global[SHARED]={});

(module.exports=function(key,value){
return store[key]||(store[key]=value!==undefined?value:{});
})('versions',[]).push({
version:core.version,
mode:__webpack_require__("2d00")?'pure':'global',
copyright:'© 2019 Denis Pushkarev (zloirock.ru)'});



/***/},

/***/"5559":
/***/function _(module,exports,__webpack_require__){

var shared=__webpack_require__("dbdb")('keys');
var uid=__webpack_require__("62a0");
module.exports=function(key){
return shared[key]||(shared[key]=uid(key));
};


/***/},

/***/"580f":
/***/function f(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var startOfYear=__webpack_require__("a4b7");
var differenceInCalendarDays=__webpack_require__("d420");

/**
 * @category Day Helpers
 * @summary Get the day of the year of the given date.
 *
 * @description
 * Get the day of the year of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the day of year
 *
 * @example
 * // Which day of the year is 2 July 2014?
 * var result = getDayOfYear(new Date(2014, 6, 2))
 * //=> 183
 */
function getDayOfYear(dirtyDate){
var date=parse(dirtyDate);
var diff=differenceInCalendarDays(date,startOfYear(date));
var dayOfYear=diff+1;
return dayOfYear;
}

module.exports=getDayOfYear;


/***/},

/***/"584a":
/***/function a(module,exports){

var core=module.exports={version:'2.6.9'};
if(typeof __e=='number')__e=core;// eslint-disable-line no-undef


/***/},

/***/"5a38":
/***/function a38(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Is the given date Thursday?
 *
 * @description
 * Is the given date Thursday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is Thursday
 *
 * @example
 * // Is 25 September 2014 Thursday?
 * var result = isThursday(new Date(2014, 8, 25))
 * //=> true
 */
function isThursday(dirtyDate){
return parse(dirtyDate).getDay()===4;
}

module.exports=isThursday;


/***/},

/***/"5a60":
/***/function a60(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Are the given dates in the same month?
 *
 * @description
 * Are the given dates in the same month?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same month
 *
 * @example
 * // Are 2 September 2014 and 25 September 2014 in the same month?
 * var result = isSameMonth(
 *   new Date(2014, 8, 2),
 *   new Date(2014, 8, 25)
 * )
 * //=> true
 */
function isSameMonth(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);
return dateLeft.getFullYear()===dateRight.getFullYear()&&
dateLeft.getMonth()===dateRight.getMonth();
}

module.exports=isSameMonth;


/***/},

/***/"5b4e":
/***/function b4e(module,exports,__webpack_require__){

// false -> Array#indexOf
// true  -> Array#includes
var toIObject=__webpack_require__("36c3");
var toLength=__webpack_require__("b447");
var toAbsoluteIndex=__webpack_require__("0fc9");
module.exports=function(IS_INCLUDES){
return function($this,el,fromIndex){
var O=toIObject($this);
var length=toLength(O.length);
var index=toAbsoluteIndex(fromIndex,length);
var value;
// Array#includes uses SameValueZero equality algorithm
// eslint-disable-next-line no-self-compare
if(IS_INCLUDES&&el!=el)while(length>index){
value=O[index++];
// eslint-disable-next-line no-self-compare
if(value!=value)return true;
// Array#indexOf ignores holes, Array#includes - not
}else for(;length>index;index++){if(IS_INCLUDES||index in O){
if(O[index]===el)return IS_INCLUDES||index||0;
}}return !IS_INCLUDES&&-1;
};
};


/***/},

/***/"5ca1":
/***/function ca1(module,exports,__webpack_require__){

var global=__webpack_require__("7726");
var core=__webpack_require__("8378");
var hide=__webpack_require__("32e9");
var redefine=__webpack_require__("2aba");
var ctx=__webpack_require__("9b43");
var PROTOTYPE='prototype';

var $export=function $export(type,name,source){
var IS_FORCED=type&$export.F;
var IS_GLOBAL=type&$export.G;
var IS_STATIC=type&$export.S;
var IS_PROTO=type&$export.P;
var IS_BIND=type&$export.B;
var target=IS_GLOBAL?global:IS_STATIC?global[name]||(global[name]={}):(global[name]||{})[PROTOTYPE];
var exports=IS_GLOBAL?core:core[name]||(core[name]={});
var expProto=exports[PROTOTYPE]||(exports[PROTOTYPE]={});
var key,own,out,exp;
if(IS_GLOBAL)source=name;
for(key in source){
// contains in native
own=!IS_FORCED&&target&&target[key]!==undefined;
// export native or passed
out=(own?target:source)[key];
// bind timers to global for call from export context
exp=IS_BIND&&own?ctx(out,global):IS_PROTO&&typeof out=='function'?ctx(Function.call,out):out;
// extend global
if(target)redefine(target,key,out,type&$export.U);
// export
if(exports[key]!=out)hide(exports,key,exp);
if(IS_PROTO&&expProto[key]!=out)expProto[key]=out;
}
};
global.core=core;
// type bitmap
$export.F=1;// forced
$export.G=2;// global
$export.S=4;// static
$export.P=8;// proto
$export.B=16;// bind
$export.W=32;// wrap
$export.U=64;// safe
$export.R=128;// real proto method for `library`
module.exports=$export;


/***/},

/***/"5d58":
/***/function d58(module,exports,__webpack_require__){

module.exports=__webpack_require__("d8d6");

/***/},

/***/"5d73":
/***/function d73(module,exports,__webpack_require__){

module.exports=__webpack_require__("469f");

/***/},

/***/"5d95":
/***/function d95(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Hour Helpers
 * @summary Get the hours of the given date.
 *
 * @description
 * Get the hours of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the hours
 *
 * @example
 * // Get the hours of 29 February 2012 11:45:00:
 * var result = getHours(new Date(2012, 1, 29, 11, 45))
 * //=> 11
 */
function getHours(dirtyDate){
var date=parse(dirtyDate);
var hours=date.getHours();
return hours;
}

module.exports=getHours;


/***/},

/***/"5dbc":
/***/function dbc(module,exports,__webpack_require__){

var isObject=__webpack_require__("d3f4");
var setPrototypeOf=__webpack_require__("8b97").set;
module.exports=function(that,target,C){
var S=target.constructor;
var P;
if(S!==C&&typeof S=='function'&&(P=S.prototype)!==C.prototype&&isObject(P)&&setPrototypeOf){
setPrototypeOf(that,P);
}return that;
};


/***/},

/***/"5eda":
/***/function eda(module,exports,__webpack_require__){

// most Object methods by ES6 should accept primitives
var $export=__webpack_require__("5ca1");
var core=__webpack_require__("8378");
var fails=__webpack_require__("79e5");
module.exports=function(KEY,exec){
var fn=(core.Object||{})[KEY]||Object[KEY];
var exp={};
exp[KEY]=exec(fn);
$export($export.S+$export.F*fails(function(){fn(1);}),'Object',exp);
};


/***/},

/***/"613b":
/***/function b(module,exports,__webpack_require__){

var shared=__webpack_require__("5537")('keys');
var uid=__webpack_require__("ca5a");
module.exports=function(key){
return shared[key]||(shared[key]=uid(key));
};


/***/},

/***/"6254":
/***/function _(module,exports,__webpack_require__){

var distanceInWords=__webpack_require__("366b");

/**
 * @category Common Helpers
 * @summary Return the distance between the given date and now in words.
 *
 * @description
 * Return the distance between the given date and now in words.
 *
 * | Distance to now                                                   | Result              |
 * |-------------------------------------------------------------------|---------------------|
 * | 0 ... 30 secs                                                     | less than a minute  |
 * | 30 secs ... 1 min 30 secs                                         | 1 minute            |
 * | 1 min 30 secs ... 44 mins 30 secs                                 | [2..44] minutes     |
 * | 44 mins ... 30 secs ... 89 mins 30 secs                           | about 1 hour        |
 * | 89 mins 30 secs ... 23 hrs 59 mins 30 secs                        | about [2..24] hours |
 * | 23 hrs 59 mins 30 secs ... 41 hrs 59 mins 30 secs                 | 1 day               |
 * | 41 hrs 59 mins 30 secs ... 29 days 23 hrs 59 mins 30 secs         | [2..30] days        |
 * | 29 days 23 hrs 59 mins 30 secs ... 44 days 23 hrs 59 mins 30 secs | about 1 month       |
 * | 44 days 23 hrs 59 mins 30 secs ... 59 days 23 hrs 59 mins 30 secs | about 2 months      |
 * | 59 days 23 hrs 59 mins 30 secs ... 1 yr                           | [2..12] months      |
 * | 1 yr ... 1 yr 3 months                                            | about 1 year        |
 * | 1 yr 3 months ... 1 yr 9 month s                                  | over 1 year         |
 * | 1 yr 9 months ... 2 yrs                                           | almost 2 years      |
 * | N yrs ... N yrs 3 months                                          | about N years       |
 * | N yrs 3 months ... N yrs 9 months                                 | over N years        |
 * | N yrs 9 months ... N+1 yrs                                        | almost N+1 years    |
 *
 * With `options.includeSeconds == true`:
 * | Distance to now     | Result               |
 * |---------------------|----------------------|
 * | 0 secs ... 5 secs   | less than 5 seconds  |
 * | 5 secs ... 10 secs  | less than 10 seconds |
 * | 10 secs ... 20 secs | less than 20 seconds |
 * | 20 secs ... 40 secs | half a minute        |
 * | 40 secs ... 60 secs | less than a minute   |
 * | 60 secs ... 90 secs | 1 minute             |
 *
 * @param {Date|String|Number} date - the given date
 * @param {Object} [options] - the object with options
 * @param {Boolean} [options.includeSeconds=false] - distances less than a minute are more detailed
 * @param {Boolean} [options.addSuffix=false] - result specifies if the second date is earlier or later than the first
 * @param {Object} [options.locale=enLocale] - the locale object
 * @returns {String} the distance in words
 *
 * @example
 * // If today is 1 January 2015, what is the distance to 2 July 2014?
 * var result = distanceInWordsToNow(
 *   new Date(2014, 6, 2)
 * )
 * //=> '6 months'
 *
 * @example
 * // If now is 1 January 2015 00:00:00,
 * // what is the distance to 1 January 2015 00:00:15, including seconds?
 * var result = distanceInWordsToNow(
 *   new Date(2015, 0, 1, 0, 0, 15),
 *   {includeSeconds: true}
 * )
 * //=> 'less than 20 seconds'
 *
 * @example
 * // If today is 1 January 2015,
 * // what is the distance to 1 January 2016, with a suffix?
 * var result = distanceInWordsToNow(
 *   new Date(2016, 0, 1),
 *   {addSuffix: true}
 * )
 * //=> 'in about 1 year'
 *
 * @example
 * // If today is 1 January 2015,
 * // what is the distance to 1 August 2016 in Esperanto?
 * var eoLocale = require('date-fns/locale/eo')
 * var result = distanceInWordsToNow(
 *   new Date(2016, 7, 1),
 *   {locale: eoLocale}
 * )
 * //=> 'pli ol 1 jaro'
 */
function distanceInWordsToNow(dirtyDate,dirtyOptions){
return distanceInWords(Date.now(),dirtyDate,dirtyOptions);
}

module.exports=distanceInWordsToNow;


/***/},

/***/"626a":
/***/function a(module,exports,__webpack_require__){

// fallback for non-array-like ES3 and non-enumerable old V8 strings
var cof=__webpack_require__("2d95");
// eslint-disable-next-line no-prototype-builtins
module.exports=Object('z').propertyIsEnumerable(0)?Object:function(it){
return cof(it)=='String'?it.split(''):Object(it);
};


/***/},

/***/"62a0":
/***/function a0(module,exports){

var id=0;
var px=Math.random();
module.exports=function(key){
return 'Symbol('.concat(key===undefined?'':key,')_',(++id+px).toString(36));
};


/***/},

/***/"6337":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

var MILLISECONDS_IN_DAY=24*60*60*1000;

/**
 * @category Range Helpers
 * @summary Get the number of days that overlap in two date ranges
 *
 * @description
 * Get the number of days that overlap in two date ranges
 *
 * @param {Date|String|Number} initialRangeStartDate - the start of the initial range
 * @param {Date|String|Number} initialRangeEndDate - the end of the initial range
 * @param {Date|String|Number} comparedRangeStartDate - the start of the range to compare it with
 * @param {Date|String|Number} comparedRangeEndDate - the end of the range to compare it with
 * @returns {Number} the number of days that overlap in two date ranges
 * @throws {Error} startDate of a date range cannot be after its endDate
 *
 * @example
 * // For overlapping date ranges adds 1 for each started overlapping day:
 * getOverlappingDaysInRanges(
 *   new Date(2014, 0, 10), new Date(2014, 0, 20), new Date(2014, 0, 17), new Date(2014, 0, 21)
 * )
 * //=> 3
 *
 * @example
 * // For non-overlapping date ranges returns 0:
 * getOverlappingDaysInRanges(
 *   new Date(2014, 0, 10), new Date(2014, 0, 20), new Date(2014, 0, 21), new Date(2014, 0, 22)
 * )
 * //=> 0
 */
function getOverlappingDaysInRanges(dirtyInitialRangeStartDate,dirtyInitialRangeEndDate,dirtyComparedRangeStartDate,dirtyComparedRangeEndDate){
var initialStartTime=parse(dirtyInitialRangeStartDate).getTime();
var initialEndTime=parse(dirtyInitialRangeEndDate).getTime();
var comparedStartTime=parse(dirtyComparedRangeStartDate).getTime();
var comparedEndTime=parse(dirtyComparedRangeEndDate).getTime();

if(initialStartTime>initialEndTime||comparedStartTime>comparedEndTime){
throw new Error('The start of the range cannot be after the end of the range');
}

var isOverlapping=initialStartTime<comparedEndTime&&comparedStartTime<initialEndTime;

if(!isOverlapping){
return 0;
}

var overlapStartDate=comparedStartTime<initialStartTime?
initialStartTime:
comparedStartTime;

var overlapEndDate=comparedEndTime>initialEndTime?
initialEndTime:
comparedEndTime;

var differenceInMs=overlapEndDate-overlapStartDate;

return Math.ceil(differenceInMs/MILLISECONDS_IN_DAY);
}

module.exports=getOverlappingDaysInRanges;


/***/},

/***/"63b6":
/***/function b6(module,exports,__webpack_require__){

var global=__webpack_require__("e53d");
var core=__webpack_require__("584a");
var ctx=__webpack_require__("d864");
var hide=__webpack_require__("35e8");
var has=__webpack_require__("07e3");
var PROTOTYPE='prototype';

var $export=function $export(type,name,source){
var IS_FORCED=type&$export.F;
var IS_GLOBAL=type&$export.G;
var IS_STATIC=type&$export.S;
var IS_PROTO=type&$export.P;
var IS_BIND=type&$export.B;
var IS_WRAP=type&$export.W;
var exports=IS_GLOBAL?core:core[name]||(core[name]={});
var expProto=exports[PROTOTYPE];
var target=IS_GLOBAL?global:IS_STATIC?global[name]:(global[name]||{})[PROTOTYPE];
var key,own,out;
if(IS_GLOBAL)source=name;
for(key in source){
// contains in native
own=!IS_FORCED&&target&&target[key]!==undefined;
if(own&&has(exports,key))continue;
// export native or passed
out=own?target[key]:source[key];
// prevent global pollution for namespaces
exports[key]=IS_GLOBAL&&typeof target[key]!='function'?source[key]
// bind timers to global for call from export context
:IS_BIND&&own?ctx(out,global)
// wrap global constructors for prevent change them in library
:IS_WRAP&&target[key]==out?function(C){
var F=function F(a,b,c){
if(this instanceof C){
switch(arguments.length){
case 0:return new C();
case 1:return new C(a);
case 2:return new C(a,b);}
return new C(a,b,c);
}return C.apply(this,arguments);
};
F[PROTOTYPE]=C[PROTOTYPE];
return F;
// make static versions for prototype methods
}(out):IS_PROTO&&typeof out=='function'?ctx(Function.call,out):out;
// export proto methods to core.%CONSTRUCTOR%.methods.%NAME%
if(IS_PROTO){
(exports.virtual||(exports.virtual={}))[key]=out;
// export proto methods to core.%CONSTRUCTOR%.prototype.%NAME%
if(type&$export.R&&expProto&&!expProto[key])hide(expProto,key,out);
}
}
};
// type bitmap
$export.F=1;// forced
$export.G=2;// global
$export.S=4;// static
$export.P=8;// proto
$export.B=16;// bind
$export.W=32;// wrap
$export.U=64;// safe
$export.R=128;// real proto method for `library`
module.exports=$export;


/***/},

/***/"6570":
/***/function _(module,exports,__webpack_require__){

var differenceInMilliseconds=__webpack_require__("e785");

var MILLISECONDS_IN_MINUTE=60000;

/**
 * @category Minute Helpers
 * @summary Get the number of minutes between the given dates.
 *
 * @description
 * Get the number of minutes between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of minutes
 *
 * @example
 * // How many minutes are between 2 July 2014 12:07:59 and 2 July 2014 12:20:00?
 * var result = differenceInMinutes(
 *   new Date(2014, 6, 2, 12, 20, 0),
 *   new Date(2014, 6, 2, 12, 7, 59)
 * )
 * //=> 12
 */
function differenceInMinutes(dirtyDateLeft,dirtyDateRight){
var diff=differenceInMilliseconds(dirtyDateLeft,dirtyDateRight)/MILLISECONDS_IN_MINUTE;
return diff>0?Math.floor(diff):Math.ceil(diff);
}

module.exports=differenceInMinutes;


/***/},

/***/"65d9":
/***/function d9(module,exports,__webpack_require__){
/**
  * vue-class-component v6.3.2
  * (c) 2015-present Evan You
  * @license MIT
  */


Object.defineProperty(exports,'__esModule',{value:true});

function _interopDefault(ex){return ex&&typeof ex==='object'&&'default'in ex?ex['default']:ex;}

var Vue=_interopDefault(__webpack_require__("8bbf"));

var reflectionIsSupported=typeof Reflect!=='undefined'&&Reflect.defineMetadata;
function copyReflectionMetadata(to,from){
forwardMetadata(to,from);
Object.getOwnPropertyNames(from.prototype).forEach(function(key){
forwardMetadata(to.prototype,from.prototype,key);
});
Object.getOwnPropertyNames(from).forEach(function(key){
forwardMetadata(to,from,key);
});
}
function forwardMetadata(to,from,propertyKey){
var metaKeys=propertyKey?
Reflect.getOwnMetadataKeys(from,propertyKey):
Reflect.getOwnMetadataKeys(from);
metaKeys.forEach(function(metaKey){
var metadata=propertyKey?
Reflect.getOwnMetadata(metaKey,from,propertyKey):
Reflect.getOwnMetadata(metaKey,from);
if(propertyKey){
Reflect.defineMetadata(metaKey,metadata,to,propertyKey);
}else
{
Reflect.defineMetadata(metaKey,metadata,to);
}
});
}

var fakeArray={__proto__:[]};
var hasProto=fakeArray instanceof Array;
function createDecorator(factory){
return function(target,key,index){
var Ctor=typeof target==='function'?
target:
target.constructor;
if(!Ctor.__decorators__){
Ctor.__decorators__=[];
}
if(typeof index!=='number'){
index=undefined;
}
Ctor.__decorators__.push(function(options){return factory(options,key,index);});
};
}
function mixins(){
var Ctors=[];
for(var _i=0;_i<arguments.length;_i++){
Ctors[_i]=arguments[_i];
}
return Vue.extend({mixins:Ctors});
}
function isPrimitive(value){
var type=typeof value;
return value==null||type!=='object'&&type!=='function';
}

function collectDataFromConstructor(vm,Component){
// override _init to prevent to init as Vue instance
var originalInit=Component.prototype._init;
Component.prototype._init=function(){
var _this=this;
// proxy to actual vm
var keys=Object.getOwnPropertyNames(vm);
// 2.2.0 compat (props are no longer exposed as self properties)
if(vm.$options.props){
for(var key in vm.$options.props){
if(!vm.hasOwnProperty(key)){
keys.push(key);
}
}
}
keys.forEach(function(key){
if(key.charAt(0)!=='_'){
Object.defineProperty(_this,key,{
get:function get(){return vm[key];},
set:function set(value){vm[key]=value;},
configurable:true});

}
});
};
// should be acquired class property values
var data=new Component();
// restore original _init to avoid memory leak (#209)
Component.prototype._init=originalInit;
// create plain data object
var plainData={};
Object.keys(data).forEach(function(key){
if(data[key]!==undefined){
plainData[key]=data[key];
}
});
return plainData;
}

var $internalHooks=[
'data',
'beforeCreate',
'created',
'beforeMount',
'mounted',
'beforeDestroy',
'destroyed',
'beforeUpdate',
'updated',
'activated',
'deactivated',
'render',
'errorCaptured'// 2.5
];
function componentFactory(Component,options){
if(options===void 0){options={};}
options.name=options.name||Component._componentTag||Component.name;
// prototype props.
var proto=Component.prototype;
Object.getOwnPropertyNames(proto).forEach(function(key){
if(key==='constructor'){
return;
}
// hooks
if($internalHooks.indexOf(key)>-1){
options[key]=proto[key];
return;
}
var descriptor=Object.getOwnPropertyDescriptor(proto,key);
if(descriptor.value!==void 0){
// methods
if(typeof descriptor.value==='function'){
(options.methods||(options.methods={}))[key]=descriptor.value;
}else
{
// typescript decorated data
(options.mixins||(options.mixins=[])).push({
data:function data(){
var _a;
return _a={},_a[key]=descriptor.value,_a;
}});

}
}else
if(descriptor.get||descriptor.set){
// computed properties
(options.computed||(options.computed={}))[key]={
get:descriptor.get,
set:descriptor.set};

}
});
(options.mixins||(options.mixins=[])).push({
data:function data(){
return collectDataFromConstructor(this,Component);
}});

// decorate options
var decorators=Component.__decorators__;
if(decorators){
decorators.forEach(function(fn){return fn(options);});
delete Component.__decorators__;
}
// find super
var superProto=Object.getPrototypeOf(Component.prototype);
var Super=superProto instanceof Vue?
superProto.constructor:
Vue;
var Extended=Super.extend(options);
forwardStaticMembers(Extended,Component,Super);
if(reflectionIsSupported){
copyReflectionMetadata(Extended,Component);
}
return Extended;
}

function forwardStaticMembers(Extended,Original,Super){
// We have to use getOwnPropertyNames since Babel registers methods as non-enumerable
Object.getOwnPropertyNames(Original).forEach(function(key){
// `prototype` should not be overwritten
if(key==='prototype'){
return;
}
// Some browsers does not allow reconfigure built-in properties
var extendedDescriptor=Object.getOwnPropertyDescriptor(Extended,key);
if(extendedDescriptor&&!extendedDescriptor.configurable){
return;
}
var descriptor=Object.getOwnPropertyDescriptor(Original,key);
// If the user agent does not support `__proto__` or its family (IE <= 10),
// the sub class properties may be inherited properties from the super class in TypeScript.
// We need to exclude such properties to prevent to overwrite
// the component options object which stored on the extended constructor (See #192).
// If the value is a referenced value (object or function),
// we can check equality of them and exclude it if they have the same reference.
// If it is a primitive value, it will be forwarded for safety.
if(!hasProto){
// Only `cid` is explicitly exluded from property forwarding
// because we cannot detect whether it is a inherited property or not
// on the no `__proto__` environment even though the property is reserved.
if(key==='cid'){
return;
}
var superDescriptor=Object.getOwnPropertyDescriptor(Super,key);
if(!isPrimitive(descriptor.value)&&
superDescriptor&&
superDescriptor.value===descriptor.value){
return;
}
}
Object.defineProperty(Extended,key,descriptor);
});
}

function Component(options){
if(typeof options==='function'){
return componentFactory(options);
}
return function(Component){
return componentFactory(Component,options);
};
}
Component.registerHooks=function registerHooks(keys){
$internalHooks.push.apply($internalHooks,keys);
};

exports.default=Component;
exports.createDecorator=createDecorator;
exports.mixins=mixins;


/***/},

/***/"662a":
/***/function a(module,exports,__webpack_require__){

var startOfHour=__webpack_require__("fbaf");

/**
 * @category Hour Helpers
 * @summary Are the given dates in the same hour?
 *
 * @description
 * Are the given dates in the same hour?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same hour
 *
 * @example
 * // Are 4 September 2014 06:00:00 and 4 September 06:30:00 in the same hour?
 * var result = isSameHour(
 *   new Date(2014, 8, 4, 6, 0),
 *   new Date(2014, 8, 4, 6, 30)
 * )
 * //=> true
 */
function isSameHour(dirtyDateLeft,dirtyDateRight){
var dateLeftStartOfHour=startOfHour(dirtyDateLeft);
var dateRightStartOfHour=startOfHour(dirtyDateRight);

return dateLeftStartOfHour.getTime()===dateRightStartOfHour.getTime();
}

module.exports=isSameHour;


/***/},

/***/"6665":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var getDaysInMonth=__webpack_require__("5416");

/**
 * @category Month Helpers
 * @summary Add the specified number of months to the given date.
 *
 * @description
 * Add the specified number of months to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of months to be added
 * @returns {Date} the new date with the months added
 *
 * @example
 * // Add 5 months to 1 September 2014:
 * var result = addMonths(new Date(2014, 8, 1), 5)
 * //=> Sun Feb 01 2015 00:00:00
 */
function addMonths(dirtyDate,dirtyAmount){
var date=parse(dirtyDate);
var amount=Number(dirtyAmount);
var desiredMonth=date.getMonth()+amount;
var dateWithDesiredMonth=new Date(0);
dateWithDesiredMonth.setFullYear(date.getFullYear(),desiredMonth,1);
dateWithDesiredMonth.setHours(0,0,0,0);
var daysInMonth=getDaysInMonth(dateWithDesiredMonth);
// Set the last day of the new month
// if the original date was the last day of the longer month
date.setMonth(desiredMonth,Math.min(daysInMonth,date.getDate()));
return date;
}

module.exports=addMonths;


/***/},

/***/"6718":
/***/function _(module,exports,__webpack_require__){

var global=__webpack_require__("e53d");
var core=__webpack_require__("584a");
var LIBRARY=__webpack_require__("b8e3");
var wksExt=__webpack_require__("ccb9");
var defineProperty=__webpack_require__("d9f6").f;
module.exports=function(name){
var $Symbol=core.Symbol||(core.Symbol=LIBRARY?{}:global.Symbol||{});
if(name.charAt(0)!='_'&&!(name in $Symbol))defineProperty($Symbol,name,{value:wksExt.f(name)});
};


/***/},

/***/"67ab":
/***/function ab(module,exports,__webpack_require__){

var META=__webpack_require__("ca5a")('meta');
var isObject=__webpack_require__("d3f4");
var has=__webpack_require__("69a8");
var setDesc=__webpack_require__("86cc").f;
var id=0;
var isExtensible=Object.isExtensible||function(){
return true;
};
var FREEZE=!__webpack_require__("79e5")(function(){
return isExtensible(Object.preventExtensions({}));
});
var setMeta=function setMeta(it){
setDesc(it,META,{value:{
i:'O'+ ++id,// object ID
w:{}// weak collections IDs
}});
};
var fastKey=function fastKey(it,create){
// return primitive with prefix
if(!isObject(it))return typeof it=='symbol'?it:(typeof it=='string'?'S':'P')+it;
if(!has(it,META)){
// can't set metadata to uncaught frozen object
if(!isExtensible(it))return 'F';
// not necessary to add metadata
if(!create)return 'E';
// add missing metadata
setMeta(it);
// return object ID
}return it[META].i;
};
var getWeak=function getWeak(it,create){
if(!has(it,META)){
// can't set metadata to uncaught frozen object
if(!isExtensible(it))return true;
// not necessary to add metadata
if(!create)return false;
// add missing metadata
setMeta(it);
// return hash weak collections IDs
}return it[META].w;
};
// add metadata on freeze-family methods calling
var onFreeze=function onFreeze(it){
if(FREEZE&&meta.NEED&&isExtensible(it)&&!has(it,META))setMeta(it);
return it;
};
var meta=module.exports={
KEY:META,
NEED:false,
fastKey:fastKey,
getWeak:getWeak,
onFreeze:onFreeze};



/***/},

/***/"67bb":
/***/function bb(module,exports,__webpack_require__){

module.exports=__webpack_require__("f921");

/***/},

/***/"6821":
/***/function _(module,exports,__webpack_require__){

// to indexed object, toObject with fallback for non-array-like ES3 strings
var IObject=__webpack_require__("626a");
var defined=__webpack_require__("be13");
module.exports=function(it){
return IObject(defined(it));
};


/***/},

/***/"693a":
/***/function a(module,exports){

/**
 * @category Day Helpers
 * @summary Return the start of yesterday.
 *
 * @description
 * Return the start of yesterday.
 *
 * @returns {Date} the start of yesterday
 *
 * @example
 * // If today is 6 October 2014:
 * var result = startOfYesterday()
 * //=> Sun Oct 5 2014 00:00:00
 */
function startOfYesterday(){
var now=new Date();
var year=now.getFullYear();
var month=now.getMonth();
var day=now.getDate();

var date=new Date(0);
date.setFullYear(year,month,day-1);
date.setHours(0,0,0,0);
return date;
}

module.exports=startOfYesterday;


/***/},

/***/"69a8":
/***/function a8(module,exports){

var hasOwnProperty={}.hasOwnProperty;
module.exports=function(it,key){
return hasOwnProperty.call(it,key);
};


/***/},

/***/"69d3":
/***/function d3(module,exports,__webpack_require__){

__webpack_require__("6718")('asyncIterator');


/***/},

/***/"6a99":
/***/function a99(module,exports,__webpack_require__){

// 7.1.1 ToPrimitive(input [, PreferredType])
var isObject=__webpack_require__("d3f4");
// instead of the ES6 spec version, we didn't implement @@toPrimitive case
// and the second argument - flag - preferred type is a string
module.exports=function(it,S){
if(!isObject(it))return it;
var fn,val;
if(S&&typeof(fn=it.toString)=='function'&&!isObject(val=fn.call(it)))return val;
if(typeof(fn=it.valueOf)=='function'&&!isObject(val=fn.call(it)))return val;
if(!S&&typeof(fn=it.toString)=='function'&&!isObject(val=fn.call(it)))return val;
throw TypeError("Can't convert object to primitive value");
};


/***/},

/***/"6abf":
/***/function abf(module,exports,__webpack_require__){

// 19.1.2.7 / 15.2.3.4 Object.getOwnPropertyNames(O)
var $keys=__webpack_require__("e6f3");
var hiddenKeys=__webpack_require__("1691").concat('length','prototype');

exports.f=Object.getOwnPropertyNames||function getOwnPropertyNames(O){
return $keys(O,hiddenKeys);
};


/***/},

/***/"6b4c":
/***/function b4c(module,exports){

var toString={}.toString;

module.exports=function(it){
return toString.call(it).slice(8,-1);
};


/***/},

/***/"6b8f":
/***/function b8f(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Is the first date before the second one?
 *
 * @description
 * Is the first date before the second one?
 *
 * @param {Date|String|Number} date - the date that should be before the other one to return true
 * @param {Date|String|Number} dateToCompare - the date to compare with
 * @returns {Boolean} the first date is before the second date
 *
 * @example
 * // Is 10 July 1989 before 11 February 1987?
 * var result = isBefore(new Date(1989, 6, 10), new Date(1987, 1, 11))
 * //=> false
 */
function isBefore(dirtyDate,dirtyDateToCompare){
var date=parse(dirtyDate);
var dateToCompare=parse(dirtyDateToCompare);
return date.getTime()<dateToCompare.getTime();
}

module.exports=isBefore;


/***/},

/***/"6c1c":
/***/function c1c(module,exports,__webpack_require__){

__webpack_require__("c367");
var global=__webpack_require__("e53d");
var hide=__webpack_require__("35e8");
var Iterators=__webpack_require__("481b");
var TO_STRING_TAG=__webpack_require__("5168")('toStringTag');

var DOMIterables=('CSSRuleList,CSSStyleDeclaration,CSSValueList,ClientRectList,DOMRectList,DOMStringList,'+
'DOMTokenList,DataTransferItemList,FileList,HTMLAllCollection,HTMLCollection,HTMLFormElement,HTMLSelectElement,'+
'MediaList,MimeTypeArray,NamedNodeMap,NodeList,PaintRequestList,Plugin,PluginArray,SVGLengthList,SVGNumberList,'+
'SVGPathSegList,SVGPointList,SVGStringList,SVGTransformList,SourceBufferList,StyleSheetList,TextTrackCueList,'+
'TextTrackList,TouchList').split(',');

for(var i=0;i<DOMIterables.length;i++){
var NAME=DOMIterables[i];
var Collection=global[NAME];
var proto=Collection&&Collection.prototype;
if(proto&&!proto[TO_STRING_TAG])hide(proto,TO_STRING_TAG,NAME);
Iterators[NAME]=Iterators.Array;
}


/***/},

/***/"6c7b":
/***/function c7b(module,exports,__webpack_require__){

// 22.1.3.6 Array.prototype.fill(value, start = 0, end = this.length)
var $export=__webpack_require__("5ca1");

$export($export.P,'Array',{fill:__webpack_require__("36bd")});

__webpack_require__("9c6c")('fill');


/***/},

/***/"6e0c":
/***/function e0c(module,exports,__webpack_require__){

var buildDistanceInWordsLocale=__webpack_require__("e485");
var buildFormatLocale=__webpack_require__("4c70");

/**
 * @category Locales
 * @summary German locale.
 * @author Thomas Eilmsteiner [@DeMuu]{@link https://github.com/DeMuu}
 * @author Asia [@asia-t]{@link https://github.com/asia-t}
 */
module.exports={
distanceInWords:buildDistanceInWordsLocale(),
format:buildFormatLocale()};



/***/},

/***/"6f00":
/***/function f00(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Hour Helpers
 * @summary Set the hours to the given date.
 *
 * @description
 * Set the hours to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} hours - the hours of the new date
 * @returns {Date} the new date with the hours setted
 *
 * @example
 * // Set 4 hours to 1 September 2014 11:30:00:
 * var result = setHours(new Date(2014, 8, 1, 11, 30), 4)
 * //=> Mon Sep 01 2014 04:30:00
 */
function setHours(dirtyDate,dirtyHours){
var date=parse(dirtyDate);
var hours=Number(dirtyHours);
date.setHours(hours);
return date;
}

module.exports=setHours;


/***/},

/***/"6f4e":
/***/function f4e(module,exports){

/**
 * @category Day Helpers
 * @summary Return the end of tomorrow.
 *
 * @description
 * Return the end of tomorrow.
 *
 * @returns {Date} the end of tomorrow
 *
 * @example
 * // If today is 6 October 2014:
 * var result = endOfTomorrow()
 * //=> Tue Oct 7 2014 23:59:59.999
 */
function endOfTomorrow(){
var now=new Date();
var year=now.getFullYear();
var month=now.getMonth();
var day=now.getDate();

var date=new Date(0);
date.setFullYear(year,month,day+1);
date.setHours(23,59,59,999);
return date;
}

module.exports=endOfTomorrow;


/***/},

/***/"6fcc":
/***/function fcc(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var differenceInCalendarYears=__webpack_require__("2a9c");
var compareAsc=__webpack_require__("0d3e");

/**
 * @category Year Helpers
 * @summary Get the number of full years between the given dates.
 *
 * @description
 * Get the number of full years between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of full years
 *
 * @example
 * // How many full years are between 31 December 2013 and 11 February 2015?
 * var result = differenceInYears(
 *   new Date(2015, 1, 11),
 *   new Date(2013, 11, 31)
 * )
 * //=> 1
 */
function differenceInYears(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);

var sign=compareAsc(dateLeft,dateRight);
var difference=Math.abs(differenceInCalendarYears(dateLeft,dateRight));
dateLeft.setFullYear(dateLeft.getFullYear()-sign*difference);

// Math.abs(diff in full years - diff in calendar years) === 1 if last calendar year is not full
// If so, result must be decreased by 1 in absolute value
var isLastYearNotFull=compareAsc(dateLeft,dateRight)===-sign;
return sign*(difference-isLastYearNotFull);
}

module.exports=differenceInYears;


/***/},

/***/"70f2":
/***/function f2(module,exports,__webpack_require__){

var getDayOfYear=__webpack_require__("580f");
var getISOWeek=__webpack_require__("81fc");
var getISOYear=__webpack_require__("8964");
var parse=__webpack_require__("c8d5");
var isValid=__webpack_require__("7eea");
var enLocale=__webpack_require__("52cf");

/**
 * @category Common Helpers
 * @summary Format the date.
 *
 * @description
 * Return the formatted date string in the given format.
 *
 * Accepted tokens:
 * | Unit                    | Token | Result examples                  |
 * |-------------------------|-------|----------------------------------|
 * | Month                   | M     | 1, 2, ..., 12                    |
 * |                         | Mo    | 1st, 2nd, ..., 12th              |
 * |                         | MM    | 01, 02, ..., 12                  |
 * |                         | MMM   | Jan, Feb, ..., Dec               |
 * |                         | MMMM  | January, February, ..., December |
 * | Quarter                 | Q     | 1, 2, 3, 4                       |
 * |                         | Qo    | 1st, 2nd, 3rd, 4th               |
 * | Day of month            | D     | 1, 2, ..., 31                    |
 * |                         | Do    | 1st, 2nd, ..., 31st              |
 * |                         | DD    | 01, 02, ..., 31                  |
 * | Day of year             | DDD   | 1, 2, ..., 366                   |
 * |                         | DDDo  | 1st, 2nd, ..., 366th             |
 * |                         | DDDD  | 001, 002, ..., 366               |
 * | Day of week             | d     | 0, 1, ..., 6                     |
 * |                         | do    | 0th, 1st, ..., 6th               |
 * |                         | dd    | Su, Mo, ..., Sa                  |
 * |                         | ddd   | Sun, Mon, ..., Sat               |
 * |                         | dddd  | Sunday, Monday, ..., Saturday    |
 * | Day of ISO week         | E     | 1, 2, ..., 7                     |
 * | ISO week                | W     | 1, 2, ..., 53                    |
 * |                         | Wo    | 1st, 2nd, ..., 53rd              |
 * |                         | WW    | 01, 02, ..., 53                  |
 * | Year                    | YY    | 00, 01, ..., 99                  |
 * |                         | YYYY  | 1900, 1901, ..., 2099            |
 * | ISO week-numbering year | GG    | 00, 01, ..., 99                  |
 * |                         | GGGG  | 1900, 1901, ..., 2099            |
 * | AM/PM                   | A     | AM, PM                           |
 * |                         | a     | am, pm                           |
 * |                         | aa    | a.m., p.m.                       |
 * | Hour                    | H     | 0, 1, ... 23                     |
 * |                         | HH    | 00, 01, ... 23                   |
 * |                         | h     | 1, 2, ..., 12                    |
 * |                         | hh    | 01, 02, ..., 12                  |
 * | Minute                  | m     | 0, 1, ..., 59                    |
 * |                         | mm    | 00, 01, ..., 59                  |
 * | Second                  | s     | 0, 1, ..., 59                    |
 * |                         | ss    | 00, 01, ..., 59                  |
 * | 1/10 of second          | S     | 0, 1, ..., 9                     |
 * | 1/100 of second         | SS    | 00, 01, ..., 99                  |
 * | Millisecond             | SSS   | 000, 001, ..., 999               |
 * | Timezone                | Z     | -01:00, +00:00, ... +12:00       |
 * |                         | ZZ    | -0100, +0000, ..., +1200         |
 * | Seconds timestamp       | X     | 512969520                        |
 * | Milliseconds timestamp  | x     | 512969520900                     |
 *
 * The characters wrapped in square brackets are escaped.
 *
 * The result may vary by locale.
 *
 * @param {Date|String|Number} date - the original date
 * @param {String} [format='YYYY-MM-DDTHH:mm:ss.SSSZ'] - the string of tokens
 * @param {Object} [options] - the object with options
 * @param {Object} [options.locale=enLocale] - the locale object
 * @returns {String} the formatted date string
 *
 * @example
 * // Represent 11 February 2014 in middle-endian format:
 * var result = format(
 *   new Date(2014, 1, 11),
 *   'MM/DD/YYYY'
 * )
 * //=> '02/11/2014'
 *
 * @example
 * // Represent 2 July 2014 in Esperanto:
 * var eoLocale = require('date-fns/locale/eo')
 * var result = format(
 *   new Date(2014, 6, 2),
 *   'Do [de] MMMM YYYY',
 *   {locale: eoLocale}
 * )
 * //=> '2-a de julio 2014'
 */
function format(dirtyDate,dirtyFormatStr,dirtyOptions){
var formatStr=dirtyFormatStr?String(dirtyFormatStr):'YYYY-MM-DDTHH:mm:ss.SSSZ';
var options=dirtyOptions||{};

var locale=options.locale;
var localeFormatters=enLocale.format.formatters;
var formattingTokensRegExp=enLocale.format.formattingTokensRegExp;
if(locale&&locale.format&&locale.format.formatters){
localeFormatters=locale.format.formatters;

if(locale.format.formattingTokensRegExp){
formattingTokensRegExp=locale.format.formattingTokensRegExp;
}
}

var date=parse(dirtyDate);

if(!isValid(date)){
return 'Invalid Date';
}

var formatFn=buildFormatFn(formatStr,localeFormatters,formattingTokensRegExp);

return formatFn(date);
}

var formatters={
// Month: 1, 2, ..., 12
'M':function M(date){
return date.getMonth()+1;
},

// Month: 01, 02, ..., 12
'MM':function MM(date){
return addLeadingZeros(date.getMonth()+1,2);
},

// Quarter: 1, 2, 3, 4
'Q':function Q(date){
return Math.ceil((date.getMonth()+1)/3);
},

// Day of month: 1, 2, ..., 31
'D':function D(date){
return date.getDate();
},

// Day of month: 01, 02, ..., 31
'DD':function DD(date){
return addLeadingZeros(date.getDate(),2);
},

// Day of year: 1, 2, ..., 366
'DDD':function DDD(date){
return getDayOfYear(date);
},

// Day of year: 001, 002, ..., 366
'DDDD':function DDDD(date){
return addLeadingZeros(getDayOfYear(date),3);
},

// Day of week: 0, 1, ..., 6
'd':function d(date){
return date.getDay();
},

// Day of ISO week: 1, 2, ..., 7
'E':function E(date){
return date.getDay()||7;
},

// ISO week: 1, 2, ..., 53
'W':function W(date){
return getISOWeek(date);
},

// ISO week: 01, 02, ..., 53
'WW':function WW(date){
return addLeadingZeros(getISOWeek(date),2);
},

// Year: 00, 01, ..., 99
'YY':function YY(date){
return addLeadingZeros(date.getFullYear(),4).substr(2);
},

// Year: 1900, 1901, ..., 2099
'YYYY':function YYYY(date){
return addLeadingZeros(date.getFullYear(),4);
},

// ISO week-numbering year: 00, 01, ..., 99
'GG':function GG(date){
return String(getISOYear(date)).substr(2);
},

// ISO week-numbering year: 1900, 1901, ..., 2099
'GGGG':function GGGG(date){
return getISOYear(date);
},

// Hour: 0, 1, ... 23
'H':function H(date){
return date.getHours();
},

// Hour: 00, 01, ..., 23
'HH':function HH(date){
return addLeadingZeros(date.getHours(),2);
},

// Hour: 1, 2, ..., 12
'h':function h(date){
var hours=date.getHours();
if(hours===0){
return 12;
}else if(hours>12){
return hours%12;
}else {
return hours;
}
},

// Hour: 01, 02, ..., 12
'hh':function hh(date){
return addLeadingZeros(formatters['h'](date),2);
},

// Minute: 0, 1, ..., 59
'm':function m(date){
return date.getMinutes();
},

// Minute: 00, 01, ..., 59
'mm':function mm(date){
return addLeadingZeros(date.getMinutes(),2);
},

// Second: 0, 1, ..., 59
's':function s(date){
return date.getSeconds();
},

// Second: 00, 01, ..., 59
'ss':function ss(date){
return addLeadingZeros(date.getSeconds(),2);
},

// 1/10 of second: 0, 1, ..., 9
'S':function S(date){
return Math.floor(date.getMilliseconds()/100);
},

// 1/100 of second: 00, 01, ..., 99
'SS':function SS(date){
return addLeadingZeros(Math.floor(date.getMilliseconds()/10),2);
},

// Millisecond: 000, 001, ..., 999
'SSS':function SSS(date){
return addLeadingZeros(date.getMilliseconds(),3);
},

// Timezone: -01:00, +00:00, ... +12:00
'Z':function Z(date){
return formatTimezone(date.getTimezoneOffset(),':');
},

// Timezone: -0100, +0000, ... +1200
'ZZ':function ZZ(date){
return formatTimezone(date.getTimezoneOffset());
},

// Seconds timestamp: 512969520
'X':function X(date){
return Math.floor(date.getTime()/1000);
},

// Milliseconds timestamp: 512969520900
'x':function x(date){
return date.getTime();
}};


function buildFormatFn(formatStr,localeFormatters,formattingTokensRegExp){
var array=formatStr.match(formattingTokensRegExp);
var length=array.length;

var i;
var formatter;
for(i=0;i<length;i++){
formatter=localeFormatters[array[i]]||formatters[array[i]];
if(formatter){
array[i]=formatter;
}else {
array[i]=removeFormattingTokens(array[i]);
}
}

return function(date){
var output='';
for(var i=0;i<length;i++){
if(array[i]instanceof Function){
output+=array[i](date,formatters);
}else {
output+=array[i];
}
}
return output;
};
}

function removeFormattingTokens(input){
if(input.match(/\[[\s\S]/)){
return input.replace(/^\[|]$/g,'');
}
return input.replace(/\\/g,'');
}

function formatTimezone(offset,delimeter){
delimeter=delimeter||'';
var sign=offset>0?'-':'+';
var absOffset=Math.abs(offset);
var hours=Math.floor(absOffset/60);
var minutes=absOffset%60;
return sign+addLeadingZeros(hours,2)+delimeter+addLeadingZeros(minutes,2);
}

function addLeadingZeros(number,targetLength){
var output=Math.abs(number).toString();
while(output.length<targetLength){
output='0'+output;
}
return output;
}

module.exports=format;


/***/},

/***/"71c1":
/***/function c1(module,exports,__webpack_require__){

var toInteger=__webpack_require__("3a38");
var defined=__webpack_require__("25eb");
// true  -> String#at
// false -> String#codePointAt
module.exports=function(TO_STRING){
return function(that,pos){
var s=String(defined(that));
var i=toInteger(pos);
var l=s.length;
var a,b;
if(i<0||i>=l)return TO_STRING?'':undefined;
a=s.charCodeAt(i);
return a<0xd800||a>0xdbff||i+1===l||(b=s.charCodeAt(i+1))<0xdc00||b>0xdfff?
TO_STRING?s.charAt(i):a:
TO_STRING?s.slice(i,i+2):(a-0xd800<<10)+(b-0xdc00)+0x10000;
};
};


/***/},

/***/"72b7":
/***/function b7(module,exports,__webpack_require__){

var addMilliseconds=__webpack_require__("ec1f");

var MILLISECONDS_IN_MINUTE=60000;

/**
 * @category Minute Helpers
 * @summary Add the specified number of minutes to the given date.
 *
 * @description
 * Add the specified number of minutes to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of minutes to be added
 * @returns {Date} the new date with the minutes added
 *
 * @example
 * // Add 30 minutes to 10 July 2014 12:00:00:
 * var result = addMinutes(new Date(2014, 6, 10, 12, 0), 30)
 * //=> Thu Jul 10 2014 12:30:00
 */
function addMinutes(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addMilliseconds(dirtyDate,amount*MILLISECONDS_IN_MINUTE);
}

module.exports=addMinutes;


/***/},

/***/"7338":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Get the month of the given date.
 *
 * @description
 * Get the month of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the month
 *
 * @example
 * // Which month is 29 February 2012?
 * var result = getMonth(new Date(2012, 1, 29))
 * //=> 1
 */
function getMonth(dirtyDate){
var date=parse(dirtyDate);
var month=date.getMonth();
return month;
}

module.exports=getMonth;


/***/},

/***/"7443":
/***/function _(module,exports,__webpack_require__){

var endOfDay=__webpack_require__("9744");

/**
 * @category Day Helpers
 * @summary Return the end of today.
 *
 * @description
 * Return the end of today.
 *
 * @returns {Date} the end of today
 *
 * @example
 * // If today is 6 October 2014:
 * var result = endOfToday()
 * //=> Mon Oct 6 2014 23:59:59.999
 */
function endOfToday(){
return endOfDay(new Date());
}

module.exports=endOfToday;


/***/},

/***/"7494":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Week Helpers
 * @summary Return the end of a week for the given date.
 *
 * @description
 * Return the end of a week for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @param {Object} [options] - the object with options
 * @param {Number} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @returns {Date} the end of a week
 *
 * @example
 * // The end of a week for 2 September 2014 11:55:00:
 * var result = endOfWeek(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Sat Sep 06 2014 23:59:59.999
 *
 * @example
 * // If the week starts on Monday, the end of the week for 2 September 2014 11:55:00:
 * var result = endOfWeek(new Date(2014, 8, 2, 11, 55, 0), {weekStartsOn: 1})
 * //=> Sun Sep 07 2014 23:59:59.999
 */
function endOfWeek(dirtyDate,dirtyOptions){
var weekStartsOn=dirtyOptions?Number(dirtyOptions.weekStartsOn)||0:0;

var date=parse(dirtyDate);
var day=date.getDay();
var diff=(day<weekStartsOn?-7:0)+6-(day-weekStartsOn);

date.setDate(date.getDate()+diff);
date.setHours(23,59,59,999);
return date;
}

module.exports=endOfWeek;


/***/},

/***/"7606":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Is the given date Tuesday?
 *
 * @description
 * Is the given date Tuesday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is Tuesday
 *
 * @example
 * // Is 23 September 2014 Tuesday?
 * var result = isTuesday(new Date(2014, 8, 23))
 * //=> true
 */
function isTuesday(dirtyDate){
return parse(dirtyDate).getDay()===2;
}

module.exports=isTuesday;


/***/},

/***/"765d":
/***/function d(module,exports,__webpack_require__){

__webpack_require__("6718")('observable');


/***/},

/***/"7726":
/***/function _(module,exports){

// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
var global=module.exports=typeof window!='undefined'&&window.Math==Math?
window:typeof self!='undefined'&&self.Math==Math?self
// eslint-disable-next-line no-new-func
:Function('return this')();
if(typeof __g=='number')__g=global;// eslint-disable-line no-undef


/***/},

/***/"77f1":
/***/function f1(module,exports,__webpack_require__){

var toInteger=__webpack_require__("4588");
var max=Math.max;
var min=Math.min;
module.exports=function(index,length){
index=toInteger(index);
return index<0?max(index+length,0):min(index,length);
};


/***/},

/***/"794b":
/***/function b(module,exports,__webpack_require__){

module.exports=!__webpack_require__("8e60")&&!__webpack_require__("294c")(function(){
return Object.defineProperty(__webpack_require__("1ec9")('div'),'a',{get:function get(){return 7;}}).a!=7;
});


/***/},

/***/"79aa":
/***/function aa(module,exports){

module.exports=function(it){
if(typeof it!='function')throw TypeError(it+' is not a function!');
return it;
};


/***/},

/***/"79e5":
/***/function e5(module,exports){

module.exports=function(exec){
try{
return !!exec();
}catch(e){
return true;
}
};


/***/},

/***/"7a83":
/***/function a83(module,exports,__webpack_require__){

var addDays=__webpack_require__("8946");

/**
 * @category Week Helpers
 * @summary Add the specified number of weeks to the given date.
 *
 * @description
 * Add the specified number of week to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of weeks to be added
 * @returns {Date} the new date with the weeks added
 *
 * @example
 * // Add 4 weeks to 1 September 2014:
 * var result = addWeeks(new Date(2014, 8, 1), 4)
 * //=> Mon Sep 29 2014 00:00:00
 */
function addWeeks(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
var days=amount*7;
return addDays(dirtyDate,days);
}

module.exports=addWeeks;


/***/},

/***/"7bbc":
/***/function bbc(module,exports,__webpack_require__){

// fallback for IE11 buggy Object.getOwnPropertyNames with iframe and window
var toIObject=__webpack_require__("6821");
var gOPN=__webpack_require__("9093").f;
var toString={}.toString;

var windowNames=typeof window=='object'&&window&&Object.getOwnPropertyNames?
Object.getOwnPropertyNames(window):[];

var getWindowNames=function getWindowNames(it){
try{
return gOPN(it);
}catch(e){
return windowNames.slice();
}
};

module.exports.f=function getOwnPropertyNames(it){
return windowNames&&toString.call(it)=='[object Window]'?getWindowNames(it):gOPN(toIObject(it));
};


/***/},

/***/"7cd6":
/***/function cd6(module,exports,__webpack_require__){

var classof=__webpack_require__("40c3");
var ITERATOR=__webpack_require__("5168")('iterator');
var Iterators=__webpack_require__("481b");
module.exports=__webpack_require__("584a").getIteratorMethod=function(it){
if(it!=undefined)return it[ITERATOR]||
it['@@iterator']||
Iterators[classof(it)];
};


/***/},

/***/"7d7b":
/***/function d7b(module,exports,__webpack_require__){

var anObject=__webpack_require__("e4ae");
var get=__webpack_require__("7cd6");
module.exports=__webpack_require__("584a").getIterator=function(it){
var iterFn=get(it);
if(typeof iterFn!='function')throw TypeError(it+' is not iterable!');
return anObject(iterFn.call(it));
};


/***/},

/***/"7e90":
/***/function e90(module,exports,__webpack_require__){

var dP=__webpack_require__("d9f6");
var anObject=__webpack_require__("e4ae");
var getKeys=__webpack_require__("c3a1");

module.exports=__webpack_require__("8e60")?Object.defineProperties:function defineProperties(O,Properties){
anObject(O);
var keys=getKeys(Properties);
var length=keys.length;
var i=0;
var P;
while(length>i){dP.f(O,P=keys[i++],Properties[P]);}
return O;
};


/***/},

/***/"7eea":
/***/function eea(module,exports,__webpack_require__){

var isDate=__webpack_require__("a735");

/**
 * @category Common Helpers
 * @summary Is the given date valid?
 *
 * @description
 * Returns false if argument is Invalid Date and true otherwise.
 * Invalid Date is a Date, whose time value is NaN.
 *
 * Time value of Date: http://es5.github.io/#x15.9.1.1
 *
 * @param {Date} date - the date to check
 * @returns {Boolean} the date is valid
 * @throws {TypeError} argument must be an instance of Date
 *
 * @example
 * // For the valid date:
 * var result = isValid(new Date(2014, 1, 31))
 * //=> true
 *
 * @example
 * // For the invalid date:
 * var result = isValid(new Date(''))
 * //=> false
 */
function isValid(dirtyDate){
if(isDate(dirtyDate)){
return !isNaN(dirtyDate);
}else {
throw new TypeError(toString.call(dirtyDate)+' is not an instance of Date');
}
}

module.exports=isValid;


/***/},

/***/"7f20":
/***/function f20(module,exports,__webpack_require__){

var def=__webpack_require__("86cc").f;
var has=__webpack_require__("69a8");
var TAG=__webpack_require__("2b4c")('toStringTag');

module.exports=function(it,tag,stat){
if(it&&!has(it=stat?it:it.prototype,TAG))def(it,TAG,{configurable:true,value:tag});
};


/***/},

/***/"7fd8":
/***/function fd8(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Return an index of the closest date from the array comparing to the given date.
 *
 * @description
 * Return an index of the closest date from the array comparing to the given date.
 *
 * @param {Date|String|Number} dateToCompare - the date to compare with
 * @param {Date[]|String[]|Number[]} datesArray - the array to search
 * @returns {Number} an index of the date closest to the given date
 * @throws {TypeError} the second argument must be an instance of Array
 *
 * @example
 * // Which date is closer to 6 September 2015?
 * var dateToCompare = new Date(2015, 8, 6)
 * var datesArray = [
 *   new Date(2015, 0, 1),
 *   new Date(2016, 0, 1),
 *   new Date(2017, 0, 1)
 * ]
 * var result = closestIndexTo(dateToCompare, datesArray)
 * //=> 1
 */
function closestIndexTo(dirtyDateToCompare,dirtyDatesArray){
if(!(dirtyDatesArray instanceof Array)){
throw new TypeError(toString.call(dirtyDatesArray)+' is not an instance of Array');
}

var dateToCompare=parse(dirtyDateToCompare);
var timeToCompare=dateToCompare.getTime();

var result;
var minDistance;

dirtyDatesArray.forEach(function(dirtyDate,index){
var currentDate=parse(dirtyDate);
var distance=Math.abs(timeToCompare-currentDate.getTime());
if(result===undefined||distance<minDistance){
result=index;
minDistance=distance;
}
});

return result;
}

module.exports=closestIndexTo;


/***/},

/***/"8148":
/***/function _(module,exports){

/**
 * @category Day Helpers
 * @summary Return the start of tomorrow.
 *
 * @description
 * Return the start of tomorrow.
 *
 * @returns {Date} the start of tomorrow
 *
 * @example
 * // If today is 6 October 2014:
 * var result = startOfTomorrow()
 * //=> Tue Oct 7 2014 00:00:00
 */
function startOfTomorrow(){
var now=new Date();
var year=now.getFullYear();
var month=now.getMonth();
var day=now.getDate();

var date=new Date(0);
date.setFullYear(year,month,day+1);
date.setHours(0,0,0,0);
return date;
}

module.exports=startOfTomorrow;


/***/},

/***/"81fc":
/***/function fc(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var startOfISOWeek=__webpack_require__("b4c7");
var startOfISOYear=__webpack_require__("4497");

var MILLISECONDS_IN_WEEK=604800000;

/**
 * @category ISO Week Helpers
 * @summary Get the ISO week of the given date.
 *
 * @description
 * Get the ISO week of the given date.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the ISO week
 *
 * @example
 * // Which week of the ISO-week numbering year is 2 January 2005?
 * var result = getISOWeek(new Date(2005, 0, 2))
 * //=> 53
 */
function getISOWeek(dirtyDate){
var date=parse(dirtyDate);
var diff=startOfISOWeek(date).getTime()-startOfISOYear(date).getTime();

// Round the number of days to the nearest integer
// because the number of milliseconds in a week is not constant
// (e.g. it's different in the week of the daylight saving time clock shift)
return Math.round(diff/MILLISECONDS_IN_WEEK)+1;
}

module.exports=getISOWeek;


/***/},

/***/"82dc":
/***/function dc(module,exports,__webpack_require__){

var startOfISOWeek=__webpack_require__("b4c7");

var MILLISECONDS_IN_MINUTE=60000;
var MILLISECONDS_IN_WEEK=604800000;

/**
 * @category ISO Week Helpers
 * @summary Get the number of calendar ISO weeks between the given dates.
 *
 * @description
 * Get the number of calendar ISO weeks between the given dates.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of calendar ISO weeks
 *
 * @example
 * // How many calendar ISO weeks are between 6 July 2014 and 21 July 2014?
 * var result = differenceInCalendarISOWeeks(
 *   new Date(2014, 6, 21),
 *   new Date(2014, 6, 6)
 * )
 * //=> 3
 */
function differenceInCalendarISOWeeks(dirtyDateLeft,dirtyDateRight){
var startOfISOWeekLeft=startOfISOWeek(dirtyDateLeft);
var startOfISOWeekRight=startOfISOWeek(dirtyDateRight);

var timestampLeft=startOfISOWeekLeft.getTime()-
startOfISOWeekLeft.getTimezoneOffset()*MILLISECONDS_IN_MINUTE;
var timestampRight=startOfISOWeekRight.getTime()-
startOfISOWeekRight.getTimezoneOffset()*MILLISECONDS_IN_MINUTE;

// Round the number of days to the nearest integer
// because the number of milliseconds in a week is not constant
// (e.g. it's different in the week of the daylight saving time clock shift)
return Math.round((timestampLeft-timestampRight)/MILLISECONDS_IN_WEEK);
}

module.exports=differenceInCalendarISOWeeks;


/***/},

/***/"8301":
/***/function _(module,exports,__webpack_require__){

var differenceInMonths=__webpack_require__("17cd");

/**
 * @category Quarter Helpers
 * @summary Get the number of full quarters between the given dates.
 *
 * @description
 * Get the number of full quarters between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of full quarters
 *
 * @example
 * // How many full quarters are between 31 December 2013 and 2 July 2014?
 * var result = differenceInQuarters(
 *   new Date(2014, 6, 2),
 *   new Date(2013, 11, 31)
 * )
 * //=> 2
 */
function differenceInQuarters(dirtyDateLeft,dirtyDateRight){
var diff=differenceInMonths(dirtyDateLeft,dirtyDateRight)/3;
return diff>0?Math.floor(diff):Math.ceil(diff);
}

module.exports=differenceInQuarters;


/***/},

/***/"8378":
/***/function _(module,exports){

var core=module.exports={version:'2.6.9'};
if(typeof __e=='number')__e=core;// eslint-disable-line no-undef


/***/},

/***/"83f0":
/***/function f0(module,exports,__webpack_require__){

var addSeconds=__webpack_require__("af1b");

/**
 * @category Second Helpers
 * @summary Subtract the specified number of seconds from the given date.
 *
 * @description
 * Subtract the specified number of seconds from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of seconds to be subtracted
 * @returns {Date} the new date with the seconds subtracted
 *
 * @example
 * // Subtract 30 seconds from 10 July 2014 12:45:00:
 * var result = subSeconds(new Date(2014, 6, 10, 12, 45, 0), 30)
 * //=> Thu Jul 10 2014 12:44:30
 */
function subSeconds(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addSeconds(dirtyDate,-amount);
}

module.exports=subSeconds;


/***/},

/***/"8436":
/***/function _(module,exports){

module.exports=function(){/* empty */};


/***/},

/***/"84b9":
/***/function b9(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Get the day of the ISO week of the given date.
 *
 * @description
 * Get the day of the ISO week of the given date,
 * which is 7 for Sunday, 1 for Monday etc.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the day of ISO week
 *
 * @example
 * // Which day of the ISO week is 26 February 2012?
 * var result = getISODay(new Date(2012, 1, 26))
 * //=> 7
 */
function getISODay(dirtyDate){
var date=parse(dirtyDate);
var day=date.getDay();

if(day===0){
day=7;
}

return day;
}

module.exports=getISODay;


/***/},

/***/"84f2":
/***/function f2(module,exports){

module.exports={};


/***/},

/***/"85f2":
/***/function f2(module,exports,__webpack_require__){

module.exports=__webpack_require__("454f");

/***/},

/***/"861d":
/***/function d(module,exports,__webpack_require__){

var getISOYear=__webpack_require__("8964");
var startOfISOWeek=__webpack_require__("b4c7");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Return the end of an ISO week-numbering year for the given date.
 *
 * @description
 * Return the end of an ISO week-numbering year,
 * which always starts 3 days before the year's first Thursday.
 * The result will be in the local timezone.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of an ISO week-numbering year
 *
 * @example
 * // The end of an ISO week-numbering year for 2 July 2005:
 * var result = endOfISOYear(new Date(2005, 6, 2))
 * //=> Sun Jan 01 2006 23:59:59.999
 */
function endOfISOYear(dirtyDate){
var year=getISOYear(dirtyDate);
var fourthOfJanuaryOfNextYear=new Date(0);
fourthOfJanuaryOfNextYear.setFullYear(year+1,0,4);
fourthOfJanuaryOfNextYear.setHours(0,0,0,0);
var date=startOfISOWeek(fourthOfJanuaryOfNextYear);
date.setMilliseconds(date.getMilliseconds()-1);
return date;
}

module.exports=endOfISOYear;


/***/},

/***/"86cc":
/***/function cc(module,exports,__webpack_require__){

var anObject=__webpack_require__("cb7c");
var IE8_DOM_DEFINE=__webpack_require__("c69a");
var toPrimitive=__webpack_require__("6a99");
var dP=Object.defineProperty;

exports.f=__webpack_require__("9e1e")?Object.defineProperty:function defineProperty(O,P,Attributes){
anObject(O);
P=toPrimitive(P,true);
anObject(Attributes);
if(IE8_DOM_DEFINE)try{
return dP(O,P,Attributes);
}catch(e){/* empty */}
if('get'in Attributes||'set'in Attributes)throw TypeError('Accessors not supported!');
if('value'in Attributes)O[P]=Attributes.value;
return O;
};


/***/},

/***/"8902":
/***/function _(module,exports,__webpack_require__){

var addYears=__webpack_require__("fcb3");

/**
 * @category Year Helpers
 * @summary Subtract the specified number of years from the given date.
 *
 * @description
 * Subtract the specified number of years from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of years to be subtracted
 * @returns {Date} the new date with the years subtracted
 *
 * @example
 * // Subtract 5 years from 1 September 2014:
 * var result = subYears(new Date(2014, 8, 1), 5)
 * //=> Tue Sep 01 2009 00:00:00
 */
function subYears(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addYears(dirtyDate,-amount);
}

module.exports=subYears;


/***/},

/***/"8946":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Day Helpers
 * @summary Add the specified number of days to the given date.
 *
 * @description
 * Add the specified number of days to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of days to be added
 * @returns {Date} the new date with the days added
 *
 * @example
 * // Add 10 days to 1 September 2014:
 * var result = addDays(new Date(2014, 8, 1), 10)
 * //=> Thu Sep 11 2014 00:00:00
 */
function addDays(dirtyDate,dirtyAmount){
var date=parse(dirtyDate);
var amount=Number(dirtyAmount);
date.setDate(date.getDate()+amount);
return date;
}

module.exports=addDays;


/***/},

/***/"8964":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var startOfISOWeek=__webpack_require__("b4c7");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Get the ISO week-numbering year of the given date.
 *
 * @description
 * Get the ISO week-numbering year of the given date,
 * which always starts 3 days before the year's first Thursday.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the ISO week-numbering year
 *
 * @example
 * // Which ISO-week numbering year is 2 January 2005?
 * var result = getISOYear(new Date(2005, 0, 2))
 * //=> 2004
 */
function getISOYear(dirtyDate){
var date=parse(dirtyDate);
var year=date.getFullYear();

var fourthOfJanuaryOfNextYear=new Date(0);
fourthOfJanuaryOfNextYear.setFullYear(year+1,0,4);
fourthOfJanuaryOfNextYear.setHours(0,0,0,0);
var startOfNextYear=startOfISOWeek(fourthOfJanuaryOfNextYear);

var fourthOfJanuaryOfThisYear=new Date(0);
fourthOfJanuaryOfThisYear.setFullYear(year,0,4);
fourthOfJanuaryOfThisYear.setHours(0,0,0,0);
var startOfThisYear=startOfISOWeek(fourthOfJanuaryOfThisYear);

if(date.getTime()>=startOfNextYear.getTime()){
return year+1;
}else if(date.getTime()>=startOfThisYear.getTime()){
return year;
}else {
return year-1;
}
}

module.exports=getISOYear;


/***/},

/***/"8a81":
/***/function a81(module,exports,__webpack_require__){

// ECMAScript 6 symbols shim
var global=__webpack_require__("7726");
var has=__webpack_require__("69a8");
var DESCRIPTORS=__webpack_require__("9e1e");
var $export=__webpack_require__("5ca1");
var redefine=__webpack_require__("2aba");
var META=__webpack_require__("67ab").KEY;
var $fails=__webpack_require__("79e5");
var shared=__webpack_require__("5537");
var setToStringTag=__webpack_require__("7f20");
var uid=__webpack_require__("ca5a");
var wks=__webpack_require__("2b4c");
var wksExt=__webpack_require__("37c8");
var wksDefine=__webpack_require__("3a72");
var enumKeys=__webpack_require__("d4c0");
var isArray=__webpack_require__("1169");
var anObject=__webpack_require__("cb7c");
var isObject=__webpack_require__("d3f4");
var toObject=__webpack_require__("4bf8");
var toIObject=__webpack_require__("6821");
var toPrimitive=__webpack_require__("6a99");
var createDesc=__webpack_require__("4630");
var _create=__webpack_require__("2aeb");
var gOPNExt=__webpack_require__("7bbc");
var $GOPD=__webpack_require__("11e9");
var $GOPS=__webpack_require__("2621");
var $DP=__webpack_require__("86cc");
var $keys=__webpack_require__("0d58");
var gOPD=$GOPD.f;
var dP=$DP.f;
var gOPN=gOPNExt.f;
var $Symbol=global.Symbol;
var $JSON=global.JSON;
var _stringify=$JSON&&$JSON.stringify;
var PROTOTYPE='prototype';
var HIDDEN=wks('_hidden');
var TO_PRIMITIVE=wks('toPrimitive');
var isEnum={}.propertyIsEnumerable;
var SymbolRegistry=shared('symbol-registry');
var AllSymbols=shared('symbols');
var OPSymbols=shared('op-symbols');
var ObjectProto=Object[PROTOTYPE];
var USE_NATIVE=typeof $Symbol=='function'&&!!$GOPS.f;
var QObject=global.QObject;
// Don't use setters in Qt Script, https://github.com/zloirock/core-js/issues/173
var setter=!QObject||!QObject[PROTOTYPE]||!QObject[PROTOTYPE].findChild;

// fallback for old Android, https://code.google.com/p/v8/issues/detail?id=687
var setSymbolDesc=DESCRIPTORS&&$fails(function(){
return _create(dP({},'a',{
get:function get(){return dP(this,'a',{value:7}).a;}})).
a!=7;
})?function(it,key,D){
var protoDesc=gOPD(ObjectProto,key);
if(protoDesc)delete ObjectProto[key];
dP(it,key,D);
if(protoDesc&&it!==ObjectProto)dP(ObjectProto,key,protoDesc);
}:dP;

var wrap=function wrap(tag){
var sym=AllSymbols[tag]=_create($Symbol[PROTOTYPE]);
sym._k=tag;
return sym;
};

var isSymbol=USE_NATIVE&&typeof $Symbol.iterator=='symbol'?function(it){
return typeof it=='symbol';
}:function(it){
return it instanceof $Symbol;
};

var $defineProperty=function defineProperty(it,key,D){
if(it===ObjectProto)$defineProperty(OPSymbols,key,D);
anObject(it);
key=toPrimitive(key,true);
anObject(D);
if(has(AllSymbols,key)){
if(!D.enumerable){
if(!has(it,HIDDEN))dP(it,HIDDEN,createDesc(1,{}));
it[HIDDEN][key]=true;
}else {
if(has(it,HIDDEN)&&it[HIDDEN][key])it[HIDDEN][key]=false;
D=_create(D,{enumerable:createDesc(0,false)});
}return setSymbolDesc(it,key,D);
}return dP(it,key,D);
};
var $defineProperties=function defineProperties(it,P){
anObject(it);
var keys=enumKeys(P=toIObject(P));
var i=0;
var l=keys.length;
var key;
while(l>i){$defineProperty(it,key=keys[i++],P[key]);}
return it;
};
var $create=function create(it,P){
return P===undefined?_create(it):$defineProperties(_create(it),P);
};
var $propertyIsEnumerable=function propertyIsEnumerable(key){
var E=isEnum.call(this,key=toPrimitive(key,true));
if(this===ObjectProto&&has(AllSymbols,key)&&!has(OPSymbols,key))return false;
return E||!has(this,key)||!has(AllSymbols,key)||has(this,HIDDEN)&&this[HIDDEN][key]?E:true;
};
var $getOwnPropertyDescriptor=function getOwnPropertyDescriptor(it,key){
it=toIObject(it);
key=toPrimitive(key,true);
if(it===ObjectProto&&has(AllSymbols,key)&&!has(OPSymbols,key))return;
var D=gOPD(it,key);
if(D&&has(AllSymbols,key)&&!(has(it,HIDDEN)&&it[HIDDEN][key]))D.enumerable=true;
return D;
};
var $getOwnPropertyNames=function getOwnPropertyNames(it){
var names=gOPN(toIObject(it));
var result=[];
var i=0;
var key;
while(names.length>i){
if(!has(AllSymbols,key=names[i++])&&key!=HIDDEN&&key!=META)result.push(key);
}return result;
};
var $getOwnPropertySymbols=function getOwnPropertySymbols(it){
var IS_OP=it===ObjectProto;
var names=gOPN(IS_OP?OPSymbols:toIObject(it));
var result=[];
var i=0;
var key;
while(names.length>i){
if(has(AllSymbols,key=names[i++])&&(IS_OP?has(ObjectProto,key):true))result.push(AllSymbols[key]);
}return result;
};

// 19.4.1.1 Symbol([description])
if(!USE_NATIVE){
$Symbol=function Symbol(){
if(this instanceof $Symbol)throw TypeError('Symbol is not a constructor!');
var tag=uid(arguments.length>0?arguments[0]:undefined);
var $set=function $set(value){
if(this===ObjectProto)$set.call(OPSymbols,value);
if(has(this,HIDDEN)&&has(this[HIDDEN],tag))this[HIDDEN][tag]=false;
setSymbolDesc(this,tag,createDesc(1,value));
};
if(DESCRIPTORS&&setter)setSymbolDesc(ObjectProto,tag,{configurable:true,set:$set});
return wrap(tag);
};
redefine($Symbol[PROTOTYPE],'toString',function toString(){
return this._k;
});

$GOPD.f=$getOwnPropertyDescriptor;
$DP.f=$defineProperty;
__webpack_require__("9093").f=gOPNExt.f=$getOwnPropertyNames;
__webpack_require__("52a7").f=$propertyIsEnumerable;
$GOPS.f=$getOwnPropertySymbols;

if(DESCRIPTORS&&!__webpack_require__("2d00")){
redefine(ObjectProto,'propertyIsEnumerable',$propertyIsEnumerable,true);
}

wksExt.f=function(name){
return wrap(wks(name));
};
}

$export($export.G+$export.W+$export.F*!USE_NATIVE,{Symbol:$Symbol});

for(var es6Symbols=
// 19.4.2.2, 19.4.2.3, 19.4.2.4, 19.4.2.6, 19.4.2.8, 19.4.2.9, 19.4.2.10, 19.4.2.11, 19.4.2.12, 19.4.2.13, 19.4.2.14
'hasInstance,isConcatSpreadable,iterator,match,replace,search,species,split,toPrimitive,toStringTag,unscopables'.
split(','),j=0;es6Symbols.length>j;){wks(es6Symbols[j++]);}

for(var wellKnownSymbols=$keys(wks.store),k=0;wellKnownSymbols.length>k;){wksDefine(wellKnownSymbols[k++]);}

$export($export.S+$export.F*!USE_NATIVE,'Symbol',{
// 19.4.2.1 Symbol.for(key)
'for':function _for(key){
return has(SymbolRegistry,key+='')?
SymbolRegistry[key]:
SymbolRegistry[key]=$Symbol(key);
},
// 19.4.2.5 Symbol.keyFor(sym)
keyFor:function keyFor(sym){
if(!isSymbol(sym))throw TypeError(sym+' is not a symbol!');
for(var key in SymbolRegistry){if(SymbolRegistry[key]===sym)return key;}
},
useSetter:function useSetter(){setter=true;},
useSimple:function useSimple(){setter=false;}});


$export($export.S+$export.F*!USE_NATIVE,'Object',{
// 19.1.2.2 Object.create(O [, Properties])
create:$create,
// 19.1.2.4 Object.defineProperty(O, P, Attributes)
defineProperty:$defineProperty,
// 19.1.2.3 Object.defineProperties(O, Properties)
defineProperties:$defineProperties,
// 19.1.2.6 Object.getOwnPropertyDescriptor(O, P)
getOwnPropertyDescriptor:$getOwnPropertyDescriptor,
// 19.1.2.7 Object.getOwnPropertyNames(O)
getOwnPropertyNames:$getOwnPropertyNames,
// 19.1.2.8 Object.getOwnPropertySymbols(O)
getOwnPropertySymbols:$getOwnPropertySymbols});


// Chrome 38 and 39 `Object.getOwnPropertySymbols` fails on primitives
// https://bugs.chromium.org/p/v8/issues/detail?id=3443
var FAILS_ON_PRIMITIVES=$fails(function(){$GOPS.f(1);});

$export($export.S+$export.F*FAILS_ON_PRIMITIVES,'Object',{
getOwnPropertySymbols:function getOwnPropertySymbols(it){
return $GOPS.f(toObject(it));
}});


// 24.3.2 JSON.stringify(value [, replacer [, space]])
$JSON&&$export($export.S+$export.F*(!USE_NATIVE||$fails(function(){
var S=$Symbol();
// MS Edge converts symbol values to JSON as {}
// WebKit converts symbol values to JSON as null
// V8 throws on boxed symbols
return _stringify([S])!='[null]'||_stringify({a:S})!='{}'||_stringify(Object(S))!='{}';
})),'JSON',{
stringify:function stringify(it){
var args=[it];
var i=1;
var replacer,$replacer;
while(arguments.length>i){args.push(arguments[i++]);}
$replacer=replacer=args[1];
if(!isObject(replacer)&&it===undefined||isSymbol(it))return;// IE8 returns string on undefined
if(!isArray(replacer))replacer=function replacer(key,value){
if(typeof $replacer=='function')value=$replacer.call(this,key,value);
if(!isSymbol(value))return value;
};
args[1]=replacer;
return _stringify.apply($JSON,args);
}});


// 19.4.3.4 Symbol.prototype[@@toPrimitive](hint)
$Symbol[PROTOTYPE][TO_PRIMITIVE]||__webpack_require__("32e9")($Symbol[PROTOTYPE],TO_PRIMITIVE,$Symbol[PROTOTYPE].valueOf);
// 19.4.3.5 Symbol.prototype[@@toStringTag]
setToStringTag($Symbol,'Symbol');
// 20.2.1.9 Math[@@toStringTag]
setToStringTag(Math,'Math',true);
// 24.3.3 JSON[@@toStringTag]
setToStringTag(global.JSON,'JSON',true);


/***/},

/***/"8aed":
/***/function aed(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Minute Helpers
 * @summary Set the minutes to the given date.
 *
 * @description
 * Set the minutes to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} minutes - the minutes of the new date
 * @returns {Date} the new date with the minutes setted
 *
 * @example
 * // Set 45 minutes to 1 September 2014 11:30:40:
 * var result = setMinutes(new Date(2014, 8, 1, 11, 30, 40), 45)
 * //=> Mon Sep 01 2014 11:45:40
 */
function setMinutes(dirtyDate,dirtyMinutes){
var date=parse(dirtyDate);
var minutes=Number(dirtyMinutes);
date.setMinutes(minutes);
return date;
}

module.exports=setMinutes;


/***/},

/***/"8b97":
/***/function b97(module,exports,__webpack_require__){

// Works with __proto__ only. Old v8 can't work with null proto objects.
/* eslint-disable no-proto */
var isObject=__webpack_require__("d3f4");
var anObject=__webpack_require__("cb7c");
var check=function check(O,proto){
anObject(O);
if(!isObject(proto)&&proto!==null)throw TypeError(proto+": can't set as prototype!");
};
module.exports={
set:Object.setPrototypeOf||('__proto__'in{}?// eslint-disable-line
function(test,buggy,set){
try{
set=__webpack_require__("9b43")(Function.call,__webpack_require__("11e9").f(Object.prototype,'__proto__').set,2);
set(test,[]);
buggy=!(test instanceof Array);
}catch(e){buggy=true;}
return function setPrototypeOf(O,proto){
check(O,proto);
if(buggy)O.__proto__=proto;else
set(O,proto);
return O;
};
}({},false):undefined),
check:check};



/***/},

/***/"8bbf":
/***/function bbf(module,exports){

module.exports=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");

/***/},

/***/"8c81":
/***/function c81(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Millisecond Helpers
 * @summary Get the milliseconds of the given date.
 *
 * @description
 * Get the milliseconds of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the milliseconds
 *
 * @example
 * // Get the milliseconds of 29 February 2012 11:45:05.123:
 * var result = getMilliseconds(new Date(2012, 1, 29, 11, 45, 5, 123))
 * //=> 123
 */
function getMilliseconds(dirtyDate){
var date=parse(dirtyDate);
var milliseconds=date.getMilliseconds();
return milliseconds;
}

module.exports=getMilliseconds;


/***/},

/***/"8e60":
/***/function e60(module,exports,__webpack_require__){

// Thank's IE8 for his funny defineProperty
module.exports=!__webpack_require__("294c")(function(){
return Object.defineProperty({},'a',{get:function get(){return 7;}}).a!=7;
});


/***/},

/***/"8f60":
/***/function f60(module,exports,__webpack_require__){

var create=__webpack_require__("a159");
var descriptor=__webpack_require__("aebd");
var setToStringTag=__webpack_require__("45f2");
var IteratorPrototype={};

// 25.1.2.1.1 %IteratorPrototype%[@@iterator]()
__webpack_require__("35e8")(IteratorPrototype,__webpack_require__("5168")('iterator'),function(){return this;});

module.exports=function(Constructor,NAME,next){
Constructor.prototype=create(IteratorPrototype,{next:descriptor(1,next)});
setToStringTag(Constructor,NAME+' Iterator');
};


/***/},

/***/"9003":
/***/function _(module,exports,__webpack_require__){

// 7.2.2 IsArray(argument)
var cof=__webpack_require__("6b4c");
module.exports=Array.isArray||function isArray(arg){
return cof(arg)=='Array';
};


/***/},

/***/"902e":
/***/function e(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Timestamp Helpers
 * @summary Get the milliseconds timestamp of the given date.
 *
 * @description
 * Get the milliseconds timestamp of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the timestamp
 *
 * @example
 * // Get the timestamp of 29 February 2012 11:45:05.123:
 * var result = getTime(new Date(2012, 1, 29, 11, 45, 5, 123))
 * //=> 1330515905123
 */
function getTime(dirtyDate){
var date=parse(dirtyDate);
var timestamp=date.getTime();
return timestamp;
}

module.exports=getTime;


/***/},

/***/"9093":
/***/function _(module,exports,__webpack_require__){

// 19.1.2.7 / 15.2.3.4 Object.getOwnPropertyNames(O)
var $keys=__webpack_require__("ce10");
var hiddenKeys=__webpack_require__("e11e").concat('length','prototype');

exports.f=Object.getOwnPropertyNames||function getOwnPropertyNames(O){
return $keys(O,hiddenKeys);
};


/***/},

/***/"90e5":
/***/function e5(module,exports){

var commonFormatterKeys=[
'M','MM','Q','D','DD','DDD','DDDD','d',
'E','W','WW','YY','YYYY','GG','GGGG',
'H','HH','h','hh','m','mm',
's','ss','S','SS','SSS',
'Z','ZZ','X','x'];


function buildFormattingTokensRegExp(formatters){
var formatterKeys=[];
for(var key in formatters){
if(formatters.hasOwnProperty(key)){
formatterKeys.push(key);
}
}

var formattingTokens=commonFormatterKeys.
concat(formatterKeys).
sort().
reverse();
var formattingTokensRegExp=new RegExp(
'(\\[[^\\[]*\\])|(\\\\)?'+'('+formattingTokens.join('|')+'|.)','g');


return formattingTokensRegExp;
}

module.exports=buildFormattingTokensRegExp;


/***/},

/***/"9113":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Second Helpers
 * @summary Set the seconds to the given date.
 *
 * @description
 * Set the seconds to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} seconds - the seconds of the new date
 * @returns {Date} the new date with the seconds setted
 *
 * @example
 * // Set 45 seconds to 1 September 2014 11:30:40:
 * var result = setSeconds(new Date(2014, 8, 1, 11, 30, 40), 45)
 * //=> Mon Sep 01 2014 11:30:45
 */
function setSeconds(dirtyDate,dirtySeconds){
var date=parse(dirtyDate);
var seconds=Number(dirtySeconds);
date.setSeconds(seconds);
return date;
}

module.exports=setSeconds;


/***/},

/***/"9138":
/***/function _(module,exports,__webpack_require__){

module.exports=__webpack_require__("35e8");


/***/},

/***/"9427":
/***/function _(module,exports,__webpack_require__){

var $export=__webpack_require__("63b6");
// 19.1.2.2 / 15.2.3.5 Object.create(O [, Properties])
$export($export.S,'Object',{create:__webpack_require__("a159")});


/***/},

/***/"942b":
/***/function b(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Return the start of a month for the given date.
 *
 * @description
 * Return the start of a month for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of a month
 *
 * @example
 * // The start of a month for 2 September 2014 11:55:00:
 * var result = startOfMonth(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Mon Sep 01 2014 00:00:00
 */
function startOfMonth(dirtyDate){
var date=parse(dirtyDate);
date.setDate(1);
date.setHours(0,0,0,0);
return date;
}

module.exports=startOfMonth;


/***/},

/***/"9530":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Day Helpers
 * @summary Set the day of the year to the given date.
 *
 * @description
 * Set the day of the year to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} dayOfYear - the day of the year of the new date
 * @returns {Date} the new date with the day of the year setted
 *
 * @example
 * // Set the 2nd day of the year to 2 July 2014:
 * var result = setDayOfYear(new Date(2014, 6, 2), 2)
 * //=> Thu Jan 02 2014 00:00:00
 */
function setDayOfYear(dirtyDate,dirtyDayOfYear){
var date=parse(dirtyDate);
var dayOfYear=Number(dirtyDayOfYear);
date.setMonth(0);
date.setDate(dayOfYear);
return date;
}

module.exports=setDayOfYear;


/***/},

/***/"957f":
/***/function f(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Day Helpers
 * @summary Set the day of the month to the given date.
 *
 * @description
 * Set the day of the month to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} dayOfMonth - the day of the month of the new date
 * @returns {Date} the new date with the day of the month setted
 *
 * @example
 * // Set the 30th day of the month to 1 September 2014:
 * var result = setDate(new Date(2014, 8, 1), 30)
 * //=> Tue Sep 30 2014 00:00:00
 */
function setDate(dirtyDate,dirtyDayOfMonth){
var date=parse(dirtyDate);
var dayOfMonth=Number(dirtyDayOfMonth);
date.setDate(dayOfMonth);
return date;
}

module.exports=setDate;


/***/},

/***/"95d5":
/***/function d5(module,exports,__webpack_require__){

var classof=__webpack_require__("40c3");
var ITERATOR=__webpack_require__("5168")('iterator');
var Iterators=__webpack_require__("481b");
module.exports=__webpack_require__("584a").isIterable=function(it){
var O=Object(it);
return O[ITERATOR]!==undefined||
'@@iterator'in O
// eslint-disable-next-line no-prototype-builtins
||Iterators.hasOwnProperty(classof(O));
};


/***/},

/***/"95ea":
/***/function ea(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Return the latest of the given dates.
 *
 * @description
 * Return the latest of the given dates.
 *
 * @param {...(Date|String|Number)} dates - the dates to compare
 * @returns {Date} the latest of the dates
 *
 * @example
 * // Which of these dates is the latest?
 * var result = max(
 *   new Date(1989, 6, 10),
 *   new Date(1987, 1, 11),
 *   new Date(1995, 6, 2),
 *   new Date(1990, 0, 1)
 * )
 * //=> Sun Jul 02 1995 00:00:00
 */
function max(){
var dirtyDates=Array.prototype.slice.call(arguments);
var dates=dirtyDates.map(function(dirtyDate){
return parse(dirtyDate);
});
var latestTimestamp=Math.max.apply(null,dates);
return new Date(latestTimestamp);
}

module.exports=max;


/***/},

/***/"9706":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var startOfISOYear=__webpack_require__("4497");
var differenceInCalendarDays=__webpack_require__("d420");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Set the ISO week-numbering year to the given date.
 *
 * @description
 * Set the ISO week-numbering year to the given date,
 * saving the week number and the weekday number.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} isoYear - the ISO week-numbering year of the new date
 * @returns {Date} the new date with the ISO week-numbering year setted
 *
 * @example
 * // Set ISO week-numbering year 2007 to 29 December 2008:
 * var result = setISOYear(new Date(2008, 11, 29), 2007)
 * //=> Mon Jan 01 2007 00:00:00
 */
function setISOYear(dirtyDate,dirtyISOYear){
var date=parse(dirtyDate);
var isoYear=Number(dirtyISOYear);
var diff=differenceInCalendarDays(date,startOfISOYear(date));
var fourthOfJanuary=new Date(0);
fourthOfJanuary.setFullYear(isoYear,0,4);
fourthOfJanuary.setHours(0,0,0,0);
date=startOfISOYear(fourthOfJanuary);
date.setDate(date.getDate()+diff);
return date;
}

module.exports=setISOYear;


/***/},

/***/"9744":
/***/function _(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Day Helpers
 * @summary Return the end of a day for the given date.
 *
 * @description
 * Return the end of a day for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of a day
 *
 * @example
 * // The end of a day for 2 September 2014 11:55:00:
 * var result = endOfDay(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 02 2014 23:59:59.999
 */
function endOfDay(dirtyDate){
var date=parse(dirtyDate);
date.setHours(23,59,59,999);
return date;
}

module.exports=endOfDay;


/***/},

/***/"97af":
/***/function af(module,exports,__webpack_require__){

var isSameISOYear=__webpack_require__("2fff");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Is the given date in the same ISO week-numbering year as the current date?
 *
 * @description
 * Is the given date in the same ISO week-numbering year as the current date?
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this ISO week-numbering year
 *
 * @example
 * // If today is 25 September 2014,
 * // is 30 December 2013 in this ISO week-numbering year?
 * var result = isThisISOYear(new Date(2013, 11, 30))
 * //=> true
 */
function isThisISOYear(dirtyDate){
return isSameISOYear(new Date(),dirtyDate);
}

module.exports=isThisISOYear;


/***/},

/***/"9aa9":
/***/function aa9(module,exports){

exports.f=Object.getOwnPropertySymbols;


/***/},

/***/"9aaa":
/***/function aaa(module,exports,__webpack_require__){

var startOfQuarter=__webpack_require__("4399");

/**
 * @category Quarter Helpers
 * @summary Are the given dates in the same year quarter?
 *
 * @description
 * Are the given dates in the same year quarter?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same quarter
 *
 * @example
 * // Are 1 January 2014 and 8 March 2014 in the same quarter?
 * var result = isSameQuarter(
 *   new Date(2014, 0, 1),
 *   new Date(2014, 2, 8)
 * )
 * //=> true
 */
function isSameQuarter(dirtyDateLeft,dirtyDateRight){
var dateLeftStartOfQuarter=startOfQuarter(dirtyDateLeft);
var dateRightStartOfQuarter=startOfQuarter(dirtyDateRight);

return dateLeftStartOfQuarter.getTime()===dateRightStartOfQuarter.getTime();
}

module.exports=isSameQuarter;


/***/},

/***/"9ad8":
/***/function ad8(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Does the given date fall on a weekend?
 *
 * @description
 * Does the given date fall on a weekend?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date falls on a weekend
 *
 * @example
 * // Does 5 October 2014 fall on a weekend?
 * var result = isWeekend(new Date(2014, 9, 5))
 * //=> true
 */
function isWeekend(dirtyDate){
var date=parse(dirtyDate);
var day=date.getDay();
return day===0||day===6;
}

module.exports=isWeekend;


/***/},

/***/"9b43":
/***/function b43(module,exports,__webpack_require__){

// optional / simple context binding
var aFunction=__webpack_require__("d8e8");
module.exports=function(fn,that,length){
aFunction(fn);
if(that===undefined)return fn;
switch(length){
case 1:return function(a){
return fn.call(that,a);
};
case 2:return function(a,b){
return fn.call(that,a,b);
};
case 3:return function(a,b,c){
return fn.call(that,a,b,c);
};}

return function()/* ...args */{
return fn.apply(that,arguments);
};
};


/***/},

/***/"9bb9":
/***/function bb9(module,exports,__webpack_require__){

var isSameMonth=__webpack_require__("5a60");

/**
 * @category Month Helpers
 * @summary Is the given date in the same month as the current date?
 *
 * @description
 * Is the given date in the same month as the current date?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this month
 *
 * @example
 * // If today is 25 September 2014, is 15 September 2014 in this month?
 * var result = isThisMonth(new Date(2014, 8, 15))
 * //=> true
 */
function isThisMonth(dirtyDate){
return isSameMonth(new Date(),dirtyDate);
}

module.exports=isThisMonth;


/***/},

/***/"9c6c":
/***/function c6c(module,exports,__webpack_require__){

// 22.1.3.31 Array.prototype[@@unscopables]
var UNSCOPABLES=__webpack_require__("2b4c")('unscopables');
var ArrayProto=Array.prototype;
if(ArrayProto[UNSCOPABLES]==undefined)__webpack_require__("32e9")(ArrayProto,UNSCOPABLES,{});
module.exports=function(key){
ArrayProto[UNSCOPABLES][key]=true;
};


/***/},

/***/"9def":
/***/function def(module,exports,__webpack_require__){

// 7.1.15 ToLength
var toInteger=__webpack_require__("4588");
var min=Math.min;
module.exports=function(it){
return it>0?min(toInteger(it),0x1fffffffffffff):0;// pow(2, 53) - 1 == 9007199254740991
};


/***/},

/***/"9e1e":
/***/function e1e(module,exports,__webpack_require__){

// Thank's IE8 for his funny defineProperty
module.exports=!__webpack_require__("79e5")(function(){
return Object.defineProperty({},'a',{get:function get(){return 7;}}).a!=7;
});


/***/},

/***/"9f3f":
/***/function f3f(module,exports,__webpack_require__){

var buildDistanceInWordsLocale=__webpack_require__("2a63");
var buildFormatLocale=__webpack_require__("5140");

/**
 * @category Locales
 * @summary Russian locale.
 */
module.exports={
distanceInWords:buildDistanceInWordsLocale(),
format:buildFormatLocale()};



/***/},

/***/"a159":
/***/function a159(module,exports,__webpack_require__){

// 19.1.2.2 / 15.2.3.5 Object.create(O [, Properties])
var anObject=__webpack_require__("e4ae");
var dPs=__webpack_require__("7e90");
var enumBugKeys=__webpack_require__("1691");
var IE_PROTO=__webpack_require__("5559")('IE_PROTO');
var Empty=function Empty(){/* empty */};
var PROTOTYPE='prototype';

// Create object with fake `null` prototype: use iframe Object with cleared prototype
var _createDict2=function createDict(){
// Thrash, waste and sodomy: IE GC bug
var iframe=__webpack_require__("1ec9")('iframe');
var i=enumBugKeys.length;
var lt='<';
var gt='>';
var iframeDocument;
iframe.style.display='none';
__webpack_require__("32fc").appendChild(iframe);
iframe.src='javascript:';// eslint-disable-line no-script-url
// createDict = iframe.contentWindow.Object;
// html.removeChild(iframe);
iframeDocument=iframe.contentWindow.document;
iframeDocument.open();
iframeDocument.write(lt+'script'+gt+'document.F=Object'+lt+'/script'+gt);
iframeDocument.close();
_createDict2=iframeDocument.F;
while(i--){delete _createDict2[PROTOTYPE][enumBugKeys[i]];}
return _createDict2();
};

module.exports=Object.create||function create(O,Properties){
var result;
if(O!==null){
Empty[PROTOTYPE]=anObject(O);
result=new Empty();
Empty[PROTOTYPE]=null;
// add "__proto__" for Object.getPrototypeOf polyfill
result[IE_PROTO]=O;
}else result=_createDict2();
return Properties===undefined?result:dPs(result,Properties);
};


/***/},

/***/"a431":
/***/function a431(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Is the first date after the second one?
 *
 * @description
 * Is the first date after the second one?
 *
 * @param {Date|String|Number} date - the date that should be after the other one to return true
 * @param {Date|String|Number} dateToCompare - the date to compare with
 * @returns {Boolean} the first date is after the second date
 *
 * @example
 * // Is 10 July 1989 after 11 February 1987?
 * var result = isAfter(new Date(1989, 6, 10), new Date(1987, 1, 11))
 * //=> true
 */
function isAfter(dirtyDate,dirtyDateToCompare){
var date=parse(dirtyDate);
var dateToCompare=parse(dirtyDateToCompare);
return date.getTime()>dateToCompare.getTime();
}

module.exports=isAfter;


/***/},

/***/"a4b7":
/***/function a4b7(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Return the start of a year for the given date.
 *
 * @description
 * Return the start of a year for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of a year
 *
 * @example
 * // The start of a year for 2 September 2014 11:55:00:
 * var result = startOfYear(new Date(2014, 8, 2, 11, 55, 00))
 * //=> Wed Jan 01 2014 00:00:00
 */
function startOfYear(dirtyDate){
var cleanDate=parse(dirtyDate);
var date=new Date(0);
date.setFullYear(cleanDate.getFullYear(),0,1);
date.setHours(0,0,0,0);
return date;
}

module.exports=startOfYear;


/***/},

/***/"a735":
/***/function a735(module,exports){

/**
 * @category Common Helpers
 * @summary Is the given argument an instance of Date?
 *
 * @description
 * Is the given argument an instance of Date?
 *
 * @param {*} argument - the argument to check
 * @returns {Boolean} the given argument is an instance of Date
 *
 * @example
 * // Is 'mayonnaise' a Date?
 * var result = isDate('mayonnaise')
 * //=> false
 */
function isDate(argument){
return argument instanceof Date;
}

module.exports=isDate;


/***/},

/***/"a745":
/***/function a745(module,exports,__webpack_require__){

module.exports=__webpack_require__("f410");

/***/},

/***/"a852":
/***/function a852(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Is the given date Friday?
 *
 * @description
 * Is the given date Friday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is Friday
 *
 * @example
 * // Is 26 September 2014 Friday?
 * var result = isFriday(new Date(2014, 8, 26))
 * //=> true
 */
function isFriday(dirtyDate){
return parse(dirtyDate).getDay()===5;
}

module.exports=isFriday;


/***/},

/***/"a935":
/***/function a935(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Is the given date in the past?
 *
 * @description
 * Is the given date in the past?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in the past
 *
 * @example
 * // If today is 6 October 2014, is 2 July 2014 in the past?
 * var result = isPast(new Date(2014, 6, 2))
 * //=> true
 */
function isPast(dirtyDate){
return parse(dirtyDate).getTime()<new Date().getTime();
}

module.exports=isPast;


/***/},

/***/"aa77":
/***/function aa77(module,exports,__webpack_require__){

var $export=__webpack_require__("5ca1");
var defined=__webpack_require__("be13");
var fails=__webpack_require__("79e5");
var spaces=__webpack_require__("fdef");
var space='['+spaces+']';
var non="\u200B\x85";
var ltrim=RegExp('^'+space+space+'*');
var rtrim=RegExp(space+space+'*$');

var exporter=function exporter(KEY,exec,ALIAS){
var exp={};
var FORCE=fails(function(){
return !!spaces[KEY]()||non[KEY]()!=non;
});
var fn=exp[KEY]=FORCE?exec(trim):spaces[KEY];
if(ALIAS)exp[ALIAS]=fn;
$export($export.P+$export.F*FORCE,'String',exp);
};

// 1 -> String#trimLeft
// 2 -> String#trimRight
// 3 -> String#trim
var trim=exporter.trim=function(string,TYPE){
string=String(defined(string));
if(TYPE&1)string=string.replace(ltrim,'');
if(TYPE&2)string=string.replace(rtrim,'');
return string;
};

module.exports=exporter;


/***/},

/***/"abd4":
/***/function abd4(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Are the given dates equal?
 *
 * @description
 * Are the given dates equal?
 *
 * @param {Date|String|Number} dateLeft - the first date to compare
 * @param {Date|String|Number} dateRight - the second date to compare
 * @returns {Boolean} the dates are equal
 *
 * @example
 * // Are 2 July 2014 06:30:45.000 and 2 July 2014 06:30:45.500 equal?
 * var result = isEqual(
 *   new Date(2014, 6, 2, 6, 30, 45, 0)
 *   new Date(2014, 6, 2, 6, 30, 45, 500)
 * )
 * //=> false
 */
function isEqual(dirtyLeftDate,dirtyRightDate){
var dateLeft=parse(dirtyLeftDate);
var dateRight=parse(dirtyRightDate);
return dateLeft.getTime()===dateRight.getTime();
}

module.exports=isEqual;


/***/},

/***/"ac4d":
/***/function ac4d(module,exports,__webpack_require__){

__webpack_require__("3a72")('asyncIterator');


/***/},

/***/"ac6a":
/***/function ac6a(module,exports,__webpack_require__){

var $iterators=__webpack_require__("cadf");
var getKeys=__webpack_require__("0d58");
var redefine=__webpack_require__("2aba");
var global=__webpack_require__("7726");
var hide=__webpack_require__("32e9");
var Iterators=__webpack_require__("84f2");
var wks=__webpack_require__("2b4c");
var ITERATOR=wks('iterator');
var TO_STRING_TAG=wks('toStringTag');
var ArrayValues=Iterators.Array;

var DOMIterables={
CSSRuleList:true,// TODO: Not spec compliant, should be false.
CSSStyleDeclaration:false,
CSSValueList:false,
ClientRectList:false,
DOMRectList:false,
DOMStringList:false,
DOMTokenList:true,
DataTransferItemList:false,
FileList:false,
HTMLAllCollection:false,
HTMLCollection:false,
HTMLFormElement:false,
HTMLSelectElement:false,
MediaList:true,// TODO: Not spec compliant, should be false.
MimeTypeArray:false,
NamedNodeMap:false,
NodeList:true,
PaintRequestList:false,
Plugin:false,
PluginArray:false,
SVGLengthList:false,
SVGNumberList:false,
SVGPathSegList:false,
SVGPointList:false,
SVGStringList:false,
SVGTransformList:false,
SourceBufferList:false,
StyleSheetList:true,// TODO: Not spec compliant, should be false.
TextTrackCueList:false,
TextTrackList:false,
TouchList:false};


for(var collections=getKeys(DOMIterables),i=0;i<collections.length;i++){
var NAME=collections[i];
var explicit=DOMIterables[NAME];
var Collection=global[NAME];
var proto=Collection&&Collection.prototype;
var key;
if(proto){
if(!proto[ITERATOR])hide(proto,ITERATOR,ArrayValues);
if(!proto[TO_STRING_TAG])hide(proto,TO_STRING_TAG,NAME);
Iterators[NAME]=ArrayValues;
if(explicit)for(key in $iterators){if(!proto[key])redefine(proto,key,$iterators[key],true);}
}
}


/***/},

/***/"acc4":
/***/function acc4(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Is the given date in the leap year?
 *
 * @description
 * Is the given date in the leap year?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in the leap year
 *
 * @example
 * // Is 1 September 2012 in the leap year?
 * var result = isLeapYear(new Date(2012, 8, 1))
 * //=> true
 */
function isLeapYear(dirtyDate){
var date=parse(dirtyDate);
var year=date.getFullYear();
return year%400===0||year%4===0&&year%100!==0;
}

module.exports=isLeapYear;


/***/},

/***/"aebd":
/***/function aebd(module,exports){

module.exports=function(bitmap,value){
return {
enumerable:!(bitmap&1),
configurable:!(bitmap&2),
writable:!(bitmap&4),
value:value};

};


/***/},

/***/"af1b":
/***/function af1b(module,exports,__webpack_require__){

var addMilliseconds=__webpack_require__("ec1f");

/**
 * @category Second Helpers
 * @summary Add the specified number of seconds to the given date.
 *
 * @description
 * Add the specified number of seconds to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of seconds to be added
 * @returns {Date} the new date with the seconds added
 *
 * @example
 * // Add 30 seconds to 10 July 2014 12:45:00:
 * var result = addSeconds(new Date(2014, 6, 10, 12, 45, 0), 30)
 * //=> Thu Jul 10 2014 12:45:30
 */
function addSeconds(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addMilliseconds(dirtyDate,amount*1000);
}

module.exports=addSeconds;


/***/},

/***/"b2e9":
/***/function b2e9(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Get the number of calendar months between the given dates.
 *
 * @description
 * Get the number of calendar months between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of calendar months
 *
 * @example
 * // How many calendar months are between 31 January 2014 and 1 September 2014?
 * var result = differenceInCalendarMonths(
 *   new Date(2014, 8, 1),
 *   new Date(2014, 0, 31)
 * )
 * //=> 8
 */
function differenceInCalendarMonths(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);

var yearDiff=dateLeft.getFullYear()-dateRight.getFullYear();
var monthDiff=dateLeft.getMonth()-dateRight.getMonth();

return yearDiff*12+monthDiff;
}

module.exports=differenceInCalendarMonths;


/***/},

/***/"b3f5":
/***/function b3f5(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var differenceInCalendarISOYears=__webpack_require__("f9ff");
var compareAsc=__webpack_require__("0d3e");
var subISOYears=__webpack_require__("df35");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Get the number of full ISO week-numbering years between the given dates.
 *
 * @description
 * Get the number of full ISO week-numbering years between the given dates.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of full ISO week-numbering years
 *
 * @example
 * // How many full ISO week-numbering years are between 1 January 2010 and 1 January 2012?
 * var result = differenceInISOYears(
 *   new Date(2012, 0, 1),
 *   new Date(2010, 0, 1)
 * )
 * //=> 1
 */
function differenceInISOYears(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);

var sign=compareAsc(dateLeft,dateRight);
var difference=Math.abs(differenceInCalendarISOYears(dateLeft,dateRight));
dateLeft=subISOYears(dateLeft,sign*difference);

// Math.abs(diff in full ISO years - diff in calendar ISO years) === 1
// if last calendar ISO year is not full
// If so, result must be decreased by 1 in absolute value
var isLastISOYearNotFull=compareAsc(dateLeft,dateRight)===-sign;
return sign*(difference-isLastISOYearNotFull);
}

module.exports=differenceInISOYears;


/***/},

/***/"b447":
/***/function b447(module,exports,__webpack_require__){

// 7.1.15 ToLength
var toInteger=__webpack_require__("3a38");
var min=Math.min;
module.exports=function(it){
return it>0?min(toInteger(it),0x1fffffffffffff):0;// pow(2, 53) - 1 == 9007199254740991
};


/***/},

/***/"b4c7":
/***/function b4c7(module,exports,__webpack_require__){

var startOfWeek=__webpack_require__("c7ce");

/**
 * @category ISO Week Helpers
 * @summary Return the start of an ISO week for the given date.
 *
 * @description
 * Return the start of an ISO week for the given date.
 * The result will be in the local timezone.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of an ISO week
 *
 * @example
 * // The start of an ISO week for 2 September 2014 11:55:00:
 * var result = startOfISOWeek(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Mon Sep 01 2014 00:00:00
 */
function startOfISOWeek(dirtyDate){
return startOfWeek(dirtyDate,{weekStartsOn:1});
}

module.exports=startOfISOWeek;


/***/},

/***/"b60f":
/***/function b60f(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Day Helpers
 * @summary Get the day of the month of the given date.
 *
 * @description
 * Get the day of the month of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the day of month
 *
 * @example
 * // Which day of the month is 29 February 2012?
 * var result = getDate(new Date(2012, 1, 29))
 * //=> 29
 */
function getDate(dirtyDate){
var date=parse(dirtyDate);
var dayOfMonth=date.getDate();
return dayOfMonth;
}

module.exports=getDate;


/***/},

/***/"b78a":
/***/function b78a(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var addDays=__webpack_require__("8946");

/**
 * @category Weekday Helpers
 * @summary Set the day of the week to the given date.
 *
 * @description
 * Set the day of the week to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} day - the day of the week of the new date
 * @param {Object} [options] - the object with options
 * @param {Number} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @returns {Date} the new date with the day of the week setted
 *
 * @example
 * // Set Sunday to 1 September 2014:
 * var result = setDay(new Date(2014, 8, 1), 0)
 * //=> Sun Aug 31 2014 00:00:00
 *
 * @example
 * // If week starts with Monday, set Sunday to 1 September 2014:
 * var result = setDay(new Date(2014, 8, 1), 0, {weekStartsOn: 1})
 * //=> Sun Sep 07 2014 00:00:00
 */
function setDay(dirtyDate,dirtyDay,dirtyOptions){
var weekStartsOn=dirtyOptions?Number(dirtyOptions.weekStartsOn)||0:0;
var date=parse(dirtyDate);
var day=Number(dirtyDay);
var currentDay=date.getDay();

var remainder=day%7;
var dayIndex=(remainder+7)%7;

var diff=(dayIndex<weekStartsOn?7:0)+day-currentDay;
return addDays(date,diff);
}

module.exports=setDay;


/***/},

/***/"b8a7":
/***/function b8a7(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Return the last day of a year for the given date.
 *
 * @description
 * Return the last day of a year for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the last day of a year
 *
 * @example
 * // The last day of a year for 2 September 2014 11:55:00:
 * var result = lastDayOfYear(new Date(2014, 8, 2, 11, 55, 00))
 * //=> Wed Dec 31 2014 00:00:00
 */
function lastDayOfYear(dirtyDate){
var date=parse(dirtyDate);
var year=date.getFullYear();
date.setFullYear(year+1,0,0);
date.setHours(0,0,0,0);
return date;
}

module.exports=lastDayOfYear;


/***/},

/***/"b8e3":
/***/function b8e3(module,exports){

module.exports=true;


/***/},

/***/"b8f9":
/***/function b8f9(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Quarter Helpers
 * @summary Get the year quarter of the given date.
 *
 * @description
 * Get the year quarter of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the quarter
 *
 * @example
 * // Which quarter is 2 July 2014?
 * var result = getQuarter(new Date(2014, 6, 2))
 * //=> 3
 */
function getQuarter(dirtyDate){
var date=parse(dirtyDate);
var quarter=Math.floor(date.getMonth()/3)+1;
return quarter;
}

module.exports=getQuarter;


/***/},

/***/"badb":
/***/function badb(module,exports,__webpack_require__){

var addMilliseconds=__webpack_require__("ec1f");

/**
 * @category Millisecond Helpers
 * @summary Subtract the specified number of milliseconds from the given date.
 *
 * @description
 * Subtract the specified number of milliseconds from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be subtracted
 * @returns {Date} the new date with the milliseconds subtracted
 *
 * @example
 * // Subtract 750 milliseconds from 10 July 2014 12:45:30.000:
 * var result = subMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:29.250
 */
function subMilliseconds(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addMilliseconds(dirtyDate,-amount);
}

module.exports=subMilliseconds;


/***/},

/***/"bb7c":
/***/function bb7c(module,exports,__webpack_require__){

var compareDesc=__webpack_require__("c873");
var parse=__webpack_require__("c8d5");
var differenceInSeconds=__webpack_require__("e13a");
var enLocale=__webpack_require__("52cf");

var MINUTES_IN_DAY=1440;
var MINUTES_IN_MONTH=43200;
var MINUTES_IN_YEAR=525600;

/**
 * @category Common Helpers
 * @summary Return the distance between the given dates in words.
 *
 * @description
 * Return the distance between the given dates in words, using strict units.
 * This is like `distanceInWords`, but does not use helpers like 'almost', 'over',
 * 'less than' and the like.
 *
 * | Distance between dates | Result              |
 * |------------------------|---------------------|
 * | 0 ... 59 secs          | [0..59] seconds     |
 * | 1 ... 59 mins          | [1..59] minutes     |
 * | 1 ... 23 hrs           | [1..23] hours       |
 * | 1 ... 29 days          | [1..29] days        |
 * | 1 ... 11 months        | [1..11] months      |
 * | 1 ... N years          | [1..N]  years       |
 *
 * @param {Date|String|Number} dateToCompare - the date to compare with
 * @param {Date|String|Number} date - the other date
 * @param {Object} [options] - the object with options
 * @param {Boolean} [options.addSuffix=false] - result indicates if the second date is earlier or later than the first
 * @param {'s'|'m'|'h'|'d'|'M'|'Y'} [options.unit] - if specified, will force a unit
 * @param {'floor'|'ceil'|'round'} [options.partialMethod='floor'] - which way to round partial units
 * @param {Object} [options.locale=enLocale] - the locale object
 * @returns {String} the distance in words
 *
 * @example
 * // What is the distance between 2 July 2014 and 1 January 2015?
 * var result = distanceInWordsStrict(
 *   new Date(2014, 6, 2),
 *   new Date(2015, 0, 2)
 * )
 * //=> '6 months'
 *
 * @example
 * // What is the distance between 1 January 2015 00:00:15
 * // and 1 January 2015 00:00:00?
 * var result = distanceInWordsStrict(
 *   new Date(2015, 0, 1, 0, 0, 15),
 *   new Date(2015, 0, 1, 0, 0, 0),
 * )
 * //=> '15 seconds'
 *
 * @example
 * // What is the distance from 1 January 2016
 * // to 1 January 2015, with a suffix?
 * var result = distanceInWordsStrict(
 *   new Date(2016, 0, 1),
 *   new Date(2015, 0, 1),
 *   {addSuffix: true}
 * )
 * //=> '1 year ago'
 *
 * @example
 * // What is the distance from 1 January 2016
 * // to 1 January 2015, in minutes?
 * var result = distanceInWordsStrict(
 *   new Date(2016, 0, 1),
 *   new Date(2015, 0, 1),
 *   {unit: 'm'}
 * )
 * //=> '525600 minutes'
 *
 * @example
 * // What is the distance from 1 January 2016
 * // to 28 January 2015, in months, rounded up?
 * var result = distanceInWordsStrict(
 *   new Date(2015, 0, 28),
 *   new Date(2015, 0, 1),
 *   {unit: 'M', partialMethod: 'ceil'}
 * )
 * //=> '1 month'
 *
 * @example
 * // What is the distance between 1 August 2016 and 1 January 2015 in Esperanto?
 * var eoLocale = require('date-fns/locale/eo')
 * var result = distanceInWordsStrict(
 *   new Date(2016, 7, 1),
 *   new Date(2015, 0, 1),
 *   {locale: eoLocale}
 * )
 * //=> '1 jaro'
 */
function distanceInWordsStrict(dirtyDateToCompare,dirtyDate,dirtyOptions){
var options=dirtyOptions||{};

var comparison=compareDesc(dirtyDateToCompare,dirtyDate);

var locale=options.locale;
var localize=enLocale.distanceInWords.localize;
if(locale&&locale.distanceInWords&&locale.distanceInWords.localize){
localize=locale.distanceInWords.localize;
}

var localizeOptions={
addSuffix:Boolean(options.addSuffix),
comparison:comparison};


var dateLeft,dateRight;
if(comparison>0){
dateLeft=parse(dirtyDateToCompare);
dateRight=parse(dirtyDate);
}else {
dateLeft=parse(dirtyDate);
dateRight=parse(dirtyDateToCompare);
}

var unit;
var mathPartial=Math[options.partialMethod?String(options.partialMethod):'floor'];
var seconds=differenceInSeconds(dateRight,dateLeft);
var offset=dateRight.getTimezoneOffset()-dateLeft.getTimezoneOffset();
var minutes=mathPartial(seconds/60)-offset;
var hours,days,months,years;

if(options.unit){
unit=String(options.unit);
}else {
if(minutes<1){
unit='s';
}else if(minutes<60){
unit='m';
}else if(minutes<MINUTES_IN_DAY){
unit='h';
}else if(minutes<MINUTES_IN_MONTH){
unit='d';
}else if(minutes<MINUTES_IN_YEAR){
unit='M';
}else {
unit='Y';
}
}

// 0 up to 60 seconds
if(unit==='s'){
return localize('xSeconds',seconds,localizeOptions);

// 1 up to 60 mins
}else if(unit==='m'){
return localize('xMinutes',minutes,localizeOptions);

// 1 up to 24 hours
}else if(unit==='h'){
hours=mathPartial(minutes/60);
return localize('xHours',hours,localizeOptions);

// 1 up to 30 days
}else if(unit==='d'){
days=mathPartial(minutes/MINUTES_IN_DAY);
return localize('xDays',days,localizeOptions);

// 1 up to 12 months
}else if(unit==='M'){
months=mathPartial(minutes/MINUTES_IN_MONTH);
return localize('xMonths',months,localizeOptions);

// 1 year up to max Date
}else if(unit==='Y'){
years=mathPartial(minutes/MINUTES_IN_YEAR);
return localize('xYears',years,localizeOptions);
}

throw new Error('Unknown unit: '+unit);
}

module.exports=distanceInWordsStrict;


/***/},

/***/"be13":
/***/function be13(module,exports){

// 7.2.1 RequireObjectCoercible(argument)
module.exports=function(it){
if(it==undefined)throw TypeError("Can't call method on  "+it);
return it;
};


/***/},

/***/"bf0b":
/***/function bf0b(module,exports,__webpack_require__){

var pIE=__webpack_require__("355d");
var createDesc=__webpack_require__("aebd");
var toIObject=__webpack_require__("36c3");
var toPrimitive=__webpack_require__("1bc3");
var has=__webpack_require__("07e3");
var IE8_DOM_DEFINE=__webpack_require__("794b");
var gOPD=Object.getOwnPropertyDescriptor;

exports.f=__webpack_require__("8e60")?gOPD:function getOwnPropertyDescriptor(O,P){
O=toIObject(O);
P=toPrimitive(P,true);
if(IE8_DOM_DEFINE)try{
return gOPD(O,P);
}catch(e){/* empty */}
if(has(O,P))return createDesc(!pIE.f.call(O,P),O[P]);
};


/***/},

/***/"c207":
/***/function c207(module,exports){



/***/},

/***/"c2b5":
/***/function c2b5(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Get the day of the week of the given date.
 *
 * @description
 * Get the day of the week of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the day of week
 *
 * @example
 * // Which day of the week is 29 February 2012?
 * var result = getDay(new Date(2012, 1, 29))
 * //=> 3
 */
function getDay(dirtyDate){
var date=parse(dirtyDate);
var day=date.getDay();
return day;
}

module.exports=getDay;


/***/},

/***/"c366":
/***/function c366(module,exports,__webpack_require__){

// false -> Array#indexOf
// true  -> Array#includes
var toIObject=__webpack_require__("6821");
var toLength=__webpack_require__("9def");
var toAbsoluteIndex=__webpack_require__("77f1");
module.exports=function(IS_INCLUDES){
return function($this,el,fromIndex){
var O=toIObject($this);
var length=toLength(O.length);
var index=toAbsoluteIndex(fromIndex,length);
var value;
// Array#includes uses SameValueZero equality algorithm
// eslint-disable-next-line no-self-compare
if(IS_INCLUDES&&el!=el)while(length>index){
value=O[index++];
// eslint-disable-next-line no-self-compare
if(value!=value)return true;
// Array#indexOf ignores holes, Array#includes - not
}else for(;length>index;index++){if(IS_INCLUDES||index in O){
if(O[index]===el)return IS_INCLUDES||index||0;
}}return !IS_INCLUDES&&-1;
};
};


/***/},

/***/"c367":
/***/function c367(module,exports,__webpack_require__){

var addToUnscopables=__webpack_require__("8436");
var step=__webpack_require__("50ed");
var Iterators=__webpack_require__("481b");
var toIObject=__webpack_require__("36c3");

// 22.1.3.4 Array.prototype.entries()
// 22.1.3.13 Array.prototype.keys()
// 22.1.3.29 Array.prototype.values()
// 22.1.3.30 Array.prototype[@@iterator]()
module.exports=__webpack_require__("30f1")(Array,'Array',function(iterated,kind){
this._t=toIObject(iterated);// target
this._i=0;// next index
this._k=kind;// kind
// 22.1.5.2.1 %ArrayIteratorPrototype%.next()
},function(){
var O=this._t;
var kind=this._k;
var index=this._i++;
if(!O||index>=O.length){
this._t=undefined;
return step(1);
}
if(kind=='keys')return step(0,index);
if(kind=='values')return step(0,O[index]);
return step(0,[index,O[index]]);
},'values');

// argumentsList[@@iterator] is %ArrayProto_values% (9.4.4.6, 9.4.4.7)
Iterators.Arguments=Iterators.Array;

addToUnscopables('keys');
addToUnscopables('values');
addToUnscopables('entries');


/***/},

/***/"c3a1":
/***/function c3a1(module,exports,__webpack_require__){

// 19.1.2.14 / 15.2.3.14 Object.keys(O)
var $keys=__webpack_require__("e6f3");
var enumBugKeys=__webpack_require__("1691");

module.exports=Object.keys||function keys(O){
return $keys(O,enumBugKeys);
};


/***/},

/***/"c4c2":
/***/function c4c2(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Day Helpers
 * @summary Return the array of dates within the specified range.
 *
 * @description
 * Return the array of dates within the specified range.
 *
 * @param {Date|String|Number} startDate - the first date
 * @param {Date|String|Number} endDate - the last date
 * @param {Number} [step=1] - the step between each day
 * @returns {Date[]} the array with starts of days from the day of startDate to the day of endDate
 * @throws {Error} startDate cannot be after endDate
 *
 * @example
 * // Each day between 6 October 2014 and 10 October 2014:
 * var result = eachDay(
 *   new Date(2014, 9, 6),
 *   new Date(2014, 9, 10)
 * )
 * //=> [
 * //   Mon Oct 06 2014 00:00:00,
 * //   Tue Oct 07 2014 00:00:00,
 * //   Wed Oct 08 2014 00:00:00,
 * //   Thu Oct 09 2014 00:00:00,
 * //   Fri Oct 10 2014 00:00:00
 * // ]
 */
function eachDay(dirtyStartDate,dirtyEndDate,dirtyStep){
var startDate=parse(dirtyStartDate);
var endDate=parse(dirtyEndDate);
var step=dirtyStep!==undefined?dirtyStep:1;

var endTime=endDate.getTime();

if(startDate.getTime()>endTime){
throw new Error('The first date cannot be after the second date');
}

var dates=[];

var currentDate=startDate;
currentDate.setHours(0,0,0,0);

while(currentDate.getTime()<=endTime){
dates.push(parse(currentDate));
currentDate.setDate(currentDate.getDate()+step);
}

return dates;
}

module.exports=eachDay;


/***/},

/***/"c4f9":
/***/function c4f9(module,exports,__webpack_require__){

var startOfDay=__webpack_require__("0978");

/**
 * @category Day Helpers
 * @summary Is the given date yesterday?
 *
 * @description
 * Is the given date yesterday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is yesterday
 *
 * @example
 * // If today is 6 October 2014, is 5 October 14:00:00 yesterday?
 * var result = isYesterday(new Date(2014, 9, 5, 14, 0))
 * //=> true
 */
function isYesterday(dirtyDate){
var yesterday=new Date();
yesterday.setDate(yesterday.getDate()-1);
return startOfDay(dirtyDate).getTime()===startOfDay(yesterday).getTime();
}

module.exports=isYesterday;


/***/},

/***/"c589":
/***/function c589(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Minute Helpers
 * @summary Get the minutes of the given date.
 *
 * @description
 * Get the minutes of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the minutes
 *
 * @example
 * // Get the minutes of 29 February 2012 11:45:05:
 * var result = getMinutes(new Date(2012, 1, 29, 11, 45, 5))
 * //=> 45
 */
function getMinutes(dirtyDate){
var date=parse(dirtyDate);
var minutes=date.getMinutes();
return minutes;
}

module.exports=getMinutes;


/***/},

/***/"c5f6":
/***/function c5f6(module,exports,__webpack_require__){

var global=__webpack_require__("7726");
var has=__webpack_require__("69a8");
var cof=__webpack_require__("2d95");
var inheritIfRequired=__webpack_require__("5dbc");
var toPrimitive=__webpack_require__("6a99");
var fails=__webpack_require__("79e5");
var gOPN=__webpack_require__("9093").f;
var gOPD=__webpack_require__("11e9").f;
var dP=__webpack_require__("86cc").f;
var $trim=__webpack_require__("aa77").trim;
var NUMBER='Number';
var $Number=global[NUMBER];
var Base=$Number;
var proto=$Number.prototype;
// Opera ~12 has broken Object#toString
var BROKEN_COF=cof(__webpack_require__("2aeb")(proto))==NUMBER;
var TRIM=('trim'in String.prototype);

// 7.1.3 ToNumber(argument)
var toNumber=function toNumber(argument){
var it=toPrimitive(argument,false);
if(typeof it=='string'&&it.length>2){
it=TRIM?it.trim():$trim(it,3);
var first=it.charCodeAt(0);
var third,radix,maxCode;
if(first===43||first===45){
third=it.charCodeAt(2);
if(third===88||third===120)return NaN;// Number('+0x1') should be NaN, old V8 fix
}else if(first===48){
switch(it.charCodeAt(1)){
case 66:case 98:radix=2;maxCode=49;break;// fast equal /^0b[01]+$/i
case 79:case 111:radix=8;maxCode=55;break;// fast equal /^0o[0-7]+$/i
default:return +it;}

for(var digits=it.slice(2),i=0,l=digits.length,code;i<l;i++){
code=digits.charCodeAt(i);
// parseInt parses a string to a first unavailable symbol
// but ToNumber should return NaN if a string contains unavailable symbols
if(code<48||code>maxCode)return NaN;
}return parseInt(digits,radix);
}
}return +it;
};

if(!$Number(' 0o1')||!$Number('0b1')||$Number('+0x1')){
$Number=function Number(value){
var it=arguments.length<1?0:value;
var that=this;
return that instanceof $Number
// check on 1..constructor(foo) case
&&(BROKEN_COF?fails(function(){proto.valueOf.call(that);}):cof(that)!=NUMBER)?
inheritIfRequired(new Base(toNumber(it)),that,$Number):toNumber(it);
};
for(var keys=__webpack_require__("9e1e")?gOPN(Base):(
// ES3:
'MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,'+
// ES6 (in case, if modules with ES6 Number statics required before):
'EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,'+
'MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger').
split(','),j=0,key;keys.length>j;j++){
if(has(Base,key=keys[j])&&!has($Number,key)){
dP($Number,key,gOPD(Base,key));
}
}
$Number.prototype=proto;
proto.constructor=$Number;
__webpack_require__("2aba")(global,NUMBER,$Number);
}


/***/},

/***/"c69a":
/***/function c69a(module,exports,__webpack_require__){

module.exports=!__webpack_require__("9e1e")&&!__webpack_require__("79e5")(function(){
return Object.defineProperty(__webpack_require__("230e")('div'),'a',{get:function get(){return 7;}}).a!=7;
});


/***/},

/***/"c6ae":
/***/function c6ae(module,exports,__webpack_require__){

var startOfSecond=__webpack_require__("2299");

/**
 * @category Second Helpers
 * @summary Are the given dates in the same second?
 *
 * @description
 * Are the given dates in the same second?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same second
 *
 * @example
 * // Are 4 September 2014 06:30:15.000 and 4 September 2014 06:30.15.500
 * // in the same second?
 * var result = isSameSecond(
 *   new Date(2014, 8, 4, 6, 30, 15),
 *   new Date(2014, 8, 4, 6, 30, 15, 500)
 * )
 * //=> true
 */
function isSameSecond(dirtyDateLeft,dirtyDateRight){
var dateLeftStartOfSecond=startOfSecond(dirtyDateLeft);
var dateRightStartOfSecond=startOfSecond(dirtyDateRight);

return dateLeftStartOfSecond.getTime()===dateRightStartOfSecond.getTime();
}

module.exports=isSameSecond;


/***/},

/***/"c7ce":
/***/function c7ce(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Week Helpers
 * @summary Return the start of a week for the given date.
 *
 * @description
 * Return the start of a week for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @param {Object} [options] - the object with options
 * @param {Number} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @returns {Date} the start of a week
 *
 * @example
 * // The start of a week for 2 September 2014 11:55:00:
 * var result = startOfWeek(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Sun Aug 31 2014 00:00:00
 *
 * @example
 * // If the week starts on Monday, the start of the week for 2 September 2014 11:55:00:
 * var result = startOfWeek(new Date(2014, 8, 2, 11, 55, 0), {weekStartsOn: 1})
 * //=> Mon Sep 01 2014 00:00:00
 */
function startOfWeek(dirtyDate,dirtyOptions){
var weekStartsOn=dirtyOptions?Number(dirtyOptions.weekStartsOn)||0:0;

var date=parse(dirtyDate);
var day=date.getDay();
var diff=(day<weekStartsOn?7:0)+day-weekStartsOn;

date.setDate(date.getDate()-diff);
date.setHours(0,0,0,0);
return date;
}

module.exports=startOfWeek;


/***/},

/***/"c873":
/***/function c873(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Common Helpers
 * @summary Compare the two dates reverse chronologically and return -1, 0 or 1.
 *
 * @description
 * Compare the two dates and return -1 if the first date is after the second,
 * 1 if the first date is before the second or 0 if dates are equal.
 *
 * @param {Date|String|Number} dateLeft - the first date to compare
 * @param {Date|String|Number} dateRight - the second date to compare
 * @returns {Number} the result of the comparison
 *
 * @example
 * // Compare 11 February 1987 and 10 July 1989 reverse chronologically:
 * var result = compareDesc(
 *   new Date(1987, 1, 11),
 *   new Date(1989, 6, 10)
 * )
 * //=> 1
 *
 * @example
 * // Sort the array of dates in reverse chronological order:
 * var result = [
 *   new Date(1995, 6, 2),
 *   new Date(1987, 1, 11),
 *   new Date(1989, 6, 10)
 * ].sort(compareDesc)
 * //=> [
 * //   Sun Jul 02 1995 00:00:00,
 * //   Mon Jul 10 1989 00:00:00,
 * //   Wed Feb 11 1987 00:00:00
 * // ]
 */
function compareDesc(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var timeLeft=dateLeft.getTime();
var dateRight=parse(dirtyDateRight);
var timeRight=dateRight.getTime();

if(timeLeft>timeRight){
return -1;
}else if(timeLeft<timeRight){
return 1;
}else {
return 0;
}
}

module.exports=compareDesc;


/***/},

/***/"c8bb":
/***/function c8bb(module,exports,__webpack_require__){

module.exports=__webpack_require__("54a1");

/***/},

/***/"c8d5":
/***/function c8d5(module,exports,__webpack_require__){

var getTimezoneOffsetInMilliseconds=__webpack_require__("5465");
var isDate=__webpack_require__("a735");

var MILLISECONDS_IN_HOUR=3600000;
var MILLISECONDS_IN_MINUTE=60000;
var DEFAULT_ADDITIONAL_DIGITS=2;

var parseTokenDateTimeDelimeter=/[T ]/;
var parseTokenPlainTime=/:/;

// year tokens
var parseTokenYY=/^(\d{2})$/;
var parseTokensYYY=[
/^([+-]\d{2})$/,// 0 additional digits
/^([+-]\d{3})$/,// 1 additional digit
/^([+-]\d{4})$/ // 2 additional digits
];

var parseTokenYYYY=/^(\d{4})/;
var parseTokensYYYYY=[
/^([+-]\d{4})/,// 0 additional digits
/^([+-]\d{5})/,// 1 additional digit
/^([+-]\d{6})/ // 2 additional digits
];

// date tokens
var parseTokenMM=/^-(\d{2})$/;
var parseTokenDDD=/^-?(\d{3})$/;
var parseTokenMMDD=/^-?(\d{2})-?(\d{2})$/;
var parseTokenWww=/^-?W(\d{2})$/;
var parseTokenWwwD=/^-?W(\d{2})-?(\d{1})$/;

// time tokens
var parseTokenHH=/^(\d{2}([.,]\d*)?)$/;
var parseTokenHHMM=/^(\d{2}):?(\d{2}([.,]\d*)?)$/;
var parseTokenHHMMSS=/^(\d{2}):?(\d{2}):?(\d{2}([.,]\d*)?)$/;

// timezone tokens
var parseTokenTimezone=/([Z+-].*)$/;
var parseTokenTimezoneZ=/^(Z)$/;
var parseTokenTimezoneHH=/^([+-])(\d{2})$/;
var parseTokenTimezoneHHMM=/^([+-])(\d{2}):?(\d{2})$/;

/**
 * @category Common Helpers
 * @summary Convert the given argument to an instance of Date.
 *
 * @description
 * Convert the given argument to an instance of Date.
 *
 * If the argument is an instance of Date, the function returns its clone.
 *
 * If the argument is a number, it is treated as a timestamp.
 *
 * If an argument is a string, the function tries to parse it.
 * Function accepts complete ISO 8601 formats as well as partial implementations.
 * ISO 8601: http://en.wikipedia.org/wiki/ISO_8601
 *
 * If all above fails, the function passes the given argument to Date constructor.
 *
 * @param {Date|String|Number} argument - the value to convert
 * @param {Object} [options] - the object with options
 * @param {0 | 1 | 2} [options.additionalDigits=2] - the additional number of digits in the extended year format
 * @returns {Date} the parsed date in the local time zone
 *
 * @example
 * // Convert string '2014-02-11T11:30:30' to date:
 * var result = parse('2014-02-11T11:30:30')
 * //=> Tue Feb 11 2014 11:30:30
 *
 * @example
 * // Parse string '+02014101',
 * // if the additional number of digits in the extended year format is 1:
 * var result = parse('+02014101', {additionalDigits: 1})
 * //=> Fri Apr 11 2014 00:00:00
 */
function parse(argument,dirtyOptions){
if(isDate(argument)){
// Prevent the date to lose the milliseconds when passed to new Date() in IE10
return new Date(argument.getTime());
}else if(typeof argument!=='string'){
return new Date(argument);
}

var options=dirtyOptions||{};
var additionalDigits=options.additionalDigits;
if(additionalDigits==null){
additionalDigits=DEFAULT_ADDITIONAL_DIGITS;
}else {
additionalDigits=Number(additionalDigits);
}

var dateStrings=splitDateString(argument);

var parseYearResult=parseYear(dateStrings.date,additionalDigits);
var year=parseYearResult.year;
var restDateString=parseYearResult.restDateString;

var date=parseDate(restDateString,year);

if(date){
var timestamp=date.getTime();
var time=0;
var offset;

if(dateStrings.time){
time=parseTime(dateStrings.time);
}

if(dateStrings.timezone){
offset=parseTimezone(dateStrings.timezone)*MILLISECONDS_IN_MINUTE;
}else {
var fullTime=timestamp+time;
var fullTimeDate=new Date(fullTime);

offset=getTimezoneOffsetInMilliseconds(fullTimeDate);

// Adjust time when it's coming from DST
var fullTimeDateNextDay=new Date(fullTime);
fullTimeDateNextDay.setDate(fullTimeDate.getDate()+1);
var offsetDiff=
getTimezoneOffsetInMilliseconds(fullTimeDateNextDay)-
getTimezoneOffsetInMilliseconds(fullTimeDate);
if(offsetDiff>0){
offset+=offsetDiff;
}
}

return new Date(timestamp+time+offset);
}else {
return new Date(argument);
}
}

function splitDateString(dateString){
var dateStrings={};
var array=dateString.split(parseTokenDateTimeDelimeter);
var timeString;

if(parseTokenPlainTime.test(array[0])){
dateStrings.date=null;
timeString=array[0];
}else {
dateStrings.date=array[0];
timeString=array[1];
}

if(timeString){
var token=parseTokenTimezone.exec(timeString);
if(token){
dateStrings.time=timeString.replace(token[1],'');
dateStrings.timezone=token[1];
}else {
dateStrings.time=timeString;
}
}

return dateStrings;
}

function parseYear(dateString,additionalDigits){
var parseTokenYYY=parseTokensYYY[additionalDigits];
var parseTokenYYYYY=parseTokensYYYYY[additionalDigits];

var token;

// YYYY or ±YYYYY
token=parseTokenYYYY.exec(dateString)||parseTokenYYYYY.exec(dateString);
if(token){
var yearString=token[1];
return {
year:parseInt(yearString,10),
restDateString:dateString.slice(yearString.length)};

}

// YY or ±YYY
token=parseTokenYY.exec(dateString)||parseTokenYYY.exec(dateString);
if(token){
var centuryString=token[1];
return {
year:parseInt(centuryString,10)*100,
restDateString:dateString.slice(centuryString.length)};

}

// Invalid ISO-formatted year
return {
year:null};

}

function parseDate(dateString,year){
// Invalid ISO-formatted year
if(year===null){
return null;
}

var token;
var date;
var month;
var week;

// YYYY
if(dateString.length===0){
date=new Date(0);
date.setUTCFullYear(year);
return date;
}

// YYYY-MM
token=parseTokenMM.exec(dateString);
if(token){
date=new Date(0);
month=parseInt(token[1],10)-1;
date.setUTCFullYear(year,month);
return date;
}

// YYYY-DDD or YYYYDDD
token=parseTokenDDD.exec(dateString);
if(token){
date=new Date(0);
var dayOfYear=parseInt(token[1],10);
date.setUTCFullYear(year,0,dayOfYear);
return date;
}

// YYYY-MM-DD or YYYYMMDD
token=parseTokenMMDD.exec(dateString);
if(token){
date=new Date(0);
month=parseInt(token[1],10)-1;
var day=parseInt(token[2],10);
date.setUTCFullYear(year,month,day);
return date;
}

// YYYY-Www or YYYYWww
token=parseTokenWww.exec(dateString);
if(token){
week=parseInt(token[1],10)-1;
return dayOfISOYear(year,week);
}

// YYYY-Www-D or YYYYWwwD
token=parseTokenWwwD.exec(dateString);
if(token){
week=parseInt(token[1],10)-1;
var dayOfWeek=parseInt(token[2],10)-1;
return dayOfISOYear(year,week,dayOfWeek);
}

// Invalid ISO-formatted date
return null;
}

function parseTime(timeString){
var token;
var hours;
var minutes;

// hh
token=parseTokenHH.exec(timeString);
if(token){
hours=parseFloat(token[1].replace(',','.'));
return hours%24*MILLISECONDS_IN_HOUR;
}

// hh:mm or hhmm
token=parseTokenHHMM.exec(timeString);
if(token){
hours=parseInt(token[1],10);
minutes=parseFloat(token[2].replace(',','.'));
return hours%24*MILLISECONDS_IN_HOUR+
minutes*MILLISECONDS_IN_MINUTE;
}

// hh:mm:ss or hhmmss
token=parseTokenHHMMSS.exec(timeString);
if(token){
hours=parseInt(token[1],10);
minutes=parseInt(token[2],10);
var seconds=parseFloat(token[3].replace(',','.'));
return hours%24*MILLISECONDS_IN_HOUR+
minutes*MILLISECONDS_IN_MINUTE+
seconds*1000;
}

// Invalid ISO-formatted time
return null;
}

function parseTimezone(timezoneString){
var token;
var absoluteOffset;

// Z
token=parseTokenTimezoneZ.exec(timezoneString);
if(token){
return 0;
}

// ±hh
token=parseTokenTimezoneHH.exec(timezoneString);
if(token){
absoluteOffset=parseInt(token[2],10)*60;
return token[1]==='+'?-absoluteOffset:absoluteOffset;
}

// ±hh:mm or ±hhmm
token=parseTokenTimezoneHHMM.exec(timezoneString);
if(token){
absoluteOffset=parseInt(token[2],10)*60+parseInt(token[3],10);
return token[1]==='+'?-absoluteOffset:absoluteOffset;
}

return 0;
}

function dayOfISOYear(isoYear,week,day){
week=week||0;
day=day||0;
var date=new Date(0);
date.setUTCFullYear(isoYear,0,4);
var fourthOfJanuaryDay=date.getUTCDay()||7;
var diff=week*7+day+1-fourthOfJanuaryDay;
date.setUTCDate(date.getUTCDate()+diff);
return date;
}

module.exports=parse;


/***/},

/***/"c980":
/***/function c980(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Weekday Helpers
 * @summary Is the given date Wednesday?
 *
 * @description
 * Is the given date Wednesday?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is Wednesday
 *
 * @example
 * // Is 24 September 2014 Wednesday?
 * var result = isWednesday(new Date(2014, 8, 24))
 * //=> true
 */
function isWednesday(dirtyDate){
return parse(dirtyDate).getDay()===3;
}

module.exports=isWednesday;


/***/},

/***/"ca5a":
/***/function ca5a(module,exports){

var id=0;
var px=Math.random();
module.exports=function(key){
return 'Symbol('.concat(key===undefined?'':key,')_',(++id+px).toString(36));
};


/***/},

/***/"cadf":
/***/function cadf(module,exports,__webpack_require__){

var addToUnscopables=__webpack_require__("9c6c");
var step=__webpack_require__("d53b");
var Iterators=__webpack_require__("84f2");
var toIObject=__webpack_require__("6821");

// 22.1.3.4 Array.prototype.entries()
// 22.1.3.13 Array.prototype.keys()
// 22.1.3.29 Array.prototype.values()
// 22.1.3.30 Array.prototype[@@iterator]()
module.exports=__webpack_require__("01f9")(Array,'Array',function(iterated,kind){
this._t=toIObject(iterated);// target
this._i=0;// next index
this._k=kind;// kind
// 22.1.5.2.1 %ArrayIteratorPrototype%.next()
},function(){
var O=this._t;
var kind=this._k;
var index=this._i++;
if(!O||index>=O.length){
this._t=undefined;
return step(1);
}
if(kind=='keys')return step(0,index);
if(kind=='values')return step(0,O[index]);
return step(0,[index,O[index]]);
},'values');

// argumentsList[@@iterator] is %ArrayProto_values% (9.4.4.6, 9.4.4.7)
Iterators.Arguments=Iterators.Array;

addToUnscopables('keys');
addToUnscopables('values');
addToUnscopables('entries');


/***/},

/***/"cb7c":
/***/function cb7c(module,exports,__webpack_require__){

var isObject=__webpack_require__("d3f4");
module.exports=function(it){
if(!isObject(it))throw TypeError(it+' is not an object!');
return it;
};


/***/},

/***/"cb96":
/***/function cb96(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Week Helpers
 * @summary Return the last day of a week for the given date.
 *
 * @description
 * Return the last day of a week for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @param {Object} [options] - the object with options
 * @param {Number} [options.weekStartsOn=0] - the index of the first day of the week (0 - Sunday)
 * @returns {Date} the last day of a week
 *
 * @example
 * // The last day of a week for 2 September 2014 11:55:00:
 * var result = lastDayOfWeek(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Sat Sep 06 2014 00:00:00
 *
 * @example
 * // If the week starts on Monday, the last day of the week for 2 September 2014 11:55:00:
 * var result = lastDayOfWeek(new Date(2014, 8, 2, 11, 55, 0), {weekStartsOn: 1})
 * //=> Sun Sep 07 2014 00:00:00
 */
function lastDayOfWeek(dirtyDate,dirtyOptions){
var weekStartsOn=dirtyOptions?Number(dirtyOptions.weekStartsOn)||0:0;

var date=parse(dirtyDate);
var day=date.getDay();
var diff=(day<weekStartsOn?-7:0)+6-(day-weekStartsOn);

date.setHours(0,0,0,0);
date.setDate(date.getDate()+diff);
return date;
}

module.exports=lastDayOfWeek;


/***/},

/***/"cc64":
/***/function cc64(module,exports,__webpack_require__){

var isSameISOWeek=__webpack_require__("ccce");

/**
 * @category ISO Week Helpers
 * @summary Is the given date in the same ISO week as the current date?
 *
 * @description
 * Is the given date in the same ISO week as the current date?
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this ISO week
 *
 * @example
 * // If today is 25 September 2014, is 22 September 2014 in this ISO week?
 * var result = isThisISOWeek(new Date(2014, 8, 22))
 * //=> true
 */
function isThisISOWeek(dirtyDate){
return isSameISOWeek(new Date(),dirtyDate);
}

module.exports=isThisISOWeek;


/***/},

/***/"ccb9":
/***/function ccb9(module,exports,__webpack_require__){

exports.f=__webpack_require__("5168");


/***/},

/***/"ccce":
/***/function ccce(module,exports,__webpack_require__){

var isSameWeek=__webpack_require__("1baf");

/**
 * @category ISO Week Helpers
 * @summary Are the given dates in the same ISO week?
 *
 * @description
 * Are the given dates in the same ISO week?
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same ISO week
 *
 * @example
 * // Are 1 September 2014 and 7 September 2014 in the same ISO week?
 * var result = isSameISOWeek(
 *   new Date(2014, 8, 1),
 *   new Date(2014, 8, 7)
 * )
 * //=> true
 */
function isSameISOWeek(dirtyDateLeft,dirtyDateRight){
return isSameWeek(dirtyDateLeft,dirtyDateRight,{weekStartsOn:1});
}

module.exports=isSameISOWeek;


/***/},

/***/"ce10":
/***/function ce10(module,exports,__webpack_require__){

var has=__webpack_require__("69a8");
var toIObject=__webpack_require__("6821");
var arrayIndexOf=__webpack_require__("c366")(false);
var IE_PROTO=__webpack_require__("613b")('IE_PROTO');

module.exports=function(object,names){
var O=toIObject(object);
var i=0;
var result=[];
var key;
for(key in O){if(key!=IE_PROTO)has(O,key)&&result.push(key);}
// Don't enum bug & hidden keys
while(names.length>i){if(has(O,key=names[i++])){
~arrayIndexOf(result,key)||result.push(key);
}}
return result;
};


/***/},

/***/"ce3d":
/***/function ce3d(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Quarter Helpers
 * @summary Return the last day of a year quarter for the given date.
 *
 * @description
 * Return the last day of a year quarter for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the last day of a quarter
 *
 * @example
 * // The last day of a quarter for 2 September 2014 11:55:00:
 * var result = lastDayOfQuarter(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 30 2014 00:00:00
 */
function lastDayOfQuarter(dirtyDate){
var date=parse(dirtyDate);
var currentMonth=date.getMonth();
var month=currentMonth-currentMonth%3+3;
date.setMonth(month,0);
date.setHours(0,0,0,0);
return date;
}

module.exports=lastDayOfQuarter;


/***/},

/***/"ce7e":
/***/function ce7e(module,exports,__webpack_require__){

// most Object methods by ES6 should accept primitives
var $export=__webpack_require__("63b6");
var core=__webpack_require__("584a");
var fails=__webpack_require__("294c");
module.exports=function(KEY,exec){
var fn=(core.Object||{})[KEY]||Object[KEY];
var exp={};
exp[KEY]=exec(fn);
$export($export.S+$export.F*fails(function(){fn(1);}),'Object',exp);
};


/***/},

/***/"d2ed":
/***/function d2ed(module,exports,__webpack_require__){

var differenceInMilliseconds=__webpack_require__("e785");

var MILLISECONDS_IN_HOUR=3600000;

/**
 * @category Hour Helpers
 * @summary Get the number of hours between the given dates.
 *
 * @description
 * Get the number of hours between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of hours
 *
 * @example
 * // How many hours are between 2 July 2014 06:50:00 and 2 July 2014 19:00:00?
 * var result = differenceInHours(
 *   new Date(2014, 6, 2, 19, 0),
 *   new Date(2014, 6, 2, 6, 50)
 * )
 * //=> 12
 */
function differenceInHours(dirtyDateLeft,dirtyDateRight){
var diff=differenceInMilliseconds(dirtyDateLeft,dirtyDateRight)/MILLISECONDS_IN_HOUR;
return diff>0?Math.floor(diff):Math.ceil(diff);
}

module.exports=differenceInHours;


/***/},

/***/"d3f4":
/***/function d3f4(module,exports){

module.exports=function(it){
return typeof it==='object'?it!==null:typeof it==='function';
};


/***/},

/***/"d420":
/***/function d420(module,exports,__webpack_require__){

var startOfDay=__webpack_require__("0978");

var MILLISECONDS_IN_MINUTE=60000;
var MILLISECONDS_IN_DAY=86400000;

/**
 * @category Day Helpers
 * @summary Get the number of calendar days between the given dates.
 *
 * @description
 * Get the number of calendar days between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of calendar days
 *
 * @example
 * // How many calendar days are between
 * // 2 July 2011 23:00:00 and 2 July 2012 00:00:00?
 * var result = differenceInCalendarDays(
 *   new Date(2012, 6, 2, 0, 0),
 *   new Date(2011, 6, 2, 23, 0)
 * )
 * //=> 366
 */
function differenceInCalendarDays(dirtyDateLeft,dirtyDateRight){
var startOfDayLeft=startOfDay(dirtyDateLeft);
var startOfDayRight=startOfDay(dirtyDateRight);

var timestampLeft=startOfDayLeft.getTime()-
startOfDayLeft.getTimezoneOffset()*MILLISECONDS_IN_MINUTE;
var timestampRight=startOfDayRight.getTime()-
startOfDayRight.getTimezoneOffset()*MILLISECONDS_IN_MINUTE;

// Round the number of days to the nearest integer
// because the number of milliseconds in a day is not constant
// (e.g. it's different in the day of the daylight saving time clock shift)
return Math.round((timestampLeft-timestampRight)/MILLISECONDS_IN_DAY);
}

module.exports=differenceInCalendarDays;


/***/},

/***/"d473":
/***/function d473(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Millisecond Helpers
 * @summary Set the milliseconds to the given date.
 *
 * @description
 * Set the milliseconds to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} milliseconds - the milliseconds of the new date
 * @returns {Date} the new date with the milliseconds setted
 *
 * @example
 * // Set 300 milliseconds to 1 September 2014 11:30:40.500:
 * var result = setMilliseconds(new Date(2014, 8, 1, 11, 30, 40, 500), 300)
 * //=> Mon Sep 01 2014 11:30:40.300
 */
function setMilliseconds(dirtyDate,dirtyMilliseconds){
var date=parse(dirtyDate);
var milliseconds=Number(dirtyMilliseconds);
date.setMilliseconds(milliseconds);
return date;
}

module.exports=setMilliseconds;


/***/},

/***/"d4ae":
/***/function d4ae(module,exports,__webpack_require__){

var addQuarters=__webpack_require__("f5dd");

/**
 * @category Quarter Helpers
 * @summary Subtract the specified number of year quarters from the given date.
 *
 * @description
 * Subtract the specified number of year quarters from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of quarters to be subtracted
 * @returns {Date} the new date with the quarters subtracted
 *
 * @example
 * // Subtract 3 quarters from 1 September 2014:
 * var result = subQuarters(new Date(2014, 8, 1), 3)
 * //=> Sun Dec 01 2013 00:00:00
 */
function subQuarters(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addQuarters(dirtyDate,-amount);
}

module.exports=subQuarters;


/***/},

/***/"d4c0":
/***/function d4c0(module,exports,__webpack_require__){

// all enumerable object keys, includes symbols
var getKeys=__webpack_require__("0d58");
var gOPS=__webpack_require__("2621");
var pIE=__webpack_require__("52a7");
module.exports=function(it){
var result=getKeys(it);
var getSymbols=gOPS.f;
if(getSymbols){
var symbols=getSymbols(it);
var isEnum=pIE.f;
var i=0;
var key;
while(symbols.length>i){if(isEnum.call(it,key=symbols[i++]))result.push(key);}
}return result;
};


/***/},

/***/"d53b":
/***/function d53b(module,exports){

module.exports=function(done,value){
return {value:value,done:!!done};
};


/***/},

/***/"d6f8":
/***/function d6f8(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Return the end of a month for the given date.
 *
 * @description
 * Return the end of a month for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of a month
 *
 * @example
 * // The end of a month for 2 September 2014 11:55:00:
 * var result = endOfMonth(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 30 2014 23:59:59.999
 */
function endOfMonth(dirtyDate){
var date=parse(dirtyDate);
var month=date.getMonth();
date.setFullYear(date.getFullYear(),month+1,0);
date.setHours(23,59,59,999);
return date;
}

module.exports=endOfMonth;


/***/},

/***/"d864":
/***/function d864(module,exports,__webpack_require__){

// optional / simple context binding
var aFunction=__webpack_require__("79aa");
module.exports=function(fn,that,length){
aFunction(fn);
if(that===undefined)return fn;
switch(length){
case 1:return function(a){
return fn.call(that,a);
};
case 2:return function(a,b){
return fn.call(that,a,b);
};
case 3:return function(a,b,c){
return fn.call(that,a,b,c);
};}

return function()/* ...args */{
return fn.apply(that,arguments);
};
};


/***/},

/***/"d8d6":
/***/function d8d6(module,exports,__webpack_require__){

__webpack_require__("1654");
__webpack_require__("6c1c");
module.exports=__webpack_require__("ccb9").f('iterator');


/***/},

/***/"d8e8":
/***/function d8e8(module,exports){

module.exports=function(it){
if(typeof it!='function')throw TypeError(it+' is not a function!');
return it;
};


/***/},

/***/"d975":
/***/function d975(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Year Helpers
 * @summary Return the end of a year for the given date.
 *
 * @description
 * Return the end of a year for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of a year
 *
 * @example
 * // The end of a year for 2 September 2014 11:55:00:
 * var result = endOfYear(new Date(2014, 8, 2, 11, 55, 00))
 * //=> Wed Dec 31 2014 23:59:59.999
 */
function endOfYear(dirtyDate){
var date=parse(dirtyDate);
var year=date.getFullYear();
date.setFullYear(year+1,0,0);
date.setHours(23,59,59,999);
return date;
}

module.exports=endOfYear;


/***/},

/***/"d9f6":
/***/function d9f6(module,exports,__webpack_require__){

var anObject=__webpack_require__("e4ae");
var IE8_DOM_DEFINE=__webpack_require__("794b");
var toPrimitive=__webpack_require__("1bc3");
var dP=Object.defineProperty;

exports.f=__webpack_require__("8e60")?Object.defineProperty:function defineProperty(O,P,Attributes){
anObject(O);
P=toPrimitive(P,true);
anObject(Attributes);
if(IE8_DOM_DEFINE)try{
return dP(O,P,Attributes);
}catch(e){/* empty */}
if('get'in Attributes||'set'in Attributes)throw TypeError('Accessors not supported!');
if('value'in Attributes)O[P]=Attributes.value;
return O;
};


/***/},

/***/"dbdb":
/***/function dbdb(module,exports,__webpack_require__){

var core=__webpack_require__("584a");
var global=__webpack_require__("e53d");
var SHARED='__core-js_shared__';
var store=global[SHARED]||(global[SHARED]={});

(module.exports=function(key,value){
return store[key]||(store[key]=value!==undefined?value:{});
})('versions',[]).push({
version:core.version,
mode:__webpack_require__("b8e3")?'pure':'global',
copyright:'© 2019 Denis Pushkarev (zloirock.ru)'});



/***/},

/***/"dc62":
/***/function dc62(module,exports,__webpack_require__){

__webpack_require__("9427");
var $Object=__webpack_require__("584a").Object;
module.exports=function create(P,D){
return $Object.create(P,D);
};


/***/},

/***/"dddf":
/***/function dddf(module,exports,__webpack_require__){

var isLeapYear=__webpack_require__("acc4");

/**
 * @category Year Helpers
 * @summary Get the number of days in a year of the given date.
 *
 * @description
 * Get the number of days in a year of the given date.
 *
 * @param {Date|String|Number} date - the given date
 * @returns {Number} the number of days in a year
 *
 * @example
 * // How many days are in 2012?
 * var result = getDaysInYear(new Date(2012, 0, 1))
 * //=> 366
 */
function getDaysInYear(dirtyDate){
return isLeapYear(dirtyDate)?366:365;
}

module.exports=getDaysInYear;


/***/},

/***/"de13":
/***/function de13(module,exports,__webpack_require__){

var getISOYear=__webpack_require__("8964");
var startOfISOWeek=__webpack_require__("b4c7");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Return the last day of an ISO week-numbering year for the given date.
 *
 * @description
 * Return the last day of an ISO week-numbering year,
 * which always starts 3 days before the year's first Thursday.
 * The result will be in the local timezone.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the end of an ISO week-numbering year
 *
 * @example
 * // The last day of an ISO week-numbering year for 2 July 2005:
 * var result = lastDayOfISOYear(new Date(2005, 6, 2))
 * //=> Sun Jan 01 2006 00:00:00
 */
function lastDayOfISOYear(dirtyDate){
var year=getISOYear(dirtyDate);
var fourthOfJanuary=new Date(0);
fourthOfJanuary.setFullYear(year+1,0,4);
fourthOfJanuary.setHours(0,0,0,0);
var date=startOfISOWeek(fourthOfJanuary);
date.setDate(date.getDate()-1);
return date;
}

module.exports=lastDayOfISOYear;


/***/},

/***/"df35":
/***/function df35(module,exports,__webpack_require__){

var addISOYears=__webpack_require__("27a1");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Subtract the specified number of ISO week-numbering years from the given date.
 *
 * @description
 * Subtract the specified number of ISO week-numbering years from the given date.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of ISO week-numbering years to be subtracted
 * @returns {Date} the new date with the ISO week-numbering years subtracted
 *
 * @example
 * // Subtract 5 ISO week-numbering years from 1 September 2014:
 * var result = subISOYears(new Date(2014, 8, 1), 5)
 * //=> Mon Aug 31 2009 00:00:00
 */
function subISOYears(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addISOYears(dirtyDate,-amount);
}

module.exports=subISOYears;


/***/},

/***/"e11e":
/***/function e11e(module,exports){

// IE 8- don't enum bug keys
module.exports=
'constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf'.
split(',');


/***/},

/***/"e13a":
/***/function e13a(module,exports,__webpack_require__){

var differenceInMilliseconds=__webpack_require__("e785");

/**
 * @category Second Helpers
 * @summary Get the number of seconds between the given dates.
 *
 * @description
 * Get the number of seconds between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of seconds
 *
 * @example
 * // How many seconds are between
 * // 2 July 2014 12:30:07.999 and 2 July 2014 12:30:20.000?
 * var result = differenceInSeconds(
 *   new Date(2014, 6, 2, 12, 30, 20, 0),
 *   new Date(2014, 6, 2, 12, 30, 7, 999)
 * )
 * //=> 12
 */
function differenceInSeconds(dirtyDateLeft,dirtyDateRight){
var diff=differenceInMilliseconds(dirtyDateLeft,dirtyDateRight)/1000;
return diff>0?Math.floor(diff):Math.ceil(diff);
}

module.exports=differenceInSeconds;


/***/},

/***/"e1ca":
/***/function e1ca(module,exports,__webpack_require__){

var addWeeks=__webpack_require__("7a83");

/**
 * @category Week Helpers
 * @summary Subtract the specified number of weeks from the given date.
 *
 * @description
 * Subtract the specified number of weeks from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of weeks to be subtracted
 * @returns {Date} the new date with the weeks subtracted
 *
 * @example
 * // Subtract 4 weeks from 1 September 2014:
 * var result = subWeeks(new Date(2014, 8, 1), 4)
 * //=> Mon Aug 04 2014 00:00:00
 */
function subWeeks(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addWeeks(dirtyDate,-amount);
}

module.exports=subWeeks;


/***/},

/***/"e2ff":
/***/function e2ff(module,exports,__webpack_require__){

var addDays=__webpack_require__("8946");

/**
 * @category Day Helpers
 * @summary Subtract the specified number of days from the given date.
 *
 * @description
 * Subtract the specified number of days from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of days to be subtracted
 * @returns {Date} the new date with the days subtracted
 *
 * @example
 * // Subtract 10 days from 1 September 2014:
 * var result = subDays(new Date(2014, 8, 1), 10)
 * //=> Fri Aug 22 2014 00:00:00
 */
function subDays(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addDays(dirtyDate,-amount);
}

module.exports=subDays;


/***/},

/***/"e485":
/***/function e485(module,exports){

function buildDistanceInWordsLocale(){
var distanceInWordsLocale={
lessThanXSeconds:{
standalone:{
one:'weniger als eine Sekunde',
other:'weniger als {{count}} Sekunden'},

withPreposition:{
one:'weniger als einer Sekunde',
other:'weniger als {{count}} Sekunden'}},



xSeconds:{
standalone:{
one:'eine Sekunde',
other:'{{count}} Sekunden'},

withPreposition:{
one:'einer Sekunde',
other:'{{count}} Sekunden'}},



halfAMinute:{
standalone:'eine halbe Minute',
withPreposition:'einer halben Minute'},


lessThanXMinutes:{
standalone:{
one:'weniger als eine Minute',
other:'weniger als {{count}} Minuten'},

withPreposition:{
one:'weniger als einer Minute',
other:'weniger als {{count}} Minuten'}},



xMinutes:{
standalone:{
one:'eine Minute',
other:'{{count}} Minuten'},

withPreposition:{
one:'einer Minute',
other:'{{count}} Minuten'}},



aboutXHours:{
standalone:{
one:'etwa eine Stunde',
other:'etwa {{count}} Stunden'},

withPreposition:{
one:'etwa einer Stunde',
other:'etwa {{count}} Stunden'}},



xHours:{
standalone:{
one:'eine Stunde',
other:'{{count}} Stunden'},

withPreposition:{
one:'einer Stunde',
other:'{{count}} Stunden'}},



xDays:{
standalone:{
one:'ein Tag',
other:'{{count}} Tage'},

withPreposition:{
one:'einem Tag',
other:'{{count}} Tagen'}},




aboutXMonths:{
standalone:{
one:'etwa ein Monat',
other:'etwa {{count}} Monate'},

withPreposition:{
one:'etwa einem Monat',
other:'etwa {{count}} Monaten'}},



xMonths:{
standalone:{
one:'ein Monat',
other:'{{count}} Monate'},

withPreposition:{
one:'einem Monat',
other:'{{count}} Monaten'}},



aboutXYears:{
standalone:{
one:'etwa ein Jahr',
other:'etwa {{count}} Jahre'},

withPreposition:{
one:'etwa einem Jahr',
other:'etwa {{count}} Jahren'}},



xYears:{
standalone:{
one:'ein Jahr',
other:'{{count}} Jahre'},

withPreposition:{
one:'einem Jahr',
other:'{{count}} Jahren'}},



overXYears:{
standalone:{
one:'mehr als ein Jahr',
other:'mehr als {{count}} Jahre'},

withPreposition:{
one:'mehr als einem Jahr',
other:'mehr als {{count}} Jahren'}},



almostXYears:{
standalone:{
one:'fast ein Jahr',
other:'fast {{count}} Jahre'},

withPreposition:{
one:'fast einem Jahr',
other:'fast {{count}} Jahren'}}};




function localize(token,count,options){
options=options||{};

var usageGroup=options.addSuffix?
distanceInWordsLocale[token].withPreposition:
distanceInWordsLocale[token].standalone;

var result;
if(typeof usageGroup==='string'){
result=usageGroup;
}else if(count===1){
result=usageGroup.one;
}else {
result=usageGroup.other.replace('{{count}}',count);
}

if(options.addSuffix){
if(options.comparison>0){
return 'in '+result;
}else {
return 'vor '+result;
}
}

return result;
}

return {
localize:localize};

}

module.exports=buildDistanceInWordsLocale;


/***/},

/***/"e4ae":
/***/function e4ae(module,exports,__webpack_require__){

var isObject=__webpack_require__("f772");
module.exports=function(it){
if(!isObject(it))throw TypeError(it+' is not an object!');
return it;
};


/***/},

/***/"e51d":
/***/function e51d(module,exports){

/**
 * @category Day Helpers
 * @summary Return the end of yesterday.
 *
 * @description
 * Return the end of yesterday.
 *
 * @returns {Date} the end of yesterday
 *
 * @example
 * // If today is 6 October 2014:
 * var result = endOfYesterday()
 * //=> Sun Oct 5 2014 23:59:59.999
 */
function endOfYesterday(){
var now=new Date();
var year=now.getFullYear();
var month=now.getMonth();
var day=now.getDate();

var date=new Date(0);
date.setFullYear(year,month,day-1);
date.setHours(23,59,59,999);
return date;
}

module.exports=endOfYesterday;


/***/},

/***/"e53d":
/***/function e53d(module,exports){

// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
var global=module.exports=typeof window!='undefined'&&window.Math==Math?
window:typeof self!='undefined'&&self.Math==Math?self
// eslint-disable-next-line no-new-func
:Function('return this')();
if(typeof __g=='number')__g=global;// eslint-disable-line no-undef


/***/},

/***/"e620":
/***/function e620(module,exports,__webpack_require__){

var isSameSecond=__webpack_require__("c6ae");

/**
 * @category Second Helpers
 * @summary Is the given date in the same second as the current date?
 *
 * @description
 * Is the given date in the same second as the current date?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this second
 *
 * @example
 * // If now is 25 September 2014 18:30:15.500,
 * // is 25 September 2014 18:30:15.000 in this second?
 * var result = isThisSecond(new Date(2014, 8, 25, 18, 30, 15))
 * //=> true
 */
function isThisSecond(dirtyDate){
return isSameSecond(new Date(),dirtyDate);
}

module.exports=isThisSecond;


/***/},

/***/"e6f3":
/***/function e6f3(module,exports,__webpack_require__){

var has=__webpack_require__("07e3");
var toIObject=__webpack_require__("36c3");
var arrayIndexOf=__webpack_require__("5b4e")(false);
var IE_PROTO=__webpack_require__("5559")('IE_PROTO');

module.exports=function(object,names){
var O=toIObject(object);
var i=0;
var result=[];
var key;
for(key in O){if(key!=IE_PROTO)has(O,key)&&result.push(key);}
// Don't enum bug & hidden keys
while(names.length>i){if(has(O,key=names[i++])){
~arrayIndexOf(result,key)||result.push(key);
}}
return result;
};


/***/},

/***/"e73d":
/***/function e73d(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var getISOWeek=__webpack_require__("81fc");

/**
 * @category ISO Week Helpers
 * @summary Set the ISO week to the given date.
 *
 * @description
 * Set the ISO week to the given date, saving the weekday number.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} isoWeek - the ISO week of the new date
 * @returns {Date} the new date with the ISO week setted
 *
 * @example
 * // Set the 53rd ISO week to 7 August 2004:
 * var result = setISOWeek(new Date(2004, 7, 7), 53)
 * //=> Sat Jan 01 2005 00:00:00
 */
function setISOWeek(dirtyDate,dirtyISOWeek){
var date=parse(dirtyDate);
var isoWeek=Number(dirtyISOWeek);
var diff=getISOWeek(date)-isoWeek;
date.setDate(date.getDate()-diff*7);
return date;
}

module.exports=setISOWeek;


/***/},

/***/"e785":
/***/function e785(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Millisecond Helpers
 * @summary Get the number of milliseconds between the given dates.
 *
 * @description
 * Get the number of milliseconds between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of milliseconds
 *
 * @example
 * // How many milliseconds are between
 * // 2 July 2014 12:30:20.600 and 2 July 2014 12:30:21.700?
 * var result = differenceInMilliseconds(
 *   new Date(2014, 6, 2, 12, 30, 21, 700),
 *   new Date(2014, 6, 2, 12, 30, 20, 600)
 * )
 * //=> 1100
 */
function differenceInMilliseconds(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);
return dateLeft.getTime()-dateRight.getTime();
}

module.exports=differenceInMilliseconds;


/***/},

/***/"e830":
/***/function e830(module,exports,__webpack_require__){

var buildFormattingTokensRegExp=__webpack_require__("90e5");

function buildFormatLocale(){
// Note: in English, the names of days of the week and months are capitalized.
// If you are making a new locale based on this one, check if the same is true for the language you're working on.
// Generally, formatted dates should look like they are in the middle of a sentence,
// e.g. in Spanish language the weekdays and months should be in the lowercase.
var months3char=['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'];
var monthsFull=['January','February','March','April','May','June','July','August','September','October','November','December'];
var weekdays2char=['Su','Mo','Tu','We','Th','Fr','Sa'];
var weekdays3char=['Sun','Mon','Tue','Wed','Thu','Fri','Sat'];
var weekdaysFull=['Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday'];
var meridiemUppercase=['AM','PM'];
var meridiemLowercase=['am','pm'];
var meridiemFull=['a.m.','p.m.'];

var formatters={
// Month: Jan, Feb, ..., Dec
'MMM':function MMM(date){
return months3char[date.getMonth()];
},

// Month: January, February, ..., December
'MMMM':function MMMM(date){
return monthsFull[date.getMonth()];
},

// Day of week: Su, Mo, ..., Sa
'dd':function dd(date){
return weekdays2char[date.getDay()];
},

// Day of week: Sun, Mon, ..., Sat
'ddd':function ddd(date){
return weekdays3char[date.getDay()];
},

// Day of week: Sunday, Monday, ..., Saturday
'dddd':function dddd(date){
return weekdaysFull[date.getDay()];
},

// AM, PM
'A':function A(date){
return date.getHours()/12>=1?meridiemUppercase[1]:meridiemUppercase[0];
},

// am, pm
'a':function a(date){
return date.getHours()/12>=1?meridiemLowercase[1]:meridiemLowercase[0];
},

// a.m., p.m.
'aa':function aa(date){
return date.getHours()/12>=1?meridiemFull[1]:meridiemFull[0];
}};


// Generate ordinal version of formatters: M -> Mo, D -> Do, etc.
var ordinalFormatters=['M','D','DDD','d','Q','W'];
ordinalFormatters.forEach(function(formatterToken){
formatters[formatterToken+'o']=function(date,formatters){
return ordinal(formatters[formatterToken](date));
};
});

return {
formatters:formatters,
formattingTokensRegExp:buildFormattingTokensRegExp(formatters)};

}

function ordinal(number){
var rem100=number%100;
if(rem100>20||rem100<10){
switch(rem100%10){
case 1:
return number+'st';
case 2:
return number+'nd';
case 3:
return number+'rd';}

}
return number+'th';
}

module.exports=buildFormatLocale;


/***/},

/***/"e96b":
/***/function e96b(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Minute Helpers
 * @summary Return the start of a minute for the given date.
 *
 * @description
 * Return the start of a minute for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of a minute
 *
 * @example
 * // The start of a minute for 1 December 2014 22:15:45.400:
 * var result = startOfMinute(new Date(2014, 11, 1, 22, 15, 45, 400))
 * //=> Mon Dec 01 2014 22:15:00
 */
function startOfMinute(dirtyDate){
var date=parse(dirtyDate);
date.setSeconds(0,0);
return date;
}

module.exports=startOfMinute;


/***/},

/***/"eaa5":
/***/function eaa5(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Range Helpers
 * @summary Is the given date range overlapping with another date range?
 *
 * @description
 * Is the given date range overlapping with another date range?
 *
 * @param {Date|String|Number} initialRangeStartDate - the start of the initial range
 * @param {Date|String|Number} initialRangeEndDate - the end of the initial range
 * @param {Date|String|Number} comparedRangeStartDate - the start of the range to compare it with
 * @param {Date|String|Number} comparedRangeEndDate - the end of the range to compare it with
 * @returns {Boolean} whether the date ranges are overlapping
 * @throws {Error} startDate of a date range cannot be after its endDate
 *
 * @example
 * // For overlapping date ranges:
 * areRangesOverlapping(
 *   new Date(2014, 0, 10), new Date(2014, 0, 20), new Date(2014, 0, 17), new Date(2014, 0, 21)
 * )
 * //=> true
 *
 * @example
 * // For non-overlapping date ranges:
 * areRangesOverlapping(
 *   new Date(2014, 0, 10), new Date(2014, 0, 20), new Date(2014, 0, 21), new Date(2014, 0, 22)
 * )
 * //=> false
 */
function areRangesOverlapping(dirtyInitialRangeStartDate,dirtyInitialRangeEndDate,dirtyComparedRangeStartDate,dirtyComparedRangeEndDate){
var initialStartTime=parse(dirtyInitialRangeStartDate).getTime();
var initialEndTime=parse(dirtyInitialRangeEndDate).getTime();
var comparedStartTime=parse(dirtyComparedRangeStartDate).getTime();
var comparedEndTime=parse(dirtyComparedRangeEndDate).getTime();

if(initialStartTime>initialEndTime||comparedStartTime>comparedEndTime){
throw new Error('The start of the range cannot be after the end of the range');
}

return initialStartTime<comparedEndTime&&comparedStartTime<initialEndTime;
}

module.exports=areRangesOverlapping;


/***/},

/***/"ead6":
/***/function ead6(module,exports,__webpack_require__){

// Works with __proto__ only. Old v8 can't work with null proto objects.
/* eslint-disable no-proto */
var isObject=__webpack_require__("f772");
var anObject=__webpack_require__("e4ae");
var check=function check(O,proto){
anObject(O);
if(!isObject(proto)&&proto!==null)throw TypeError(proto+": can't set as prototype!");
};
module.exports={
set:Object.setPrototypeOf||('__proto__'in{}?// eslint-disable-line
function(test,buggy,set){
try{
set=__webpack_require__("d864")(Function.call,__webpack_require__("bf0b").f(Object.prototype,'__proto__').set,2);
set(test,[]);
buggy=!(test instanceof Array);
}catch(e){buggy=true;}
return function setPrototypeOf(O,proto){
check(O,proto);
if(buggy)O.__proto__=proto;else
set(O,proto);
return O;
};
}({},false):undefined),
check:check};



/***/},

/***/"ebfd":
/***/function ebfd(module,exports,__webpack_require__){

var META=__webpack_require__("62a0")('meta');
var isObject=__webpack_require__("f772");
var has=__webpack_require__("07e3");
var setDesc=__webpack_require__("d9f6").f;
var id=0;
var isExtensible=Object.isExtensible||function(){
return true;
};
var FREEZE=!__webpack_require__("294c")(function(){
return isExtensible(Object.preventExtensions({}));
});
var setMeta=function setMeta(it){
setDesc(it,META,{value:{
i:'O'+ ++id,// object ID
w:{}// weak collections IDs
}});
};
var fastKey=function fastKey(it,create){
// return primitive with prefix
if(!isObject(it))return typeof it=='symbol'?it:(typeof it=='string'?'S':'P')+it;
if(!has(it,META)){
// can't set metadata to uncaught frozen object
if(!isExtensible(it))return 'F';
// not necessary to add metadata
if(!create)return 'E';
// add missing metadata
setMeta(it);
// return object ID
}return it[META].i;
};
var getWeak=function getWeak(it,create){
if(!has(it,META)){
// can't set metadata to uncaught frozen object
if(!isExtensible(it))return true;
// not necessary to add metadata
if(!create)return false;
// add missing metadata
setMeta(it);
// return hash weak collections IDs
}return it[META].w;
};
// add metadata on freeze-family methods calling
var onFreeze=function onFreeze(it){
if(FREEZE&&meta.NEED&&isExtensible(it)&&!has(it,META))setMeta(it);
return it;
};
var meta=module.exports={
KEY:META,
NEED:false,
fastKey:fastKey,
getWeak:getWeak,
onFreeze:onFreeze};



/***/},

/***/"ec1f":
/***/function ec1f(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Millisecond Helpers
 * @summary Add the specified number of milliseconds to the given date.
 *
 * @description
 * Add the specified number of milliseconds to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of milliseconds to be added
 * @returns {Date} the new date with the milliseconds added
 *
 * @example
 * // Add 750 milliseconds to 10 July 2014 12:45:30.000:
 * var result = addMilliseconds(new Date(2014, 6, 10, 12, 45, 30, 0), 750)
 * //=> Thu Jul 10 2014 12:45:30.750
 */
function addMilliseconds(dirtyDate,dirtyAmount){
var timestamp=parse(dirtyDate).getTime();
var amount=Number(dirtyAmount);
return new Date(timestamp+amount);
}

module.exports=addMilliseconds;


/***/},

/***/"eca2":
/***/function eca2(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Month Helpers
 * @summary Return the last day of a month for the given date.
 *
 * @description
 * Return the last day of a month for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the last day of a month
 *
 * @example
 * // The last day of a month for 2 September 2014 11:55:00:
 * var result = lastDayOfMonth(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 30 2014 00:00:00
 */
function lastDayOfMonth(dirtyDate){
var date=parse(dirtyDate);
var month=date.getMonth();
date.setFullYear(date.getFullYear(),month+1,0);
date.setHours(0,0,0,0);
return date;
}

module.exports=lastDayOfMonth;


/***/},

/***/"ee91":
/***/function ee91(module,exports,__webpack_require__){

var differenceInDays=__webpack_require__("3bc7");

/**
 * @category Week Helpers
 * @summary Get the number of full weeks between the given dates.
 *
 * @description
 * Get the number of full weeks between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of full weeks
 *
 * @example
 * // How many full weeks are between 5 July 2014 and 20 July 2014?
 * var result = differenceInWeeks(
 *   new Date(2014, 6, 20),
 *   new Date(2014, 6, 5)
 * )
 * //=> 2
 */
function differenceInWeeks(dirtyDateLeft,dirtyDateRight){
var diff=differenceInDays(dirtyDateLeft,dirtyDateRight)/7;
return diff>0?Math.floor(diff):Math.ceil(diff);
}

module.exports=differenceInWeeks;


/***/},

/***/"f410":
/***/function f410(module,exports,__webpack_require__){

__webpack_require__("1af6");
module.exports=__webpack_require__("584a").Array.isArray;


/***/},

/***/"f564":
/***/function f564(module,exports,__webpack_require__){

var startOfMinute=__webpack_require__("e96b");

/**
 * @category Minute Helpers
 * @summary Are the given dates in the same minute?
 *
 * @description
 * Are the given dates in the same minute?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same minute
 *
 * @example
 * // Are 4 September 2014 06:30:00 and 4 September 2014 06:30:15
 * // in the same minute?
 * var result = isSameMinute(
 *   new Date(2014, 8, 4, 6, 30),
 *   new Date(2014, 8, 4, 6, 30, 15)
 * )
 * //=> true
 */
function isSameMinute(dirtyDateLeft,dirtyDateRight){
var dateLeftStartOfMinute=startOfMinute(dirtyDateLeft);
var dateRightStartOfMinute=startOfMinute(dirtyDateRight);

return dateLeftStartOfMinute.getTime()===dateRightStartOfMinute.getTime();
}

module.exports=isSameMinute;


/***/},

/***/"f56a":
/***/function f56a(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Range Helpers
 * @summary Is the given date within the range?
 *
 * @description
 * Is the given date within the range?
 *
 * @param {Date|String|Number} date - the date to check
 * @param {Date|String|Number} startDate - the start of range
 * @param {Date|String|Number} endDate - the end of range
 * @returns {Boolean} the date is within the range
 * @throws {Error} startDate cannot be after endDate
 *
 * @example
 * // For the date within the range:
 * isWithinRange(
 *   new Date(2014, 0, 3), new Date(2014, 0, 1), new Date(2014, 0, 7)
 * )
 * //=> true
 *
 * @example
 * // For the date outside of the range:
 * isWithinRange(
 *   new Date(2014, 0, 10), new Date(2014, 0, 1), new Date(2014, 0, 7)
 * )
 * //=> false
 */
function isWithinRange(dirtyDate,dirtyStartDate,dirtyEndDate){
var time=parse(dirtyDate).getTime();
var startTime=parse(dirtyStartDate).getTime();
var endTime=parse(dirtyEndDate).getTime();

if(startTime>endTime){
throw new Error('The start of the range cannot be after the end of the range');
}

return time>=startTime&&time<=endTime;
}

module.exports=isWithinRange;


/***/},

/***/"f5dd":
/***/function f5dd(module,exports,__webpack_require__){

var addMonths=__webpack_require__("6665");

/**
 * @category Quarter Helpers
 * @summary Add the specified number of year quarters to the given date.
 *
 * @description
 * Add the specified number of year quarters to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of quarters to be added
 * @returns {Date} the new date with the quarters added
 *
 * @example
 * // Add 1 quarter to 1 September 2014:
 * var result = addQuarters(new Date(2014, 8, 1), 1)
 * //=> Mon Dec 01 2014 00:00:00
 */
function addQuarters(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
var months=amount*3;
return addMonths(dirtyDate,months);
}

module.exports=addQuarters;


/***/},

/***/"f66d":
/***/function f66d(module,exports,__webpack_require__){

var isSameYear=__webpack_require__("26d5");

/**
 * @category Year Helpers
 * @summary Is the given date in the same year as the current date?
 *
 * @description
 * Is the given date in the same year as the current date?
 *
 * @param {Date|String|Number} date - the date to check
 * @returns {Boolean} the date is in this year
 *
 * @example
 * // If today is 25 September 2014, is 2 July 2014 in this year?
 * var result = isThisYear(new Date(2014, 6, 2))
 * //=> true
 */
function isThisYear(dirtyDate){
return isSameYear(new Date(),dirtyDate);
}

module.exports=isThisYear;


/***/},

/***/"f6fd":
/***/function f6fd(module,exports){

// document.currentScript polyfill by Adam Miller

// MIT license

(function(document){
var currentScript="currentScript",
scripts=document.getElementsByTagName('script');// Live NodeList collection

// If browser needs currentScript polyfill, add get currentScript() to the document object
if(!(currentScript in document)){
Object.defineProperty(document,currentScript,{
get:function get(){

// IE 6-10 supports script readyState
// IE 10+ support stack trace
try{throw new Error();}
catch(err){

// Find the second match for the "at" string to get file src url from stack.
// Specifically works with the format of stack traces in IE.
var i,res=(/.*at [^\(]*\((.*):.+:.+\)$/ig.exec(err.stack)||[false])[1];

// For all scripts on the page, if src matches or if ready state is interactive, return the script tag
for(i in scripts){
if(scripts[i].src==res||scripts[i].readyState=="interactive"){
return scripts[i];
}
}

// If no match, return null
return null;
}
}});

}
})(document);


/***/},

/***/"f772":
/***/function f772(module,exports){

module.exports=function(it){
return typeof it==='object'?it!==null:typeof it==='function';
};


/***/},

/***/"f921":
/***/function f921(module,exports,__webpack_require__){

__webpack_require__("014b");
__webpack_require__("c207");
__webpack_require__("69d3");
__webpack_require__("765d");
module.exports=__webpack_require__("584a").Symbol;


/***/},

/***/"f9ff":
/***/function f9ff(module,exports,__webpack_require__){

var getISOYear=__webpack_require__("8964");

/**
 * @category ISO Week-Numbering Year Helpers
 * @summary Get the number of calendar ISO week-numbering years between the given dates.
 *
 * @description
 * Get the number of calendar ISO week-numbering years between the given dates.
 *
 * ISO week-numbering year: http://en.wikipedia.org/wiki/ISO_week_date
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of calendar ISO week-numbering years
 *
 * @example
 * // How many calendar ISO week-numbering years are 1 January 2010 and 1 January 2012?
 * var result = differenceInCalendarISOYears(
 *   new Date(2012, 0, 1),
 *   new Date(2010, 0, 1)
 * )
 * //=> 2
 */
function differenceInCalendarISOYears(dirtyDateLeft,dirtyDateRight){
return getISOYear(dirtyDateLeft)-getISOYear(dirtyDateRight);
}

module.exports=differenceInCalendarISOYears;


/***/},

/***/"fa5b":
/***/function fa5b(module,exports,__webpack_require__){

module.exports=__webpack_require__("5537")('native-function-to-string',Function.toString);


/***/},

/***/"fa76":
/***/function fa76(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");
var addDays=__webpack_require__("8946");
var getISODay=__webpack_require__("84b9");

/**
 * @category Weekday Helpers
 * @summary Set the day of the ISO week to the given date.
 *
 * @description
 * Set the day of the ISO week to the given date.
 * ISO week starts with Monday.
 * 7 is the index of Sunday, 1 is the index of Monday etc.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} day - the day of the ISO week of the new date
 * @returns {Date} the new date with the day of the ISO week setted
 *
 * @example
 * // Set Sunday to 1 September 2014:
 * var result = setISODay(new Date(2014, 8, 1), 7)
 * //=> Sun Sep 07 2014 00:00:00
 */
function setISODay(dirtyDate,dirtyDay){
var date=parse(dirtyDate);
var day=Number(dirtyDay);
var currentDay=getISODay(date);
var diff=day-currentDay;
return addDays(date,diff);
}

module.exports=setISODay;


/***/},

/***/"fa99":
/***/function fa99(module,exports,__webpack_require__){

__webpack_require__("0293");
module.exports=__webpack_require__("584a").Object.getPrototypeOf;


/***/},

/***/"fab2":
/***/function fab2(module,exports,__webpack_require__){

var document=__webpack_require__("7726").document;
module.exports=document&&document.documentElement;


/***/},

/***/"fb15":
/***/function fb15(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);

// CONCATENATED MODULE: ./node_modules/@vue/cli-service/lib/commands/build/setPublicPath.js
// This file is imported into lib/wc client bundles.

if(typeof window!=='undefined'){
{
__webpack_require__("f6fd");
}

var setPublicPath_i;
if((setPublicPath_i=window.document.currentScript)&&(setPublicPath_i=setPublicPath_i.src.match(/(.+\/)[^/]+\.js(\?.*)?$/))){
__webpack_require__.p=setPublicPath_i[1];// eslint-disable-line
}
}

// EXTERNAL MODULE: external {"commonjs":"vue","commonjs2":"vue","root":"Vue"}
var external_commonjs_vue_commonjs2_vue_root_Vue_=__webpack_require__("8bbf");
var external_commonjs_vue_commonjs2_vue_root_Vue_default=/*#__PURE__*/__webpack_require__.n(external_commonjs_vue_commonjs2_vue_root_Vue_);

// CONCATENATED MODULE: ./node_modules/cache-loader/dist/cjs.js?{"cacheDirectory":"node_modules/.cache/vue-loader","cacheIdentifier":"30407d4c-vue-loader-template"}!./node_modules/vue-loader/lib/loaders/templateLoader.js??vue-loader-options!./node_modules/pug-plain-loader!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader/lib??vue-loader-options!./src/components/DateRangePicker.vue?vue&type=template&id=79f77391&lang=pug&
var render=function render(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"mj-daterange-picker",style:_vm.cssProps},[_vm.availablePanels.length>1?_c('div',{staticClass:"panels-choices"},_vm._l(_vm.availablePanels,function(panel){return _c('div',{staticClass:"panel-button",class:{'is-current':panel===_vm.currentPanel},on:{"click":function click($event){_vm.currentPanel=panel;}}},[_vm._v(_vm._s(_vm.$legends[_vm.locale].panels[panel]))]);}),0):_vm._e(),_vm.isPresetPicker&&_vm.presets.length>1?_c('div',{staticClass:"preset-ranges"},_vm._l(_vm.availablePresets,function(entry){return _c('div',{staticClass:"preset",on:{"click":function click($event){return _vm.selectPreset(entry);}}},[_c('input',{directives:[{name:"model",rawName:"v-model",value:_vm.preset,expression:"preset"}],attrs:{"type":"radio"},domProps:{"value":entry,"checked":_vm._q(_vm.preset,entry)},on:{"change":function change($event){_vm.preset=entry;}}}),_c('label',{attrs:{"for":entry}},[_c('span',{staticClass:"check"}),_c('span',[_vm._v(_vm._s(_vm.$legends[_vm.locale].presets[entry]))])])]);}),0):_vm._e(),_vm.isDaysPicker?_c('div',{staticClass:"mj-calendar",class:_vm.weekSelector?'mj-calendar-week':'mj-calendar-days'},[_c('div',{staticClass:"calendar-header"},[_c('div',{staticClass:"calendar-previous-month calendar-arrow calendar-arrow-previous",attrs:{"aria-label":_vm.$legends[_vm.locale].previousMonth},on:{"click":function click($event){return _vm.changeMonth(1);}}},[_c('svgicon',{attrs:{"icon":"arrow-left","width":"7.4","height":"12"}})],1),_c('div',{staticClass:"calendar-month-name"},[_vm._v(_vm._s(_vm.currentMonthName))]),_c('div',{staticClass:"calendar-previous-month calendar-arrow calendar-arrow-next",attrs:{"aria-label":_vm.$legends[_vm.locale].nextMonth},on:{"click":function click($event){return _vm.changeMonth(-1);}}},[_c('svgicon',{attrs:{"icon":"arrow-right","width":"7.4","height":"12"}})],1)]),_c('div',{staticClass:"calendar-days-name"},_vm._l(_vm.firstWeek,function(day){return _c('div',{staticClass:"day"},[_c('span',[_vm._v(_vm._s(day.name))])]);}),0),_c('div',{staticClass:"calendar-days"},_vm._l(_vm.monthDays,function(day){return _c('div',{key:_vm._f("date")(day.date,'DDMMYYYY'),staticClass:"day",class:_vm.dayClasses(day),on:{"click":function click($event){return _vm.selectDay(day.date);},"mouseover":function mouseover($event){return _vm.hoverizeDay(day.date);},"mouseleave":function mouseleave($event){_vm.hoverRange=[];}}},[_c('span',[_vm._v(_vm._s(_vm._f("date")(day.date,'D')))])]);}),0)]):_vm._e(),_vm.isMonthsPicker?_c('div',{staticClass:"mj-calendar"},[_c('div',{staticClass:"calendar-header"},[_c('div',{staticClass:"calendar-previous-month calendar-arrow calendar-arrow-previous",attrs:{"aria-label":_vm.$legends[_vm.locale].previousYear},on:{"click":function click($event){return _vm.changeYear(1);}}},[_c('svgicon',{attrs:{"icon":"arrow-left","width":"7.4","height":"12"}})],1),_c('div',{staticClass:"calendar-month-name"},[_vm._v(_vm._s(_vm.currentYearName))]),_c('div',{staticClass:"calendar-previous-month calendar-arrow calendar-arrow-next",attrs:{"aria-label":_vm.$legends[_vm.locale].nextYear},on:{"click":function click($event){return _vm.changeYear(-1);}}},[_c('svgicon',{attrs:{"icon":"arrow-right","width":"7.4","height":"12"}})],1)]),_vm.isMonthsPanel?_c('div',{staticClass:"calendar-months"},_vm._l(_vm.yearMonths,function(month){return _c('div',{key:_vm._f("date")(month.date,'DDMMYYYY'),staticClass:"month",class:_vm.monthClasses(month),on:{"click":function click($event){return _vm.selectMonth(month);}}},[_c('span',[_vm._v(_vm._s(month.displayDate))])]);}),0):_vm._e(),_vm.isQuartersPanel?_c('div',{staticClass:"calendar-quarters"},_vm._l(_vm.yearQuarters,function(quarter,index){return _c('div',{staticClass:"quarter",class:_vm.quarterClasses(quarter),on:{"click":function click($event){return _vm.selectQuarter(quarter);}}},[_c('div',{staticClass:"legend"},[_vm._v(_vm._s(_vm.$legends[_vm.locale].quarter)+" "+_vm._s(++index))]),_c('div',{staticClass:"months"},_vm._l(quarter.months,function(month){return _c('div',{staticClass:"month"},[_c('span',[_vm._v(_vm._s(month.displayDate))])]);}),0)]);}),0):_vm._e()]):_vm._e(),_vm.isYearPicker?_c('div',{staticClass:"mj-calendar"},[_c('div',{staticClass:"calendar-years"},_vm._l(_vm.years,function(year){return _c('div',{staticClass:"year",class:_vm.yearClasses(year),on:{"click":function click($event){return _vm.selectYear(year);}}},[_c('span',[_vm._v(_vm._s(year.displayDate))])]);}),0)]):_vm._e(),_vm.showControls?_c('div',{staticClass:"mj-daterange-picker-controls"},[_c('div',{staticClass:"mj-daterange-picker-button mj-daterange-picker-reset",on:{"click":_vm.reset}},[_vm._v(_vm._s(_vm.resetLegend))]),_c('div',{staticClass:"mj-daterange-picker-button mj-daterange-picker-submit",class:{'is-disabled':!(_vm.values.from&&_vm.values.to)},on:{"click":_vm.update}},[_vm._v(_vm._s(_vm.submitLegend))])]):_vm._e()]);};
var staticRenderFns=[];


// CONCATENATED MODULE: ./src/components/DateRangePicker.vue?vue&type=template&id=79f77391&lang=pug&

// EXTERNAL MODULE: ./node_modules/core-js/modules/es6.number.constructor.js
var es6_number_constructor=__webpack_require__("c5f6");

// EXTERNAL MODULE: ./node_modules/core-js/modules/es7.symbol.async-iterator.js
var es7_symbol_async_iterator=__webpack_require__("ac4d");

// EXTERNAL MODULE: ./node_modules/core-js/modules/es6.symbol.js
var es6_symbol=__webpack_require__("8a81");

// EXTERNAL MODULE: ./node_modules/core-js/modules/es6.array.fill.js
var es6_array_fill=__webpack_require__("6c7b");

// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/array/is-array.js
var is_array=__webpack_require__("a745");
var is_array_default=/*#__PURE__*/__webpack_require__.n(is_array);

// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/arrayWithHoles.js

function _arrayWithHoles(arr){
if(is_array_default()(arr))return arr;
}
// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/get-iterator.js
var get_iterator=__webpack_require__("5d73");
var get_iterator_default=/*#__PURE__*/__webpack_require__.n(get_iterator);

// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/is-iterable.js
var is_iterable=__webpack_require__("c8bb");
var is_iterable_default=/*#__PURE__*/__webpack_require__.n(is_iterable);

// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/iterableToArrayLimit.js


function _iterableToArrayLimit(arr,i){
if(!(is_iterable_default()(Object(arr))||Object.prototype.toString.call(arr)==="[object Arguments]")){
return;
}

var _arr=[];
var _n=true;
var _d=false;
var _e=undefined;

try{
for(var _i=get_iterator_default()(arr),_s;!(_n=(_s=_i.next()).done);_n=true){
_arr.push(_s.value);

if(i&&_arr.length===i)break;
}
}catch(err){
_d=true;
_e=err;
}finally{
try{
if(!_n&&_i["return"]!=null)_i["return"]();
}finally{
if(_d)throw _e;
}
}

return _arr;
}
// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/nonIterableRest.js
function _nonIterableRest(){
throw new TypeError("Invalid attempt to destructure non-iterable instance");
}
// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/slicedToArray.js



function _slicedToArray(arr,i){
return _arrayWithHoles(arr)||_iterableToArrayLimit(arr,i)||_nonIterableRest();
}
// EXTERNAL MODULE: ./node_modules/core-js/modules/es6.object.keys.js
var es6_object_keys=__webpack_require__("456d");

// EXTERNAL MODULE: ./node_modules/core-js/modules/web.dom.iterable.js
var web_dom_iterable=__webpack_require__("ac6a");

// EXTERNAL MODULE: ./node_modules/core-js/modules/es6.array.iterator.js
var es6_array_iterator=__webpack_require__("cadf");

// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/classCallCheck.js
function _classCallCheck(instance,Constructor){
if(!(instance instanceof Constructor)){
throw new TypeError("Cannot call a class as a function");
}
}
// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/object/define-property.js
var define_property=__webpack_require__("85f2");
var define_property_default=/*#__PURE__*/__webpack_require__.n(define_property);

// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/createClass.js


function _defineProperties(target,props){
for(var i=0;i<props.length;i++){
var descriptor=props[i];
descriptor.enumerable=descriptor.enumerable||false;
descriptor.configurable=true;
if("value"in descriptor)descriptor.writable=true;

define_property_default()(target,descriptor.key,descriptor);
}
}

function _createClass(Constructor,protoProps,staticProps){
if(protoProps)_defineProperties(Constructor.prototype,protoProps);
if(staticProps)_defineProperties(Constructor,staticProps);
return Constructor;
}
// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/symbol/iterator.js
var iterator=__webpack_require__("5d58");
var iterator_default=/*#__PURE__*/__webpack_require__.n(iterator);

// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/symbol.js
var symbol=__webpack_require__("67bb");
var symbol_default=/*#__PURE__*/__webpack_require__.n(symbol);

// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/typeof.js



function typeof_typeof2(obj){if(typeof symbol_default.a==="function"&&typeof iterator_default.a==="symbol"){typeof_typeof2=function _typeof2(obj){return typeof obj;};}else {typeof_typeof2=function _typeof2(obj){return obj&&typeof symbol_default.a==="function"&&obj.constructor===symbol_default.a&&obj!==symbol_default.a.prototype?"symbol":typeof obj;};}return typeof_typeof2(obj);}

function typeof_typeof(obj){
if(typeof symbol_default.a==="function"&&typeof_typeof2(iterator_default.a)==="symbol"){
typeof_typeof=function _typeof(obj){
return typeof_typeof2(obj);
};
}else {
typeof_typeof=function _typeof(obj){
return obj&&typeof symbol_default.a==="function"&&obj.constructor===symbol_default.a&&obj!==symbol_default.a.prototype?"symbol":typeof_typeof2(obj);
};
}

return typeof_typeof(obj);
}
// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/assertThisInitialized.js
function _assertThisInitialized(self){
if(self===void 0){
throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
}

return self;
}
// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/possibleConstructorReturn.js


function _possibleConstructorReturn(self,call){
if(call&&(typeof_typeof(call)==="object"||typeof call==="function")){
return call;
}

return _assertThisInitialized(self);
}
// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/object/get-prototype-of.js
var get_prototype_of=__webpack_require__("061b");
var get_prototype_of_default=/*#__PURE__*/__webpack_require__.n(get_prototype_of);

// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/object/set-prototype-of.js
var set_prototype_of=__webpack_require__("4d16");
var set_prototype_of_default=/*#__PURE__*/__webpack_require__.n(set_prototype_of);

// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/getPrototypeOf.js


function getPrototypeOf_getPrototypeOf(o){
getPrototypeOf_getPrototypeOf=set_prototype_of_default.a?get_prototype_of_default.a:function _getPrototypeOf(o){
return o.__proto__||get_prototype_of_default()(o);
};
return getPrototypeOf_getPrototypeOf(o);
}
// EXTERNAL MODULE: ./node_modules/@babel/runtime-corejs2/core-js/object/create.js
var create=__webpack_require__("4aa6");
var create_default=/*#__PURE__*/__webpack_require__.n(create);

// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/setPrototypeOf.js

function _setPrototypeOf(o,p){
_setPrototypeOf=set_prototype_of_default.a||function _setPrototypeOf(o,p){
o.__proto__=p;
return o;
};

return _setPrototypeOf(o,p);
}
// CONCATENATED MODULE: ./node_modules/@babel/runtime-corejs2/helpers/esm/inherits.js


function _inherits(subClass,superClass){
if(typeof superClass!=="function"&&superClass!==null){
throw new TypeError("Super expression must either be null or a function");
}

subClass.prototype=create_default()(superClass&&superClass.prototype,{
constructor:{
value:subClass,
writable:true,
configurable:true}});


if(superClass)_setPrototypeOf(subClass,superClass);
}

function __decorate(decorators,target,key,desc){
var c=arguments.length,r=c<3?target:desc===null?desc=Object.getOwnPropertyDescriptor(target,key):desc,d;
if(typeof Reflect==="object"&&typeof Reflect.decorate==="function")r=Reflect.decorate(decorators,target,key,desc);else
for(var i=decorators.length-1;i>=0;i--){if(d=decorators[i])r=(c<3?d(r):c>3?d(target,key,r):d(target,key))||r;}
return c>3&&r&&Object.defineProperty(target,key,r),r;
}

// EXTERNAL MODULE: ./node_modules/vue-class-component/dist/vue-class-component.common.js
var vue_class_component_common=__webpack_require__("65d9");
var vue_class_component_common_default=/*#__PURE__*/__webpack_require__.n(vue_class_component_common);
/**
 * decorator of a prop
 * @param  options the options for the prop
 * @return PropertyDecorator | void
 */
function Prop(options){
if(options===void 0){options={};}
return Object(vue_class_component_common["createDecorator"])(function(componentOptions,k){
(componentOptions.props||(componentOptions.props={}))[k]=options;
});
}
/**
 * decorator of a watch function
 * @param  path the path or the expression to observe
 * @param  WatchOption
 * @return MethodDecorator
 */
function Watch(path,options){
if(options===void 0){options={};}
var _a=options.deep,deep=_a===void 0?false:_a,_b=options.immediate,immediate=_b===void 0?false:_b;
return Object(vue_class_component_common["createDecorator"])(function(componentOptions,handler){
if(typeof componentOptions.watch!=='object'){
componentOptions.watch=Object.create(null);
}
var watch=componentOptions.watch;
if(typeof watch[path]==='object'&&!Array.isArray(watch[path])){
watch[path]=[watch[path]];
}else
if(typeof watch[path]==='undefined'){
watch[path]=[];
}
watch[path].push({handler:handler,deep:deep,immediate:immediate});
});
}

// EXTERNAL MODULE: ./node_modules/vue-svgicon/dist/components/svgicon.common.js
var svgicon_common=__webpack_require__("038a");
var svgicon_common_default=/*#__PURE__*/__webpack_require__.n(svgicon_common);

// CONCATENATED MODULE: ./src/assets/icons/arrow-left.js
/* eslint-disable */

/* tslint:disable */
// @ts-ignore

svgicon_common_default.a.register({
'arrow-left':{
width:8,
height:13,
viewBox:'0 0 8 13',
data:'<path pid="0" d="M7.766 1.658L3.008 6.094l4.437 4.758-1.448 1.35L.21 5.997 6.416.21z"/>'}});


// CONCATENATED MODULE: ./src/assets/icons/arrow-right.js
/* eslint-disable */

/* tslint:disable */
// @ts-ignore

svgicon_common_default.a.register({
'arrow-right':{
width:8,
height:13,
viewBox:'0 0 8 13',
data:'<path pid="0" d="M.048 1.658l4.758 4.436L.37 10.852l1.448 1.35 5.787-6.205L1.4.21z"/>'}});


// CONCATENATED MODULE: ./src/assets/icons/index.js
/* eslint-disable */


// EXTERNAL MODULE: ./node_modules/vue-date-fns/src/index.js
var src=__webpack_require__("4c9f");

// EXTERNAL MODULE: ./node_modules/date-fns/index.js
var date_fns=__webpack_require__("340b");

// CONCATENATED MODULE: ./src/translations/index.js
var dictonnaries={
"fr":{
"reset":"Réinitialiser les dates",
"submit":"Valider",
"previousMonth":"Mois précédent",
"nextMonth":"Mois suivant",
"previousYear":"Année précédente",
"nextYear":"Année suivante",
"quarter":"Trimestre",
"panels":{
"range":"Plage",
"week":"Semaine",
"month":"Mois",
"quarter":"Trimestre",
"year":"Année"},

"presets":{
"custom":"Période personnalisée",
"forever":"Depuis le début",
"last7days":"7 derniers jours",
"last30days":"30 derniers jours",
"last90days":"90 derniers jours",
"last365days":"365 dernier jours",
"next365days":"365 prochains jours",
"next90days":"90 prochains jours",
"next30days":"30 prochains jours",
"next7days":"7 prochains jours",
"today":"Aujourd\"hui",
"tomorrow":"Demain",
"yesterday":"Hier"}},


"en":{
"reset":"Reset ranges",
"submit":"Submit",
"previousMonth":"Previous month",
"nextMonth":"Next month",
"previousYear":"Previous year",
"nextYear":"Next year",
"quarter":"Quarter",
"panels":{
"range":"Range",
"week":"Week",
"month":"Month",
"quarter":"Quarter",
"year":"Year"},

"presets":{
"custom":"Custom range",
"forever":"From the beginning",
"last7days":"Last 7 days",
"last30days":"Last 30 days",
"last90days":"Last 90 days",
"last365days":"Last 365 days",
"next365days":"next 365 days",
"next90days":"Next 90 days",
"next30days":"Next 30 days",
"next7days":"Next 7 days",
"today":"Today",
"tomorrow":"Tomorrow",
"yesterday":"Yesterday"}},


"de":{
"reset":"Zurücksetzen",
"submit":"Ok",
"previousMonth":"Letztes Monat",
"nextMonth":"Nächstes Monat",
"previousYear":"Letztes Jahr",
"nextYear":"Nächstes Jahr",
"quarter":"Quartal",
"panels":{
"range":"Zeitraum",
"week":"Woche",
"month":"Monat",
"quarter":"Quartal",
"year":"Jahr"},

"presets":{
"custom":"Benutzerdefiniert",
"forever":"Von Anfang",
"last7days":"Letzten 7 Tage",
"last30days":"Letzten 30 Tage",
"last90days":"Letzten 90 Tage",
"last365days":"Letzten 365 Tage",
"next365days":"Nächsten 365 Tage",
"next90days":"Nächsten 90 Tage",
"next30days":"Nächsten 30 Tage",
"next7days":"Nächsten 7 Tage",
"today":"Heute",
"tomorrow":"Morgen",
"yesterday":"Gestern"}},


"es":{
"reset":"Quitar selección",
"submit":"Guardar",
"previousMonth":"mes anterior",
"nextMonth":"mes siguiente",
"previousYear":"año anterior",
"nextYear":"año siguiente",
"quarter":"Trimestre",
"panels":{
"range":"Rango",
"week":"Semanal",
"month":"Mensual",
"quarter":"Trimestral",
"year":"Anual"},

"presets":{
"custom":"Selección personalizada",
"forever":"Desde el principio",
"last7days":"Últimos 7 días",
"last30days":"Últimos 30 días",
"last90days":"Últimos 90 días",
"last365days":"Últimos 365 días",
"next365days":"Próximos 365 días",
"next90days":"Próximos 90 días",
"next30days":"Próximos 30 días",
"next7days":"Próximos 7 días",
"today":"Hoy",
"tomorrow":"Mañana",
"yesterday":"Ayer"}},


"ru":{
"reset":"Сбросить",
"submit":"Применить",
"previousMonth":"Предыдущий месяц",
"nextMonth":"Следующий месяц",
"previousYear":"Предыдущий год",
"nextYear":"Следующий год",
"quarter":"Квартал",
"panels":{
"range":"Период",
"week":"Неделя",
"month":"Месяц",
"quarter":"Квартал",
"year":"Год"},

"presets":{
"custom":"Пользовательский диапазон",
"forever":"С начала",
"last7days":"Последние 7 дней",
"last30days":"Последние 30 дней",
"last90days":"Последние 90 дней",
"last365days":"Последние 365 дней",
"next365days":"Следующие 365 дней",
"next90days":"Следующие 90 дней",
"next30days":"Следующие 30 дней",
"next7days":"Следующие 7 дней",
"today":"Сегодня",
"tomorrow":"Завтра",
"yesterday":"Вчера"}}};



/* harmony default export */var translations=dictonnaries;
// CONCATENATED MODULE: ./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/thread-loader/dist/cjs.js!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader/lib??vue-loader-options!./src/components/DateRangePicker.vue?vue&type=script&lang=ts&




















external_commonjs_vue_commonjs2_vue_root_Vue_default.a.prototype.$legends=translations;
var locales={
en:__webpack_require__("52cf"),
fr:__webpack_require__("2ca0"),
de:__webpack_require__("6e0c"),
es:__webpack_require__("fd2d"),
ru:__webpack_require__("9f3f")};

external_commonjs_vue_commonjs2_vue_root_Vue_default.a.use(svgicon_common_default.a,{
tagName:'svgicon'});


var DateRangePickervue_type_script_lang_ts_default_1=
/*#__PURE__*/
function(_Vue){
_inherits(default_1,_Vue);

function default_1(){
var _this;

_classCallCheck(this,default_1);

_this=_possibleConstructorReturn(this,getPrototypeOf_getPrototypeOf(default_1).apply(this,arguments));
_this.currentPanel=null;
_this.current=null;
_this.weekSelector=false;
_this.daySelector=false;
_this.monthDays=[];
_this.now=new Date().toISOString();
_this.values={
from:null,
to:null};

_this.hoverRange=[];
_this.preset='custom';
return _this;
}

_createClass(default_1,[{
key:"switchMode",
value:function switchMode(panel){
this.weekSelector=panel==='week'?true:false;
this.daySelector=panel==='day'?true:false;
this.updateCalendar();
this.$emit('update:panel',panel);
}},
{
key:"emitValuesWithSelect",
value:function emitValuesWithSelect(values){
if(values.from&&values.to){
this.$emit('select',{
to:Object(date_fns["format"])(Object(date_fns["endOfDay"])(this.values.to),'YYYY-MM-DDTHH:mm:ss.SSSZ'),
from:Object(date_fns["format"])(Object(date_fns["startOfDay"])(this.values.from),'YYYY-MM-DDTHH:mm:ss.SSSZ'),
panel:this.currentPanel});

}
}},
{
key:"affectPreset",
value:function affectPreset(preset){
this.current=this.now;
this.updateCalendar();

switch(preset){
case'custom':
this.values={
from:null,
to:null};

break;

case'today':
this.values={
from:Object(date_fns["startOfDay"])(this.now),
to:this.now};

break;

case'yesterday':
this.values={
from:Object(date_fns["startOfDay"])(Object(date_fns["subDays"])(this.now,1)),
to:Object(date_fns["endOfDay"])(Object(date_fns["subDays"])(this.now,1))};

break;

case'tomorrow':
this.values={
from:Object(date_fns["startOfDay"])(Object(date_fns["addDays"])(this.now,1)),
to:Object(date_fns["endOfDay"])(Object(date_fns["addDays"])(this.now,1))};

break;

case'last7days':
this.values={
from:Object(date_fns["startOfDay"])(Object(date_fns["subWeeks"])(this.now,1)),
to:this.now};

break;

case'next7days':
this.values={
to:Object(date_fns["startOfDay"])(Object(date_fns["addWeeks"])(this.now,1)),
from:this.now};

break;

case'last30days':
this.values={
from:Object(date_fns["startOfDay"])(Object(date_fns["subMonths"])(this.now,1)),
to:this.now};

break;

case'next30days':
this.values={
to:Object(date_fns["startOfDay"])(Object(date_fns["addMonths"])(this.now,1)),
from:this.now};

break;

case'last90days':
this.values={
from:Object(date_fns["startOfDay"])(Object(date_fns["subMonths"])(this.now,3)),
to:this.now};

break;

case'next90days':
this.values={
to:Object(date_fns["startOfDay"])(Object(date_fns["addMonths"])(this.now,3)),
from:this.now};

break;

case'last365days':
this.values={
from:Object(date_fns["startOfDay"])(Object(date_fns["subYears"])(this.now,1)),
to:this.now};

break;

case'next365days':
this.values={
to:Object(date_fns["startOfDay"])(Object(date_fns["addYears"])(this.now,1)),
from:this.now};

break;

case'forever':
this.values={
from:this.begin,
to:this.now};

break;}

}},
{
key:"created",
value:function created(){
var _this2=this;

// Parse Inputs
Object.keys(this.values).forEach(function(value){
_this2.values[value]=Object(date_fns["isValid"])(Object(date_fns["parse"])(_this2[value]))?_this2[value]:null;
});// Todo ? If from or to is null, or from is after to, both are null
// Display current month or "to" month

this.current=this.values[this.rangeDisplayed]?this.values[this.rangeDisplayed]:this.now;// Update Calendar

this.updateCalendar();// Set current panel

this.currentPanel=this.panel||this.availablePanels[0];
}},
{
key:"reset",
value:function reset(){
this.values={
to:null,
from:null};

this.preset=null;
this.$emit('reset',{
to:null,
from:null});

}},
{
key:"update",
value:function update(){
if(!this.values.from||!this.values.to){
return;
}

this.$emit('update',{
to:Object(date_fns["format"])(Object(date_fns["endOfDay"])(this.values.to),'YYYY-MM-DDTHH:mm:ss.SSSZ'),
from:Object(date_fns["format"])(Object(date_fns["startOfDay"])(this.values.from),'YYYY-MM-DDTHH:mm:ss.SSSZ'),
panel:this.currentPanel});

}},
{
key:"changeMonth",
value:function changeMonth(diff){
this.current=Object(date_fns["subMonths"])(this.current,diff);
this.updateCalendar();
}},
{
key:"changeYear",
value:function changeYear(diff){
this.current=Object(date_fns["subYears"])(this.current,diff);
this.updateCalendar();
}},
{
key:"selectPreset",
value:function selectPreset(preset){
this.preset=preset;
}},
{
key:"selectDay",
value:function selectDay(date){
if(this.weekSelector){
var range=this.getAllowedDatesOfRange([Object(date_fns["startOfWeek"])(date,{
weekStartsOn:1}),
Object(date_fns["endOfWeek"])(date,{
weekStartsOn:1})]);

this.values.from=range[0];
this.values.to=range[range.length-1];
return;
}

if(this.daySelector){
this.values.from=Object(date_fns["startOfDay"])(date);
this.values.to=Object(date_fns["startOfDay"])(date);
return;
}

if(this.values.from&&this.values.to||!this.values.from&&!this.values.to){
this.values.from=date;
this.values.to=null;
}else if(this.values.from&&!this.values.to){
if(Object(date_fns["isBefore"])(date,this.values.from)){
this.values.from=date;
}else {
this.values.to=date;
this.hoverRange=[];
}
}

this.preset='custom';
}},
{
key:"selectQuarter",
value:function selectQuarter(quarter){
this.values.from=Object(date_fns["startOfDay"])(Object(date_fns["startOfMonth"])(quarter.range.start));
this.values.to=Object(date_fns["endOfMonth"])(quarter.range.end);
this.current=this.values.to;
}},
{
key:"selectMonth",
value:function selectMonth(month){
this.values.from=Object(date_fns["startOfMonth"])(month.date);
this.values.to=Object(date_fns["endOfMonth"])(month.date);
this.current=this.values.to;
}},
{
key:"selectYear",
value:function selectYear(year){
this.values.from=Object(date_fns["startOfYear"])(year.date);
this.values.to=Object(date_fns["endOfYear"])(year.date);
this.current=this.values.to;
}},
{
key:"hoverizeDay",
value:function hoverizeDay(date){
if(!this.weekSelector&&(!(this.values.from&&!this.values.to)||Object(date_fns["isBefore"])(date,this.values.from))){
this.hoverRange=[];
return;
}

if(this.weekSelector){
this.hoverRange=[Object(date_fns["startOfWeek"])(date,{
weekStartsOn:1}),
Object(date_fns["endOfWeek"])(date,{
weekStartsOn:1})];

}else {
this.hoverRange=[this.values.from,date];
}
}},
{
key:"updateCalendar",
value:function updateCalendar(){
var days=[];
var lastDayOfMonth=Object(date_fns["endOfMonth"])(this.current);
var firstDayOfMonth=Object(date_fns["startOfMonth"])(this.current);
var nbDaysLastMonth=(+Object(date_fns["format"])(firstDayOfMonth,'d')-1)%7;

if(nbDaysLastMonth===-1){
nbDaysLastMonth=6;
}

var day=Object(date_fns["subDays"])(firstDayOfMonth,nbDaysLastMonth);

while(Object(date_fns["isBefore"])(day,lastDayOfMonth)||days.length%7>0){
var isAllowedByFutureAndPast=this.future&&Object(date_fns["isAfter"])(day,this.now)?true:this.past&&Object(date_fns["isBefore"])(day,this.now)?true:Object(date_fns["isSameDay"])(day,this.now);
var isAllowedByAllowedProps=this.isDateAllowed(day);
days.push({
date:day,
selectable:isAllowedByFutureAndPast&&isAllowedByAllowedProps,
currentMonth:Object(date_fns["isSameMonth"])(this.current,day)});

day=Object(date_fns["addDays"])(day,1);
}

this.monthDays=days;
}},
{
key:"dayClasses",
value:function dayClasses(day){
var classes=[];

if(day.currentMonth){
classes.push('is-current-month');
}

if(this.values.from&&this.values.to&&Object(date_fns["isWithinRange"])(day.date,this.values.from,this.values.to)){
classes.push('is-selected');
}

if(!day.selectable){
classes.push('is-disabled');
}

if(Object(date_fns["isSameDay"])(day.date,this.now)){
classes.push('is-today');
}

if(!this.values.to&&Object(date_fns["isSameDay"])(day.date,this.values.from)||this.values.to&&!this.values.from&&Object(date_fns["isSameDay"])(day.date,this.values.from)&&Object(date_fns["isSameDay"])(day.date,this.values.to)||this.values.to&&this.values.from&&Object(date_fns["isSameDay"])(day.date,this.values.from)){
classes.push('is-first-range');
classes.push('is-edge-range');
}

if(this.values.to&&Object(date_fns["isSameDay"])(day.date,this.values.to)){
classes.push('is-last-range');
classes.push('is-edge-range');
}

if(this.hoverRange.length===2&&Object(date_fns["isWithinRange"])(day.date,this.hoverRange[0],this.hoverRange[1])){
classes.push('is-in-range');
}

return classes;
}},
{
key:"monthClasses",
value:function monthClasses(month){
var classes=[];

if(!month.selectable){
classes.push('is-disabled');
}

if(this.values.to&&this.values.from&&Object(date_fns["isWithinRange"])(month.date,this.values.from,this.values.to)){
classes.push('is-selected');
}

return classes;
}},
{
key:"quarterClasses",
value:function quarterClasses(quarter){
var classes=[];

if(!quarter.selectable){
classes.push('is-disabled');
}

if(this.values.to&&this.values.from&&Object(date_fns["isWithinRange"])(quarter.range.start,this.values.from,this.values.to)&&Object(date_fns["isWithinRange"])(quarter.range.end,this.values.from,this.values.to)){
classes.push('is-selected');
}

return classes;
}},
{
key:"yearClasses",
value:function yearClasses(year){
var classes=[];

if(!year.selectable){
classes.push('is-disabled');
}

if(this.values.to&&this.values.from){
if(Object(date_fns["isSameDay"])(this.values.from,Object(date_fns["startOfYear"])(year.date))&&Object(date_fns["isSameDay"])(this.values.to,Object(date_fns["endOfYear"])(year.date))){
classes.push('is-selected');
}
}

return classes;
}},
{
key:"isDateAllowed",
value:function isDateAllowed(date){
var isAllowed=true;

if(this.allowFrom){
isAllowed=isAllowed&&!Object(date_fns["isBefore"])(date,Object(date_fns["parse"])(this.allowFrom));
}

if(this.allowTo){
isAllowed=isAllowed&&!Object(date_fns["isAfter"])(date,Object(date_fns["parse"])(this.allowTo));
}

return isAllowed;
}},
{
key:"isRangeAllowed",
value:function isRangeAllowed(_ref){
var _ref2=_slicedToArray(_ref,2),
from=_ref2[0],
to=_ref2[1];

return this.isDateAllowed(from)&&this.isDateAllowed(to);
}},
{
key:"getAllowedDatesOfRange",
value:function getAllowedDatesOfRange(_ref3){
var _ref4=_slicedToArray(_ref3,2),
from=_ref4[0],
to=_ref4[1];

var distance=Object(date_fns["differenceInDays"])(to,from);
return new Array(distance+1).fill(null).map(function(_,index){
return Object(date_fns["addDays"])(from,index);
}).filter(this.isDateAllowed);
}},
{
key:"availablePanels",
get:function get(){
return this.panels;
}},
{
key:"availablePresets",
get:function get(){
var index=this.presets.indexOf('forever');

if(!this.begin&&index>-1){
this.presets.splice(index,1);
}

return this.presets;
}},
{
key:"resetLegend",
get:function get(){
return this.resetTitle?this.resetTitle:this.$legends[this.locale].reset;
}},
{
key:"submitLegend",
get:function get(){
return this.submitTitle?this.submitTitle:this.$legends[this.locale].submit;
}},
{
key:"firstWeek",
get:function get(){
var days=this.monthDays.slice(0,7);
var week=[];
var _iteratorNormalCompletion=true;
var _didIteratorError=false;
var _iteratorError=undefined;

try{
for(var _iterator=days[Symbol.iterator](),_step;!(_iteratorNormalCompletion=(_step=_iterator.next()).done);_iteratorNormalCompletion=true){
var day=_step.value;
week.push({
name:Object(date_fns["format"])(day.date,'dd',{
locale:locales[this.locale]})});


}
}catch(err){
_didIteratorError=true;
_iteratorError=err;
}finally{
try{
if(!_iteratorNormalCompletion&&_iterator.return!=null){
_iterator.return();
}
}finally{
if(_didIteratorError){
throw _iteratorError;
}
}
}

return week;
}},
{
key:"cssProps",
get:function get(){
return {
'--default-width':this.width,
'--primary-color':this.theme.primary,
'--hover-day-color':this.theme.hovers.day,
'--hover-range-color':this.theme.hovers.range,
'--secondary-color':this.theme.secondary,
'--ternary-color':this.theme.ternary,
'--normal-color':this.theme.light,
'--contrast-color':this.theme.dark,
'--border-color':this.theme.border};

}},
{
key:"yearMonths",
get:function get(){
var months=[];
var month=Object(date_fns["startOfYear"])(this.current);

while(months.length!==12){
var isMonthAllowed=this.isRangeAllowed([Object(date_fns["startOfMonth"])(month),Object(date_fns["endOfMonth"])(month)]);
months.push({
date:month,
selectable:isMonthAllowed,
displayDate:Object(date_fns["format"])(month,'MMMM',{
locale:locales[this.locale]})});


month=Object(date_fns["addMonths"])(month,1);
}

return months;
}},
{
key:"yearQuarters",
get:function get(){
var quarters=[];
var _iteratorNormalCompletion2=true;
var _didIteratorError2=false;
var _iteratorError2=undefined;

try{
for(var _iterator2=this.yearMonths.entries()[Symbol.iterator](),_step2;!(_iteratorNormalCompletion2=(_step2=_iterator2.next()).done);_iteratorNormalCompletion2=true){
var _step2$value=_slicedToArray(_step2.value,2),
index=_step2$value[0],
month=_step2$value[1];

if(index%3===0){
var isQuarterAllowed=this.isRangeAllowed([Object(date_fns["startOfMonth"])(this.yearMonths[index].date),Object(date_fns["endOfMonth"])(this.yearMonths[index+2].date)]);
quarters.push({
months:[this.yearMonths[index],this.yearMonths[index+1],this.yearMonths[index+2]],
selectable:isQuarterAllowed,
range:{
start:Object(date_fns["startOfDay"])(Object(date_fns["startOfMonth"])(this.yearMonths[index].date)),
end:Object(date_fns["endOfDay"])(Object(date_fns["endOfMonth"])(this.yearMonths[index+2].date))}});


}
}
}catch(err){
_didIteratorError2=true;
_iteratorError2=err;
}finally{
try{
if(!_iteratorNormalCompletion2&&_iterator2.return!=null){
_iterator2.return();
}
}finally{
if(_didIteratorError2){
throw _iteratorError2;
}
}
}

return quarters;
}},
{
key:"years",
get:function get(){
var years=[];
var i=this.yearsCount;
var start=this.future?Object(date_fns["addYears"])(this.now,this.yearsCount):this.now;
i=+this.future*this.yearsCount+ +this.past*this.yearsCount+1;

while(i!==0){
var isYearAllowed=this.isRangeAllowed([Object(date_fns["startOfYear"])(start),Object(date_fns["endOfYear"])(start)]);
years.push({
date:start,
selectable:isYearAllowed,
displayDate:Object(date_fns["format"])(start,'YYYY',{
locale:locales[this.locale]})});


start=Object(date_fns["subYears"])(start,1);
i=i-1;
}

return years;
}},
{
key:"currentMonthName",
get:function get(){
return Object(date_fns["format"])(this.current,'MMMM YYYY',{
locale:locales[this.locale]});

}},
{
key:"currentYearName",
get:function get(){
return Object(date_fns["format"])(this.current,'YYYY',{
locale:locales[this.locale]});

}},
{
key:"isPresetPicker",
get:function get(){
return this.currentPanel==='range';
}},
{
key:"isDaysPicker",
get:function get(){
return this.currentPanel==='range'||this.currentPanel==='week'||this.currentPanel==='day';
}},
{
key:"isMonthsPicker",
get:function get(){
return this.currentPanel==='month'||this.currentPanel==='quarter';
}},
{
key:"isYearPicker",
get:function get(){
return this.currentPanel==='year';
}},
{
key:"isMonthsPanel",
get:function get(){
return this.currentPanel==='month';
}},
{
key:"isQuartersPanel",
get:function get(){
return this.currentPanel==='quarter';
}}]);


return default_1;
}(external_commonjs_vue_commonjs2_vue_root_Vue_default.a);

__decorate([Prop({
type:String,
default:'en'})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"locale",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"from",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"to",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"begin",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"allowFrom",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"allowTo",void 0);

__decorate([Prop({
type:Boolean,
default:true})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"past",void 0);

__decorate([Prop({
type:Boolean,
default:true})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"future",void 0);

__decorate([Prop({
type:Boolean,
default:true})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"showControls",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"panel",void 0);

__decorate([Prop({
type:Number,
default:2})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"yearsCount",void 0);

__decorate([Prop({
type:Array,
default:function _default(){
return ['range','week','month','quarter','year'];
}})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"panels",void 0);

__decorate([Prop({
type:Object,
default:function _default(){
return {
primary:'#3297DB',
secondary:'#2D3E50',
ternary:'#93A0BD',
border:'#e6e6e6',
light:'#ffffff',
dark:'#000000',
hovers:{
day:'#CCC',
range:'#e6e6e6'}};


}})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"theme",void 0);

__decorate([Prop({
type:String,
default:'auto'})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"width",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"resetTitle",void 0);

__decorate([Prop({
type:String,
default:null})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"submitTitle",void 0);

__decorate([Prop({
type:Array,
default:function _default(){
return ['today','yesterday','last7days','last30days','last90days','last365days','forever','custom'];
}})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"presets",void 0);

__decorate([Prop({
type:String,
default:'to',
validator:function validator(value){
return ['to','from'].indexOf(value)!==-1;
}})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"rangeDisplayed",void 0);

__decorate([Watch('currentPanel',{
immediate:true})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"switchMode",null);

__decorate([Watch('values',{
deep:true})],
DateRangePickervue_type_script_lang_ts_default_1.prototype,"emitValuesWithSelect",null);

__decorate([Watch('preset')],DateRangePickervue_type_script_lang_ts_default_1.prototype,"affectPreset",null);

DateRangePickervue_type_script_lang_ts_default_1=__decorate([vue_class_component_common_default()({
filters:{
date:src["dateFilter"]}})],

DateRangePickervue_type_script_lang_ts_default_1);
/* harmony default export */var DateRangePickervue_type_script_lang_ts_=DateRangePickervue_type_script_lang_ts_default_1;
// CONCATENATED MODULE: ./src/components/DateRangePicker.vue?vue&type=script&lang=ts&
/* harmony default export */var components_DateRangePickervue_type_script_lang_ts_=DateRangePickervue_type_script_lang_ts_;
// EXTERNAL MODULE: ./src/components/DateRangePicker.vue?vue&type=style&index=0&lang=scss&
var DateRangePickervue_type_style_index_0_lang_scss_=__webpack_require__("0e58");

// CONCATENATED MODULE: ./node_modules/vue-loader/lib/runtime/componentNormalizer.js
/* globals __VUE_SSR_CONTEXT__ */

// IMPORTANT: Do NOT use ES2015 features in this file (except for modules).
// This module is a runtime utility for cleaner component module output and will
// be included in the final webpack user bundle.

function normalizeComponent(
scriptExports,
render,
staticRenderFns,
functionalTemplate,
injectStyles,
scopeId,
moduleIdentifier,/* server only */
shadowMode/* vue-cli only */)
{
// Vue.extend constructor export interop
var options=typeof scriptExports==='function'?
scriptExports.options:
scriptExports;

// render functions
if(render){
options.render=render;
options.staticRenderFns=staticRenderFns;
options._compiled=true;
}

// functional template
if(functionalTemplate){
options.functional=true;
}

// scopedId
if(scopeId){
options._scopeId='data-v-'+scopeId;
}

var hook;
if(moduleIdentifier){// server build
hook=function hook(context){
// 2.3 injection
context=
context||// cached call
this.$vnode&&this.$vnode.ssrContext||// stateful
this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext;// functional
// 2.2 with runInNewContext: true
if(!context&&typeof __VUE_SSR_CONTEXT__!=='undefined'){
context=__VUE_SSR_CONTEXT__;
}
// inject component styles
if(injectStyles){
injectStyles.call(this,context);
}
// register component module identifier for async chunk inferrence
if(context&&context._registeredComponents){
context._registeredComponents.add(moduleIdentifier);
}
};
// used by ssr in case component is cached and beforeCreate
// never gets called
options._ssrRegister=hook;
}else if(injectStyles){
hook=shadowMode?
function(){injectStyles.call(this,this.$root.$options.shadowRoot);}:
injectStyles;
}

if(hook){
if(options.functional){
// for template-only hot-reload because in that case the render fn doesn't
// go through the normalizer
options._injectStyles=hook;
// register for functioal component in vue file
var originalRender=options.render;
options.render=function renderWithStyleInjection(h,context){
hook.call(context);
return originalRender(h,context);
};
}else {
// inject component registration as beforeCreate hook
var existing=options.beforeCreate;
options.beforeCreate=existing?
[].concat(existing,hook):
[hook];
}
}

return {
exports:scriptExports,
options:options};

}

// CONCATENATED MODULE: ./src/components/DateRangePicker.vue






/* normalize component */

var component=normalizeComponent(
components_DateRangePickervue_type_script_lang_ts_,
render,
staticRenderFns,
false,
null,
null,
null);



/* harmony default export */var DateRangePicker=component.exports;
// CONCATENATED MODULE: ./src/components/index.js


var components_plugin={
install:function install(Vue,options){
Vue.component('DateRangePicker',DateRangePicker);
}};

/* harmony default export */var components=components_plugin;
// CONCATENATED MODULE: ./node_modules/@vue/cli-service/lib/commands/build/entry-lib.js


/* harmony default export */var entry_lib=__webpack_exports__["default"]=components;



/***/},

/***/"fb36":
/***/function fb36(module,exports,__webpack_require__){

var getQuarter=__webpack_require__("b8f9");
var parse=__webpack_require__("c8d5");

/**
 * @category Quarter Helpers
 * @summary Get the number of calendar quarters between the given dates.
 *
 * @description
 * Get the number of calendar quarters between the given dates.
 *
 * @param {Date|String|Number} dateLeft - the later date
 * @param {Date|String|Number} dateRight - the earlier date
 * @returns {Number} the number of calendar quarters
 *
 * @example
 * // How many calendar quarters are between 31 December 2013 and 2 July 2014?
 * var result = differenceInCalendarQuarters(
 *   new Date(2014, 6, 2),
 *   new Date(2013, 11, 31)
 * )
 * //=> 3
 */
function differenceInCalendarQuarters(dirtyDateLeft,dirtyDateRight){
var dateLeft=parse(dirtyDateLeft);
var dateRight=parse(dirtyDateRight);

var yearDiff=dateLeft.getFullYear()-dateRight.getFullYear();
var quarterDiff=getQuarter(dateLeft)-getQuarter(dateRight);

return yearDiff*4+quarterDiff;
}

module.exports=differenceInCalendarQuarters;


/***/},

/***/"fb98":
/***/function fb98(module,exports,__webpack_require__){

var addHours=__webpack_require__("1cc6");

/**
 * @category Hour Helpers
 * @summary Subtract the specified number of hours from the given date.
 *
 * @description
 * Subtract the specified number of hours from the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of hours to be subtracted
 * @returns {Date} the new date with the hours subtracted
 *
 * @example
 * // Subtract 2 hours from 11 July 2014 01:00:00:
 * var result = subHours(new Date(2014, 6, 11, 1, 0), 2)
 * //=> Thu Jul 10 2014 23:00:00
 */
function subHours(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addHours(dirtyDate,-amount);
}

module.exports=subHours;


/***/},

/***/"fbaf":
/***/function fbaf(module,exports,__webpack_require__){

var parse=__webpack_require__("c8d5");

/**
 * @category Hour Helpers
 * @summary Return the start of an hour for the given date.
 *
 * @description
 * Return the start of an hour for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|String|Number} date - the original date
 * @returns {Date} the start of an hour
 *
 * @example
 * // The start of an hour for 2 September 2014 11:55:00:
 * var result = startOfHour(new Date(2014, 8, 2, 11, 55))
 * //=> Tue Sep 02 2014 11:00:00
 */
function startOfHour(dirtyDate){
var date=parse(dirtyDate);
date.setMinutes(0,0,0);
return date;
}

module.exports=startOfHour;


/***/},

/***/"fcb3":
/***/function fcb3(module,exports,__webpack_require__){

var addMonths=__webpack_require__("6665");

/**
 * @category Year Helpers
 * @summary Add the specified number of years to the given date.
 *
 * @description
 * Add the specified number of years to the given date.
 *
 * @param {Date|String|Number} date - the date to be changed
 * @param {Number} amount - the amount of years to be added
 * @returns {Date} the new date with the years added
 *
 * @example
 * // Add 5 years to 1 September 2014:
 * var result = addYears(new Date(2014, 8, 1), 5)
 * //=> Sun Sep 01 2019 00:00:00
 */
function addYears(dirtyDate,dirtyAmount){
var amount=Number(dirtyAmount);
return addMonths(dirtyDate,amount*12);
}

module.exports=addYears;


/***/},

/***/"fd2d":
/***/function fd2d(module,exports,__webpack_require__){

var buildDistanceInWordsLocale=__webpack_require__("1847");
var buildFormatLocale=__webpack_require__("3bec");

/**
 * @category Locales
 * @summary Spanish locale.
 * @author Juan Angosto [@juanangosto]{@link https://github.com/juanangosto}
 * @author Guillermo Grau [@guigrpa]{@link https://github.com/guigrpa}
 * @author Fernando Agüero [@fjaguero]{@link https://github.com/fjaguero}
 */
module.exports={
distanceInWords:buildDistanceInWordsLocale(),
format:buildFormatLocale()};



/***/},

/***/"fd39":
/***/function fd39(module,exports,__webpack_require__){

var startOfDay=__webpack_require__("0978");

/**
 * @category Day Helpers
 * @summary Are the given dates in the same day?
 *
 * @description
 * Are the given dates in the same day?
 *
 * @param {Date|String|Number} dateLeft - the first date to check
 * @param {Date|String|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same day
 *
 * @example
 * // Are 4 September 06:00:00 and 4 September 18:00:00 in the same day?
 * var result = isSameDay(
 *   new Date(2014, 8, 4, 6, 0),
 *   new Date(2014, 8, 4, 18, 0)
 * )
 * //=> true
 */
function isSameDay(dirtyDateLeft,dirtyDateRight){
var dateLeftStartOfDay=startOfDay(dirtyDateLeft);
var dateRightStartOfDay=startOfDay(dirtyDateRight);

return dateLeftStartOfDay.getTime()===dateRightStartOfDay.getTime();
}

module.exports=isSameDay;


/***/},

/***/"fdef":
/***/function fdef(module,exports){

module.exports="\t\n\x0B\f\r \xA0\u1680\u180E\u2000\u2001\u2002\u2003"+
"\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF";


/***/}

/******/});


/***/},

/***/"./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.css":
/*!*****************************************************************************!*\
  !*** ./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.css ***!
  \*****************************************************************************/
/*! no static exports found */
/***/function node_modulesVueMjDaterangepickerDistVueMjDaterangepickerCss(module,exports,__webpack_require__){


var content=__webpack_require__(/*! !../../css-loader??ref--6-1!../../postcss-loader/src??ref--6-2!./vue-mj-daterangepicker.css */"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.css");

if(typeof content==='string')content=[[module.i,content,'']];

var transform;



var options={"hmr":true};

options.transform=transform;
options.insertInto=undefined;

var update=__webpack_require__(/*! ../../style-loader/lib/addStyles.js */"./node_modules/style-loader/lib/addStyles.js")(content,options);

if(content.locals)module.exports=content.locals;

/***/},

/***/"./node_modules/vue-router/dist/vue-router.esm.js":
/*!********************************************************!*\
  !*** ./node_modules/vue-router/dist/vue-router.esm.js ***!
  \********************************************************/
/*! exports provided: default */
/***/function node_modulesVueRouterDistVueRouterEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/*!
  * vue-router v3.5.1
  * (c) 2021 Evan You
  * @license MIT
  */
/*  */

function assert(condition,message){
if(!condition){
throw new Error("[vue-router] "+message);
}
}

function warn(condition,message){
if(!condition){
typeof console!=='undefined'&&console.warn("[vue-router] "+message);
}
}

function extend(a,b){
for(var key in b){
a[key]=b[key];
}
return a;
}

/*  */

var encodeReserveRE=/[!'()*]/g;
var encodeReserveReplacer=function encodeReserveReplacer(c){return '%'+c.charCodeAt(0).toString(16);};
var commaRE=/%2C/g;

// fixed encodeURIComponent which is more conformant to RFC3986:
// - escapes [!'()*]
// - preserve commas
var encode=function encode(str){return encodeURIComponent(str).
replace(encodeReserveRE,encodeReserveReplacer).
replace(commaRE,',');};

function decode(str){
try{
return decodeURIComponent(str);
}catch(err){
{
warn(false,"Error decoding \""+str+"\". Leaving it intact.");
}
}
return str;
}

function resolveQuery(
query,
extraQuery,
_parseQuery)
{
if(extraQuery===void 0)extraQuery={};

var parse=_parseQuery||parseQuery;
var parsedQuery;
try{
parsedQuery=parse(query||'');
}catch(e){
warn(false,e.message);
parsedQuery={};
}
for(var key in extraQuery){
var value=extraQuery[key];
parsedQuery[key]=Array.isArray(value)?
value.map(castQueryParamValue):
castQueryParamValue(value);
}
return parsedQuery;
}

var castQueryParamValue=function castQueryParamValue(value){return value==null||typeof value==='object'?value:String(value);};

function parseQuery(query){
var res={};

query=query.trim().replace(/^(\?|#|&)/,'');

if(!query){
return res;
}

query.split('&').forEach(function(param){
var parts=param.replace(/\+/g,' ').split('=');
var key=decode(parts.shift());
var val=parts.length>0?decode(parts.join('=')):null;

if(res[key]===undefined){
res[key]=val;
}else if(Array.isArray(res[key])){
res[key].push(val);
}else {
res[key]=[res[key],val];
}
});

return res;
}

function stringifyQuery(obj){
var res=obj?
Object.keys(obj).
map(function(key){
var val=obj[key];

if(val===undefined){
return '';
}

if(val===null){
return encode(key);
}

if(Array.isArray(val)){
var result=[];
val.forEach(function(val2){
if(val2===undefined){
return;
}
if(val2===null){
result.push(encode(key));
}else {
result.push(encode(key)+'='+encode(val2));
}
});
return result.join('&');
}

return encode(key)+'='+encode(val);
}).
filter(function(x){return x.length>0;}).
join('&'):
null;
return res?"?"+res:'';
}

/*  */

var trailingSlashRE=/\/?$/;

function createRoute(
record,
location,
redirectedFrom,
router)
{
var stringifyQuery=router&&router.options.stringifyQuery;

var query=location.query||{};
try{
query=clone(query);
}catch(e){}

var route={
name:location.name||record&&record.name,
meta:record&&record.meta||{},
path:location.path||'/',
hash:location.hash||'',
query:query,
params:location.params||{},
fullPath:getFullPath(location,stringifyQuery),
matched:record?formatMatch(record):[]};

if(redirectedFrom){
route.redirectedFrom=getFullPath(redirectedFrom,stringifyQuery);
}
return Object.freeze(route);
}

function clone(value){
if(Array.isArray(value)){
return value.map(clone);
}else if(value&&typeof value==='object'){
var res={};
for(var key in value){
res[key]=clone(value[key]);
}
return res;
}else {
return value;
}
}

// the starting route that represents the initial state
var START=createRoute(null,{
path:'/'});


function formatMatch(record){
var res=[];
while(record){
res.unshift(record);
record=record.parent;
}
return res;
}

function getFullPath(
ref,
_stringifyQuery)
{
var path=ref.path;
var query=ref.query;if(query===void 0)query={};
var hash=ref.hash;if(hash===void 0)hash='';

var stringify=_stringifyQuery||stringifyQuery;
return (path||'/')+stringify(query)+hash;
}

function isSameRoute(a,b,onlyPath){
if(b===START){
return a===b;
}else if(!b){
return false;
}else if(a.path&&b.path){
return a.path.replace(trailingSlashRE,'')===b.path.replace(trailingSlashRE,'')&&(onlyPath||
a.hash===b.hash&&
isObjectEqual(a.query,b.query));
}else if(a.name&&b.name){
return(
a.name===b.name&&(
onlyPath||
a.hash===b.hash&&
isObjectEqual(a.query,b.query)&&
isObjectEqual(a.params,b.params)));


}else {
return false;
}
}

function isObjectEqual(a,b){
if(a===void 0)a={};
if(b===void 0)b={};

// handle null value #1566
if(!a||!b){return a===b;}
var aKeys=Object.keys(a).sort();
var bKeys=Object.keys(b).sort();
if(aKeys.length!==bKeys.length){
return false;
}
return aKeys.every(function(key,i){
var aVal=a[key];
var bKey=bKeys[i];
if(bKey!==key){return false;}
var bVal=b[key];
// query values can be null and undefined
if(aVal==null||bVal==null){return aVal===bVal;}
// check nested equality
if(typeof aVal==='object'&&typeof bVal==='object'){
return isObjectEqual(aVal,bVal);
}
return String(aVal)===String(bVal);
});
}

function isIncludedRoute(current,target){
return(
current.path.replace(trailingSlashRE,'/').indexOf(
target.path.replace(trailingSlashRE,'/'))===
0&&(
!target.hash||current.hash===target.hash)&&
queryIncludes(current.query,target.query));

}

function queryIncludes(current,target){
for(var key in target){
if(!(key in current)){
return false;
}
}
return true;
}

function handleRouteEntered(route){
for(var i=0;i<route.matched.length;i++){
var record=route.matched[i];
for(var name in record.instances){
var instance=record.instances[name];
var cbs=record.enteredCbs[name];
if(!instance||!cbs){continue;}
delete record.enteredCbs[name];
for(var i$1=0;i$1<cbs.length;i$1++){
if(!instance._isBeingDestroyed){cbs[i$1](instance);}
}
}
}
}

var View={
name:'RouterView',
functional:true,
props:{
name:{
type:String,
default:'default'}},


render:function render(_,ref){
var props=ref.props;
var children=ref.children;
var parent=ref.parent;
var data=ref.data;

// used by devtools to display a router-view badge
data.routerView=true;

// directly use parent context's createElement() function
// so that components rendered by router-view can resolve named slots
var h=parent.$createElement;
var name=props.name;
var route=parent.$route;
var cache=parent._routerViewCache||(parent._routerViewCache={});

// determine current view depth, also check to see if the tree
// has been toggled inactive but kept-alive.
var depth=0;
var inactive=false;
while(parent&&parent._routerRoot!==parent){
var vnodeData=parent.$vnode?parent.$vnode.data:{};
if(vnodeData.routerView){
depth++;
}
if(vnodeData.keepAlive&&parent._directInactive&&parent._inactive){
inactive=true;
}
parent=parent.$parent;
}
data.routerViewDepth=depth;

// render previous view if the tree is inactive and kept-alive
if(inactive){
var cachedData=cache[name];
var cachedComponent=cachedData&&cachedData.component;
if(cachedComponent){
// #2301
// pass props
if(cachedData.configProps){
fillPropsinData(cachedComponent,data,cachedData.route,cachedData.configProps);
}
return h(cachedComponent,data,children);
}else {
// render previous empty view
return h();
}
}

var matched=route.matched[depth];
var component=matched&&matched.components[name];

// render empty node if no matched route or no config component
if(!matched||!component){
cache[name]=null;
return h();
}

// cache component
cache[name]={component:component};

// attach instance registration hook
// this will be called in the instance's injected lifecycle hooks
data.registerRouteInstance=function(vm,val){
// val could be undefined for unregistration
var current=matched.instances[name];
if(
val&&current!==vm||
!val&&current===vm)
{
matched.instances[name]=val;
}
}

// also register instance in prepatch hook
// in case the same component instance is reused across different routes
;(data.hook||(data.hook={})).prepatch=function(_,vnode){
matched.instances[name]=vnode.componentInstance;
};

// register instance in init hook
// in case kept-alive component be actived when routes changed
data.hook.init=function(vnode){
if(vnode.data.keepAlive&&
vnode.componentInstance&&
vnode.componentInstance!==matched.instances[name])
{
matched.instances[name]=vnode.componentInstance;
}

// if the route transition has already been confirmed then we weren't
// able to call the cbs during confirmation as the component was not
// registered yet, so we call it here.
handleRouteEntered(route);
};

var configProps=matched.props&&matched.props[name];
// save route and configProps in cache
if(configProps){
extend(cache[name],{
route:route,
configProps:configProps});

fillPropsinData(component,data,route,configProps);
}

return h(component,data,children);
}};


function fillPropsinData(component,data,route,configProps){
// resolve props
var propsToPass=data.props=resolveProps(route,configProps);
if(propsToPass){
// clone to prevent mutation
propsToPass=data.props=extend({},propsToPass);
// pass non-declared props as attrs
var attrs=data.attrs=data.attrs||{};
for(var key in propsToPass){
if(!component.props||!(key in component.props)){
attrs[key]=propsToPass[key];
delete propsToPass[key];
}
}
}
}

function resolveProps(route,config){
switch(typeof config){
case'undefined':
return;
case'object':
return config;
case'function':
return config(route);
case'boolean':
return config?route.params:undefined;
default:
{
warn(
false,
"props in \""+route.path+"\" is a "+typeof config+", "+
"expecting an object, function or boolean.");

}}

}

/*  */

function resolvePath(
relative,
base,
append)
{
var firstChar=relative.charAt(0);
if(firstChar==='/'){
return relative;
}

if(firstChar==='?'||firstChar==='#'){
return base+relative;
}

var stack=base.split('/');

// remove trailing segment if:
// - not appending
// - appending to trailing slash (last segment is empty)
if(!append||!stack[stack.length-1]){
stack.pop();
}

// resolve relative path
var segments=relative.replace(/^\//,'').split('/');
for(var i=0;i<segments.length;i++){
var segment=segments[i];
if(segment==='..'){
stack.pop();
}else if(segment!=='.'){
stack.push(segment);
}
}

// ensure leading slash
if(stack[0]!==''){
stack.unshift('');
}

return stack.join('/');
}

function parsePath(path){
var hash='';
var query='';

var hashIndex=path.indexOf('#');
if(hashIndex>=0){
hash=path.slice(hashIndex);
path=path.slice(0,hashIndex);
}

var queryIndex=path.indexOf('?');
if(queryIndex>=0){
query=path.slice(queryIndex+1);
path=path.slice(0,queryIndex);
}

return {
path:path,
query:query,
hash:hash};

}

function cleanPath(path){
return path.replace(/\/\//g,'/');
}

var isarray=Array.isArray||function(arr){
return Object.prototype.toString.call(arr)=='[object Array]';
};

/**
 * Expose `pathToRegexp`.
 */
var pathToRegexp_1=pathToRegexp;
var parse_1=parse;
var compile_1=compile;
var tokensToFunction_1=tokensToFunction;
var tokensToRegExp_1=tokensToRegExp;

/**
 * The main path matching regexp utility.
 *
 * @type {RegExp}
 */
var PATH_REGEXP=new RegExp([
// Match escaped characters that would otherwise appear in future matches.
// This allows the user to escape special characters that won't transform.
'(\\\\.)',
// Match Express-style parameters and un-named parameters with a prefix
// and optional suffixes. Matches appear as:
//
// "/:test(\\d+)?" => ["/", "test", "\d+", undefined, "?", undefined]
// "/route(\\d+)"  => [undefined, undefined, undefined, "\d+", undefined, undefined]
// "/*"            => ["/", undefined, undefined, undefined, undefined, "*"]
'([\\/.])?(?:(?:\\:(\\w+)(?:\\(((?:\\\\.|[^\\\\()])+)\\))?|\\(((?:\\\\.|[^\\\\()])+)\\))([+*?])?|(\\*))'].
join('|'),'g');

/**
 * Parse a string for the raw tokens.
 *
 * @param  {string}  str
 * @param  {Object=} options
 * @return {!Array}
 */
function parse(str,options){
var tokens=[];
var key=0;
var index=0;
var path='';
var defaultDelimiter=options&&options.delimiter||'/';
var res;

while((res=PATH_REGEXP.exec(str))!=null){
var m=res[0];
var escaped=res[1];
var offset=res.index;
path+=str.slice(index,offset);
index=offset+m.length;

// Ignore already escaped sequences.
if(escaped){
path+=escaped[1];
continue;
}

var next=str[index];
var prefix=res[2];
var name=res[3];
var capture=res[4];
var group=res[5];
var modifier=res[6];
var asterisk=res[7];

// Push the current path onto the tokens.
if(path){
tokens.push(path);
path='';
}

var partial=prefix!=null&&next!=null&&next!==prefix;
var repeat=modifier==='+'||modifier==='*';
var optional=modifier==='?'||modifier==='*';
var delimiter=res[2]||defaultDelimiter;
var pattern=capture||group;

tokens.push({
name:name||key++,
prefix:prefix||'',
delimiter:delimiter,
optional:optional,
repeat:repeat,
partial:partial,
asterisk:!!asterisk,
pattern:pattern?escapeGroup(pattern):asterisk?'.*':'[^'+escapeString(delimiter)+']+?'});

}

// Match any characters still remaining.
if(index<str.length){
path+=str.substr(index);
}

// If the path exists, push it onto the end.
if(path){
tokens.push(path);
}

return tokens;
}

/**
 * Compile a string to a template function for the path.
 *
 * @param  {string}             str
 * @param  {Object=}            options
 * @return {!function(Object=, Object=)}
 */
function compile(str,options){
return tokensToFunction(parse(str,options),options);
}

/**
 * Prettier encoding of URI path segments.
 *
 * @param  {string}
 * @return {string}
 */
function encodeURIComponentPretty(str){
return encodeURI(str).replace(/[\/?#]/g,function(c){
return '%'+c.charCodeAt(0).toString(16).toUpperCase();
});
}

/**
 * Encode the asterisk parameter. Similar to `pretty`, but allows slashes.
 *
 * @param  {string}
 * @return {string}
 */
function encodeAsterisk(str){
return encodeURI(str).replace(/[?#]/g,function(c){
return '%'+c.charCodeAt(0).toString(16).toUpperCase();
});
}

/**
 * Expose a method for transforming tokens into the path function.
 */
function tokensToFunction(tokens,options){
// Compile all the tokens into regexps.
var matches=new Array(tokens.length);

// Compile all the patterns before compilation.
for(var i=0;i<tokens.length;i++){
if(typeof tokens[i]==='object'){
matches[i]=new RegExp('^(?:'+tokens[i].pattern+')$',flags(options));
}
}

return function(obj,opts){
var path='';
var data=obj||{};
var options=opts||{};
var encode=options.pretty?encodeURIComponentPretty:encodeURIComponent;

for(var i=0;i<tokens.length;i++){
var token=tokens[i];

if(typeof token==='string'){
path+=token;

continue;
}

var value=data[token.name];
var segment;

if(value==null){
if(token.optional){
// Prepend partial segment prefixes.
if(token.partial){
path+=token.prefix;
}

continue;
}else {
throw new TypeError('Expected "'+token.name+'" to be defined');
}
}

if(isarray(value)){
if(!token.repeat){
throw new TypeError('Expected "'+token.name+'" to not repeat, but received `'+JSON.stringify(value)+'`');
}

if(value.length===0){
if(token.optional){
continue;
}else {
throw new TypeError('Expected "'+token.name+'" to not be empty');
}
}

for(var j=0;j<value.length;j++){
segment=encode(value[j]);

if(!matches[i].test(segment)){
throw new TypeError('Expected all "'+token.name+'" to match "'+token.pattern+'", but received `'+JSON.stringify(segment)+'`');
}

path+=(j===0?token.prefix:token.delimiter)+segment;
}

continue;
}

segment=token.asterisk?encodeAsterisk(value):encode(value);

if(!matches[i].test(segment)){
throw new TypeError('Expected "'+token.name+'" to match "'+token.pattern+'", but received "'+segment+'"');
}

path+=token.prefix+segment;
}

return path;
};
}

/**
 * Escape a regular expression string.
 *
 * @param  {string} str
 * @return {string}
 */
function escapeString(str){
return str.replace(/([.+*?=^!:${}()[\]|\/\\])/g,'\\$1');
}

/**
 * Escape the capturing group by escaping special characters and meaning.
 *
 * @param  {string} group
 * @return {string}
 */
function escapeGroup(group){
return group.replace(/([=!:$\/()])/g,'\\$1');
}

/**
 * Attach the keys as a property of the regexp.
 *
 * @param  {!RegExp} re
 * @param  {Array}   keys
 * @return {!RegExp}
 */
function attachKeys(re,keys){
re.keys=keys;
return re;
}

/**
 * Get the flags for a regexp from the options.
 *
 * @param  {Object} options
 * @return {string}
 */
function flags(options){
return options&&options.sensitive?'':'i';
}

/**
 * Pull out keys from a regexp.
 *
 * @param  {!RegExp} path
 * @param  {!Array}  keys
 * @return {!RegExp}
 */
function regexpToRegexp(path,keys){
// Use a negative lookahead to match only capturing groups.
var groups=path.source.match(/\((?!\?)/g);

if(groups){
for(var i=0;i<groups.length;i++){
keys.push({
name:i,
prefix:null,
delimiter:null,
optional:false,
repeat:false,
partial:false,
asterisk:false,
pattern:null});

}
}

return attachKeys(path,keys);
}

/**
 * Transform an array into a regexp.
 *
 * @param  {!Array}  path
 * @param  {Array}   keys
 * @param  {!Object} options
 * @return {!RegExp}
 */
function arrayToRegexp(path,keys,options){
var parts=[];

for(var i=0;i<path.length;i++){
parts.push(pathToRegexp(path[i],keys,options).source);
}

var regexp=new RegExp('(?:'+parts.join('|')+')',flags(options));

return attachKeys(regexp,keys);
}

/**
 * Create a path regexp from string input.
 *
 * @param  {string}  path
 * @param  {!Array}  keys
 * @param  {!Object} options
 * @return {!RegExp}
 */
function stringToRegexp(path,keys,options){
return tokensToRegExp(parse(path,options),keys,options);
}

/**
 * Expose a function for taking tokens and returning a RegExp.
 *
 * @param  {!Array}          tokens
 * @param  {(Array|Object)=} keys
 * @param  {Object=}         options
 * @return {!RegExp}
 */
function tokensToRegExp(tokens,keys,options){
if(!isarray(keys)){
options=/** @type {!Object} */keys||options;
keys=[];
}

options=options||{};

var strict=options.strict;
var end=options.end!==false;
var route='';

// Iterate over the tokens and create our regexp string.
for(var i=0;i<tokens.length;i++){
var token=tokens[i];

if(typeof token==='string'){
route+=escapeString(token);
}else {
var prefix=escapeString(token.prefix);
var capture='(?:'+token.pattern+')';

keys.push(token);

if(token.repeat){
capture+='(?:'+prefix+capture+')*';
}

if(token.optional){
if(!token.partial){
capture='(?:'+prefix+'('+capture+'))?';
}else {
capture=prefix+'('+capture+')?';
}
}else {
capture=prefix+'('+capture+')';
}

route+=capture;
}
}

var delimiter=escapeString(options.delimiter||'/');
var endsWithDelimiter=route.slice(-delimiter.length)===delimiter;

// In non-strict mode we allow a slash at the end of match. If the path to
// match already ends with a slash, we remove it for consistency. The slash
// is valid at the end of a path match, not in the middle. This is important
// in non-ending mode, where "/test/" shouldn't match "/test//route".
if(!strict){
route=(endsWithDelimiter?route.slice(0,-delimiter.length):route)+'(?:'+delimiter+'(?=$))?';
}

if(end){
route+='$';
}else {
// In non-ending mode, we need the capturing groups to match as much as
// possible by using a positive lookahead to the end or next path segment.
route+=strict&&endsWithDelimiter?'':'(?='+delimiter+'|$)';
}

return attachKeys(new RegExp('^'+route,flags(options)),keys);
}

/**
 * Normalize the given path string, returning a regular expression.
 *
 * An empty array can be passed in for the keys, which will hold the
 * placeholder key descriptions. For example, using `/user/:id`, `keys` will
 * contain `[{ name: 'id', delimiter: '/', optional: false, repeat: false }]`.
 *
 * @param  {(string|RegExp|Array)} path
 * @param  {(Array|Object)=}       keys
 * @param  {Object=}               options
 * @return {!RegExp}
 */
function pathToRegexp(path,keys,options){
if(!isarray(keys)){
options=/** @type {!Object} */keys||options;
keys=[];
}

options=options||{};

if(path instanceof RegExp){
return regexpToRegexp(path,/** @type {!Array} */keys);
}

if(isarray(path)){
return arrayToRegexp(/** @type {!Array} */path,/** @type {!Array} */keys,options);
}

return stringToRegexp(/** @type {string} */path,/** @type {!Array} */keys,options);
}
pathToRegexp_1.parse=parse_1;
pathToRegexp_1.compile=compile_1;
pathToRegexp_1.tokensToFunction=tokensToFunction_1;
pathToRegexp_1.tokensToRegExp=tokensToRegExp_1;

/*  */

// $flow-disable-line
var regexpCompileCache=Object.create(null);

function fillParams(
path,
params,
routeMsg)
{
params=params||{};
try{
var filler=
regexpCompileCache[path]||(
regexpCompileCache[path]=pathToRegexp_1.compile(path));

// Fix #2505 resolving asterisk routes { name: 'not-found', params: { pathMatch: '/not-found' }}
// and fix #3106 so that you can work with location descriptor object having params.pathMatch equal to empty string
if(typeof params.pathMatch==='string'){params[0]=params.pathMatch;}

return filler(params,{pretty:true});
}catch(e){
{
// Fix #3072 no warn if `pathMatch` is string
warn(typeof params.pathMatch==='string',"missing param for "+routeMsg+": "+e.message);
}
return '';
}finally{
// delete the 0 if it was added
delete params[0];
}
}

/*  */

function normalizeLocation(
raw,
current,
append,
router)
{
var next=typeof raw==='string'?{path:raw}:raw;
// named target
if(next._normalized){
return next;
}else if(next.name){
next=extend({},raw);
var params=next.params;
if(params&&typeof params==='object'){
next.params=extend({},params);
}
return next;
}

// relative params
if(!next.path&&next.params&&current){
next=extend({},next);
next._normalized=true;
var params$1=extend(extend({},current.params),next.params);
if(current.name){
next.name=current.name;
next.params=params$1;
}else if(current.matched.length){
var rawPath=current.matched[current.matched.length-1].path;
next.path=fillParams(rawPath,params$1,"path "+current.path);
}else {
warn(false,"relative params navigation requires a current route.");
}
return next;
}

var parsedPath=parsePath(next.path||'');
var basePath=current&&current.path||'/';
var path=parsedPath.path?
resolvePath(parsedPath.path,basePath,append||next.append):
basePath;

var query=resolveQuery(
parsedPath.query,
next.query,
router&&router.options.parseQuery);


var hash=next.hash||parsedPath.hash;
if(hash&&hash.charAt(0)!=='#'){
hash="#"+hash;
}

return {
_normalized:true,
path:path,
query:query,
hash:hash};

}

/*  */

// work around weird flow bug
var toTypes=[String,Object];
var eventTypes=[String,Array];

var noop=function noop(){};

var warnedCustomSlot;
var warnedTagProp;
var warnedEventProp;

var Link={
name:'RouterLink',
props:{
to:{
type:toTypes,
required:true},

tag:{
type:String,
default:'a'},

custom:Boolean,
exact:Boolean,
exactPath:Boolean,
append:Boolean,
replace:Boolean,
activeClass:String,
exactActiveClass:String,
ariaCurrentValue:{
type:String,
default:'page'},

event:{
type:eventTypes,
default:'click'}},


render:function render(h){
var this$1=this;

var router=this.$router;
var current=this.$route;
var ref=router.resolve(
this.to,
current,
this.append);

var location=ref.location;
var route=ref.route;
var href=ref.href;

var classes={};
var globalActiveClass=router.options.linkActiveClass;
var globalExactActiveClass=router.options.linkExactActiveClass;
// Support global empty active class
var activeClassFallback=
globalActiveClass==null?'router-link-active':globalActiveClass;
var exactActiveClassFallback=
globalExactActiveClass==null?
'router-link-exact-active':
globalExactActiveClass;
var activeClass=
this.activeClass==null?activeClassFallback:this.activeClass;
var exactActiveClass=
this.exactActiveClass==null?
exactActiveClassFallback:
this.exactActiveClass;

var compareTarget=route.redirectedFrom?
createRoute(null,normalizeLocation(route.redirectedFrom),null,router):
route;

classes[exactActiveClass]=isSameRoute(current,compareTarget,this.exactPath);
classes[activeClass]=this.exact||this.exactPath?
classes[exactActiveClass]:
isIncludedRoute(current,compareTarget);

var ariaCurrentValue=classes[exactActiveClass]?this.ariaCurrentValue:null;

var handler=function handler(e){
if(guardEvent(e)){
if(this$1.replace){
router.replace(location,noop);
}else {
router.push(location,noop);
}
}
};

var on={click:guardEvent};
if(Array.isArray(this.event)){
this.event.forEach(function(e){
on[e]=handler;
});
}else {
on[this.event]=handler;
}

var data={class:classes};

var scopedSlot=
!this.$scopedSlots.$hasNormal&&
this.$scopedSlots.default&&
this.$scopedSlots.default({
href:href,
route:route,
navigate:handler,
isActive:classes[activeClass],
isExactActive:classes[exactActiveClass]});


if(scopedSlot){
if(!this.custom){
!warnedCustomSlot&&warn(false,'In Vue Router 4, the v-slot API will by default wrap its content with an <a> element. Use the custom prop to remove this warning:\n<router-link v-slot="{ navigate, href }" custom></router-link>\n');
warnedCustomSlot=true;
}
if(scopedSlot.length===1){
return scopedSlot[0];
}else if(scopedSlot.length>1||!scopedSlot.length){
{
warn(
false,
"<router-link> with to=\""+this.to+"\" is trying to use a scoped slot but it didn't provide exactly one child. Wrapping the content with a span element.");

}
return scopedSlot.length===0?h():h('span',{},scopedSlot);
}
}

{
if('tag'in this.$options.propsData&&!warnedTagProp){
warn(
false,
"<router-link>'s tag prop is deprecated and has been removed in Vue Router 4. Use the v-slot API to remove this warning: https://next.router.vuejs.org/guide/migration/#removal-of-event-and-tag-props-in-router-link.");

warnedTagProp=true;
}
if('event'in this.$options.propsData&&!warnedEventProp){
warn(
false,
"<router-link>'s event prop is deprecated and has been removed in Vue Router 4. Use the v-slot API to remove this warning: https://next.router.vuejs.org/guide/migration/#removal-of-event-and-tag-props-in-router-link.");

warnedEventProp=true;
}
}

if(this.tag==='a'){
data.on=on;
data.attrs={href:href,'aria-current':ariaCurrentValue};
}else {
// find the first <a> child and apply listener and href
var a=findAnchor(this.$slots.default);
if(a){
// in case the <a> is a static node
a.isStatic=false;
var aData=a.data=extend({},a.data);
aData.on=aData.on||{};
// transform existing events in both objects into arrays so we can push later
for(var event in aData.on){
var handler$1=aData.on[event];
if(event in on){
aData.on[event]=Array.isArray(handler$1)?handler$1:[handler$1];
}
}
// append new listeners for router-link
for(var event$1 in on){
if(event$1 in aData.on){
// on[event] is always a function
aData.on[event$1].push(on[event$1]);
}else {
aData.on[event$1]=handler;
}
}

var aAttrs=a.data.attrs=extend({},a.data.attrs);
aAttrs.href=href;
aAttrs['aria-current']=ariaCurrentValue;
}else {
// doesn't have <a> child, apply listener to self
data.on=on;
}
}

return h(this.tag,data,this.$slots.default);
}};


function guardEvent(e){
// don't redirect with control keys
if(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey){return;}
// don't redirect when preventDefault called
if(e.defaultPrevented){return;}
// don't redirect on right click
if(e.button!==undefined&&e.button!==0){return;}
// don't redirect if `target="_blank"`
if(e.currentTarget&&e.currentTarget.getAttribute){
var target=e.currentTarget.getAttribute('target');
if(/\b_blank\b/i.test(target)){return;}
}
// this may be a Weex event which doesn't have this method
if(e.preventDefault){
e.preventDefault();
}
return true;
}

function findAnchor(children){
if(children){
var child;
for(var i=0;i<children.length;i++){
child=children[i];
if(child.tag==='a'){
return child;
}
if(child.children&&(child=findAnchor(child.children))){
return child;
}
}
}
}

var _Vue;

function install(Vue){
if(install.installed&&_Vue===Vue){return;}
install.installed=true;

_Vue=Vue;

var isDef=function isDef(v){return v!==undefined;};

var registerInstance=function registerInstance(vm,callVal){
var i=vm.$options._parentVnode;
if(isDef(i)&&isDef(i=i.data)&&isDef(i=i.registerRouteInstance)){
i(vm,callVal);
}
};

Vue.mixin({
beforeCreate:function beforeCreate(){
if(isDef(this.$options.router)){
this._routerRoot=this;
this._router=this.$options.router;
this._router.init(this);
Vue.util.defineReactive(this,'_route',this._router.history.current);
}else {
this._routerRoot=this.$parent&&this.$parent._routerRoot||this;
}
registerInstance(this,this);
},
destroyed:function destroyed(){
registerInstance(this);
}});


Object.defineProperty(Vue.prototype,'$router',{
get:function get(){return this._routerRoot._router;}});


Object.defineProperty(Vue.prototype,'$route',{
get:function get(){return this._routerRoot._route;}});


Vue.component('RouterView',View);
Vue.component('RouterLink',Link);

var strats=Vue.config.optionMergeStrategies;
// use the same hook merging strategy for route hooks
strats.beforeRouteEnter=strats.beforeRouteLeave=strats.beforeRouteUpdate=strats.created;
}

/*  */

var inBrowser=typeof window!=='undefined';

/*  */

function createRouteMap(
routes,
oldPathList,
oldPathMap,
oldNameMap,
parentRoute)
{
// the path list is used to control path matching priority
var pathList=oldPathList||[];
// $flow-disable-line
var pathMap=oldPathMap||Object.create(null);
// $flow-disable-line
var nameMap=oldNameMap||Object.create(null);

routes.forEach(function(route){
addRouteRecord(pathList,pathMap,nameMap,route,parentRoute);
});

// ensure wildcard routes are always at the end
for(var i=0,l=pathList.length;i<l;i++){
if(pathList[i]==='*'){
pathList.push(pathList.splice(i,1)[0]);
l--;
i--;
}
}

{
// warn if routes do not include leading slashes
var found=pathList
// check for missing leading slash
.filter(function(path){return path&&path.charAt(0)!=='*'&&path.charAt(0)!=='/';});

if(found.length>0){
var pathNames=found.map(function(path){return "- "+path;}).join('\n');
warn(false,"Non-nested routes must include a leading slash character. Fix the following routes: \n"+pathNames);
}
}

return {
pathList:pathList,
pathMap:pathMap,
nameMap:nameMap};

}

function addRouteRecord(
pathList,
pathMap,
nameMap,
route,
parent,
matchAs)
{
var path=route.path;
var name=route.name;
{
assert(path!=null,"\"path\" is required in a route configuration.");
assert(
typeof route.component!=='string',
"route config \"component\" for path: "+String(
path||name)+
" cannot be a "+"string id. Use an actual component instead.");


warn(
// eslint-disable-next-line no-control-regex
!/[^\u0000-\u007F]+/.test(path),
"Route with path \""+path+"\" contains unencoded characters, make sure "+
"your path is correctly encoded before passing it to the router. Use "+
"encodeURI to encode static segments of your path.");

}

var pathToRegexpOptions=
route.pathToRegexpOptions||{};
var normalizedPath=normalizePath(path,parent,pathToRegexpOptions.strict);

if(typeof route.caseSensitive==='boolean'){
pathToRegexpOptions.sensitive=route.caseSensitive;
}

var record={
path:normalizedPath,
regex:compileRouteRegex(normalizedPath,pathToRegexpOptions),
components:route.components||{default:route.component},
alias:route.alias?
typeof route.alias==='string'?
[route.alias]:
route.alias:
[],
instances:{},
enteredCbs:{},
name:name,
parent:parent,
matchAs:matchAs,
redirect:route.redirect,
beforeEnter:route.beforeEnter,
meta:route.meta||{},
props:
route.props==null?
{}:
route.components?
route.props:
{default:route.props}};


if(route.children){
// Warn if route is named, does not redirect and has a default child route.
// If users navigate to this route by name, the default child will
// not be rendered (GH Issue #629)
{
if(
route.name&&
!route.redirect&&
route.children.some(function(child){return /^\/?$/.test(child.path);}))
{
warn(
false,
"Named Route '"+route.name+"' has a default child route. "+
"When navigating to this named route (:to=\"{name: '"+route.name+"'\"), "+
"the default child route will not be rendered. Remove the name from "+
"this route and use the name of the default child route for named "+
"links instead.");

}
}
route.children.forEach(function(child){
var childMatchAs=matchAs?
cleanPath(matchAs+"/"+child.path):
undefined;
addRouteRecord(pathList,pathMap,nameMap,child,record,childMatchAs);
});
}

if(!pathMap[record.path]){
pathList.push(record.path);
pathMap[record.path]=record;
}

if(route.alias!==undefined){
var aliases=Array.isArray(route.alias)?route.alias:[route.alias];
for(var i=0;i<aliases.length;++i){
var alias=aliases[i];
if(alias===path){
warn(
false,
"Found an alias with the same value as the path: \""+path+"\". You have to remove that alias. It will be ignored in development.");

// skip in dev to make it work
continue;
}

var aliasRoute={
path:alias,
children:route.children};

addRouteRecord(
pathList,
pathMap,
nameMap,
aliasRoute,
parent,
record.path||'/'// matchAs
);
}
}

if(name){
if(!nameMap[name]){
nameMap[name]=record;
}else if(!matchAs){
warn(
false,
"Duplicate named routes definition: "+
"{ name: \""+name+"\", path: \""+record.path+"\" }");

}
}
}

function compileRouteRegex(
path,
pathToRegexpOptions)
{
var regex=pathToRegexp_1(path,[],pathToRegexpOptions);
{
var keys=Object.create(null);
regex.keys.forEach(function(key){
warn(
!keys[key.name],
"Duplicate param keys in route with path: \""+path+"\"");

keys[key.name]=true;
});
}
return regex;
}

function normalizePath(
path,
parent,
strict)
{
if(!strict){path=path.replace(/\/$/,'');}
if(path[0]==='/'){return path;}
if(parent==null){return path;}
return cleanPath(parent.path+"/"+path);
}

/*  */



function createMatcher(
routes,
router)
{
var ref=createRouteMap(routes);
var pathList=ref.pathList;
var pathMap=ref.pathMap;
var nameMap=ref.nameMap;

function addRoutes(routes){
createRouteMap(routes,pathList,pathMap,nameMap);
}

function addRoute(parentOrRoute,route){
var parent=typeof parentOrRoute!=='object'?nameMap[parentOrRoute]:undefined;
// $flow-disable-line
createRouteMap([route||parentOrRoute],pathList,pathMap,nameMap,parent);

// add aliases of parent
if(parent){
createRouteMap(
// $flow-disable-line route is defined if parent is
parent.alias.map(function(alias){return {path:alias,children:[route]};}),
pathList,
pathMap,
nameMap,
parent);

}
}

function getRoutes(){
return pathList.map(function(path){return pathMap[path];});
}

function match(
raw,
currentRoute,
redirectedFrom)
{
var location=normalizeLocation(raw,currentRoute,false,router);
var name=location.name;

if(name){
var record=nameMap[name];
{
warn(record,"Route with name '"+name+"' does not exist");
}
if(!record){return _createRoute(null,location);}
var paramNames=record.regex.keys.
filter(function(key){return !key.optional;}).
map(function(key){return key.name;});

if(typeof location.params!=='object'){
location.params={};
}

if(currentRoute&&typeof currentRoute.params==='object'){
for(var key in currentRoute.params){
if(!(key in location.params)&&paramNames.indexOf(key)>-1){
location.params[key]=currentRoute.params[key];
}
}
}

location.path=fillParams(record.path,location.params,"named route \""+name+"\"");
return _createRoute(record,location,redirectedFrom);
}else if(location.path){
location.params={};
for(var i=0;i<pathList.length;i++){
var path=pathList[i];
var record$1=pathMap[path];
if(matchRoute(record$1.regex,location.path,location.params)){
return _createRoute(record$1,location,redirectedFrom);
}
}
}
// no match
return _createRoute(null,location);
}

function redirect(
record,
location)
{
var originalRedirect=record.redirect;
var redirect=typeof originalRedirect==='function'?
originalRedirect(createRoute(record,location,null,router)):
originalRedirect;

if(typeof redirect==='string'){
redirect={path:redirect};
}

if(!redirect||typeof redirect!=='object'){
{
warn(
false,"invalid redirect option: "+JSON.stringify(redirect));

}
return _createRoute(null,location);
}

var re=redirect;
var name=re.name;
var path=re.path;
var query=location.query;
var hash=location.hash;
var params=location.params;
query=re.hasOwnProperty('query')?re.query:query;
hash=re.hasOwnProperty('hash')?re.hash:hash;
params=re.hasOwnProperty('params')?re.params:params;

if(name){
// resolved named direct
var targetRecord=nameMap[name];
{
assert(targetRecord,"redirect failed: named route \""+name+"\" not found.");
}
return match({
_normalized:true,
name:name,
query:query,
hash:hash,
params:params},
undefined,location);
}else if(path){
// 1. resolve relative redirect
var rawPath=resolveRecordPath(path,record);
// 2. resolve params
var resolvedPath=fillParams(rawPath,params,"redirect route with path \""+rawPath+"\"");
// 3. rematch with existing query and hash
return match({
_normalized:true,
path:resolvedPath,
query:query,
hash:hash},
undefined,location);
}else {
{
warn(false,"invalid redirect option: "+JSON.stringify(redirect));
}
return _createRoute(null,location);
}
}

function alias(
record,
location,
matchAs)
{
var aliasedPath=fillParams(matchAs,location.params,"aliased route with path \""+matchAs+"\"");
var aliasedMatch=match({
_normalized:true,
path:aliasedPath});

if(aliasedMatch){
var matched=aliasedMatch.matched;
var aliasedRecord=matched[matched.length-1];
location.params=aliasedMatch.params;
return _createRoute(aliasedRecord,location);
}
return _createRoute(null,location);
}

function _createRoute(
record,
location,
redirectedFrom)
{
if(record&&record.redirect){
return redirect(record,redirectedFrom||location);
}
if(record&&record.matchAs){
return alias(record,location,record.matchAs);
}
return createRoute(record,location,redirectedFrom,router);
}

return {
match:match,
addRoute:addRoute,
getRoutes:getRoutes,
addRoutes:addRoutes};

}

function matchRoute(
regex,
path,
params)
{
var m=path.match(regex);

if(!m){
return false;
}else if(!params){
return true;
}

for(var i=1,len=m.length;i<len;++i){
var key=regex.keys[i-1];
if(key){
// Fix #1994: using * with props: true generates a param named 0
params[key.name||'pathMatch']=typeof m[i]==='string'?decode(m[i]):m[i];
}
}

return true;
}

function resolveRecordPath(path,record){
return resolvePath(path,record.parent?record.parent.path:'/',true);
}

/*  */

// use User Timing api (if present) for more accurate key precision
var Time=
inBrowser&&window.performance&&window.performance.now?
window.performance:
Date;

function genStateKey(){
return Time.now().toFixed(3);
}

var _key=genStateKey();

function getStateKey(){
return _key;
}

function setStateKey(key){
return _key=key;
}

/*  */

var positionStore=Object.create(null);

function setupScroll(){
// Prevent browser scroll behavior on History popstate
if('scrollRestoration'in window.history){
window.history.scrollRestoration='manual';
}
// Fix for #1585 for Firefox
// Fix for #2195 Add optional third attribute to workaround a bug in safari https://bugs.webkit.org/show_bug.cgi?id=182678
// Fix for #2774 Support for apps loaded from Windows file shares not mapped to network drives: replaced location.origin with
// window.location.protocol + '//' + window.location.host
// location.host contains the port and location.hostname doesn't
var protocolAndPath=window.location.protocol+'//'+window.location.host;
var absolutePath=window.location.href.replace(protocolAndPath,'');
// preserve existing history state as it could be overriden by the user
var stateCopy=extend({},window.history.state);
stateCopy.key=getStateKey();
window.history.replaceState(stateCopy,'',absolutePath);
window.addEventListener('popstate',handlePopState);
return function(){
window.removeEventListener('popstate',handlePopState);
};
}

function handleScroll(
router,
to,
from,
isPop)
{
if(!router.app){
return;
}

var behavior=router.options.scrollBehavior;
if(!behavior){
return;
}

{
assert(typeof behavior==='function',"scrollBehavior must be a function");
}

// wait until re-render finishes before scrolling
router.app.$nextTick(function(){
var position=getScrollPosition();
var shouldScroll=behavior.call(
router,
to,
from,
isPop?position:null);


if(!shouldScroll){
return;
}

if(typeof shouldScroll.then==='function'){
shouldScroll.
then(function(shouldScroll){
scrollToPosition(shouldScroll,position);
}).
catch(function(err){
{
assert(false,err.toString());
}
});
}else {
scrollToPosition(shouldScroll,position);
}
});
}

function saveScrollPosition(){
var key=getStateKey();
if(key){
positionStore[key]={
x:window.pageXOffset,
y:window.pageYOffset};

}
}

function handlePopState(e){
saveScrollPosition();
if(e.state&&e.state.key){
setStateKey(e.state.key);
}
}

function getScrollPosition(){
var key=getStateKey();
if(key){
return positionStore[key];
}
}

function getElementPosition(el,offset){
var docEl=document.documentElement;
var docRect=docEl.getBoundingClientRect();
var elRect=el.getBoundingClientRect();
return {
x:elRect.left-docRect.left-offset.x,
y:elRect.top-docRect.top-offset.y};

}

function isValidPosition(obj){
return isNumber(obj.x)||isNumber(obj.y);
}

function normalizePosition(obj){
return {
x:isNumber(obj.x)?obj.x:window.pageXOffset,
y:isNumber(obj.y)?obj.y:window.pageYOffset};

}

function normalizeOffset(obj){
return {
x:isNumber(obj.x)?obj.x:0,
y:isNumber(obj.y)?obj.y:0};

}

function isNumber(v){
return typeof v==='number';
}

var hashStartsWithNumberRE=/^#\d/;

function scrollToPosition(shouldScroll,position){
var isObject=typeof shouldScroll==='object';
if(isObject&&typeof shouldScroll.selector==='string'){
// getElementById would still fail if the selector contains a more complicated query like #main[data-attr]
// but at the same time, it doesn't make much sense to select an element with an id and an extra selector
var el=hashStartsWithNumberRE.test(shouldScroll.selector)// $flow-disable-line
?document.getElementById(shouldScroll.selector.slice(1))// $flow-disable-line
:document.querySelector(shouldScroll.selector);

if(el){
var offset=
shouldScroll.offset&&typeof shouldScroll.offset==='object'?
shouldScroll.offset:
{};
offset=normalizeOffset(offset);
position=getElementPosition(el,offset);
}else if(isValidPosition(shouldScroll)){
position=normalizePosition(shouldScroll);
}
}else if(isObject&&isValidPosition(shouldScroll)){
position=normalizePosition(shouldScroll);
}

if(position){
// $flow-disable-line
if('scrollBehavior'in document.documentElement.style){
window.scrollTo({
left:position.x,
top:position.y,
// $flow-disable-line
behavior:shouldScroll.behavior});

}else {
window.scrollTo(position.x,position.y);
}
}
}

/*  */

var supportsPushState=
inBrowser&&
function(){
var ua=window.navigator.userAgent;

if(
(ua.indexOf('Android 2.')!==-1||ua.indexOf('Android 4.0')!==-1)&&
ua.indexOf('Mobile Safari')!==-1&&
ua.indexOf('Chrome')===-1&&
ua.indexOf('Windows Phone')===-1)
{
return false;
}

return window.history&&typeof window.history.pushState==='function';
}();

function pushState(url,replace){
saveScrollPosition();
// try...catch the pushState call to get around Safari
// DOM Exception 18 where it limits to 100 pushState calls
var history=window.history;
try{
if(replace){
// preserve existing history state as it could be overriden by the user
var stateCopy=extend({},history.state);
stateCopy.key=getStateKey();
history.replaceState(stateCopy,'',url);
}else {
history.pushState({key:setStateKey(genStateKey())},'',url);
}
}catch(e){
window.location[replace?'replace':'assign'](url);
}
}

function replaceState(url){
pushState(url,true);
}

/*  */

function runQueue(queue,fn,cb){
var step=function step(index){
if(index>=queue.length){
cb();
}else {
if(queue[index]){
fn(queue[index],function(){
step(index+1);
});
}else {
step(index+1);
}
}
};
step(0);
}

// When changing thing, also edit router.d.ts
var NavigationFailureType={
redirected:2,
aborted:4,
cancelled:8,
duplicated:16};


function createNavigationRedirectedError(from,to){
return createRouterError(
from,
to,
NavigationFailureType.redirected,
"Redirected when going from \""+from.fullPath+"\" to \""+stringifyRoute(
to)+
"\" via a navigation guard.");

}

function createNavigationDuplicatedError(from,to){
var error=createRouterError(
from,
to,
NavigationFailureType.duplicated,
"Avoided redundant navigation to current location: \""+from.fullPath+"\".");

// backwards compatible with the first introduction of Errors
error.name='NavigationDuplicated';
return error;
}

function createNavigationCancelledError(from,to){
return createRouterError(
from,
to,
NavigationFailureType.cancelled,
"Navigation cancelled from \""+from.fullPath+"\" to \""+to.fullPath+"\" with a new navigation.");

}

function createNavigationAbortedError(from,to){
return createRouterError(
from,
to,
NavigationFailureType.aborted,
"Navigation aborted from \""+from.fullPath+"\" to \""+to.fullPath+"\" via a navigation guard.");

}

function createRouterError(from,to,type,message){
var error=new Error(message);
error._isRouter=true;
error.from=from;
error.to=to;
error.type=type;

return error;
}

var propertiesToLog=['params','query','hash'];

function stringifyRoute(to){
if(typeof to==='string'){return to;}
if('path'in to){return to.path;}
var location={};
propertiesToLog.forEach(function(key){
if(key in to){location[key]=to[key];}
});
return JSON.stringify(location,null,2);
}

function isError(err){
return Object.prototype.toString.call(err).indexOf('Error')>-1;
}

function isNavigationFailure(err,errorType){
return(
isError(err)&&
err._isRouter&&(
errorType==null||err.type===errorType));

}

/*  */

function resolveAsyncComponents(matched){
return function(to,from,next){
var hasAsync=false;
var pending=0;
var error=null;

flatMapComponents(matched,function(def,_,match,key){
// if it's a function and doesn't have cid attached,
// assume it's an async component resolve function.
// we are not using Vue's default async resolving mechanism because
// we want to halt the navigation until the incoming component has been
// resolved.
if(typeof def==='function'&&def.cid===undefined){
hasAsync=true;
pending++;

var resolve=once(function(resolvedDef){
if(isESModule(resolvedDef)){
resolvedDef=resolvedDef.default;
}
// save resolved on async factory in case it's used elsewhere
def.resolved=typeof resolvedDef==='function'?
resolvedDef:
_Vue.extend(resolvedDef);
match.components[key]=resolvedDef;
pending--;
if(pending<=0){
next();
}
});

var reject=once(function(reason){
var msg="Failed to resolve async component "+key+": "+reason;
warn(false,msg);
if(!error){
error=isError(reason)?
reason:
new Error(msg);
next(error);
}
});

var res;
try{
res=def(resolve,reject);
}catch(e){
reject(e);
}
if(res){
if(typeof res.then==='function'){
res.then(resolve,reject);
}else {
// new syntax in Vue 2.3
var comp=res.component;
if(comp&&typeof comp.then==='function'){
comp.then(resolve,reject);
}
}
}
}
});

if(!hasAsync){next();}
};
}

function flatMapComponents(
matched,
fn)
{
return flatten(matched.map(function(m){
return Object.keys(m.components).map(function(key){return fn(
m.components[key],
m.instances[key],
m,key);
});
}));
}

function flatten(arr){
return Array.prototype.concat.apply([],arr);
}

var hasSymbol=
typeof Symbol==='function'&&
typeof Symbol.toStringTag==='symbol';

function isESModule(obj){
return obj.__esModule||hasSymbol&&obj[Symbol.toStringTag]==='Module';
}

// in Webpack 2, require.ensure now also returns a Promise
// so the resolve/reject functions may get called an extra time
// if the user uses an arrow function shorthand that happens to
// return that Promise.
function once(fn){
var called=false;
return function(){
var args=[],len=arguments.length;
while(len--){args[len]=arguments[len];}

if(called){return;}
called=true;
return fn.apply(this,args);
};
}

/*  */

var History=function History(router,base){
this.router=router;
this.base=normalizeBase(base);
// start with a route object that stands for "nowhere"
this.current=START;
this.pending=null;
this.ready=false;
this.readyCbs=[];
this.readyErrorCbs=[];
this.errorCbs=[];
this.listeners=[];
};

History.prototype.listen=function listen(cb){
this.cb=cb;
};

History.prototype.onReady=function onReady(cb,errorCb){
if(this.ready){
cb();
}else {
this.readyCbs.push(cb);
if(errorCb){
this.readyErrorCbs.push(errorCb);
}
}
};

History.prototype.onError=function onError(errorCb){
this.errorCbs.push(errorCb);
};

History.prototype.transitionTo=function transitionTo(
location,
onComplete,
onAbort)
{
var this$1=this;

var route;
// catch redirect option https://github.com/vuejs/vue-router/issues/3201
try{
route=this.router.match(location,this.current);
}catch(e){
this.errorCbs.forEach(function(cb){
cb(e);
});
// Exception should still be thrown
throw e;
}
var prev=this.current;
this.confirmTransition(
route,
function(){
this$1.updateRoute(route);
onComplete&&onComplete(route);
this$1.ensureURL();
this$1.router.afterHooks.forEach(function(hook){
hook&&hook(route,prev);
});

// fire ready cbs once
if(!this$1.ready){
this$1.ready=true;
this$1.readyCbs.forEach(function(cb){
cb(route);
});
}
},
function(err){
if(onAbort){
onAbort(err);
}
if(err&&!this$1.ready){
// Initial redirection should not mark the history as ready yet
// because it's triggered by the redirection instead
// https://github.com/vuejs/vue-router/issues/3225
// https://github.com/vuejs/vue-router/issues/3331
if(!isNavigationFailure(err,NavigationFailureType.redirected)||prev!==START){
this$1.ready=true;
this$1.readyErrorCbs.forEach(function(cb){
cb(err);
});
}
}
});

};

History.prototype.confirmTransition=function confirmTransition(route,onComplete,onAbort){
var this$1=this;

var current=this.current;
this.pending=route;
var abort=function abort(err){
// changed after adding errors with
// https://github.com/vuejs/vue-router/pull/3047 before that change,
// redirect and aborted navigation would produce an err == null
if(!isNavigationFailure(err)&&isError(err)){
if(this$1.errorCbs.length){
this$1.errorCbs.forEach(function(cb){
cb(err);
});
}else {
warn(false,'uncaught error during route navigation:');
console.error(err);
}
}
onAbort&&onAbort(err);
};
var lastRouteIndex=route.matched.length-1;
var lastCurrentIndex=current.matched.length-1;
if(
isSameRoute(route,current)&&
// in the case the route map has been dynamically appended to
lastRouteIndex===lastCurrentIndex&&
route.matched[lastRouteIndex]===current.matched[lastCurrentIndex])
{
this.ensureURL();
return abort(createNavigationDuplicatedError(current,route));
}

var ref=resolveQueue(
this.current.matched,
route.matched);

var updated=ref.updated;
var deactivated=ref.deactivated;
var activated=ref.activated;

var queue=[].concat(
// in-component leave guards
extractLeaveGuards(deactivated),
// global before hooks
this.router.beforeHooks,
// in-component update hooks
extractUpdateHooks(updated),
// in-config enter guards
activated.map(function(m){return m.beforeEnter;}),
// async components
resolveAsyncComponents(activated));


var iterator=function iterator(hook,next){
if(this$1.pending!==route){
return abort(createNavigationCancelledError(current,route));
}
try{
hook(route,current,function(to){
if(to===false){
// next(false) -> abort navigation, ensure current URL
this$1.ensureURL(true);
abort(createNavigationAbortedError(current,route));
}else if(isError(to)){
this$1.ensureURL(true);
abort(to);
}else if(
typeof to==='string'||
typeof to==='object'&&(
typeof to.path==='string'||typeof to.name==='string'))
{
// next('/') or next({ path: '/' }) -> redirect
abort(createNavigationRedirectedError(current,route));
if(typeof to==='object'&&to.replace){
this$1.replace(to);
}else {
this$1.push(to);
}
}else {
// confirm transition and pass on the value
next(to);
}
});
}catch(e){
abort(e);
}
};

runQueue(queue,iterator,function(){
// wait until async components are resolved before
// extracting in-component enter guards
var enterGuards=extractEnterGuards(activated);
var queue=enterGuards.concat(this$1.router.resolveHooks);
runQueue(queue,iterator,function(){
if(this$1.pending!==route){
return abort(createNavigationCancelledError(current,route));
}
this$1.pending=null;
onComplete(route);
if(this$1.router.app){
this$1.router.app.$nextTick(function(){
handleRouteEntered(route);
});
}
});
});
};

History.prototype.updateRoute=function updateRoute(route){
this.current=route;
this.cb&&this.cb(route);
};

History.prototype.setupListeners=function setupListeners(){
// Default implementation is empty
};

History.prototype.teardown=function teardown(){
// clean up event listeners
// https://github.com/vuejs/vue-router/issues/2341
this.listeners.forEach(function(cleanupListener){
cleanupListener();
});
this.listeners=[];

// reset current history route
// https://github.com/vuejs/vue-router/issues/3294
this.current=START;
this.pending=null;
};

function normalizeBase(base){
if(!base){
if(inBrowser){
// respect <base> tag
var baseEl=document.querySelector('base');
base=baseEl&&baseEl.getAttribute('href')||'/';
// strip full URL origin
base=base.replace(/^https?:\/\/[^\/]+/,'');
}else {
base='/';
}
}
// make sure there's the starting slash
if(base.charAt(0)!=='/'){
base='/'+base;
}
// remove trailing slash
return base.replace(/\/$/,'');
}

function resolveQueue(
current,
next)
{
var i;
var max=Math.max(current.length,next.length);
for(i=0;i<max;i++){
if(current[i]!==next[i]){
break;
}
}
return {
updated:next.slice(0,i),
activated:next.slice(i),
deactivated:current.slice(i)};

}

function extractGuards(
records,
name,
bind,
reverse)
{
var guards=flatMapComponents(records,function(def,instance,match,key){
var guard=extractGuard(def,name);
if(guard){
return Array.isArray(guard)?
guard.map(function(guard){return bind(guard,instance,match,key);}):
bind(guard,instance,match,key);
}
});
return flatten(reverse?guards.reverse():guards);
}

function extractGuard(
def,
key)
{
if(typeof def!=='function'){
// extend now so that global mixins are applied.
def=_Vue.extend(def);
}
return def.options[key];
}

function extractLeaveGuards(deactivated){
return extractGuards(deactivated,'beforeRouteLeave',bindGuard,true);
}

function extractUpdateHooks(updated){
return extractGuards(updated,'beforeRouteUpdate',bindGuard);
}

function bindGuard(guard,instance){
if(instance){
return function boundRouteGuard(){
return guard.apply(instance,arguments);
};
}
}

function extractEnterGuards(
activated)
{
return extractGuards(
activated,
'beforeRouteEnter',
function(guard,_,match,key){
return bindEnterGuard(guard,match,key);
});

}

function bindEnterGuard(
guard,
match,
key)
{
return function routeEnterGuard(to,from,next){
return guard(to,from,function(cb){
if(typeof cb==='function'){
if(!match.enteredCbs[key]){
match.enteredCbs[key]=[];
}
match.enteredCbs[key].push(cb);
}
next(cb);
});
};
}

/*  */

var HTML5History=/*@__PURE__*/function(History){
function HTML5History(router,base){
History.call(this,router,base);

this._startLocation=getLocation(this.base);
}

if(History)HTML5History.__proto__=History;
HTML5History.prototype=Object.create(History&&History.prototype);
HTML5History.prototype.constructor=HTML5History;

HTML5History.prototype.setupListeners=function setupListeners(){
var this$1=this;

if(this.listeners.length>0){
return;
}

var router=this.router;
var expectScroll=router.options.scrollBehavior;
var supportsScroll=supportsPushState&&expectScroll;

if(supportsScroll){
this.listeners.push(setupScroll());
}

var handleRoutingEvent=function handleRoutingEvent(){
var current=this$1.current;

// Avoiding first `popstate` event dispatched in some browsers but first
// history route not updated since async guard at the same time.
var location=getLocation(this$1.base);
if(this$1.current===START&&location===this$1._startLocation){
return;
}

this$1.transitionTo(location,function(route){
if(supportsScroll){
handleScroll(router,route,current,true);
}
});
};
window.addEventListener('popstate',handleRoutingEvent);
this.listeners.push(function(){
window.removeEventListener('popstate',handleRoutingEvent);
});
};

HTML5History.prototype.go=function go(n){
window.history.go(n);
};

HTML5History.prototype.push=function push(location,onComplete,onAbort){
var this$1=this;

var ref=this;
var fromRoute=ref.current;
this.transitionTo(location,function(route){
pushState(cleanPath(this$1.base+route.fullPath));
handleScroll(this$1.router,route,fromRoute,false);
onComplete&&onComplete(route);
},onAbort);
};

HTML5History.prototype.replace=function replace(location,onComplete,onAbort){
var this$1=this;

var ref=this;
var fromRoute=ref.current;
this.transitionTo(location,function(route){
replaceState(cleanPath(this$1.base+route.fullPath));
handleScroll(this$1.router,route,fromRoute,false);
onComplete&&onComplete(route);
},onAbort);
};

HTML5History.prototype.ensureURL=function ensureURL(push){
if(getLocation(this.base)!==this.current.fullPath){
var current=cleanPath(this.base+this.current.fullPath);
push?pushState(current):replaceState(current);
}
};

HTML5History.prototype.getCurrentLocation=function getCurrentLocation(){
return getLocation(this.base);
};

return HTML5History;
}(History);

function getLocation(base){
var path=window.location.pathname;
if(base&&path.toLowerCase().indexOf(base.toLowerCase())===0){
path=path.slice(base.length);
}
return (path||'/')+window.location.search+window.location.hash;
}

/*  */

var HashHistory=/*@__PURE__*/function(History){
function HashHistory(router,base,fallback){
History.call(this,router,base);
// check history fallback deeplinking
if(fallback&&checkFallback(this.base)){
return;
}
ensureSlash();
}

if(History)HashHistory.__proto__=History;
HashHistory.prototype=Object.create(History&&History.prototype);
HashHistory.prototype.constructor=HashHistory;

// this is delayed until the app mounts
// to avoid the hashchange listener being fired too early
HashHistory.prototype.setupListeners=function setupListeners(){
var this$1=this;

if(this.listeners.length>0){
return;
}

var router=this.router;
var expectScroll=router.options.scrollBehavior;
var supportsScroll=supportsPushState&&expectScroll;

if(supportsScroll){
this.listeners.push(setupScroll());
}

var handleRoutingEvent=function handleRoutingEvent(){
var current=this$1.current;
if(!ensureSlash()){
return;
}
this$1.transitionTo(getHash(),function(route){
if(supportsScroll){
handleScroll(this$1.router,route,current,true);
}
if(!supportsPushState){
replaceHash(route.fullPath);
}
});
};
var eventType=supportsPushState?'popstate':'hashchange';
window.addEventListener(
eventType,
handleRoutingEvent);

this.listeners.push(function(){
window.removeEventListener(eventType,handleRoutingEvent);
});
};

HashHistory.prototype.push=function push(location,onComplete,onAbort){
var this$1=this;

var ref=this;
var fromRoute=ref.current;
this.transitionTo(
location,
function(route){
pushHash(route.fullPath);
handleScroll(this$1.router,route,fromRoute,false);
onComplete&&onComplete(route);
},
onAbort);

};

HashHistory.prototype.replace=function replace(location,onComplete,onAbort){
var this$1=this;

var ref=this;
var fromRoute=ref.current;
this.transitionTo(
location,
function(route){
replaceHash(route.fullPath);
handleScroll(this$1.router,route,fromRoute,false);
onComplete&&onComplete(route);
},
onAbort);

};

HashHistory.prototype.go=function go(n){
window.history.go(n);
};

HashHistory.prototype.ensureURL=function ensureURL(push){
var current=this.current.fullPath;
if(getHash()!==current){
push?pushHash(current):replaceHash(current);
}
};

HashHistory.prototype.getCurrentLocation=function getCurrentLocation(){
return getHash();
};

return HashHistory;
}(History);

function checkFallback(base){
var location=getLocation(base);
if(!/^\/#/.test(location)){
window.location.replace(cleanPath(base+'/#'+location));
return true;
}
}

function ensureSlash(){
var path=getHash();
if(path.charAt(0)==='/'){
return true;
}
replaceHash('/'+path);
return false;
}

function getHash(){
// We can't use window.location.hash here because it's not
// consistent across browsers - Firefox will pre-decode it!
var href=window.location.href;
var index=href.indexOf('#');
// empty path
if(index<0){return '';}

href=href.slice(index+1);

return href;
}

function getUrl(path){
var href=window.location.href;
var i=href.indexOf('#');
var base=i>=0?href.slice(0,i):href;
return base+"#"+path;
}

function pushHash(path){
if(supportsPushState){
pushState(getUrl(path));
}else {
window.location.hash=path;
}
}

function replaceHash(path){
if(supportsPushState){
replaceState(getUrl(path));
}else {
window.location.replace(getUrl(path));
}
}

/*  */

var AbstractHistory=/*@__PURE__*/function(History){
function AbstractHistory(router,base){
History.call(this,router,base);
this.stack=[];
this.index=-1;
}

if(History)AbstractHistory.__proto__=History;
AbstractHistory.prototype=Object.create(History&&History.prototype);
AbstractHistory.prototype.constructor=AbstractHistory;

AbstractHistory.prototype.push=function push(location,onComplete,onAbort){
var this$1=this;

this.transitionTo(
location,
function(route){
this$1.stack=this$1.stack.slice(0,this$1.index+1).concat(route);
this$1.index++;
onComplete&&onComplete(route);
},
onAbort);

};

AbstractHistory.prototype.replace=function replace(location,onComplete,onAbort){
var this$1=this;

this.transitionTo(
location,
function(route){
this$1.stack=this$1.stack.slice(0,this$1.index).concat(route);
onComplete&&onComplete(route);
},
onAbort);

};

AbstractHistory.prototype.go=function go(n){
var this$1=this;

var targetIndex=this.index+n;
if(targetIndex<0||targetIndex>=this.stack.length){
return;
}
var route=this.stack[targetIndex];
this.confirmTransition(
route,
function(){
var prev=this$1.current;
this$1.index=targetIndex;
this$1.updateRoute(route);
this$1.router.afterHooks.forEach(function(hook){
hook&&hook(route,prev);
});
},
function(err){
if(isNavigationFailure(err,NavigationFailureType.duplicated)){
this$1.index=targetIndex;
}
});

};

AbstractHistory.prototype.getCurrentLocation=function getCurrentLocation(){
var current=this.stack[this.stack.length-1];
return current?current.fullPath:'/';
};

AbstractHistory.prototype.ensureURL=function ensureURL(){
// noop
};

return AbstractHistory;
}(History);

/*  */

var VueRouter=function VueRouter(options){
if(options===void 0)options={};

this.app=null;
this.apps=[];
this.options=options;
this.beforeHooks=[];
this.resolveHooks=[];
this.afterHooks=[];
this.matcher=createMatcher(options.routes||[],this);

var mode=options.mode||'hash';
this.fallback=
mode==='history'&&!supportsPushState&&options.fallback!==false;
if(this.fallback){
mode='hash';
}
if(!inBrowser){
mode='abstract';
}
this.mode=mode;

switch(mode){
case'history':
this.history=new HTML5History(this,options.base);
break;
case'hash':
this.history=new HashHistory(this,options.base,this.fallback);
break;
case'abstract':
this.history=new AbstractHistory(this,options.base);
break;
default:
{
assert(false,"invalid mode: "+mode);
}}

};

var prototypeAccessors={currentRoute:{configurable:true}};

VueRouter.prototype.match=function match(raw,current,redirectedFrom){
return this.matcher.match(raw,current,redirectedFrom);
};

prototypeAccessors.currentRoute.get=function(){
return this.history&&this.history.current;
};

VueRouter.prototype.init=function init(app/* Vue component instance */){
var this$1=this;


assert(
install.installed,
"not installed. Make sure to call `Vue.use(VueRouter)` "+
"before creating root instance.");


this.apps.push(app);

// set up app destroyed handler
// https://github.com/vuejs/vue-router/issues/2639
app.$once('hook:destroyed',function(){
// clean out app from this.apps array once destroyed
var index=this$1.apps.indexOf(app);
if(index>-1){this$1.apps.splice(index,1);}
// ensure we still have a main app or null if no apps
// we do not release the router so it can be reused
if(this$1.app===app){this$1.app=this$1.apps[0]||null;}

if(!this$1.app){this$1.history.teardown();}
});

// main app previously initialized
// return as we don't need to set up new history listener
if(this.app){
return;
}

this.app=app;

var history=this.history;

if(history instanceof HTML5History||history instanceof HashHistory){
var handleInitialScroll=function handleInitialScroll(routeOrError){
var from=history.current;
var expectScroll=this$1.options.scrollBehavior;
var supportsScroll=supportsPushState&&expectScroll;

if(supportsScroll&&'fullPath'in routeOrError){
handleScroll(this$1,routeOrError,from,false);
}
};
var setupListeners=function setupListeners(routeOrError){
history.setupListeners();
handleInitialScroll(routeOrError);
};
history.transitionTo(
history.getCurrentLocation(),
setupListeners,
setupListeners);

}

history.listen(function(route){
this$1.apps.forEach(function(app){
app._route=route;
});
});
};

VueRouter.prototype.beforeEach=function beforeEach(fn){
return registerHook(this.beforeHooks,fn);
};

VueRouter.prototype.beforeResolve=function beforeResolve(fn){
return registerHook(this.resolveHooks,fn);
};

VueRouter.prototype.afterEach=function afterEach(fn){
return registerHook(this.afterHooks,fn);
};

VueRouter.prototype.onReady=function onReady(cb,errorCb){
this.history.onReady(cb,errorCb);
};

VueRouter.prototype.onError=function onError(errorCb){
this.history.onError(errorCb);
};

VueRouter.prototype.push=function push(location,onComplete,onAbort){
var this$1=this;

// $flow-disable-line
if(!onComplete&&!onAbort&&typeof Promise!=='undefined'){
return new Promise(function(resolve,reject){
this$1.history.push(location,resolve,reject);
});
}else {
this.history.push(location,onComplete,onAbort);
}
};

VueRouter.prototype.replace=function replace(location,onComplete,onAbort){
var this$1=this;

// $flow-disable-line
if(!onComplete&&!onAbort&&typeof Promise!=='undefined'){
return new Promise(function(resolve,reject){
this$1.history.replace(location,resolve,reject);
});
}else {
this.history.replace(location,onComplete,onAbort);
}
};

VueRouter.prototype.go=function go(n){
this.history.go(n);
};

VueRouter.prototype.back=function back(){
this.go(-1);
};

VueRouter.prototype.forward=function forward(){
this.go(1);
};

VueRouter.prototype.getMatchedComponents=function getMatchedComponents(to){
var route=to?
to.matched?
to:
this.resolve(to).route:
this.currentRoute;
if(!route){
return [];
}
return [].concat.apply(
[],
route.matched.map(function(m){
return Object.keys(m.components).map(function(key){
return m.components[key];
});
}));

};

VueRouter.prototype.resolve=function resolve(
to,
current,
append)
{
current=current||this.history.current;
var location=normalizeLocation(to,current,append,this);
var route=this.match(location,current);
var fullPath=route.redirectedFrom||route.fullPath;
var base=this.history.base;
var href=createHref(base,fullPath,this.mode);
return {
location:location,
route:route,
href:href,
// for backwards compat
normalizedTo:location,
resolved:route};

};

VueRouter.prototype.getRoutes=function getRoutes(){
return this.matcher.getRoutes();
};

VueRouter.prototype.addRoute=function addRoute(parentOrRoute,route){
this.matcher.addRoute(parentOrRoute,route);
if(this.history.current!==START){
this.history.transitionTo(this.history.getCurrentLocation());
}
};

VueRouter.prototype.addRoutes=function addRoutes(routes){
{
warn(false,'router.addRoutes() is deprecated and has been removed in Vue Router 4. Use router.addRoute() instead.');
}
this.matcher.addRoutes(routes);
if(this.history.current!==START){
this.history.transitionTo(this.history.getCurrentLocation());
}
};

Object.defineProperties(VueRouter.prototype,prototypeAccessors);

function registerHook(list,fn){
list.push(fn);
return function(){
var i=list.indexOf(fn);
if(i>-1){list.splice(i,1);}
};
}

function createHref(base,fullPath,mode){
var path=mode==='hash'?'#'+fullPath:fullPath;
return base?cleanPath(base+'/'+path):path;
}

VueRouter.install=install;
VueRouter.version='3.5.1';
VueRouter.isNavigationFailure=isNavigationFailure;
VueRouter.NavigationFailureType=NavigationFailureType;
VueRouter.START_LOCATION=START;

if(inBrowser&&window.Vue){
window.Vue.use(VueRouter);
}

/* harmony default export */__webpack_exports__["default"]=VueRouter;


/***/},

/***/"./node_modules/vue-select/dist/vue-select.css":
/*!*****************************************************!*\
  !*** ./node_modules/vue-select/dist/vue-select.css ***!
  \*****************************************************/
/*! no static exports found */
/***/function node_modulesVueSelectDistVueSelectCss(module,exports,__webpack_require__){


var content=__webpack_require__(/*! !../../css-loader??ref--6-1!../../postcss-loader/src??ref--6-2!./vue-select.css */"./node_modules/css-loader/index.js?!./node_modules/postcss-loader/src/index.js?!./node_modules/vue-select/dist/vue-select.css");

if(typeof content==='string')content=[[module.i,content,'']];

var transform;



var options={"hmr":true};

options.transform=transform;
options.insertInto=undefined;

var update=__webpack_require__(/*! ../../style-loader/lib/addStyles.js */"./node_modules/style-loader/lib/addStyles.js")(content,options);

if(content.locals)module.exports=content.locals;

/***/},

/***/"./node_modules/vue-select/dist/vue-select.js":
/*!****************************************************!*\
  !*** ./node_modules/vue-select/dist/vue-select.js ***!
  \****************************************************/
/*! no static exports found */
/***/function node_modulesVueSelectDistVueSelectJs(module,exports,__webpack_require__){

!function(t,e){module.exports=e();}("undefined"!=typeof self?self:this,function(){return function(t){var e={};function n(o){if(e[o])return e[o].exports;var i=e[o]={i:o,l:!1,exports:{}};return t[o].call(i.exports,i,i.exports,n),i.l=!0,i.exports;}return n.m=t,n.c=e,n.d=function(t,e,o){n.o(t,e)||Object.defineProperty(t,e,{enumerable:!0,get:o});},n.r=function(t){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0});},n.t=function(t,e){if(1&e&&(t=n(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var o=Object.create(null);if(n.r(o),Object.defineProperty(o,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var i in t){n.d(o,i,function(e){return t[e];}.bind(null,i));}return o;},n.n=function(t){var e=t&&t.__esModule?function(){return t.default;}:function(){return t;};return n.d(e,"a",e),e;},n.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e);},n.p="/",n(n.s=8);}([function(t,e,n){var o=n(4),i=n(5),s=n(6);t.exports=function(t){return o(t)||i(t)||s();};},function(t,e){function n(e){return "function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?t.exports=n=function n(t){return typeof t;}:t.exports=n=function n(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t;},n(e);}t.exports=n;},function(t,e,n){},function(t,e){t.exports=function(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t;};},function(t,e){t.exports=function(t){if(Array.isArray(t)){for(var e=0,n=new Array(t.length);e<t.length;e++){n[e]=t[e];}return n;}};},function(t,e){t.exports=function(t){if(Symbol.iterator in Object(t)||"[object Arguments]"===Object.prototype.toString.call(t))return Array.from(t);};},function(t,e){t.exports=function(){throw new TypeError("Invalid attempt to spread non-iterable instance");};},function(t,e,n){var o=n(2);n.n(o).a;},function(t,e,n){n.r(e);var o=n(0),i=n.n(o),s=n(1),r=n.n(s),a=n(3),l=n.n(a),c={props:{autoscroll:{type:Boolean,default:!0}},watch:{typeAheadPointer:function typeAheadPointer(){this.autoscroll&&this.maybeAdjustScroll();}},methods:{maybeAdjustScroll:function maybeAdjustScroll(){var t,e=(null===(t=this.$refs.dropdownMenu)||void 0===t?void 0:t.children[this.typeAheadPointer])||!1;if(e){var n=this.getDropdownViewport(),o=e.getBoundingClientRect(),i=o.top,s=o.bottom,r=o.height;if(i<n.top)return this.$refs.dropdownMenu.scrollTop=e.offsetTop;if(s>n.bottom)return this.$refs.dropdownMenu.scrollTop=e.offsetTop-(n.height-r);}},getDropdownViewport:function getDropdownViewport(){return this.$refs.dropdownMenu?this.$refs.dropdownMenu.getBoundingClientRect():{height:0,top:0,bottom:0};}}},u={data:function data(){return {typeAheadPointer:-1};},watch:{filteredOptions:function filteredOptions(){for(var t=0;t<this.filteredOptions.length;t++){if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break;}}}},methods:{typeAheadUp:function typeAheadUp(){for(var t=this.typeAheadPointer-1;t>=0;t--){if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break;}}},typeAheadDown:function typeAheadDown(){for(var t=this.typeAheadPointer+1;t<this.filteredOptions.length;t++){if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break;}}},typeAheadSelect:function typeAheadSelect(){var t=this.filteredOptions[this.typeAheadPointer];t&&this.select(t);}}},p={props:{loading:{type:Boolean,default:!1}},data:function data(){return {mutableLoading:!1};},watch:{search:function search(){this.$emit("search",this.search,this.toggleLoading);},loading:function loading(t){this.mutableLoading=t;}},methods:{toggleLoading:function toggleLoading(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null;return this.mutableLoading=null==t?!this.mutableLoading:t;}}};function h(t,e,n,o,i,s,r,a){var l,c="function"==typeof t?t.options:t;if(e&&(c.render=e,c.staticRenderFns=n,c._compiled=!0),o&&(c.functional=!0),s&&(c._scopeId="data-v-"+s),r?(l=function l(t){(t=t||this.$vnode&&this.$vnode.ssrContext||this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext)||"undefined"==typeof __VUE_SSR_CONTEXT__||(t=__VUE_SSR_CONTEXT__),i&&i.call(this,t),t&&t._registeredComponents&&t._registeredComponents.add(r);},c._ssrRegister=l):i&&(l=a?function(){i.call(this,this.$root.$options.shadowRoot);}:i),l)if(c.functional){c._injectStyles=l;var u=c.render;c.render=function(t,e){return l.call(e),u(t,e);};}else {var p=c.beforeCreate;c.beforeCreate=p?[].concat(p,l):[l];}return {exports:t,options:c};}var d={Deselect:h({},function(){var t=this.$createElement,e=this._self._c||t;return e("svg",{attrs:{xmlns:"http://www.w3.org/2000/svg",width:"10",height:"10"}},[e("path",{attrs:{d:"M6.895455 5l2.842897-2.842898c.348864-.348863.348864-.914488 0-1.263636L9.106534.261648c-.348864-.348864-.914489-.348864-1.263636 0L5 3.104545 2.157102.261648c-.348863-.348864-.914488-.348864-1.263636 0L.261648.893466c-.348864.348864-.348864.914489 0 1.263636L3.104545 5 .261648 7.842898c-.348864.348863-.348864.914488 0 1.263636l.631818.631818c.348864.348864.914773.348864 1.263636 0L5 6.895455l2.842898 2.842897c.348863.348864.914772.348864 1.263636 0l.631818-.631818c.348864-.348864.348864-.914489 0-1.263636L6.895455 5z"}})]);},[],!1,null,null,null).exports,OpenIndicator:h({},function(){var t=this.$createElement,e=this._self._c||t;return e("svg",{attrs:{xmlns:"http://www.w3.org/2000/svg",width:"14",height:"10"}},[e("path",{attrs:{d:"M9.211364 7.59931l4.48338-4.867229c.407008-.441854.407008-1.158247 0-1.60046l-.73712-.80023c-.407008-.441854-1.066904-.441854-1.474243 0L7 5.198617 2.51662.33139c-.407008-.441853-1.066904-.441853-1.474243 0l-.737121.80023c-.407008.441854-.407008 1.158248 0 1.600461l4.48338 4.867228L7 10l2.211364-2.40069z"}})]);},[],!1,null,null,null).exports},f={inserted:function inserted(t,e,n){var o=n.context;if(o.appendToBody){var i=o.$refs.toggle.getBoundingClientRect(),s=i.height,r=i.top,a=i.left,l=i.width,c=window.scrollX||window.pageXOffset,u=window.scrollY||window.pageYOffset;t.unbindPosition=o.calculatePosition(t,o,{width:l+"px",left:c+a+"px",top:u+r+s+"px"}),document.body.appendChild(t);}},unbind:function unbind(t,e,n){n.context.appendToBody&&(t.unbindPosition&&"function"==typeof t.unbindPosition&&t.unbindPosition(),t.parentNode&&t.parentNode.removeChild(t));}};var y=function y(t){var e={};return Object.keys(t).sort().forEach(function(n){e[n]=t[n];}),JSON.stringify(e);},b=0;var g=function g(){return ++b;};function v(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(t);e&&(o=o.filter(function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable;})),n.push.apply(n,o);}return n;}function m(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?v(Object(n),!0).forEach(function(e){l()(t,e,n[e]);}):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):v(Object(n)).forEach(function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e));});}return t;}var _={components:m({},d),mixins:[c,u,p],directives:{appendToBody:f},props:{value:{},components:{type:Object,default:function _default(){return {};}},options:{type:Array,default:function _default(){return [];}},disabled:{type:Boolean,default:!1},clearable:{type:Boolean,default:!0},searchable:{type:Boolean,default:!0},multiple:{type:Boolean,default:!1},placeholder:{type:String,default:""},transition:{type:String,default:"vs__fade"},clearSearchOnSelect:{type:Boolean,default:!0},closeOnSelect:{type:Boolean,default:!0},label:{type:String,default:"label"},autocomplete:{type:String,default:"off"},reduce:{type:Function,default:function _default(t){return t;}},selectable:{type:Function,default:function _default(t){return !0;}},getOptionLabel:{type:Function,default:function _default(t){return "object"===r()(t)?t.hasOwnProperty(this.label)?t[this.label]:console.warn('[vue-select warn]: Label key "option.'.concat(this.label,'" does not')+" exist in options object ".concat(JSON.stringify(t),".\n")+"https://vue-select.org/api/props.html#getoptionlabel"):t;}},getOptionKey:{type:Function,default:function _default(t){if("object"!==r()(t))return t;try{return t.hasOwnProperty("id")?t.id:y(t);}catch(e){return console.warn("[vue-select warn]: Could not stringify this option to generate unique key. Please provide'getOptionKey' prop to return a unique key for each option.\nhttps://vue-select.org/api/props.html#getoptionkey",t,e);}}},onTab:{type:Function,default:function _default(){this.selectOnTab&&!this.isComposing&&this.typeAheadSelect();}},taggable:{type:Boolean,default:!1},tabindex:{type:Number,default:null},pushTags:{type:Boolean,default:!1},filterable:{type:Boolean,default:!0},filterBy:{type:Function,default:function _default(t,e,n){return (e||"").toLowerCase().indexOf(n.toLowerCase())>-1;}},filter:{type:Function,default:function _default(t,e){var n=this;return t.filter(function(t){var o=n.getOptionLabel(t);return "number"==typeof o&&(o=o.toString()),n.filterBy(t,o,e);});}},createOption:{type:Function,default:function _default(t){return "object"===r()(this.optionList[0])?l()({},this.label,t):t;}},resetOnOptionsChange:{default:!1,validator:function validator(t){return ["function","boolean"].includes(r()(t));}},clearSearchOnBlur:{type:Function,default:function _default(t){var e=t.clearSearchOnSelect,n=t.multiple;return e&&!n;}},noDrop:{type:Boolean,default:!1},inputId:{type:String},dir:{type:String,default:"auto"},selectOnTab:{type:Boolean,default:!1},selectOnKeyCodes:{type:Array,default:function _default(){return [13];}},searchInputQuerySelector:{type:String,default:"[type=search]"},mapKeydown:{type:Function,default:function _default(t,e){return t;}},appendToBody:{type:Boolean,default:!1},calculatePosition:{type:Function,default:function _default(t,e,n){var o=n.width,i=n.top,s=n.left;t.style.top=i,t.style.left=s,t.style.width=o;}}},data:function data(){return {uid:g(),search:"",open:!1,isComposing:!1,pushedTags:[],_value:[]};},watch:{options:function options(t,e){var n=this;!this.taggable&&("function"==typeof n.resetOnOptionsChange?n.resetOnOptionsChange(t,e,n.selectedValue):n.resetOnOptionsChange)&&this.clearSelection(),this.value&&this.isTrackingValues&&this.setInternalValueFromOptions(this.value);},value:function value(t){this.isTrackingValues&&this.setInternalValueFromOptions(t);},multiple:function multiple(){this.clearSelection();},open:function open(t){this.$emit(t?"open":"close");}},created:function created(){this.mutableLoading=this.loading,void 0!==this.value&&this.isTrackingValues&&this.setInternalValueFromOptions(this.value),this.$on("option:created",this.pushTag);},methods:{setInternalValueFromOptions:function setInternalValueFromOptions(t){var e=this;Array.isArray(t)?this.$data._value=t.map(function(t){return e.findOptionFromReducedValue(t);}):this.$data._value=this.findOptionFromReducedValue(t);},select:function select(t){this.$emit("option:selecting",t),this.isOptionSelected(t)||(this.taggable&&!this.optionExists(t)&&this.$emit("option:created",t),this.multiple&&(t=this.selectedValue.concat(t)),this.updateValue(t),this.$emit("option:selected",t)),this.onAfterSelect(t);},deselect:function deselect(t){var e=this;this.$emit("option:deselecting",t),this.updateValue(this.selectedValue.filter(function(n){return !e.optionComparator(n,t);})),this.$emit("option:deselected",t);},clearSelection:function clearSelection(){this.updateValue(this.multiple?[]:null);},onAfterSelect:function onAfterSelect(t){this.closeOnSelect&&(this.open=!this.open,this.searchEl.blur()),this.clearSearchOnSelect&&(this.search="");},updateValue:function updateValue(t){var e=this;void 0===this.value&&(this.$data._value=t),null!==t&&(t=Array.isArray(t)?t.map(function(t){return e.reduce(t);}):this.reduce(t)),this.$emit("input",t);},toggleDropdown:function toggleDropdown(t){var e=t.target!==this.searchEl;e&&t.preventDefault();var n=[].concat(i()(this.$refs.deselectButtons||[]),i()([this.$refs.clearButton]||false));void 0===this.searchEl||n.filter(Boolean).some(function(e){return e.contains(t.target)||e===t.target;})?t.preventDefault():this.open&&e?this.searchEl.blur():this.disabled||(this.open=!0,this.searchEl.focus());},isOptionSelected:function isOptionSelected(t){var e=this;return this.selectedValue.some(function(n){return e.optionComparator(n,t);});},optionComparator:function optionComparator(t,e){return this.getOptionKey(t)===this.getOptionKey(e);},findOptionFromReducedValue:function findOptionFromReducedValue(t){var e=this,n=[].concat(i()(this.options),i()(this.pushedTags)).filter(function(n){return JSON.stringify(e.reduce(n))===JSON.stringify(t);});return 1===n.length?n[0]:n.find(function(t){return e.optionComparator(t,e.$data._value);})||t;},closeSearchOptions:function closeSearchOptions(){this.open=!1,this.$emit("search:blur");},maybeDeleteValue:function maybeDeleteValue(){if(!this.searchEl.value.length&&this.selectedValue&&this.selectedValue.length&&this.clearable){var t=null;this.multiple&&(t=i()(this.selectedValue.slice(0,this.selectedValue.length-1))),this.updateValue(t);}},optionExists:function optionExists(t){var e=this;return this.optionList.some(function(n){return e.optionComparator(n,t);});},normalizeOptionForSlot:function normalizeOptionForSlot(t){return "object"===r()(t)?t:l()({},this.label,t);},pushTag:function pushTag(t){this.pushedTags.push(t);},onEscape:function onEscape(){this.search.length?this.search="":this.searchEl.blur();},onSearchBlur:function onSearchBlur(){if(!this.mousedown||this.searching){var t=this.clearSearchOnSelect,e=this.multiple;return this.clearSearchOnBlur({clearSearchOnSelect:t,multiple:e})&&(this.search=""),void this.closeSearchOptions();}this.mousedown=!1,0!==this.search.length||0!==this.options.length||this.closeSearchOptions();},onSearchFocus:function onSearchFocus(){this.open=!0,this.$emit("search:focus");},onMousedown:function onMousedown(){this.mousedown=!0;},onMouseUp:function onMouseUp(){this.mousedown=!1;},onSearchKeyDown:function onSearchKeyDown(t){var e=this,n=function n(t){return t.preventDefault(),!e.isComposing&&e.typeAheadSelect();},o={8:function _(t){return e.maybeDeleteValue();},9:function _(t){return e.onTab();},27:function _(t){return e.onEscape();},38:function _(t){return t.preventDefault(),e.typeAheadUp();},40:function _(t){return t.preventDefault(),e.typeAheadDown();}};this.selectOnKeyCodes.forEach(function(t){return o[t]=n;});var i=this.mapKeydown(o,this);if("function"==typeof i[t.keyCode])return i[t.keyCode](t);}},computed:{isTrackingValues:function isTrackingValues(){return void 0===this.value||this.$options.propsData.hasOwnProperty("reduce");},selectedValue:function selectedValue(){var t=this.value;return this.isTrackingValues&&(t=this.$data._value),t?[].concat(t):[];},optionList:function optionList(){return this.options.concat(this.pushTags?this.pushedTags:[]);},searchEl:function searchEl(){return this.$scopedSlots.search?this.$refs.selectedOptions.querySelector(this.searchInputQuerySelector):this.$refs.search;},scope:function scope(){var t=this,e={search:this.search,loading:this.loading,searching:this.searching,filteredOptions:this.filteredOptions};return {search:{attributes:m({disabled:this.disabled,placeholder:this.searchPlaceholder,tabindex:this.tabindex,readonly:!this.searchable,id:this.inputId,"aria-autocomplete":"list","aria-labelledby":"vs".concat(this.uid,"__combobox"),"aria-controls":"vs".concat(this.uid,"__listbox"),ref:"search",type:"search",autocomplete:this.autocomplete,value:this.search},this.dropdownOpen&&this.filteredOptions[this.typeAheadPointer]?{"aria-activedescendant":"vs".concat(this.uid,"__option-").concat(this.typeAheadPointer)}:{}),events:{compositionstart:function compositionstart(){return t.isComposing=!0;},compositionend:function compositionend(){return t.isComposing=!1;},keydown:this.onSearchKeyDown,blur:this.onSearchBlur,focus:this.onSearchFocus,input:function input(e){return t.search=e.target.value;}}},spinner:{loading:this.mutableLoading},noOptions:{search:this.search,loading:this.loading,searching:this.searching},openIndicator:{attributes:{ref:"openIndicator",role:"presentation",class:"vs__open-indicator"}},listHeader:e,listFooter:e,header:m({},e,{deselect:this.deselect}),footer:m({},e,{deselect:this.deselect})};},childComponents:function childComponents(){return m({},d,{},this.components);},stateClasses:function stateClasses(){return {"vs--open":this.dropdownOpen,"vs--single":!this.multiple,"vs--searching":this.searching&&!this.noDrop,"vs--searchable":this.searchable&&!this.noDrop,"vs--unsearchable":!this.searchable,"vs--loading":this.mutableLoading,"vs--disabled":this.disabled};},searching:function searching(){return !!this.search;},dropdownOpen:function dropdownOpen(){return !this.noDrop&&this.open&&!this.mutableLoading;},searchPlaceholder:function searchPlaceholder(){if(this.isValueEmpty&&this.placeholder)return this.placeholder;},filteredOptions:function filteredOptions(){var t=[].concat(this.optionList);if(!this.filterable&&!this.taggable)return t;var e=this.search.length?this.filter(t,this.search,this):t;if(this.taggable&&this.search.length){var n=this.createOption(this.search);this.optionExists(n)||e.unshift(n);}return e;},isValueEmpty:function isValueEmpty(){return 0===this.selectedValue.length;},showClearButton:function showClearButton(){return !this.multiple&&this.clearable&&!this.open&&!this.isValueEmpty;}}},O=(n(7),h(_,function(){var t=this,e=t.$createElement,n=t._self._c||e;return n("div",{staticClass:"v-select",class:t.stateClasses,attrs:{dir:t.dir}},[t._t("header",null,null,t.scope.header),t._v(" "),n("div",{ref:"toggle",staticClass:"vs__dropdown-toggle",attrs:{id:"vs"+t.uid+"__combobox",role:"combobox","aria-expanded":t.dropdownOpen.toString(),"aria-owns":"vs"+t.uid+"__listbox","aria-label":"Search for option"},on:{mousedown:function mousedown(e){return t.toggleDropdown(e);}}},[n("div",{ref:"selectedOptions",staticClass:"vs__selected-options"},[t._l(t.selectedValue,function(e){return t._t("selected-option-container",[n("span",{key:t.getOptionKey(e),staticClass:"vs__selected"},[t._t("selected-option",[t._v("\n            "+t._s(t.getOptionLabel(e))+"\n          ")],null,t.normalizeOptionForSlot(e)),t._v(" "),t.multiple?n("button",{ref:"deselectButtons",refInFor:!0,staticClass:"vs__deselect",attrs:{disabled:t.disabled,type:"button",title:"Deselect "+t.getOptionLabel(e),"aria-label":"Deselect "+t.getOptionLabel(e)},on:{click:function click(n){return t.deselect(e);}}},[n(t.childComponents.Deselect,{tag:"component"})],1):t._e()],2)],{option:t.normalizeOptionForSlot(e),deselect:t.deselect,multiple:t.multiple,disabled:t.disabled});}),t._v(" "),t._t("search",[n("input",t._g(t._b({staticClass:"vs__search"},"input",t.scope.search.attributes,!1),t.scope.search.events))],null,t.scope.search)],2),t._v(" "),n("div",{ref:"actions",staticClass:"vs__actions"},[n("button",{directives:[{name:"show",rawName:"v-show",value:t.showClearButton,expression:"showClearButton"}],ref:"clearButton",staticClass:"vs__clear",attrs:{disabled:t.disabled,type:"button",title:"Clear Selected","aria-label":"Clear Selected"},on:{click:t.clearSelection}},[n(t.childComponents.Deselect,{tag:"component"})],1),t._v(" "),t._t("open-indicator",[t.noDrop?t._e():n(t.childComponents.OpenIndicator,t._b({tag:"component"},"component",t.scope.openIndicator.attributes,!1))],null,t.scope.openIndicator),t._v(" "),t._t("spinner",[n("div",{directives:[{name:"show",rawName:"v-show",value:t.mutableLoading,expression:"mutableLoading"}],staticClass:"vs__spinner"},[t._v("Loading...")])],null,t.scope.spinner)],2)]),t._v(" "),n("transition",{attrs:{name:t.transition}},[t.dropdownOpen?n("ul",{directives:[{name:"append-to-body",rawName:"v-append-to-body"}],key:"vs"+t.uid+"__listbox",ref:"dropdownMenu",staticClass:"vs__dropdown-menu",attrs:{id:"vs"+t.uid+"__listbox",role:"listbox",tabindex:"-1"},on:{mousedown:function mousedown(e){return e.preventDefault(),t.onMousedown(e);},mouseup:t.onMouseUp}},[t._t("list-header",null,null,t.scope.listHeader),t._v(" "),t._l(t.filteredOptions,function(e,o){return n("li",{key:t.getOptionKey(e),staticClass:"vs__dropdown-option",class:{"vs__dropdown-option--selected":t.isOptionSelected(e),"vs__dropdown-option--highlight":o===t.typeAheadPointer,"vs__dropdown-option--disabled":!t.selectable(e)},attrs:{role:"option",id:"vs"+t.uid+"__option-"+o,"aria-selected":o===t.typeAheadPointer||null},on:{mouseover:function mouseover(n){t.selectable(e)&&(t.typeAheadPointer=o);},mousedown:function mousedown(n){n.preventDefault(),n.stopPropagation(),t.selectable(e)&&t.select(e);}}},[t._t("option",[t._v("\n          "+t._s(t.getOptionLabel(e))+"\n        ")],null,t.normalizeOptionForSlot(e))],2);}),t._v(" "),0===t.filteredOptions.length?n("li",{staticClass:"vs__no-options"},[t._t("no-options",[t._v("Sorry, no matching options.")],null,t.scope.noOptions)],2):t._e(),t._v(" "),t._t("list-footer",null,null,t.scope.listFooter)],2):n("ul",{staticStyle:{display:"none",visibility:"hidden"},attrs:{id:"vs"+t.uid+"__listbox",role:"listbox"}})]),t._v(" "),t._t("footer",null,null,t.scope.footer)],2);},[],!1,null,null,null).exports),w={ajax:p,pointer:u,pointerScroll:c};n.d(e,"VueSelect",function(){return O;}),n.d(e,"mixins",function(){return w;});e.default=O;}]);});


/***/},

/***/"./node_modules/vue-sweetalert2/dist/index.js":
/*!****************************************************!*\
  !*** ./node_modules/vue-sweetalert2/dist/index.js ***!
  \****************************************************/
/*! exports provided: default */
/***/function node_modulesVueSweetalert2DistIndexJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var sweetalert2__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! sweetalert2 */"./node_modules/sweetalert2/dist/sweetalert2.all.js");
/* harmony import */var sweetalert2__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(sweetalert2__WEBPACK_IMPORTED_MODULE_0__);
var __spreadArrays=function(){
for(var s=0,i=0,il=arguments.length;i<il;i++){s+=arguments[i].length;}
for(var r=Array(s),k=0,i=0;i<il;i++){
for(var a=arguments[i],j=0,jl=a.length;j<jl;j++,k++){
r[k]=a[j];}}
return r;
};

var VueSweetalert2=function(){
function VueSweetalert2(){
}
VueSweetalert2.install=function(vue,options){
var swalLocalInstance=options?sweetalert2__WEBPACK_IMPORTED_MODULE_0___default.a.mixin(options):sweetalert2__WEBPACK_IMPORTED_MODULE_0___default.a;
var swalFunction=function swalFunction(){
var _a;
var args=[];
for(var _i=0;_i<arguments.length;_i++){
args[_i]=arguments[_i];
}
return (_a=swalLocalInstance.fire).call.apply(_a,__spreadArrays([swalLocalInstance],args));
};
var methodName;
for(methodName in swalLocalInstance){
if(Object.prototype.hasOwnProperty.call(swalLocalInstance,methodName)&&
typeof swalLocalInstance[methodName]==='function'){
swalFunction[methodName]=function(method){
return function(){
var _a;
var args=[];
for(var _i=0;_i<arguments.length;_i++){
args[_i]=arguments[_i];
}
return (_a=swalLocalInstance[method]).call.apply(_a,__spreadArrays([swalLocalInstance],args));
};
}(methodName);
}
}
vue['swal']=swalFunction;
if(!Object.prototype.hasOwnProperty.call(vue,'$swal')){
vue.prototype.$swal=swalFunction;
}
};
return VueSweetalert2;
}();
/* harmony default export */__webpack_exports__["default"]=VueSweetalert2;


/***/},

/***/"./node_modules/vue/dist/vue.common.dev.js":
/*!*************************************************!*\
  !*** ./node_modules/vue/dist/vue.common.dev.js ***!
  \*************************************************/
/*! no static exports found */
/***/function node_modulesVueDistVueCommonDevJs(module,exports,__webpack_require__){
/* WEBPACK VAR INJECTION */(function(global,setImmediate){/*!
 * Vue.js v2.6.12
 * (c) 2014-2020 Evan You
 * Released under the MIT License.
 */


/*  */

var emptyObject=Object.freeze({});

// These helpers produce better VM code in JS engines due to their
// explicitness and function inlining.
function isUndef(v){
return v===undefined||v===null;
}

function isDef(v){
return v!==undefined&&v!==null;
}

function isTrue(v){
return v===true;
}

function isFalse(v){
return v===false;
}

/**
 * Check if value is primitive.
 */
function isPrimitive(value){
return(
typeof value==='string'||
typeof value==='number'||
// $flow-disable-line
typeof value==='symbol'||
typeof value==='boolean');

}

/**
 * Quick object check - this is primarily used to tell
 * Objects from primitive values when we know the value
 * is a JSON-compliant type.
 */
function isObject(obj){
return obj!==null&&typeof obj==='object';
}

/**
 * Get the raw type string of a value, e.g., [object Object].
 */
var _toString=Object.prototype.toString;

function toRawType(value){
return _toString.call(value).slice(8,-1);
}

/**
 * Strict object type check. Only returns true
 * for plain JavaScript objects.
 */
function isPlainObject(obj){
return _toString.call(obj)==='[object Object]';
}

function isRegExp(v){
return _toString.call(v)==='[object RegExp]';
}

/**
 * Check if val is a valid array index.
 */
function isValidArrayIndex(val){
var n=parseFloat(String(val));
return n>=0&&Math.floor(n)===n&&isFinite(val);
}

function isPromise(val){
return(
isDef(val)&&
typeof val.then==='function'&&
typeof val.catch==='function');

}

/**
 * Convert a value to a string that is actually rendered.
 */
function toString(val){
return val==null?
'':
Array.isArray(val)||isPlainObject(val)&&val.toString===_toString?
JSON.stringify(val,null,2):
String(val);
}

/**
 * Convert an input value to a number for persistence.
 * If the conversion fails, return original string.
 */
function toNumber(val){
var n=parseFloat(val);
return isNaN(n)?val:n;
}

/**
 * Make a map and return a function for checking if a key
 * is in that map.
 */
function makeMap(
str,
expectsLowerCase)
{
var map=Object.create(null);
var list=str.split(',');
for(var i=0;i<list.length;i++){
map[list[i]]=true;
}
return expectsLowerCase?
function(val){return map[val.toLowerCase()];}:
function(val){return map[val];};
}

/**
 * Check if a tag is a built-in tag.
 */
var isBuiltInTag=makeMap('slot,component',true);

/**
 * Check if an attribute is a reserved attribute.
 */
var isReservedAttribute=makeMap('key,ref,slot,slot-scope,is');

/**
 * Remove an item from an array.
 */
function remove(arr,item){
if(arr.length){
var index=arr.indexOf(item);
if(index>-1){
return arr.splice(index,1);
}
}
}

/**
 * Check whether an object has the property.
 */
var hasOwnProperty=Object.prototype.hasOwnProperty;
function hasOwn(obj,key){
return hasOwnProperty.call(obj,key);
}

/**
 * Create a cached version of a pure function.
 */
function cached(fn){
var cache=Object.create(null);
return function cachedFn(str){
var hit=cache[str];
return hit||(cache[str]=fn(str));
};
}

/**
 * Camelize a hyphen-delimited string.
 */
var camelizeRE=/-(\w)/g;
var camelize=cached(function(str){
return str.replace(camelizeRE,function(_,c){return c?c.toUpperCase():'';});
});

/**
 * Capitalize a string.
 */
var capitalize=cached(function(str){
return str.charAt(0).toUpperCase()+str.slice(1);
});

/**
 * Hyphenate a camelCase string.
 */
var hyphenateRE=/\B([A-Z])/g;
var hyphenate=cached(function(str){
return str.replace(hyphenateRE,'-$1').toLowerCase();
});

/**
 * Simple bind polyfill for environments that do not support it,
 * e.g., PhantomJS 1.x. Technically, we don't need this anymore
 * since native bind is now performant enough in most browsers.
 * But removing it would mean breaking code that was able to run in
 * PhantomJS 1.x, so this must be kept for backward compatibility.
 */

/* istanbul ignore next */
function polyfillBind(fn,ctx){
function boundFn(a){
var l=arguments.length;
return l?
l>1?
fn.apply(ctx,arguments):
fn.call(ctx,a):
fn.call(ctx);
}

boundFn._length=fn.length;
return boundFn;
}

function nativeBind(fn,ctx){
return fn.bind(ctx);
}

var bind=Function.prototype.bind?
nativeBind:
polyfillBind;

/**
 * Convert an Array-like object to a real Array.
 */
function toArray(list,start){
start=start||0;
var i=list.length-start;
var ret=new Array(i);
while(i--){
ret[i]=list[i+start];
}
return ret;
}

/**
 * Mix properties into target object.
 */
function extend(to,_from){
for(var key in _from){
to[key]=_from[key];
}
return to;
}

/**
 * Merge an Array of Objects into a single Object.
 */
function toObject(arr){
var res={};
for(var i=0;i<arr.length;i++){
if(arr[i]){
extend(res,arr[i]);
}
}
return res;
}

/* eslint-disable no-unused-vars */

/**
 * Perform no operation.
 * Stubbing args to make Flow happy without leaving useless transpiled code
 * with ...rest (https://flow.org/blog/2017/05/07/Strict-Function-Call-Arity/).
 */
function noop(a,b,c){}

/**
 * Always return false.
 */
var no=function no(a,b,c){return false;};

/* eslint-enable no-unused-vars */

/**
 * Return the same value.
 */
var identity=function identity(_){return _;};

/**
 * Generate a string containing static keys from compiler modules.
 */
function genStaticKeys(modules){
return modules.reduce(function(keys,m){
return keys.concat(m.staticKeys||[]);
},[]).join(',');
}

/**
 * Check if two values are loosely equal - that is,
 * if they are plain objects, do they have the same shape?
 */
function looseEqual(a,b){
if(a===b){return true;}
var isObjectA=isObject(a);
var isObjectB=isObject(b);
if(isObjectA&&isObjectB){
try{
var isArrayA=Array.isArray(a);
var isArrayB=Array.isArray(b);
if(isArrayA&&isArrayB){
return a.length===b.length&&a.every(function(e,i){
return looseEqual(e,b[i]);
});
}else if(a instanceof Date&&b instanceof Date){
return a.getTime()===b.getTime();
}else if(!isArrayA&&!isArrayB){
var keysA=Object.keys(a);
var keysB=Object.keys(b);
return keysA.length===keysB.length&&keysA.every(function(key){
return looseEqual(a[key],b[key]);
});
}else {
/* istanbul ignore next */
return false;
}
}catch(e){
/* istanbul ignore next */
return false;
}
}else if(!isObjectA&&!isObjectB){
return String(a)===String(b);
}else {
return false;
}
}

/**
 * Return the first index at which a loosely equal value can be
 * found in the array (if value is a plain object, the array must
 * contain an object of the same shape), or -1 if it is not present.
 */
function looseIndexOf(arr,val){
for(var i=0;i<arr.length;i++){
if(looseEqual(arr[i],val)){return i;}
}
return -1;
}

/**
 * Ensure a function is called only once.
 */
function once(fn){
var called=false;
return function(){
if(!called){
called=true;
fn.apply(this,arguments);
}
};
}

var SSR_ATTR='data-server-rendered';

var ASSET_TYPES=[
'component',
'directive',
'filter'];


var LIFECYCLE_HOOKS=[
'beforeCreate',
'created',
'beforeMount',
'mounted',
'beforeUpdate',
'updated',
'beforeDestroy',
'destroyed',
'activated',
'deactivated',
'errorCaptured',
'serverPrefetch'];


/*  */



var config={
/**
   * Option merge strategies (used in core/util/options)
   */
// $flow-disable-line
optionMergeStrategies:Object.create(null),

/**
   * Whether to suppress warnings.
   */
silent:false,

/**
   * Show production mode tip message on boot?
   */
productionTip:"development"!=='production',

/**
   * Whether to enable devtools
   */
devtools:"development"!=='production',

/**
   * Whether to record perf
   */
performance:false,

/**
   * Error handler for watcher errors
   */
errorHandler:null,

/**
   * Warn handler for watcher warns
   */
warnHandler:null,

/**
   * Ignore certain custom elements
   */
ignoredElements:[],

/**
   * Custom user key aliases for v-on
   */
// $flow-disable-line
keyCodes:Object.create(null),

/**
   * Check if a tag is reserved so that it cannot be registered as a
   * component. This is platform-dependent and may be overwritten.
   */
isReservedTag:no,

/**
   * Check if an attribute is reserved so that it cannot be used as a component
   * prop. This is platform-dependent and may be overwritten.
   */
isReservedAttr:no,

/**
   * Check if a tag is an unknown element.
   * Platform-dependent.
   */
isUnknownElement:no,

/**
   * Get the namespace of an element
   */
getTagNamespace:noop,

/**
   * Parse the real tag name for the specific platform.
   */
parsePlatformTagName:identity,

/**
   * Check if an attribute must be bound using property, e.g. value
   * Platform-dependent.
   */
mustUseProp:no,

/**
   * Perform updates asynchronously. Intended to be used by Vue Test Utils
   * This will significantly reduce performance if set to false.
   */
async:true,

/**
   * Exposed for legacy reasons
   */
_lifecycleHooks:LIFECYCLE_HOOKS};


/*  */

/**
 * unicode letters used for parsing html tags, component names and property paths.
 * using https://www.w3.org/TR/html53/semantics-scripting.html#potentialcustomelementname
 * skipping \u10000-\uEFFFF due to it freezing up PhantomJS
 */
var unicodeRegExp=/a-zA-Z\u00B7\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u037D\u037F-\u1FFF\u200C-\u200D\u203F-\u2040\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD/;

/**
 * Check if a string starts with $ or _
 */
function isReserved(str){
var c=(str+'').charCodeAt(0);
return c===0x24||c===0x5F;
}

/**
 * Define a property.
 */
function def(obj,key,val,enumerable){
Object.defineProperty(obj,key,{
value:val,
enumerable:!!enumerable,
writable:true,
configurable:true});

}

/**
 * Parse simple path.
 */
var bailRE=new RegExp("[^"+unicodeRegExp.source+".$_\\d]");
function parsePath(path){
if(bailRE.test(path)){
return;
}
var segments=path.split('.');
return function(obj){
for(var i=0;i<segments.length;i++){
if(!obj){return;}
obj=obj[segments[i]];
}
return obj;
};
}

/*  */

// can we use __proto__?
var hasProto=('__proto__'in{});

// Browser environment sniffing
var inBrowser=typeof window!=='undefined';
var inWeex=typeof WXEnvironment!=='undefined'&&!!WXEnvironment.platform;
var weexPlatform=inWeex&&WXEnvironment.platform.toLowerCase();
var UA=inBrowser&&window.navigator.userAgent.toLowerCase();
var isIE=UA&&/msie|trident/.test(UA);
var isIE9=UA&&UA.indexOf('msie 9.0')>0;
var isEdge=UA&&UA.indexOf('edge/')>0;
var isAndroid=UA&&UA.indexOf('android')>0||weexPlatform==='android';
var isIOS=UA&&/iphone|ipad|ipod|ios/.test(UA)||weexPlatform==='ios';
var isChrome=UA&&/chrome\/\d+/.test(UA)&&!isEdge;
var isPhantomJS=UA&&/phantomjs/.test(UA);
var isFF=UA&&UA.match(/firefox\/(\d+)/);

// Firefox has a "watch" function on Object.prototype...
var nativeWatch={}.watch;

var supportsPassive=false;
if(inBrowser){
try{
var opts={};
Object.defineProperty(opts,'passive',{
get:function get(){
/* istanbul ignore next */
supportsPassive=true;
}});
// https://github.com/facebook/flow/issues/285
window.addEventListener('test-passive',null,opts);
}catch(e){}
}

// this needs to be lazy-evaled because vue may be required before
// vue-server-renderer can set VUE_ENV
var _isServer;
var isServerRendering=function isServerRendering(){
if(_isServer===undefined){
/* istanbul ignore if */
if(!inBrowser&&!inWeex&&typeof global!=='undefined'){
// detect presence of vue-server-renderer and avoid
// Webpack shimming the process
_isServer=global['process']&&global['process'].env.VUE_ENV==='server';
}else {
_isServer=false;
}
}
return _isServer;
};

// detect devtools
var devtools=inBrowser&&window.__VUE_DEVTOOLS_GLOBAL_HOOK__;

/* istanbul ignore next */
function isNative(Ctor){
return typeof Ctor==='function'&&/native code/.test(Ctor.toString());
}

var hasSymbol=
typeof Symbol!=='undefined'&&isNative(Symbol)&&
typeof Reflect!=='undefined'&&isNative(Reflect.ownKeys);

var _Set;
/* istanbul ignore if */ // $flow-disable-line
if(typeof Set!=='undefined'&&isNative(Set)){
// use native Set when available.
_Set=Set;
}else {
// a non-standard Set polyfill that only works with primitive keys.
_Set=/*@__PURE__*/function(){
function Set(){
this.set=Object.create(null);
}
Set.prototype.has=function has(key){
return this.set[key]===true;
};
Set.prototype.add=function add(key){
this.set[key]=true;
};
Set.prototype.clear=function clear(){
this.set=Object.create(null);
};

return Set;
}();
}

/*  */

var warn=noop;
var tip=noop;
var generateComponentTrace=noop;// work around flow check
var formatComponentName=noop;

{
var hasConsole=typeof console!=='undefined';
var classifyRE=/(?:^|[-_])(\w)/g;
var classify=function classify(str){return str.
replace(classifyRE,function(c){return c.toUpperCase();}).
replace(/[-_]/g,'');};

warn=function warn(msg,vm){
var trace=vm?generateComponentTrace(vm):'';

if(config.warnHandler){
config.warnHandler.call(null,msg,vm,trace);
}else if(hasConsole&&!config.silent){
console.error("[Vue warn]: "+msg+trace);
}
};

tip=function tip(msg,vm){
if(hasConsole&&!config.silent){
console.warn("[Vue tip]: "+msg+(
vm?generateComponentTrace(vm):''));

}
};

formatComponentName=function formatComponentName(vm,includeFile){
if(vm.$root===vm){
return '<Root>';
}
var options=typeof vm==='function'&&vm.cid!=null?
vm.options:
vm._isVue?
vm.$options||vm.constructor.options:
vm;
var name=options.name||options._componentTag;
var file=options.__file;
if(!name&&file){
var match=file.match(/([^/\\]+)\.vue$/);
name=match&&match[1];
}

return(
(name?"<"+classify(name)+">":"<Anonymous>")+(
file&&includeFile!==false?" at "+file:''));

};

var repeat=function repeat(str,n){
var res='';
while(n){
if(n%2===1){res+=str;}
if(n>1){str+=str;}
n>>=1;
}
return res;
};

generateComponentTrace=function generateComponentTrace(vm){
if(vm._isVue&&vm.$parent){
var tree=[];
var currentRecursiveSequence=0;
while(vm){
if(tree.length>0){
var last=tree[tree.length-1];
if(last.constructor===vm.constructor){
currentRecursiveSequence++;
vm=vm.$parent;
continue;
}else if(currentRecursiveSequence>0){
tree[tree.length-1]=[last,currentRecursiveSequence];
currentRecursiveSequence=0;
}
}
tree.push(vm);
vm=vm.$parent;
}
return '\n\nfound in\n\n'+tree.
map(function(vm,i){return ""+(i===0?'---> ':repeat(' ',5+i*2))+(Array.isArray(vm)?
formatComponentName(vm[0])+"... ("+vm[1]+" recursive calls)":
formatComponentName(vm));}).
join('\n');
}else {
return "\n\n(found in "+formatComponentName(vm)+")";
}
};
}

/*  */

var uid=0;

/**
 * A dep is an observable that can have multiple
 * directives subscribing to it.
 */
var Dep=function Dep(){
this.id=uid++;
this.subs=[];
};

Dep.prototype.addSub=function addSub(sub){
this.subs.push(sub);
};

Dep.prototype.removeSub=function removeSub(sub){
remove(this.subs,sub);
};

Dep.prototype.depend=function depend(){
if(Dep.target){
Dep.target.addDep(this);
}
};

Dep.prototype.notify=function notify(){
// stabilize the subscriber list first
var subs=this.subs.slice();
if(!config.async){
// subs aren't sorted in scheduler if not running async
// we need to sort them now to make sure they fire in correct
// order
subs.sort(function(a,b){return a.id-b.id;});
}
for(var i=0,l=subs.length;i<l;i++){
subs[i].update();
}
};

// The current target watcher being evaluated.
// This is globally unique because only one watcher
// can be evaluated at a time.
Dep.target=null;
var targetStack=[];

function pushTarget(target){
targetStack.push(target);
Dep.target=target;
}

function popTarget(){
targetStack.pop();
Dep.target=targetStack[targetStack.length-1];
}

/*  */

var VNode=function VNode(
tag,
data,
children,
text,
elm,
context,
componentOptions,
asyncFactory)
{
this.tag=tag;
this.data=data;
this.children=children;
this.text=text;
this.elm=elm;
this.ns=undefined;
this.context=context;
this.fnContext=undefined;
this.fnOptions=undefined;
this.fnScopeId=undefined;
this.key=data&&data.key;
this.componentOptions=componentOptions;
this.componentInstance=undefined;
this.parent=undefined;
this.raw=false;
this.isStatic=false;
this.isRootInsert=true;
this.isComment=false;
this.isCloned=false;
this.isOnce=false;
this.asyncFactory=asyncFactory;
this.asyncMeta=undefined;
this.isAsyncPlaceholder=false;
};

var prototypeAccessors={child:{configurable:true}};

// DEPRECATED: alias for componentInstance for backwards compat.
/* istanbul ignore next */
prototypeAccessors.child.get=function(){
return this.componentInstance;
};

Object.defineProperties(VNode.prototype,prototypeAccessors);

var createEmptyVNode=function createEmptyVNode(text){
if(text===void 0)text='';

var node=new VNode();
node.text=text;
node.isComment=true;
return node;
};

function createTextVNode(val){
return new VNode(undefined,undefined,undefined,String(val));
}

// optimized shallow clone
// used for static nodes and slot nodes because they may be reused across
// multiple renders, cloning them avoids errors when DOM manipulations rely
// on their elm reference.
function cloneVNode(vnode){
var cloned=new VNode(
vnode.tag,
vnode.data,
// #7975
// clone children array to avoid mutating original in case of cloning
// a child.
vnode.children&&vnode.children.slice(),
vnode.text,
vnode.elm,
vnode.context,
vnode.componentOptions,
vnode.asyncFactory);

cloned.ns=vnode.ns;
cloned.isStatic=vnode.isStatic;
cloned.key=vnode.key;
cloned.isComment=vnode.isComment;
cloned.fnContext=vnode.fnContext;
cloned.fnOptions=vnode.fnOptions;
cloned.fnScopeId=vnode.fnScopeId;
cloned.asyncMeta=vnode.asyncMeta;
cloned.isCloned=true;
return cloned;
}

/*
 * not type checking this file because flow doesn't play well with
 * dynamically accessing methods on Array prototype
 */

var arrayProto=Array.prototype;
var arrayMethods=Object.create(arrayProto);

var methodsToPatch=[
'push',
'pop',
'shift',
'unshift',
'splice',
'sort',
'reverse'];


/**
 * Intercept mutating methods and emit events
 */
methodsToPatch.forEach(function(method){
// cache original method
var original=arrayProto[method];
def(arrayMethods,method,function mutator(){
var args=[],len=arguments.length;
while(len--){args[len]=arguments[len];}

var result=original.apply(this,args);
var ob=this.__ob__;
var inserted;
switch(method){
case'push':
case'unshift':
inserted=args;
break;
case'splice':
inserted=args.slice(2);
break;}

if(inserted){ob.observeArray(inserted);}
// notify change
ob.dep.notify();
return result;
});
});

/*  */

var arrayKeys=Object.getOwnPropertyNames(arrayMethods);

/**
 * In some cases we may want to disable observation inside a component's
 * update computation.
 */
var shouldObserve=true;

function toggleObserving(value){
shouldObserve=value;
}

/**
 * Observer class that is attached to each observed
 * object. Once attached, the observer converts the target
 * object's property keys into getter/setters that
 * collect dependencies and dispatch updates.
 */
var Observer=function Observer(value){
this.value=value;
this.dep=new Dep();
this.vmCount=0;
def(value,'__ob__',this);
if(Array.isArray(value)){
if(hasProto){
protoAugment(value,arrayMethods);
}else {
copyAugment(value,arrayMethods,arrayKeys);
}
this.observeArray(value);
}else {
this.walk(value);
}
};

/**
 * Walk through all properties and convert them into
 * getter/setters. This method should only be called when
 * value type is Object.
 */
Observer.prototype.walk=function walk(obj){
var keys=Object.keys(obj);
for(var i=0;i<keys.length;i++){
defineReactive$$1(obj,keys[i]);
}
};

/**
 * Observe a list of Array items.
 */
Observer.prototype.observeArray=function observeArray(items){
for(var i=0,l=items.length;i<l;i++){
observe(items[i]);
}
};

// helpers

/**
 * Augment a target Object or Array by intercepting
 * the prototype chain using __proto__
 */
function protoAugment(target,src){
/* eslint-disable no-proto */
target.__proto__=src;
/* eslint-enable no-proto */
}

/**
 * Augment a target Object or Array by defining
 * hidden properties.
 */
/* istanbul ignore next */
function copyAugment(target,src,keys){
for(var i=0,l=keys.length;i<l;i++){
var key=keys[i];
def(target,key,src[key]);
}
}

/**
 * Attempt to create an observer instance for a value,
 * returns the new observer if successfully observed,
 * or the existing observer if the value already has one.
 */
function observe(value,asRootData){
if(!isObject(value)||value instanceof VNode){
return;
}
var ob;
if(hasOwn(value,'__ob__')&&value.__ob__ instanceof Observer){
ob=value.__ob__;
}else if(
shouldObserve&&
!isServerRendering()&&(
Array.isArray(value)||isPlainObject(value))&&
Object.isExtensible(value)&&
!value._isVue)
{
ob=new Observer(value);
}
if(asRootData&&ob){
ob.vmCount++;
}
return ob;
}

/**
 * Define a reactive property on an Object.
 */
function defineReactive$$1(
obj,
key,
val,
customSetter,
shallow)
{
var dep=new Dep();

var property=Object.getOwnPropertyDescriptor(obj,key);
if(property&&property.configurable===false){
return;
}

// cater for pre-defined getter/setters
var getter=property&&property.get;
var setter=property&&property.set;
if((!getter||setter)&&arguments.length===2){
val=obj[key];
}

var childOb=!shallow&&observe(val);
Object.defineProperty(obj,key,{
enumerable:true,
configurable:true,
get:function reactiveGetter(){
var value=getter?getter.call(obj):val;
if(Dep.target){
dep.depend();
if(childOb){
childOb.dep.depend();
if(Array.isArray(value)){
dependArray(value);
}
}
}
return value;
},
set:function reactiveSetter(newVal){
var value=getter?getter.call(obj):val;
/* eslint-disable no-self-compare */
if(newVal===value||newVal!==newVal&&value!==value){
return;
}
/* eslint-enable no-self-compare */
if(customSetter){
customSetter();
}
// #7981: for accessor properties without setter
if(getter&&!setter){return;}
if(setter){
setter.call(obj,newVal);
}else {
val=newVal;
}
childOb=!shallow&&observe(newVal);
dep.notify();
}});

}

/**
 * Set a property on an object. Adds the new property and
 * triggers change notification if the property doesn't
 * already exist.
 */
function set(target,key,val){
if(isUndef(target)||isPrimitive(target))
{
warn("Cannot set reactive property on undefined, null, or primitive value: "+target);
}
if(Array.isArray(target)&&isValidArrayIndex(key)){
target.length=Math.max(target.length,key);
target.splice(key,1,val);
return val;
}
if(key in target&&!(key in Object.prototype)){
target[key]=val;
return val;
}
var ob=target.__ob__;
if(target._isVue||ob&&ob.vmCount){
warn(
'Avoid adding reactive properties to a Vue instance or its root $data '+
'at runtime - declare it upfront in the data option.');

return val;
}
if(!ob){
target[key]=val;
return val;
}
defineReactive$$1(ob.value,key,val);
ob.dep.notify();
return val;
}

/**
 * Delete a property and trigger change if necessary.
 */
function del(target,key){
if(isUndef(target)||isPrimitive(target))
{
warn("Cannot delete reactive property on undefined, null, or primitive value: "+target);
}
if(Array.isArray(target)&&isValidArrayIndex(key)){
target.splice(key,1);
return;
}
var ob=target.__ob__;
if(target._isVue||ob&&ob.vmCount){
warn(
'Avoid deleting properties on a Vue instance or its root $data '+
'- just set it to null.');

return;
}
if(!hasOwn(target,key)){
return;
}
delete target[key];
if(!ob){
return;
}
ob.dep.notify();
}

/**
 * Collect dependencies on array elements when the array is touched, since
 * we cannot intercept array element access like property getters.
 */
function dependArray(value){
for(var e=void 0,i=0,l=value.length;i<l;i++){
e=value[i];
e&&e.__ob__&&e.__ob__.dep.depend();
if(Array.isArray(e)){
dependArray(e);
}
}
}

/*  */

/**
 * Option overwriting strategies are functions that handle
 * how to merge a parent option value and a child option
 * value into the final value.
 */
var strats=config.optionMergeStrategies;

/**
 * Options with restrictions
 */
{
strats.el=strats.propsData=function(parent,child,vm,key){
if(!vm){
warn(
"option \""+key+"\" can only be used during instance "+
'creation with the `new` keyword.');

}
return defaultStrat(parent,child);
};
}

/**
 * Helper that recursively merges two data objects together.
 */
function mergeData(to,from){
if(!from){return to;}
var key,toVal,fromVal;

var keys=hasSymbol?
Reflect.ownKeys(from):
Object.keys(from);

for(var i=0;i<keys.length;i++){
key=keys[i];
// in case the object is already observed...
if(key==='__ob__'){continue;}
toVal=to[key];
fromVal=from[key];
if(!hasOwn(to,key)){
set(to,key,fromVal);
}else if(
toVal!==fromVal&&
isPlainObject(toVal)&&
isPlainObject(fromVal))
{
mergeData(toVal,fromVal);
}
}
return to;
}

/**
 * Data
 */
function mergeDataOrFn(
parentVal,
childVal,
vm)
{
if(!vm){
// in a Vue.extend merge, both should be functions
if(!childVal){
return parentVal;
}
if(!parentVal){
return childVal;
}
// when parentVal & childVal are both present,
// we need to return a function that returns the
// merged result of both functions... no need to
// check if parentVal is a function here because
// it has to be a function to pass previous merges.
return function mergedDataFn(){
return mergeData(
typeof childVal==='function'?childVal.call(this,this):childVal,
typeof parentVal==='function'?parentVal.call(this,this):parentVal);

};
}else {
return function mergedInstanceDataFn(){
// instance merge
var instanceData=typeof childVal==='function'?
childVal.call(vm,vm):
childVal;
var defaultData=typeof parentVal==='function'?
parentVal.call(vm,vm):
parentVal;
if(instanceData){
return mergeData(instanceData,defaultData);
}else {
return defaultData;
}
};
}
}

strats.data=function(
parentVal,
childVal,
vm)
{
if(!vm){
if(childVal&&typeof childVal!=='function'){
warn(
'The "data" option should be a function '+
'that returns a per-instance value in component '+
'definitions.',
vm);


return parentVal;
}
return mergeDataOrFn(parentVal,childVal);
}

return mergeDataOrFn(parentVal,childVal,vm);
};

/**
 * Hooks and props are merged as arrays.
 */
function mergeHook(
parentVal,
childVal)
{
var res=childVal?
parentVal?
parentVal.concat(childVal):
Array.isArray(childVal)?
childVal:
[childVal]:
parentVal;
return res?
dedupeHooks(res):
res;
}

function dedupeHooks(hooks){
var res=[];
for(var i=0;i<hooks.length;i++){
if(res.indexOf(hooks[i])===-1){
res.push(hooks[i]);
}
}
return res;
}

LIFECYCLE_HOOKS.forEach(function(hook){
strats[hook]=mergeHook;
});

/**
 * Assets
 *
 * When a vm is present (instance creation), we need to do
 * a three-way merge between constructor options, instance
 * options and parent options.
 */
function mergeAssets(
parentVal,
childVal,
vm,
key)
{
var res=Object.create(parentVal||null);
if(childVal){
assertObjectType(key,childVal,vm);
return extend(res,childVal);
}else {
return res;
}
}

ASSET_TYPES.forEach(function(type){
strats[type+'s']=mergeAssets;
});

/**
 * Watchers.
 *
 * Watchers hashes should not overwrite one
 * another, so we merge them as arrays.
 */
strats.watch=function(
parentVal,
childVal,
vm,
key)
{
// work around Firefox's Object.prototype.watch...
if(parentVal===nativeWatch){parentVal=undefined;}
if(childVal===nativeWatch){childVal=undefined;}
/* istanbul ignore if */
if(!childVal){return Object.create(parentVal||null);}
{
assertObjectType(key,childVal,vm);
}
if(!parentVal){return childVal;}
var ret={};
extend(ret,parentVal);
for(var key$1 in childVal){
var parent=ret[key$1];
var child=childVal[key$1];
if(parent&&!Array.isArray(parent)){
parent=[parent];
}
ret[key$1]=parent?
parent.concat(child):
Array.isArray(child)?child:[child];
}
return ret;
};

/**
 * Other object hashes.
 */
strats.props=
strats.methods=
strats.inject=
strats.computed=function(
parentVal,
childVal,
vm,
key)
{
if(childVal&&"development"!=='production'){
assertObjectType(key,childVal,vm);
}
if(!parentVal){return childVal;}
var ret=Object.create(null);
extend(ret,parentVal);
if(childVal){extend(ret,childVal);}
return ret;
};
strats.provide=mergeDataOrFn;

/**
 * Default strategy.
 */
var defaultStrat=function defaultStrat(parentVal,childVal){
return childVal===undefined?
parentVal:
childVal;
};

/**
 * Validate component names
 */
function checkComponents(options){
for(var key in options.components){
validateComponentName(key);
}
}

function validateComponentName(name){
if(!new RegExp("^[a-zA-Z][\\-\\.0-9_"+unicodeRegExp.source+"]*$").test(name)){
warn(
'Invalid component name: "'+name+'". Component names '+
'should conform to valid custom element name in html5 specification.');

}
if(isBuiltInTag(name)||config.isReservedTag(name)){
warn(
'Do not use built-in or reserved HTML elements as component '+
'id: '+name);

}
}

/**
 * Ensure all props option syntax are normalized into the
 * Object-based format.
 */
function normalizeProps(options,vm){
var props=options.props;
if(!props){return;}
var res={};
var i,val,name;
if(Array.isArray(props)){
i=props.length;
while(i--){
val=props[i];
if(typeof val==='string'){
name=camelize(val);
res[name]={type:null};
}else {
warn('props must be strings when using array syntax.');
}
}
}else if(isPlainObject(props)){
for(var key in props){
val=props[key];
name=camelize(key);
res[name]=isPlainObject(val)?
val:
{type:val};
}
}else {
warn(
"Invalid value for option \"props\": expected an Array or an Object, "+
"but got "+toRawType(props)+".",
vm);

}
options.props=res;
}

/**
 * Normalize all injections into Object-based format
 */
function normalizeInject(options,vm){
var inject=options.inject;
if(!inject){return;}
var normalized=options.inject={};
if(Array.isArray(inject)){
for(var i=0;i<inject.length;i++){
normalized[inject[i]]={from:inject[i]};
}
}else if(isPlainObject(inject)){
for(var key in inject){
var val=inject[key];
normalized[key]=isPlainObject(val)?
extend({from:key},val):
{from:val};
}
}else {
warn(
"Invalid value for option \"inject\": expected an Array or an Object, "+
"but got "+toRawType(inject)+".",
vm);

}
}

/**
 * Normalize raw function directives into object format.
 */
function normalizeDirectives(options){
var dirs=options.directives;
if(dirs){
for(var key in dirs){
var def$$1=dirs[key];
if(typeof def$$1==='function'){
dirs[key]={bind:def$$1,update:def$$1};
}
}
}
}

function assertObjectType(name,value,vm){
if(!isPlainObject(value)){
warn(
"Invalid value for option \""+name+"\": expected an Object, "+
"but got "+toRawType(value)+".",
vm);

}
}

/**
 * Merge two option objects into a new one.
 * Core utility used in both instantiation and inheritance.
 */
function mergeOptions(
parent,
child,
vm)
{
{
checkComponents(child);
}

if(typeof child==='function'){
child=child.options;
}

normalizeProps(child,vm);
normalizeInject(child,vm);
normalizeDirectives(child);

// Apply extends and mixins on the child options,
// but only if it is a raw options object that isn't
// the result of another mergeOptions call.
// Only merged options has the _base property.
if(!child._base){
if(child.extends){
parent=mergeOptions(parent,child.extends,vm);
}
if(child.mixins){
for(var i=0,l=child.mixins.length;i<l;i++){
parent=mergeOptions(parent,child.mixins[i],vm);
}
}
}

var options={};
var key;
for(key in parent){
mergeField(key);
}
for(key in child){
if(!hasOwn(parent,key)){
mergeField(key);
}
}
function mergeField(key){
var strat=strats[key]||defaultStrat;
options[key]=strat(parent[key],child[key],vm,key);
}
return options;
}

/**
 * Resolve an asset.
 * This function is used because child instances need access
 * to assets defined in its ancestor chain.
 */
function resolveAsset(
options,
type,
id,
warnMissing)
{
/* istanbul ignore if */
if(typeof id!=='string'){
return;
}
var assets=options[type];
// check local registration variations first
if(hasOwn(assets,id)){return assets[id];}
var camelizedId=camelize(id);
if(hasOwn(assets,camelizedId)){return assets[camelizedId];}
var PascalCaseId=capitalize(camelizedId);
if(hasOwn(assets,PascalCaseId)){return assets[PascalCaseId];}
// fallback to prototype chain
var res=assets[id]||assets[camelizedId]||assets[PascalCaseId];
if(warnMissing&&!res){
warn(
'Failed to resolve '+type.slice(0,-1)+': '+id,
options);

}
return res;
}

/*  */



function validateProp(
key,
propOptions,
propsData,
vm)
{
var prop=propOptions[key];
var absent=!hasOwn(propsData,key);
var value=propsData[key];
// boolean casting
var booleanIndex=getTypeIndex(Boolean,prop.type);
if(booleanIndex>-1){
if(absent&&!hasOwn(prop,'default')){
value=false;
}else if(value===''||value===hyphenate(key)){
// only cast empty string / same name to boolean if
// boolean has higher priority
var stringIndex=getTypeIndex(String,prop.type);
if(stringIndex<0||booleanIndex<stringIndex){
value=true;
}
}
}
// check default value
if(value===undefined){
value=getPropDefaultValue(vm,prop,key);
// since the default value is a fresh copy,
// make sure to observe it.
var prevShouldObserve=shouldObserve;
toggleObserving(true);
observe(value);
toggleObserving(prevShouldObserve);
}
{
assertProp(prop,key,value,vm,absent);
}
return value;
}

/**
 * Get the default value of a prop.
 */
function getPropDefaultValue(vm,prop,key){
// no default, return undefined
if(!hasOwn(prop,'default')){
return undefined;
}
var def=prop.default;
// warn against non-factory defaults for Object & Array
if(isObject(def)){
warn(
'Invalid default value for prop "'+key+'": '+
'Props with type Object/Array must use a factory function '+
'to return the default value.',
vm);

}
// the raw prop value was also undefined from previous render,
// return previous default value to avoid unnecessary watcher trigger
if(vm&&vm.$options.propsData&&
vm.$options.propsData[key]===undefined&&
vm._props[key]!==undefined)
{
return vm._props[key];
}
// call factory function for non-Function types
// a value is Function if its prototype is function even across different execution context
return typeof def==='function'&&getType(prop.type)!=='Function'?
def.call(vm):
def;
}

/**
 * Assert whether a prop is valid.
 */
function assertProp(
prop,
name,
value,
vm,
absent)
{
if(prop.required&&absent){
warn(
'Missing required prop: "'+name+'"',
vm);

return;
}
if(value==null&&!prop.required){
return;
}
var type=prop.type;
var valid=!type||type===true;
var expectedTypes=[];
if(type){
if(!Array.isArray(type)){
type=[type];
}
for(var i=0;i<type.length&&!valid;i++){
var assertedType=assertType(value,type[i]);
expectedTypes.push(assertedType.expectedType||'');
valid=assertedType.valid;
}
}

if(!valid){
warn(
getInvalidTypeMessage(name,value,expectedTypes),
vm);

return;
}
var validator=prop.validator;
if(validator){
if(!validator(value)){
warn(
'Invalid prop: custom validator check failed for prop "'+name+'".',
vm);

}
}
}

var simpleCheckRE=/^(String|Number|Boolean|Function|Symbol)$/;

function assertType(value,type){
var valid;
var expectedType=getType(type);
if(simpleCheckRE.test(expectedType)){
var t=typeof value;
valid=t===expectedType.toLowerCase();
// for primitive wrapper objects
if(!valid&&t==='object'){
valid=value instanceof type;
}
}else if(expectedType==='Object'){
valid=isPlainObject(value);
}else if(expectedType==='Array'){
valid=Array.isArray(value);
}else {
valid=value instanceof type;
}
return {
valid:valid,
expectedType:expectedType};

}

/**
 * Use function string name to check built-in types,
 * because a simple equality check will fail when running
 * across different vms / iframes.
 */
function getType(fn){
var match=fn&&fn.toString().match(/^\s*function (\w+)/);
return match?match[1]:'';
}

function isSameType(a,b){
return getType(a)===getType(b);
}

function getTypeIndex(type,expectedTypes){
if(!Array.isArray(expectedTypes)){
return isSameType(expectedTypes,type)?0:-1;
}
for(var i=0,len=expectedTypes.length;i<len;i++){
if(isSameType(expectedTypes[i],type)){
return i;
}
}
return -1;
}

function getInvalidTypeMessage(name,value,expectedTypes){
var message="Invalid prop: type check failed for prop \""+name+"\"."+
" Expected "+expectedTypes.map(capitalize).join(', ');
var expectedType=expectedTypes[0];
var receivedType=toRawType(value);
var expectedValue=styleValue(value,expectedType);
var receivedValue=styleValue(value,receivedType);
// check if we need to specify expected value
if(expectedTypes.length===1&&
isExplicable(expectedType)&&
!isBoolean(expectedType,receivedType)){
message+=" with value "+expectedValue;
}
message+=", got "+receivedType+" ";
// check if we need to specify received value
if(isExplicable(receivedType)){
message+="with value "+receivedValue+".";
}
return message;
}

function styleValue(value,type){
if(type==='String'){
return "\""+value+"\"";
}else if(type==='Number'){
return ""+Number(value);
}else {
return ""+value;
}
}

function isExplicable(value){
var explicitTypes=['string','number','boolean'];
return explicitTypes.some(function(elem){return value.toLowerCase()===elem;});
}

function isBoolean(){
var args=[],len=arguments.length;
while(len--){args[len]=arguments[len];}

return args.some(function(elem){return elem.toLowerCase()==='boolean';});
}

/*  */

function handleError(err,vm,info){
// Deactivate deps tracking while processing error handler to avoid possible infinite rendering.
// See: https://github.com/vuejs/vuex/issues/1505
pushTarget();
try{
if(vm){
var cur=vm;
while(cur=cur.$parent){
var hooks=cur.$options.errorCaptured;
if(hooks){
for(var i=0;i<hooks.length;i++){
try{
var capture=hooks[i].call(cur,err,vm,info)===false;
if(capture){return;}
}catch(e){
globalHandleError(e,cur,'errorCaptured hook');
}
}
}
}
}
globalHandleError(err,vm,info);
}finally{
popTarget();
}
}

function invokeWithErrorHandling(
handler,
context,
args,
vm,
info)
{
var res;
try{
res=args?handler.apply(context,args):handler.call(context);
if(res&&!res._isVue&&isPromise(res)&&!res._handled){
res.catch(function(e){return handleError(e,vm,info+" (Promise/async)");});
// issue #9511
// avoid catch triggering multiple times when nested calls
res._handled=true;
}
}catch(e){
handleError(e,vm,info);
}
return res;
}

function globalHandleError(err,vm,info){
if(config.errorHandler){
try{
return config.errorHandler.call(null,err,vm,info);
}catch(e){
// if the user intentionally throws the original error in the handler,
// do not log it twice
if(e!==err){
logError(e,null,'config.errorHandler');
}
}
}
logError(err,vm,info);
}

function logError(err,vm,info){
{
warn("Error in "+info+": \""+err.toString()+"\"",vm);
}
/* istanbul ignore else */
if((inBrowser||inWeex)&&typeof console!=='undefined'){
console.error(err);
}else {
throw err;
}
}

/*  */

var isUsingMicroTask=false;

var callbacks=[];
var pending=false;

function flushCallbacks(){
pending=false;
var copies=callbacks.slice(0);
callbacks.length=0;
for(var i=0;i<copies.length;i++){
copies[i]();
}
}

// Here we have async deferring wrappers using microtasks.
// In 2.5 we used (macro) tasks (in combination with microtasks).
// However, it has subtle problems when state is changed right before repaint
// (e.g. #6813, out-in transitions).
// Also, using (macro) tasks in event handler would cause some weird behaviors
// that cannot be circumvented (e.g. #7109, #7153, #7546, #7834, #8109).
// So we now use microtasks everywhere, again.
// A major drawback of this tradeoff is that there are some scenarios
// where microtasks have too high a priority and fire in between supposedly
// sequential events (e.g. #4521, #6690, which have workarounds)
// or even between bubbling of the same event (#6566).
var timerFunc;

// The nextTick behavior leverages the microtask queue, which can be accessed
// via either native Promise.then or MutationObserver.
// MutationObserver has wider support, however it is seriously bugged in
// UIWebView in iOS >= 9.3.3 when triggered in touch event handlers. It
// completely stops working after triggering a few times... so, if native
// Promise is available, we will use it:
/* istanbul ignore next, $flow-disable-line */
if(typeof Promise!=='undefined'&&isNative(Promise)){
var p=Promise.resolve();
timerFunc=function timerFunc(){
p.then(flushCallbacks);
// In problematic UIWebViews, Promise.then doesn't completely break, but
// it can get stuck in a weird state where callbacks are pushed into the
// microtask queue but the queue isn't being flushed, until the browser
// needs to do some other work, e.g. handle a timer. Therefore we can
// "force" the microtask queue to be flushed by adding an empty timer.
if(isIOS){setTimeout(noop);}
};
isUsingMicroTask=true;
}else if(!isIE&&typeof MutationObserver!=='undefined'&&(
isNative(MutationObserver)||
// PhantomJS and iOS 7.x
MutationObserver.toString()==='[object MutationObserverConstructor]'))
{
// Use MutationObserver where native Promise is not available,
// e.g. PhantomJS, iOS7, Android 4.4
// (#6466 MutationObserver is unreliable in IE11)
var counter=1;
var observer=new MutationObserver(flushCallbacks);
var textNode=document.createTextNode(String(counter));
observer.observe(textNode,{
characterData:true});

timerFunc=function timerFunc(){
counter=(counter+1)%2;
textNode.data=String(counter);
};
isUsingMicroTask=true;
}else if(typeof setImmediate!=='undefined'&&isNative(setImmediate)){
// Fallback to setImmediate.
// Technically it leverages the (macro) task queue,
// but it is still a better choice than setTimeout.
timerFunc=function timerFunc(){
setImmediate(flushCallbacks);
};
}else {
// Fallback to setTimeout.
timerFunc=function timerFunc(){
setTimeout(flushCallbacks,0);
};
}

function nextTick(cb,ctx){
var _resolve;
callbacks.push(function(){
if(cb){
try{
cb.call(ctx);
}catch(e){
handleError(e,ctx,'nextTick');
}
}else if(_resolve){
_resolve(ctx);
}
});
if(!pending){
pending=true;
timerFunc();
}
// $flow-disable-line
if(!cb&&typeof Promise!=='undefined'){
return new Promise(function(resolve){
_resolve=resolve;
});
}
}

/*  */

var mark;
var measure;

{
var perf=inBrowser&&window.performance;
/* istanbul ignore if */
if(
perf&&
perf.mark&&
perf.measure&&
perf.clearMarks&&
perf.clearMeasures)
{
mark=function mark(tag){return perf.mark(tag);};
measure=function measure(name,startTag,endTag){
perf.measure(name,startTag,endTag);
perf.clearMarks(startTag);
perf.clearMarks(endTag);
// perf.clearMeasures(name)
};
}
}

/* not type checking this file because flow doesn't play well with Proxy */

var initProxy;

{
var allowedGlobals=makeMap(
'Infinity,undefined,NaN,isFinite,isNaN,'+
'parseFloat,parseInt,decodeURI,decodeURIComponent,encodeURI,encodeURIComponent,'+
'Math,Number,Date,Array,Object,Boolean,String,RegExp,Map,Set,JSON,Intl,'+
'require'// for Webpack/Browserify
);

var warnNonPresent=function warnNonPresent(target,key){
warn(
"Property or method \""+key+"\" is not defined on the instance but "+
'referenced during render. Make sure that this property is reactive, '+
'either in the data option, or for class-based components, by '+
'initializing the property. '+
'See: https://vuejs.org/v2/guide/reactivity.html#Declaring-Reactive-Properties.',
target);

};

var warnReservedPrefix=function warnReservedPrefix(target,key){
warn(
"Property \""+key+"\" must be accessed with \"$data."+key+"\" because "+
'properties starting with "$" or "_" are not proxied in the Vue instance to '+
'prevent conflicts with Vue internals. '+
'See: https://vuejs.org/v2/api/#data',
target);

};

var hasProxy=
typeof Proxy!=='undefined'&&isNative(Proxy);

if(hasProxy){
var isBuiltInModifier=makeMap('stop,prevent,self,ctrl,shift,alt,meta,exact');
config.keyCodes=new Proxy(config.keyCodes,{
set:function set(target,key,value){
if(isBuiltInModifier(key)){
warn("Avoid overwriting built-in modifier in config.keyCodes: ."+key);
return false;
}else {
target[key]=value;
return true;
}
}});

}

var hasHandler={
has:function has(target,key){
var has=(key in target);
var isAllowed=allowedGlobals(key)||
typeof key==='string'&&key.charAt(0)==='_'&&!(key in target.$data);
if(!has&&!isAllowed){
if(key in target.$data){warnReservedPrefix(target,key);}else
{warnNonPresent(target,key);}
}
return has||!isAllowed;
}};


var getHandler={
get:function get(target,key){
if(typeof key==='string'&&!(key in target)){
if(key in target.$data){warnReservedPrefix(target,key);}else
{warnNonPresent(target,key);}
}
return target[key];
}};


initProxy=function initProxy(vm){
if(hasProxy){
// determine which proxy handler to use
var options=vm.$options;
var handlers=options.render&&options.render._withStripped?
getHandler:
hasHandler;
vm._renderProxy=new Proxy(vm,handlers);
}else {
vm._renderProxy=vm;
}
};
}

/*  */

var seenObjects=new _Set();

/**
 * Recursively traverse an object to evoke all converted
 * getters, so that every nested property inside the object
 * is collected as a "deep" dependency.
 */
function traverse(val){
_traverse(val,seenObjects);
seenObjects.clear();
}

function _traverse(val,seen){
var i,keys;
var isA=Array.isArray(val);
if(!isA&&!isObject(val)||Object.isFrozen(val)||val instanceof VNode){
return;
}
if(val.__ob__){
var depId=val.__ob__.dep.id;
if(seen.has(depId)){
return;
}
seen.add(depId);
}
if(isA){
i=val.length;
while(i--){_traverse(val[i],seen);}
}else {
keys=Object.keys(val);
i=keys.length;
while(i--){_traverse(val[keys[i]],seen);}
}
}

/*  */

var normalizeEvent=cached(function(name){
var passive=name.charAt(0)==='&';
name=passive?name.slice(1):name;
var once$$1=name.charAt(0)==='~';// Prefixed last, checked first
name=once$$1?name.slice(1):name;
var capture=name.charAt(0)==='!';
name=capture?name.slice(1):name;
return {
name:name,
once:once$$1,
capture:capture,
passive:passive};

});

function createFnInvoker(fns,vm){
function invoker(){
var arguments$1=arguments;

var fns=invoker.fns;
if(Array.isArray(fns)){
var cloned=fns.slice();
for(var i=0;i<cloned.length;i++){
invokeWithErrorHandling(cloned[i],null,arguments$1,vm,"v-on handler");
}
}else {
// return handler return value for single handlers
return invokeWithErrorHandling(fns,null,arguments,vm,"v-on handler");
}
}
invoker.fns=fns;
return invoker;
}

function updateListeners(
on,
oldOn,
add,
remove$$1,
createOnceHandler,
vm)
{
var name,def$$1,cur,old,event;
for(name in on){
def$$1=cur=on[name];
old=oldOn[name];
event=normalizeEvent(name);
if(isUndef(cur)){
warn(
"Invalid handler for event \""+event.name+"\": got "+String(cur),
vm);

}else if(isUndef(old)){
if(isUndef(cur.fns)){
cur=on[name]=createFnInvoker(cur,vm);
}
if(isTrue(event.once)){
cur=on[name]=createOnceHandler(event.name,cur,event.capture);
}
add(event.name,cur,event.capture,event.passive,event.params);
}else if(cur!==old){
old.fns=cur;
on[name]=old;
}
}
for(name in oldOn){
if(isUndef(on[name])){
event=normalizeEvent(name);
remove$$1(event.name,oldOn[name],event.capture);
}
}
}

/*  */

function mergeVNodeHook(def,hookKey,hook){
if(def instanceof VNode){
def=def.data.hook||(def.data.hook={});
}
var invoker;
var oldHook=def[hookKey];

function wrappedHook(){
hook.apply(this,arguments);
// important: remove merged hook to ensure it's called only once
// and prevent memory leak
remove(invoker.fns,wrappedHook);
}

if(isUndef(oldHook)){
// no existing hook
invoker=createFnInvoker([wrappedHook]);
}else {
/* istanbul ignore if */
if(isDef(oldHook.fns)&&isTrue(oldHook.merged)){
// already a merged invoker
invoker=oldHook;
invoker.fns.push(wrappedHook);
}else {
// existing plain hook
invoker=createFnInvoker([oldHook,wrappedHook]);
}
}

invoker.merged=true;
def[hookKey]=invoker;
}

/*  */

function extractPropsFromVNodeData(
data,
Ctor,
tag)
{
// we are only extracting raw values here.
// validation and default values are handled in the child
// component itself.
var propOptions=Ctor.options.props;
if(isUndef(propOptions)){
return;
}
var res={};
var attrs=data.attrs;
var props=data.props;
if(isDef(attrs)||isDef(props)){
for(var key in propOptions){
var altKey=hyphenate(key);
{
var keyInLowerCase=key.toLowerCase();
if(
key!==keyInLowerCase&&
attrs&&hasOwn(attrs,keyInLowerCase))
{
tip(
"Prop \""+keyInLowerCase+"\" is passed to component "+
formatComponentName(tag||Ctor)+", but the declared prop name is"+
" \""+key+"\". "+
"Note that HTML attributes are case-insensitive and camelCased "+
"props need to use their kebab-case equivalents when using in-DOM "+
"templates. You should probably use \""+altKey+"\" instead of \""+key+"\".");

}
}
checkProp(res,props,key,altKey,true)||
checkProp(res,attrs,key,altKey,false);
}
}
return res;
}

function checkProp(
res,
hash,
key,
altKey,
preserve)
{
if(isDef(hash)){
if(hasOwn(hash,key)){
res[key]=hash[key];
if(!preserve){
delete hash[key];
}
return true;
}else if(hasOwn(hash,altKey)){
res[key]=hash[altKey];
if(!preserve){
delete hash[altKey];
}
return true;
}
}
return false;
}

/*  */

// The template compiler attempts to minimize the need for normalization by
// statically analyzing the template at compile time.
//
// For plain HTML markup, normalization can be completely skipped because the
// generated render function is guaranteed to return Array<VNode>. There are
// two cases where extra normalization is needed:

// 1. When the children contains components - because a functional component
// may return an Array instead of a single root. In this case, just a simple
// normalization is needed - if any child is an Array, we flatten the whole
// thing with Array.prototype.concat. It is guaranteed to be only 1-level deep
// because functional components already normalize their own children.
function simpleNormalizeChildren(children){
for(var i=0;i<children.length;i++){
if(Array.isArray(children[i])){
return Array.prototype.concat.apply([],children);
}
}
return children;
}

// 2. When the children contains constructs that always generated nested Arrays,
// e.g. <template>, <slot>, v-for, or when the children is provided by user
// with hand-written render functions / JSX. In such cases a full normalization
// is needed to cater to all possible types of children values.
function normalizeChildren(children){
return isPrimitive(children)?
[createTextVNode(children)]:
Array.isArray(children)?
normalizeArrayChildren(children):
undefined;
}

function isTextNode(node){
return isDef(node)&&isDef(node.text)&&isFalse(node.isComment);
}

function normalizeArrayChildren(children,nestedIndex){
var res=[];
var i,c,lastIndex,last;
for(i=0;i<children.length;i++){
c=children[i];
if(isUndef(c)||typeof c==='boolean'){continue;}
lastIndex=res.length-1;
last=res[lastIndex];
//  nested
if(Array.isArray(c)){
if(c.length>0){
c=normalizeArrayChildren(c,(nestedIndex||'')+"_"+i);
// merge adjacent text nodes
if(isTextNode(c[0])&&isTextNode(last)){
res[lastIndex]=createTextVNode(last.text+c[0].text);
c.shift();
}
res.push.apply(res,c);
}
}else if(isPrimitive(c)){
if(isTextNode(last)){
// merge adjacent text nodes
// this is necessary for SSR hydration because text nodes are
// essentially merged when rendered to HTML strings
res[lastIndex]=createTextVNode(last.text+c);
}else if(c!==''){
// convert primitive to vnode
res.push(createTextVNode(c));
}
}else {
if(isTextNode(c)&&isTextNode(last)){
// merge adjacent text nodes
res[lastIndex]=createTextVNode(last.text+c.text);
}else {
// default key for nested array children (likely generated by v-for)
if(isTrue(children._isVList)&&
isDef(c.tag)&&
isUndef(c.key)&&
isDef(nestedIndex)){
c.key="__vlist"+nestedIndex+"_"+i+"__";
}
res.push(c);
}
}
}
return res;
}

/*  */

function initProvide(vm){
var provide=vm.$options.provide;
if(provide){
vm._provided=typeof provide==='function'?
provide.call(vm):
provide;
}
}

function initInjections(vm){
var result=resolveInject(vm.$options.inject,vm);
if(result){
toggleObserving(false);
Object.keys(result).forEach(function(key){
/* istanbul ignore else */
{
defineReactive$$1(vm,key,result[key],function(){
warn(
"Avoid mutating an injected value directly since the changes will be "+
"overwritten whenever the provided component re-renders. "+
"injection being mutated: \""+key+"\"",
vm);

});
}
});
toggleObserving(true);
}
}

function resolveInject(inject,vm){
if(inject){
// inject is :any because flow is not smart enough to figure out cached
var result=Object.create(null);
var keys=hasSymbol?
Reflect.ownKeys(inject):
Object.keys(inject);

for(var i=0;i<keys.length;i++){
var key=keys[i];
// #6574 in case the inject object is observed...
if(key==='__ob__'){continue;}
var provideKey=inject[key].from;
var source=vm;
while(source){
if(source._provided&&hasOwn(source._provided,provideKey)){
result[key]=source._provided[provideKey];
break;
}
source=source.$parent;
}
if(!source){
if('default'in inject[key]){
var provideDefault=inject[key].default;
result[key]=typeof provideDefault==='function'?
provideDefault.call(vm):
provideDefault;
}else {
warn("Injection \""+key+"\" not found",vm);
}
}
}
return result;
}
}

/*  */



/**
 * Runtime helper for resolving raw children VNodes into a slot object.
 */
function resolveSlots(
children,
context)
{
if(!children||!children.length){
return {};
}
var slots={};
for(var i=0,l=children.length;i<l;i++){
var child=children[i];
var data=child.data;
// remove slot attribute if the node is resolved as a Vue slot node
if(data&&data.attrs&&data.attrs.slot){
delete data.attrs.slot;
}
// named slots should only be respected if the vnode was rendered in the
// same context.
if((child.context===context||child.fnContext===context)&&
data&&data.slot!=null)
{
var name=data.slot;
var slot=slots[name]||(slots[name]=[]);
if(child.tag==='template'){
slot.push.apply(slot,child.children||[]);
}else {
slot.push(child);
}
}else {
(slots.default||(slots.default=[])).push(child);
}
}
// ignore slots that contains only whitespace
for(var name$1 in slots){
if(slots[name$1].every(isWhitespace)){
delete slots[name$1];
}
}
return slots;
}

function isWhitespace(node){
return node.isComment&&!node.asyncFactory||node.text===' ';
}

/*  */

function normalizeScopedSlots(
slots,
normalSlots,
prevSlots)
{
var res;
var hasNormalSlots=Object.keys(normalSlots).length>0;
var isStable=slots?!!slots.$stable:!hasNormalSlots;
var key=slots&&slots.$key;
if(!slots){
res={};
}else if(slots._normalized){
// fast path 1: child component re-render only, parent did not change
return slots._normalized;
}else if(
isStable&&
prevSlots&&
prevSlots!==emptyObject&&
key===prevSlots.$key&&
!hasNormalSlots&&
!prevSlots.$hasNormal)
{
// fast path 2: stable scoped slots w/ no normal slots to proxy,
// only need to normalize once
return prevSlots;
}else {
res={};
for(var key$1 in slots){
if(slots[key$1]&&key$1[0]!=='$'){
res[key$1]=normalizeScopedSlot(normalSlots,key$1,slots[key$1]);
}
}
}
// expose normal slots on scopedSlots
for(var key$2 in normalSlots){
if(!(key$2 in res)){
res[key$2]=proxyNormalSlot(normalSlots,key$2);
}
}
// avoriaz seems to mock a non-extensible $scopedSlots object
// and when that is passed down this would cause an error
if(slots&&Object.isExtensible(slots)){
slots._normalized=res;
}
def(res,'$stable',isStable);
def(res,'$key',key);
def(res,'$hasNormal',hasNormalSlots);
return res;
}

function normalizeScopedSlot(normalSlots,key,fn){
var normalized=function normalized(){
var res=arguments.length?fn.apply(null,arguments):fn({});
res=res&&typeof res==='object'&&!Array.isArray(res)?
[res]// single vnode
:normalizeChildren(res);
return res&&(
res.length===0||
res.length===1&&res[0].isComment// #9658
)?undefined:
res;
};
// this is a slot using the new v-slot syntax without scope. although it is
// compiled as a scoped slot, render fn users would expect it to be present
// on this.$slots because the usage is semantically a normal slot.
if(fn.proxy){
Object.defineProperty(normalSlots,key,{
get:normalized,
enumerable:true,
configurable:true});

}
return normalized;
}

function proxyNormalSlot(slots,key){
return function(){return slots[key];};
}

/*  */

/**
 * Runtime helper for rendering v-for lists.
 */
function renderList(
val,
render)
{
var ret,i,l,keys,key;
if(Array.isArray(val)||typeof val==='string'){
ret=new Array(val.length);
for(i=0,l=val.length;i<l;i++){
ret[i]=render(val[i],i);
}
}else if(typeof val==='number'){
ret=new Array(val);
for(i=0;i<val;i++){
ret[i]=render(i+1,i);
}
}else if(isObject(val)){
if(hasSymbol&&val[Symbol.iterator]){
ret=[];
var iterator=val[Symbol.iterator]();
var result=iterator.next();
while(!result.done){
ret.push(render(result.value,ret.length));
result=iterator.next();
}
}else {
keys=Object.keys(val);
ret=new Array(keys.length);
for(i=0,l=keys.length;i<l;i++){
key=keys[i];
ret[i]=render(val[key],key,i);
}
}
}
if(!isDef(ret)){
ret=[];
}
ret._isVList=true;
return ret;
}

/*  */

/**
 * Runtime helper for rendering <slot>
 */
function renderSlot(
name,
fallback,
props,
bindObject)
{
var scopedSlotFn=this.$scopedSlots[name];
var nodes;
if(scopedSlotFn){// scoped slot
props=props||{};
if(bindObject){
if(!isObject(bindObject)){
warn(
'slot v-bind without argument expects an Object',
this);

}
props=extend(extend({},bindObject),props);
}
nodes=scopedSlotFn(props)||fallback;
}else {
nodes=this.$slots[name]||fallback;
}

var target=props&&props.slot;
if(target){
return this.$createElement('template',{slot:target},nodes);
}else {
return nodes;
}
}

/*  */

/**
 * Runtime helper for resolving filters
 */
function resolveFilter(id){
return resolveAsset(this.$options,'filters',id,true)||identity;
}

/*  */

function isKeyNotMatch(expect,actual){
if(Array.isArray(expect)){
return expect.indexOf(actual)===-1;
}else {
return expect!==actual;
}
}

/**
 * Runtime helper for checking keyCodes from config.
 * exposed as Vue.prototype._k
 * passing in eventKeyName as last argument separately for backwards compat
 */
function checkKeyCodes(
eventKeyCode,
key,
builtInKeyCode,
eventKeyName,
builtInKeyName)
{
var mappedKeyCode=config.keyCodes[key]||builtInKeyCode;
if(builtInKeyName&&eventKeyName&&!config.keyCodes[key]){
return isKeyNotMatch(builtInKeyName,eventKeyName);
}else if(mappedKeyCode){
return isKeyNotMatch(mappedKeyCode,eventKeyCode);
}else if(eventKeyName){
return hyphenate(eventKeyName)!==key;
}
}

/*  */

/**
 * Runtime helper for merging v-bind="object" into a VNode's data.
 */
function bindObjectProps(
data,
tag,
value,
asProp,
isSync)
{
if(value){
if(!isObject(value)){
warn(
'v-bind without argument expects an Object or Array value',
this);

}else {
if(Array.isArray(value)){
value=toObject(value);
}
var hash;
var loop=function loop(key){
if(
key==='class'||
key==='style'||
isReservedAttribute(key))
{
hash=data;
}else {
var type=data.attrs&&data.attrs.type;
hash=asProp||config.mustUseProp(tag,type,key)?
data.domProps||(data.domProps={}):
data.attrs||(data.attrs={});
}
var camelizedKey=camelize(key);
var hyphenatedKey=hyphenate(key);
if(!(camelizedKey in hash)&&!(hyphenatedKey in hash)){
hash[key]=value[key];

if(isSync){
var on=data.on||(data.on={});
on["update:"+key]=function($event){
value[key]=$event;
};
}
}
};

for(var key in value){loop(key);}
}
}
return data;
}

/*  */

/**
 * Runtime helper for rendering static trees.
 */
function renderStatic(
index,
isInFor)
{
var cached=this._staticTrees||(this._staticTrees=[]);
var tree=cached[index];
// if has already-rendered static tree and not inside v-for,
// we can reuse the same tree.
if(tree&&!isInFor){
return tree;
}
// otherwise, render a fresh tree.
tree=cached[index]=this.$options.staticRenderFns[index].call(
this._renderProxy,
null,
this// for render fns generated for functional component templates
);
markStatic(tree,"__static__"+index,false);
return tree;
}

/**
 * Runtime helper for v-once.
 * Effectively it means marking the node as static with a unique key.
 */
function markOnce(
tree,
index,
key)
{
markStatic(tree,"__once__"+index+(key?"_"+key:""),true);
return tree;
}

function markStatic(
tree,
key,
isOnce)
{
if(Array.isArray(tree)){
for(var i=0;i<tree.length;i++){
if(tree[i]&&typeof tree[i]!=='string'){
markStaticNode(tree[i],key+"_"+i,isOnce);
}
}
}else {
markStaticNode(tree,key,isOnce);
}
}

function markStaticNode(node,key,isOnce){
node.isStatic=true;
node.key=key;
node.isOnce=isOnce;
}

/*  */

function bindObjectListeners(data,value){
if(value){
if(!isPlainObject(value)){
warn(
'v-on without argument expects an Object value',
this);

}else {
var on=data.on=data.on?extend({},data.on):{};
for(var key in value){
var existing=on[key];
var ours=value[key];
on[key]=existing?[].concat(existing,ours):ours;
}
}
}
return data;
}

/*  */

function resolveScopedSlots(
fns,// see flow/vnode
res,
// the following are added in 2.6
hasDynamicKeys,
contentHashKey)
{
res=res||{$stable:!hasDynamicKeys};
for(var i=0;i<fns.length;i++){
var slot=fns[i];
if(Array.isArray(slot)){
resolveScopedSlots(slot,res,hasDynamicKeys);
}else if(slot){
// marker for reverse proxying v-slot without scope on this.$slots
if(slot.proxy){
slot.fn.proxy=true;
}
res[slot.key]=slot.fn;
}
}
if(contentHashKey){
res.$key=contentHashKey;
}
return res;
}

/*  */

function bindDynamicKeys(baseObj,values){
for(var i=0;i<values.length;i+=2){
var key=values[i];
if(typeof key==='string'&&key){
baseObj[values[i]]=values[i+1];
}else if(key!==''&&key!==null){
// null is a special value for explicitly removing a binding
warn(
"Invalid value for dynamic directive argument (expected string or null): "+key,
this);

}
}
return baseObj;
}

// helper to dynamically append modifier runtime markers to event names.
// ensure only append when value is already string, otherwise it will be cast
// to string and cause the type check to miss.
function prependModifier(value,symbol){
return typeof value==='string'?symbol+value:value;
}

/*  */

function installRenderHelpers(target){
target._o=markOnce;
target._n=toNumber;
target._s=toString;
target._l=renderList;
target._t=renderSlot;
target._q=looseEqual;
target._i=looseIndexOf;
target._m=renderStatic;
target._f=resolveFilter;
target._k=checkKeyCodes;
target._b=bindObjectProps;
target._v=createTextVNode;
target._e=createEmptyVNode;
target._u=resolveScopedSlots;
target._g=bindObjectListeners;
target._d=bindDynamicKeys;
target._p=prependModifier;
}

/*  */

function FunctionalRenderContext(
data,
props,
children,
parent,
Ctor)
{
var this$1=this;

var options=Ctor.options;
// ensure the createElement function in functional components
// gets a unique context - this is necessary for correct named slot check
var contextVm;
if(hasOwn(parent,'_uid')){
contextVm=Object.create(parent);
// $flow-disable-line
contextVm._original=parent;
}else {
// the context vm passed in is a functional context as well.
// in this case we want to make sure we are able to get a hold to the
// real context instance.
contextVm=parent;
// $flow-disable-line
parent=parent._original;
}
var isCompiled=isTrue(options._compiled);
var needNormalization=!isCompiled;

this.data=data;
this.props=props;
this.children=children;
this.parent=parent;
this.listeners=data.on||emptyObject;
this.injections=resolveInject(options.inject,parent);
this.slots=function(){
if(!this$1.$slots){
normalizeScopedSlots(
data.scopedSlots,
this$1.$slots=resolveSlots(children,parent));

}
return this$1.$slots;
};

Object.defineProperty(this,'scopedSlots',{
enumerable:true,
get:function get(){
return normalizeScopedSlots(data.scopedSlots,this.slots());
}});


// support for compiled functional template
if(isCompiled){
// exposing $options for renderStatic()
this.$options=options;
// pre-resolve slots for renderSlot()
this.$slots=this.slots();
this.$scopedSlots=normalizeScopedSlots(data.scopedSlots,this.$slots);
}

if(options._scopeId){
this._c=function(a,b,c,d){
var vnode=createElement(contextVm,a,b,c,d,needNormalization);
if(vnode&&!Array.isArray(vnode)){
vnode.fnScopeId=options._scopeId;
vnode.fnContext=parent;
}
return vnode;
};
}else {
this._c=function(a,b,c,d){return createElement(contextVm,a,b,c,d,needNormalization);};
}
}

installRenderHelpers(FunctionalRenderContext.prototype);

function createFunctionalComponent(
Ctor,
propsData,
data,
contextVm,
children)
{
var options=Ctor.options;
var props={};
var propOptions=options.props;
if(isDef(propOptions)){
for(var key in propOptions){
props[key]=validateProp(key,propOptions,propsData||emptyObject);
}
}else {
if(isDef(data.attrs)){mergeProps(props,data.attrs);}
if(isDef(data.props)){mergeProps(props,data.props);}
}

var renderContext=new FunctionalRenderContext(
data,
props,
children,
contextVm,
Ctor);


var vnode=options.render.call(null,renderContext._c,renderContext);

if(vnode instanceof VNode){
return cloneAndMarkFunctionalResult(vnode,data,renderContext.parent,options,renderContext);
}else if(Array.isArray(vnode)){
var vnodes=normalizeChildren(vnode)||[];
var res=new Array(vnodes.length);
for(var i=0;i<vnodes.length;i++){
res[i]=cloneAndMarkFunctionalResult(vnodes[i],data,renderContext.parent,options,renderContext);
}
return res;
}
}

function cloneAndMarkFunctionalResult(vnode,data,contextVm,options,renderContext){
// #7817 clone node before setting fnContext, otherwise if the node is reused
// (e.g. it was from a cached normal slot) the fnContext causes named slots
// that should not be matched to match.
var clone=cloneVNode(vnode);
clone.fnContext=contextVm;
clone.fnOptions=options;
{
(clone.devtoolsMeta=clone.devtoolsMeta||{}).renderContext=renderContext;
}
if(data.slot){
(clone.data||(clone.data={})).slot=data.slot;
}
return clone;
}

function mergeProps(to,from){
for(var key in from){
to[camelize(key)]=from[key];
}
}

/*  */

/*  */

/*  */

/*  */

// inline hooks to be invoked on component VNodes during patch
var componentVNodeHooks={
init:function init(vnode,hydrating){
if(
vnode.componentInstance&&
!vnode.componentInstance._isDestroyed&&
vnode.data.keepAlive)
{
// kept-alive components, treat as a patch
var mountedNode=vnode;// work around flow
componentVNodeHooks.prepatch(mountedNode,mountedNode);
}else {
var child=vnode.componentInstance=createComponentInstanceForVnode(
vnode,
activeInstance);

child.$mount(hydrating?vnode.elm:undefined,hydrating);
}
},

prepatch:function prepatch(oldVnode,vnode){
var options=vnode.componentOptions;
var child=vnode.componentInstance=oldVnode.componentInstance;
updateChildComponent(
child,
options.propsData,// updated props
options.listeners,// updated listeners
vnode,// new parent vnode
options.children// new children
);
},

insert:function insert(vnode){
var context=vnode.context;
var componentInstance=vnode.componentInstance;
if(!componentInstance._isMounted){
componentInstance._isMounted=true;
callHook(componentInstance,'mounted');
}
if(vnode.data.keepAlive){
if(context._isMounted){
// vue-router#1212
// During updates, a kept-alive component's child components may
// change, so directly walking the tree here may call activated hooks
// on incorrect children. Instead we push them into a queue which will
// be processed after the whole patch process ended.
queueActivatedComponent(componentInstance);
}else {
activateChildComponent(componentInstance,true/* direct */);
}
}
},

destroy:function destroy(vnode){
var componentInstance=vnode.componentInstance;
if(!componentInstance._isDestroyed){
if(!vnode.data.keepAlive){
componentInstance.$destroy();
}else {
deactivateChildComponent(componentInstance,true/* direct */);
}
}
}};


var hooksToMerge=Object.keys(componentVNodeHooks);

function createComponent(
Ctor,
data,
context,
children,
tag)
{
if(isUndef(Ctor)){
return;
}

var baseCtor=context.$options._base;

// plain options object: turn it into a constructor
if(isObject(Ctor)){
Ctor=baseCtor.extend(Ctor);
}

// if at this stage it's not a constructor or an async component factory,
// reject.
if(typeof Ctor!=='function'){
{
warn("Invalid Component definition: "+String(Ctor),context);
}
return;
}

// async component
var asyncFactory;
if(isUndef(Ctor.cid)){
asyncFactory=Ctor;
Ctor=resolveAsyncComponent(asyncFactory,baseCtor);
if(Ctor===undefined){
// return a placeholder node for async component, which is rendered
// as a comment node but preserves all the raw information for the node.
// the information will be used for async server-rendering and hydration.
return createAsyncPlaceholder(
asyncFactory,
data,
context,
children,
tag);

}
}

data=data||{};

// resolve constructor options in case global mixins are applied after
// component constructor creation
resolveConstructorOptions(Ctor);

// transform component v-model data into props & events
if(isDef(data.model)){
transformModel(Ctor.options,data);
}

// extract props
var propsData=extractPropsFromVNodeData(data,Ctor,tag);

// functional component
if(isTrue(Ctor.options.functional)){
return createFunctionalComponent(Ctor,propsData,data,context,children);
}

// extract listeners, since these needs to be treated as
// child component listeners instead of DOM listeners
var listeners=data.on;
// replace with listeners with .native modifier
// so it gets processed during parent component patch.
data.on=data.nativeOn;

if(isTrue(Ctor.options.abstract)){
// abstract components do not keep anything
// other than props & listeners & slot

// work around flow
var slot=data.slot;
data={};
if(slot){
data.slot=slot;
}
}

// install component management hooks onto the placeholder node
installComponentHooks(data);

// return a placeholder vnode
var name=Ctor.options.name||tag;
var vnode=new VNode(
"vue-component-"+Ctor.cid+(name?"-"+name:''),
data,undefined,undefined,undefined,context,
{Ctor:Ctor,propsData:propsData,listeners:listeners,tag:tag,children:children},
asyncFactory);


return vnode;
}

function createComponentInstanceForVnode(
vnode,// we know it's MountedComponentVNode but flow doesn't
parent// activeInstance in lifecycle state
){
var options={
_isComponent:true,
_parentVnode:vnode,
parent:parent};

// check inline-template render functions
var inlineTemplate=vnode.data.inlineTemplate;
if(isDef(inlineTemplate)){
options.render=inlineTemplate.render;
options.staticRenderFns=inlineTemplate.staticRenderFns;
}
return new vnode.componentOptions.Ctor(options);
}

function installComponentHooks(data){
var hooks=data.hook||(data.hook={});
for(var i=0;i<hooksToMerge.length;i++){
var key=hooksToMerge[i];
var existing=hooks[key];
var toMerge=componentVNodeHooks[key];
if(existing!==toMerge&&!(existing&&existing._merged)){
hooks[key]=existing?mergeHook$1(toMerge,existing):toMerge;
}
}
}

function mergeHook$1(f1,f2){
var merged=function merged(a,b){
// flow complains about extra args which is why we use any
f1(a,b);
f2(a,b);
};
merged._merged=true;
return merged;
}

// transform component v-model info (value and callback) into
// prop and event handler respectively.
function transformModel(options,data){
var prop=options.model&&options.model.prop||'value';
var event=options.model&&options.model.event||'input';
(data.attrs||(data.attrs={}))[prop]=data.model.value;
var on=data.on||(data.on={});
var existing=on[event];
var callback=data.model.callback;
if(isDef(existing)){
if(
Array.isArray(existing)?
existing.indexOf(callback)===-1:
existing!==callback)
{
on[event]=[callback].concat(existing);
}
}else {
on[event]=callback;
}
}

/*  */

var SIMPLE_NORMALIZE=1;
var ALWAYS_NORMALIZE=2;

// wrapper function for providing a more flexible interface
// without getting yelled at by flow
function createElement(
context,
tag,
data,
children,
normalizationType,
alwaysNormalize)
{
if(Array.isArray(data)||isPrimitive(data)){
normalizationType=children;
children=data;
data=undefined;
}
if(isTrue(alwaysNormalize)){
normalizationType=ALWAYS_NORMALIZE;
}
return _createElement(context,tag,data,children,normalizationType);
}

function _createElement(
context,
tag,
data,
children,
normalizationType)
{
if(isDef(data)&&isDef(data.__ob__)){
warn(
"Avoid using observed data object as vnode data: "+JSON.stringify(data)+"\n"+
'Always create fresh vnode data objects in each render!',
context);

return createEmptyVNode();
}
// object syntax in v-bind
if(isDef(data)&&isDef(data.is)){
tag=data.is;
}
if(!tag){
// in case of component :is set to falsy value
return createEmptyVNode();
}
// warn against non-primitive key
if(isDef(data)&&isDef(data.key)&&!isPrimitive(data.key))
{
{
warn(
'Avoid using non-primitive value as key, '+
'use string/number value instead.',
context);

}
}
// support single function children as default scoped slot
if(Array.isArray(children)&&
typeof children[0]==='function')
{
data=data||{};
data.scopedSlots={default:children[0]};
children.length=0;
}
if(normalizationType===ALWAYS_NORMALIZE){
children=normalizeChildren(children);
}else if(normalizationType===SIMPLE_NORMALIZE){
children=simpleNormalizeChildren(children);
}
var vnode,ns;
if(typeof tag==='string'){
var Ctor;
ns=context.$vnode&&context.$vnode.ns||config.getTagNamespace(tag);
if(config.isReservedTag(tag)){
// platform built-in elements
if(isDef(data)&&isDef(data.nativeOn)){
warn(
"The .native modifier for v-on is only valid on components but it was used on <"+tag+">.",
context);

}
vnode=new VNode(
config.parsePlatformTagName(tag),data,children,
undefined,undefined,context);

}else if((!data||!data.pre)&&isDef(Ctor=resolveAsset(context.$options,'components',tag))){
// component
vnode=createComponent(Ctor,data,context,children,tag);
}else {
// unknown or unlisted namespaced elements
// check at runtime because it may get assigned a namespace when its
// parent normalizes children
vnode=new VNode(
tag,data,children,
undefined,undefined,context);

}
}else {
// direct component options / constructor
vnode=createComponent(tag,data,context,children);
}
if(Array.isArray(vnode)){
return vnode;
}else if(isDef(vnode)){
if(isDef(ns)){applyNS(vnode,ns);}
if(isDef(data)){registerDeepBindings(data);}
return vnode;
}else {
return createEmptyVNode();
}
}

function applyNS(vnode,ns,force){
vnode.ns=ns;
if(vnode.tag==='foreignObject'){
// use default namespace inside foreignObject
ns=undefined;
force=true;
}
if(isDef(vnode.children)){
for(var i=0,l=vnode.children.length;i<l;i++){
var child=vnode.children[i];
if(isDef(child.tag)&&(
isUndef(child.ns)||isTrue(force)&&child.tag!=='svg')){
applyNS(child,ns,force);
}
}
}
}

// ref #5318
// necessary to ensure parent re-render when deep bindings like :style and
// :class are used on slot nodes
function registerDeepBindings(data){
if(isObject(data.style)){
traverse(data.style);
}
if(isObject(data.class)){
traverse(data.class);
}
}

/*  */

function initRender(vm){
vm._vnode=null;// the root of the child tree
vm._staticTrees=null;// v-once cached trees
var options=vm.$options;
var parentVnode=vm.$vnode=options._parentVnode;// the placeholder node in parent tree
var renderContext=parentVnode&&parentVnode.context;
vm.$slots=resolveSlots(options._renderChildren,renderContext);
vm.$scopedSlots=emptyObject;
// bind the createElement fn to this instance
// so that we get proper render context inside it.
// args order: tag, data, children, normalizationType, alwaysNormalize
// internal version is used by render functions compiled from templates
vm._c=function(a,b,c,d){return createElement(vm,a,b,c,d,false);};
// normalization is always applied for the public version, used in
// user-written render functions.
vm.$createElement=function(a,b,c,d){return createElement(vm,a,b,c,d,true);};

// $attrs & $listeners are exposed for easier HOC creation.
// they need to be reactive so that HOCs using them are always updated
var parentData=parentVnode&&parentVnode.data;

/* istanbul ignore else */
{
defineReactive$$1(vm,'$attrs',parentData&&parentData.attrs||emptyObject,function(){
!isUpdatingChildComponent&&warn("$attrs is readonly.",vm);
},true);
defineReactive$$1(vm,'$listeners',options._parentListeners||emptyObject,function(){
!isUpdatingChildComponent&&warn("$listeners is readonly.",vm);
},true);
}
}

var currentRenderingInstance=null;

function renderMixin(Vue){
// install runtime convenience helpers
installRenderHelpers(Vue.prototype);

Vue.prototype.$nextTick=function(fn){
return nextTick(fn,this);
};

Vue.prototype._render=function(){
var vm=this;
var ref=vm.$options;
var render=ref.render;
var _parentVnode=ref._parentVnode;

if(_parentVnode){
vm.$scopedSlots=normalizeScopedSlots(
_parentVnode.data.scopedSlots,
vm.$slots,
vm.$scopedSlots);

}

// set parent vnode. this allows render functions to have access
// to the data on the placeholder node.
vm.$vnode=_parentVnode;
// render self
var vnode;
try{
// There's no need to maintain a stack because all render fns are called
// separately from one another. Nested component's render fns are called
// when parent component is patched.
currentRenderingInstance=vm;
vnode=render.call(vm._renderProxy,vm.$createElement);
}catch(e){
handleError(e,vm,"render");
// return error render result,
// or previous vnode to prevent render error causing blank component
/* istanbul ignore else */
if(vm.$options.renderError){
try{
vnode=vm.$options.renderError.call(vm._renderProxy,vm.$createElement,e);
}catch(e){
handleError(e,vm,"renderError");
vnode=vm._vnode;
}
}else {
vnode=vm._vnode;
}
}finally{
currentRenderingInstance=null;
}
// if the returned array contains only a single node, allow it
if(Array.isArray(vnode)&&vnode.length===1){
vnode=vnode[0];
}
// return empty vnode in case the render function errored out
if(!(vnode instanceof VNode)){
if(Array.isArray(vnode)){
warn(
'Multiple root nodes returned from render function. Render function '+
'should return a single root node.',
vm);

}
vnode=createEmptyVNode();
}
// set parent
vnode.parent=_parentVnode;
return vnode;
};
}

/*  */

function ensureCtor(comp,base){
if(
comp.__esModule||
hasSymbol&&comp[Symbol.toStringTag]==='Module')
{
comp=comp.default;
}
return isObject(comp)?
base.extend(comp):
comp;
}

function createAsyncPlaceholder(
factory,
data,
context,
children,
tag)
{
var node=createEmptyVNode();
node.asyncFactory=factory;
node.asyncMeta={data:data,context:context,children:children,tag:tag};
return node;
}

function resolveAsyncComponent(
factory,
baseCtor)
{
if(isTrue(factory.error)&&isDef(factory.errorComp)){
return factory.errorComp;
}

if(isDef(factory.resolved)){
return factory.resolved;
}

var owner=currentRenderingInstance;
if(owner&&isDef(factory.owners)&&factory.owners.indexOf(owner)===-1){
// already pending
factory.owners.push(owner);
}

if(isTrue(factory.loading)&&isDef(factory.loadingComp)){
return factory.loadingComp;
}

if(owner&&!isDef(factory.owners)){
var owners=factory.owners=[owner];
var sync=true;
var timerLoading=null;
var timerTimeout=null;

owner.$on('hook:destroyed',function(){return remove(owners,owner);});

var forceRender=function forceRender(renderCompleted){
for(var i=0,l=owners.length;i<l;i++){
owners[i].$forceUpdate();
}

if(renderCompleted){
owners.length=0;
if(timerLoading!==null){
clearTimeout(timerLoading);
timerLoading=null;
}
if(timerTimeout!==null){
clearTimeout(timerTimeout);
timerTimeout=null;
}
}
};

var resolve=once(function(res){
// cache resolved
factory.resolved=ensureCtor(res,baseCtor);
// invoke callbacks only if this is not a synchronous resolve
// (async resolves are shimmed as synchronous during SSR)
if(!sync){
forceRender(true);
}else {
owners.length=0;
}
});

var reject=once(function(reason){
warn(
"Failed to resolve async component: "+String(factory)+(
reason?"\nReason: "+reason:''));

if(isDef(factory.errorComp)){
factory.error=true;
forceRender(true);
}
});

var res=factory(resolve,reject);

if(isObject(res)){
if(isPromise(res)){
// () => Promise
if(isUndef(factory.resolved)){
res.then(resolve,reject);
}
}else if(isPromise(res.component)){
res.component.then(resolve,reject);

if(isDef(res.error)){
factory.errorComp=ensureCtor(res.error,baseCtor);
}

if(isDef(res.loading)){
factory.loadingComp=ensureCtor(res.loading,baseCtor);
if(res.delay===0){
factory.loading=true;
}else {
timerLoading=setTimeout(function(){
timerLoading=null;
if(isUndef(factory.resolved)&&isUndef(factory.error)){
factory.loading=true;
forceRender(false);
}
},res.delay||200);
}
}

if(isDef(res.timeout)){
timerTimeout=setTimeout(function(){
timerTimeout=null;
if(isUndef(factory.resolved)){
reject(
"timeout ("+res.timeout+"ms)");

}
},res.timeout);
}
}
}

sync=false;
// return in case resolved synchronously
return factory.loading?
factory.loadingComp:
factory.resolved;
}
}

/*  */

function isAsyncPlaceholder(node){
return node.isComment&&node.asyncFactory;
}

/*  */

function getFirstComponentChild(children){
if(Array.isArray(children)){
for(var i=0;i<children.length;i++){
var c=children[i];
if(isDef(c)&&(isDef(c.componentOptions)||isAsyncPlaceholder(c))){
return c;
}
}
}
}

/*  */

/*  */

function initEvents(vm){
vm._events=Object.create(null);
vm._hasHookEvent=false;
// init parent attached events
var listeners=vm.$options._parentListeners;
if(listeners){
updateComponentListeners(vm,listeners);
}
}

var target;

function add(event,fn){
target.$on(event,fn);
}

function remove$1(event,fn){
target.$off(event,fn);
}

function createOnceHandler(event,fn){
var _target=target;
return function onceHandler(){
var res=fn.apply(null,arguments);
if(res!==null){
_target.$off(event,onceHandler);
}
};
}

function updateComponentListeners(
vm,
listeners,
oldListeners)
{
target=vm;
updateListeners(listeners,oldListeners||{},add,remove$1,createOnceHandler,vm);
target=undefined;
}

function eventsMixin(Vue){
var hookRE=/^hook:/;
Vue.prototype.$on=function(event,fn){
var vm=this;
if(Array.isArray(event)){
for(var i=0,l=event.length;i<l;i++){
vm.$on(event[i],fn);
}
}else {
(vm._events[event]||(vm._events[event]=[])).push(fn);
// optimize hook:event cost by using a boolean flag marked at registration
// instead of a hash lookup
if(hookRE.test(event)){
vm._hasHookEvent=true;
}
}
return vm;
};

Vue.prototype.$once=function(event,fn){
var vm=this;
function on(){
vm.$off(event,on);
fn.apply(vm,arguments);
}
on.fn=fn;
vm.$on(event,on);
return vm;
};

Vue.prototype.$off=function(event,fn){
var vm=this;
// all
if(!arguments.length){
vm._events=Object.create(null);
return vm;
}
// array of events
if(Array.isArray(event)){
for(var i$1=0,l=event.length;i$1<l;i$1++){
vm.$off(event[i$1],fn);
}
return vm;
}
// specific event
var cbs=vm._events[event];
if(!cbs){
return vm;
}
if(!fn){
vm._events[event]=null;
return vm;
}
// specific handler
var cb;
var i=cbs.length;
while(i--){
cb=cbs[i];
if(cb===fn||cb.fn===fn){
cbs.splice(i,1);
break;
}
}
return vm;
};

Vue.prototype.$emit=function(event){
var vm=this;
{
var lowerCaseEvent=event.toLowerCase();
if(lowerCaseEvent!==event&&vm._events[lowerCaseEvent]){
tip(
"Event \""+lowerCaseEvent+"\" is emitted in component "+
formatComponentName(vm)+" but the handler is registered for \""+event+"\". "+
"Note that HTML attributes are case-insensitive and you cannot use "+
"v-on to listen to camelCase events when using in-DOM templates. "+
"You should probably use \""+hyphenate(event)+"\" instead of \""+event+"\".");

}
}
var cbs=vm._events[event];
if(cbs){
cbs=cbs.length>1?toArray(cbs):cbs;
var args=toArray(arguments,1);
var info="event handler for \""+event+"\"";
for(var i=0,l=cbs.length;i<l;i++){
invokeWithErrorHandling(cbs[i],vm,args,vm,info);
}
}
return vm;
};
}

/*  */

var activeInstance=null;
var isUpdatingChildComponent=false;

function setActiveInstance(vm){
var prevActiveInstance=activeInstance;
activeInstance=vm;
return function(){
activeInstance=prevActiveInstance;
};
}

function initLifecycle(vm){
var options=vm.$options;

// locate first non-abstract parent
var parent=options.parent;
if(parent&&!options.abstract){
while(parent.$options.abstract&&parent.$parent){
parent=parent.$parent;
}
parent.$children.push(vm);
}

vm.$parent=parent;
vm.$root=parent?parent.$root:vm;

vm.$children=[];
vm.$refs={};

vm._watcher=null;
vm._inactive=null;
vm._directInactive=false;
vm._isMounted=false;
vm._isDestroyed=false;
vm._isBeingDestroyed=false;
}

function lifecycleMixin(Vue){
Vue.prototype._update=function(vnode,hydrating){
var vm=this;
var prevEl=vm.$el;
var prevVnode=vm._vnode;
var restoreActiveInstance=setActiveInstance(vm);
vm._vnode=vnode;
// Vue.prototype.__patch__ is injected in entry points
// based on the rendering backend used.
if(!prevVnode){
// initial render
vm.$el=vm.__patch__(vm.$el,vnode,hydrating,false/* removeOnly */);
}else {
// updates
vm.$el=vm.__patch__(prevVnode,vnode);
}
restoreActiveInstance();
// update __vue__ reference
if(prevEl){
prevEl.__vue__=null;
}
if(vm.$el){
vm.$el.__vue__=vm;
}
// if parent is an HOC, update its $el as well
if(vm.$vnode&&vm.$parent&&vm.$vnode===vm.$parent._vnode){
vm.$parent.$el=vm.$el;
}
// updated hook is called by the scheduler to ensure that children are
// updated in a parent's updated hook.
};

Vue.prototype.$forceUpdate=function(){
var vm=this;
if(vm._watcher){
vm._watcher.update();
}
};

Vue.prototype.$destroy=function(){
var vm=this;
if(vm._isBeingDestroyed){
return;
}
callHook(vm,'beforeDestroy');
vm._isBeingDestroyed=true;
// remove self from parent
var parent=vm.$parent;
if(parent&&!parent._isBeingDestroyed&&!vm.$options.abstract){
remove(parent.$children,vm);
}
// teardown watchers
if(vm._watcher){
vm._watcher.teardown();
}
var i=vm._watchers.length;
while(i--){
vm._watchers[i].teardown();
}
// remove reference from data ob
// frozen object may not have observer.
if(vm._data.__ob__){
vm._data.__ob__.vmCount--;
}
// call the last hook...
vm._isDestroyed=true;
// invoke destroy hooks on current rendered tree
vm.__patch__(vm._vnode,null);
// fire destroyed hook
callHook(vm,'destroyed');
// turn off all instance listeners.
vm.$off();
// remove __vue__ reference
if(vm.$el){
vm.$el.__vue__=null;
}
// release circular reference (#6759)
if(vm.$vnode){
vm.$vnode.parent=null;
}
};
}

function mountComponent(
vm,
el,
hydrating)
{
vm.$el=el;
if(!vm.$options.render){
vm.$options.render=createEmptyVNode;
{
/* istanbul ignore if */
if(vm.$options.template&&vm.$options.template.charAt(0)!=='#'||
vm.$options.el||el){
warn(
'You are using the runtime-only build of Vue where the template '+
'compiler is not available. Either pre-compile the templates into '+
'render functions, or use the compiler-included build.',
vm);

}else {
warn(
'Failed to mount component: template or render function not defined.',
vm);

}
}
}
callHook(vm,'beforeMount');

var updateComponent;
/* istanbul ignore if */
if(config.performance&&mark){
updateComponent=function updateComponent(){
var name=vm._name;
var id=vm._uid;
var startTag="vue-perf-start:"+id;
var endTag="vue-perf-end:"+id;

mark(startTag);
var vnode=vm._render();
mark(endTag);
measure("vue "+name+" render",startTag,endTag);

mark(startTag);
vm._update(vnode,hydrating);
mark(endTag);
measure("vue "+name+" patch",startTag,endTag);
};
}else {
updateComponent=function updateComponent(){
vm._update(vm._render(),hydrating);
};
}

// we set this to vm._watcher inside the watcher's constructor
// since the watcher's initial patch may call $forceUpdate (e.g. inside child
// component's mounted hook), which relies on vm._watcher being already defined
new Watcher(vm,updateComponent,noop,{
before:function before(){
if(vm._isMounted&&!vm._isDestroyed){
callHook(vm,'beforeUpdate');
}
}},
true/* isRenderWatcher */);
hydrating=false;

// manually mounted instance, call mounted on self
// mounted is called for render-created child components in its inserted hook
if(vm.$vnode==null){
vm._isMounted=true;
callHook(vm,'mounted');
}
return vm;
}

function updateChildComponent(
vm,
propsData,
listeners,
parentVnode,
renderChildren)
{
{
isUpdatingChildComponent=true;
}

// determine whether component has slot children
// we need to do this before overwriting $options._renderChildren.

// check if there are dynamic scopedSlots (hand-written or compiled but with
// dynamic slot names). Static scoped slots compiled from template has the
// "$stable" marker.
var newScopedSlots=parentVnode.data.scopedSlots;
var oldScopedSlots=vm.$scopedSlots;
var hasDynamicScopedSlot=!!(
newScopedSlots&&!newScopedSlots.$stable||
oldScopedSlots!==emptyObject&&!oldScopedSlots.$stable||
newScopedSlots&&vm.$scopedSlots.$key!==newScopedSlots.$key);


// Any static slot children from the parent may have changed during parent's
// update. Dynamic scoped slots may also have changed. In such cases, a forced
// update is necessary to ensure correctness.
var needsForceUpdate=!!(
renderChildren||// has new static slots
vm.$options._renderChildren||// has old static slots
hasDynamicScopedSlot);


vm.$options._parentVnode=parentVnode;
vm.$vnode=parentVnode;// update vm's placeholder node without re-render

if(vm._vnode){// update child tree's parent
vm._vnode.parent=parentVnode;
}
vm.$options._renderChildren=renderChildren;

// update $attrs and $listeners hash
// these are also reactive so they may trigger child update if the child
// used them during render
vm.$attrs=parentVnode.data.attrs||emptyObject;
vm.$listeners=listeners||emptyObject;

// update props
if(propsData&&vm.$options.props){
toggleObserving(false);
var props=vm._props;
var propKeys=vm.$options._propKeys||[];
for(var i=0;i<propKeys.length;i++){
var key=propKeys[i];
var propOptions=vm.$options.props;// wtf flow?
props[key]=validateProp(key,propOptions,propsData,vm);
}
toggleObserving(true);
// keep a copy of raw propsData
vm.$options.propsData=propsData;
}

// update listeners
listeners=listeners||emptyObject;
var oldListeners=vm.$options._parentListeners;
vm.$options._parentListeners=listeners;
updateComponentListeners(vm,listeners,oldListeners);

// resolve slots + force update if has children
if(needsForceUpdate){
vm.$slots=resolveSlots(renderChildren,parentVnode.context);
vm.$forceUpdate();
}

{
isUpdatingChildComponent=false;
}
}

function isInInactiveTree(vm){
while(vm&&(vm=vm.$parent)){
if(vm._inactive){return true;}
}
return false;
}

function activateChildComponent(vm,direct){
if(direct){
vm._directInactive=false;
if(isInInactiveTree(vm)){
return;
}
}else if(vm._directInactive){
return;
}
if(vm._inactive||vm._inactive===null){
vm._inactive=false;
for(var i=0;i<vm.$children.length;i++){
activateChildComponent(vm.$children[i]);
}
callHook(vm,'activated');
}
}

function deactivateChildComponent(vm,direct){
if(direct){
vm._directInactive=true;
if(isInInactiveTree(vm)){
return;
}
}
if(!vm._inactive){
vm._inactive=true;
for(var i=0;i<vm.$children.length;i++){
deactivateChildComponent(vm.$children[i]);
}
callHook(vm,'deactivated');
}
}

function callHook(vm,hook){
// #7573 disable dep collection when invoking lifecycle hooks
pushTarget();
var handlers=vm.$options[hook];
var info=hook+" hook";
if(handlers){
for(var i=0,j=handlers.length;i<j;i++){
invokeWithErrorHandling(handlers[i],vm,null,vm,info);
}
}
if(vm._hasHookEvent){
vm.$emit('hook:'+hook);
}
popTarget();
}

/*  */

var MAX_UPDATE_COUNT=100;

var queue=[];
var activatedChildren=[];
var has={};
var circular={};
var waiting=false;
var flushing=false;
var index=0;

/**
 * Reset the scheduler's state.
 */
function resetSchedulerState(){
index=queue.length=activatedChildren.length=0;
has={};
{
circular={};
}
waiting=flushing=false;
}

// Async edge case #6566 requires saving the timestamp when event listeners are
// attached. However, calling performance.now() has a perf overhead especially
// if the page has thousands of event listeners. Instead, we take a timestamp
// every time the scheduler flushes and use that for all event listeners
// attached during that flush.
var currentFlushTimestamp=0;

// Async edge case fix requires storing an event listener's attach timestamp.
var getNow=Date.now;

// Determine what event timestamp the browser is using. Annoyingly, the
// timestamp can either be hi-res (relative to page load) or low-res
// (relative to UNIX epoch), so in order to compare time we have to use the
// same timestamp type when saving the flush timestamp.
// All IE versions use low-res event timestamps, and have problematic clock
// implementations (#9632)
if(inBrowser&&!isIE){
var performance=window.performance;
if(
performance&&
typeof performance.now==='function'&&
getNow()>document.createEvent('Event').timeStamp)
{
// if the event timestamp, although evaluated AFTER the Date.now(), is
// smaller than it, it means the event is using a hi-res timestamp,
// and we need to use the hi-res version for event listener timestamps as
// well.
getNow=function getNow(){return performance.now();};
}
}

/**
 * Flush both queues and run the watchers.
 */
function flushSchedulerQueue(){
currentFlushTimestamp=getNow();
flushing=true;
var watcher,id;

// Sort queue before flush.
// This ensures that:
// 1. Components are updated from parent to child. (because parent is always
//    created before the child)
// 2. A component's user watchers are run before its render watcher (because
//    user watchers are created before the render watcher)
// 3. If a component is destroyed during a parent component's watcher run,
//    its watchers can be skipped.
queue.sort(function(a,b){return a.id-b.id;});

// do not cache length because more watchers might be pushed
// as we run existing watchers
for(index=0;index<queue.length;index++){
watcher=queue[index];
if(watcher.before){
watcher.before();
}
id=watcher.id;
has[id]=null;
watcher.run();
// in dev build, check and stop circular updates.
if(has[id]!=null){
circular[id]=(circular[id]||0)+1;
if(circular[id]>MAX_UPDATE_COUNT){
warn(
'You may have an infinite update loop '+(
watcher.user?
"in watcher with expression \""+watcher.expression+"\"":
"in a component render function."),

watcher.vm);

break;
}
}
}

// keep copies of post queues before resetting state
var activatedQueue=activatedChildren.slice();
var updatedQueue=queue.slice();

resetSchedulerState();

// call component updated and activated hooks
callActivatedHooks(activatedQueue);
callUpdatedHooks(updatedQueue);

// devtool hook
/* istanbul ignore if */
if(devtools&&config.devtools){
devtools.emit('flush');
}
}

function callUpdatedHooks(queue){
var i=queue.length;
while(i--){
var watcher=queue[i];
var vm=watcher.vm;
if(vm._watcher===watcher&&vm._isMounted&&!vm._isDestroyed){
callHook(vm,'updated');
}
}
}

/**
 * Queue a kept-alive component that was activated during patch.
 * The queue will be processed after the entire tree has been patched.
 */
function queueActivatedComponent(vm){
// setting _inactive to false here so that a render function can
// rely on checking whether it's in an inactive tree (e.g. router-view)
vm._inactive=false;
activatedChildren.push(vm);
}

function callActivatedHooks(queue){
for(var i=0;i<queue.length;i++){
queue[i]._inactive=true;
activateChildComponent(queue[i],true/* true */);
}
}

/**
 * Push a watcher into the watcher queue.
 * Jobs with duplicate IDs will be skipped unless it's
 * pushed when the queue is being flushed.
 */
function queueWatcher(watcher){
var id=watcher.id;
if(has[id]==null){
has[id]=true;
if(!flushing){
queue.push(watcher);
}else {
// if already flushing, splice the watcher based on its id
// if already past its id, it will be run next immediately.
var i=queue.length-1;
while(i>index&&queue[i].id>watcher.id){
i--;
}
queue.splice(i+1,0,watcher);
}
// queue the flush
if(!waiting){
waiting=true;

if(!config.async){
flushSchedulerQueue();
return;
}
nextTick(flushSchedulerQueue);
}
}
}

/*  */



var uid$2=0;

/**
 * A watcher parses an expression, collects dependencies,
 * and fires callback when the expression value changes.
 * This is used for both the $watch() api and directives.
 */
var Watcher=function Watcher(
vm,
expOrFn,
cb,
options,
isRenderWatcher)
{
this.vm=vm;
if(isRenderWatcher){
vm._watcher=this;
}
vm._watchers.push(this);
// options
if(options){
this.deep=!!options.deep;
this.user=!!options.user;
this.lazy=!!options.lazy;
this.sync=!!options.sync;
this.before=options.before;
}else {
this.deep=this.user=this.lazy=this.sync=false;
}
this.cb=cb;
this.id=++uid$2;// uid for batching
this.active=true;
this.dirty=this.lazy;// for lazy watchers
this.deps=[];
this.newDeps=[];
this.depIds=new _Set();
this.newDepIds=new _Set();
this.expression=expOrFn.toString();
// parse expression for getter
if(typeof expOrFn==='function'){
this.getter=expOrFn;
}else {
this.getter=parsePath(expOrFn);
if(!this.getter){
this.getter=noop;
warn(
"Failed watching path: \""+expOrFn+"\" "+
'Watcher only accepts simple dot-delimited paths. '+
'For full control, use a function instead.',
vm);

}
}
this.value=this.lazy?
undefined:
this.get();
};

/**
 * Evaluate the getter, and re-collect dependencies.
 */
Watcher.prototype.get=function get(){
pushTarget(this);
var value;
var vm=this.vm;
try{
value=this.getter.call(vm,vm);
}catch(e){
if(this.user){
handleError(e,vm,"getter for watcher \""+this.expression+"\"");
}else {
throw e;
}
}finally{
// "touch" every property so they are all tracked as
// dependencies for deep watching
if(this.deep){
traverse(value);
}
popTarget();
this.cleanupDeps();
}
return value;
};

/**
 * Add a dependency to this directive.
 */
Watcher.prototype.addDep=function addDep(dep){
var id=dep.id;
if(!this.newDepIds.has(id)){
this.newDepIds.add(id);
this.newDeps.push(dep);
if(!this.depIds.has(id)){
dep.addSub(this);
}
}
};

/**
 * Clean up for dependency collection.
 */
Watcher.prototype.cleanupDeps=function cleanupDeps(){
var i=this.deps.length;
while(i--){
var dep=this.deps[i];
if(!this.newDepIds.has(dep.id)){
dep.removeSub(this);
}
}
var tmp=this.depIds;
this.depIds=this.newDepIds;
this.newDepIds=tmp;
this.newDepIds.clear();
tmp=this.deps;
this.deps=this.newDeps;
this.newDeps=tmp;
this.newDeps.length=0;
};

/**
 * Subscriber interface.
 * Will be called when a dependency changes.
 */
Watcher.prototype.update=function update(){
/* istanbul ignore else */
if(this.lazy){
this.dirty=true;
}else if(this.sync){
this.run();
}else {
queueWatcher(this);
}
};

/**
 * Scheduler job interface.
 * Will be called by the scheduler.
 */
Watcher.prototype.run=function run(){
if(this.active){
var value=this.get();
if(
value!==this.value||
// Deep watchers and watchers on Object/Arrays should fire even
// when the value is the same, because the value may
// have mutated.
isObject(value)||
this.deep)
{
// set new value
var oldValue=this.value;
this.value=value;
if(this.user){
try{
this.cb.call(this.vm,value,oldValue);
}catch(e){
handleError(e,this.vm,"callback for watcher \""+this.expression+"\"");
}
}else {
this.cb.call(this.vm,value,oldValue);
}
}
}
};

/**
 * Evaluate the value of the watcher.
 * This only gets called for lazy watchers.
 */
Watcher.prototype.evaluate=function evaluate(){
this.value=this.get();
this.dirty=false;
};

/**
 * Depend on all deps collected by this watcher.
 */
Watcher.prototype.depend=function depend(){
var i=this.deps.length;
while(i--){
this.deps[i].depend();
}
};

/**
 * Remove self from all dependencies' subscriber list.
 */
Watcher.prototype.teardown=function teardown(){
if(this.active){
// remove self from vm's watcher list
// this is a somewhat expensive operation so we skip it
// if the vm is being destroyed.
if(!this.vm._isBeingDestroyed){
remove(this.vm._watchers,this);
}
var i=this.deps.length;
while(i--){
this.deps[i].removeSub(this);
}
this.active=false;
}
};

/*  */

var sharedPropertyDefinition={
enumerable:true,
configurable:true,
get:noop,
set:noop};


function proxy(target,sourceKey,key){
sharedPropertyDefinition.get=function proxyGetter(){
return this[sourceKey][key];
};
sharedPropertyDefinition.set=function proxySetter(val){
this[sourceKey][key]=val;
};
Object.defineProperty(target,key,sharedPropertyDefinition);
}

function initState(vm){
vm._watchers=[];
var opts=vm.$options;
if(opts.props){initProps(vm,opts.props);}
if(opts.methods){initMethods(vm,opts.methods);}
if(opts.data){
initData(vm);
}else {
observe(vm._data={},true/* asRootData */);
}
if(opts.computed){initComputed(vm,opts.computed);}
if(opts.watch&&opts.watch!==nativeWatch){
initWatch(vm,opts.watch);
}
}

function initProps(vm,propsOptions){
var propsData=vm.$options.propsData||{};
var props=vm._props={};
// cache prop keys so that future props updates can iterate using Array
// instead of dynamic object key enumeration.
var keys=vm.$options._propKeys=[];
var isRoot=!vm.$parent;
// root instance props should be converted
if(!isRoot){
toggleObserving(false);
}
var loop=function loop(key){
keys.push(key);
var value=validateProp(key,propsOptions,propsData,vm);
/* istanbul ignore else */
{
var hyphenatedKey=hyphenate(key);
if(isReservedAttribute(hyphenatedKey)||
config.isReservedAttr(hyphenatedKey)){
warn(
"\""+hyphenatedKey+"\" is a reserved attribute and cannot be used as component prop.",
vm);

}
defineReactive$$1(props,key,value,function(){
if(!isRoot&&!isUpdatingChildComponent){
warn(
"Avoid mutating a prop directly since the value will be "+
"overwritten whenever the parent component re-renders. "+
"Instead, use a data or computed property based on the prop's "+
"value. Prop being mutated: \""+key+"\"",
vm);

}
});
}
// static props are already proxied on the component's prototype
// during Vue.extend(). We only need to proxy props defined at
// instantiation here.
if(!(key in vm)){
proxy(vm,"_props",key);
}
};

for(var key in propsOptions){loop(key);}
toggleObserving(true);
}

function initData(vm){
var data=vm.$options.data;
data=vm._data=typeof data==='function'?
getData(data,vm):
data||{};
if(!isPlainObject(data)){
data={};
warn(
'data functions should return an object:\n'+
'https://vuejs.org/v2/guide/components.html#data-Must-Be-a-Function',
vm);

}
// proxy data on instance
var keys=Object.keys(data);
var props=vm.$options.props;
var methods=vm.$options.methods;
var i=keys.length;
while(i--){
var key=keys[i];
{
if(methods&&hasOwn(methods,key)){
warn(
"Method \""+key+"\" has already been defined as a data property.",
vm);

}
}
if(props&&hasOwn(props,key)){
warn(
"The data property \""+key+"\" is already declared as a prop. "+
"Use prop default value instead.",
vm);

}else if(!isReserved(key)){
proxy(vm,"_data",key);
}
}
// observe data
observe(data,true/* asRootData */);
}

function getData(data,vm){
// #7573 disable dep collection when invoking data getters
pushTarget();
try{
return data.call(vm,vm);
}catch(e){
handleError(e,vm,"data()");
return {};
}finally{
popTarget();
}
}

var computedWatcherOptions={lazy:true};

function initComputed(vm,computed){
// $flow-disable-line
var watchers=vm._computedWatchers=Object.create(null);
// computed properties are just getters during SSR
var isSSR=isServerRendering();

for(var key in computed){
var userDef=computed[key];
var getter=typeof userDef==='function'?userDef:userDef.get;
if(getter==null){
warn(
"Getter is missing for computed property \""+key+"\".",
vm);

}

if(!isSSR){
// create internal watcher for the computed property.
watchers[key]=new Watcher(
vm,
getter||noop,
noop,
computedWatcherOptions);

}

// component-defined computed properties are already defined on the
// component prototype. We only need to define computed properties defined
// at instantiation here.
if(!(key in vm)){
defineComputed(vm,key,userDef);
}else {
if(key in vm.$data){
warn("The computed property \""+key+"\" is already defined in data.",vm);
}else if(vm.$options.props&&key in vm.$options.props){
warn("The computed property \""+key+"\" is already defined as a prop.",vm);
}
}
}
}

function defineComputed(
target,
key,
userDef)
{
var shouldCache=!isServerRendering();
if(typeof userDef==='function'){
sharedPropertyDefinition.get=shouldCache?
createComputedGetter(key):
createGetterInvoker(userDef);
sharedPropertyDefinition.set=noop;
}else {
sharedPropertyDefinition.get=userDef.get?
shouldCache&&userDef.cache!==false?
createComputedGetter(key):
createGetterInvoker(userDef.get):
noop;
sharedPropertyDefinition.set=userDef.set||noop;
}
if(sharedPropertyDefinition.set===noop){
sharedPropertyDefinition.set=function(){
warn(
"Computed property \""+key+"\" was assigned to but it has no setter.",
this);

};
}
Object.defineProperty(target,key,sharedPropertyDefinition);
}

function createComputedGetter(key){
return function computedGetter(){
var watcher=this._computedWatchers&&this._computedWatchers[key];
if(watcher){
if(watcher.dirty){
watcher.evaluate();
}
if(Dep.target){
watcher.depend();
}
return watcher.value;
}
};
}

function createGetterInvoker(fn){
return function computedGetter(){
return fn.call(this,this);
};
}

function initMethods(vm,methods){
var props=vm.$options.props;
for(var key in methods){
{
if(typeof methods[key]!=='function'){
warn(
"Method \""+key+"\" has type \""+typeof methods[key]+"\" in the component definition. "+
"Did you reference the function correctly?",
vm);

}
if(props&&hasOwn(props,key)){
warn(
"Method \""+key+"\" has already been defined as a prop.",
vm);

}
if(key in vm&&isReserved(key)){
warn(
"Method \""+key+"\" conflicts with an existing Vue instance method. "+
"Avoid defining component methods that start with _ or $.");

}
}
vm[key]=typeof methods[key]!=='function'?noop:bind(methods[key],vm);
}
}

function initWatch(vm,watch){
for(var key in watch){
var handler=watch[key];
if(Array.isArray(handler)){
for(var i=0;i<handler.length;i++){
createWatcher(vm,key,handler[i]);
}
}else {
createWatcher(vm,key,handler);
}
}
}

function createWatcher(
vm,
expOrFn,
handler,
options)
{
if(isPlainObject(handler)){
options=handler;
handler=handler.handler;
}
if(typeof handler==='string'){
handler=vm[handler];
}
return vm.$watch(expOrFn,handler,options);
}

function stateMixin(Vue){
// flow somehow has problems with directly declared definition object
// when using Object.defineProperty, so we have to procedurally build up
// the object here.
var dataDef={};
dataDef.get=function(){return this._data;};
var propsDef={};
propsDef.get=function(){return this._props;};
{
dataDef.set=function(){
warn(
'Avoid replacing instance root $data. '+
'Use nested data properties instead.',
this);

};
propsDef.set=function(){
warn("$props is readonly.",this);
};
}
Object.defineProperty(Vue.prototype,'$data',dataDef);
Object.defineProperty(Vue.prototype,'$props',propsDef);

Vue.prototype.$set=set;
Vue.prototype.$delete=del;

Vue.prototype.$watch=function(
expOrFn,
cb,
options)
{
var vm=this;
if(isPlainObject(cb)){
return createWatcher(vm,expOrFn,cb,options);
}
options=options||{};
options.user=true;
var watcher=new Watcher(vm,expOrFn,cb,options);
if(options.immediate){
try{
cb.call(vm,watcher.value);
}catch(error){
handleError(error,vm,"callback for immediate watcher \""+watcher.expression+"\"");
}
}
return function unwatchFn(){
watcher.teardown();
};
};
}

/*  */

var uid$3=0;

function initMixin(Vue){
Vue.prototype._init=function(options){
var vm=this;
// a uid
vm._uid=uid$3++;

var startTag,endTag;
/* istanbul ignore if */
if(config.performance&&mark){
startTag="vue-perf-start:"+vm._uid;
endTag="vue-perf-end:"+vm._uid;
mark(startTag);
}

// a flag to avoid this being observed
vm._isVue=true;
// merge options
if(options&&options._isComponent){
// optimize internal component instantiation
// since dynamic options merging is pretty slow, and none of the
// internal component options needs special treatment.
initInternalComponent(vm,options);
}else {
vm.$options=mergeOptions(
resolveConstructorOptions(vm.constructor),
options||{},
vm);

}
/* istanbul ignore else */
{
initProxy(vm);
}
// expose real self
vm._self=vm;
initLifecycle(vm);
initEvents(vm);
initRender(vm);
callHook(vm,'beforeCreate');
initInjections(vm);// resolve injections before data/props
initState(vm);
initProvide(vm);// resolve provide after data/props
callHook(vm,'created');

/* istanbul ignore if */
if(config.performance&&mark){
vm._name=formatComponentName(vm,false);
mark(endTag);
measure("vue "+vm._name+" init",startTag,endTag);
}

if(vm.$options.el){
vm.$mount(vm.$options.el);
}
};
}

function initInternalComponent(vm,options){
var opts=vm.$options=Object.create(vm.constructor.options);
// doing this because it's faster than dynamic enumeration.
var parentVnode=options._parentVnode;
opts.parent=options.parent;
opts._parentVnode=parentVnode;

var vnodeComponentOptions=parentVnode.componentOptions;
opts.propsData=vnodeComponentOptions.propsData;
opts._parentListeners=vnodeComponentOptions.listeners;
opts._renderChildren=vnodeComponentOptions.children;
opts._componentTag=vnodeComponentOptions.tag;

if(options.render){
opts.render=options.render;
opts.staticRenderFns=options.staticRenderFns;
}
}

function resolveConstructorOptions(Ctor){
var options=Ctor.options;
if(Ctor.super){
var superOptions=resolveConstructorOptions(Ctor.super);
var cachedSuperOptions=Ctor.superOptions;
if(superOptions!==cachedSuperOptions){
// super option changed,
// need to resolve new options.
Ctor.superOptions=superOptions;
// check if there are any late-modified/attached options (#4976)
var modifiedOptions=resolveModifiedOptions(Ctor);
// update base extend options
if(modifiedOptions){
extend(Ctor.extendOptions,modifiedOptions);
}
options=Ctor.options=mergeOptions(superOptions,Ctor.extendOptions);
if(options.name){
options.components[options.name]=Ctor;
}
}
}
return options;
}

function resolveModifiedOptions(Ctor){
var modified;
var latest=Ctor.options;
var sealed=Ctor.sealedOptions;
for(var key in latest){
if(latest[key]!==sealed[key]){
if(!modified){modified={};}
modified[key]=latest[key];
}
}
return modified;
}

function Vue(options){
if(!(this instanceof Vue))
{
warn('Vue is a constructor and should be called with the `new` keyword');
}
this._init(options);
}

initMixin(Vue);
stateMixin(Vue);
eventsMixin(Vue);
lifecycleMixin(Vue);
renderMixin(Vue);

/*  */

function initUse(Vue){
Vue.use=function(plugin){
var installedPlugins=this._installedPlugins||(this._installedPlugins=[]);
if(installedPlugins.indexOf(plugin)>-1){
return this;
}

// additional parameters
var args=toArray(arguments,1);
args.unshift(this);
if(typeof plugin.install==='function'){
plugin.install.apply(plugin,args);
}else if(typeof plugin==='function'){
plugin.apply(null,args);
}
installedPlugins.push(plugin);
return this;
};
}

/*  */

function initMixin$1(Vue){
Vue.mixin=function(mixin){
this.options=mergeOptions(this.options,mixin);
return this;
};
}

/*  */

function initExtend(Vue){
/**
   * Each instance constructor, including Vue, has a unique
   * cid. This enables us to create wrapped "child
   * constructors" for prototypal inheritance and cache them.
   */
Vue.cid=0;
var cid=1;

/**
   * Class inheritance
   */
Vue.extend=function(extendOptions){
extendOptions=extendOptions||{};
var Super=this;
var SuperId=Super.cid;
var cachedCtors=extendOptions._Ctor||(extendOptions._Ctor={});
if(cachedCtors[SuperId]){
return cachedCtors[SuperId];
}

var name=extendOptions.name||Super.options.name;
if(name){
validateComponentName(name);
}

var Sub=function VueComponent(options){
this._init(options);
};
Sub.prototype=Object.create(Super.prototype);
Sub.prototype.constructor=Sub;
Sub.cid=cid++;
Sub.options=mergeOptions(
Super.options,
extendOptions);

Sub['super']=Super;

// For props and computed properties, we define the proxy getters on
// the Vue instances at extension time, on the extended prototype. This
// avoids Object.defineProperty calls for each instance created.
if(Sub.options.props){
initProps$1(Sub);
}
if(Sub.options.computed){
initComputed$1(Sub);
}

// allow further extension/mixin/plugin usage
Sub.extend=Super.extend;
Sub.mixin=Super.mixin;
Sub.use=Super.use;

// create asset registers, so extended classes
// can have their private assets too.
ASSET_TYPES.forEach(function(type){
Sub[type]=Super[type];
});
// enable recursive self-lookup
if(name){
Sub.options.components[name]=Sub;
}

// keep a reference to the super options at extension time.
// later at instantiation we can check if Super's options have
// been updated.
Sub.superOptions=Super.options;
Sub.extendOptions=extendOptions;
Sub.sealedOptions=extend({},Sub.options);

// cache constructor
cachedCtors[SuperId]=Sub;
return Sub;
};
}

function initProps$1(Comp){
var props=Comp.options.props;
for(var key in props){
proxy(Comp.prototype,"_props",key);
}
}

function initComputed$1(Comp){
var computed=Comp.options.computed;
for(var key in computed){
defineComputed(Comp.prototype,key,computed[key]);
}
}

/*  */

function initAssetRegisters(Vue){
/**
   * Create asset registration methods.
   */
ASSET_TYPES.forEach(function(type){
Vue[type]=function(
id,
definition)
{
if(!definition){
return this.options[type+'s'][id];
}else {
/* istanbul ignore if */
if(type==='component'){
validateComponentName(id);
}
if(type==='component'&&isPlainObject(definition)){
definition.name=definition.name||id;
definition=this.options._base.extend(definition);
}
if(type==='directive'&&typeof definition==='function'){
definition={bind:definition,update:definition};
}
this.options[type+'s'][id]=definition;
return definition;
}
};
});
}

/*  */



function getComponentName(opts){
return opts&&(opts.Ctor.options.name||opts.tag);
}

function matches(pattern,name){
if(Array.isArray(pattern)){
return pattern.indexOf(name)>-1;
}else if(typeof pattern==='string'){
return pattern.split(',').indexOf(name)>-1;
}else if(isRegExp(pattern)){
return pattern.test(name);
}
/* istanbul ignore next */
return false;
}

function pruneCache(keepAliveInstance,filter){
var cache=keepAliveInstance.cache;
var keys=keepAliveInstance.keys;
var _vnode=keepAliveInstance._vnode;
for(var key in cache){
var cachedNode=cache[key];
if(cachedNode){
var name=getComponentName(cachedNode.componentOptions);
if(name&&!filter(name)){
pruneCacheEntry(cache,key,keys,_vnode);
}
}
}
}

function pruneCacheEntry(
cache,
key,
keys,
current)
{
var cached$$1=cache[key];
if(cached$$1&&(!current||cached$$1.tag!==current.tag)){
cached$$1.componentInstance.$destroy();
}
cache[key]=null;
remove(keys,key);
}

var patternTypes=[String,RegExp,Array];

var KeepAlive={
name:'keep-alive',
abstract:true,

props:{
include:patternTypes,
exclude:patternTypes,
max:[String,Number]},


created:function created(){
this.cache=Object.create(null);
this.keys=[];
},

destroyed:function destroyed(){
for(var key in this.cache){
pruneCacheEntry(this.cache,key,this.keys);
}
},

mounted:function mounted(){
var this$1=this;

this.$watch('include',function(val){
pruneCache(this$1,function(name){return matches(val,name);});
});
this.$watch('exclude',function(val){
pruneCache(this$1,function(name){return !matches(val,name);});
});
},

render:function render(){
var slot=this.$slots.default;
var vnode=getFirstComponentChild(slot);
var componentOptions=vnode&&vnode.componentOptions;
if(componentOptions){
// check pattern
var name=getComponentName(componentOptions);
var ref=this;
var include=ref.include;
var exclude=ref.exclude;
if(
// not included
include&&(!name||!matches(include,name))||
// excluded
exclude&&name&&matches(exclude,name))
{
return vnode;
}

var ref$1=this;
var cache=ref$1.cache;
var keys=ref$1.keys;
var key=vnode.key==null
// same constructor may get registered as different local components
// so cid alone is not enough (#3269)
?componentOptions.Ctor.cid+(componentOptions.tag?"::"+componentOptions.tag:''):
vnode.key;
if(cache[key]){
vnode.componentInstance=cache[key].componentInstance;
// make current key freshest
remove(keys,key);
keys.push(key);
}else {
cache[key]=vnode;
keys.push(key);
// prune oldest entry
if(this.max&&keys.length>parseInt(this.max)){
pruneCacheEntry(cache,keys[0],keys,this._vnode);
}
}

vnode.data.keepAlive=true;
}
return vnode||slot&&slot[0];
}};


var builtInComponents={
KeepAlive:KeepAlive};


/*  */

function initGlobalAPI(Vue){
// config
var configDef={};
configDef.get=function(){return config;};
{
configDef.set=function(){
warn(
'Do not replace the Vue.config object, set individual fields instead.');

};
}
Object.defineProperty(Vue,'config',configDef);

// exposed util methods.
// NOTE: these are not considered part of the public API - avoid relying on
// them unless you are aware of the risk.
Vue.util={
warn:warn,
extend:extend,
mergeOptions:mergeOptions,
defineReactive:defineReactive$$1};


Vue.set=set;
Vue.delete=del;
Vue.nextTick=nextTick;

// 2.6 explicit observable API
Vue.observable=function(obj){
observe(obj);
return obj;
};

Vue.options=Object.create(null);
ASSET_TYPES.forEach(function(type){
Vue.options[type+'s']=Object.create(null);
});

// this is used to identify the "base" constructor to extend all plain-object
// components with in Weex's multi-instance scenarios.
Vue.options._base=Vue;

extend(Vue.options.components,builtInComponents);

initUse(Vue);
initMixin$1(Vue);
initExtend(Vue);
initAssetRegisters(Vue);
}

initGlobalAPI(Vue);

Object.defineProperty(Vue.prototype,'$isServer',{
get:isServerRendering});


Object.defineProperty(Vue.prototype,'$ssrContext',{
get:function get(){
/* istanbul ignore next */
return this.$vnode&&this.$vnode.ssrContext;
}});


// expose FunctionalRenderContext for ssr runtime helper installation
Object.defineProperty(Vue,'FunctionalRenderContext',{
value:FunctionalRenderContext});


Vue.version='2.6.12';

/*  */

// these are reserved for web because they are directly compiled away
// during template compilation
var isReservedAttr=makeMap('style,class');

// attributes that should be using props for binding
var acceptValue=makeMap('input,textarea,option,select,progress');
var mustUseProp=function mustUseProp(tag,type,attr){
return(
attr==='value'&&acceptValue(tag)&&type!=='button'||
attr==='selected'&&tag==='option'||
attr==='checked'&&tag==='input'||
attr==='muted'&&tag==='video');

};

var isEnumeratedAttr=makeMap('contenteditable,draggable,spellcheck');

var isValidContentEditableValue=makeMap('events,caret,typing,plaintext-only');

var convertEnumeratedValue=function convertEnumeratedValue(key,value){
return isFalsyAttrValue(value)||value==='false'?
'false'
// allow arbitrary string value for contenteditable
:key==='contenteditable'&&isValidContentEditableValue(value)?
value:
'true';
};

var isBooleanAttr=makeMap(
'allowfullscreen,async,autofocus,autoplay,checked,compact,controls,declare,'+
'default,defaultchecked,defaultmuted,defaultselected,defer,disabled,'+
'enabled,formnovalidate,hidden,indeterminate,inert,ismap,itemscope,loop,multiple,'+
'muted,nohref,noresize,noshade,novalidate,nowrap,open,pauseonexit,readonly,'+
'required,reversed,scoped,seamless,selected,sortable,translate,'+
'truespeed,typemustmatch,visible');


var xlinkNS='http://www.w3.org/1999/xlink';

var isXlink=function isXlink(name){
return name.charAt(5)===':'&&name.slice(0,5)==='xlink';
};

var getXlinkProp=function getXlinkProp(name){
return isXlink(name)?name.slice(6,name.length):'';
};

var isFalsyAttrValue=function isFalsyAttrValue(val){
return val==null||val===false;
};

/*  */

function genClassForVnode(vnode){
var data=vnode.data;
var parentNode=vnode;
var childNode=vnode;
while(isDef(childNode.componentInstance)){
childNode=childNode.componentInstance._vnode;
if(childNode&&childNode.data){
data=mergeClassData(childNode.data,data);
}
}
while(isDef(parentNode=parentNode.parent)){
if(parentNode&&parentNode.data){
data=mergeClassData(data,parentNode.data);
}
}
return renderClass(data.staticClass,data.class);
}

function mergeClassData(child,parent){
return {
staticClass:concat(child.staticClass,parent.staticClass),
class:isDef(child.class)?
[child.class,parent.class]:
parent.class};

}

function renderClass(
staticClass,
dynamicClass)
{
if(isDef(staticClass)||isDef(dynamicClass)){
return concat(staticClass,stringifyClass(dynamicClass));
}
/* istanbul ignore next */
return '';
}

function concat(a,b){
return a?b?a+' '+b:a:b||'';
}

function stringifyClass(value){
if(Array.isArray(value)){
return stringifyArray(value);
}
if(isObject(value)){
return stringifyObject(value);
}
if(typeof value==='string'){
return value;
}
/* istanbul ignore next */
return '';
}

function stringifyArray(value){
var res='';
var stringified;
for(var i=0,l=value.length;i<l;i++){
if(isDef(stringified=stringifyClass(value[i]))&&stringified!==''){
if(res){res+=' ';}
res+=stringified;
}
}
return res;
}

function stringifyObject(value){
var res='';
for(var key in value){
if(value[key]){
if(res){res+=' ';}
res+=key;
}
}
return res;
}

/*  */

var namespaceMap={
svg:'http://www.w3.org/2000/svg',
math:'http://www.w3.org/1998/Math/MathML'};


var isHTMLTag=makeMap(
'html,body,base,head,link,meta,style,title,'+
'address,article,aside,footer,header,h1,h2,h3,h4,h5,h6,hgroup,nav,section,'+
'div,dd,dl,dt,figcaption,figure,picture,hr,img,li,main,ol,p,pre,ul,'+
'a,b,abbr,bdi,bdo,br,cite,code,data,dfn,em,i,kbd,mark,q,rp,rt,rtc,ruby,'+
's,samp,small,span,strong,sub,sup,time,u,var,wbr,area,audio,map,track,video,'+
'embed,object,param,source,canvas,script,noscript,del,ins,'+
'caption,col,colgroup,table,thead,tbody,td,th,tr,'+
'button,datalist,fieldset,form,input,label,legend,meter,optgroup,option,'+
'output,progress,select,textarea,'+
'details,dialog,menu,menuitem,summary,'+
'content,element,shadow,template,blockquote,iframe,tfoot');


// this map is intentionally selective, only covering SVG elements that may
// contain child elements.
var isSVG=makeMap(
'svg,animate,circle,clippath,cursor,defs,desc,ellipse,filter,font-face,'+
'foreignObject,g,glyph,image,line,marker,mask,missing-glyph,path,pattern,'+
'polygon,polyline,rect,switch,symbol,text,textpath,tspan,use,view',
true);


var isPreTag=function isPreTag(tag){return tag==='pre';};

var isReservedTag=function isReservedTag(tag){
return isHTMLTag(tag)||isSVG(tag);
};

function getTagNamespace(tag){
if(isSVG(tag)){
return 'svg';
}
// basic support for MathML
// note it doesn't support other MathML elements being component roots
if(tag==='math'){
return 'math';
}
}

var unknownElementCache=Object.create(null);
function isUnknownElement(tag){
/* istanbul ignore if */
if(!inBrowser){
return true;
}
if(isReservedTag(tag)){
return false;
}
tag=tag.toLowerCase();
/* istanbul ignore if */
if(unknownElementCache[tag]!=null){
return unknownElementCache[tag];
}
var el=document.createElement(tag);
if(tag.indexOf('-')>-1){
// http://stackoverflow.com/a/28210364/1070244
return unknownElementCache[tag]=
el.constructor===window.HTMLUnknownElement||
el.constructor===window.HTMLElement;

}else {
return unknownElementCache[tag]=/HTMLUnknownElement/.test(el.toString());
}
}

var isTextInputType=makeMap('text,number,password,search,email,tel,url');

/*  */

/**
 * Query an element selector if it's not an element already.
 */
function query(el){
if(typeof el==='string'){
var selected=document.querySelector(el);
if(!selected){
warn(
'Cannot find element: '+el);

return document.createElement('div');
}
return selected;
}else {
return el;
}
}

/*  */

function createElement$1(tagName,vnode){
var elm=document.createElement(tagName);
if(tagName!=='select'){
return elm;
}
// false or null will remove the attribute but undefined will not
if(vnode.data&&vnode.data.attrs&&vnode.data.attrs.multiple!==undefined){
elm.setAttribute('multiple','multiple');
}
return elm;
}

function createElementNS(namespace,tagName){
return document.createElementNS(namespaceMap[namespace],tagName);
}

function createTextNode(text){
return document.createTextNode(text);
}

function createComment(text){
return document.createComment(text);
}

function insertBefore(parentNode,newNode,referenceNode){
parentNode.insertBefore(newNode,referenceNode);
}

function removeChild(node,child){
node.removeChild(child);
}

function appendChild(node,child){
node.appendChild(child);
}

function parentNode(node){
return node.parentNode;
}

function nextSibling(node){
return node.nextSibling;
}

function tagName(node){
return node.tagName;
}

function setTextContent(node,text){
node.textContent=text;
}

function setStyleScope(node,scopeId){
node.setAttribute(scopeId,'');
}

var nodeOps=/*#__PURE__*/Object.freeze({
createElement:createElement$1,
createElementNS:createElementNS,
createTextNode:createTextNode,
createComment:createComment,
insertBefore:insertBefore,
removeChild:removeChild,
appendChild:appendChild,
parentNode:parentNode,
nextSibling:nextSibling,
tagName:tagName,
setTextContent:setTextContent,
setStyleScope:setStyleScope});


/*  */

var ref={
create:function create(_,vnode){
registerRef(vnode);
},
update:function update(oldVnode,vnode){
if(oldVnode.data.ref!==vnode.data.ref){
registerRef(oldVnode,true);
registerRef(vnode);
}
},
destroy:function destroy(vnode){
registerRef(vnode,true);
}};


function registerRef(vnode,isRemoval){
var key=vnode.data.ref;
if(!isDef(key)){return;}

var vm=vnode.context;
var ref=vnode.componentInstance||vnode.elm;
var refs=vm.$refs;
if(isRemoval){
if(Array.isArray(refs[key])){
remove(refs[key],ref);
}else if(refs[key]===ref){
refs[key]=undefined;
}
}else {
if(vnode.data.refInFor){
if(!Array.isArray(refs[key])){
refs[key]=[ref];
}else if(refs[key].indexOf(ref)<0){
// $flow-disable-line
refs[key].push(ref);
}
}else {
refs[key]=ref;
}
}
}

/**
 * Virtual DOM patching algorithm based on Snabbdom by
 * Simon Friis Vindum (@paldepind)
 * Licensed under the MIT License
 * https://github.com/paldepind/snabbdom/blob/master/LICENSE
 *
 * modified by Evan You (@yyx990803)
 *
 * Not type-checking this because this file is perf-critical and the cost
 * of making flow understand it is not worth it.
 */

var emptyNode=new VNode('',{},[]);

var hooks=['create','activate','update','remove','destroy'];

function sameVnode(a,b){
return(
a.key===b.key&&(

a.tag===b.tag&&
a.isComment===b.isComment&&
isDef(a.data)===isDef(b.data)&&
sameInputType(a,b)||

isTrue(a.isAsyncPlaceholder)&&
a.asyncFactory===b.asyncFactory&&
isUndef(b.asyncFactory.error)));



}

function sameInputType(a,b){
if(a.tag!=='input'){return true;}
var i;
var typeA=isDef(i=a.data)&&isDef(i=i.attrs)&&i.type;
var typeB=isDef(i=b.data)&&isDef(i=i.attrs)&&i.type;
return typeA===typeB||isTextInputType(typeA)&&isTextInputType(typeB);
}

function createKeyToOldIdx(children,beginIdx,endIdx){
var i,key;
var map={};
for(i=beginIdx;i<=endIdx;++i){
key=children[i].key;
if(isDef(key)){map[key]=i;}
}
return map;
}

function createPatchFunction(backend){
var i,j;
var cbs={};

var modules=backend.modules;
var nodeOps=backend.nodeOps;

for(i=0;i<hooks.length;++i){
cbs[hooks[i]]=[];
for(j=0;j<modules.length;++j){
if(isDef(modules[j][hooks[i]])){
cbs[hooks[i]].push(modules[j][hooks[i]]);
}
}
}

function emptyNodeAt(elm){
return new VNode(nodeOps.tagName(elm).toLowerCase(),{},[],undefined,elm);
}

function createRmCb(childElm,listeners){
function remove$$1(){
if(--remove$$1.listeners===0){
removeNode(childElm);
}
}
remove$$1.listeners=listeners;
return remove$$1;
}

function removeNode(el){
var parent=nodeOps.parentNode(el);
// element may have already been removed due to v-html / v-text
if(isDef(parent)){
nodeOps.removeChild(parent,el);
}
}

function isUnknownElement$$1(vnode,inVPre){
return(
!inVPre&&
!vnode.ns&&
!(
config.ignoredElements.length&&
config.ignoredElements.some(function(ignore){
return isRegExp(ignore)?
ignore.test(vnode.tag):
ignore===vnode.tag;
}))&&

config.isUnknownElement(vnode.tag));

}

var creatingElmInVPre=0;

function createElm(
vnode,
insertedVnodeQueue,
parentElm,
refElm,
nested,
ownerArray,
index)
{
if(isDef(vnode.elm)&&isDef(ownerArray)){
// This vnode was used in a previous render!
// now it's used as a new node, overwriting its elm would cause
// potential patch errors down the road when it's used as an insertion
// reference node. Instead, we clone the node on-demand before creating
// associated DOM element for it.
vnode=ownerArray[index]=cloneVNode(vnode);
}

vnode.isRootInsert=!nested;// for transition enter check
if(createComponent(vnode,insertedVnodeQueue,parentElm,refElm)){
return;
}

var data=vnode.data;
var children=vnode.children;
var tag=vnode.tag;
if(isDef(tag)){
{
if(data&&data.pre){
creatingElmInVPre++;
}
if(isUnknownElement$$1(vnode,creatingElmInVPre)){
warn(
'Unknown custom element: <'+tag+'> - did you '+
'register the component correctly? For recursive components, '+
'make sure to provide the "name" option.',
vnode.context);

}
}

vnode.elm=vnode.ns?
nodeOps.createElementNS(vnode.ns,tag):
nodeOps.createElement(tag,vnode);
setScope(vnode);

/* istanbul ignore if */
{
createChildren(vnode,children,insertedVnodeQueue);
if(isDef(data)){
invokeCreateHooks(vnode,insertedVnodeQueue);
}
insert(parentElm,vnode.elm,refElm);
}

if(data&&data.pre){
creatingElmInVPre--;
}
}else if(isTrue(vnode.isComment)){
vnode.elm=nodeOps.createComment(vnode.text);
insert(parentElm,vnode.elm,refElm);
}else {
vnode.elm=nodeOps.createTextNode(vnode.text);
insert(parentElm,vnode.elm,refElm);
}
}

function createComponent(vnode,insertedVnodeQueue,parentElm,refElm){
var i=vnode.data;
if(isDef(i)){
var isReactivated=isDef(vnode.componentInstance)&&i.keepAlive;
if(isDef(i=i.hook)&&isDef(i=i.init)){
i(vnode,false/* hydrating */);
}
// after calling the init hook, if the vnode is a child component
// it should've created a child instance and mounted it. the child
// component also has set the placeholder vnode's elm.
// in that case we can just return the element and be done.
if(isDef(vnode.componentInstance)){
initComponent(vnode,insertedVnodeQueue);
insert(parentElm,vnode.elm,refElm);
if(isTrue(isReactivated)){
reactivateComponent(vnode,insertedVnodeQueue,parentElm,refElm);
}
return true;
}
}
}

function initComponent(vnode,insertedVnodeQueue){
if(isDef(vnode.data.pendingInsert)){
insertedVnodeQueue.push.apply(insertedVnodeQueue,vnode.data.pendingInsert);
vnode.data.pendingInsert=null;
}
vnode.elm=vnode.componentInstance.$el;
if(isPatchable(vnode)){
invokeCreateHooks(vnode,insertedVnodeQueue);
setScope(vnode);
}else {
// empty component root.
// skip all element-related modules except for ref (#3455)
registerRef(vnode);
// make sure to invoke the insert hook
insertedVnodeQueue.push(vnode);
}
}

function reactivateComponent(vnode,insertedVnodeQueue,parentElm,refElm){
var i;
// hack for #4339: a reactivated component with inner transition
// does not trigger because the inner node's created hooks are not called
// again. It's not ideal to involve module-specific logic in here but
// there doesn't seem to be a better way to do it.
var innerNode=vnode;
while(innerNode.componentInstance){
innerNode=innerNode.componentInstance._vnode;
if(isDef(i=innerNode.data)&&isDef(i=i.transition)){
for(i=0;i<cbs.activate.length;++i){
cbs.activate[i](emptyNode,innerNode);
}
insertedVnodeQueue.push(innerNode);
break;
}
}
// unlike a newly created component,
// a reactivated keep-alive component doesn't insert itself
insert(parentElm,vnode.elm,refElm);
}

function insert(parent,elm,ref$$1){
if(isDef(parent)){
if(isDef(ref$$1)){
if(nodeOps.parentNode(ref$$1)===parent){
nodeOps.insertBefore(parent,elm,ref$$1);
}
}else {
nodeOps.appendChild(parent,elm);
}
}
}

function createChildren(vnode,children,insertedVnodeQueue){
if(Array.isArray(children)){
{
checkDuplicateKeys(children);
}
for(var i=0;i<children.length;++i){
createElm(children[i],insertedVnodeQueue,vnode.elm,null,true,children,i);
}
}else if(isPrimitive(vnode.text)){
nodeOps.appendChild(vnode.elm,nodeOps.createTextNode(String(vnode.text)));
}
}

function isPatchable(vnode){
while(vnode.componentInstance){
vnode=vnode.componentInstance._vnode;
}
return isDef(vnode.tag);
}

function invokeCreateHooks(vnode,insertedVnodeQueue){
for(var i$1=0;i$1<cbs.create.length;++i$1){
cbs.create[i$1](emptyNode,vnode);
}
i=vnode.data.hook;// Reuse variable
if(isDef(i)){
if(isDef(i.create)){i.create(emptyNode,vnode);}
if(isDef(i.insert)){insertedVnodeQueue.push(vnode);}
}
}

// set scope id attribute for scoped CSS.
// this is implemented as a special case to avoid the overhead
// of going through the normal attribute patching process.
function setScope(vnode){
var i;
if(isDef(i=vnode.fnScopeId)){
nodeOps.setStyleScope(vnode.elm,i);
}else {
var ancestor=vnode;
while(ancestor){
if(isDef(i=ancestor.context)&&isDef(i=i.$options._scopeId)){
nodeOps.setStyleScope(vnode.elm,i);
}
ancestor=ancestor.parent;
}
}
// for slot content they should also get the scopeId from the host instance.
if(isDef(i=activeInstance)&&
i!==vnode.context&&
i!==vnode.fnContext&&
isDef(i=i.$options._scopeId))
{
nodeOps.setStyleScope(vnode.elm,i);
}
}

function addVnodes(parentElm,refElm,vnodes,startIdx,endIdx,insertedVnodeQueue){
for(;startIdx<=endIdx;++startIdx){
createElm(vnodes[startIdx],insertedVnodeQueue,parentElm,refElm,false,vnodes,startIdx);
}
}

function invokeDestroyHook(vnode){
var i,j;
var data=vnode.data;
if(isDef(data)){
if(isDef(i=data.hook)&&isDef(i=i.destroy)){i(vnode);}
for(i=0;i<cbs.destroy.length;++i){cbs.destroy[i](vnode);}
}
if(isDef(i=vnode.children)){
for(j=0;j<vnode.children.length;++j){
invokeDestroyHook(vnode.children[j]);
}
}
}

function removeVnodes(vnodes,startIdx,endIdx){
for(;startIdx<=endIdx;++startIdx){
var ch=vnodes[startIdx];
if(isDef(ch)){
if(isDef(ch.tag)){
removeAndInvokeRemoveHook(ch);
invokeDestroyHook(ch);
}else {// Text node
removeNode(ch.elm);
}
}
}
}

function removeAndInvokeRemoveHook(vnode,rm){
if(isDef(rm)||isDef(vnode.data)){
var i;
var listeners=cbs.remove.length+1;
if(isDef(rm)){
// we have a recursively passed down rm callback
// increase the listeners count
rm.listeners+=listeners;
}else {
// directly removing
rm=createRmCb(vnode.elm,listeners);
}
// recursively invoke hooks on child component root node
if(isDef(i=vnode.componentInstance)&&isDef(i=i._vnode)&&isDef(i.data)){
removeAndInvokeRemoveHook(i,rm);
}
for(i=0;i<cbs.remove.length;++i){
cbs.remove[i](vnode,rm);
}
if(isDef(i=vnode.data.hook)&&isDef(i=i.remove)){
i(vnode,rm);
}else {
rm();
}
}else {
removeNode(vnode.elm);
}
}

function updateChildren(parentElm,oldCh,newCh,insertedVnodeQueue,removeOnly){
var oldStartIdx=0;
var newStartIdx=0;
var oldEndIdx=oldCh.length-1;
var oldStartVnode=oldCh[0];
var oldEndVnode=oldCh[oldEndIdx];
var newEndIdx=newCh.length-1;
var newStartVnode=newCh[0];
var newEndVnode=newCh[newEndIdx];
var oldKeyToIdx,idxInOld,vnodeToMove,refElm;

// removeOnly is a special flag used only by <transition-group>
// to ensure removed elements stay in correct relative positions
// during leaving transitions
var canMove=!removeOnly;

{
checkDuplicateKeys(newCh);
}

while(oldStartIdx<=oldEndIdx&&newStartIdx<=newEndIdx){
if(isUndef(oldStartVnode)){
oldStartVnode=oldCh[++oldStartIdx];// Vnode has been moved left
}else if(isUndef(oldEndVnode)){
oldEndVnode=oldCh[--oldEndIdx];
}else if(sameVnode(oldStartVnode,newStartVnode)){
patchVnode(oldStartVnode,newStartVnode,insertedVnodeQueue,newCh,newStartIdx);
oldStartVnode=oldCh[++oldStartIdx];
newStartVnode=newCh[++newStartIdx];
}else if(sameVnode(oldEndVnode,newEndVnode)){
patchVnode(oldEndVnode,newEndVnode,insertedVnodeQueue,newCh,newEndIdx);
oldEndVnode=oldCh[--oldEndIdx];
newEndVnode=newCh[--newEndIdx];
}else if(sameVnode(oldStartVnode,newEndVnode)){// Vnode moved right
patchVnode(oldStartVnode,newEndVnode,insertedVnodeQueue,newCh,newEndIdx);
canMove&&nodeOps.insertBefore(parentElm,oldStartVnode.elm,nodeOps.nextSibling(oldEndVnode.elm));
oldStartVnode=oldCh[++oldStartIdx];
newEndVnode=newCh[--newEndIdx];
}else if(sameVnode(oldEndVnode,newStartVnode)){// Vnode moved left
patchVnode(oldEndVnode,newStartVnode,insertedVnodeQueue,newCh,newStartIdx);
canMove&&nodeOps.insertBefore(parentElm,oldEndVnode.elm,oldStartVnode.elm);
oldEndVnode=oldCh[--oldEndIdx];
newStartVnode=newCh[++newStartIdx];
}else {
if(isUndef(oldKeyToIdx)){oldKeyToIdx=createKeyToOldIdx(oldCh,oldStartIdx,oldEndIdx);}
idxInOld=isDef(newStartVnode.key)?
oldKeyToIdx[newStartVnode.key]:
findIdxInOld(newStartVnode,oldCh,oldStartIdx,oldEndIdx);
if(isUndef(idxInOld)){// New element
createElm(newStartVnode,insertedVnodeQueue,parentElm,oldStartVnode.elm,false,newCh,newStartIdx);
}else {
vnodeToMove=oldCh[idxInOld];
if(sameVnode(vnodeToMove,newStartVnode)){
patchVnode(vnodeToMove,newStartVnode,insertedVnodeQueue,newCh,newStartIdx);
oldCh[idxInOld]=undefined;
canMove&&nodeOps.insertBefore(parentElm,vnodeToMove.elm,oldStartVnode.elm);
}else {
// same key but different element. treat as new element
createElm(newStartVnode,insertedVnodeQueue,parentElm,oldStartVnode.elm,false,newCh,newStartIdx);
}
}
newStartVnode=newCh[++newStartIdx];
}
}
if(oldStartIdx>oldEndIdx){
refElm=isUndef(newCh[newEndIdx+1])?null:newCh[newEndIdx+1].elm;
addVnodes(parentElm,refElm,newCh,newStartIdx,newEndIdx,insertedVnodeQueue);
}else if(newStartIdx>newEndIdx){
removeVnodes(oldCh,oldStartIdx,oldEndIdx);
}
}

function checkDuplicateKeys(children){
var seenKeys={};
for(var i=0;i<children.length;i++){
var vnode=children[i];
var key=vnode.key;
if(isDef(key)){
if(seenKeys[key]){
warn(
"Duplicate keys detected: '"+key+"'. This may cause an update error.",
vnode.context);

}else {
seenKeys[key]=true;
}
}
}
}

function findIdxInOld(node,oldCh,start,end){
for(var i=start;i<end;i++){
var c=oldCh[i];
if(isDef(c)&&sameVnode(node,c)){return i;}
}
}

function patchVnode(
oldVnode,
vnode,
insertedVnodeQueue,
ownerArray,
index,
removeOnly)
{
if(oldVnode===vnode){
return;
}

if(isDef(vnode.elm)&&isDef(ownerArray)){
// clone reused vnode
vnode=ownerArray[index]=cloneVNode(vnode);
}

var elm=vnode.elm=oldVnode.elm;

if(isTrue(oldVnode.isAsyncPlaceholder)){
if(isDef(vnode.asyncFactory.resolved)){
hydrate(oldVnode.elm,vnode,insertedVnodeQueue);
}else {
vnode.isAsyncPlaceholder=true;
}
return;
}

// reuse element for static trees.
// note we only do this if the vnode is cloned -
// if the new node is not cloned it means the render functions have been
// reset by the hot-reload-api and we need to do a proper re-render.
if(isTrue(vnode.isStatic)&&
isTrue(oldVnode.isStatic)&&
vnode.key===oldVnode.key&&(
isTrue(vnode.isCloned)||isTrue(vnode.isOnce)))
{
vnode.componentInstance=oldVnode.componentInstance;
return;
}

var i;
var data=vnode.data;
if(isDef(data)&&isDef(i=data.hook)&&isDef(i=i.prepatch)){
i(oldVnode,vnode);
}

var oldCh=oldVnode.children;
var ch=vnode.children;
if(isDef(data)&&isPatchable(vnode)){
for(i=0;i<cbs.update.length;++i){cbs.update[i](oldVnode,vnode);}
if(isDef(i=data.hook)&&isDef(i=i.update)){i(oldVnode,vnode);}
}
if(isUndef(vnode.text)){
if(isDef(oldCh)&&isDef(ch)){
if(oldCh!==ch){updateChildren(elm,oldCh,ch,insertedVnodeQueue,removeOnly);}
}else if(isDef(ch)){
{
checkDuplicateKeys(ch);
}
if(isDef(oldVnode.text)){nodeOps.setTextContent(elm,'');}
addVnodes(elm,null,ch,0,ch.length-1,insertedVnodeQueue);
}else if(isDef(oldCh)){
removeVnodes(oldCh,0,oldCh.length-1);
}else if(isDef(oldVnode.text)){
nodeOps.setTextContent(elm,'');
}
}else if(oldVnode.text!==vnode.text){
nodeOps.setTextContent(elm,vnode.text);
}
if(isDef(data)){
if(isDef(i=data.hook)&&isDef(i=i.postpatch)){i(oldVnode,vnode);}
}
}

function invokeInsertHook(vnode,queue,initial){
// delay insert hooks for component root nodes, invoke them after the
// element is really inserted
if(isTrue(initial)&&isDef(vnode.parent)){
vnode.parent.data.pendingInsert=queue;
}else {
for(var i=0;i<queue.length;++i){
queue[i].data.hook.insert(queue[i]);
}
}
}

var hydrationBailed=false;
// list of modules that can skip create hook during hydration because they
// are already rendered on the client or has no need for initialization
// Note: style is excluded because it relies on initial clone for future
// deep updates (#7063).
var isRenderedModule=makeMap('attrs,class,staticClass,staticStyle,key');

// Note: this is a browser-only function so we can assume elms are DOM nodes.
function hydrate(elm,vnode,insertedVnodeQueue,inVPre){
var i;
var tag=vnode.tag;
var data=vnode.data;
var children=vnode.children;
inVPre=inVPre||data&&data.pre;
vnode.elm=elm;

if(isTrue(vnode.isComment)&&isDef(vnode.asyncFactory)){
vnode.isAsyncPlaceholder=true;
return true;
}
// assert node match
{
if(!assertNodeMatch(elm,vnode,inVPre)){
return false;
}
}
if(isDef(data)){
if(isDef(i=data.hook)&&isDef(i=i.init)){i(vnode,true/* hydrating */);}
if(isDef(i=vnode.componentInstance)){
// child component. it should have hydrated its own tree.
initComponent(vnode,insertedVnodeQueue);
return true;
}
}
if(isDef(tag)){
if(isDef(children)){
// empty element, allow client to pick up and populate children
if(!elm.hasChildNodes()){
createChildren(vnode,children,insertedVnodeQueue);
}else {
// v-html and domProps: innerHTML
if(isDef(i=data)&&isDef(i=i.domProps)&&isDef(i=i.innerHTML)){
if(i!==elm.innerHTML){
/* istanbul ignore if */
if(typeof console!=='undefined'&&
!hydrationBailed)
{
hydrationBailed=true;
console.warn('Parent: ',elm);
console.warn('server innerHTML: ',i);
console.warn('client innerHTML: ',elm.innerHTML);
}
return false;
}
}else {
// iterate and compare children lists
var childrenMatch=true;
var childNode=elm.firstChild;
for(var i$1=0;i$1<children.length;i$1++){
if(!childNode||!hydrate(childNode,children[i$1],insertedVnodeQueue,inVPre)){
childrenMatch=false;
break;
}
childNode=childNode.nextSibling;
}
// if childNode is not null, it means the actual childNodes list is
// longer than the virtual children list.
if(!childrenMatch||childNode){
/* istanbul ignore if */
if(typeof console!=='undefined'&&
!hydrationBailed)
{
hydrationBailed=true;
console.warn('Parent: ',elm);
console.warn('Mismatching childNodes vs. VNodes: ',elm.childNodes,children);
}
return false;
}
}
}
}
if(isDef(data)){
var fullInvoke=false;
for(var key in data){
if(!isRenderedModule(key)){
fullInvoke=true;
invokeCreateHooks(vnode,insertedVnodeQueue);
break;
}
}
if(!fullInvoke&&data['class']){
// ensure collecting deps for deep class bindings for future updates
traverse(data['class']);
}
}
}else if(elm.data!==vnode.text){
elm.data=vnode.text;
}
return true;
}

function assertNodeMatch(node,vnode,inVPre){
if(isDef(vnode.tag)){
return vnode.tag.indexOf('vue-component')===0||
!isUnknownElement$$1(vnode,inVPre)&&
vnode.tag.toLowerCase()===(node.tagName&&node.tagName.toLowerCase());

}else {
return node.nodeType===(vnode.isComment?8:3);
}
}

return function patch(oldVnode,vnode,hydrating,removeOnly){
if(isUndef(vnode)){
if(isDef(oldVnode)){invokeDestroyHook(oldVnode);}
return;
}

var isInitialPatch=false;
var insertedVnodeQueue=[];

if(isUndef(oldVnode)){
// empty mount (likely as component), create new root element
isInitialPatch=true;
createElm(vnode,insertedVnodeQueue);
}else {
var isRealElement=isDef(oldVnode.nodeType);
if(!isRealElement&&sameVnode(oldVnode,vnode)){
// patch existing root node
patchVnode(oldVnode,vnode,insertedVnodeQueue,null,null,removeOnly);
}else {
if(isRealElement){
// mounting to a real element
// check if this is server-rendered content and if we can perform
// a successful hydration.
if(oldVnode.nodeType===1&&oldVnode.hasAttribute(SSR_ATTR)){
oldVnode.removeAttribute(SSR_ATTR);
hydrating=true;
}
if(isTrue(hydrating)){
if(hydrate(oldVnode,vnode,insertedVnodeQueue)){
invokeInsertHook(vnode,insertedVnodeQueue,true);
return oldVnode;
}else {
warn(
'The client-side rendered virtual DOM tree is not matching '+
'server-rendered content. This is likely caused by incorrect '+
'HTML markup, for example nesting block-level elements inside '+
'<p>, or missing <tbody>. Bailing hydration and performing '+
'full client-side render.');

}
}
// either not server-rendered, or hydration failed.
// create an empty node and replace it
oldVnode=emptyNodeAt(oldVnode);
}

// replacing existing element
var oldElm=oldVnode.elm;
var parentElm=nodeOps.parentNode(oldElm);

// create new node
createElm(
vnode,
insertedVnodeQueue,
// extremely rare edge case: do not insert if old element is in a
// leaving transition. Only happens when combining transition +
// keep-alive + HOCs. (#4590)
oldElm._leaveCb?null:parentElm,
nodeOps.nextSibling(oldElm));


// update parent placeholder node element, recursively
if(isDef(vnode.parent)){
var ancestor=vnode.parent;
var patchable=isPatchable(vnode);
while(ancestor){
for(var i=0;i<cbs.destroy.length;++i){
cbs.destroy[i](ancestor);
}
ancestor.elm=vnode.elm;
if(patchable){
for(var i$1=0;i$1<cbs.create.length;++i$1){
cbs.create[i$1](emptyNode,ancestor);
}
// #6513
// invoke insert hooks that may have been merged by create hooks.
// e.g. for directives that uses the "inserted" hook.
var insert=ancestor.data.hook.insert;
if(insert.merged){
// start at index 1 to avoid re-invoking component mounted hook
for(var i$2=1;i$2<insert.fns.length;i$2++){
insert.fns[i$2]();
}
}
}else {
registerRef(ancestor);
}
ancestor=ancestor.parent;
}
}

// destroy old node
if(isDef(parentElm)){
removeVnodes([oldVnode],0,0);
}else if(isDef(oldVnode.tag)){
invokeDestroyHook(oldVnode);
}
}
}

invokeInsertHook(vnode,insertedVnodeQueue,isInitialPatch);
return vnode.elm;
};
}

/*  */

var directives={
create:updateDirectives,
update:updateDirectives,
destroy:function unbindDirectives(vnode){
updateDirectives(vnode,emptyNode);
}};


function updateDirectives(oldVnode,vnode){
if(oldVnode.data.directives||vnode.data.directives){
_update(oldVnode,vnode);
}
}

function _update(oldVnode,vnode){
var isCreate=oldVnode===emptyNode;
var isDestroy=vnode===emptyNode;
var oldDirs=normalizeDirectives$1(oldVnode.data.directives,oldVnode.context);
var newDirs=normalizeDirectives$1(vnode.data.directives,vnode.context);

var dirsWithInsert=[];
var dirsWithPostpatch=[];

var key,oldDir,dir;
for(key in newDirs){
oldDir=oldDirs[key];
dir=newDirs[key];
if(!oldDir){
// new directive, bind
callHook$1(dir,'bind',vnode,oldVnode);
if(dir.def&&dir.def.inserted){
dirsWithInsert.push(dir);
}
}else {
// existing directive, update
dir.oldValue=oldDir.value;
dir.oldArg=oldDir.arg;
callHook$1(dir,'update',vnode,oldVnode);
if(dir.def&&dir.def.componentUpdated){
dirsWithPostpatch.push(dir);
}
}
}

if(dirsWithInsert.length){
var callInsert=function callInsert(){
for(var i=0;i<dirsWithInsert.length;i++){
callHook$1(dirsWithInsert[i],'inserted',vnode,oldVnode);
}
};
if(isCreate){
mergeVNodeHook(vnode,'insert',callInsert);
}else {
callInsert();
}
}

if(dirsWithPostpatch.length){
mergeVNodeHook(vnode,'postpatch',function(){
for(var i=0;i<dirsWithPostpatch.length;i++){
callHook$1(dirsWithPostpatch[i],'componentUpdated',vnode,oldVnode);
}
});
}

if(!isCreate){
for(key in oldDirs){
if(!newDirs[key]){
// no longer present, unbind
callHook$1(oldDirs[key],'unbind',oldVnode,oldVnode,isDestroy);
}
}
}
}

var emptyModifiers=Object.create(null);

function normalizeDirectives$1(
dirs,
vm)
{
var res=Object.create(null);
if(!dirs){
// $flow-disable-line
return res;
}
var i,dir;
for(i=0;i<dirs.length;i++){
dir=dirs[i];
if(!dir.modifiers){
// $flow-disable-line
dir.modifiers=emptyModifiers;
}
res[getRawDirName(dir)]=dir;
dir.def=resolveAsset(vm.$options,'directives',dir.name,true);
}
// $flow-disable-line
return res;
}

function getRawDirName(dir){
return dir.rawName||dir.name+"."+Object.keys(dir.modifiers||{}).join('.');
}

function callHook$1(dir,hook,vnode,oldVnode,isDestroy){
var fn=dir.def&&dir.def[hook];
if(fn){
try{
fn(vnode.elm,dir,vnode,oldVnode,isDestroy);
}catch(e){
handleError(e,vnode.context,"directive "+dir.name+" "+hook+" hook");
}
}
}

var baseModules=[
ref,
directives];


/*  */

function updateAttrs(oldVnode,vnode){
var opts=vnode.componentOptions;
if(isDef(opts)&&opts.Ctor.options.inheritAttrs===false){
return;
}
if(isUndef(oldVnode.data.attrs)&&isUndef(vnode.data.attrs)){
return;
}
var key,cur,old;
var elm=vnode.elm;
var oldAttrs=oldVnode.data.attrs||{};
var attrs=vnode.data.attrs||{};
// clone observed objects, as the user probably wants to mutate it
if(isDef(attrs.__ob__)){
attrs=vnode.data.attrs=extend({},attrs);
}

for(key in attrs){
cur=attrs[key];
old=oldAttrs[key];
if(old!==cur){
setAttr(elm,key,cur);
}
}
// #4391: in IE9, setting type can reset value for input[type=radio]
// #6666: IE/Edge forces progress value down to 1 before setting a max
/* istanbul ignore if */
if((isIE||isEdge)&&attrs.value!==oldAttrs.value){
setAttr(elm,'value',attrs.value);
}
for(key in oldAttrs){
if(isUndef(attrs[key])){
if(isXlink(key)){
elm.removeAttributeNS(xlinkNS,getXlinkProp(key));
}else if(!isEnumeratedAttr(key)){
elm.removeAttribute(key);
}
}
}
}

function setAttr(el,key,value){
if(el.tagName.indexOf('-')>-1){
baseSetAttr(el,key,value);
}else if(isBooleanAttr(key)){
// set attribute for blank value
// e.g. <option disabled>Select one</option>
if(isFalsyAttrValue(value)){
el.removeAttribute(key);
}else {
// technically allowfullscreen is a boolean attribute for <iframe>,
// but Flash expects a value of "true" when used on <embed> tag
value=key==='allowfullscreen'&&el.tagName==='EMBED'?
'true':
key;
el.setAttribute(key,value);
}
}else if(isEnumeratedAttr(key)){
el.setAttribute(key,convertEnumeratedValue(key,value));
}else if(isXlink(key)){
if(isFalsyAttrValue(value)){
el.removeAttributeNS(xlinkNS,getXlinkProp(key));
}else {
el.setAttributeNS(xlinkNS,key,value);
}
}else {
baseSetAttr(el,key,value);
}
}

function baseSetAttr(el,key,value){
if(isFalsyAttrValue(value)){
el.removeAttribute(key);
}else {
// #7138: IE10 & 11 fires input event when setting placeholder on
// <textarea>... block the first input event and remove the blocker
// immediately.
/* istanbul ignore if */
if(
isIE&&!isIE9&&
el.tagName==='TEXTAREA'&&
key==='placeholder'&&value!==''&&!el.__ieph)
{
var blocker=function blocker(e){
e.stopImmediatePropagation();
el.removeEventListener('input',blocker);
};
el.addEventListener('input',blocker);
// $flow-disable-line
el.__ieph=true;/* IE placeholder patched */
}
el.setAttribute(key,value);
}
}

var attrs={
create:updateAttrs,
update:updateAttrs};


/*  */

function updateClass(oldVnode,vnode){
var el=vnode.elm;
var data=vnode.data;
var oldData=oldVnode.data;
if(
isUndef(data.staticClass)&&
isUndef(data.class)&&(
isUndef(oldData)||
isUndef(oldData.staticClass)&&
isUndef(oldData.class)))


{
return;
}

var cls=genClassForVnode(vnode);

// handle transition classes
var transitionClass=el._transitionClasses;
if(isDef(transitionClass)){
cls=concat(cls,stringifyClass(transitionClass));
}

// set the class
if(cls!==el._prevClass){
el.setAttribute('class',cls);
el._prevClass=cls;
}
}

var klass={
create:updateClass,
update:updateClass};


/*  */

var validDivisionCharRE=/[\w).+\-_$\]]/;

function parseFilters(exp){
var inSingle=false;
var inDouble=false;
var inTemplateString=false;
var inRegex=false;
var curly=0;
var square=0;
var paren=0;
var lastFilterIndex=0;
var c,prev,i,expression,filters;

for(i=0;i<exp.length;i++){
prev=c;
c=exp.charCodeAt(i);
if(inSingle){
if(c===0x27&&prev!==0x5C){inSingle=false;}
}else if(inDouble){
if(c===0x22&&prev!==0x5C){inDouble=false;}
}else if(inTemplateString){
if(c===0x60&&prev!==0x5C){inTemplateString=false;}
}else if(inRegex){
if(c===0x2f&&prev!==0x5C){inRegex=false;}
}else if(
c===0x7C&&// pipe
exp.charCodeAt(i+1)!==0x7C&&
exp.charCodeAt(i-1)!==0x7C&&
!curly&&!square&&!paren)
{
if(expression===undefined){
// first filter, end of expression
lastFilterIndex=i+1;
expression=exp.slice(0,i).trim();
}else {
pushFilter();
}
}else {
switch(c){
case 0x22:inDouble=true;break;// "
case 0x27:inSingle=true;break;// '
case 0x60:inTemplateString=true;break;// `
case 0x28:paren++;break;// (
case 0x29:paren--;break;// )
case 0x5B:square++;break;// [
case 0x5D:square--;break;// ]
case 0x7B:curly++;break;// {
case 0x7D:curly--;break;// }
}
if(c===0x2f){// /
var j=i-1;
var p=void 0;
// find first non-whitespace prev char
for(;j>=0;j--){
p=exp.charAt(j);
if(p!==' '){break;}
}
if(!p||!validDivisionCharRE.test(p)){
inRegex=true;
}
}
}
}

if(expression===undefined){
expression=exp.slice(0,i).trim();
}else if(lastFilterIndex!==0){
pushFilter();
}

function pushFilter(){
(filters||(filters=[])).push(exp.slice(lastFilterIndex,i).trim());
lastFilterIndex=i+1;
}

if(filters){
for(i=0;i<filters.length;i++){
expression=wrapFilter(expression,filters[i]);
}
}

return expression;
}

function wrapFilter(exp,filter){
var i=filter.indexOf('(');
if(i<0){
// _f: resolveFilter
return "_f(\""+filter+"\")("+exp+")";
}else {
var name=filter.slice(0,i);
var args=filter.slice(i+1);
return "_f(\""+name+"\")("+exp+(args!==')'?','+args:args);
}
}

/*  */



/* eslint-disable no-unused-vars */
function baseWarn(msg,range){
console.error("[Vue compiler]: "+msg);
}
/* eslint-enable no-unused-vars */

function pluckModuleFunction(
modules,
key)
{
return modules?
modules.map(function(m){return m[key];}).filter(function(_){return _;}):
[];
}

function addProp(el,name,value,range,dynamic){
(el.props||(el.props=[])).push(rangeSetItem({name:name,value:value,dynamic:dynamic},range));
el.plain=false;
}

function addAttr(el,name,value,range,dynamic){
var attrs=dynamic?
el.dynamicAttrs||(el.dynamicAttrs=[]):
el.attrs||(el.attrs=[]);
attrs.push(rangeSetItem({name:name,value:value,dynamic:dynamic},range));
el.plain=false;
}

// add a raw attr (use this in preTransforms)
function addRawAttr(el,name,value,range){
el.attrsMap[name]=value;
el.attrsList.push(rangeSetItem({name:name,value:value},range));
}

function addDirective(
el,
name,
rawName,
value,
arg,
isDynamicArg,
modifiers,
range)
{
(el.directives||(el.directives=[])).push(rangeSetItem({
name:name,
rawName:rawName,
value:value,
arg:arg,
isDynamicArg:isDynamicArg,
modifiers:modifiers},
range));
el.plain=false;
}

function prependModifierMarker(symbol,name,dynamic){
return dynamic?
"_p("+name+",\""+symbol+"\")":
symbol+name;// mark the event as captured
}

function addHandler(
el,
name,
value,
modifiers,
important,
warn,
range,
dynamic)
{
modifiers=modifiers||emptyObject;
// warn prevent and passive modifier
/* istanbul ignore if */
if(
warn&&
modifiers.prevent&&modifiers.passive)
{
warn(
'passive and prevent can\'t be used together. '+
'Passive handler can\'t prevent default event.',
range);

}

// normalize click.right and click.middle since they don't actually fire
// this is technically browser-specific, but at least for now browsers are
// the only target envs that have right/middle clicks.
if(modifiers.right){
if(dynamic){
name="("+name+")==='click'?'contextmenu':("+name+")";
}else if(name==='click'){
name='contextmenu';
delete modifiers.right;
}
}else if(modifiers.middle){
if(dynamic){
name="("+name+")==='click'?'mouseup':("+name+")";
}else if(name==='click'){
name='mouseup';
}
}

// check capture modifier
if(modifiers.capture){
delete modifiers.capture;
name=prependModifierMarker('!',name,dynamic);
}
if(modifiers.once){
delete modifiers.once;
name=prependModifierMarker('~',name,dynamic);
}
/* istanbul ignore if */
if(modifiers.passive){
delete modifiers.passive;
name=prependModifierMarker('&',name,dynamic);
}

var events;
if(modifiers.native){
delete modifiers.native;
events=el.nativeEvents||(el.nativeEvents={});
}else {
events=el.events||(el.events={});
}

var newHandler=rangeSetItem({value:value.trim(),dynamic:dynamic},range);
if(modifiers!==emptyObject){
newHandler.modifiers=modifiers;
}

var handlers=events[name];
/* istanbul ignore if */
if(Array.isArray(handlers)){
important?handlers.unshift(newHandler):handlers.push(newHandler);
}else if(handlers){
events[name]=important?[newHandler,handlers]:[handlers,newHandler];
}else {
events[name]=newHandler;
}

el.plain=false;
}

function getRawBindingAttr(
el,
name)
{
return el.rawAttrsMap[':'+name]||
el.rawAttrsMap['v-bind:'+name]||
el.rawAttrsMap[name];
}

function getBindingAttr(
el,
name,
getStatic)
{
var dynamicValue=
getAndRemoveAttr(el,':'+name)||
getAndRemoveAttr(el,'v-bind:'+name);
if(dynamicValue!=null){
return parseFilters(dynamicValue);
}else if(getStatic!==false){
var staticValue=getAndRemoveAttr(el,name);
if(staticValue!=null){
return JSON.stringify(staticValue);
}
}
}

// note: this only removes the attr from the Array (attrsList) so that it
// doesn't get processed by processAttrs.
// By default it does NOT remove it from the map (attrsMap) because the map is
// needed during codegen.
function getAndRemoveAttr(
el,
name,
removeFromMap)
{
var val;
if((val=el.attrsMap[name])!=null){
var list=el.attrsList;
for(var i=0,l=list.length;i<l;i++){
if(list[i].name===name){
list.splice(i,1);
break;
}
}
}
if(removeFromMap){
delete el.attrsMap[name];
}
return val;
}

function getAndRemoveAttrByRegex(
el,
name)
{
var list=el.attrsList;
for(var i=0,l=list.length;i<l;i++){
var attr=list[i];
if(name.test(attr.name)){
list.splice(i,1);
return attr;
}
}
}

function rangeSetItem(
item,
range)
{
if(range){
if(range.start!=null){
item.start=range.start;
}
if(range.end!=null){
item.end=range.end;
}
}
return item;
}

/*  */

/**
 * Cross-platform code generation for component v-model
 */
function genComponentModel(
el,
value,
modifiers)
{
var ref=modifiers||{};
var number=ref.number;
var trim=ref.trim;

var baseValueExpression='$$v';
var valueExpression=baseValueExpression;
if(trim){
valueExpression=
"(typeof "+baseValueExpression+" === 'string'"+
"? "+baseValueExpression+".trim()"+
": "+baseValueExpression+")";
}
if(number){
valueExpression="_n("+valueExpression+")";
}
var assignment=genAssignmentCode(value,valueExpression);

el.model={
value:"("+value+")",
expression:JSON.stringify(value),
callback:"function ("+baseValueExpression+") {"+assignment+"}"};

}

/**
 * Cross-platform codegen helper for generating v-model value assignment code.
 */
function genAssignmentCode(
value,
assignment)
{
var res=parseModel(value);
if(res.key===null){
return value+"="+assignment;
}else {
return "$set("+res.exp+", "+res.key+", "+assignment+")";
}
}

/**
 * Parse a v-model expression into a base path and a final key segment.
 * Handles both dot-path and possible square brackets.
 *
 * Possible cases:
 *
 * - test
 * - test[key]
 * - test[test1[key]]
 * - test["a"][key]
 * - xxx.test[a[a].test1[key]]
 * - test.xxx.a["asa"][test1[key]]
 *
 */

var len,str,chr,index$1,expressionPos,expressionEndPos;



function parseModel(val){
// Fix https://github.com/vuejs/vue/pull/7730
// allow v-model="obj.val " (trailing whitespace)
val=val.trim();
len=val.length;

if(val.indexOf('[')<0||val.lastIndexOf(']')<len-1){
index$1=val.lastIndexOf('.');
if(index$1>-1){
return {
exp:val.slice(0,index$1),
key:'"'+val.slice(index$1+1)+'"'};

}else {
return {
exp:val,
key:null};

}
}

str=val;
index$1=expressionPos=expressionEndPos=0;

while(!eof()){
chr=next();
/* istanbul ignore if */
if(isStringStart(chr)){
parseString(chr);
}else if(chr===0x5B){
parseBracket(chr);
}
}

return {
exp:val.slice(0,expressionPos),
key:val.slice(expressionPos+1,expressionEndPos)};

}

function next(){
return str.charCodeAt(++index$1);
}

function eof(){
return index$1>=len;
}

function isStringStart(chr){
return chr===0x22||chr===0x27;
}

function parseBracket(chr){
var inBracket=1;
expressionPos=index$1;
while(!eof()){
chr=next();
if(isStringStart(chr)){
parseString(chr);
continue;
}
if(chr===0x5B){inBracket++;}
if(chr===0x5D){inBracket--;}
if(inBracket===0){
expressionEndPos=index$1;
break;
}
}
}

function parseString(chr){
var stringQuote=chr;
while(!eof()){
chr=next();
if(chr===stringQuote){
break;
}
}
}

/*  */

var warn$1;

// in some cases, the event used has to be determined at runtime
// so we used some reserved tokens during compile.
var RANGE_TOKEN='__r';
var CHECKBOX_RADIO_TOKEN='__c';

function model(
el,
dir,
_warn)
{
warn$1=_warn;
var value=dir.value;
var modifiers=dir.modifiers;
var tag=el.tag;
var type=el.attrsMap.type;

{
// inputs with type="file" are read only and setting the input's
// value will throw an error.
if(tag==='input'&&type==='file'){
warn$1(
"<"+el.tag+" v-model=\""+value+"\" type=\"file\">:\n"+
"File inputs are read only. Use a v-on:change listener instead.",
el.rawAttrsMap['v-model']);

}
}

if(el.component){
genComponentModel(el,value,modifiers);
// component v-model doesn't need extra runtime
return false;
}else if(tag==='select'){
genSelect(el,value,modifiers);
}else if(tag==='input'&&type==='checkbox'){
genCheckboxModel(el,value,modifiers);
}else if(tag==='input'&&type==='radio'){
genRadioModel(el,value,modifiers);
}else if(tag==='input'||tag==='textarea'){
genDefaultModel(el,value,modifiers);
}else if(!config.isReservedTag(tag)){
genComponentModel(el,value,modifiers);
// component v-model doesn't need extra runtime
return false;
}else {
warn$1(
"<"+el.tag+" v-model=\""+value+"\">: "+
"v-model is not supported on this element type. "+
'If you are working with contenteditable, it\'s recommended to '+
'wrap a library dedicated for that purpose inside a custom component.',
el.rawAttrsMap['v-model']);

}

// ensure runtime directive metadata
return true;
}

function genCheckboxModel(
el,
value,
modifiers)
{
var number=modifiers&&modifiers.number;
var valueBinding=getBindingAttr(el,'value')||'null';
var trueValueBinding=getBindingAttr(el,'true-value')||'true';
var falseValueBinding=getBindingAttr(el,'false-value')||'false';
addProp(el,'checked',
"Array.isArray("+value+")"+
"?_i("+value+","+valueBinding+")>-1"+(
trueValueBinding==='true'?
":("+value+")":
":_q("+value+","+trueValueBinding+")"));


addHandler(el,'change',
"var $$a="+value+","+
'$$el=$event.target,'+
"$$c=$$el.checked?("+trueValueBinding+"):("+falseValueBinding+");"+
'if(Array.isArray($$a)){'+
"var $$v="+(number?'_n('+valueBinding+')':valueBinding)+","+
'$$i=_i($$a,$$v);'+
"if($$el.checked){$$i<0&&("+genAssignmentCode(value,'$$a.concat([$$v])')+")}"+
"else{$$i>-1&&("+genAssignmentCode(value,'$$a.slice(0,$$i).concat($$a.slice($$i+1))')+")}"+
"}else{"+genAssignmentCode(value,'$$c')+"}",
null,true);

}

function genRadioModel(
el,
value,
modifiers)
{
var number=modifiers&&modifiers.number;
var valueBinding=getBindingAttr(el,'value')||'null';
valueBinding=number?"_n("+valueBinding+")":valueBinding;
addProp(el,'checked',"_q("+value+","+valueBinding+")");
addHandler(el,'change',genAssignmentCode(value,valueBinding),null,true);
}

function genSelect(
el,
value,
modifiers)
{
var number=modifiers&&modifiers.number;
var selectedVal="Array.prototype.filter"+
".call($event.target.options,function(o){return o.selected})"+
".map(function(o){var val = \"_value\" in o ? o._value : o.value;"+
"return "+(number?'_n(val)':'val')+"})";

var assignment='$event.target.multiple ? $$selectedVal : $$selectedVal[0]';
var code="var $$selectedVal = "+selectedVal+";";
code=code+" "+genAssignmentCode(value,assignment);
addHandler(el,'change',code,null,true);
}

function genDefaultModel(
el,
value,
modifiers)
{
var type=el.attrsMap.type;

// warn if v-bind:value conflicts with v-model
// except for inputs with v-bind:type
{
var value$1=el.attrsMap['v-bind:value']||el.attrsMap[':value'];
var typeBinding=el.attrsMap['v-bind:type']||el.attrsMap[':type'];
if(value$1&&!typeBinding){
var binding=el.attrsMap['v-bind:value']?'v-bind:value':':value';
warn$1(
binding+"=\""+value$1+"\" conflicts with v-model on the same element "+
'because the latter already expands to a value binding internally',
el.rawAttrsMap[binding]);

}
}

var ref=modifiers||{};
var lazy=ref.lazy;
var number=ref.number;
var trim=ref.trim;
var needCompositionGuard=!lazy&&type!=='range';
var event=lazy?
'change':
type==='range'?
RANGE_TOKEN:
'input';

var valueExpression='$event.target.value';
if(trim){
valueExpression="$event.target.value.trim()";
}
if(number){
valueExpression="_n("+valueExpression+")";
}

var code=genAssignmentCode(value,valueExpression);
if(needCompositionGuard){
code="if($event.target.composing)return;"+code;
}

addProp(el,'value',"("+value+")");
addHandler(el,event,code,null,true);
if(trim||number){
addHandler(el,'blur','$forceUpdate()');
}
}

/*  */

// normalize v-model event tokens that can only be determined at runtime.
// it's important to place the event as the first in the array because
// the whole point is ensuring the v-model callback gets called before
// user-attached handlers.
function normalizeEvents(on){
/* istanbul ignore if */
if(isDef(on[RANGE_TOKEN])){
// IE input[type=range] only supports `change` event
var event=isIE?'change':'input';
on[event]=[].concat(on[RANGE_TOKEN],on[event]||[]);
delete on[RANGE_TOKEN];
}
// This was originally intended to fix #4521 but no longer necessary
// after 2.5. Keeping it for backwards compat with generated code from < 2.4
/* istanbul ignore if */
if(isDef(on[CHECKBOX_RADIO_TOKEN])){
on.change=[].concat(on[CHECKBOX_RADIO_TOKEN],on.change||[]);
delete on[CHECKBOX_RADIO_TOKEN];
}
}

var target$1;

function createOnceHandler$1(event,handler,capture){
var _target=target$1;// save current target element in closure
return function onceHandler(){
var res=handler.apply(null,arguments);
if(res!==null){
remove$2(event,onceHandler,capture,_target);
}
};
}

// #9446: Firefox <= 53 (in particular, ESR 52) has incorrect Event.timeStamp
// implementation and does not fire microtasks in between event propagation, so
// safe to exclude.
var useMicrotaskFix=isUsingMicroTask&&!(isFF&&Number(isFF[1])<=53);

function add$1(
name,
handler,
capture,
passive)
{
// async edge case #6566: inner click event triggers patch, event handler
// attached to outer element during patch, and triggered again. This
// happens because browsers fire microtask ticks between event propagation.
// the solution is simple: we save the timestamp when a handler is attached,
// and the handler would only fire if the event passed to it was fired
// AFTER it was attached.
if(useMicrotaskFix){
var attachedTimestamp=currentFlushTimestamp;
var original=handler;
handler=original._wrapper=function(e){
if(
// no bubbling, should always fire.
// this is just a safety net in case event.timeStamp is unreliable in
// certain weird environments...
e.target===e.currentTarget||
// event is fired after handler attachment
e.timeStamp>=attachedTimestamp||
// bail for environments that have buggy event.timeStamp implementations
// #9462 iOS 9 bug: event.timeStamp is 0 after history.pushState
// #9681 QtWebEngine event.timeStamp is negative value
e.timeStamp<=0||
// #9448 bail if event is fired in another document in a multi-page
// electron/nw.js app, since event.timeStamp will be using a different
// starting reference
e.target.ownerDocument!==document)
{
return original.apply(this,arguments);
}
};
}
target$1.addEventListener(
name,
handler,
supportsPassive?
{capture:capture,passive:passive}:
capture);

}

function remove$2(
name,
handler,
capture,
_target)
{
(_target||target$1).removeEventListener(
name,
handler._wrapper||handler,
capture);

}

function updateDOMListeners(oldVnode,vnode){
if(isUndef(oldVnode.data.on)&&isUndef(vnode.data.on)){
return;
}
var on=vnode.data.on||{};
var oldOn=oldVnode.data.on||{};
target$1=vnode.elm;
normalizeEvents(on);
updateListeners(on,oldOn,add$1,remove$2,createOnceHandler$1,vnode.context);
target$1=undefined;
}

var events={
create:updateDOMListeners,
update:updateDOMListeners};


/*  */

var svgContainer;

function updateDOMProps(oldVnode,vnode){
if(isUndef(oldVnode.data.domProps)&&isUndef(vnode.data.domProps)){
return;
}
var key,cur;
var elm=vnode.elm;
var oldProps=oldVnode.data.domProps||{};
var props=vnode.data.domProps||{};
// clone observed objects, as the user probably wants to mutate it
if(isDef(props.__ob__)){
props=vnode.data.domProps=extend({},props);
}

for(key in oldProps){
if(!(key in props)){
elm[key]='';
}
}

for(key in props){
cur=props[key];
// ignore children if the node has textContent or innerHTML,
// as these will throw away existing DOM nodes and cause removal errors
// on subsequent patches (#3360)
if(key==='textContent'||key==='innerHTML'){
if(vnode.children){vnode.children.length=0;}
if(cur===oldProps[key]){continue;}
// #6601 work around Chrome version <= 55 bug where single textNode
// replaced by innerHTML/textContent retains its parentNode property
if(elm.childNodes.length===1){
elm.removeChild(elm.childNodes[0]);
}
}

if(key==='value'&&elm.tagName!=='PROGRESS'){
// store value as _value as well since
// non-string values will be stringified
elm._value=cur;
// avoid resetting cursor position when value is the same
var strCur=isUndef(cur)?'':String(cur);
if(shouldUpdateValue(elm,strCur)){
elm.value=strCur;
}
}else if(key==='innerHTML'&&isSVG(elm.tagName)&&isUndef(elm.innerHTML)){
// IE doesn't support innerHTML for SVG elements
svgContainer=svgContainer||document.createElement('div');
svgContainer.innerHTML="<svg>"+cur+"</svg>";
var svg=svgContainer.firstChild;
while(elm.firstChild){
elm.removeChild(elm.firstChild);
}
while(svg.firstChild){
elm.appendChild(svg.firstChild);
}
}else if(
// skip the update if old and new VDOM state is the same.
// `value` is handled separately because the DOM value may be temporarily
// out of sync with VDOM state due to focus, composition and modifiers.
// This  #4521 by skipping the unnecessary `checked` update.
cur!==oldProps[key])
{
// some property updates can throw
// e.g. `value` on <progress> w/ non-finite value
try{
elm[key]=cur;
}catch(e){}
}
}
}

// check platforms/web/util/attrs.js acceptValue


function shouldUpdateValue(elm,checkVal){
return !elm.composing&&(
elm.tagName==='OPTION'||
isNotInFocusAndDirty(elm,checkVal)||
isDirtyWithModifiers(elm,checkVal));

}

function isNotInFocusAndDirty(elm,checkVal){
// return true when textbox (.number and .trim) loses focus and its value is
// not equal to the updated value
var notInFocus=true;
// #6157
// work around IE bug when accessing document.activeElement in an iframe
try{notInFocus=document.activeElement!==elm;}catch(e){}
return notInFocus&&elm.value!==checkVal;
}

function isDirtyWithModifiers(elm,newVal){
var value=elm.value;
var modifiers=elm._vModifiers;// injected by v-model runtime
if(isDef(modifiers)){
if(modifiers.number){
return toNumber(value)!==toNumber(newVal);
}
if(modifiers.trim){
return value.trim()!==newVal.trim();
}
}
return value!==newVal;
}

var domProps={
create:updateDOMProps,
update:updateDOMProps};


/*  */

var parseStyleText=cached(function(cssText){
var res={};
var listDelimiter=/;(?![^(]*\))/g;
var propertyDelimiter=/:(.+)/;
cssText.split(listDelimiter).forEach(function(item){
if(item){
var tmp=item.split(propertyDelimiter);
tmp.length>1&&(res[tmp[0].trim()]=tmp[1].trim());
}
});
return res;
});

// merge static and dynamic style data on the same vnode
function normalizeStyleData(data){
var style=normalizeStyleBinding(data.style);
// static style is pre-processed into an object during compilation
// and is always a fresh object, so it's safe to merge into it
return data.staticStyle?
extend(data.staticStyle,style):
style;
}

// normalize possible array / string values into Object
function normalizeStyleBinding(bindingStyle){
if(Array.isArray(bindingStyle)){
return toObject(bindingStyle);
}
if(typeof bindingStyle==='string'){
return parseStyleText(bindingStyle);
}
return bindingStyle;
}

/**
 * parent component style should be after child's
 * so that parent component's style could override it
 */
function getStyle(vnode,checkChild){
var res={};
var styleData;

if(checkChild){
var childNode=vnode;
while(childNode.componentInstance){
childNode=childNode.componentInstance._vnode;
if(
childNode&&childNode.data&&(
styleData=normalizeStyleData(childNode.data)))
{
extend(res,styleData);
}
}
}

if(styleData=normalizeStyleData(vnode.data)){
extend(res,styleData);
}

var parentNode=vnode;
while(parentNode=parentNode.parent){
if(parentNode.data&&(styleData=normalizeStyleData(parentNode.data))){
extend(res,styleData);
}
}
return res;
}

/*  */

var cssVarRE=/^--/;
var importantRE=/\s*!important$/;
var setProp=function setProp(el,name,val){
/* istanbul ignore if */
if(cssVarRE.test(name)){
el.style.setProperty(name,val);
}else if(importantRE.test(val)){
el.style.setProperty(hyphenate(name),val.replace(importantRE,''),'important');
}else {
var normalizedName=normalize(name);
if(Array.isArray(val)){
// Support values array created by autoprefixer, e.g.
// {display: ["-webkit-box", "-ms-flexbox", "flex"]}
// Set them one by one, and the browser will only set those it can recognize
for(var i=0,len=val.length;i<len;i++){
el.style[normalizedName]=val[i];
}
}else {
el.style[normalizedName]=val;
}
}
};

var vendorNames=['Webkit','Moz','ms'];

var emptyStyle;
var normalize=cached(function(prop){
emptyStyle=emptyStyle||document.createElement('div').style;
prop=camelize(prop);
if(prop!=='filter'&&prop in emptyStyle){
return prop;
}
var capName=prop.charAt(0).toUpperCase()+prop.slice(1);
for(var i=0;i<vendorNames.length;i++){
var name=vendorNames[i]+capName;
if(name in emptyStyle){
return name;
}
}
});

function updateStyle(oldVnode,vnode){
var data=vnode.data;
var oldData=oldVnode.data;

if(isUndef(data.staticStyle)&&isUndef(data.style)&&
isUndef(oldData.staticStyle)&&isUndef(oldData.style))
{
return;
}

var cur,name;
var el=vnode.elm;
var oldStaticStyle=oldData.staticStyle;
var oldStyleBinding=oldData.normalizedStyle||oldData.style||{};

// if static style exists, stylebinding already merged into it when doing normalizeStyleData
var oldStyle=oldStaticStyle||oldStyleBinding;

var style=normalizeStyleBinding(vnode.data.style)||{};

// store normalized style under a different key for next diff
// make sure to clone it if it's reactive, since the user likely wants
// to mutate it.
vnode.data.normalizedStyle=isDef(style.__ob__)?
extend({},style):
style;

var newStyle=getStyle(vnode,true);

for(name in oldStyle){
if(isUndef(newStyle[name])){
setProp(el,name,'');
}
}
for(name in newStyle){
cur=newStyle[name];
if(cur!==oldStyle[name]){
// ie9 setting to null has no effect, must use empty string
setProp(el,name,cur==null?'':cur);
}
}
}

var style={
create:updateStyle,
update:updateStyle};


/*  */

var whitespaceRE=/\s+/;

/**
 * Add class with compatibility for SVG since classList is not supported on
 * SVG elements in IE
 */
function addClass(el,cls){
/* istanbul ignore if */
if(!cls||!(cls=cls.trim())){
return;
}

/* istanbul ignore else */
if(el.classList){
if(cls.indexOf(' ')>-1){
cls.split(whitespaceRE).forEach(function(c){return el.classList.add(c);});
}else {
el.classList.add(cls);
}
}else {
var cur=" "+(el.getAttribute('class')||'')+" ";
if(cur.indexOf(' '+cls+' ')<0){
el.setAttribute('class',(cur+cls).trim());
}
}
}

/**
 * Remove class with compatibility for SVG since classList is not supported on
 * SVG elements in IE
 */
function removeClass(el,cls){
/* istanbul ignore if */
if(!cls||!(cls=cls.trim())){
return;
}

/* istanbul ignore else */
if(el.classList){
if(cls.indexOf(' ')>-1){
cls.split(whitespaceRE).forEach(function(c){return el.classList.remove(c);});
}else {
el.classList.remove(cls);
}
if(!el.classList.length){
el.removeAttribute('class');
}
}else {
var cur=" "+(el.getAttribute('class')||'')+" ";
var tar=' '+cls+' ';
while(cur.indexOf(tar)>=0){
cur=cur.replace(tar,' ');
}
cur=cur.trim();
if(cur){
el.setAttribute('class',cur);
}else {
el.removeAttribute('class');
}
}
}

/*  */

function resolveTransition(def$$1){
if(!def$$1){
return;
}
/* istanbul ignore else */
if(typeof def$$1==='object'){
var res={};
if(def$$1.css!==false){
extend(res,autoCssTransition(def$$1.name||'v'));
}
extend(res,def$$1);
return res;
}else if(typeof def$$1==='string'){
return autoCssTransition(def$$1);
}
}

var autoCssTransition=cached(function(name){
return {
enterClass:name+"-enter",
enterToClass:name+"-enter-to",
enterActiveClass:name+"-enter-active",
leaveClass:name+"-leave",
leaveToClass:name+"-leave-to",
leaveActiveClass:name+"-leave-active"};

});

var hasTransition=inBrowser&&!isIE9;
var TRANSITION='transition';
var ANIMATION='animation';

// Transition property/event sniffing
var transitionProp='transition';
var transitionEndEvent='transitionend';
var animationProp='animation';
var animationEndEvent='animationend';
if(hasTransition){
/* istanbul ignore if */
if(window.ontransitionend===undefined&&
window.onwebkittransitionend!==undefined)
{
transitionProp='WebkitTransition';
transitionEndEvent='webkitTransitionEnd';
}
if(window.onanimationend===undefined&&
window.onwebkitanimationend!==undefined)
{
animationProp='WebkitAnimation';
animationEndEvent='webkitAnimationEnd';
}
}

// binding to window is necessary to make hot reload work in IE in strict mode
var raf=inBrowser?
window.requestAnimationFrame?
window.requestAnimationFrame.bind(window):
setTimeout:
/* istanbul ignore next */function(fn){return fn();};

function nextFrame(fn){
raf(function(){
raf(fn);
});
}

function addTransitionClass(el,cls){
var transitionClasses=el._transitionClasses||(el._transitionClasses=[]);
if(transitionClasses.indexOf(cls)<0){
transitionClasses.push(cls);
addClass(el,cls);
}
}

function removeTransitionClass(el,cls){
if(el._transitionClasses){
remove(el._transitionClasses,cls);
}
removeClass(el,cls);
}

function whenTransitionEnds(
el,
expectedType,
cb)
{
var ref=getTransitionInfo(el,expectedType);
var type=ref.type;
var timeout=ref.timeout;
var propCount=ref.propCount;
if(!type){return cb();}
var event=type===TRANSITION?transitionEndEvent:animationEndEvent;
var ended=0;
var end=function end(){
el.removeEventListener(event,onEnd);
cb();
};
var onEnd=function onEnd(e){
if(e.target===el){
if(++ended>=propCount){
end();
}
}
};
setTimeout(function(){
if(ended<propCount){
end();
}
},timeout+1);
el.addEventListener(event,onEnd);
}

var transformRE=/\b(transform|all)(,|$)/;

function getTransitionInfo(el,expectedType){
var styles=window.getComputedStyle(el);
// JSDOM may return undefined for transition properties
var transitionDelays=(styles[transitionProp+'Delay']||'').split(', ');
var transitionDurations=(styles[transitionProp+'Duration']||'').split(', ');
var transitionTimeout=getTimeout(transitionDelays,transitionDurations);
var animationDelays=(styles[animationProp+'Delay']||'').split(', ');
var animationDurations=(styles[animationProp+'Duration']||'').split(', ');
var animationTimeout=getTimeout(animationDelays,animationDurations);

var type;
var timeout=0;
var propCount=0;
/* istanbul ignore if */
if(expectedType===TRANSITION){
if(transitionTimeout>0){
type=TRANSITION;
timeout=transitionTimeout;
propCount=transitionDurations.length;
}
}else if(expectedType===ANIMATION){
if(animationTimeout>0){
type=ANIMATION;
timeout=animationTimeout;
propCount=animationDurations.length;
}
}else {
timeout=Math.max(transitionTimeout,animationTimeout);
type=timeout>0?
transitionTimeout>animationTimeout?
TRANSITION:
ANIMATION:
null;
propCount=type?
type===TRANSITION?
transitionDurations.length:
animationDurations.length:
0;
}
var hasTransform=
type===TRANSITION&&
transformRE.test(styles[transitionProp+'Property']);
return {
type:type,
timeout:timeout,
propCount:propCount,
hasTransform:hasTransform};

}

function getTimeout(delays,durations){
/* istanbul ignore next */
while(delays.length<durations.length){
delays=delays.concat(delays);
}

return Math.max.apply(null,durations.map(function(d,i){
return toMs(d)+toMs(delays[i]);
}));
}

// Old versions of Chromium (below 61.0.3163.100) formats floating pointer numbers
// in a locale-dependent way, using a comma instead of a dot.
// If comma is not replaced with a dot, the input will be rounded down (i.e. acting
// as a floor function) causing unexpected behaviors
function toMs(s){
return Number(s.slice(0,-1).replace(',','.'))*1000;
}

/*  */

function enter(vnode,toggleDisplay){
var el=vnode.elm;

// call leave callback now
if(isDef(el._leaveCb)){
el._leaveCb.cancelled=true;
el._leaveCb();
}

var data=resolveTransition(vnode.data.transition);
if(isUndef(data)){
return;
}

/* istanbul ignore if */
if(isDef(el._enterCb)||el.nodeType!==1){
return;
}

var css=data.css;
var type=data.type;
var enterClass=data.enterClass;
var enterToClass=data.enterToClass;
var enterActiveClass=data.enterActiveClass;
var appearClass=data.appearClass;
var appearToClass=data.appearToClass;
var appearActiveClass=data.appearActiveClass;
var beforeEnter=data.beforeEnter;
var enter=data.enter;
var afterEnter=data.afterEnter;
var enterCancelled=data.enterCancelled;
var beforeAppear=data.beforeAppear;
var appear=data.appear;
var afterAppear=data.afterAppear;
var appearCancelled=data.appearCancelled;
var duration=data.duration;

// activeInstance will always be the <transition> component managing this
// transition. One edge case to check is when the <transition> is placed
// as the root node of a child component. In that case we need to check
// <transition>'s parent for appear check.
var context=activeInstance;
var transitionNode=activeInstance.$vnode;
while(transitionNode&&transitionNode.parent){
context=transitionNode.context;
transitionNode=transitionNode.parent;
}

var isAppear=!context._isMounted||!vnode.isRootInsert;

if(isAppear&&!appear&&appear!==''){
return;
}

var startClass=isAppear&&appearClass?
appearClass:
enterClass;
var activeClass=isAppear&&appearActiveClass?
appearActiveClass:
enterActiveClass;
var toClass=isAppear&&appearToClass?
appearToClass:
enterToClass;

var beforeEnterHook=isAppear?
beforeAppear||beforeEnter:
beforeEnter;
var enterHook=isAppear?
typeof appear==='function'?appear:enter:
enter;
var afterEnterHook=isAppear?
afterAppear||afterEnter:
afterEnter;
var enterCancelledHook=isAppear?
appearCancelled||enterCancelled:
enterCancelled;

var explicitEnterDuration=toNumber(
isObject(duration)?
duration.enter:
duration);


if(explicitEnterDuration!=null){
checkDuration(explicitEnterDuration,'enter',vnode);
}

var expectsCSS=css!==false&&!isIE9;
var userWantsControl=getHookArgumentsLength(enterHook);

var cb=el._enterCb=once(function(){
if(expectsCSS){
removeTransitionClass(el,toClass);
removeTransitionClass(el,activeClass);
}
if(cb.cancelled){
if(expectsCSS){
removeTransitionClass(el,startClass);
}
enterCancelledHook&&enterCancelledHook(el);
}else {
afterEnterHook&&afterEnterHook(el);
}
el._enterCb=null;
});

if(!vnode.data.show){
// remove pending leave element on enter by injecting an insert hook
mergeVNodeHook(vnode,'insert',function(){
var parent=el.parentNode;
var pendingNode=parent&&parent._pending&&parent._pending[vnode.key];
if(pendingNode&&
pendingNode.tag===vnode.tag&&
pendingNode.elm._leaveCb)
{
pendingNode.elm._leaveCb();
}
enterHook&&enterHook(el,cb);
});
}

// start enter transition
beforeEnterHook&&beforeEnterHook(el);
if(expectsCSS){
addTransitionClass(el,startClass);
addTransitionClass(el,activeClass);
nextFrame(function(){
removeTransitionClass(el,startClass);
if(!cb.cancelled){
addTransitionClass(el,toClass);
if(!userWantsControl){
if(isValidDuration(explicitEnterDuration)){
setTimeout(cb,explicitEnterDuration);
}else {
whenTransitionEnds(el,type,cb);
}
}
}
});
}

if(vnode.data.show){
toggleDisplay&&toggleDisplay();
enterHook&&enterHook(el,cb);
}

if(!expectsCSS&&!userWantsControl){
cb();
}
}

function leave(vnode,rm){
var el=vnode.elm;

// call enter callback now
if(isDef(el._enterCb)){
el._enterCb.cancelled=true;
el._enterCb();
}

var data=resolveTransition(vnode.data.transition);
if(isUndef(data)||el.nodeType!==1){
return rm();
}

/* istanbul ignore if */
if(isDef(el._leaveCb)){
return;
}

var css=data.css;
var type=data.type;
var leaveClass=data.leaveClass;
var leaveToClass=data.leaveToClass;
var leaveActiveClass=data.leaveActiveClass;
var beforeLeave=data.beforeLeave;
var leave=data.leave;
var afterLeave=data.afterLeave;
var leaveCancelled=data.leaveCancelled;
var delayLeave=data.delayLeave;
var duration=data.duration;

var expectsCSS=css!==false&&!isIE9;
var userWantsControl=getHookArgumentsLength(leave);

var explicitLeaveDuration=toNumber(
isObject(duration)?
duration.leave:
duration);


if(isDef(explicitLeaveDuration)){
checkDuration(explicitLeaveDuration,'leave',vnode);
}

var cb=el._leaveCb=once(function(){
if(el.parentNode&&el.parentNode._pending){
el.parentNode._pending[vnode.key]=null;
}
if(expectsCSS){
removeTransitionClass(el,leaveToClass);
removeTransitionClass(el,leaveActiveClass);
}
if(cb.cancelled){
if(expectsCSS){
removeTransitionClass(el,leaveClass);
}
leaveCancelled&&leaveCancelled(el);
}else {
rm();
afterLeave&&afterLeave(el);
}
el._leaveCb=null;
});

if(delayLeave){
delayLeave(performLeave);
}else {
performLeave();
}

function performLeave(){
// the delayed leave may have already been cancelled
if(cb.cancelled){
return;
}
// record leaving element
if(!vnode.data.show&&el.parentNode){
(el.parentNode._pending||(el.parentNode._pending={}))[vnode.key]=vnode;
}
beforeLeave&&beforeLeave(el);
if(expectsCSS){
addTransitionClass(el,leaveClass);
addTransitionClass(el,leaveActiveClass);
nextFrame(function(){
removeTransitionClass(el,leaveClass);
if(!cb.cancelled){
addTransitionClass(el,leaveToClass);
if(!userWantsControl){
if(isValidDuration(explicitLeaveDuration)){
setTimeout(cb,explicitLeaveDuration);
}else {
whenTransitionEnds(el,type,cb);
}
}
}
});
}
leave&&leave(el,cb);
if(!expectsCSS&&!userWantsControl){
cb();
}
}
}

// only used in dev mode
function checkDuration(val,name,vnode){
if(typeof val!=='number'){
warn(
"<transition> explicit "+name+" duration is not a valid number - "+
"got "+JSON.stringify(val)+".",
vnode.context);

}else if(isNaN(val)){
warn(
"<transition> explicit "+name+" duration is NaN - "+
'the duration expression might be incorrect.',
vnode.context);

}
}

function isValidDuration(val){
return typeof val==='number'&&!isNaN(val);
}

/**
 * Normalize a transition hook's argument length. The hook may be:
 * - a merged hook (invoker) with the original in .fns
 * - a wrapped component method (check ._length)
 * - a plain function (.length)
 */
function getHookArgumentsLength(fn){
if(isUndef(fn)){
return false;
}
var invokerFns=fn.fns;
if(isDef(invokerFns)){
// invoker
return getHookArgumentsLength(
Array.isArray(invokerFns)?
invokerFns[0]:
invokerFns);

}else {
return (fn._length||fn.length)>1;
}
}

function _enter(_,vnode){
if(vnode.data.show!==true){
enter(vnode);
}
}

var transition=inBrowser?{
create:_enter,
activate:_enter,
remove:function remove$$1(vnode,rm){
/* istanbul ignore else */
if(vnode.data.show!==true){
leave(vnode,rm);
}else {
rm();
}
}}:
{};

var platformModules=[
attrs,
klass,
events,
domProps,
style,
transition];


/*  */

// the directive module should be applied last, after all
// built-in modules have been applied.
var modules=platformModules.concat(baseModules);

var patch=createPatchFunction({nodeOps:nodeOps,modules:modules});

/**
 * Not type checking this file because flow doesn't like attaching
 * properties to Elements.
 */

/* istanbul ignore if */
if(isIE9){
// http://www.matts411.com/post/internet-explorer-9-oninput/
document.addEventListener('selectionchange',function(){
var el=document.activeElement;
if(el&&el.vmodel){
trigger(el,'input');
}
});
}

var directive={
inserted:function inserted(el,binding,vnode,oldVnode){
if(vnode.tag==='select'){
// #6903
if(oldVnode.elm&&!oldVnode.elm._vOptions){
mergeVNodeHook(vnode,'postpatch',function(){
directive.componentUpdated(el,binding,vnode);
});
}else {
setSelected(el,binding,vnode.context);
}
el._vOptions=[].map.call(el.options,getValue);
}else if(vnode.tag==='textarea'||isTextInputType(el.type)){
el._vModifiers=binding.modifiers;
if(!binding.modifiers.lazy){
el.addEventListener('compositionstart',onCompositionStart);
el.addEventListener('compositionend',onCompositionEnd);
// Safari < 10.2 & UIWebView doesn't fire compositionend when
// switching focus before confirming composition choice
// this also fixes the issue where some browsers e.g. iOS Chrome
// fires "change" instead of "input" on autocomplete.
el.addEventListener('change',onCompositionEnd);
/* istanbul ignore if */
if(isIE9){
el.vmodel=true;
}
}
}
},

componentUpdated:function componentUpdated(el,binding,vnode){
if(vnode.tag==='select'){
setSelected(el,binding,vnode.context);
// in case the options rendered by v-for have changed,
// it's possible that the value is out-of-sync with the rendered options.
// detect such cases and filter out values that no longer has a matching
// option in the DOM.
var prevOptions=el._vOptions;
var curOptions=el._vOptions=[].map.call(el.options,getValue);
if(curOptions.some(function(o,i){return !looseEqual(o,prevOptions[i]);})){
// trigger change event if
// no matching option found for at least one value
var needReset=el.multiple?
binding.value.some(function(v){return hasNoMatchingOption(v,curOptions);}):
binding.value!==binding.oldValue&&hasNoMatchingOption(binding.value,curOptions);
if(needReset){
trigger(el,'change');
}
}
}
}};


function setSelected(el,binding,vm){
actuallySetSelected(el,binding,vm);
/* istanbul ignore if */
if(isIE||isEdge){
setTimeout(function(){
actuallySetSelected(el,binding,vm);
},0);
}
}

function actuallySetSelected(el,binding,vm){
var value=binding.value;
var isMultiple=el.multiple;
if(isMultiple&&!Array.isArray(value)){
warn(
"<select multiple v-model=\""+binding.expression+"\"> "+
"expects an Array value for its binding, but got "+Object.prototype.toString.call(value).slice(8,-1),
vm);

return;
}
var selected,option;
for(var i=0,l=el.options.length;i<l;i++){
option=el.options[i];
if(isMultiple){
selected=looseIndexOf(value,getValue(option))>-1;
if(option.selected!==selected){
option.selected=selected;
}
}else {
if(looseEqual(getValue(option),value)){
if(el.selectedIndex!==i){
el.selectedIndex=i;
}
return;
}
}
}
if(!isMultiple){
el.selectedIndex=-1;
}
}

function hasNoMatchingOption(value,options){
return options.every(function(o){return !looseEqual(o,value);});
}

function getValue(option){
return '_value'in option?
option._value:
option.value;
}

function onCompositionStart(e){
e.target.composing=true;
}

function onCompositionEnd(e){
// prevent triggering an input event for no reason
if(!e.target.composing){return;}
e.target.composing=false;
trigger(e.target,'input');
}

function trigger(el,type){
var e=document.createEvent('HTMLEvents');
e.initEvent(type,true,true);
el.dispatchEvent(e);
}

/*  */

// recursively search for possible transition defined inside the component root
function locateNode(vnode){
return vnode.componentInstance&&(!vnode.data||!vnode.data.transition)?
locateNode(vnode.componentInstance._vnode):
vnode;
}

var show={
bind:function bind(el,ref,vnode){
var value=ref.value;

vnode=locateNode(vnode);
var transition$$1=vnode.data&&vnode.data.transition;
var originalDisplay=el.__vOriginalDisplay=
el.style.display==='none'?'':el.style.display;
if(value&&transition$$1){
vnode.data.show=true;
enter(vnode,function(){
el.style.display=originalDisplay;
});
}else {
el.style.display=value?originalDisplay:'none';
}
},

update:function update(el,ref,vnode){
var value=ref.value;
var oldValue=ref.oldValue;

/* istanbul ignore if */
if(!value===!oldValue){return;}
vnode=locateNode(vnode);
var transition$$1=vnode.data&&vnode.data.transition;
if(transition$$1){
vnode.data.show=true;
if(value){
enter(vnode,function(){
el.style.display=el.__vOriginalDisplay;
});
}else {
leave(vnode,function(){
el.style.display='none';
});
}
}else {
el.style.display=value?el.__vOriginalDisplay:'none';
}
},

unbind:function unbind(
el,
binding,
vnode,
oldVnode,
isDestroy)
{
if(!isDestroy){
el.style.display=el.__vOriginalDisplay;
}
}};


var platformDirectives={
model:directive,
show:show};


/*  */

var transitionProps={
name:String,
appear:Boolean,
css:Boolean,
mode:String,
type:String,
enterClass:String,
leaveClass:String,
enterToClass:String,
leaveToClass:String,
enterActiveClass:String,
leaveActiveClass:String,
appearClass:String,
appearActiveClass:String,
appearToClass:String,
duration:[Number,String,Object]};


// in case the child is also an abstract component, e.g. <keep-alive>
// we want to recursively retrieve the real component to be rendered
function getRealChild(vnode){
var compOptions=vnode&&vnode.componentOptions;
if(compOptions&&compOptions.Ctor.options.abstract){
return getRealChild(getFirstComponentChild(compOptions.children));
}else {
return vnode;
}
}

function extractTransitionData(comp){
var data={};
var options=comp.$options;
// props
for(var key in options.propsData){
data[key]=comp[key];
}
// events.
// extract listeners and pass them directly to the transition methods
var listeners=options._parentListeners;
for(var key$1 in listeners){
data[camelize(key$1)]=listeners[key$1];
}
return data;
}

function placeholder(h,rawChild){
if(/\d-keep-alive$/.test(rawChild.tag)){
return h('keep-alive',{
props:rawChild.componentOptions.propsData});

}
}

function hasParentTransition(vnode){
while(vnode=vnode.parent){
if(vnode.data.transition){
return true;
}
}
}

function isSameChild(child,oldChild){
return oldChild.key===child.key&&oldChild.tag===child.tag;
}

var isNotTextNode=function isNotTextNode(c){return c.tag||isAsyncPlaceholder(c);};

var isVShowDirective=function isVShowDirective(d){return d.name==='show';};

var Transition={
name:'transition',
props:transitionProps,
abstract:true,

render:function render(h){
var this$1=this;

var children=this.$slots.default;
if(!children){
return;
}

// filter out text nodes (possible whitespaces)
children=children.filter(isNotTextNode);
/* istanbul ignore if */
if(!children.length){
return;
}

// warn multiple elements
if(children.length>1){
warn(
'<transition> can only be used on a single element. Use '+
'<transition-group> for lists.',
this.$parent);

}

var mode=this.mode;

// warn invalid mode
if(mode&&mode!=='in-out'&&mode!=='out-in')
{
warn(
'invalid <transition> mode: '+mode,
this.$parent);

}

var rawChild=children[0];

// if this is a component root node and the component's
// parent container node also has transition, skip.
if(hasParentTransition(this.$vnode)){
return rawChild;
}

// apply transition data to child
// use getRealChild() to ignore abstract components e.g. keep-alive
var child=getRealChild(rawChild);
/* istanbul ignore if */
if(!child){
return rawChild;
}

if(this._leaving){
return placeholder(h,rawChild);
}

// ensure a key that is unique to the vnode type and to this transition
// component instance. This key will be used to remove pending leaving nodes
// during entering.
var id="__transition-"+this._uid+"-";
child.key=child.key==null?
child.isComment?
id+'comment':
id+child.tag:
isPrimitive(child.key)?
String(child.key).indexOf(id)===0?child.key:id+child.key:
child.key;

var data=(child.data||(child.data={})).transition=extractTransitionData(this);
var oldRawChild=this._vnode;
var oldChild=getRealChild(oldRawChild);

// mark v-show
// so that the transition module can hand over the control to the directive
if(child.data.directives&&child.data.directives.some(isVShowDirective)){
child.data.show=true;
}

if(
oldChild&&
oldChild.data&&
!isSameChild(child,oldChild)&&
!isAsyncPlaceholder(oldChild)&&
// #6687 component root is a comment node
!(oldChild.componentInstance&&oldChild.componentInstance._vnode.isComment))
{
// replace old child transition data with fresh one
// important for dynamic transitions!
var oldData=oldChild.data.transition=extend({},data);
// handle transition mode
if(mode==='out-in'){
// return placeholder node and queue update when leave finishes
this._leaving=true;
mergeVNodeHook(oldData,'afterLeave',function(){
this$1._leaving=false;
this$1.$forceUpdate();
});
return placeholder(h,rawChild);
}else if(mode==='in-out'){
if(isAsyncPlaceholder(child)){
return oldRawChild;
}
var delayedLeave;
var performLeave=function performLeave(){delayedLeave();};
mergeVNodeHook(data,'afterEnter',performLeave);
mergeVNodeHook(data,'enterCancelled',performLeave);
mergeVNodeHook(oldData,'delayLeave',function(leave){delayedLeave=leave;});
}
}

return rawChild;
}};


/*  */

var props=extend({
tag:String,
moveClass:String},
transitionProps);

delete props.mode;

var TransitionGroup={
props:props,

beforeMount:function beforeMount(){
var this$1=this;

var update=this._update;
this._update=function(vnode,hydrating){
var restoreActiveInstance=setActiveInstance(this$1);
// force removing pass
this$1.__patch__(
this$1._vnode,
this$1.kept,
false,// hydrating
true// removeOnly (!important, avoids unnecessary moves)
);
this$1._vnode=this$1.kept;
restoreActiveInstance();
update.call(this$1,vnode,hydrating);
};
},

render:function render(h){
var tag=this.tag||this.$vnode.data.tag||'span';
var map=Object.create(null);
var prevChildren=this.prevChildren=this.children;
var rawChildren=this.$slots.default||[];
var children=this.children=[];
var transitionData=extractTransitionData(this);

for(var i=0;i<rawChildren.length;i++){
var c=rawChildren[i];
if(c.tag){
if(c.key!=null&&String(c.key).indexOf('__vlist')!==0){
children.push(c);
map[c.key]=c;
(c.data||(c.data={})).transition=transitionData;
}else {
var opts=c.componentOptions;
var name=opts?opts.Ctor.options.name||opts.tag||'':c.tag;
warn("<transition-group> children must be keyed: <"+name+">");
}
}
}

if(prevChildren){
var kept=[];
var removed=[];
for(var i$1=0;i$1<prevChildren.length;i$1++){
var c$1=prevChildren[i$1];
c$1.data.transition=transitionData;
c$1.data.pos=c$1.elm.getBoundingClientRect();
if(map[c$1.key]){
kept.push(c$1);
}else {
removed.push(c$1);
}
}
this.kept=h(tag,null,kept);
this.removed=removed;
}

return h(tag,null,children);
},

updated:function updated(){
var children=this.prevChildren;
var moveClass=this.moveClass||(this.name||'v')+'-move';
if(!children.length||!this.hasMove(children[0].elm,moveClass)){
return;
}

// we divide the work into three loops to avoid mixing DOM reads and writes
// in each iteration - which helps prevent layout thrashing.
children.forEach(callPendingCbs);
children.forEach(recordPosition);
children.forEach(applyTranslation);

// force reflow to put everything in position
// assign to this to avoid being removed in tree-shaking
// $flow-disable-line
this._reflow=document.body.offsetHeight;

children.forEach(function(c){
if(c.data.moved){
var el=c.elm;
var s=el.style;
addTransitionClass(el,moveClass);
s.transform=s.WebkitTransform=s.transitionDuration='';
el.addEventListener(transitionEndEvent,el._moveCb=function cb(e){
if(e&&e.target!==el){
return;
}
if(!e||/transform$/.test(e.propertyName)){
el.removeEventListener(transitionEndEvent,cb);
el._moveCb=null;
removeTransitionClass(el,moveClass);
}
});
}
});
},

methods:{
hasMove:function hasMove(el,moveClass){
/* istanbul ignore if */
if(!hasTransition){
return false;
}
/* istanbul ignore if */
if(this._hasMove){
return this._hasMove;
}
// Detect whether an element with the move class applied has
// CSS transitions. Since the element may be inside an entering
// transition at this very moment, we make a clone of it and remove
// all other transition classes applied to ensure only the move class
// is applied.
var clone=el.cloneNode();
if(el._transitionClasses){
el._transitionClasses.forEach(function(cls){removeClass(clone,cls);});
}
addClass(clone,moveClass);
clone.style.display='none';
this.$el.appendChild(clone);
var info=getTransitionInfo(clone);
this.$el.removeChild(clone);
return this._hasMove=info.hasTransform;
}}};



function callPendingCbs(c){
/* istanbul ignore if */
if(c.elm._moveCb){
c.elm._moveCb();
}
/* istanbul ignore if */
if(c.elm._enterCb){
c.elm._enterCb();
}
}

function recordPosition(c){
c.data.newPos=c.elm.getBoundingClientRect();
}

function applyTranslation(c){
var oldPos=c.data.pos;
var newPos=c.data.newPos;
var dx=oldPos.left-newPos.left;
var dy=oldPos.top-newPos.top;
if(dx||dy){
c.data.moved=true;
var s=c.elm.style;
s.transform=s.WebkitTransform="translate("+dx+"px,"+dy+"px)";
s.transitionDuration='0s';
}
}

var platformComponents={
Transition:Transition,
TransitionGroup:TransitionGroup};


/*  */

// install platform specific utils
Vue.config.mustUseProp=mustUseProp;
Vue.config.isReservedTag=isReservedTag;
Vue.config.isReservedAttr=isReservedAttr;
Vue.config.getTagNamespace=getTagNamespace;
Vue.config.isUnknownElement=isUnknownElement;

// install platform runtime directives & components
extend(Vue.options.directives,platformDirectives);
extend(Vue.options.components,platformComponents);

// install platform patch function
Vue.prototype.__patch__=inBrowser?patch:noop;

// public mount method
Vue.prototype.$mount=function(
el,
hydrating)
{
el=el&&inBrowser?query(el):undefined;
return mountComponent(this,el,hydrating);
};

// devtools global hook
/* istanbul ignore next */
if(inBrowser){
setTimeout(function(){
if(config.devtools){
if(devtools){
devtools.emit('init',Vue);
}else {
console[console.info?'info':'log'](
'Download the Vue Devtools extension for a better development experience:\n'+
'https://github.com/vuejs/vue-devtools');

}
}
if(config.productionTip!==false&&
typeof console!=='undefined')
{
console[console.info?'info':'log'](
"You are running Vue in development mode.\n"+
"Make sure to turn on production mode when deploying for production.\n"+
"See more tips at https://vuejs.org/guide/deployment.html");

}
},0);
}

/*  */

var defaultTagRE=/\{\{((?:.|\r?\n)+?)\}\}/g;
var regexEscapeRE=/[-.*+?^${}()|[\]\/\\]/g;

var buildRegex=cached(function(delimiters){
var open=delimiters[0].replace(regexEscapeRE,'\\$&');
var close=delimiters[1].replace(regexEscapeRE,'\\$&');
return new RegExp(open+'((?:.|\\n)+?)'+close,'g');
});



function parseText(
text,
delimiters)
{
var tagRE=delimiters?buildRegex(delimiters):defaultTagRE;
if(!tagRE.test(text)){
return;
}
var tokens=[];
var rawTokens=[];
var lastIndex=tagRE.lastIndex=0;
var match,index,tokenValue;
while(match=tagRE.exec(text)){
index=match.index;
// push text token
if(index>lastIndex){
rawTokens.push(tokenValue=text.slice(lastIndex,index));
tokens.push(JSON.stringify(tokenValue));
}
// tag token
var exp=parseFilters(match[1].trim());
tokens.push("_s("+exp+")");
rawTokens.push({'@binding':exp});
lastIndex=index+match[0].length;
}
if(lastIndex<text.length){
rawTokens.push(tokenValue=text.slice(lastIndex));
tokens.push(JSON.stringify(tokenValue));
}
return {
expression:tokens.join('+'),
tokens:rawTokens};

}

/*  */

function transformNode(el,options){
var warn=options.warn||baseWarn;
var staticClass=getAndRemoveAttr(el,'class');
if(staticClass){
var res=parseText(staticClass,options.delimiters);
if(res){
warn(
"class=\""+staticClass+"\": "+
'Interpolation inside attributes has been removed. '+
'Use v-bind or the colon shorthand instead. For example, '+
'instead of <div class="{{ val }}">, use <div :class="val">.',
el.rawAttrsMap['class']);

}
}
if(staticClass){
el.staticClass=JSON.stringify(staticClass);
}
var classBinding=getBindingAttr(el,'class',false/* getStatic */);
if(classBinding){
el.classBinding=classBinding;
}
}

function genData(el){
var data='';
if(el.staticClass){
data+="staticClass:"+el.staticClass+",";
}
if(el.classBinding){
data+="class:"+el.classBinding+",";
}
return data;
}

var klass$1={
staticKeys:['staticClass'],
transformNode:transformNode,
genData:genData};


/*  */

function transformNode$1(el,options){
var warn=options.warn||baseWarn;
var staticStyle=getAndRemoveAttr(el,'style');
if(staticStyle){
/* istanbul ignore if */
{
var res=parseText(staticStyle,options.delimiters);
if(res){
warn(
"style=\""+staticStyle+"\": "+
'Interpolation inside attributes has been removed. '+
'Use v-bind or the colon shorthand instead. For example, '+
'instead of <div style="{{ val }}">, use <div :style="val">.',
el.rawAttrsMap['style']);

}
}
el.staticStyle=JSON.stringify(parseStyleText(staticStyle));
}

var styleBinding=getBindingAttr(el,'style',false/* getStatic */);
if(styleBinding){
el.styleBinding=styleBinding;
}
}

function genData$1(el){
var data='';
if(el.staticStyle){
data+="staticStyle:"+el.staticStyle+",";
}
if(el.styleBinding){
data+="style:("+el.styleBinding+"),";
}
return data;
}

var style$1={
staticKeys:['staticStyle'],
transformNode:transformNode$1,
genData:genData$1};


/*  */

var decoder;

var he={
decode:function decode(html){
decoder=decoder||document.createElement('div');
decoder.innerHTML=html;
return decoder.textContent;
}};


/*  */

var isUnaryTag=makeMap(
'area,base,br,col,embed,frame,hr,img,input,isindex,keygen,'+
'link,meta,param,source,track,wbr');


// Elements that you can, intentionally, leave open
// (and which close themselves)
var canBeLeftOpenTag=makeMap(
'colgroup,dd,dt,li,options,p,td,tfoot,th,thead,tr,source');


// HTML5 tags https://html.spec.whatwg.org/multipage/indices.html#elements-3
// Phrasing Content https://html.spec.whatwg.org/multipage/dom.html#phrasing-content
var isNonPhrasingTag=makeMap(
'address,article,aside,base,blockquote,body,caption,col,colgroup,dd,'+
'details,dialog,div,dl,dt,fieldset,figcaption,figure,footer,form,'+
'h1,h2,h3,h4,h5,h6,head,header,hgroup,hr,html,legend,li,menuitem,meta,'+
'optgroup,option,param,rp,rt,source,style,summary,tbody,td,tfoot,th,thead,'+
'title,tr,track');


/**
 * Not type-checking this file because it's mostly vendor code.
 */

// Regular Expressions for parsing tags and attributes
var attribute=/^\s*([^\s"'<>\/=]+)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/;
var dynamicArgAttribute=/^\s*((?:v-[\w-]+:|@|:|#)\[[^=]+\][^\s"'<>\/=]*)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/;
var ncname="[a-zA-Z_][\\-\\.0-9_a-zA-Z"+unicodeRegExp.source+"]*";
var qnameCapture="((?:"+ncname+"\\:)?"+ncname+")";
var startTagOpen=new RegExp("^<"+qnameCapture);
var startTagClose=/^\s*(\/?)>/;
var endTag=new RegExp("^<\\/"+qnameCapture+"[^>]*>");
var doctype=/^<!DOCTYPE [^>]+>/i;
// #7298: escape - to avoid being passed as HTML comment when inlined in page
var comment=/^<!\--/;
var conditionalComment=/^<!\[/;

// Special Elements (can contain anything)
var isPlainTextElement=makeMap('script,style,textarea',true);
var reCache={};

var decodingMap={
'&lt;':'<',
'&gt;':'>',
'&quot;':'"',
'&amp;':'&',
'&#10;':'\n',
'&#9;':'\t',
'&#39;':"'"};

var encodedAttr=/&(?:lt|gt|quot|amp|#39);/g;
var encodedAttrWithNewLines=/&(?:lt|gt|quot|amp|#39|#10|#9);/g;

// #5992
var isIgnoreNewlineTag=makeMap('pre,textarea',true);
var shouldIgnoreFirstNewline=function shouldIgnoreFirstNewline(tag,html){return tag&&isIgnoreNewlineTag(tag)&&html[0]==='\n';};

function decodeAttr(value,shouldDecodeNewlines){
var re=shouldDecodeNewlines?encodedAttrWithNewLines:encodedAttr;
return value.replace(re,function(match){return decodingMap[match];});
}

function parseHTML(html,options){
var stack=[];
var expectHTML=options.expectHTML;
var isUnaryTag$$1=options.isUnaryTag||no;
var canBeLeftOpenTag$$1=options.canBeLeftOpenTag||no;
var index=0;
var last,lastTag;
while(html){
last=html;
// Make sure we're not in a plaintext content element like script/style
if(!lastTag||!isPlainTextElement(lastTag)){
var textEnd=html.indexOf('<');
if(textEnd===0){
// Comment:
if(comment.test(html)){
var commentEnd=html.indexOf('-->');

if(commentEnd>=0){
if(options.shouldKeepComment){
options.comment(html.substring(4,commentEnd),index,index+commentEnd+3);
}
advance(commentEnd+3);
continue;
}
}

// http://en.wikipedia.org/wiki/Conditional_comment#Downlevel-revealed_conditional_comment
if(conditionalComment.test(html)){
var conditionalEnd=html.indexOf(']>');

if(conditionalEnd>=0){
advance(conditionalEnd+2);
continue;
}
}

// Doctype:
var doctypeMatch=html.match(doctype);
if(doctypeMatch){
advance(doctypeMatch[0].length);
continue;
}

// End tag:
var endTagMatch=html.match(endTag);
if(endTagMatch){
var curIndex=index;
advance(endTagMatch[0].length);
parseEndTag(endTagMatch[1],curIndex,index);
continue;
}

// Start tag:
var startTagMatch=parseStartTag();
if(startTagMatch){
handleStartTag(startTagMatch);
if(shouldIgnoreFirstNewline(startTagMatch.tagName,html)){
advance(1);
}
continue;
}
}

var text=void 0,rest=void 0,next=void 0;
if(textEnd>=0){
rest=html.slice(textEnd);
while(
!endTag.test(rest)&&
!startTagOpen.test(rest)&&
!comment.test(rest)&&
!conditionalComment.test(rest))
{
// < in plain text, be forgiving and treat it as text
next=rest.indexOf('<',1);
if(next<0){break;}
textEnd+=next;
rest=html.slice(textEnd);
}
text=html.substring(0,textEnd);
}

if(textEnd<0){
text=html;
}

if(text){
advance(text.length);
}

if(options.chars&&text){
options.chars(text,index-text.length,index);
}
}else {
var endTagLength=0;
var stackedTag=lastTag.toLowerCase();
var reStackedTag=reCache[stackedTag]||(reCache[stackedTag]=new RegExp('([\\s\\S]*?)(</'+stackedTag+'[^>]*>)','i'));
var rest$1=html.replace(reStackedTag,function(all,text,endTag){
endTagLength=endTag.length;
if(!isPlainTextElement(stackedTag)&&stackedTag!=='noscript'){
text=text.
replace(/<!\--([\s\S]*?)-->/g,'$1')// #7298
.replace(/<!\[CDATA\[([\s\S]*?)]]>/g,'$1');
}
if(shouldIgnoreFirstNewline(stackedTag,text)){
text=text.slice(1);
}
if(options.chars){
options.chars(text);
}
return '';
});
index+=html.length-rest$1.length;
html=rest$1;
parseEndTag(stackedTag,index-endTagLength,index);
}

if(html===last){
options.chars&&options.chars(html);
if(!stack.length&&options.warn){
options.warn("Mal-formatted tag at end of template: \""+html+"\"",{start:index+html.length});
}
break;
}
}

// Clean up any remaining tags
parseEndTag();

function advance(n){
index+=n;
html=html.substring(n);
}

function parseStartTag(){
var start=html.match(startTagOpen);
if(start){
var match={
tagName:start[1],
attrs:[],
start:index};

advance(start[0].length);
var end,attr;
while(!(end=html.match(startTagClose))&&(attr=html.match(dynamicArgAttribute)||html.match(attribute))){
attr.start=index;
advance(attr[0].length);
attr.end=index;
match.attrs.push(attr);
}
if(end){
match.unarySlash=end[1];
advance(end[0].length);
match.end=index;
return match;
}
}
}

function handleStartTag(match){
var tagName=match.tagName;
var unarySlash=match.unarySlash;

if(expectHTML){
if(lastTag==='p'&&isNonPhrasingTag(tagName)){
parseEndTag(lastTag);
}
if(canBeLeftOpenTag$$1(tagName)&&lastTag===tagName){
parseEndTag(tagName);
}
}

var unary=isUnaryTag$$1(tagName)||!!unarySlash;

var l=match.attrs.length;
var attrs=new Array(l);
for(var i=0;i<l;i++){
var args=match.attrs[i];
var value=args[3]||args[4]||args[5]||'';
var shouldDecodeNewlines=tagName==='a'&&args[1]==='href'?
options.shouldDecodeNewlinesForHref:
options.shouldDecodeNewlines;
attrs[i]={
name:args[1],
value:decodeAttr(value,shouldDecodeNewlines)};

if(options.outputSourceRange){
attrs[i].start=args.start+args[0].match(/^\s*/).length;
attrs[i].end=args.end;
}
}

if(!unary){
stack.push({tag:tagName,lowerCasedTag:tagName.toLowerCase(),attrs:attrs,start:match.start,end:match.end});
lastTag=tagName;
}

if(options.start){
options.start(tagName,attrs,unary,match.start,match.end);
}
}

function parseEndTag(tagName,start,end){
var pos,lowerCasedTagName;
if(start==null){start=index;}
if(end==null){end=index;}

// Find the closest opened tag of the same type
if(tagName){
lowerCasedTagName=tagName.toLowerCase();
for(pos=stack.length-1;pos>=0;pos--){
if(stack[pos].lowerCasedTag===lowerCasedTagName){
break;
}
}
}else {
// If no tag name is provided, clean shop
pos=0;
}

if(pos>=0){
// Close all the open elements, up the stack
for(var i=stack.length-1;i>=pos;i--){
if(i>pos||!tagName&&
options.warn)
{
options.warn(
"tag <"+stack[i].tag+"> has no matching end tag.",
{start:stack[i].start,end:stack[i].end});

}
if(options.end){
options.end(stack[i].tag,start,end);
}
}

// Remove the open elements from the stack
stack.length=pos;
lastTag=pos&&stack[pos-1].tag;
}else if(lowerCasedTagName==='br'){
if(options.start){
options.start(tagName,[],true,start,end);
}
}else if(lowerCasedTagName==='p'){
if(options.start){
options.start(tagName,[],false,start,end);
}
if(options.end){
options.end(tagName,start,end);
}
}
}
}

/*  */

var onRE=/^@|^v-on:/;
var dirRE=/^v-|^@|^:|^#/;
var forAliasRE=/([\s\S]*?)\s+(?:in|of)\s+([\s\S]*)/;
var forIteratorRE=/,([^,\}\]]*)(?:,([^,\}\]]*))?$/;
var stripParensRE=/^\(|\)$/g;
var dynamicArgRE=/^\[.*\]$/;

var argRE=/:(.*)$/;
var bindRE=/^:|^\.|^v-bind:/;
var modifierRE=/\.[^.\]]+(?=[^\]]*$)/g;

var slotRE=/^v-slot(:|$)|^#/;

var lineBreakRE=/[\r\n]/;
var whitespaceRE$1=/\s+/g;

var invalidAttributeRE=/[\s"'<>\/=]/;

var decodeHTMLCached=cached(he.decode);

var emptySlotScopeToken="_empty_";

// configurable state
var warn$2;
var delimiters;
var transforms;
var preTransforms;
var postTransforms;
var platformIsPreTag;
var platformMustUseProp;
var platformGetTagNamespace;
var maybeComponent;

function createASTElement(
tag,
attrs,
parent)
{
return {
type:1,
tag:tag,
attrsList:attrs,
attrsMap:makeAttrsMap(attrs),
rawAttrsMap:{},
parent:parent,
children:[]};

}

/**
 * Convert HTML string to AST.
 */
function parse(
template,
options)
{
warn$2=options.warn||baseWarn;

platformIsPreTag=options.isPreTag||no;
platformMustUseProp=options.mustUseProp||no;
platformGetTagNamespace=options.getTagNamespace||no;
var isReservedTag=options.isReservedTag||no;
maybeComponent=function maybeComponent(el){return !!el.component||!isReservedTag(el.tag);};

transforms=pluckModuleFunction(options.modules,'transformNode');
preTransforms=pluckModuleFunction(options.modules,'preTransformNode');
postTransforms=pluckModuleFunction(options.modules,'postTransformNode');

delimiters=options.delimiters;

var stack=[];
var preserveWhitespace=options.preserveWhitespace!==false;
var whitespaceOption=options.whitespace;
var root;
var currentParent;
var inVPre=false;
var inPre=false;
var warned=false;

function warnOnce(msg,range){
if(!warned){
warned=true;
warn$2(msg,range);
}
}

function closeElement(element){
trimEndingWhitespace(element);
if(!inVPre&&!element.processed){
element=processElement(element,options);
}
// tree management
if(!stack.length&&element!==root){
// allow root elements with v-if, v-else-if and v-else
if(root.if&&(element.elseif||element.else)){
{
checkRootConstraints(element);
}
addIfCondition(root,{
exp:element.elseif,
block:element});

}else {
warnOnce(
"Component template should contain exactly one root element. "+
"If you are using v-if on multiple elements, "+
"use v-else-if to chain them instead.",
{start:element.start});

}
}
if(currentParent&&!element.forbidden){
if(element.elseif||element.else){
processIfConditions(element,currentParent);
}else {
if(element.slotScope){
// scoped slot
// keep it in the children list so that v-else(-if) conditions can
// find it as the prev node.
var name=element.slotTarget||'"default"';
(currentParent.scopedSlots||(currentParent.scopedSlots={}))[name]=element;
}
currentParent.children.push(element);
element.parent=currentParent;
}
}

// final children cleanup
// filter out scoped slots
element.children=element.children.filter(function(c){return !c.slotScope;});
// remove trailing whitespace node again
trimEndingWhitespace(element);

// check pre state
if(element.pre){
inVPre=false;
}
if(platformIsPreTag(element.tag)){
inPre=false;
}
// apply post-transforms
for(var i=0;i<postTransforms.length;i++){
postTransforms[i](element,options);
}
}

function trimEndingWhitespace(el){
// remove trailing whitespace node
if(!inPre){
var lastNode;
while(
(lastNode=el.children[el.children.length-1])&&
lastNode.type===3&&
lastNode.text===' ')
{
el.children.pop();
}
}
}

function checkRootConstraints(el){
if(el.tag==='slot'||el.tag==='template'){
warnOnce(
"Cannot use <"+el.tag+"> as component root element because it may "+
'contain multiple nodes.',
{start:el.start});

}
if(el.attrsMap.hasOwnProperty('v-for')){
warnOnce(
'Cannot use v-for on stateful component root element because '+
'it renders multiple elements.',
el.rawAttrsMap['v-for']);

}
}

parseHTML(template,{
warn:warn$2,
expectHTML:options.expectHTML,
isUnaryTag:options.isUnaryTag,
canBeLeftOpenTag:options.canBeLeftOpenTag,
shouldDecodeNewlines:options.shouldDecodeNewlines,
shouldDecodeNewlinesForHref:options.shouldDecodeNewlinesForHref,
shouldKeepComment:options.comments,
outputSourceRange:options.outputSourceRange,
start:function start(tag,attrs,unary,start$1,end){
// check namespace.
// inherit parent ns if there is one
var ns=currentParent&&currentParent.ns||platformGetTagNamespace(tag);

// handle IE svg bug
/* istanbul ignore if */
if(isIE&&ns==='svg'){
attrs=guardIESVGBug(attrs);
}

var element=createASTElement(tag,attrs,currentParent);
if(ns){
element.ns=ns;
}

{
if(options.outputSourceRange){
element.start=start$1;
element.end=end;
element.rawAttrsMap=element.attrsList.reduce(function(cumulated,attr){
cumulated[attr.name]=attr;
return cumulated;
},{});
}
attrs.forEach(function(attr){
if(invalidAttributeRE.test(attr.name)){
warn$2(
"Invalid dynamic argument expression: attribute names cannot contain "+
"spaces, quotes, <, >, / or =.",
{
start:attr.start+attr.name.indexOf("["),
end:attr.start+attr.name.length});


}
});
}

if(isForbiddenTag(element)&&!isServerRendering()){
element.forbidden=true;
warn$2(
'Templates should only be responsible for mapping the state to the '+
'UI. Avoid placing tags with side-effects in your templates, such as '+
"<"+tag+">"+', as they will not be parsed.',
{start:element.start});

}

// apply pre-transforms
for(var i=0;i<preTransforms.length;i++){
element=preTransforms[i](element,options)||element;
}

if(!inVPre){
processPre(element);
if(element.pre){
inVPre=true;
}
}
if(platformIsPreTag(element.tag)){
inPre=true;
}
if(inVPre){
processRawAttrs(element);
}else if(!element.processed){
// structural directives
processFor(element);
processIf(element);
processOnce(element);
}

if(!root){
root=element;
{
checkRootConstraints(root);
}
}

if(!unary){
currentParent=element;
stack.push(element);
}else {
closeElement(element);
}
},

end:function end(tag,start,end$1){
var element=stack[stack.length-1];
// pop stack
stack.length-=1;
currentParent=stack[stack.length-1];
if(options.outputSourceRange){
element.end=end$1;
}
closeElement(element);
},

chars:function chars(text,start,end){
if(!currentParent){
{
if(text===template){
warnOnce(
'Component template requires a root element, rather than just text.',
{start:start});

}else if(text=text.trim()){
warnOnce(
"text \""+text+"\" outside root element will be ignored.",
{start:start});

}
}
return;
}
// IE textarea placeholder bug
/* istanbul ignore if */
if(isIE&&
currentParent.tag==='textarea'&&
currentParent.attrsMap.placeholder===text)
{
return;
}
var children=currentParent.children;
if(inPre||text.trim()){
text=isTextTag(currentParent)?text:decodeHTMLCached(text);
}else if(!children.length){
// remove the whitespace-only node right after an opening tag
text='';
}else if(whitespaceOption){
if(whitespaceOption==='condense'){
// in condense mode, remove the whitespace node if it contains
// line break, otherwise condense to a single space
text=lineBreakRE.test(text)?'':' ';
}else {
text=' ';
}
}else {
text=preserveWhitespace?' ':'';
}
if(text){
if(!inPre&&whitespaceOption==='condense'){
// condense consecutive whitespaces into single space
text=text.replace(whitespaceRE$1,' ');
}
var res;
var child;
if(!inVPre&&text!==' '&&(res=parseText(text,delimiters))){
child={
type:2,
expression:res.expression,
tokens:res.tokens,
text:text};

}else if(text!==' '||!children.length||children[children.length-1].text!==' '){
child={
type:3,
text:text};

}
if(child){
if(options.outputSourceRange){
child.start=start;
child.end=end;
}
children.push(child);
}
}
},
comment:function comment(text,start,end){
// adding anything as a sibling to the root node is forbidden
// comments should still be allowed, but ignored
if(currentParent){
var child={
type:3,
text:text,
isComment:true};

if(options.outputSourceRange){
child.start=start;
child.end=end;
}
currentParent.children.push(child);
}
}});

return root;
}

function processPre(el){
if(getAndRemoveAttr(el,'v-pre')!=null){
el.pre=true;
}
}

function processRawAttrs(el){
var list=el.attrsList;
var len=list.length;
if(len){
var attrs=el.attrs=new Array(len);
for(var i=0;i<len;i++){
attrs[i]={
name:list[i].name,
value:JSON.stringify(list[i].value)};

if(list[i].start!=null){
attrs[i].start=list[i].start;
attrs[i].end=list[i].end;
}
}
}else if(!el.pre){
// non root node in pre blocks with no attributes
el.plain=true;
}
}

function processElement(
element,
options)
{
processKey(element);

// determine whether this is a plain element after
// removing structural attributes
element.plain=
!element.key&&
!element.scopedSlots&&
!element.attrsList.length;


processRef(element);
processSlotContent(element);
processSlotOutlet(element);
processComponent(element);
for(var i=0;i<transforms.length;i++){
element=transforms[i](element,options)||element;
}
processAttrs(element);
return element;
}

function processKey(el){
var exp=getBindingAttr(el,'key');
if(exp){
{
if(el.tag==='template'){
warn$2(
"<template> cannot be keyed. Place the key on real elements instead.",
getRawBindingAttr(el,'key'));

}
if(el.for){
var iterator=el.iterator2||el.iterator1;
var parent=el.parent;
if(iterator&&iterator===exp&&parent&&parent.tag==='transition-group'){
warn$2(
"Do not use v-for index as key on <transition-group> children, "+
"this is the same as not using keys.",
getRawBindingAttr(el,'key'),
true/* tip */);

}
}
}
el.key=exp;
}
}

function processRef(el){
var ref=getBindingAttr(el,'ref');
if(ref){
el.ref=ref;
el.refInFor=checkInFor(el);
}
}

function processFor(el){
var exp;
if(exp=getAndRemoveAttr(el,'v-for')){
var res=parseFor(exp);
if(res){
extend(el,res);
}else {
warn$2(
"Invalid v-for expression: "+exp,
el.rawAttrsMap['v-for']);

}
}
}



function parseFor(exp){
var inMatch=exp.match(forAliasRE);
if(!inMatch){return;}
var res={};
res.for=inMatch[2].trim();
var alias=inMatch[1].trim().replace(stripParensRE,'');
var iteratorMatch=alias.match(forIteratorRE);
if(iteratorMatch){
res.alias=alias.replace(forIteratorRE,'').trim();
res.iterator1=iteratorMatch[1].trim();
if(iteratorMatch[2]){
res.iterator2=iteratorMatch[2].trim();
}
}else {
res.alias=alias;
}
return res;
}

function processIf(el){
var exp=getAndRemoveAttr(el,'v-if');
if(exp){
el.if=exp;
addIfCondition(el,{
exp:exp,
block:el});

}else {
if(getAndRemoveAttr(el,'v-else')!=null){
el.else=true;
}
var elseif=getAndRemoveAttr(el,'v-else-if');
if(elseif){
el.elseif=elseif;
}
}
}

function processIfConditions(el,parent){
var prev=findPrevElement(parent.children);
if(prev&&prev.if){
addIfCondition(prev,{
exp:el.elseif,
block:el});

}else {
warn$2(
"v-"+(el.elseif?'else-if="'+el.elseif+'"':'else')+" "+
"used on element <"+el.tag+"> without corresponding v-if.",
el.rawAttrsMap[el.elseif?'v-else-if':'v-else']);

}
}

function findPrevElement(children){
var i=children.length;
while(i--){
if(children[i].type===1){
return children[i];
}else {
if(children[i].text!==' '){
warn$2(
"text \""+children[i].text.trim()+"\" between v-if and v-else(-if) "+
"will be ignored.",
children[i]);

}
children.pop();
}
}
}

function addIfCondition(el,condition){
if(!el.ifConditions){
el.ifConditions=[];
}
el.ifConditions.push(condition);
}

function processOnce(el){
var once$$1=getAndRemoveAttr(el,'v-once');
if(once$$1!=null){
el.once=true;
}
}

// handle content being passed to a component as slot,
// e.g. <template slot="xxx">, <div slot-scope="xxx">
function processSlotContent(el){
var slotScope;
if(el.tag==='template'){
slotScope=getAndRemoveAttr(el,'scope');
/* istanbul ignore if */
if(slotScope){
warn$2(
"the \"scope\" attribute for scoped slots have been deprecated and "+
"replaced by \"slot-scope\" since 2.5. The new \"slot-scope\" attribute "+
"can also be used on plain elements in addition to <template> to "+
"denote scoped slots.",
el.rawAttrsMap['scope'],
true);

}
el.slotScope=slotScope||getAndRemoveAttr(el,'slot-scope');
}else if(slotScope=getAndRemoveAttr(el,'slot-scope')){
/* istanbul ignore if */
if(el.attrsMap['v-for']){
warn$2(
"Ambiguous combined usage of slot-scope and v-for on <"+el.tag+"> "+
"(v-for takes higher priority). Use a wrapper <template> for the "+
"scoped slot to make it clearer.",
el.rawAttrsMap['slot-scope'],
true);

}
el.slotScope=slotScope;
}

// slot="xxx"
var slotTarget=getBindingAttr(el,'slot');
if(slotTarget){
el.slotTarget=slotTarget==='""'?'"default"':slotTarget;
el.slotTargetDynamic=!!(el.attrsMap[':slot']||el.attrsMap['v-bind:slot']);
// preserve slot as an attribute for native shadow DOM compat
// only for non-scoped slots.
if(el.tag!=='template'&&!el.slotScope){
addAttr(el,'slot',slotTarget,getRawBindingAttr(el,'slot'));
}
}

// 2.6 v-slot syntax
{
if(el.tag==='template'){
// v-slot on <template>
var slotBinding=getAndRemoveAttrByRegex(el,slotRE);
if(slotBinding){
{
if(el.slotTarget||el.slotScope){
warn$2(
"Unexpected mixed usage of different slot syntaxes.",
el);

}
if(el.parent&&!maybeComponent(el.parent)){
warn$2(
"<template v-slot> can only appear at the root level inside "+
"the receiving component",
el);

}
}
var ref=getSlotName(slotBinding);
var name=ref.name;
var dynamic=ref.dynamic;
el.slotTarget=name;
el.slotTargetDynamic=dynamic;
el.slotScope=slotBinding.value||emptySlotScopeToken;// force it into a scoped slot for perf
}
}else {
// v-slot on component, denotes default slot
var slotBinding$1=getAndRemoveAttrByRegex(el,slotRE);
if(slotBinding$1){
{
if(!maybeComponent(el)){
warn$2(
"v-slot can only be used on components or <template>.",
slotBinding$1);

}
if(el.slotScope||el.slotTarget){
warn$2(
"Unexpected mixed usage of different slot syntaxes.",
el);

}
if(el.scopedSlots){
warn$2(
"To avoid scope ambiguity, the default slot should also use "+
"<template> syntax when there are other named slots.",
slotBinding$1);

}
}
// add the component's children to its default slot
var slots=el.scopedSlots||(el.scopedSlots={});
var ref$1=getSlotName(slotBinding$1);
var name$1=ref$1.name;
var dynamic$1=ref$1.dynamic;
var slotContainer=slots[name$1]=createASTElement('template',[],el);
slotContainer.slotTarget=name$1;
slotContainer.slotTargetDynamic=dynamic$1;
slotContainer.children=el.children.filter(function(c){
if(!c.slotScope){
c.parent=slotContainer;
return true;
}
});
slotContainer.slotScope=slotBinding$1.value||emptySlotScopeToken;
// remove children as they are returned from scopedSlots now
el.children=[];
// mark el non-plain so data gets generated
el.plain=false;
}
}
}
}

function getSlotName(binding){
var name=binding.name.replace(slotRE,'');
if(!name){
if(binding.name[0]!=='#'){
name='default';
}else {
warn$2(
"v-slot shorthand syntax requires a slot name.",
binding);

}
}
return dynamicArgRE.test(name)
// dynamic [name]
?{name:name.slice(1,-1),dynamic:true}
// static name
:{name:"\""+name+"\"",dynamic:false};
}

// handle <slot/> outlets
function processSlotOutlet(el){
if(el.tag==='slot'){
el.slotName=getBindingAttr(el,'name');
if(el.key){
warn$2(
"`key` does not work on <slot> because slots are abstract outlets "+
"and can possibly expand into multiple elements. "+
"Use the key on a wrapping element instead.",
getRawBindingAttr(el,'key'));

}
}
}

function processComponent(el){
var binding;
if(binding=getBindingAttr(el,'is')){
el.component=binding;
}
if(getAndRemoveAttr(el,'inline-template')!=null){
el.inlineTemplate=true;
}
}

function processAttrs(el){
var list=el.attrsList;
var i,l,name,rawName,value,modifiers,syncGen,isDynamic;
for(i=0,l=list.length;i<l;i++){
name=rawName=list[i].name;
value=list[i].value;
if(dirRE.test(name)){
// mark element as dynamic
el.hasBindings=true;
// modifiers
modifiers=parseModifiers(name.replace(dirRE,''));
// support .foo shorthand syntax for the .prop modifier
if(modifiers){
name=name.replace(modifierRE,'');
}
if(bindRE.test(name)){// v-bind
name=name.replace(bindRE,'');
value=parseFilters(value);
isDynamic=dynamicArgRE.test(name);
if(isDynamic){
name=name.slice(1,-1);
}
if(
value.trim().length===0)
{
warn$2(
"The value for a v-bind expression cannot be empty. Found in \"v-bind:"+name+"\"");

}
if(modifiers){
if(modifiers.prop&&!isDynamic){
name=camelize(name);
if(name==='innerHtml'){name='innerHTML';}
}
if(modifiers.camel&&!isDynamic){
name=camelize(name);
}
if(modifiers.sync){
syncGen=genAssignmentCode(value,"$event");
if(!isDynamic){
addHandler(
el,
"update:"+camelize(name),
syncGen,
null,
false,
warn$2,
list[i]);

if(hyphenate(name)!==camelize(name)){
addHandler(
el,
"update:"+hyphenate(name),
syncGen,
null,
false,
warn$2,
list[i]);

}
}else {
// handler w/ dynamic event name
addHandler(
el,
"\"update:\"+("+name+")",
syncGen,
null,
false,
warn$2,
list[i],
true// dynamic
);
}
}
}
if(modifiers&&modifiers.prop||
!el.component&&platformMustUseProp(el.tag,el.attrsMap.type,name))
{
addProp(el,name,value,list[i],isDynamic);
}else {
addAttr(el,name,value,list[i],isDynamic);
}
}else if(onRE.test(name)){// v-on
name=name.replace(onRE,'');
isDynamic=dynamicArgRE.test(name);
if(isDynamic){
name=name.slice(1,-1);
}
addHandler(el,name,value,modifiers,false,warn$2,list[i],isDynamic);
}else {// normal directives
name=name.replace(dirRE,'');
// parse arg
var argMatch=name.match(argRE);
var arg=argMatch&&argMatch[1];
isDynamic=false;
if(arg){
name=name.slice(0,-(arg.length+1));
if(dynamicArgRE.test(arg)){
arg=arg.slice(1,-1);
isDynamic=true;
}
}
addDirective(el,name,rawName,value,arg,isDynamic,modifiers,list[i]);
if(name==='model'){
checkForAliasModel(el,value);
}
}
}else {
// literal attribute
{
var res=parseText(value,delimiters);
if(res){
warn$2(
name+"=\""+value+"\": "+
'Interpolation inside attributes has been removed. '+
'Use v-bind or the colon shorthand instead. For example, '+
'instead of <div id="{{ val }}">, use <div :id="val">.',
list[i]);

}
}
addAttr(el,name,JSON.stringify(value),list[i]);
// #6887 firefox doesn't update muted state if set via attribute
// even immediately after element creation
if(!el.component&&
name==='muted'&&
platformMustUseProp(el.tag,el.attrsMap.type,name)){
addProp(el,name,'true',list[i]);
}
}
}
}

function checkInFor(el){
var parent=el;
while(parent){
if(parent.for!==undefined){
return true;
}
parent=parent.parent;
}
return false;
}

function parseModifiers(name){
var match=name.match(modifierRE);
if(match){
var ret={};
match.forEach(function(m){ret[m.slice(1)]=true;});
return ret;
}
}

function makeAttrsMap(attrs){
var map={};
for(var i=0,l=attrs.length;i<l;i++){
if(
map[attrs[i].name]&&!isIE&&!isEdge)
{
warn$2('duplicate attribute: '+attrs[i].name,attrs[i]);
}
map[attrs[i].name]=attrs[i].value;
}
return map;
}

// for script (e.g. type="x/template") or style, do not decode content
function isTextTag(el){
return el.tag==='script'||el.tag==='style';
}

function isForbiddenTag(el){
return(
el.tag==='style'||
el.tag==='script'&&(
!el.attrsMap.type||
el.attrsMap.type==='text/javascript'));


}

var ieNSBug=/^xmlns:NS\d+/;
var ieNSPrefix=/^NS\d+:/;

/* istanbul ignore next */
function guardIESVGBug(attrs){
var res=[];
for(var i=0;i<attrs.length;i++){
var attr=attrs[i];
if(!ieNSBug.test(attr.name)){
attr.name=attr.name.replace(ieNSPrefix,'');
res.push(attr);
}
}
return res;
}

function checkForAliasModel(el,value){
var _el=el;
while(_el){
if(_el.for&&_el.alias===value){
warn$2(
"<"+el.tag+" v-model=\""+value+"\">: "+
"You are binding v-model directly to a v-for iteration alias. "+
"This will not be able to modify the v-for source array because "+
"writing to the alias is like modifying a function local variable. "+
"Consider using an array of objects and use v-model on an object property instead.",
el.rawAttrsMap['v-model']);

}
_el=_el.parent;
}
}

/*  */

function preTransformNode(el,options){
if(el.tag==='input'){
var map=el.attrsMap;
if(!map['v-model']){
return;
}

var typeBinding;
if(map[':type']||map['v-bind:type']){
typeBinding=getBindingAttr(el,'type');
}
if(!map.type&&!typeBinding&&map['v-bind']){
typeBinding="("+map['v-bind']+").type";
}

if(typeBinding){
var ifCondition=getAndRemoveAttr(el,'v-if',true);
var ifConditionExtra=ifCondition?"&&("+ifCondition+")":"";
var hasElse=getAndRemoveAttr(el,'v-else',true)!=null;
var elseIfCondition=getAndRemoveAttr(el,'v-else-if',true);
// 1. checkbox
var branch0=cloneASTElement(el);
// process for on the main node
processFor(branch0);
addRawAttr(branch0,'type','checkbox');
processElement(branch0,options);
branch0.processed=true;// prevent it from double-processed
branch0.if="("+typeBinding+")==='checkbox'"+ifConditionExtra;
addIfCondition(branch0,{
exp:branch0.if,
block:branch0});

// 2. add radio else-if condition
var branch1=cloneASTElement(el);
getAndRemoveAttr(branch1,'v-for',true);
addRawAttr(branch1,'type','radio');
processElement(branch1,options);
addIfCondition(branch0,{
exp:"("+typeBinding+")==='radio'"+ifConditionExtra,
block:branch1});

// 3. other
var branch2=cloneASTElement(el);
getAndRemoveAttr(branch2,'v-for',true);
addRawAttr(branch2,':type',typeBinding);
processElement(branch2,options);
addIfCondition(branch0,{
exp:ifCondition,
block:branch2});


if(hasElse){
branch0.else=true;
}else if(elseIfCondition){
branch0.elseif=elseIfCondition;
}

return branch0;
}
}
}

function cloneASTElement(el){
return createASTElement(el.tag,el.attrsList.slice(),el.parent);
}

var model$1={
preTransformNode:preTransformNode};


var modules$1=[
klass$1,
style$1,
model$1];


/*  */

function text(el,dir){
if(dir.value){
addProp(el,'textContent',"_s("+dir.value+")",dir);
}
}

/*  */

function html(el,dir){
if(dir.value){
addProp(el,'innerHTML',"_s("+dir.value+")",dir);
}
}

var directives$1={
model:model,
text:text,
html:html};


/*  */

var baseOptions={
expectHTML:true,
modules:modules$1,
directives:directives$1,
isPreTag:isPreTag,
isUnaryTag:isUnaryTag,
mustUseProp:mustUseProp,
canBeLeftOpenTag:canBeLeftOpenTag,
isReservedTag:isReservedTag,
getTagNamespace:getTagNamespace,
staticKeys:genStaticKeys(modules$1)};


/*  */

var isStaticKey;
var isPlatformReservedTag;

var genStaticKeysCached=cached(genStaticKeys$1);

/**
 * Goal of the optimizer: walk the generated template AST tree
 * and detect sub-trees that are purely static, i.e. parts of
 * the DOM that never needs to change.
 *
 * Once we detect these sub-trees, we can:
 *
 * 1. Hoist them into constants, so that we no longer need to
 *    create fresh nodes for them on each re-render;
 * 2. Completely skip them in the patching process.
 */
function optimize(root,options){
if(!root){return;}
isStaticKey=genStaticKeysCached(options.staticKeys||'');
isPlatformReservedTag=options.isReservedTag||no;
// first pass: mark all non-static nodes.
markStatic$1(root);
// second pass: mark static roots.
markStaticRoots(root,false);
}

function genStaticKeys$1(keys){
return makeMap(
'type,tag,attrsList,attrsMap,plain,parent,children,attrs,start,end,rawAttrsMap'+(
keys?','+keys:''));

}

function markStatic$1(node){
node.static=isStatic(node);
if(node.type===1){
// do not make component slot content static. this avoids
// 1. components not able to mutate slot nodes
// 2. static slot content fails for hot-reloading
if(
!isPlatformReservedTag(node.tag)&&
node.tag!=='slot'&&
node.attrsMap['inline-template']==null)
{
return;
}
for(var i=0,l=node.children.length;i<l;i++){
var child=node.children[i];
markStatic$1(child);
if(!child.static){
node.static=false;
}
}
if(node.ifConditions){
for(var i$1=1,l$1=node.ifConditions.length;i$1<l$1;i$1++){
var block=node.ifConditions[i$1].block;
markStatic$1(block);
if(!block.static){
node.static=false;
}
}
}
}
}

function markStaticRoots(node,isInFor){
if(node.type===1){
if(node.static||node.once){
node.staticInFor=isInFor;
}
// For a node to qualify as a static root, it should have children that
// are not just static text. Otherwise the cost of hoisting out will
// outweigh the benefits and it's better off to just always render it fresh.
if(node.static&&node.children.length&&!(
node.children.length===1&&
node.children[0].type===3))
{
node.staticRoot=true;
return;
}else {
node.staticRoot=false;
}
if(node.children){
for(var i=0,l=node.children.length;i<l;i++){
markStaticRoots(node.children[i],isInFor||!!node.for);
}
}
if(node.ifConditions){
for(var i$1=1,l$1=node.ifConditions.length;i$1<l$1;i$1++){
markStaticRoots(node.ifConditions[i$1].block,isInFor);
}
}
}
}

function isStatic(node){
if(node.type===2){// expression
return false;
}
if(node.type===3){// text
return true;
}
return !!(node.pre||
!node.hasBindings&&// no dynamic bindings
!node.if&&!node.for&&// not v-if or v-for or v-else
!isBuiltInTag(node.tag)&&// not a built-in
isPlatformReservedTag(node.tag)&&// not a component
!isDirectChildOfTemplateFor(node)&&
Object.keys(node).every(isStaticKey));

}

function isDirectChildOfTemplateFor(node){
while(node.parent){
node=node.parent;
if(node.tag!=='template'){
return false;
}
if(node.for){
return true;
}
}
return false;
}

/*  */

var fnExpRE=/^([\w$_]+|\([^)]*?\))\s*=>|^function(?:\s+[\w$]+)?\s*\(/;
var fnInvokeRE=/\([^)]*?\);*$/;
var simplePathRE=/^[A-Za-z_$][\w$]*(?:\.[A-Za-z_$][\w$]*|\['[^']*?']|\["[^"]*?"]|\[\d+]|\[[A-Za-z_$][\w$]*])*$/;

// KeyboardEvent.keyCode aliases
var keyCodes={
esc:27,
tab:9,
enter:13,
space:32,
up:38,
left:37,
right:39,
down:40,
'delete':[8,46]};


// KeyboardEvent.key aliases
var keyNames={
// #7880: IE11 and Edge use `Esc` for Escape key name.
esc:['Esc','Escape'],
tab:'Tab',
enter:'Enter',
// #9112: IE11 uses `Spacebar` for Space key name.
space:[' ','Spacebar'],
// #7806: IE11 uses key names without `Arrow` prefix for arrow keys.
up:['Up','ArrowUp'],
left:['Left','ArrowLeft'],
right:['Right','ArrowRight'],
down:['Down','ArrowDown'],
// #9112: IE11 uses `Del` for Delete key name.
'delete':['Backspace','Delete','Del']};


// #4868: modifiers that prevent the execution of the listener
// need to explicitly return null so that we can determine whether to remove
// the listener for .once
var genGuard=function genGuard(condition){return "if("+condition+")return null;";};

var modifierCode={
stop:'$event.stopPropagation();',
prevent:'$event.preventDefault();',
self:genGuard("$event.target !== $event.currentTarget"),
ctrl:genGuard("!$event.ctrlKey"),
shift:genGuard("!$event.shiftKey"),
alt:genGuard("!$event.altKey"),
meta:genGuard("!$event.metaKey"),
left:genGuard("'button' in $event && $event.button !== 0"),
middle:genGuard("'button' in $event && $event.button !== 1"),
right:genGuard("'button' in $event && $event.button !== 2")};


function genHandlers(
events,
isNative)
{
var prefix=isNative?'nativeOn:':'on:';
var staticHandlers="";
var dynamicHandlers="";
for(var name in events){
var handlerCode=genHandler(events[name]);
if(events[name]&&events[name].dynamic){
dynamicHandlers+=name+","+handlerCode+",";
}else {
staticHandlers+="\""+name+"\":"+handlerCode+",";
}
}
staticHandlers="{"+staticHandlers.slice(0,-1)+"}";
if(dynamicHandlers){
return prefix+"_d("+staticHandlers+",["+dynamicHandlers.slice(0,-1)+"])";
}else {
return prefix+staticHandlers;
}
}

function genHandler(handler){
if(!handler){
return 'function(){}';
}

if(Array.isArray(handler)){
return "["+handler.map(function(handler){return genHandler(handler);}).join(',')+"]";
}

var isMethodPath=simplePathRE.test(handler.value);
var isFunctionExpression=fnExpRE.test(handler.value);
var isFunctionInvocation=simplePathRE.test(handler.value.replace(fnInvokeRE,''));

if(!handler.modifiers){
if(isMethodPath||isFunctionExpression){
return handler.value;
}
return "function($event){"+(isFunctionInvocation?"return "+handler.value:handler.value)+"}";// inline statement
}else {
var code='';
var genModifierCode='';
var keys=[];
for(var key in handler.modifiers){
if(modifierCode[key]){
genModifierCode+=modifierCode[key];
// left/right
if(keyCodes[key]){
keys.push(key);
}
}else if(key==='exact'){
var modifiers=handler.modifiers;
genModifierCode+=genGuard(
['ctrl','shift','alt','meta'].
filter(function(keyModifier){return !modifiers[keyModifier];}).
map(function(keyModifier){return "$event."+keyModifier+"Key";}).
join('||'));

}else {
keys.push(key);
}
}
if(keys.length){
code+=genKeyFilter(keys);
}
// Make sure modifiers like prevent and stop get executed after key filtering
if(genModifierCode){
code+=genModifierCode;
}
var handlerCode=isMethodPath?
"return "+handler.value+"($event)":
isFunctionExpression?
"return ("+handler.value+")($event)":
isFunctionInvocation?
"return "+handler.value:
handler.value;
return "function($event){"+code+handlerCode+"}";
}
}

function genKeyFilter(keys){
return(
// make sure the key filters only apply to KeyboardEvents
// #9441: can't use 'keyCode' in $event because Chrome autofill fires fake
// key events that do not have keyCode property...
"if(!$event.type.indexOf('key')&&"+
keys.map(genFilterCode).join('&&')+")return null;");

}

function genFilterCode(key){
var keyVal=parseInt(key,10);
if(keyVal){
return "$event.keyCode!=="+keyVal;
}
var keyCode=keyCodes[key];
var keyName=keyNames[key];
return(
"_k($event.keyCode,"+
JSON.stringify(key)+","+
JSON.stringify(keyCode)+","+
"$event.key,"+
""+JSON.stringify(keyName)+
")");

}

/*  */

function on(el,dir){
if(dir.modifiers){
warn("v-on without argument does not support modifiers.");
}
el.wrapListeners=function(code){return "_g("+code+","+dir.value+")";};
}

/*  */

function bind$1(el,dir){
el.wrapData=function(code){
return "_b("+code+",'"+el.tag+"',"+dir.value+","+(dir.modifiers&&dir.modifiers.prop?'true':'false')+(dir.modifiers&&dir.modifiers.sync?',true':'')+")";
};
}

/*  */

var baseDirectives={
on:on,
bind:bind$1,
cloak:noop};


/*  */





var CodegenState=function CodegenState(options){
this.options=options;
this.warn=options.warn||baseWarn;
this.transforms=pluckModuleFunction(options.modules,'transformCode');
this.dataGenFns=pluckModuleFunction(options.modules,'genData');
this.directives=extend(extend({},baseDirectives),options.directives);
var isReservedTag=options.isReservedTag||no;
this.maybeComponent=function(el){return !!el.component||!isReservedTag(el.tag);};
this.onceId=0;
this.staticRenderFns=[];
this.pre=false;
};



function generate(
ast,
options)
{
var state=new CodegenState(options);
var code=ast?genElement(ast,state):'_c("div")';
return {
render:"with(this){return "+code+"}",
staticRenderFns:state.staticRenderFns};

}

function genElement(el,state){
if(el.parent){
el.pre=el.pre||el.parent.pre;
}

if(el.staticRoot&&!el.staticProcessed){
return genStatic(el,state);
}else if(el.once&&!el.onceProcessed){
return genOnce(el,state);
}else if(el.for&&!el.forProcessed){
return genFor(el,state);
}else if(el.if&&!el.ifProcessed){
return genIf(el,state);
}else if(el.tag==='template'&&!el.slotTarget&&!state.pre){
return genChildren(el,state)||'void 0';
}else if(el.tag==='slot'){
return genSlot(el,state);
}else {
// component or element
var code;
if(el.component){
code=genComponent(el.component,el,state);
}else {
var data;
if(!el.plain||el.pre&&state.maybeComponent(el)){
data=genData$2(el,state);
}

var children=el.inlineTemplate?null:genChildren(el,state,true);
code="_c('"+el.tag+"'"+(data?","+data:'')+(children?","+children:'')+")";
}
// module transforms
for(var i=0;i<state.transforms.length;i++){
code=state.transforms[i](el,code);
}
return code;
}
}

// hoist static sub-trees out
function genStatic(el,state){
el.staticProcessed=true;
// Some elements (templates) need to behave differently inside of a v-pre
// node.  All pre nodes are static roots, so we can use this as a location to
// wrap a state change and reset it upon exiting the pre node.
var originalPreState=state.pre;
if(el.pre){
state.pre=el.pre;
}
state.staticRenderFns.push("with(this){return "+genElement(el,state)+"}");
state.pre=originalPreState;
return "_m("+(state.staticRenderFns.length-1)+(el.staticInFor?',true':'')+")";
}

// v-once
function genOnce(el,state){
el.onceProcessed=true;
if(el.if&&!el.ifProcessed){
return genIf(el,state);
}else if(el.staticInFor){
var key='';
var parent=el.parent;
while(parent){
if(parent.for){
key=parent.key;
break;
}
parent=parent.parent;
}
if(!key){
state.warn(
"v-once can only be used inside v-for that is keyed. ",
el.rawAttrsMap['v-once']);

return genElement(el,state);
}
return "_o("+genElement(el,state)+","+state.onceId++ +","+key+")";
}else {
return genStatic(el,state);
}
}

function genIf(
el,
state,
altGen,
altEmpty)
{
el.ifProcessed=true;// avoid recursion
return genIfConditions(el.ifConditions.slice(),state,altGen,altEmpty);
}

function genIfConditions(
conditions,
state,
altGen,
altEmpty)
{
if(!conditions.length){
return altEmpty||'_e()';
}

var condition=conditions.shift();
if(condition.exp){
return "("+condition.exp+")?"+genTernaryExp(condition.block)+":"+genIfConditions(conditions,state,altGen,altEmpty);
}else {
return ""+genTernaryExp(condition.block);
}

// v-if with v-once should generate code like (a)?_m(0):_m(1)
function genTernaryExp(el){
return altGen?
altGen(el,state):
el.once?
genOnce(el,state):
genElement(el,state);
}
}

function genFor(
el,
state,
altGen,
altHelper)
{
var exp=el.for;
var alias=el.alias;
var iterator1=el.iterator1?","+el.iterator1:'';
var iterator2=el.iterator2?","+el.iterator2:'';

if(state.maybeComponent(el)&&
el.tag!=='slot'&&
el.tag!=='template'&&
!el.key)
{
state.warn(
"<"+el.tag+" v-for=\""+alias+" in "+exp+"\">: component lists rendered with "+
"v-for should have explicit keys. "+
"See https://vuejs.org/guide/list.html#key for more info.",
el.rawAttrsMap['v-for'],
true/* tip */);

}

el.forProcessed=true;// avoid recursion
return (altHelper||'_l')+"(("+exp+"),"+
"function("+alias+iterator1+iterator2+"){"+
"return "+(altGen||genElement)(el,state)+
'})';
}

function genData$2(el,state){
var data='{';

// directives first.
// directives may mutate the el's other properties before they are generated.
var dirs=genDirectives(el,state);
if(dirs){data+=dirs+',';}

// key
if(el.key){
data+="key:"+el.key+",";
}
// ref
if(el.ref){
data+="ref:"+el.ref+",";
}
if(el.refInFor){
data+="refInFor:true,";
}
// pre
if(el.pre){
data+="pre:true,";
}
// record original tag name for components using "is" attribute
if(el.component){
data+="tag:\""+el.tag+"\",";
}
// module data generation functions
for(var i=0;i<state.dataGenFns.length;i++){
data+=state.dataGenFns[i](el);
}
// attributes
if(el.attrs){
data+="attrs:"+genProps(el.attrs)+",";
}
// DOM props
if(el.props){
data+="domProps:"+genProps(el.props)+",";
}
// event handlers
if(el.events){
data+=genHandlers(el.events,false)+",";
}
if(el.nativeEvents){
data+=genHandlers(el.nativeEvents,true)+",";
}
// slot target
// only for non-scoped slots
if(el.slotTarget&&!el.slotScope){
data+="slot:"+el.slotTarget+",";
}
// scoped slots
if(el.scopedSlots){
data+=genScopedSlots(el,el.scopedSlots,state)+",";
}
// component v-model
if(el.model){
data+="model:{value:"+el.model.value+",callback:"+el.model.callback+",expression:"+el.model.expression+"},";
}
// inline-template
if(el.inlineTemplate){
var inlineTemplate=genInlineTemplate(el,state);
if(inlineTemplate){
data+=inlineTemplate+",";
}
}
data=data.replace(/,$/,'')+'}';
// v-bind dynamic argument wrap
// v-bind with dynamic arguments must be applied using the same v-bind object
// merge helper so that class/style/mustUseProp attrs are handled correctly.
if(el.dynamicAttrs){
data="_b("+data+",\""+el.tag+"\","+genProps(el.dynamicAttrs)+")";
}
// v-bind data wrap
if(el.wrapData){
data=el.wrapData(data);
}
// v-on data wrap
if(el.wrapListeners){
data=el.wrapListeners(data);
}
return data;
}

function genDirectives(el,state){
var dirs=el.directives;
if(!dirs){return;}
var res='directives:[';
var hasRuntime=false;
var i,l,dir,needRuntime;
for(i=0,l=dirs.length;i<l;i++){
dir=dirs[i];
needRuntime=true;
var gen=state.directives[dir.name];
if(gen){
// compile-time directive that manipulates AST.
// returns true if it also needs a runtime counterpart.
needRuntime=!!gen(el,dir,state.warn);
}
if(needRuntime){
hasRuntime=true;
res+="{name:\""+dir.name+"\",rawName:\""+dir.rawName+"\""+(dir.value?",value:("+dir.value+"),expression:"+JSON.stringify(dir.value):'')+(dir.arg?",arg:"+(dir.isDynamicArg?dir.arg:"\""+dir.arg+"\""):'')+(dir.modifiers?",modifiers:"+JSON.stringify(dir.modifiers):'')+"},";
}
}
if(hasRuntime){
return res.slice(0,-1)+']';
}
}

function genInlineTemplate(el,state){
var ast=el.children[0];
if(el.children.length!==1||ast.type!==1){
state.warn(
'Inline-template components must have exactly one child element.',
{start:el.start});

}
if(ast&&ast.type===1){
var inlineRenderFns=generate(ast,state.options);
return "inlineTemplate:{render:function(){"+inlineRenderFns.render+"},staticRenderFns:["+inlineRenderFns.staticRenderFns.map(function(code){return "function(){"+code+"}";}).join(',')+"]}";
}
}

function genScopedSlots(
el,
slots,
state)
{
// by default scoped slots are considered "stable", this allows child
// components with only scoped slots to skip forced updates from parent.
// but in some cases we have to bail-out of this optimization
// for example if the slot contains dynamic names, has v-if or v-for on them...
var needsForceUpdate=el.for||Object.keys(slots).some(function(key){
var slot=slots[key];
return(
slot.slotTargetDynamic||
slot.if||
slot.for||
containsSlotChild(slot)// is passing down slot from parent which may be dynamic
);
});

// #9534: if a component with scoped slots is inside a conditional branch,
// it's possible for the same component to be reused but with different
// compiled slot content. To avoid that, we generate a unique key based on
// the generated code of all the slot contents.
var needsKey=!!el.if;

// OR when it is inside another scoped slot or v-for (the reactivity may be
// disconnected due to the intermediate scope variable)
// #9438, #9506
// TODO: this can be further optimized by properly analyzing in-scope bindings
// and skip force updating ones that do not actually use scope variables.
if(!needsForceUpdate){
var parent=el.parent;
while(parent){
if(
parent.slotScope&&parent.slotScope!==emptySlotScopeToken||
parent.for)
{
needsForceUpdate=true;
break;
}
if(parent.if){
needsKey=true;
}
parent=parent.parent;
}
}

var generatedSlots=Object.keys(slots).
map(function(key){return genScopedSlot(slots[key],state);}).
join(',');

return "scopedSlots:_u(["+generatedSlots+"]"+(needsForceUpdate?",null,true":"")+(!needsForceUpdate&&needsKey?",null,false,"+hash(generatedSlots):"")+")";
}

function hash(str){
var hash=5381;
var i=str.length;
while(i){
hash=hash*33^str.charCodeAt(--i);
}
return hash>>>0;
}

function containsSlotChild(el){
if(el.type===1){
if(el.tag==='slot'){
return true;
}
return el.children.some(containsSlotChild);
}
return false;
}

function genScopedSlot(
el,
state)
{
var isLegacySyntax=el.attrsMap['slot-scope'];
if(el.if&&!el.ifProcessed&&!isLegacySyntax){
return genIf(el,state,genScopedSlot,"null");
}
if(el.for&&!el.forProcessed){
return genFor(el,state,genScopedSlot);
}
var slotScope=el.slotScope===emptySlotScopeToken?
"":
String(el.slotScope);
var fn="function("+slotScope+"){"+
"return "+(el.tag==='template'?
el.if&&isLegacySyntax?
"("+el.if+")?"+(genChildren(el,state)||'undefined')+":undefined":
genChildren(el,state)||'undefined':
genElement(el,state))+"}";
// reverse proxy v-slot without scope on this.$slots
var reverseProxy=slotScope?"":",proxy:true";
return "{key:"+(el.slotTarget||"\"default\"")+",fn:"+fn+reverseProxy+"}";
}

function genChildren(
el,
state,
checkSkip,
altGenElement,
altGenNode)
{
var children=el.children;
if(children.length){
var el$1=children[0];
// optimize single v-for
if(children.length===1&&
el$1.for&&
el$1.tag!=='template'&&
el$1.tag!=='slot')
{
var normalizationType=checkSkip?
state.maybeComponent(el$1)?",1":",0":
"";
return ""+(altGenElement||genElement)(el$1,state)+normalizationType;
}
var normalizationType$1=checkSkip?
getNormalizationType(children,state.maybeComponent):
0;
var gen=altGenNode||genNode;
return "["+children.map(function(c){return gen(c,state);}).join(',')+"]"+(normalizationType$1?","+normalizationType$1:'');
}
}

// determine the normalization needed for the children array.
// 0: no normalization needed
// 1: simple normalization needed (possible 1-level deep nested array)
// 2: full normalization needed
function getNormalizationType(
children,
maybeComponent)
{
var res=0;
for(var i=0;i<children.length;i++){
var el=children[i];
if(el.type!==1){
continue;
}
if(needsNormalization(el)||
el.ifConditions&&el.ifConditions.some(function(c){return needsNormalization(c.block);})){
res=2;
break;
}
if(maybeComponent(el)||
el.ifConditions&&el.ifConditions.some(function(c){return maybeComponent(c.block);})){
res=1;
}
}
return res;
}

function needsNormalization(el){
return el.for!==undefined||el.tag==='template'||el.tag==='slot';
}

function genNode(node,state){
if(node.type===1){
return genElement(node,state);
}else if(node.type===3&&node.isComment){
return genComment(node);
}else {
return genText(node);
}
}

function genText(text){
return "_v("+(text.type===2?
text.expression// no need for () because already wrapped in _s()
:transformSpecialNewlines(JSON.stringify(text.text)))+")";
}

function genComment(comment){
return "_e("+JSON.stringify(comment.text)+")";
}

function genSlot(el,state){
var slotName=el.slotName||'"default"';
var children=genChildren(el,state);
var res="_t("+slotName+(children?","+children:'');
var attrs=el.attrs||el.dynamicAttrs?
genProps((el.attrs||[]).concat(el.dynamicAttrs||[]).map(function(attr){return {
// slot props are camelized
name:camelize(attr.name),
value:attr.value,
dynamic:attr.dynamic};
})):
null;
var bind$$1=el.attrsMap['v-bind'];
if((attrs||bind$$1)&&!children){
res+=",null";
}
if(attrs){
res+=","+attrs;
}
if(bind$$1){
res+=(attrs?'':',null')+","+bind$$1;
}
return res+')';
}

// componentName is el.component, take it as argument to shun flow's pessimistic refinement
function genComponent(
componentName,
el,
state)
{
var children=el.inlineTemplate?null:genChildren(el,state,true);
return "_c("+componentName+","+genData$2(el,state)+(children?","+children:'')+")";
}

function genProps(props){
var staticProps="";
var dynamicProps="";
for(var i=0;i<props.length;i++){
var prop=props[i];
var value=transformSpecialNewlines(prop.value);
if(prop.dynamic){
dynamicProps+=prop.name+","+value+",";
}else {
staticProps+="\""+prop.name+"\":"+value+",";
}
}
staticProps="{"+staticProps.slice(0,-1)+"}";
if(dynamicProps){
return "_d("+staticProps+",["+dynamicProps.slice(0,-1)+"])";
}else {
return staticProps;
}
}

// #3895, #4268
function transformSpecialNewlines(text){
return text.
replace(/\u2028/g,"\\u2028").
replace(/\u2029/g,"\\u2029");
}

/*  */



// these keywords should not appear inside expressions, but operators like
// typeof, instanceof and in are allowed
var prohibitedKeywordRE=new RegExp('\\b'+(
'do,if,for,let,new,try,var,case,else,with,await,break,catch,class,const,'+
'super,throw,while,yield,delete,export,import,return,switch,default,'+
'extends,finally,continue,debugger,function,arguments').
split(',').join('\\b|\\b')+'\\b');

// these unary operators should not be used as property/method names
var unaryOperatorsRE=new RegExp('\\b'+
'delete,typeof,void'.
split(',').join('\\s*\\([^\\)]*\\)|\\b')+'\\s*\\([^\\)]*\\)');

// strip strings in expressions
var stripStringRE=/'(?:[^'\\]|\\.)*'|"(?:[^"\\]|\\.)*"|`(?:[^`\\]|\\.)*\$\{|\}(?:[^`\\]|\\.)*`|`(?:[^`\\]|\\.)*`/g;

// detect problematic expressions in a template
function detectErrors(ast,warn){
if(ast){
checkNode(ast,warn);
}
}

function checkNode(node,warn){
if(node.type===1){
for(var name in node.attrsMap){
if(dirRE.test(name)){
var value=node.attrsMap[name];
if(value){
var range=node.rawAttrsMap[name];
if(name==='v-for'){
checkFor(node,"v-for=\""+value+"\"",warn,range);
}else if(name==='v-slot'||name[0]==='#'){
checkFunctionParameterExpression(value,name+"=\""+value+"\"",warn,range);
}else if(onRE.test(name)){
checkEvent(value,name+"=\""+value+"\"",warn,range);
}else {
checkExpression(value,name+"=\""+value+"\"",warn,range);
}
}
}
}
if(node.children){
for(var i=0;i<node.children.length;i++){
checkNode(node.children[i],warn);
}
}
}else if(node.type===2){
checkExpression(node.expression,node.text,warn,node);
}
}

function checkEvent(exp,text,warn,range){
var stripped=exp.replace(stripStringRE,'');
var keywordMatch=stripped.match(unaryOperatorsRE);
if(keywordMatch&&stripped.charAt(keywordMatch.index-1)!=='$'){
warn(
"avoid using JavaScript unary operator as property name: "+
"\""+keywordMatch[0]+"\" in expression "+text.trim(),
range);

}
checkExpression(exp,text,warn,range);
}

function checkFor(node,text,warn,range){
checkExpression(node.for||'',text,warn,range);
checkIdentifier(node.alias,'v-for alias',text,warn,range);
checkIdentifier(node.iterator1,'v-for iterator',text,warn,range);
checkIdentifier(node.iterator2,'v-for iterator',text,warn,range);
}

function checkIdentifier(
ident,
type,
text,
warn,
range)
{
if(typeof ident==='string'){
try{
new Function("var "+ident+"=_");
}catch(e){
warn("invalid "+type+" \""+ident+"\" in expression: "+text.trim(),range);
}
}
}

function checkExpression(exp,text,warn,range){
try{
new Function("return "+exp);
}catch(e){
var keywordMatch=exp.replace(stripStringRE,'').match(prohibitedKeywordRE);
if(keywordMatch){
warn(
"avoid using JavaScript keyword as property name: "+
"\""+keywordMatch[0]+"\"\n  Raw expression: "+text.trim(),
range);

}else {
warn(
"invalid expression: "+e.message+" in\n\n"+
"    "+exp+"\n\n"+
"  Raw expression: "+text.trim()+"\n",
range);

}
}
}

function checkFunctionParameterExpression(exp,text,warn,range){
try{
new Function(exp,'');
}catch(e){
warn(
"invalid function parameter expression: "+e.message+" in\n\n"+
"    "+exp+"\n\n"+
"  Raw expression: "+text.trim()+"\n",
range);

}
}

/*  */

var range=2;

function generateCodeFrame(
source,
start,
end)
{
if(start===void 0)start=0;
if(end===void 0)end=source.length;

var lines=source.split(/\r?\n/);
var count=0;
var res=[];
for(var i=0;i<lines.length;i++){
count+=lines[i].length+1;
if(count>=start){
for(var j=i-range;j<=i+range||end>count;j++){
if(j<0||j>=lines.length){continue;}
res.push(""+(j+1)+repeat$1(" ",3-String(j+1).length)+"|  "+lines[j]);
var lineLength=lines[j].length;
if(j===i){
// push underline
var pad=start-(count-lineLength)+1;
var length=end>count?lineLength-pad:end-start;
res.push("   |  "+repeat$1(" ",pad)+repeat$1("^",length));
}else if(j>i){
if(end>count){
var length$1=Math.min(end-count,lineLength);
res.push("   |  "+repeat$1("^",length$1));
}
count+=lineLength+1;
}
}
break;
}
}
return res.join('\n');
}

function repeat$1(str,n){
var result='';
if(n>0){
while(true){// eslint-disable-line
if(n&1){result+=str;}
n>>>=1;
if(n<=0){break;}
str+=str;
}
}
return result;
}

/*  */



function createFunction(code,errors){
try{
return new Function(code);
}catch(err){
errors.push({err:err,code:code});
return noop;
}
}

function createCompileToFunctionFn(compile){
var cache=Object.create(null);

return function compileToFunctions(
template,
options,
vm)
{
options=extend({},options);
var warn$$1=options.warn||warn;
delete options.warn;

/* istanbul ignore if */
{
// detect possible CSP restriction
try{
new Function('return 1');
}catch(e){
if(e.toString().match(/unsafe-eval|CSP/)){
warn$$1(
'It seems you are using the standalone build of Vue.js in an '+
'environment with Content Security Policy that prohibits unsafe-eval. '+
'The template compiler cannot work in this environment. Consider '+
'relaxing the policy to allow unsafe-eval or pre-compiling your '+
'templates into render functions.');

}
}
}

// check cache
var key=options.delimiters?
String(options.delimiters)+template:
template;
if(cache[key]){
return cache[key];
}

// compile
var compiled=compile(template,options);

// check compilation errors/tips
{
if(compiled.errors&&compiled.errors.length){
if(options.outputSourceRange){
compiled.errors.forEach(function(e){
warn$$1(
"Error compiling template:\n\n"+e.msg+"\n\n"+
generateCodeFrame(template,e.start,e.end),
vm);

});
}else {
warn$$1(
"Error compiling template:\n\n"+template+"\n\n"+
compiled.errors.map(function(e){return "- "+e;}).join('\n')+'\n',
vm);

}
}
if(compiled.tips&&compiled.tips.length){
if(options.outputSourceRange){
compiled.tips.forEach(function(e){return tip(e.msg,vm);});
}else {
compiled.tips.forEach(function(msg){return tip(msg,vm);});
}
}
}

// turn code into functions
var res={};
var fnGenErrors=[];
res.render=createFunction(compiled.render,fnGenErrors);
res.staticRenderFns=compiled.staticRenderFns.map(function(code){
return createFunction(code,fnGenErrors);
});

// check function generation errors.
// this should only happen if there is a bug in the compiler itself.
// mostly for codegen development use
/* istanbul ignore if */
{
if((!compiled.errors||!compiled.errors.length)&&fnGenErrors.length){
warn$$1(
"Failed to generate render function:\n\n"+
fnGenErrors.map(function(ref){
var err=ref.err;
var code=ref.code;

return err.toString()+" in\n\n"+code+"\n";
}).join('\n'),
vm);

}
}

return cache[key]=res;
};
}

/*  */

function createCompilerCreator(baseCompile){
return function createCompiler(baseOptions){
function compile(
template,
options)
{
var finalOptions=Object.create(baseOptions);
var errors=[];
var tips=[];

var warn=function warn(msg,range,tip){
(tip?tips:errors).push(msg);
};

if(options){
if(options.outputSourceRange){
// $flow-disable-line
var leadingSpaceLength=template.match(/^\s*/)[0].length;

warn=function warn(msg,range,tip){
var data={msg:msg};
if(range){
if(range.start!=null){
data.start=range.start+leadingSpaceLength;
}
if(range.end!=null){
data.end=range.end+leadingSpaceLength;
}
}
(tip?tips:errors).push(data);
};
}
// merge custom modules
if(options.modules){
finalOptions.modules=
(baseOptions.modules||[]).concat(options.modules);
}
// merge custom directives
if(options.directives){
finalOptions.directives=extend(
Object.create(baseOptions.directives||null),
options.directives);

}
// copy other options
for(var key in options){
if(key!=='modules'&&key!=='directives'){
finalOptions[key]=options[key];
}
}
}

finalOptions.warn=warn;

var compiled=baseCompile(template.trim(),finalOptions);
{
detectErrors(compiled.ast,warn);
}
compiled.errors=errors;
compiled.tips=tips;
return compiled;
}

return {
compile:compile,
compileToFunctions:createCompileToFunctionFn(compile)};

};
}

/*  */

// `createCompilerCreator` allows creating compilers that use alternative
// parser/optimizer/codegen, e.g the SSR optimizing compiler.
// Here we just export a default compiler using the default parts.
var createCompiler=createCompilerCreator(function baseCompile(
template,
options)
{
var ast=parse(template.trim(),options);
if(options.optimize!==false){
optimize(ast,options);
}
var code=generate(ast,options);
return {
ast:ast,
render:code.render,
staticRenderFns:code.staticRenderFns};

});

/*  */

var ref$1=createCompiler(baseOptions);
var compileToFunctions=ref$1.compileToFunctions;

/*  */

// check whether current browser encodes a char inside attribute values
var div;
function getShouldDecode(href){
div=div||document.createElement('div');
div.innerHTML=href?"<a href=\"\n\"/>":"<div a=\"\n\"/>";
return div.innerHTML.indexOf('&#10;')>0;
}

// #3663: IE encodes newlines inside attribute values while other browsers don't
var shouldDecodeNewlines=inBrowser?getShouldDecode(false):false;
// #6828: chrome encodes content in a[href]
var shouldDecodeNewlinesForHref=inBrowser?getShouldDecode(true):false;

/*  */

var idToTemplate=cached(function(id){
var el=query(id);
return el&&el.innerHTML;
});

var mount=Vue.prototype.$mount;
Vue.prototype.$mount=function(
el,
hydrating)
{
el=el&&query(el);

/* istanbul ignore if */
if(el===document.body||el===document.documentElement){
warn(
"Do not mount Vue to <html> or <body> - mount to normal elements instead.");

return this;
}

var options=this.$options;
// resolve template/el and convert to render function
if(!options.render){
var template=options.template;
if(template){
if(typeof template==='string'){
if(template.charAt(0)==='#'){
template=idToTemplate(template);
/* istanbul ignore if */
if(!template){
warn(
"Template element not found or is empty: "+options.template,
this);

}
}
}else if(template.nodeType){
template=template.innerHTML;
}else {
{
warn('invalid template option:'+template,this);
}
return this;
}
}else if(el){
template=getOuterHTML(el);
}
if(template){
/* istanbul ignore if */
if(config.performance&&mark){
mark('compile');
}

var ref=compileToFunctions(template,{
outputSourceRange:"development"!=='production',
shouldDecodeNewlines:shouldDecodeNewlines,
shouldDecodeNewlinesForHref:shouldDecodeNewlinesForHref,
delimiters:options.delimiters,
comments:options.comments},
this);
var render=ref.render;
var staticRenderFns=ref.staticRenderFns;
options.render=render;
options.staticRenderFns=staticRenderFns;

/* istanbul ignore if */
if(config.performance&&mark){
mark('compile end');
measure("vue "+this._name+" compile",'compile','compile end');
}
}
}
return mount.call(this,el,hydrating);
};

/**
 * Get outerHTML of elements, taking care
 * of SVG elements in IE as well.
 */
function getOuterHTML(el){
if(el.outerHTML){
return el.outerHTML;
}else {
var container=document.createElement('div');
container.appendChild(el.cloneNode(true));
return container.innerHTML;
}
}

Vue.compile=compileToFunctions;

module.exports=Vue;

/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"),__webpack_require__(/*! ./../../timers-browserify/main.js */"./node_modules/timers-browserify/main.js").setImmediate);

/***/},

/***/"./node_modules/vue/dist/vue.common.js":
/*!*********************************************!*\
  !*** ./node_modules/vue/dist/vue.common.js ***!
  \*********************************************/
/*! no static exports found */
/***/function node_modulesVueDistVueCommonJs(module,exports,__webpack_require__){

{
module.exports=__webpack_require__(/*! ./vue.common.dev.js */"./node_modules/vue/dist/vue.common.dev.js");
}


/***/},

/***/"./node_modules/vuex/dist/vuex.esm.js":
/*!********************************************!*\
  !*** ./node_modules/vuex/dist/vuex.esm.js ***!
  \********************************************/
/*! exports provided: default, Store, createLogger, createNamespacedHelpers, install, mapActions, mapGetters, mapMutations, mapState */
/***/function node_modulesVuexDistVuexEsmJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* WEBPACK VAR INJECTION */(function(global){/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"Store",function(){return Store;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"createLogger",function(){return createLogger;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"createNamespacedHelpers",function(){return createNamespacedHelpers;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"install",function(){return install;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"mapActions",function(){return mapActions;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"mapGetters",function(){return mapGetters;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"mapMutations",function(){return mapMutations;});
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"mapState",function(){return mapState;});
/*!
 * vuex v3.6.2
 * (c) 2021 Evan You
 * @license MIT
 */
function applyMixin(Vue){
var version=Number(Vue.version.split('.')[0]);

if(version>=2){
Vue.mixin({beforeCreate:vuexInit});
}else {
// override init and inject vuex init procedure
// for 1.x backwards compatibility.
var _init=Vue.prototype._init;
Vue.prototype._init=function(options){
if(options===void 0)options={};

options.init=options.init?
[vuexInit].concat(options.init):
vuexInit;
_init.call(this,options);
};
}

/**
   * Vuex init hook, injected into each instances init hooks list.
   */

function vuexInit(){
var options=this.$options;
// store injection
if(options.store){
this.$store=typeof options.store==='function'?
options.store():
options.store;
}else if(options.parent&&options.parent.$store){
this.$store=options.parent.$store;
}
}
}

var target=typeof window!=='undefined'?
window:
typeof global!=='undefined'?
global:
{};
var devtoolHook=target.__VUE_DEVTOOLS_GLOBAL_HOOK__;

function devtoolPlugin(store){
if(!devtoolHook){return;}

store._devtoolHook=devtoolHook;

devtoolHook.emit('vuex:init',store);

devtoolHook.on('vuex:travel-to-state',function(targetState){
store.replaceState(targetState);
});

store.subscribe(function(mutation,state){
devtoolHook.emit('vuex:mutation',mutation,state);
},{prepend:true});

store.subscribeAction(function(action,state){
devtoolHook.emit('vuex:action',action,state);
},{prepend:true});
}

/**
 * Get the first item that pass the test
 * by second argument function
 *
 * @param {Array} list
 * @param {Function} f
 * @return {*}
 */
function find(list,f){
return list.filter(f)[0];
}

/**
 * Deep copy the given object considering circular structure.
 * This function caches all nested objects and its copies.
 * If it detects circular structure, use cached copy to avoid infinite loop.
 *
 * @param {*} obj
 * @param {Array<Object>} cache
 * @return {*}
 */
function deepCopy(obj,cache){
if(cache===void 0)cache=[];

// just return if obj is immutable value
if(obj===null||typeof obj!=='object'){
return obj;
}

// if obj is hit, it is in circular structure
var hit=find(cache,function(c){return c.original===obj;});
if(hit){
return hit.copy;
}

var copy=Array.isArray(obj)?[]:{};
// put the copy into cache at first
// because we want to refer it in recursive deepCopy
cache.push({
original:obj,
copy:copy});


Object.keys(obj).forEach(function(key){
copy[key]=deepCopy(obj[key],cache);
});

return copy;
}

/**
 * forEach for object
 */
function forEachValue(obj,fn){
Object.keys(obj).forEach(function(key){return fn(obj[key],key);});
}

function isObject(obj){
return obj!==null&&typeof obj==='object';
}

function isPromise(val){
return val&&typeof val.then==='function';
}

function assert(condition,msg){
if(!condition){throw new Error("[vuex] "+msg);}
}

function partial(fn,arg){
return function(){
return fn(arg);
};
}

// Base data struct for store's module, package with some attribute and method
var Module=function Module(rawModule,runtime){
this.runtime=runtime;
// Store some children item
this._children=Object.create(null);
// Store the origin module object which passed by programmer
this._rawModule=rawModule;
var rawState=rawModule.state;

// Store the origin module's state
this.state=(typeof rawState==='function'?rawState():rawState)||{};
};

var prototypeAccessors={namespaced:{configurable:true}};

prototypeAccessors.namespaced.get=function(){
return !!this._rawModule.namespaced;
};

Module.prototype.addChild=function addChild(key,module){
this._children[key]=module;
};

Module.prototype.removeChild=function removeChild(key){
delete this._children[key];
};

Module.prototype.getChild=function getChild(key){
return this._children[key];
};

Module.prototype.hasChild=function hasChild(key){
return key in this._children;
};

Module.prototype.update=function update(rawModule){
this._rawModule.namespaced=rawModule.namespaced;
if(rawModule.actions){
this._rawModule.actions=rawModule.actions;
}
if(rawModule.mutations){
this._rawModule.mutations=rawModule.mutations;
}
if(rawModule.getters){
this._rawModule.getters=rawModule.getters;
}
};

Module.prototype.forEachChild=function forEachChild(fn){
forEachValue(this._children,fn);
};

Module.prototype.forEachGetter=function forEachGetter(fn){
if(this._rawModule.getters){
forEachValue(this._rawModule.getters,fn);
}
};

Module.prototype.forEachAction=function forEachAction(fn){
if(this._rawModule.actions){
forEachValue(this._rawModule.actions,fn);
}
};

Module.prototype.forEachMutation=function forEachMutation(fn){
if(this._rawModule.mutations){
forEachValue(this._rawModule.mutations,fn);
}
};

Object.defineProperties(Module.prototype,prototypeAccessors);

var ModuleCollection=function ModuleCollection(rawRootModule){
// register root module (Vuex.Store options)
this.register([],rawRootModule,false);
};

ModuleCollection.prototype.get=function get(path){
return path.reduce(function(module,key){
return module.getChild(key);
},this.root);
};

ModuleCollection.prototype.getNamespace=function getNamespace(path){
var module=this.root;
return path.reduce(function(namespace,key){
module=module.getChild(key);
return namespace+(module.namespaced?key+'/':'');
},'');
};

ModuleCollection.prototype.update=function update$1(rawRootModule){
update([],this.root,rawRootModule);
};

ModuleCollection.prototype.register=function register(path,rawModule,runtime){
var this$1=this;
if(runtime===void 0)runtime=true;

{
assertRawModule(path,rawModule);
}

var newModule=new Module(rawModule,runtime);
if(path.length===0){
this.root=newModule;
}else {
var parent=this.get(path.slice(0,-1));
parent.addChild(path[path.length-1],newModule);
}

// register nested modules
if(rawModule.modules){
forEachValue(rawModule.modules,function(rawChildModule,key){
this$1.register(path.concat(key),rawChildModule,runtime);
});
}
};

ModuleCollection.prototype.unregister=function unregister(path){
var parent=this.get(path.slice(0,-1));
var key=path[path.length-1];
var child=parent.getChild(key);

if(!child){
{
console.warn(
"[vuex] trying to unregister module '"+key+"', which is "+
"not registered");

}
return;
}

if(!child.runtime){
return;
}

parent.removeChild(key);
};

ModuleCollection.prototype.isRegistered=function isRegistered(path){
var parent=this.get(path.slice(0,-1));
var key=path[path.length-1];

if(parent){
return parent.hasChild(key);
}

return false;
};

function update(path,targetModule,newModule){
{
assertRawModule(path,newModule);
}

// update target module
targetModule.update(newModule);

// update nested modules
if(newModule.modules){
for(var key in newModule.modules){
if(!targetModule.getChild(key)){
{
console.warn(
"[vuex] trying to add a new module '"+key+"' on hot reloading, "+
'manual reload is needed');

}
return;
}
update(
path.concat(key),
targetModule.getChild(key),
newModule.modules[key]);

}
}
}

var functionAssert={
assert:function assert(value){return typeof value==='function';},
expected:'function'};


var objectAssert={
assert:function assert(value){return typeof value==='function'||
typeof value==='object'&&typeof value.handler==='function';},
expected:'function or object with "handler" function'};


var assertTypes={
getters:functionAssert,
mutations:functionAssert,
actions:objectAssert};


function assertRawModule(path,rawModule){
Object.keys(assertTypes).forEach(function(key){
if(!rawModule[key]){return;}

var assertOptions=assertTypes[key];

forEachValue(rawModule[key],function(value,type){
assert(
assertOptions.assert(value),
makeAssertionMessage(path,key,type,value,assertOptions.expected));

});
});
}

function makeAssertionMessage(path,key,type,value,expected){
var buf=key+" should be "+expected+" but \""+key+"."+type+"\"";
if(path.length>0){
buf+=" in module \""+path.join('.')+"\"";
}
buf+=" is "+JSON.stringify(value)+".";
return buf;
}

var Vue;// bind on install

var Store=function Store(options){
var this$1=this;
if(options===void 0)options={};

// Auto install if it is not done yet and `window` has `Vue`.
// To allow users to avoid auto-installation in some cases,
// this code should be placed here. See #731
if(!Vue&&typeof window!=='undefined'&&window.Vue){
install(window.Vue);
}

{
assert(Vue,"must call Vue.use(Vuex) before creating a store instance.");
assert(typeof Promise!=='undefined',"vuex requires a Promise polyfill in this browser.");
assert(this instanceof Store,"store must be called with the new operator.");
}

var plugins=options.plugins;if(plugins===void 0)plugins=[];
var strict=options.strict;if(strict===void 0)strict=false;

// store internal state
this._committing=false;
this._actions=Object.create(null);
this._actionSubscribers=[];
this._mutations=Object.create(null);
this._wrappedGetters=Object.create(null);
this._modules=new ModuleCollection(options);
this._modulesNamespaceMap=Object.create(null);
this._subscribers=[];
this._watcherVM=new Vue();
this._makeLocalGettersCache=Object.create(null);

// bind commit and dispatch to self
var store=this;
var ref=this;
var dispatch=ref.dispatch;
var commit=ref.commit;
this.dispatch=function boundDispatch(type,payload){
return dispatch.call(store,type,payload);
};
this.commit=function boundCommit(type,payload,options){
return commit.call(store,type,payload,options);
};

// strict mode
this.strict=strict;

var state=this._modules.root.state;

// init root module.
// this also recursively registers all sub-modules
// and collects all module getters inside this._wrappedGetters
installModule(this,state,[],this._modules.root);

// initialize the store vm, which is responsible for the reactivity
// (also registers _wrappedGetters as computed properties)
resetStoreVM(this,state);

// apply plugins
plugins.forEach(function(plugin){return plugin(this$1);});

var useDevtools=options.devtools!==undefined?options.devtools:Vue.config.devtools;
if(useDevtools){
devtoolPlugin(this);
}
};

var prototypeAccessors$1={state:{configurable:true}};

prototypeAccessors$1.state.get=function(){
return this._vm._data.$$state;
};

prototypeAccessors$1.state.set=function(v){
{
assert(false,"use store.replaceState() to explicit replace store state.");
}
};

Store.prototype.commit=function commit(_type,_payload,_options){
var this$1=this;

// check object-style commit
var ref=unifyObjectStyle(_type,_payload,_options);
var type=ref.type;
var payload=ref.payload;
var options=ref.options;

var mutation={type:type,payload:payload};
var entry=this._mutations[type];
if(!entry){
{
console.error("[vuex] unknown mutation type: "+type);
}
return;
}
this._withCommit(function(){
entry.forEach(function commitIterator(handler){
handler(payload);
});
});

this._subscribers.
slice()// shallow copy to prevent iterator invalidation if subscriber synchronously calls unsubscribe
.forEach(function(sub){return sub(mutation,this$1.state);});

if(

options&&options.silent)
{
console.warn(
"[vuex] mutation type: "+type+". Silent option has been removed. "+
'Use the filter functionality in the vue-devtools');

}
};

Store.prototype.dispatch=function dispatch(_type,_payload){
var this$1=this;

// check object-style dispatch
var ref=unifyObjectStyle(_type,_payload);
var type=ref.type;
var payload=ref.payload;

var action={type:type,payload:payload};
var entry=this._actions[type];
if(!entry){
{
console.error("[vuex] unknown action type: "+type);
}
return;
}

try{
this._actionSubscribers.
slice()// shallow copy to prevent iterator invalidation if subscriber synchronously calls unsubscribe
.filter(function(sub){return sub.before;}).
forEach(function(sub){return sub.before(action,this$1.state);});
}catch(e){
{
console.warn("[vuex] error in before action subscribers: ");
console.error(e);
}
}

var result=entry.length>1?
Promise.all(entry.map(function(handler){return handler(payload);})):
entry[0](payload);

return new Promise(function(resolve,reject){
result.then(function(res){
try{
this$1._actionSubscribers.
filter(function(sub){return sub.after;}).
forEach(function(sub){return sub.after(action,this$1.state);});
}catch(e){
{
console.warn("[vuex] error in after action subscribers: ");
console.error(e);
}
}
resolve(res);
},function(error){
try{
this$1._actionSubscribers.
filter(function(sub){return sub.error;}).
forEach(function(sub){return sub.error(action,this$1.state,error);});
}catch(e){
{
console.warn("[vuex] error in error action subscribers: ");
console.error(e);
}
}
reject(error);
});
});
};

Store.prototype.subscribe=function subscribe(fn,options){
return genericSubscribe(fn,this._subscribers,options);
};

Store.prototype.subscribeAction=function subscribeAction(fn,options){
var subs=typeof fn==='function'?{before:fn}:fn;
return genericSubscribe(subs,this._actionSubscribers,options);
};

Store.prototype.watch=function watch(getter,cb,options){
var this$1=this;

{
assert(typeof getter==='function',"store.watch only accepts a function.");
}
return this._watcherVM.$watch(function(){return getter(this$1.state,this$1.getters);},cb,options);
};

Store.prototype.replaceState=function replaceState(state){
var this$1=this;

this._withCommit(function(){
this$1._vm._data.$$state=state;
});
};

Store.prototype.registerModule=function registerModule(path,rawModule,options){
if(options===void 0)options={};

if(typeof path==='string'){path=[path];}

{
assert(Array.isArray(path),"module path must be a string or an Array.");
assert(path.length>0,'cannot register the root module by using registerModule.');
}

this._modules.register(path,rawModule);
installModule(this,this.state,path,this._modules.get(path),options.preserveState);
// reset store to update getters...
resetStoreVM(this,this.state);
};

Store.prototype.unregisterModule=function unregisterModule(path){
var this$1=this;

if(typeof path==='string'){path=[path];}

{
assert(Array.isArray(path),"module path must be a string or an Array.");
}

this._modules.unregister(path);
this._withCommit(function(){
var parentState=getNestedState(this$1.state,path.slice(0,-1));
Vue.delete(parentState,path[path.length-1]);
});
resetStore(this);
};

Store.prototype.hasModule=function hasModule(path){
if(typeof path==='string'){path=[path];}

{
assert(Array.isArray(path),"module path must be a string or an Array.");
}

return this._modules.isRegistered(path);
};

Store.prototype.hotUpdate=function hotUpdate(newOptions){
this._modules.update(newOptions);
resetStore(this,true);
};

Store.prototype._withCommit=function _withCommit(fn){
var committing=this._committing;
this._committing=true;
fn();
this._committing=committing;
};

Object.defineProperties(Store.prototype,prototypeAccessors$1);

function genericSubscribe(fn,subs,options){
if(subs.indexOf(fn)<0){
options&&options.prepend?
subs.unshift(fn):
subs.push(fn);
}
return function(){
var i=subs.indexOf(fn);
if(i>-1){
subs.splice(i,1);
}
};
}

function resetStore(store,hot){
store._actions=Object.create(null);
store._mutations=Object.create(null);
store._wrappedGetters=Object.create(null);
store._modulesNamespaceMap=Object.create(null);
var state=store.state;
// init all modules
installModule(store,state,[],store._modules.root,true);
// reset vm
resetStoreVM(store,state,hot);
}

function resetStoreVM(store,state,hot){
var oldVm=store._vm;

// bind store public getters
store.getters={};
// reset local getters cache
store._makeLocalGettersCache=Object.create(null);
var wrappedGetters=store._wrappedGetters;
var computed={};
forEachValue(wrappedGetters,function(fn,key){
// use computed to leverage its lazy-caching mechanism
// direct inline function use will lead to closure preserving oldVm.
// using partial to return function with only arguments preserved in closure environment.
computed[key]=partial(fn,store);
Object.defineProperty(store.getters,key,{
get:function get(){return store._vm[key];},
enumerable:true// for local getters
});
});

// use a Vue instance to store the state tree
// suppress warnings just in case the user has added
// some funky global mixins
var silent=Vue.config.silent;
Vue.config.silent=true;
store._vm=new Vue({
data:{
$$state:state},

computed:computed});

Vue.config.silent=silent;

// enable strict mode for new vm
if(store.strict){
enableStrictMode(store);
}

if(oldVm){
if(hot){
// dispatch changes in all subscribed watchers
// to force getter re-evaluation for hot reloading.
store._withCommit(function(){
oldVm._data.$$state=null;
});
}
Vue.nextTick(function(){return oldVm.$destroy();});
}
}

function installModule(store,rootState,path,module,hot){
var isRoot=!path.length;
var namespace=store._modules.getNamespace(path);

// register in namespace map
if(module.namespaced){
if(store._modulesNamespaceMap[namespace]&&"development"!=='production'){
console.error("[vuex] duplicate namespace "+namespace+" for the namespaced module "+path.join('/'));
}
store._modulesNamespaceMap[namespace]=module;
}

// set state
if(!isRoot&&!hot){
var parentState=getNestedState(rootState,path.slice(0,-1));
var moduleName=path[path.length-1];
store._withCommit(function(){
{
if(moduleName in parentState){
console.warn(
"[vuex] state field \""+moduleName+"\" was overridden by a module with the same name at \""+path.join('.')+"\"");

}
}
Vue.set(parentState,moduleName,module.state);
});
}

var local=module.context=makeLocalContext(store,namespace,path);

module.forEachMutation(function(mutation,key){
var namespacedType=namespace+key;
registerMutation(store,namespacedType,mutation,local);
});

module.forEachAction(function(action,key){
var type=action.root?key:namespace+key;
var handler=action.handler||action;
registerAction(store,type,handler,local);
});

module.forEachGetter(function(getter,key){
var namespacedType=namespace+key;
registerGetter(store,namespacedType,getter,local);
});

module.forEachChild(function(child,key){
installModule(store,rootState,path.concat(key),child,hot);
});
}

/**
 * make localized dispatch, commit, getters and state
 * if there is no namespace, just use root ones
 */
function makeLocalContext(store,namespace,path){
var noNamespace=namespace==='';

var local={
dispatch:noNamespace?store.dispatch:function(_type,_payload,_options){
var args=unifyObjectStyle(_type,_payload,_options);
var payload=args.payload;
var options=args.options;
var type=args.type;

if(!options||!options.root){
type=namespace+type;
if(!store._actions[type]){
console.error("[vuex] unknown local action type: "+args.type+", global type: "+type);
return;
}
}

return store.dispatch(type,payload);
},

commit:noNamespace?store.commit:function(_type,_payload,_options){
var args=unifyObjectStyle(_type,_payload,_options);
var payload=args.payload;
var options=args.options;
var type=args.type;

if(!options||!options.root){
type=namespace+type;
if(!store._mutations[type]){
console.error("[vuex] unknown local mutation type: "+args.type+", global type: "+type);
return;
}
}

store.commit(type,payload,options);
}};


// getters and state object must be gotten lazily
// because they will be changed by vm update
Object.defineProperties(local,{
getters:{
get:noNamespace?
function(){return store.getters;}:
function(){return makeLocalGetters(store,namespace);}},

state:{
get:function get(){return getNestedState(store.state,path);}}});



return local;
}

function makeLocalGetters(store,namespace){
if(!store._makeLocalGettersCache[namespace]){
var gettersProxy={};
var splitPos=namespace.length;
Object.keys(store.getters).forEach(function(type){
// skip if the target getter is not match this namespace
if(type.slice(0,splitPos)!==namespace){return;}

// extract local getter type
var localType=type.slice(splitPos);

// Add a port to the getters proxy.
// Define as getter property because
// we do not want to evaluate the getters in this time.
Object.defineProperty(gettersProxy,localType,{
get:function get(){return store.getters[type];},
enumerable:true});

});
store._makeLocalGettersCache[namespace]=gettersProxy;
}

return store._makeLocalGettersCache[namespace];
}

function registerMutation(store,type,handler,local){
var entry=store._mutations[type]||(store._mutations[type]=[]);
entry.push(function wrappedMutationHandler(payload){
handler.call(store,local.state,payload);
});
}

function registerAction(store,type,handler,local){
var entry=store._actions[type]||(store._actions[type]=[]);
entry.push(function wrappedActionHandler(payload){
var res=handler.call(store,{
dispatch:local.dispatch,
commit:local.commit,
getters:local.getters,
state:local.state,
rootGetters:store.getters,
rootState:store.state},
payload);
if(!isPromise(res)){
res=Promise.resolve(res);
}
if(store._devtoolHook){
return res.catch(function(err){
store._devtoolHook.emit('vuex:error',err);
throw err;
});
}else {
return res;
}
});
}

function registerGetter(store,type,rawGetter,local){
if(store._wrappedGetters[type]){
{
console.error("[vuex] duplicate getter key: "+type);
}
return;
}
store._wrappedGetters[type]=function wrappedGetter(store){
return rawGetter(
local.state,// local state
local.getters,// local getters
store.state,// root state
store.getters// root getters
);
};
}

function enableStrictMode(store){
store._vm.$watch(function(){return this._data.$$state;},function(){
{
assert(store._committing,"do not mutate vuex store state outside mutation handlers.");
}
},{deep:true,sync:true});
}

function getNestedState(state,path){
return path.reduce(function(state,key){return state[key];},state);
}

function unifyObjectStyle(type,payload,options){
if(isObject(type)&&type.type){
options=payload;
payload=type;
type=type.type;
}

{
assert(typeof type==='string',"expects string as the type, but found "+typeof type+".");
}

return {type:type,payload:payload,options:options};
}

function install(_Vue){
if(Vue&&_Vue===Vue){
{
console.error(
'[vuex] already installed. Vue.use(Vuex) should be called only once.');

}
return;
}
Vue=_Vue;
applyMixin(Vue);
}

/**
 * Reduce the code which written in Vue.js for getting the state.
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} states # Object's item can be a function which accept state and getters for param, you can do something for state and getters in it.
 * @param {Object}
 */
var mapState=normalizeNamespace(function(namespace,states){
var res={};
if(!isValidMap(states)){
console.error('[vuex] mapState: mapper parameter must be either an Array or an Object');
}
normalizeMap(states).forEach(function(ref){
var key=ref.key;
var val=ref.val;

res[key]=function mappedState(){
var state=this.$store.state;
var getters=this.$store.getters;
if(namespace){
var module=getModuleByNamespace(this.$store,'mapState',namespace);
if(!module){
return;
}
state=module.context.state;
getters=module.context.getters;
}
return typeof val==='function'?
val.call(this,state,getters):
state[val];
};
// mark vuex getter for devtools
res[key].vuex=true;
});
return res;
});

/**
 * Reduce the code which written in Vue.js for committing the mutation
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} mutations # Object's item can be a function which accept `commit` function as the first param, it can accept another params. You can commit mutation and do any other things in this function. specially, You need to pass anthor params from the mapped function.
 * @return {Object}
 */
var mapMutations=normalizeNamespace(function(namespace,mutations){
var res={};
if(!isValidMap(mutations)){
console.error('[vuex] mapMutations: mapper parameter must be either an Array or an Object');
}
normalizeMap(mutations).forEach(function(ref){
var key=ref.key;
var val=ref.val;

res[key]=function mappedMutation(){
var args=[],len=arguments.length;
while(len--){args[len]=arguments[len];}

// Get the commit method from store
var commit=this.$store.commit;
if(namespace){
var module=getModuleByNamespace(this.$store,'mapMutations',namespace);
if(!module){
return;
}
commit=module.context.commit;
}
return typeof val==='function'?
val.apply(this,[commit].concat(args)):
commit.apply(this.$store,[val].concat(args));
};
});
return res;
});

/**
 * Reduce the code which written in Vue.js for getting the getters
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} getters
 * @return {Object}
 */
var mapGetters=normalizeNamespace(function(namespace,getters){
var res={};
if(!isValidMap(getters)){
console.error('[vuex] mapGetters: mapper parameter must be either an Array or an Object');
}
normalizeMap(getters).forEach(function(ref){
var key=ref.key;
var val=ref.val;

// The namespace has been mutated by normalizeNamespace
val=namespace+val;
res[key]=function mappedGetter(){
if(namespace&&!getModuleByNamespace(this.$store,'mapGetters',namespace)){
return;
}
if(!(val in this.$store.getters)){
console.error("[vuex] unknown getter: "+val);
return;
}
return this.$store.getters[val];
};
// mark vuex getter for devtools
res[key].vuex=true;
});
return res;
});

/**
 * Reduce the code which written in Vue.js for dispatch the action
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} actions # Object's item can be a function which accept `dispatch` function as the first param, it can accept anthor params. You can dispatch action and do any other things in this function. specially, You need to pass anthor params from the mapped function.
 * @return {Object}
 */
var mapActions=normalizeNamespace(function(namespace,actions){
var res={};
if(!isValidMap(actions)){
console.error('[vuex] mapActions: mapper parameter must be either an Array or an Object');
}
normalizeMap(actions).forEach(function(ref){
var key=ref.key;
var val=ref.val;

res[key]=function mappedAction(){
var args=[],len=arguments.length;
while(len--){args[len]=arguments[len];}

// get dispatch function from store
var dispatch=this.$store.dispatch;
if(namespace){
var module=getModuleByNamespace(this.$store,'mapActions',namespace);
if(!module){
return;
}
dispatch=module.context.dispatch;
}
return typeof val==='function'?
val.apply(this,[dispatch].concat(args)):
dispatch.apply(this.$store,[val].concat(args));
};
});
return res;
});

/**
 * Rebinding namespace param for mapXXX function in special scoped, and return them by simple object
 * @param {String} namespace
 * @return {Object}
 */
var createNamespacedHelpers=function createNamespacedHelpers(namespace){return {
mapState:mapState.bind(null,namespace),
mapGetters:mapGetters.bind(null,namespace),
mapMutations:mapMutations.bind(null,namespace),
mapActions:mapActions.bind(null,namespace)};
};

/**
 * Normalize the map
 * normalizeMap([1, 2, 3]) => [ { key: 1, val: 1 }, { key: 2, val: 2 }, { key: 3, val: 3 } ]
 * normalizeMap({a: 1, b: 2, c: 3}) => [ { key: 'a', val: 1 }, { key: 'b', val: 2 }, { key: 'c', val: 3 } ]
 * @param {Array|Object} map
 * @return {Object}
 */
function normalizeMap(map){
if(!isValidMap(map)){
return [];
}
return Array.isArray(map)?
map.map(function(key){return {key:key,val:key};}):
Object.keys(map).map(function(key){return {key:key,val:map[key]};});
}

/**
 * Validate whether given map is valid or not
 * @param {*} map
 * @return {Boolean}
 */
function isValidMap(map){
return Array.isArray(map)||isObject(map);
}

/**
 * Return a function expect two param contains namespace and map. it will normalize the namespace and then the param's function will handle the new namespace and the map.
 * @param {Function} fn
 * @return {Function}
 */
function normalizeNamespace(fn){
return function(namespace,map){
if(typeof namespace!=='string'){
map=namespace;
namespace='';
}else if(namespace.charAt(namespace.length-1)!=='/'){
namespace+='/';
}
return fn(namespace,map);
};
}

/**
 * Search a special module from store by namespace. if module not exist, print error message.
 * @param {Object} store
 * @param {String} helper
 * @param {String} namespace
 * @return {Object}
 */
function getModuleByNamespace(store,helper,namespace){
var module=store._modulesNamespaceMap[namespace];
if(!module){
console.error("[vuex] module namespace not found in "+helper+"(): "+namespace);
}
return module;
}

// Credits: borrowed code from fcomb/redux-logger

function createLogger(ref){
if(ref===void 0)ref={};
var collapsed=ref.collapsed;if(collapsed===void 0)collapsed=true;
var filter=ref.filter;if(filter===void 0)filter=function filter(mutation,stateBefore,stateAfter){return true;};
var transformer=ref.transformer;if(transformer===void 0)transformer=function transformer(state){return state;};
var mutationTransformer=ref.mutationTransformer;if(mutationTransformer===void 0)mutationTransformer=function mutationTransformer(mut){return mut;};
var actionFilter=ref.actionFilter;if(actionFilter===void 0)actionFilter=function actionFilter(action,state){return true;};
var actionTransformer=ref.actionTransformer;if(actionTransformer===void 0)actionTransformer=function actionTransformer(act){return act;};
var logMutations=ref.logMutations;if(logMutations===void 0)logMutations=true;
var logActions=ref.logActions;if(logActions===void 0)logActions=true;
var logger=ref.logger;if(logger===void 0)logger=console;

return function(store){
var prevState=deepCopy(store.state);

if(typeof logger==='undefined'){
return;
}

if(logMutations){
store.subscribe(function(mutation,state){
var nextState=deepCopy(state);

if(filter(mutation,prevState,nextState)){
var formattedTime=getFormattedTime();
var formattedMutation=mutationTransformer(mutation);
var message="mutation "+mutation.type+formattedTime;

startMessage(logger,message,collapsed);
logger.log('%c prev state','color: #9E9E9E; font-weight: bold',transformer(prevState));
logger.log('%c mutation','color: #03A9F4; font-weight: bold',formattedMutation);
logger.log('%c next state','color: #4CAF50; font-weight: bold',transformer(nextState));
endMessage(logger);
}

prevState=nextState;
});
}

if(logActions){
store.subscribeAction(function(action,state){
if(actionFilter(action,state)){
var formattedTime=getFormattedTime();
var formattedAction=actionTransformer(action);
var message="action "+action.type+formattedTime;

startMessage(logger,message,collapsed);
logger.log('%c action','color: #03A9F4; font-weight: bold',formattedAction);
endMessage(logger);
}
});
}
};
}

function startMessage(logger,message,collapsed){
var startMessage=collapsed?
logger.groupCollapsed:
logger.group;

// render
try{
startMessage.call(logger,message);
}catch(e){
logger.log(message);
}
}

function endMessage(logger){
try{
logger.groupEnd();
}catch(e){
logger.log('—— log end ——');
}
}

function getFormattedTime(){
var time=new Date();
return " @ "+pad(time.getHours(),2)+":"+pad(time.getMinutes(),2)+":"+pad(time.getSeconds(),2)+"."+pad(time.getMilliseconds(),3);
}

function repeat(str,times){
return new Array(times+1).join(str);
}

function pad(num,maxLength){
return repeat('0',maxLength-num.toString().length)+num;
}

var index={
Store:Store,
install:install,
version:'3.6.2',
mapState:mapState,
mapMutations:mapMutations,
mapGetters:mapGetters,
mapActions:mapActions,
createNamespacedHelpers:createNamespacedHelpers,
createLogger:createLogger};


/* harmony default export */__webpack_exports__["default"]=index;


/* WEBPACK VAR INJECTION */}).call(this,__webpack_require__(/*! ./../../webpack/buildin/global.js */"./node_modules/webpack/buildin/global.js"));

/***/},

/***/"./node_modules/webpack/buildin/global.js":
/*!***********************************!*\
  !*** (webpack)/buildin/global.js ***!
  \***********************************/
/*! no static exports found */
/***/function node_modulesWebpackBuildinGlobalJs(module,exports){

var g;

// This works in non-strict mode
g=function(){
return this;
}();

try{
// This works if eval is allowed (see CSP)
g=g||new Function("return this")();
}catch(e){
// This works if the window reference is available
if(typeof window==="object")g=window;
}

// g can still be undefined, but nothing to do about it...
// We return undefined, instead of nothing here, so it's
// easier to handle this case. if(!global) { ...}

module.exports=g;


/***/},

/***/"./resources/src/App.vue":
/*!*******************************!*\
  !*** ./resources/src/App.vue ***!
  \*******************************/
/*! exports provided: default */
/***/function resourcesSrcAppVue(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _App_vue_vue_type_template_id_ab9f5064___WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! ./App.vue?vue&type=template&id=ab9f5064& */"./resources/src/App.vue?vue&type=template&id=ab9f5064&");
/* harmony import */var _App_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! ./App.vue?vue&type=script&lang=js& */"./resources/src/App.vue?vue&type=script&lang=js&");
/* empty/unused harmony star reexport */ /* harmony import */var _node_modules_vue_loader_lib_runtime_componentNormalizer_js__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ../../node_modules/vue-loader/lib/runtime/componentNormalizer.js */"./node_modules/vue-loader/lib/runtime/componentNormalizer.js");





/* normalize component */

var component=Object(_node_modules_vue_loader_lib_runtime_componentNormalizer_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
_App_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_1__["default"],
_App_vue_vue_type_template_id_ab9f5064___WEBPACK_IMPORTED_MODULE_0__["render"],
_App_vue_vue_type_template_id_ab9f5064___WEBPACK_IMPORTED_MODULE_0__["staticRenderFns"],
false,
null,
null,
null);
component.options.__file="resources/src/App.vue";
/* harmony default export */__webpack_exports__["default"]=component.exports;

/***/},

/***/"./resources/src/App.vue?vue&type=script&lang=js&":
/*!********************************************************!*\
  !*** ./resources/src/App.vue?vue&type=script&lang=js& ***!
  \********************************************************/
/*! exports provided: default */
/***/function resourcesSrcAppVueVueTypeScriptLangJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _node_modules_babel_loader_lib_index_js_ref_4_0_node_modules_vue_loader_lib_index_js_vue_loader_options_App_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! -!../../node_modules/babel-loader/lib??ref--4-0!../../node_modules/vue-loader/lib??vue-loader-options!./App.vue?vue&type=script&lang=js& */"./node_modules/babel-loader/lib/index.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/App.vue?vue&type=script&lang=js&");
/* empty/unused harmony star reexport */ /* harmony default export */__webpack_exports__["default"]=_node_modules_babel_loader_lib_index_js_ref_4_0_node_modules_vue_loader_lib_index_js_vue_loader_options_App_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_0__["default"];

/***/},

/***/"./resources/src/App.vue?vue&type=template&id=ab9f5064&":
/*!**************************************************************!*\
  !*** ./resources/src/App.vue?vue&type=template&id=ab9f5064& ***!
  \**************************************************************/
/*! exports provided: render, staticRenderFns */
/***/function resourcesSrcAppVueVueTypeTemplateIdAb9f5064(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _node_modules_vue_loader_lib_loaders_templateLoader_js_vue_loader_options_node_modules_vue_loader_lib_index_js_vue_loader_options_App_vue_vue_type_template_id_ab9f5064___WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! -!../../node_modules/vue-loader/lib/loaders/templateLoader.js??vue-loader-options!../../node_modules/vue-loader/lib??vue-loader-options!./App.vue?vue&type=template&id=ab9f5064& */"./node_modules/vue-loader/lib/loaders/templateLoader.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/App.vue?vue&type=template&id=ab9f5064&");
/* harmony reexport (safe) */__webpack_require__.d(__webpack_exports__,"render",function(){return _node_modules_vue_loader_lib_loaders_templateLoader_js_vue_loader_options_node_modules_vue_loader_lib_index_js_vue_loader_options_App_vue_vue_type_template_id_ab9f5064___WEBPACK_IMPORTED_MODULE_0__["render"];});

/* harmony reexport (safe) */__webpack_require__.d(__webpack_exports__,"staticRenderFns",function(){return _node_modules_vue_loader_lib_loaders_templateLoader_js_vue_loader_options_node_modules_vue_loader_lib_index_js_vue_loader_options_App_vue_vue_type_template_id_ab9f5064___WEBPACK_IMPORTED_MODULE_0__["staticRenderFns"];});



/***/},

/***/"./resources/src/assets/fonts/iconsmind/icomoon.eot":
/*!**********************************************************!*\
  !*** ./resources/src/assets/fonts/iconsmind/icomoon.eot ***!
  \**********************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsFontsIconsmindIcomoonEot(module,exports){

module.exports="/fonts/icomoon.eot?5a93ca370c17dfa3cb9d26d5f993716b";

/***/},

/***/"./resources/src/assets/fonts/iconsmind/icomoon.eot?-rdmvgc":
/*!******************************************************************!*\
  !*** ./resources/src/assets/fonts/iconsmind/icomoon.eot?-rdmvgc ***!
  \******************************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsFontsIconsmindIcomoonEotRdmvgc(module,exports){

module.exports="/fonts/icomoon.eot?5a93ca370c17dfa3cb9d26d5f993716b";

/***/},

/***/"./resources/src/assets/fonts/iconsmind/icomoon.ttf?-rdmvgc":
/*!******************************************************************!*\
  !*** ./resources/src/assets/fonts/iconsmind/icomoon.ttf?-rdmvgc ***!
  \******************************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsFontsIconsmindIcomoonTtfRdmvgc(module,exports){

module.exports="/fonts/icomoon.ttf?f0409337cef4caa891f01a833caf73d0";

/***/},

/***/"./resources/src/assets/fonts/iconsmind/icomoon.woff?-rdmvgc":
/*!*******************************************************************!*\
  !*** ./resources/src/assets/fonts/iconsmind/icomoon.woff?-rdmvgc ***!
  \*******************************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsFontsIconsmindIcomoonWoffRdmvgc(module,exports){

module.exports="/fonts/icomoon.woff?2864469c0e8a84417f318ee2cac54b04";

/***/},

/***/"./resources/src/assets/images/page-bg-bottom.png":
/*!********************************************************!*\
  !*** ./resources/src/assets/images/page-bg-bottom.png ***!
  \********************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsImagesPageBgBottomPng(module,exports){

module.exports="/images/page-bg-bottom.png?ec613ada298590517b55ec1e07aaa754";

/***/},

/***/"./resources/src/assets/images/photo-wide-4.jpg":
/*!******************************************************!*\
  !*** ./resources/src/assets/images/photo-wide-4.jpg ***!
  \******************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsImagesPhotoWide4Jpg(module,exports){

module.exports="/images/photo-wide-4.jpg?2e142cde64f1b8e128390567fc4bded6";

/***/},

/***/"./resources/src/assets/images/photo-wide-5.jpeg":
/*!*******************************************************!*\
  !*** ./resources/src/assets/images/photo-wide-5.jpeg ***!
  \*******************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsImagesPhotoWide5Jpeg(module,exports){

module.exports="/images/photo-wide-5.jpeg?9f1d8eb903ef302c5c61195b9cb751a3";

/***/},

/***/"./resources/src/assets/styles/sass/globals/globals.scss":
/*!***************************************************************!*\
  !*** ./resources/src/assets/styles/sass/globals/globals.scss ***!
  \***************************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsStylesSassGlobalsGlobalsScss(module,exports){

// removed by extract-text-webpack-plugin

/***/},

/***/"./resources/src/assets/styles/sass/themes/lite-purple.scss":
/*!******************************************************************!*\
  !*** ./resources/src/assets/styles/sass/themes/lite-purple.scss ***!
  \******************************************************************/
/*! no static exports found */
/***/function resourcesSrcAssetsStylesSassThemesLitePurpleScss(module,exports,__webpack_require__){


var content=__webpack_require__(/*! !../../../../../../node_modules/css-loader!../../../../../../node_modules/postcss-loader/src??ref--7-2!../../../../../../node_modules/sass-loader/dist/cjs.js??ref--7-3!./lite-purple.scss */"./node_modules/css-loader/index.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./resources/src/assets/styles/sass/themes/lite-purple.scss");

if(typeof content==='string')content=[[module.i,content,'']];

var transform;



var options={"hmr":true};

options.transform=transform;
options.insertInto=undefined;

var update=__webpack_require__(/*! ../../../../../../node_modules/style-loader/lib/addStyles.js */"./node_modules/style-loader/lib/addStyles.js")(content,options);

if(content.locals)module.exports=content.locals;

/***/},

/***/"./resources/src/auth/IsConnected.js":
/*!*******************************************!*\
  !*** ./resources/src/auth/IsConnected.js ***!
  \*******************************************/
/*! exports provided: default */
/***/function resourcesSrcAuthIsConnectedJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var vue_cookies__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue-cookies */"./node_modules/vue-cookies/vue-cookies.js");
/* harmony import */var vue_cookies__WEBPACK_IMPORTED_MODULE_1___default=/*#__PURE__*/__webpack_require__.n(vue_cookies__WEBPACK_IMPORTED_MODULE_1__);


vue__WEBPACK_IMPORTED_MODULE_0___default.a.use(vue_cookies__WEBPACK_IMPORTED_MODULE_1___default.a);
/* harmony default export */__webpack_exports__["default"]=function(to,from,next){
var accessToken=vue_cookies__WEBPACK_IMPORTED_MODULE_1___default.a.isKey("Stocky_token");

if(accessToken){
next("/app/dashboard");
}else {
return next();
}
};

/***/},

/***/"./resources/src/auth/authenticate.js":
/*!********************************************!*\
  !*** ./resources/src/auth/authenticate.js ***!
  \********************************************/
/*! exports provided: default */
/***/function resourcesSrcAuthAuthenticateJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var vue_cookies__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue-cookies */"./node_modules/vue-cookies/vue-cookies.js");
/* harmony import */var vue_cookies__WEBPACK_IMPORTED_MODULE_1___default=/*#__PURE__*/__webpack_require__.n(vue_cookies__WEBPACK_IMPORTED_MODULE_1__);


vue__WEBPACK_IMPORTED_MODULE_0___default.a.use(vue_cookies__WEBPACK_IMPORTED_MODULE_1___default.a);
/* harmony default export */__webpack_exports__["default"]=function(to,from,next){
var accessToken=vue_cookies__WEBPACK_IMPORTED_MODULE_1___default.a.isKey("Stocky_token");

if(!accessToken){
next("/app/sessions/signIn");
}else {
return next();
}
};

/***/},

/***/"./resources/src/auth/index.js":
/*!*************************************!*\
  !*** ./resources/src/auth/index.js ***!
  \*************************************/
/*! exports provided: default */
/***/function resourcesSrcAuthIndexJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"default",function(){return Auth;});
/* harmony import */var axios__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! axios */"./node_modules/axios/index.js");
/* harmony import */var axios__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(axios__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var _store_index_js__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! ../store/index.js */"./resources/src/store/index.js");
function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}

function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}

function _createClass(Constructor,protoProps,staticProps){if(protoProps)_defineProperties(Constructor.prototype,protoProps);if(staticProps)_defineProperties(Constructor,staticProps);return Constructor;}




var Auth=/*#__PURE__*/function(){
function Auth(){
_classCallCheck(this,Auth);
}

_createClass(Auth,[{
key:"login",
value:function login(token){
_store_index_js__WEBPACK_IMPORTED_MODULE_1__["default"].dispatch('setLoginCred',{
token:token});

}},
{
key:"setAuthToken",
value:function setAuthToken(token){
var tokenIsSet=axios__WEBPACK_IMPORTED_MODULE_0___default.a.defaults.headers.common['Authorization']='Bearer '+token;
}// checks for login status, returns boolean
},
{
key:"check",
value:function check(){
return !!_store_index_js__WEBPACK_IMPORTED_MODULE_1__["default"].state.auth.token;
}}]);


return Auth;
}();



/***/},

/***/"./resources/src/components/breadcumb.vue":
/*!************************************************!*\
  !*** ./resources/src/components/breadcumb.vue ***!
  \************************************************/
/*! exports provided: default */
/***/function resourcesSrcComponentsBreadcumbVue(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _breadcumb_vue_vue_type_template_id_630e5b49___WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! ./breadcumb.vue?vue&type=template&id=630e5b49& */"./resources/src/components/breadcumb.vue?vue&type=template&id=630e5b49&");
/* harmony import */var _breadcumb_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! ./breadcumb.vue?vue&type=script&lang=js& */"./resources/src/components/breadcumb.vue?vue&type=script&lang=js&");
/* empty/unused harmony star reexport */ /* harmony import */var _node_modules_vue_loader_lib_runtime_componentNormalizer_js__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ../../../node_modules/vue-loader/lib/runtime/componentNormalizer.js */"./node_modules/vue-loader/lib/runtime/componentNormalizer.js");





/* normalize component */

var component=Object(_node_modules_vue_loader_lib_runtime_componentNormalizer_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
_breadcumb_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_1__["default"],
_breadcumb_vue_vue_type_template_id_630e5b49___WEBPACK_IMPORTED_MODULE_0__["render"],
_breadcumb_vue_vue_type_template_id_630e5b49___WEBPACK_IMPORTED_MODULE_0__["staticRenderFns"],
false,
null,
null,
null);
component.options.__file="resources/src/components/breadcumb.vue";
/* harmony default export */__webpack_exports__["default"]=component.exports;

/***/},

/***/"./resources/src/components/breadcumb.vue?vue&type=script&lang=js&":
/*!*************************************************************************!*\
  !*** ./resources/src/components/breadcumb.vue?vue&type=script&lang=js& ***!
  \*************************************************************************/
/*! exports provided: default */
/***/function resourcesSrcComponentsBreadcumbVueVueTypeScriptLangJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _node_modules_babel_loader_lib_index_js_ref_4_0_node_modules_vue_loader_lib_index_js_vue_loader_options_breadcumb_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! -!../../../node_modules/babel-loader/lib??ref--4-0!../../../node_modules/vue-loader/lib??vue-loader-options!./breadcumb.vue?vue&type=script&lang=js& */"./node_modules/babel-loader/lib/index.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/components/breadcumb.vue?vue&type=script&lang=js&");
/* empty/unused harmony star reexport */ /* harmony default export */__webpack_exports__["default"]=_node_modules_babel_loader_lib_index_js_ref_4_0_node_modules_vue_loader_lib_index_js_vue_loader_options_breadcumb_vue_vue_type_script_lang_js___WEBPACK_IMPORTED_MODULE_0__["default"];

/***/},

/***/"./resources/src/components/breadcumb.vue?vue&type=template&id=630e5b49&":
/*!*******************************************************************************!*\
  !*** ./resources/src/components/breadcumb.vue?vue&type=template&id=630e5b49& ***!
  \*******************************************************************************/
/*! exports provided: render, staticRenderFns */
/***/function resourcesSrcComponentsBreadcumbVueVueTypeTemplateId630e5b49(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _node_modules_vue_loader_lib_loaders_templateLoader_js_vue_loader_options_node_modules_vue_loader_lib_index_js_vue_loader_options_breadcumb_vue_vue_type_template_id_630e5b49___WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! -!../../../node_modules/vue-loader/lib/loaders/templateLoader.js??vue-loader-options!../../../node_modules/vue-loader/lib??vue-loader-options!./breadcumb.vue?vue&type=template&id=630e5b49& */"./node_modules/vue-loader/lib/loaders/templateLoader.js?!./node_modules/vue-loader/lib/index.js?!./resources/src/components/breadcumb.vue?vue&type=template&id=630e5b49&");
/* harmony reexport (safe) */__webpack_require__.d(__webpack_exports__,"render",function(){return _node_modules_vue_loader_lib_loaders_templateLoader_js_vue_loader_options_node_modules_vue_loader_lib_index_js_vue_loader_options_breadcumb_vue_vue_type_template_id_630e5b49___WEBPACK_IMPORTED_MODULE_0__["render"];});

/* harmony reexport (safe) */__webpack_require__.d(__webpack_exports__,"staticRenderFns",function(){return _node_modules_vue_loader_lib_loaders_templateLoader_js_vue_loader_options_node_modules_vue_loader_lib_index_js_vue_loader_options_breadcumb_vue_vue_type_template_id_630e5b49___WEBPACK_IMPORTED_MODULE_0__["staticRenderFns"];});



/***/},

/***/"./resources/src/main.js":
/*!*******************************!*\
  !*** ./resources/src/main.js ***!
  \*******************************/
/*! no exports provided */
/***/function resourcesSrcMainJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _store__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! ./store */"./resources/src/store/index.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */var _App_vue__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ./App.vue */"./resources/src/App.vue");
/* harmony import */var _router__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(/*! ./router */"./resources/src/router.js");
/* harmony import */var _auth_index_js__WEBPACK_IMPORTED_MODULE_4__=__webpack_require__(/*! ./auth/index.js */"./resources/src/auth/index.js");
/* harmony import */var vee_validate__WEBPACK_IMPORTED_MODULE_5__=__webpack_require__(/*! vee-validate */"./node_modules/vee-validate/dist/vee-validate.esm.js");
/* harmony import */var vee_validate_dist_rules__WEBPACK_IMPORTED_MODULE_6__=__webpack_require__(/*! vee-validate/dist/rules */"./node_modules/vee-validate/dist/rules.js");
/* harmony import */var _plugins_stocky_kit__WEBPACK_IMPORTED_MODULE_7__=__webpack_require__(/*! ./plugins/stocky.kit */"./resources/src/plugins/stocky.kit.js");
/* harmony import */var vue_cookies__WEBPACK_IMPORTED_MODULE_8__=__webpack_require__(/*! vue-cookies */"./node_modules/vue-cookies/vue-cookies.js");
/* harmony import */var vue_cookies__WEBPACK_IMPORTED_MODULE_8___default=/*#__PURE__*/__webpack_require__.n(vue_cookies__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */var vue_select__WEBPACK_IMPORTED_MODULE_9__=__webpack_require__(/*! vue-select */"./node_modules/vue-select/dist/vue-select.js");
/* harmony import */var vue_select__WEBPACK_IMPORTED_MODULE_9___default=/*#__PURE__*/__webpack_require__.n(vue_select__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */var vue_select_dist_vue_select_css__WEBPACK_IMPORTED_MODULE_10__=__webpack_require__(/*! vue-select/dist/vue-select.css */"./node_modules/vue-select/dist/vue-select.css");
/* harmony import */var _trevoreyre_autocomplete_vue__WEBPACK_IMPORTED_MODULE_11__=__webpack_require__(/*! @trevoreyre/autocomplete-vue */"./node_modules/@trevoreyre/autocomplete-vue/dist/autocomplete.esm.js");
/* harmony import */var _trevoreyre_autocomplete_vue_dist_style_css__WEBPACK_IMPORTED_MODULE_12__=__webpack_require__(/*! @trevoreyre/autocomplete-vue/dist/style.css */"./node_modules/@trevoreyre/autocomplete-vue/dist/style.css");
/* harmony import */var _components_breadcumb__WEBPACK_IMPORTED_MODULE_13__=__webpack_require__(/*! ./components/breadcumb */"./resources/src/components/breadcumb.vue");
/* harmony import */var _plugins_i18n__WEBPACK_IMPORTED_MODULE_14__=__webpack_require__(/*! ./plugins/i18n */"./resources/src/plugins/i18n.js");





window.auth=new _auth_index_js__WEBPACK_IMPORTED_MODULE_4__["default"]();


Object(vee_validate__WEBPACK_IMPORTED_MODULE_5__["localize"])({
en:{
messages:{
required:'This field is required',
required_if:'This field is required',
regex:'This field must be a valid',
mimes:"This field must have a valid file type.",
size:function size(_,_ref){
var _size=_ref.size;
return "This field size must be less than ".concat(_size,".");
},
min:'This field must have no less than {length} characters',
max:function max(_,_ref2){
var length=_ref2.length;
return "This field must have no more than ".concat(length," characters");
}}}});


// Install VeeValidate rules and localization

Object.keys(vee_validate_dist_rules__WEBPACK_IMPORTED_MODULE_6__).forEach(function(rule){
Object(vee_validate__WEBPACK_IMPORTED_MODULE_5__["extend"])(rule,vee_validate_dist_rules__WEBPACK_IMPORTED_MODULE_6__[rule]);
});// Register it globally

vue__WEBPACK_IMPORTED_MODULE_1___default.a.component("ValidationObserver",vee_validate__WEBPACK_IMPORTED_MODULE_5__["ValidationObserver"]);
vue__WEBPACK_IMPORTED_MODULE_1___default.a.component('ValidationProvider',vee_validate__WEBPACK_IMPORTED_MODULE_5__["ValidationProvider"]);

vue__WEBPACK_IMPORTED_MODULE_1___default.a.use(_plugins_stocky_kit__WEBPACK_IMPORTED_MODULE_7__["default"]);

vue__WEBPACK_IMPORTED_MODULE_1___default.a.use(vue_cookies__WEBPACK_IMPORTED_MODULE_8___default.a);

var VueCookie=__webpack_require__(/*! vue-cookie */"./node_modules/vue-cookie/src/vue-cookie.js");

vue__WEBPACK_IMPORTED_MODULE_1___default.a.use(VueCookie);
window.axios=__webpack_require__(/*! axios */"./node_modules/axios/index.js");
window.axios.defaults.baseURL='/api/';
window.axios.defaults.withCredentials=true;
window.axios.defaults.headers.common['X-Requested-With']='XMLHttpRequest';
axios.interceptors.response.use(function(response){
return response;
},function(error){
if(error.response&&error.response.data){
if(error.response.status===401){
window.location.href='/login';
}

if(error.response.status===404){
_router__WEBPACK_IMPORTED_MODULE_3__["default"].push({
name:'NotFound'});

}

if(error.response.status===403){
_router__WEBPACK_IMPORTED_MODULE_3__["default"].push({
name:'not_authorize'});

}

return Promise.reject(error.response.data);
}

return Promise.reject(error.message);
});

vue__WEBPACK_IMPORTED_MODULE_1___default.a.component('v-select',vue_select__WEBPACK_IMPORTED_MODULE_9___default.a);



vue__WEBPACK_IMPORTED_MODULE_1___default.a.use(_trevoreyre_autocomplete_vue__WEBPACK_IMPORTED_MODULE_11__["default"]);
window.Fire=new vue__WEBPACK_IMPORTED_MODULE_1___default.a();


vue__WEBPACK_IMPORTED_MODULE_1___default.a.component("breadcumb",_components_breadcumb__WEBPACK_IMPORTED_MODULE_13__["default"]);
vue__WEBPACK_IMPORTED_MODULE_1___default.a.config.productionTip=true;
vue__WEBPACK_IMPORTED_MODULE_1___default.a.config.silent=true;
vue__WEBPACK_IMPORTED_MODULE_1___default.a.config.devtools=false;
new vue__WEBPACK_IMPORTED_MODULE_1___default.a({
store:_store__WEBPACK_IMPORTED_MODULE_0__["default"],
router:_router__WEBPACK_IMPORTED_MODULE_3__["default"],
VueCookie:VueCookie,
i18n:_plugins_i18n__WEBPACK_IMPORTED_MODULE_14__["i18n"],
render:function render(h){
return h(_App_vue__WEBPACK_IMPORTED_MODULE_2__["default"]);
}}).
$mount("#app");

/***/},

/***/"./resources/src/plugins/i18n.js":
/*!***************************************!*\
  !*** ./resources/src/plugins/i18n.js ***!
  \***************************************/
/*! exports provided: i18n */
/***/function resourcesSrcPluginsI18nJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */__webpack_require__.d(__webpack_exports__,"i18n",function(){return i18n;});
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var vue_i18n__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue-i18n */"./node_modules/vue-i18n/dist/vue-i18n.esm.js");
/* harmony import */var _translations__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ../translations */"./resources/src/translations/index.js");



vue__WEBPACK_IMPORTED_MODULE_0___default.a.use(vue_i18n__WEBPACK_IMPORTED_MODULE_1__["default"]);
var i18n=new vue_i18n__WEBPACK_IMPORTED_MODULE_1__["default"]({
locale:'en',
fallbackLocale:'en',
messages:_translations__WEBPACK_IMPORTED_MODULE_2__["default"]});


/***/},

/***/"./resources/src/plugins/stocky.kit.js":
/*!*********************************************!*\
  !*** ./resources/src/plugins/stocky.kit.js ***!
  \*********************************************/
/*! exports provided: default */
/***/function resourcesSrcPluginsStockyKitJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var bootstrap_vue_dist_bootstrap_vue_esm__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! bootstrap-vue/dist/bootstrap-vue.esm */"./node_modules/bootstrap-vue/dist/bootstrap-vue.esm.js");
/* harmony import */var vue_good_table__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue-good-table */"./node_modules/vue-good-table/dist/vue-good-table.esm.js");
/* harmony import */var vue_meta__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! vue-meta */"./node_modules/vue-meta/dist/vue-meta.esm.js");
/* harmony import */var vue_mj_daterangepicker__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(/*! vue-mj-daterangepicker */"./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.common.js");
/* harmony import */var vue_mj_daterangepicker__WEBPACK_IMPORTED_MODULE_3___default=/*#__PURE__*/__webpack_require__.n(vue_mj_daterangepicker__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */var vue_mj_daterangepicker_dist_vue_mj_daterangepicker_css__WEBPACK_IMPORTED_MODULE_4__=__webpack_require__(/*! vue-mj-daterangepicker/dist/vue-mj-daterangepicker.css */"./node_modules/vue-mj-daterangepicker/dist/vue-mj-daterangepicker.css");
/* harmony import */var _assets_styles_sass_themes_lite_purple_scss__WEBPACK_IMPORTED_MODULE_5__=__webpack_require__(/*! ./../assets/styles/sass/themes/lite-purple.scss */"./resources/src/assets/styles/sass/themes/lite-purple.scss");
/* harmony import */var _sweetalert2_js__WEBPACK_IMPORTED_MODULE_6__=__webpack_require__(/*! ./sweetalert2.js */"./resources/src/plugins/sweetalert2.js");







/* harmony default export */__webpack_exports__["default"]={
install:function install(Vue){
Vue.use(bootstrap_vue_dist_bootstrap_vue_esm__WEBPACK_IMPORTED_MODULE_0__["default"]);
Vue.component("large-sidebar",// The `import` function returns a Promise.
function(){
return Promise.all(/*! import() | largeSidebar */[__webpack_require__.e("vendors~largeSidebar~pos"),__webpack_require__.e("vendors~largeSidebar"),__webpack_require__.e("largeSidebar")]).then(__webpack_require__.bind(null,/*! ../containers/layouts/largeSidebar */"./resources/src/containers/layouts/largeSidebar/index.vue"));
});
Vue.component("customizer",// The `import` function returns a Promise.
function(){
return __webpack_require__.e(/*! import() | customizer */"customizer").then(__webpack_require__.bind(null,/*! ../components/common/customizer.vue */"./resources/src/components/common/customizer.vue"));
});
Vue.component("vue-perfect-scrollbar",function(){
return __webpack_require__.e(/*! import() | vue-perfect-scrollbar */"vendors~vue-perfect-scrollbar").then(__webpack_require__.t.bind(null,/*! vue-perfect-scrollbar */"./node_modules/vue-perfect-scrollbar/dist/index.js",7));
});
Vue.use(vue_mj_daterangepicker__WEBPACK_IMPORTED_MODULE_3___default.a);
Vue.use(vue_meta__WEBPACK_IMPORTED_MODULE_2__["default"],{
keyName:"metaInfo",
attribute:"data-vue-meta",
ssrAttribute:"data-vue-meta-server-rendered",
tagIDKeyName:"vmid",
refreshOnceOnNavigation:true});

Vue.use(vue_good_table__WEBPACK_IMPORTED_MODULE_1__["default"]);
}};


/***/},

/***/"./resources/src/plugins/sweetalert2.js":
/*!**********************************************!*\
  !*** ./resources/src/plugins/sweetalert2.js ***!
  \**********************************************/
/*! no exports provided */
/***/function resourcesSrcPluginsSweetalert2Js(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var vue_sweetalert2__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue-sweetalert2 */"./node_modules/vue-sweetalert2/dist/index.js");
/* harmony import */var sweetalert2_dist_sweetalert2_min_css__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! sweetalert2/dist/sweetalert2.min.css */"./node_modules/sweetalert2/dist/sweetalert2.min.css");
// main.js

// If you don't need the styles, do not connect


var options={
confirmButtonColor:'#41b882',
cancelButtonColor:'#ff7674'};

vue__WEBPACK_IMPORTED_MODULE_0___default.a.use(vue_sweetalert2__WEBPACK_IMPORTED_MODULE_1__["default"],options);

/***/},

/***/"./resources/src/router.js":
/*!*********************************!*\
  !*** ./resources/src/router.js ***!
  \*********************************/
/*! exports provided: default */
/***/function resourcesSrcRouterJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _babel_runtime_regenerator__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! @babel/runtime/regenerator */"./node_modules/@babel/runtime/regenerator/index.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */var _store__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ./store */"./resources/src/store/index.js");
/* harmony import */var vue_router__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(/*! vue-router */"./node_modules/vue-router/dist/vue-router.esm.js");
/* harmony import */var _plugins_i18n__WEBPACK_IMPORTED_MODULE_4__=__webpack_require__(/*! ./plugins/i18n */"./resources/src/plugins/i18n.js");
/* harmony import */var _auth_authenticate__WEBPACK_IMPORTED_MODULE_5__=__webpack_require__(/*! ./auth/authenticate */"./resources/src/auth/authenticate.js");
/* harmony import */var _auth_IsConnected__WEBPACK_IMPORTED_MODULE_6__=__webpack_require__(/*! ./auth/IsConnected */"./resources/src/auth/IsConnected.js");
/* harmony import */var nprogress__WEBPACK_IMPORTED_MODULE_7__=__webpack_require__(/*! nprogress */"./node_modules/nprogress/nprogress.js");
/* harmony import */var nprogress__WEBPACK_IMPORTED_MODULE_7___default=/*#__PURE__*/__webpack_require__.n(nprogress__WEBPACK_IMPORTED_MODULE_7__);








vue__WEBPACK_IMPORTED_MODULE_1___default.a.use(vue_router__WEBPACK_IMPORTED_MODULE_3__["default"]);// create new router

var routes=[{
path:"/",
component:function component(){
return __webpack_require__.e(/*! import() */2).then(__webpack_require__.bind(null,/*! ./views/app */"./resources/src/views/app/index.vue"));
},
// beforeEnter: authenticate,
redirect:"/app/dashboard",
children:[{
path:"/app/dashboard",
name:"dashboard",
component:function component(){
return Promise.all(/*! import() | dashboard */[__webpack_require__.e("vendors~dashboard~warehouse_report"),__webpack_require__.e("dashboard")]).then(__webpack_require__.bind(null,/*! ./views/app/dashboard/dashboard */"./resources/src/views/app/dashboard/dashboard.vue"));
}},
//Products
{
path:"/app/products",
component:function component(){
return __webpack_require__.e(/*! import() | products */"products").then(__webpack_require__.bind(null,/*! ./views/app/pages/products */"./resources/src/views/app/pages/products/index.vue"));
},
redirect:"app/products/list",
children:[{
name:"index_products",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_products */[__webpack_require__.e(0),__webpack_require__.e("index_products")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/products/index_products */"./resources/src/views/app/pages/products/index_products.vue"));
}},
{
path:"store",
name:"store_product",
component:function component(){
return Promise.all(/*! import() | store_product */[__webpack_require__.e("vendors~edit_product~store_product"),__webpack_require__.e("store_product")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/products/Add_product */"./resources/src/views/app/pages/products/Add_product.vue"));
}},
{
path:"edit/:id",
name:"edit_product",
component:function component(){
return Promise.all(/*! import() | edit_product */[__webpack_require__.e("vendors~edit_product~store_product"),__webpack_require__.e("edit_product")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/products/Edit_product */"./resources/src/views/app/pages/products/Edit_product.vue"));
}},
{
path:"detail/:id",
name:"detail_product",
component:function component(){
return Promise.all(/*! import() | detail_product */[__webpack_require__.e("vendors~barcode~detail_product~index_sales~pos"),__webpack_require__.e("detail_product")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/products/Detail_Product */"./resources/src/views/app/pages/products/Detail_Product.vue"));
}},
{
path:"barcode",
name:"barcode",
component:function component(){
return Promise.all(/*! import() | barcode */[__webpack_require__.e("vendors~barcode~detail_product~index_sales~pos"),__webpack_require__.e("barcode")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/products/barcode */"./resources/src/views/app/pages/products/barcode.vue"));
}}]},

//Adjustement
{
path:"/app/adjustments",
component:function component(){
return __webpack_require__.e(/*! import() | adjustments */"adjustments").then(__webpack_require__.bind(null,/*! ./views/app/pages/adjustment */"./resources/src/views/app/pages/adjustment/index.vue"));
},
redirect:"/app/adjustments/list",
children:[{
name:"index_adjustment",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_adjustment */[__webpack_require__.e(0),__webpack_require__.e("index_adjustment")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/adjustment/index_Adjustment */"./resources/src/views/app/pages/adjustment/index_Adjustment.vue"));
}},
{
name:"store_adjustment",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_adjustment */"store_adjustment").then(__webpack_require__.bind(null,/*! ./views/app/pages/adjustment/Create_Adjustment */"./resources/src/views/app/pages/adjustment/Create_Adjustment.vue"));
}},
{
name:"edit_adjustment",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_adjustment */"edit_adjustment").then(__webpack_require__.bind(null,/*! ./views/app/pages/adjustment/Edit_Adjustment */"./resources/src/views/app/pages/adjustment/Edit_Adjustment.vue"));
}}]},

//Transfer
{
path:"/app/transfers",
component:function component(){
return __webpack_require__.e(/*! import() | transfers */"transfers").then(__webpack_require__.bind(null,/*! ./views/app/pages/transfers */"./resources/src/views/app/pages/transfers/index.vue"));
},
redirect:"/app/transfers/list",
children:[{
name:"index_transfer",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_transfer */[__webpack_require__.e(0),__webpack_require__.e("index_transfer")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/transfers/index_transfer */"./resources/src/views/app/pages/transfers/index_transfer.vue"));
}},
{
name:"store_transfer",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_transfer */"store_transfer").then(__webpack_require__.bind(null,/*! ./views/app/pages/transfers/create_transfer */"./resources/src/views/app/pages/transfers/create_transfer.vue"));
}},
{
name:"edit_transfer",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_transfer */"edit_transfer").then(__webpack_require__.bind(null,/*! ./views/app/pages/transfers/edit_transfer */"./resources/src/views/app/pages/transfers/edit_transfer.vue"));
}}]},

//Expense
{
path:"/app/expenses",
component:function component(){
return __webpack_require__.e(/*! import() | expenses */"expenses").then(__webpack_require__.bind(null,/*! ./views/app/pages/expense */"./resources/src/views/app/pages/expense/index.vue"));
},
redirect:"/app/expenses/list",
children:[{
name:"index_expense",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_expense */[__webpack_require__.e(0),__webpack_require__.e("index_expense")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/expense/index_expense */"./resources/src/views/app/pages/expense/index_expense.vue"));
}},
{
name:"store_expense",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_expense */"store_expense").then(__webpack_require__.bind(null,/*! ./views/app/pages/expense/Create_expense */"./resources/src/views/app/pages/expense/Create_expense.vue"));
}},
{
name:"edit_expense",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_expense */"edit_expense").then(__webpack_require__.bind(null,/*! ./views/app/pages/expense/Edit_expense */"./resources/src/views/app/pages/expense/Edit_expense.vue"));
}},
{
name:"expense_category",
path:"category",
component:function component(){
return __webpack_require__.e(/*! import() | expense_category */"expense_category").then(__webpack_require__.bind(null,/*! ./views/app/pages/expense/category_expense */"./resources/src/views/app/pages/expense/category_expense.vue"));
}}]},

//Quotation
{
path:"/app/quotations",
component:function component(){
return __webpack_require__.e(/*! import() | quotations */"quotations").then(__webpack_require__.bind(null,/*! ./views/app/pages/quotations */"./resources/src/views/app/pages/quotations/index.vue"));
},
redirect:"/app/quotations/list",
children:[{
name:"index_quotation",
path:"list",
component:function component(){
return Promise.all(/*! import() */[__webpack_require__.e(0),__webpack_require__.e(3)]).then(__webpack_require__.bind(null,/*! ./views/app/pages/quotations/index_quotation */"./resources/src/views/app/pages/quotations/index_quotation.vue"));
}},
{
name:"store_quotation",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_quotation */"store_quotation").then(__webpack_require__.bind(null,/*! ./views/app/pages/quotations/create_quotation */"./resources/src/views/app/pages/quotations/create_quotation.vue"));
}},
{
name:"edit_quotation",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_quotation */"edit_quotation").then(__webpack_require__.bind(null,/*! ./views/app/pages/quotations/edit_quotation */"./resources/src/views/app/pages/quotations/edit_quotation.vue"));
}},
{
name:"detail_quotation",
path:"detail/:id",
component:function component(){
return __webpack_require__.e(/*! import() | detail_quotation */"detail_quotation").then(__webpack_require__.bind(null,/*! ./views/app/pages/quotations/detail_quotation */"./resources/src/views/app/pages/quotations/detail_quotation.vue"));
}},
{
name:"change_to_sale",
path:"create_sale/:id",
component:function component(){
return __webpack_require__.e(/*! import() | change_to_sale */"change_to_sale").then(__webpack_require__.bind(null,/*! ./views/app/pages/sales/change_to_sale.vue */"./resources/src/views/app/pages/sales/change_to_sale.vue"));
}}]},

//Purchase
{
path:"/app/purchases",
component:function component(){
return __webpack_require__.e(/*! import() | purchases */"purchases").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchases */"./resources/src/views/app/pages/purchases/index.vue"));
},
redirect:"/app/purchases/list",
children:[{
name:"index_purchases",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_purchases */[__webpack_require__.e(0),__webpack_require__.e("index_purchases")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/purchases/index_purchase */"./resources/src/views/app/pages/purchases/index_purchase.vue"));
}},
{
name:"store_purchase",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_purchase */"store_purchase").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchases/create_purchase */"./resources/src/views/app/pages/purchases/create_purchase.vue"));
}},
{
name:"edit_purchase",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_purchase */"edit_purchase").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchases/edit_purchase */"./resources/src/views/app/pages/purchases/edit_purchase.vue"));
}},
{
name:"detail_purchase",
path:"detail/:id",
component:function component(){
return __webpack_require__.e(/*! import() | detail_purchase */"detail_purchase").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchases/detail_purchase */"./resources/src/views/app/pages/purchases/detail_purchase.vue"));
}}]},

//Sale
{
path:"/app/sales",
component:function component(){
return __webpack_require__.e(/*! import() | sales */"sales").then(__webpack_require__.bind(null,/*! ./views/app/pages/sales */"./resources/src/views/app/pages/sales/index.vue"));
},
redirect:"/app/sales/list",
children:[{
name:"index_sales",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_sales */[__webpack_require__.e(0),__webpack_require__.e("vendors~barcode~detail_product~index_sales~pos"),__webpack_require__.e("vendors~index_sales~pos"),__webpack_require__.e("index_sales")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/sales/index_sale */"./resources/src/views/app/pages/sales/index_sale.vue"));
}},
{
name:"store_sale",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_sale */"store_sale").then(__webpack_require__.bind(null,/*! ./views/app/pages/sales/create_sale */"./resources/src/views/app/pages/sales/create_sale.vue"));
}},
{
name:"edit_sale",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_sale */"edit_sale").then(__webpack_require__.bind(null,/*! ./views/app/pages/sales/edit_sale */"./resources/src/views/app/pages/sales/edit_sale.vue"));
}},
{
name:"detail_sale",
path:"detail/:id",
component:function component(){
return __webpack_require__.e(/*! import() | detail_sale */"detail_sale").then(__webpack_require__.bind(null,/*! ./views/app/pages/sales/detail_sale */"./resources/src/views/app/pages/sales/detail_sale.vue"));
}}]},

// Sales Return
{
path:"/app/sale_return",
component:function component(){
return __webpack_require__.e(/*! import() | sale_return */"sale_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/sale_return */"./resources/src/views/app/pages/sale_return/index.vue"));
},
redirect:"/app/sale_return/list",
children:[{
name:"index_sale_return",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_sale_return */[__webpack_require__.e(0),__webpack_require__.e("index_sale_return")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/sale_return/index_sale_return */"./resources/src/views/app/pages/sale_return/index_sale_return.vue"));
}},
{
name:"store_sale_return",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_sale_return */"store_sale_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/sale_return/create_sale_return */"./resources/src/views/app/pages/sale_return/create_sale_return.vue"));
}},
{
name:"edit_sale_return",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_sale_return */"edit_sale_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/sale_return/edit_sale_return */"./resources/src/views/app/pages/sale_return/edit_sale_return.vue"));
}},
{
name:"detail_sale_return",
path:"detail/:id",
component:function component(){
return __webpack_require__.e(/*! import() | detail_sale_return */"detail_sale_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/sale_return/detail_sale_return */"./resources/src/views/app/pages/sale_return/detail_sale_return.vue"));
}}]},

// purchase Return
{
path:"/app/purchase_return",
component:function component(){
return __webpack_require__.e(/*! import() | purchase_return */"purchase_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchase_return */"./resources/src/views/app/pages/purchase_return/index.vue"));
},
redirect:"/app/purchase_return/list",
children:[{
name:"index_purchase_return",
path:"list",
component:function component(){
return Promise.all(/*! import() | index_purchase_return */[__webpack_require__.e(0),__webpack_require__.e("index_purchase_return")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/purchase_return/index_purchase_return */"./resources/src/views/app/pages/purchase_return/index_purchase_return.vue"));
}},
{
name:"store_purchase_return",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_purchase_return */"store_purchase_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchase_return/create_purchase_return */"./resources/src/views/app/pages/purchase_return/create_purchase_return.vue"));
}},
{
name:"edit_purchase_return",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_purchase_return */"edit_purchase_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchase_return/edit_purchase_return */"./resources/src/views/app/pages/purchase_return/edit_purchase_return.vue"));
}},
{
name:"detail_purchase_return",
path:"detail/:id",
component:function component(){
return __webpack_require__.e(/*! import() | detail_purchase_return */"detail_purchase_return").then(__webpack_require__.bind(null,/*! ./views/app/pages/purchase_return/detail_purchase_return */"./resources/src/views/app/pages/purchase_return/detail_purchase_return.vue"));
}}]},

// People
{
path:"/app/People",
component:function component(){
return __webpack_require__.e(/*! import() | People */"People").then(__webpack_require__.bind(null,/*! ./views/app/pages/people */"./resources/src/views/app/pages/people/index.vue"));
},
redirect:"/app/People/Customers",
children:[// Customers
{
name:"Customers",
path:"Customers",
component:function component(){
return Promise.all(/*! import() | Customers */[__webpack_require__.e(0),__webpack_require__.e("Customers")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/people/customers */"./resources/src/views/app/pages/people/customers.vue"));
}},
// Suppliers
{
name:"Suppliers",
path:"Suppliers",
component:function component(){
return Promise.all(/*! import() | Suppliers */[__webpack_require__.e(0),__webpack_require__.e("Suppliers")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/people/providers */"./resources/src/views/app/pages/people/providers.vue"));
}},
// Users
{
name:"user",
path:"Users",
component:function component(){
return Promise.all(/*! import() | Users */[__webpack_require__.e(0),__webpack_require__.e("Users")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/people/users */"./resources/src/views/app/pages/people/users.vue"));
}}]},

// Settings
{
path:"/app/settings",
component:function component(){
return __webpack_require__.e(/*! import() | settings */"settings").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings */"./resources/src/views/app/pages/settings/index.vue"));
},
redirect:"/app/settings/System_settings",
children:[// Permissions
{
path:"permissions",
component:function component(){
return __webpack_require__.e(/*! import() | permissions */"permissions").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/permissions */"./resources/src/views/app/pages/settings/permissions/index.vue"));
},
redirect:"/app/settings/permissions/list",
children:[{
name:"groupPermission",
path:"list",
component:function component(){
return __webpack_require__.e(/*! import() | groupPermission */"groupPermission").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/permissions/Permissions */"./resources/src/views/app/pages/settings/permissions/Permissions.vue"));
}},
{
name:"store_permission",
path:"store",
component:function component(){
return __webpack_require__.e(/*! import() | store_permission */"store_permission").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/permissions/Create_permission */"./resources/src/views/app/pages/settings/permissions/Create_permission.vue"));
}},
{
name:"edit_permission",
path:"edit/:id",
component:function component(){
return __webpack_require__.e(/*! import() | edit_permission */"edit_permission").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/permissions/Edit_permission */"./resources/src/views/app/pages/settings/permissions/Edit_permission.vue"));
}}]},

// categories
{
name:"categories",
path:"Categories",
component:function component(){
return __webpack_require__.e(/*! import() | Categories */"Categories").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/categorie */"./resources/src/views/app/pages/settings/categorie.vue"));
}},
// brands
{
name:"brands",
path:"Brands",
component:function component(){
return __webpack_require__.e(/*! import() | Brands */"Brands").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/brands */"./resources/src/views/app/pages/settings/brands.vue"));
}},
// currencies
{
name:"currencies",
path:"Currencies",
component:function component(){
return __webpack_require__.e(/*! import() | Currencies */"Currencies").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/currencies */"./resources/src/views/app/pages/settings/currencies.vue"));
}},
// units
{
name:"units",
path:"Units",
component:function component(){
return __webpack_require__.e(/*! import() | units */"units").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/units */"./resources/src/views/app/pages/settings/units.vue"));
}},
// Backup
{
name:"Backup",
path:"Backup",
component:function component(){
return __webpack_require__.e(/*! import() | Backup */"Backup").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/backup */"./resources/src/views/app/pages/settings/backup.vue"));
}},
// Warehouses
{
name:"Warehouses",
path:"Warehouses",
component:function component(){
return __webpack_require__.e(/*! import() | Warehouses */"Warehouses").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/warehouses */"./resources/src/views/app/pages/settings/warehouses.vue"));
}},
// System Settings
{
name:"system_settings",
path:"System_settings",
component:function component(){
return __webpack_require__.e(/*! import() | System_settings */"System_settings").then(__webpack_require__.bind(null,/*! ./views/app/pages/settings/system_settings */"./resources/src/views/app/pages/settings/system_settings.vue"));
}}
// updates
//  {
//     name: "updates",
//     path: "updates",
//     component: () =>
//         import(/* webpackChunkName: "updates" */"./views/app/pages/settings/updates")
// }
]},
// Reports
{
path:"/app/reports",
component:function component(){
return __webpack_require__.e(/*! import() */4).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports */"./resources/src/views/app/pages/reports/index.vue"));
},
redirect:"/app/reports/profit_and_loss",
children:[{
name:"payments_purchases",
path:"payments_purchase",
component:function component(){
return Promise.all(/*! import() | payments_purchases */[__webpack_require__.e(0),__webpack_require__.e("payments_purchases")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/payments/payments_purchases */"./resources/src/views/app/pages/reports/payments/payments_purchases.vue"));
}},
{
name:"payments_sales",
path:"payments_sale",
component:function component(){
return Promise.all(/*! import() | payments_sales */[__webpack_require__.e(0),__webpack_require__.e("payments_sales")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/payments/payments_sales */"./resources/src/views/app/pages/reports/payments/payments_sales.vue"));
}},
{
name:"payments_purchases_returns",
path:"payments_purchases_returns",
component:function component(){
return Promise.all(/*! import() | payments_purchases_returns */[__webpack_require__.e(0),__webpack_require__.e("payments_purchases_returns")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/payments/payments_purchases_returns */"./resources/src/views/app/pages/reports/payments/payments_purchases_returns.vue"));
}},
{
name:"payments_sales_returns",
path:"payments_sales_returns",
component:function component(){
return Promise.all(/*! import() | payments_sales_returns */[__webpack_require__.e(0),__webpack_require__.e("payments_sales_returns")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/payments/payments_sales_returns */"./resources/src/views/app/pages/reports/payments/payments_sales_returns.vue"));
}},
{
name:"profit_and_loss",
path:"profit_and_loss",
component:function component(){
return __webpack_require__.e(/*! import() | profit_and_loss */"profit_and_loss").then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/profit_and_loss */"./resources/src/views/app/pages/reports/profit_and_loss.vue"));
}},
{
name:"quantity_alerts",
path:"quantity_alerts",
component:function component(){
return __webpack_require__.e(/*! import() | quantity_alerts */"quantity_alerts").then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/quantity_alerts */"./resources/src/views/app/pages/reports/quantity_alerts.vue"));
}},
{
name:"warehouse_report",
path:"warehouse_report",
component:function component(){
return Promise.all(/*! import() | warehouse_report */[__webpack_require__.e("vendors~dashboard~warehouse_report"),__webpack_require__.e("warehouse_report")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/warehouse_report */"./resources/src/views/app/pages/reports/warehouse_report.vue"));
}},
{
name:"sales_report",
path:"sales_report",
component:function component(){
return Promise.all(/*! import() | sales_report */[__webpack_require__.e(0),__webpack_require__.e("sales_report")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/sales_report */"./resources/src/views/app/pages/reports/sales_report.vue"));
}},
{
name:"purchase_report",
path:"purchase_report",
component:function component(){
return Promise.all(/*! import() | purchase_report */[__webpack_require__.e(0),__webpack_require__.e("purchase_report")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/purchase_report */"./resources/src/views/app/pages/reports/purchase_report.vue"));
}},
{
name:"customers_report",
path:"customers_report",
component:function component(){
return __webpack_require__.e(/*! import() | customers_report */"customers_report").then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/customers_report */"./resources/src/views/app/pages/reports/customers_report.vue"));
}},
{
name:"detail_customer_report",
path:"detail_customer/:id",
component:function component(){
return __webpack_require__.e(/*! import() | detail_customer_report */"detail_customer_report").then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/detail_Customer_Report */"./resources/src/views/app/pages/reports/detail_Customer_Report.vue"));
}},
{
name:"providers_report",
path:"providers_report",
component:function component(){
return __webpack_require__.e(/*! import() | providers_report */"providers_report").then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/providers_report */"./resources/src/views/app/pages/reports/providers_report.vue"));
}},
{
name:"detail_supplier_report",
path:"detail_supplier/:id",
component:function component(){
return __webpack_require__.e(/*! import() | detail_supplier_report */"detail_supplier_report").then(__webpack_require__.bind(null,/*! ./views/app/pages/reports/detail_Supplier_Report */"./resources/src/views/app/pages/reports/detail_Supplier_Report.vue"));
}}]},

{
name:"profile",
path:"/app/profile",
component:function component(){
return __webpack_require__.e(/*! import() | profile */"profile").then(__webpack_require__.bind(null,/*! ./views/app/pages/profile */"./resources/src/views/app/pages/profile.vue"));
}}]},

{
name:"pos",
path:"/app/pos",
// beforeEnter: authenticate,
component:function component(){
return Promise.all(/*! import() | pos */[__webpack_require__.e("vendors~barcode~detail_product~index_sales~pos"),__webpack_require__.e("vendors~largeSidebar~pos"),__webpack_require__.e("vendors~index_sales~pos"),__webpack_require__.e("pos")]).then(__webpack_require__.bind(null,/*! ./views/app/pages/pos */"./resources/src/views/app/pages/pos.vue"));
}},
{
path:"*",
name:"NotFound",
component:function component(){
return __webpack_require__.e(/*! import() | NotFound */"NotFound").then(__webpack_require__.bind(null,/*! ./views/app/pages/notFound */"./resources/src/views/app/pages/notFound.vue"));
}},
{
path:"not_authorize",
name:"not_authorize",
component:function component(){
return __webpack_require__.e(/*! import() | not_authorize */"not_authorize").then(__webpack_require__.bind(null,/*! ./views/app/pages/NotAuthorize */"./resources/src/views/app/pages/NotAuthorize.vue"));
}}];

var router=new vue_router__WEBPACK_IMPORTED_MODULE_3__["default"]({
mode:"history",
linkActiveClass:"open",
routes:routes,
scrollBehavior:function scrollBehavior(to,from,savedPosition){
return {
x:0,
y:0};

}});

var originalPush=vue_router__WEBPACK_IMPORTED_MODULE_3__["default"].prototype.push;

vue_router__WEBPACK_IMPORTED_MODULE_3__["default"].prototype.push=function push(location,onResolve,onReject){
if(onResolve||onReject)return originalPush.call(this,location,onResolve,onReject);
return originalPush.call(this,location)["catch"](function(err){
return err;
});
};

router.beforeEach(function(to,from,next){
// If this isn't an initial page load.
if(to.path){
// Start the route progress bar.
nprogress__WEBPACK_IMPORTED_MODULE_7___default.a.start();
nprogress__WEBPACK_IMPORTED_MODULE_7___default.a.set(0.1);
}

next();

if(_store__WEBPACK_IMPORTED_MODULE_2__["default"].state.language.language&&_store__WEBPACK_IMPORTED_MODULE_2__["default"].state.language.language!==_plugins_i18n__WEBPACK_IMPORTED_MODULE_4__["i18n"].locale){
_plugins_i18n__WEBPACK_IMPORTED_MODULE_4__["i18n"].locale=_store__WEBPACK_IMPORTED_MODULE_2__["default"].state.language.language;
next();
}else if(!_store__WEBPACK_IMPORTED_MODULE_2__["default"].state.language.language){
_store__WEBPACK_IMPORTED_MODULE_2__["default"].dispatch("language/setLanguage",navigator.languages).then(function(){
_plugins_i18n__WEBPACK_IMPORTED_MODULE_4__["i18n"].locale=_store__WEBPACK_IMPORTED_MODULE_2__["default"].state.language.language;
next();
});
}else {
next();
}
});
router.afterEach(function(){
// Remove initial loading
var gullPreLoading=document.getElementById("loading_wrap");

if(gullPreLoading){
gullPreLoading.style.display="none";
}// Complete the animation of the route progress bar.


setTimeout(function(){
return nprogress__WEBPACK_IMPORTED_MODULE_7___default.a.done();
},500);// NProgress.done();

if(window.innerWidth<=1200){
_store__WEBPACK_IMPORTED_MODULE_2__["default"].dispatch("changeSidebarProperties");

if(_store__WEBPACK_IMPORTED_MODULE_2__["default"].getters.getSideBarToggleProperties.isSecondarySideNavOpen){
_store__WEBPACK_IMPORTED_MODULE_2__["default"].dispatch("changeSecondarySidebarProperties");
}

if(_store__WEBPACK_IMPORTED_MODULE_2__["default"].getters.getCompactSideBarToggleProperties.isSideNavOpen){
_store__WEBPACK_IMPORTED_MODULE_2__["default"].dispatch("changeCompactSidebarProperties");
}
}else {
if(_store__WEBPACK_IMPORTED_MODULE_2__["default"].getters.getSideBarToggleProperties.isSecondarySideNavOpen){
_store__WEBPACK_IMPORTED_MODULE_2__["default"].dispatch("changeSecondarySidebarProperties");
}
}
});

/* harmony default export */__webpack_exports__["default"]=router;

/***/},

/***/"./resources/src/store/index.js":
/*!**************************************!*\
  !*** ./resources/src/store/index.js ***!
  \**************************************/
/*! exports provided: default */
/***/function resourcesSrcStoreIndexJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var vuex__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vuex */"./node_modules/vuex/dist/vuex.esm.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */var _modules_largeSidebar__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ./modules/largeSidebar */"./resources/src/store/modules/largeSidebar.js");
/* harmony import */var _modules_compactSidebar__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(/*! ./modules/compactSidebar */"./resources/src/store/modules/compactSidebar.js");
/* harmony import */var _modules_config__WEBPACK_IMPORTED_MODULE_4__=__webpack_require__(/*! ./modules/config */"./resources/src/store/modules/config.js");
/* harmony import */var _modules_auth__WEBPACK_IMPORTED_MODULE_5__=__webpack_require__(/*! ./modules/auth */"./resources/src/store/modules/auth.js");
/* harmony import */var _modules_language__WEBPACK_IMPORTED_MODULE_6__=__webpack_require__(/*! ./modules/language */"./resources/src/store/modules/language.js");






// Load Vuex

vue__WEBPACK_IMPORTED_MODULE_1___default.a.use(vuex__WEBPACK_IMPORTED_MODULE_0__["default"]);// Create store

/* harmony default export */__webpack_exports__["default"]=new vuex__WEBPACK_IMPORTED_MODULE_0__["default"].Store({
modules:{
language:_modules_language__WEBPACK_IMPORTED_MODULE_6__["default"],
auth:_modules_auth__WEBPACK_IMPORTED_MODULE_5__["default"],
largeSidebar:_modules_largeSidebar__WEBPACK_IMPORTED_MODULE_2__["default"],
compactSidebar:_modules_compactSidebar__WEBPACK_IMPORTED_MODULE_3__["default"],
config:_modules_config__WEBPACK_IMPORTED_MODULE_4__["default"]}});



/***/},

/***/"./resources/src/store/modules/auth.js":
/*!*********************************************!*\
  !*** ./resources/src/store/modules/auth.js ***!
  \*********************************************/
/*! exports provided: default */
/***/function resourcesSrcStoreModulesAuthJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _babel_runtime_regenerator__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! @babel/runtime/regenerator */"./node_modules/@babel/runtime/regenerator/index.js");
/* harmony import */var _babel_runtime_regenerator__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(_babel_runtime_regenerator__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_1___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */var vuex__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! vuex */"./node_modules/vuex/dist/vuex.esm.js");
/* harmony import */var axios__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(/*! axios */"./node_modules/axios/index.js");
/* harmony import */var axios__WEBPACK_IMPORTED_MODULE_3___default=/*#__PURE__*/__webpack_require__.n(axios__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */var _router__WEBPACK_IMPORTED_MODULE_4__=__webpack_require__(/*! ./../../router */"./resources/src/router.js");


function asyncGeneratorStep(gen,resolve,reject,_next,_throw,key,arg){try{var info=gen[key](arg);var value=info.value;}catch(error){reject(error);return;}if(info.done){resolve(value);}else {Promise.resolve(value).then(_next,_throw);}}

function _asyncToGenerator(fn){return function(){var self=this,args=arguments;return new Promise(function(resolve,reject){var gen=fn.apply(self,args);function _next(value){asyncGeneratorStep(gen,resolve,reject,_next,_throw,"next",value);}function _throw(err){asyncGeneratorStep(gen,resolve,reject,_next,_throw,"throw",err);}_next(undefined);});};}


// import VueCookie from 'vue-cookie'



vue__WEBPACK_IMPORTED_MODULE_1___default.a.use(vuex__WEBPACK_IMPORTED_MODULE_2__["default"]);// Vue.use(VueCookie)

var state={
// token: Vue.cookie.get('Stocky_token'),
isAuthenticated:false,
Permissions:null,
user:{},
loading:false,
error:null,
notifs:0};

var getters={
isAuthenticated:function isAuthenticated(state){
return state.isAuthenticated;
},
currentUser:function currentUser(state){
return state.user;
},
currentUserPermissions:function currentUserPermissions(state){
return state.Permissions;
},
loading:function loading(state){
return state.loading;
},
notifs_alert:function notifs_alert(state){
return state.notifs;
},
error:function error(state){
return state.error;
}};

var mutations={
setLoading:function setLoading(state,data){
state.loading=data;
state.error=null;
},
setError:function setError(state,data){
state.error=data;
state.loggedInUser=null;
state.loading=false;
},
clearError:function clearError(state){
state.error=null;
},
// setLoginCred(state, payload) {
//     state.token = payload.token;
//     // state.isAuthenticated = true;
// },
setPermissions:function setPermissions(state,Permissions){
state.Permissions=Permissions;// state.user = user;
},
setUser:function setUser(state,user){
state.user=user;
},
// SET_AUTHENTICATED(state, isAuthenticated) {
//     state.isAuthenticated = isAuthenticated;
// },
Notifs_alert:function Notifs_alert(state,notifs){
state.notifs=notifs;
},
logout:function logout(state){
// state.token = null;
state.user=null;
state.Permissions=null;// state.isAuthenticated = false;
// Vue.cookie.delete('Stocky_token');

state.loggedInUser=null;
state.loading=false;
state.error=null;
}};

var actions={
// setLoginCred(context, payload) {
//     context.commit('setLoading', true)
//     context.commit('setLoginCred', payload)
// },
refreshUserPermissions:function refreshUserPermissions(context){
return _asyncToGenerator(/*#__PURE__*/_babel_runtime_regenerator__WEBPACK_IMPORTED_MODULE_0___default.a.mark(function _callee(){
return _babel_runtime_regenerator__WEBPACK_IMPORTED_MODULE_0___default.a.wrap(function _callee$(_context){
while(1){
switch(_context.prev=_context.next){
case 0:
_context.next=2;
return axios__WEBPACK_IMPORTED_MODULE_3___default.a.get("GetUserAuth").then(function(userAuth){
var Permissions=userAuth.data.permissions;
var user=userAuth.data.user;
var notifs=userAuth.data.notifs;// context.commit('SET_AUTHENTICATED', true)

// context.commit('SET_AUTHENTICATED', true)
context.commit('setPermissions',Permissions);
context.commit('setUser',user);
context.commit('Notifs_alert',notifs);
})["catch"](function(){
// context.commit('SET_AUTHENTICATED', false)
context.commit('setPermissions',null);
context.commit('setUser',null);
context.commit('Notifs_alert',null);
});

case 2:
case"end":
return _context.stop();}

}
},_callee);
}))();
},
logout:function logout(_ref){
var commit=_ref.commit;
axios__WEBPACK_IMPORTED_MODULE_3___default()({
method:'post',
url:'/logout',
baseURL:''}).
then(function(userData){
window.location.href='/login';
});
}};

/* harmony default export */__webpack_exports__["default"]={
state:state,
getters:getters,
actions:actions,
mutations:mutations};


/***/},

/***/"./resources/src/store/modules/compactSidebar.js":
/*!*******************************************************!*\
  !*** ./resources/src/store/modules/compactSidebar.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/function resourcesSrcStoreModulesCompactSidebarJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var state={
compactSidebarToggleProperties:{
isSideNavOpen:true,
isActiveSecondarySideNav:false},

compactLeftSideBarBgColor:"sidebar-dark-purple"};

var getters={
getCompactSideBarToggleProperties:function getCompactSideBarToggleProperties(state){
return state.compactSidebarToggleProperties;
},
getcompactLeftSideBarBgColor:function getcompactLeftSideBarBgColor(state){
return state.compactLeftSideBarBgColor;
}};

var actions={
changeCompactSidebarProperties:function changeCompactSidebarProperties(_ref){
var commit=_ref.commit;
commit("toggleCompactSidebarProperties");
},
changecompactLeftSideBarBgColor:function changecompactLeftSideBarBgColor(_ref2,data){
var commit=_ref2.commit;
commit("togglecompactLeftSideBarBgColor",data);
}};

var mutations={
toggleCompactSidebarProperties:function toggleCompactSidebarProperties(state){
return state.compactSidebarToggleProperties.isSideNavOpen=!state.compactSidebarToggleProperties.isSideNavOpen;
},
togglecompactLeftSideBarBgColor:function togglecompactLeftSideBarBgColor(state,data){
state.compactLeftSideBarBgColor=data;
}};

/* harmony default export */__webpack_exports__["default"]={
state:state,
getters:getters,
actions:actions,
mutations:mutations};


/***/},

/***/"./resources/src/store/modules/config.js":
/*!***********************************************!*\
  !*** ./resources/src/store/modules/config.js ***!
  \***********************************************/
/*! exports provided: default */
/***/function resourcesSrcStoreModulesConfigJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var state={
themeMode:{
dark:false,
light:true,
semi_dark:false,
theme_color:'lite-purple',
layout:'large-sidebar',
rtl:false}};


var getters={
getThemeMode:function getThemeMode(state){
return state.themeMode;
}};

var actions={
changeThemeMode:function changeThemeMode(_ref){
var commit=_ref.commit;
commit('toggleThemeMode');
},
changeThemeLayout:function changeThemeLayout(_ref2,data){
var commit=_ref2.commit;
commit('toggleThemeLayout',data);
},
changeThemeRtl:function changeThemeRtl(_ref3){
var commit=_ref3.commit;
commit('toggleThemeRtl');
}};

var mutations={
toggleThemeMode:function toggleThemeMode(state){
state.themeMode.dark=!state.themeMode.dark;
},
toggleThemeLayout:function toggleThemeLayout(state,data){
state.themeMode.layout=data;
},
toggleThemeRtl:function toggleThemeRtl(state){
state.themeMode.rtl=!state.themeMode.rtl;
}};

/* harmony default export */__webpack_exports__["default"]={
state:state,
getters:getters,
actions:actions,
mutations:mutations};


/***/},

/***/"./resources/src/store/modules/language.js":
/*!*************************************************!*\
  !*** ./resources/src/store/modules/language.js ***!
  \*************************************************/
/*! exports provided: default */
/***/function resourcesSrcStoreModulesLanguageJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! vue */"./node_modules/vue/dist/vue.common.js");
/* harmony import */var vue__WEBPACK_IMPORTED_MODULE_0___default=/*#__PURE__*/__webpack_require__.n(vue__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */var vue_localstorage__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! vue-localstorage */"./node_modules/vue-localstorage/dist/vue-local-storage.js");
/* harmony import */var vue_localstorage__WEBPACK_IMPORTED_MODULE_1___default=/*#__PURE__*/__webpack_require__.n(vue_localstorage__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */var _translations__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ../../translations */"./resources/src/translations/index.js");



vue__WEBPACK_IMPORTED_MODULE_0___default.a.use(vue_localstorage__WEBPACK_IMPORTED_MODULE_1___default.a);
var supportedLanguages=Object.getOwnPropertyNames(_translations__WEBPACK_IMPORTED_MODULE_2__["default"]);
/* harmony default export */__webpack_exports__["default"]={
namespaced:true,
state:{
language:vue__WEBPACK_IMPORTED_MODULE_0___default.a.localStorage.get('language')},

mutations:{
SET_LANGUAGE:function SET_LANGUAGE(state,lang){
vue__WEBPACK_IMPORTED_MODULE_0___default.a.localStorage.set('language',lang);
state.language=lang;
}},

actions:{
setLanguage:function setLanguage(_ref,languages){
var commit=_ref.commit;

if(typeof languages==='string'){
commit('SET_LANGUAGE',languages);
}else {
var language=supportedLanguages.find(function(sl){
return languages.find(function(l){
return l.split(new RegExp(sl,'gi')).length-1>0?sl:null;
});
});
commit('SET_LANGUAGE',language);
}
}}};



/***/},

/***/"./resources/src/store/modules/largeSidebar.js":
/*!*****************************************************!*\
  !*** ./resources/src/store/modules/largeSidebar.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/function resourcesSrcStoreModulesLargeSidebarJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var state={
sidebarToggleProperties:{
isSideNavOpen:true,
isSecondarySideNavOpen:false,
isActiveSecondarySideNav:false}};


var getters={
getSideBarToggleProperties:function getSideBarToggleProperties(state){
return state.sidebarToggleProperties;
}};

var actions={
changeSidebarProperties:function changeSidebarProperties(_ref){
var commit=_ref.commit;
commit("toggleSidebarProperties");
},
changeSecondarySidebarProperties:function changeSecondarySidebarProperties(_ref2){
var commit=_ref2.commit;
commit("toggleSecondarySidebarProperties");
},
changeSecondarySidebarPropertiesViaMenuItem:function changeSecondarySidebarPropertiesViaMenuItem(_ref3,data){
var commit=_ref3.commit;
commit("toggleSecondarySidebarPropertiesViaMenuItem",data);
},
changeSecondarySidebarPropertiesViaOverlay:function changeSecondarySidebarPropertiesViaOverlay(_ref4){
var commit=_ref4.commit;
commit("toggleSecondarySidebarPropertiesViaOverlay");
}};

var mutations={
toggleSidebarProperties:function toggleSidebarProperties(state){
return state.sidebarToggleProperties.isSideNavOpen=!state.sidebarToggleProperties.isSideNavOpen;
},
toggleSecondarySidebarProperties:function toggleSecondarySidebarProperties(state){
return state.sidebarToggleProperties.isSecondarySideNavOpen=!state.sidebarToggleProperties.isSecondarySideNavOpen;
},
toggleSecondarySidebarPropertiesViaMenuItem:function toggleSecondarySidebarPropertiesViaMenuItem(state,data){
state.sidebarToggleProperties.isSecondarySideNavOpen=data;
state.sidebarToggleProperties.isActiveSecondarySideNav=data;
},
toggleSecondarySidebarPropertiesViaOverlay:function toggleSecondarySidebarPropertiesViaOverlay(state){
state.sidebarToggleProperties.isSecondarySideNavOpen=!state.sidebarToggleProperties.isSecondarySideNavOpen;
}};

/* harmony default export */__webpack_exports__["default"]={
state:state,
getters:getters,
actions:actions,
mutations:mutations};


/***/},

/***/"./resources/src/translations/index.js":
/*!*********************************************!*\
  !*** ./resources/src/translations/index.js ***!
  \*********************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsIndexJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
/* harmony import */var _locales_en__WEBPACK_IMPORTED_MODULE_0__=__webpack_require__(/*! ./locales/en */"./resources/src/translations/locales/en.js");
/* harmony import */var _locales_fr__WEBPACK_IMPORTED_MODULE_1__=__webpack_require__(/*! ./locales/fr */"./resources/src/translations/locales/fr.js");
/* harmony import */var _locales_ar__WEBPACK_IMPORTED_MODULE_2__=__webpack_require__(/*! ./locales/ar */"./resources/src/translations/locales/ar.js");
/* harmony import */var _locales_de__WEBPACK_IMPORTED_MODULE_3__=__webpack_require__(/*! ./locales/de */"./resources/src/translations/locales/de.js");
/* harmony import */var _locales_es__WEBPACK_IMPORTED_MODULE_4__=__webpack_require__(/*! ./locales/es */"./resources/src/translations/locales/es.js");
/* harmony import */var _locales_it__WEBPACK_IMPORTED_MODULE_5__=__webpack_require__(/*! ./locales/it */"./resources/src/translations/locales/it.js");
/* harmony import */var _locales_Ind__WEBPACK_IMPORTED_MODULE_6__=__webpack_require__(/*! ./locales/Ind */"./resources/src/translations/locales/Ind.js");
/* harmony import */var _locales_thai__WEBPACK_IMPORTED_MODULE_7__=__webpack_require__(/*! ./locales/thai */"./resources/src/translations/locales/thai.js");
/* harmony import */var _locales_tr_ch__WEBPACK_IMPORTED_MODULE_8__=__webpack_require__(/*! ./locales/tr_ch */"./resources/src/translations/locales/tr_ch.js");
/* harmony import */var _locales_sm_ch__WEBPACK_IMPORTED_MODULE_9__=__webpack_require__(/*! ./locales/sm_ch */"./resources/src/translations/locales/sm_ch.js");
/* harmony import */var _locales_tur__WEBPACK_IMPORTED_MODULE_10__=__webpack_require__(/*! ./locales/tur */"./resources/src/translations/locales/tur.js");
/* harmony import */var _locales_ru__WEBPACK_IMPORTED_MODULE_11__=__webpack_require__(/*! ./locales/ru */"./resources/src/translations/locales/ru.js");
/* harmony import */var _locales_hn__WEBPACK_IMPORTED_MODULE_12__=__webpack_require__(/*! ./locales/hn */"./resources/src/translations/locales/hn.js");
/* harmony import */var _locales_vn__WEBPACK_IMPORTED_MODULE_13__=__webpack_require__(/*! ./locales/vn */"./resources/src/translations/locales/vn.js");














/* harmony default export */__webpack_exports__["default"]={
en:_locales_en__WEBPACK_IMPORTED_MODULE_0__["default"],
fr:_locales_fr__WEBPACK_IMPORTED_MODULE_1__["default"],
ar:_locales_ar__WEBPACK_IMPORTED_MODULE_2__["default"],
de:_locales_de__WEBPACK_IMPORTED_MODULE_3__["default"],
es:_locales_es__WEBPACK_IMPORTED_MODULE_4__["default"],
it:_locales_it__WEBPACK_IMPORTED_MODULE_5__["default"],
Ind:_locales_Ind__WEBPACK_IMPORTED_MODULE_6__["default"],
thai:_locales_thai__WEBPACK_IMPORTED_MODULE_7__["default"],
tr_ch:_locales_tr_ch__WEBPACK_IMPORTED_MODULE_8__["default"],
sm_ch:_locales_sm_ch__WEBPACK_IMPORTED_MODULE_9__["default"],
tur:_locales_tur__WEBPACK_IMPORTED_MODULE_10__["default"],
ru:_locales_ru__WEBPACK_IMPORTED_MODULE_11__["default"],
hn:_locales_hn__WEBPACK_IMPORTED_MODULE_12__["default"],
vn:_locales_vn__WEBPACK_IMPORTED_MODULE_13__["default"]};


/***/},

/***/"./resources/src/translations/locales/Ind.js":
/*!***************************************************!*\
  !*** ./resources/src/translations/locales/Ind.js ***!
  \***************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesIndJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Indonesian
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Jumlah yang Diterima',
Paying_Amount:'Membayar Jumlah',
Change:'Mengubah',
Paying_amount_is_greater_than_Received_amount:'Jumlah pembayaran lebih besar dari jumlah yang diterima',
Paying_amount_is_greater_than_Grand_Total:'Jumlah pembayaran lebih besar dari total keseluruhan',
code_must_be_not_exist_already:'kode harus belum ada',
You_will_find_your_backup_on:'Anda akan menemukan cadangan Anda di',
and_save_it_to_your_pc:'dan simpan ke pc Anda',
Scan_your_barcode_and_select_the_correct_symbology_below:'Pindai kode batang Anda dan pilih simbologi yang benar di bawah ini',
Scan_Search_Product_by_Code_Name:'Pindai/Cari Produk dengan Nama Kode',
Paper_size:'Ukuran kertas',
Clear_Cache:'Hapus Cache',
Cache_cleared_successfully:'Cache berhasil dibersihkan',
Failed_to_clear_cache:'Gagal menghapus cache',
Scan_Barcode:'Pemindai kode batang',
Please_use_short_name_of_unit:'Silakan gunakan nama pendek unit',
DefaultCustomer:'Pelanggan Default',
DefaultWarehouse:'Gudang Bawaan',
Payment_Gateway:'Payment Gateway',
SMS_Configuration:'Konfigurasi SMS',
Gateway:'Payment Gateway',
Choose_Gateway:'Pilih Payment Gateway',
Send_SMS:'Pesan berhasil dikirim',
sms_config_invalid:'konfigurasi sms salah tidak valid',
Remove_Stripe_Key_Secret:'Hapus kunci API Stripe',
credit_card_account_not_available:'Rekening kartu kredit tidak tersedia',
Credit_Card_Info:'Info Kartu Kredit',
developed_by:'Dikembangkan oleh',
Unit_already_linked_with_sub_unit:'Unit sudah terhubung dengan sub unit',
Total_Items_Quantity:'Total Item dan Kuantitas',
Value_by_Cost_and_Price:'Nilai berdasarkan Biaya dan Harga',
Search_this_table:'Cari tabel ini',
import_products:'Produk impor',
Field_optional:'Bidang opsional',
Download_exemple:'Unduh contoh',
field_must_be_in_csv_format:'Bidang harus dalam format csv',
Successfully_Imported:'Berhasil Diimpor',
file_size_must_be_less_than_1_mega:'Ukuran file harus kurang dari 1 mega',
Please_follow_the_import_instructions:'Harap ikuti petunjuk impor',
must_be_exist:'unit harus sudah dibuat',
Import_Customers:'Impor Pelanggan',
Import_Suppliers:'Pemasok Impor',
Recent_Sales:'Penjualan Terbaru',
Create_Transfer:'Buat Transfer',
order_products:'Item pesanan',
Search_Product_by_Code_Name:'Cari Produk dengan Kode atau Nama',
Reports_payments_Purchase_Return:'Melaporkan Pembayaran Pengembalian Pembelian',
Reports_payments_Sale_Return:'Laporan Pembayaran Retur Penjualan',
payments_Sales_Return:'Pembayaran retur penjualan',
payments_Purchases_Return:'Pembayaran pembelian kembali',
CreateSaleReturn:'Buat Retur Penjualan',
EditSaleReturn:'Edit Pengembalian Penjualan',
SalesReturn:'Retur Penjualan',
CreatePurchaseReturn:'Buat Pengembalian Pembelian',
EditPurchaseReturn:'Edit Pengembalian Pembelian',
PurchasesReturn:'Pembelian Kembali',
Due:'jatuh tempo',
Profit:'Keuntungan',
Revenue:'Pendapatan',
Sales_today:'Penjualan hari ini',
People:'Orang-orang',
Successfully_Created:'Berhasil Dibuat',
Successfully_Updated:'Berhasil diperbaharui',
Success:'sukses',
Failed:'Gagal',
Warning:'Peringatan',
Please_fill_the_form_correctly:'Harap isi formulir dengan benar',
Field_is_required:'Bidang wajib diisi',
Error:'Kesalahan!',
you_are_not_authorized:'Maaf! Anda tidak berwenang.',
Go_back_to_home:'Kembali ke beranda',
page_not_exist:'Maaf! Halaman yang Anda cari tidak ada.',
Choose_Status:'Pilih status',
Choose_Method:'Pilih Metode',
Choose_Symbology:'Pilih simbologi',
Choose_Category:'Pilih Kategori',
Choose_Customer:'Pilih Pelanggan',
Choose_Supplier:'Pilih Pemasok',
Choose_Unit_Purchase:'Pilih Unit Pembelian',
Choose_Sub_Category:'Pilih Subkategori',
Choose_Brand:'Pilih Merek',
Choose_Warehouse:'Pilih Gudang',
Choose_Unit_Sale:'Pilih Unit Penjualan',
Enter_Product_Cost:'Masukkan Biaya Produk',
Enter_Stock_alert:'Masuk ke Stock alert',
Choose_Unit_Product:'Pilih Unit Produk',
Enter_Product_Price:'Masukkan Harga Produk',
Enter_Name_Product:'Masukkan Nama Produk',
Enter_Role_Name:'Masukkan Nama Peran',
Enter_Role_Description:'Masukkan Deskripsi Peran',
Enter_name_category:'Masukkan Nama kategori',
Enter_Code_category:'Masukkan Kode kategori',
Enter_Name_Brand:'Masukkan Nama Merek',
Enter_Description_Brand:'Masukkan Deskripsi Merek',
Enter_Code_Currency:'Masukkan Mata Uang Kode',
Enter_name_Currency:'Masukkan nama Mata uang',
Enter_Symbol_Currency:'Masukkan Mata Uang Simbol',
Enter_Name_Unit:'Masukkan Nama Unit',
Enter_ShortName_Unit:'Masukkan Unit nama pendek',
Choose_Base_Unit:'Pilih Unit Dudukan',
Choose_Operator:'Pilih Operator',
Enter_Operation_Value:'Masukkan Nilai Operasi',
Enter_Name_Warehouse:'Masukkan Nama Gudang',
Enter_Phone_Warehouse:'Masukkan Telepon Gudang',
Enter_Country_Warehouse:'Masukkan Negara Gudang',
Enter_City_Warehouse:'Masuk kota gudang',
Enter_Email_Warehouse:'Masukkan email Gudang',
Enter_ZipCode_Warehouse:'Masukkan Kode Pos Gudang',
Choose_Currency:'Pilih mata uang',
Thank_you_for_your_business:'Terima kasih atas bisnis Anda!',
Cancel:'Membatalkan',
New_Customer:'Pelanggan baru',
Incorrect_Login:'Login Salah',
Successfully_Logged_In:'Berhasil Masuk',
This_user_not_active:'Pengguna ini tidak aktif',
SignIn:'Masuk',
Create_an_account:'Buat sebuah akun',
Forgot_Password:'Tidak ingat kata sandi ?',
Email_Address:'Alamat email',
SignUp:'Daftar',
Already_have_an_account:'Sudah memiliki akun ?',
Reset_Password:'Setel Ulang Kata Sandi',
Failed_to_authenticate_on_SMTP_server:'Gagal mengautentikasi di server SMTP',
We_cant_find_a_user_with_that_email_addres:'Kami tidak dapat menemukan pengguna dengan alamat email itu',
We_have_emailed_your_password_reset_link:'Kami telah mengirimkan email tautan pengaturan ulang kata sandi Anda',
Please_fill_the_Email_Adress:'Silahkan isi Alamat Email',
Confirm_password:'Setujui password',
Your_Password_has_been_changed:'Kata sandi Anda telah diubah',
The_password_confirmation_does_not_match:'Konfirmasi kata sandi tidak cocok',
This_password_reset_token_is_invalid:'Token penyetelan ulang sandi ini tidak valid',
Warehouse_report:'Laporan gudang',
All_Warehouses:'Semua Gudang',
Expense_List:'Daftar Biaya',
Expenses:'Beban',
This_Week_Sales_Purchases:'Penjualan & Pembelian Minggu Ini',
Top_Selling_Products:'Produk Terlaris',
View_all:'Lihat semua',
Payment_Sent_Received:'Pembayaran Dikirim & Diterima',
Filter:'Saring',
Invoice_POS:'POS Faktur',
Invoice:'Faktur',
Customer_Info:'Info Pelanggan',
Company_Info:'Info perusahaan',
Invoice_Info:'Info Faktur',
Order_Summary:'Ringkasan Pesanan',
Quote_Info:'Info Kutipan',
Del:'Menghapus',
SuppliersPaiementsReport:'Laporan Pembayaran Pemasok',
Purchase_Info:'Beli Info',
Supplier_Info:'Info Pemasok',
Return_Info:'info Kembali',
Expense_Category:'Kategori Biaya',
Create_Expense:'Buat Beban',
Details:'rincian',
Discount_Method:'Metode Diskon',
Net_Unit_Cost:'Biaya Satuan Net',
Net_Unit_Price:'Harga Satuan Bersih',
Edit_Expense:'Edit Biaya',
All_Brand:'Semua Merek',
All_Category:'Semua Kategori',
ListExpenses:'Daftar Biaya',
Create_Permission:'Buat Izin',
Edit_Permission:'Edit Izin',
Reports_payments_Sales:'Laporan pembayaran Penjualan',
Reports_payments_Purchases:'Melaporkan pembayaran Pembelian',
Reports_payments_Return_Customers:'Laporan pembayaran Retur Pelanggan',
Reports_payments_Return_Suppliers:'Laporan pembayaran Kembali Pemasok',
Expense_Deleted:'Pengeluaran ini telah dihapus',
Expense_Updated:'Biaya ini telah Diperbarui',
Expense_Created:'Pengeluaran Ini Telah Dibuat',
DemoVersion:'Anda tidak dapat melakukan ini di versi demo',
OrderStatistics:'Statistik Penjualan',
AlreadyAdd:'Produk Ini Sudah Ditambahkan !!',
AddProductToList:'Silakan Tambahkan Produk Ke Daftar !!',
AddQuantity:'Tambahkan jumlah Detail !!',
InvalidData:'Data Tidak Valid !!',
LowStock:'kuantitas melebihi kuantitas yang tersedia dalam stok',
WarehouseIdentical:'Kedua gudang itu tidak mungkin sama !!',
VariantDuplicate:'Varian Ini Duplikat !!',
Filesize:'Ukuran file',
GenerateBackup:'Hasilkan Cadangan',
BackupDatabase:'Database cadangan',
Backup:'Cadangan',
Paid:'Dibayar',
Unpaid:'Belum dibayar',
Today:'Hari ini',
Income:'Pendapatan'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Beban'),_defineProperty(_Received_Amount$Payi,"Sale",'Penjualan'),_defineProperty(_Received_Amount$Payi,"Actif",'Aktif'),_defineProperty(_Received_Amount$Payi,"Inactif",'Tidak aktif'),_defineProperty(_Received_Amount$Payi,"Customers",'Pelanggan'),_defineProperty(_Received_Amount$Payi,"Phone",'Telepon'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Cari lewat Telepon'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Pemasok'),_defineProperty(_Received_Amount$Payi,"Quotations",'Kutipan'),_defineProperty(_Received_Amount$Payi,"Sales",'Penjualan'),_defineProperty(_Received_Amount$Payi,"Purchases",'Pembelian'),_defineProperty(_Received_Amount$Payi,"Returns",'Kembali'),_defineProperty(_Received_Amount$Payi,"Settings",'Pengaturan'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'Pengaturan sistem'),_defineProperty(_Received_Amount$Payi,"Users",'Pengguna'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Izin Grup'),_defineProperty(_Received_Amount$Payi,"Currencies",'Mata Uang'),_defineProperty(_Received_Amount$Payi,"Warehouses",'Gudang'),_defineProperty(_Received_Amount$Payi,"Units",'Unit'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",' Pembelian Unit'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Unit Penjualan'),_defineProperty(_Received_Amount$Payi,"Reports",'Laporan'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Laporan Pembayaran'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Pembelian Pembayaran'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Pembayaran Penjualan'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Laba rugi'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Grafik Stok Gudang'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Laporan penjualan'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Laporan Pembelian'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Laporan Pelanggan'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Laporan Pemasok'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Laporan Pemasok'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Data Penjualan Harian'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Data Pembelian Harian'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Lima rekor terakhir'),_defineProperty(_Received_Amount$Payi,"Filters",'Filter'),_defineProperty(_Received_Amount$Payi,"date",'tanggal'),_defineProperty(_Received_Amount$Payi,"Reference",'Referensi'),_defineProperty(_Received_Amount$Payi,"Supplier",'Pemasok'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Status pembayaran'),_defineProperty(_Received_Amount$Payi,"Customer",'Pelanggan'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Kode pelanggan'),_defineProperty(_Received_Amount$Payi,"Status",'Status'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Kode penyuplai'),_defineProperty(_Received_Amount$Payi,"Categorie",'Kategori'),_defineProperty(_Received_Amount$Payi,"Categories",'Kategori'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Transfer Saham'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Manajemen Stok'),_defineProperty(_Received_Amount$Payi,"dashboard",'Dasbor'),_defineProperty(_Received_Amount$Payi,"Products",'Produk'),_defineProperty(_Received_Amount$Payi,"productsList",'Daftar produk'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Manajemen Produk'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Peringatan Kuantitas Produk'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Kode Produk'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Pajak Produk'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'Subkategori'),_defineProperty(_Received_Amount$Payi,"Name_product",'Penunjukan'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Peringatan Stok'),_defineProperty(_Received_Amount$Payi,"warehouse",'gudang'),_defineProperty(_Received_Amount$Payi,"Tax",'Pajak'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Harga beli'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Harga jual'),_defineProperty(_Received_Amount$Payi,"Quantity",'Kuantitas'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Penjualan Unit'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Pembelian Unit'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Manajemen Mata Uang'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Kode mata uang'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Nama Mata Uang'),_defineProperty(_Received_Amount$Payi,"Symbol",'Simbol'),_defineProperty(_Received_Amount$Payi,"All",'Semua'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Edit Produk'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Cari berdasarkan Kode'),_defineProperty(_Received_Amount$Payi,"SearchByName",'Cari berdasarkan nama'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'Rincian Produk'),_defineProperty(_Received_Amount$Payi,"CustomerName",'Nama Pelanggan'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Manajemen pelanggan'),_defineProperty(_Received_Amount$Payi,"Add",'Membuat'),_defineProperty(_Received_Amount$Payi,"add",'Membuat'),_defineProperty(_Received_Amount$Payi,"Edit",'Edit'),_defineProperty(_Received_Amount$Payi,"Close",'Menutup'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Silahkan pilih'),_defineProperty(_Received_Amount$Payi,"Action",'Tindakan'),_defineProperty(_Received_Amount$Payi,"Email",'Surel'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Edit Pelanggan'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Buat Pelanggan'),_defineProperty(_Received_Amount$Payi,"Country",'Negara'),_defineProperty(_Received_Amount$Payi,"City",'Kota'),_defineProperty(_Received_Amount$Payi,"Adress",'Alamat'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'detil pelanggan'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Daftar Pelanggan'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Kode penyuplai'),_defineProperty(_Received_Amount$Payi,"SupplierName",'nama pemasok'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Manajemen Pemasok'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Detail Pemasok'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Manajemen Kutipan'),_defineProperty(_Received_Amount$Payi,"SubTotal",'Subtotal'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Jumlah tersisa'),_defineProperty(_Received_Amount$Payi,"complete",'lengkap'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'tertunda'),_defineProperty(_Received_Amount$Payi,"Recu",'Diterima'),_defineProperty(_Received_Amount$Payi,"partial",'Sebagian'),_defineProperty(_Received_Amount$Payi,"Retournee",'Kembali'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Detail kutipan'),_defineProperty(_Received_Amount$Payi,"EditQuote",'Edit Kutipan'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Buat Penjualan'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'Unduh PDF'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'Kutipan Terkirim di Email'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'Hapus Kutipan'),_defineProperty(_Received_Amount$Payi,"AddQuote",'Buat Kutipan'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Pilih Produk'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Produk (Kode - Nama)'),_defineProperty(_Received_Amount$Payi,"Price",'Harga'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'persediaan'),_defineProperty(_Received_Amount$Payi,"Total",'Total'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'Biaya unit'),_defineProperty(_Received_Amount$Payi,"to",'ke'),_defineProperty(_Received_Amount$Payi,"Subject",'Subyek'),_defineProperty(_Received_Amount$Payi,"Message",'Pesan'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'Email Pelanggan'),_defineProperty(_Received_Amount$Payi,"Sent",'Kirim'),_defineProperty(_Received_Amount$Payi,"Quote",'Kutipan'),_defineProperty(_Received_Amount$Payi,"Hello",'Halo'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Silakan temukan lampiran untuk Quotation Anda'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Tambahkan Produk ke Daftar Pesanan'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Pilih gudang'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'silahkan Pilih Pelanggan'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Manajemen penjualan'),_defineProperty(_Received_Amount$Payi,"Balance",'Keseimbangan'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Kuantitas Kembali'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Total Pengembalian'),_defineProperty(_Received_Amount$Payi,"Amount",'Jumlah'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Detail penjualan'),_defineProperty(_Received_Amount$Payi,"EditSale",'Edit Obral'),_defineProperty(_Received_Amount$Payi,"AddSale",'Buat Penjualan'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Tunjukkan Pembayaran'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Buat Pembayaran'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Edit Pembayaran'),_defineProperty(_Received_Amount$Payi,"EmailSale",'Kirim Obral melalui Email'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Hapus Obral'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Dibayar oleh'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Pilihan pembayaran'),_defineProperty(_Received_Amount$Payi,"Note",'Catatan'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Pembayaran selesai!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Manajemen Pembelian'),_defineProperty(_Received_Amount$Payi,"Ordered",'Dipesan'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Hapus Pembelian'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Kirim Pembelian melalui Email'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Edit Pembelian'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Detail pembelian'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Buat Pembelian'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Email Pemasok'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Membeli pembayaran'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Membeli data pembayaran'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'Pembayaran penjualan'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Data pembayaran penjualan'),_defineProperty(_Received_Amount$Payi,"UserManagement",'manajemen pengguna'),_defineProperty(_Received_Amount$Payi,"Firstname",'Nama depan'),_defineProperty(_Received_Amount$Payi,"lastname",'nama keluarga'),_defineProperty(_Received_Amount$Payi,"username",'Nama pengguna'),_defineProperty(_Received_Amount$Payi,"password",'Kata sandi'),_defineProperty(_Received_Amount$Payi,"Newpassword",'Kata sandi baru'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Mengubah avatar'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Harap kosongkan bidang ini jika Anda belum mengubahnya'),_defineProperty(_Received_Amount$Payi,"type",'Tipe'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Izin Pengguna'),_defineProperty(_Received_Amount$Payi,"RoleName",'Wewenang'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Deskripsi peran'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'Buat Izin'),_defineProperty(_Received_Amount$Payi,"View",'Melihat'),_defineProperty(_Received_Amount$Payi,"Del",'Menghapus'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'Penyesuaian Baru'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Edit Penyesuaian'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'Anda tidak dapat mengurangi produk yang memiliki stok 0'),_defineProperty(_Received_Amount$Payi,"Addition",'Tambahan'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Pengurangan'),_defineProperty(_Received_Amount$Payi,"profil",'profil'),_defineProperty(_Received_Amount$Payi,"logout",'keluar'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'Anda tidak dapat mengubah karena Pembelian ini sudah dibayar'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'Anda tidak dapat mengubah karena Obral ini sudah dibayar'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'Anda tidak dapat mengubah karena Pengembalian ini sudah dibayar'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'Kutipan ini sudah menghasilkan penjualan'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Buat produk'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'Kutipan Ini Lengkap'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Konfigurasi Situs'),_defineProperty(_Received_Amount$Payi,"Language",'Bahasa'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'Mata Uang Default'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Masuk Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Default Email'),_defineProperty(_Received_Amount$Payi,"SiteName",'Nama situs'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Ubah Logo'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'Konfigurasi SMTP'),_defineProperty(_Received_Amount$Payi,"HOST",'TUAN RUMAH'),_defineProperty(_Received_Amount$Payi,"PORT",'PELABUHAN'),_defineProperty(_Received_Amount$Payi,"encryption",'Enkripsi'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'Konfigurasi SMTP Salah'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Pembayaran Kembali'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'Mengembalikan Faktur'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'Mengembalikan Data Faktur'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Tampilkan semua catatan dari semua Pengguna'),_defineProperty(_Received_Amount$Payi,"Discount",'Diskon'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Pajak Pesanan'),_defineProperty(_Received_Amount$Payi,"Shipping",'pengiriman'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Nama Perusahaan'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Telepon Perusahaan'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'Alamat perusahaan'),_defineProperty(_Received_Amount$Payi,"Code",'Kode'),_defineProperty(_Received_Amount$Payi,"image",'gambar'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'Cetak kode batang'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'Mengembalikan Pelanggan'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'Pengembalian Pemasok'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'Kembalikan Faktur Pelanggan'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'Faktur Pemasok Kembali'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'Tidak ada data yang tersedia'),_defineProperty(_Received_Amount$Payi,"ProductImage",'gambar produk'),_defineProperty(_Received_Amount$Payi,"Barcode",'Barcode'),_defineProperty(_Received_Amount$Payi,"pointofsales",'titik Penjualan'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Unggah Ubahsuaian'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'Point of Sale Management'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Pengaturan'),_defineProperty(_Received_Amount$Payi,"Updat",'Memperbarui'),_defineProperty(_Received_Amount$Payi,"Reset",'Setel ulang'),_defineProperty(_Received_Amount$Payi,"print",'Mencetak'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'Cari Melalui Email'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Choose Product'),_defineProperty(_Received_Amount$Payi,"Qty",'Jml'),_defineProperty(_Received_Amount$Payi,"Items",'Item'),_defineProperty(_Received_Amount$Payi,"AmountHT",'Jumlah'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'jumlah total'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Silakan Pilih Pemasok'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Silakan Pilih Status'),_defineProperty(_Received_Amount$Payi,"PayeBy",'Dibayar oleh'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Pilih Gudang'),_defineProperty(_Received_Amount$Payi,"payNow",'Bayar sekarang'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'Daftar Kategori'),_defineProperty(_Received_Amount$Payi,"Description",'Deskripsi'),_defineProperty(_Received_Amount$Payi,"submit",'Kirimkan'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'Terjadi masalah saat membuat Faktur ini. Silakan coba lagi'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'Ada masalah pembayaran. Silakan coba lagi.'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'Pendapatan & Beban'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'Penjualan & Pembelian Harian'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'Produk Kedaluwarsa'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Daftar Merek'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Buat Penyesuaian'),_defineProperty(_Received_Amount$Payi,"Afewwords",'Beberapa kata ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'Gambar Pengguna'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Perbarui Produk'),_defineProperty(_Received_Amount$Payi,"Brand",'Merek'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Simbologi Barcode'),_defineProperty(_Received_Amount$Payi,"ProductCost",'Biaya Produk'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Harga Produk'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Produk Satuan'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Metode Perpajakan'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Beberapa Gambar'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Produk Memiliki Banyak Varian'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'Produk Memiliki Promosi'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Promosi Mulai'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Promosi Berakhir'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Harga promosi'),_defineProperty(_Received_Amount$Payi,"Price",'Harga'),_defineProperty(_Received_Amount$Payi,"Cost",'Biaya'),_defineProperty(_Received_Amount$Payi,"Unit",'Satuan'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Variasi Produk'),_defineProperty(_Received_Amount$Payi,"Variant",'Varian'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Patokan harga'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'Buat Pelanggan Kembali'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'Edit Pelanggan Kembali'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'Buat Pemasok Pengembalian'),_defineProperty(_Received_Amount$Payi,"Documentation",'Dokumentasi'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'Edit Pemasok Pengembalian'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'Dari Gudang'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'Ke Gudang'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Edit Transfer'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Transfer Detail'),_defineProperty(_Received_Amount$Payi,"Pending",'tertunda'),_defineProperty(_Received_Amount$Payi,"Received",'Diterima'),_defineProperty(_Received_Amount$Payi,"Ordered",'Dipesan'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'Manajemen Izin'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Merek'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Citra Merek'),_defineProperty(_Received_Amount$Payi,"BrandName",'Nama merk'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Deskripsi Merek'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Unit dasar'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Manajemen Unit'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Nilai Operasi'),_defineProperty(_Received_Amount$Payi,"Operator",'Operator'),_defineProperty(_Received_Amount$Payi,"Top5Products",'Lima Produk Teratas'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'Lima Penjualan terakhir'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'Penyesuaian Daftar'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Daftar Transfer'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Buat Transfer'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Manajemen Pesanan'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Daftar Kutipan'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Daftar Pembelian'),_defineProperty(_Received_Amount$Payi,"ListSales",'Daftar Penjualan'),_defineProperty(_Received_Amount$Payi,"ListReturns",'Daftar Pengembalian'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'Manajemen Orang'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Apakah kamu yakin',
Text:'Anda tidak akan dapat mengembalikan ini!',
confirmButtonText:'Ya, hapus!',
cancelButtonText:'Membatalkan',
Deleted:'Dihapus!',
Failed:'Gagal!',
Therewassomethingwronge:'Ada yang salah',
CustomerDeleted:'Klien ini telah dihapus.',
SupplierDeleted:'Pemasok ini telah dihapus.',
QuoteDeleted:'Kutipan ini telah dihapus.',
SaleDeleted:'Obral ini telah dihapus.',
PaymentDeleted:'Pembayaran ini telah dihapus.',
PurchaseDeleted:'Pembelian ini telah dihapus.',
ReturnDeleted:'Pengembalian ini telah dihapus.',
ProductDeleted:'Produk ini telah dihapus.',
ClientError:'Klien ini sudah terhubung dengan Operasi lain',
ProviderError:'Pemasok ini sudah terhubung dengan Operasi lain',
UserDeleted:'Pengguna ini telah dihapus.',
UnitDeleted:'Unit ini telah dihapus.',
RoleDeleted:'Peran ini telah dihapus.',
TaxeDeleted:'Pajak ini telah dihapus.',
SubCatDeleted:'Sub Kategori ini telah dihapus.',
CatDeleted:'Kategori ini telah dihapus.',
WarehouseDeleted:'Gudang ini telah dihapus.',
AlreadyLinked:'produk ini sudah ditautkan dengan Operasi lain',
AdjustDeleted:'Penyesuaian ini telah dihapus.',
TitleCurrency:'Mata Uang ini telah dihapus.',
TitleTransfer:'Transfer berhasil dihapus',
BackupDeleted:'Cadangan berhasil dihapus',
TitleBrand:'Merek ini telah dihapus'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleProfile:'Profil Anda berhasil diperbarui',
TitleAdjust:'Penyesuaian Berhasil diperbarui',
TitleRole:'Peran berhasil diperbarui',
TitleUnit:'Unit Berhasil Diperbarui',
TitleUser:'Pengguna Berhasil Diperbarui',
TitleCustomer:'Pembaruan Pelanggan berhasil',
TitleQuote:'Kutipan Berhasil Diperbarui',
TitleSale:'Obral Berhasil Diperbarui',
TitlePayment:'Pembayaran berhasil diperbarui',
TitlePurchase:'Pembelian Berhasil Diperbarui',
TitleReturn:'Kembali Diperbarui dengan sukses',
TitleProduct:'Pembaruan Produk berhasil',
TitleSupplier:'Pemasok berhasil diperbarui',
TitleTaxe:'Pajak berhasil diperbarui',
TitleCat:'Kategori Berhasil diperbarui',
TitleWarhouse:'Gudang berhasil diperbarui',
TitleSetting:'Pengaturan Berhasil Diperbarui',
TitleCurrency:'Pembaruan Mata Uang berhasil',
TitleTransfer:'Transfer Berhasil diperbarui',
TitleBrand:'Merek ini telah diperbarui'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'Merek Ini Telah Dibuat',
TitleRole:'Peran berhasil dibuat',
TitleUnit:'Unit Berhasil Dibuat',
TitleUser:'Pengguna Berhasil Dibuat di',
TitleCustomer:'Pelanggan Dibuat dengan sukses',
TitleQuote:'Kutipan Berhasil dibuat',
TitleSale:'Penjualan Berhasil dibuat',
TitlePayment:'Pembayaran Berhasil Dibuat',
TitlePurchase:'Pembelian Berhasil dibuat',
TitleReturn:'Kembali Dibuat dengan sukses',
TitleProduct:'Produk Berhasil Dibuat di',
TitleSupplier:'Pemasok Dibuat dengan sukses',
TitleTaxe:'Pajak berhasil dibuat',
TitleCat:'Kategori Berhasil dibuat',
TitleWarhouse:'Gudang Dibuat dengan sukses',
TitleAdjust:'Penyesuaian Berhasil Dibuat',
TitleCurrency:'Mata uang Dibuat dengan sukses',
TitleTransfer:'Transfer Dibuat dengan sukses'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'Email Berhasil dikirim'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'penjualan ini sudah ditautkan dengan Return!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'Manajemen Pengembalian'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'detail pengembalian'),_defineProperty(_Received_Amount$Payi,"EditReturn",'Edit Kembali'),_defineProperty(_Received_Amount$Payi,"AddReturn",'Buat Pengembalian'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'Kirim Pengembalian melalui Email'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'Hapus Kembali'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'Biaya Tambahan Pengembalian'),_defineProperty(_Received_Amount$Payi,"Laivrison",'pengiriman'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Pilih Sale'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'Anda dapat menghapus item atau mengatur kuantitas dikembalikan ke nol jika tidak dikembalikan'),_defineProperty(_Received_Amount$Payi,"Return",'Kembali'),_defineProperty(_Received_Amount$Payi,"Purchase",'Membeli'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Total Penjualan'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Total Pembelian'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Total Pengembalian'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Pembayaran Bersih'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Paiements Sent'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Pembayaran diterima'),_defineProperty(_Received_Amount$Payi,"Recieved",'Diterima'),_defineProperty(_Received_Amount$Payi,"Sent",'Terkirim'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Peringatan Kuantitas Produk'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Kode'),_defineProperty(_Received_Amount$Payi,"ProductName",'Produk'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Kuantitas Peringatan'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Grafik Stok Gudang'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Total Produk'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Jumlah total'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'Lima Pelanggan Teratas'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Jumlah total'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Total Dibayar'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Laporan Penjualan Pelanggan'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Laporan Pembayaran Pelanggan'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'Laporan Kutipan Pelanggan'),_defineProperty(_Received_Amount$Payi,"Payments",'Pembayaran'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'Lima Pemasok Teratas'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Laporan Pembelian Pemasok'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Laporan Pembayaran Pemasok'),_defineProperty(_Received_Amount$Payi,"Name",'Nama'),_defineProperty(_Received_Amount$Payi,"Code",'Kode'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Manajemen Gudang'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Kode Pos'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Manajemen kategori'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Kategori kode'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'Kategori nama'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Kategori Induk'),_defineProperty(_Received_Amount$Payi,"managementTax",'Manajemen pajak'),_defineProperty(_Received_Amount$Payi,"TaxName",'Nama Pajak'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Persentase pajak'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Pembelian Unit'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Unit penjualan'),_defineProperty(_Received_Amount$Payi,"ShortName",'Nama pendek'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Harap Pilih Ini sebelum menambahkan produk apa pun'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Penyesuaian Stok'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Pilih gudang sebelum memilih produk apa pun'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Transfer Saham'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Pilih Periode'),_defineProperty(_Received_Amount$Payi,"ThisYear",'Tahun ini'),_defineProperty(_Received_Amount$Payi,"ThisToday",'Hari Ini'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'Bulan ini'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'Minggu ini'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Detail Penyesuaian'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'Pengguna Ini Telah Diaktifkan'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'Pengguna Ini Telah Dinonaktifkan'),_defineProperty(_Received_Amount$Payi,"NotFound",'Halaman tidak ditemukan.'),_defineProperty(_Received_Amount$Payi,"oops",'kesalahan! Halaman tidak ditemukan.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'Kami tidak dapat menemukan halaman yang Anda cari. Sementara itu, Anda mungkin'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'kembali ke dasbor'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/ar.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/ar.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesArJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Update,_Create,_Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Arabe
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'المبلغ المستلم',
Paying_Amount:'مبلغ الدفع',
Change:'الصرف',
Paying_amount_is_greater_than_Received_amount:'مبلغ الدفع أكبر من المبلغ المستلم',
Paying_amount_is_greater_than_Grand_Total:'مبلغ الدفع أكبر من المبلغ الإجمالي الكلي',
code_must_be_not_exist_already:'يجب أن يكون الرمز غير موجود بالفعل',
You_will_find_your_backup_on:'سوف تجد النسخة الاحتياطية الخاصة بك على',
and_save_it_to_your_pc:'و قم بحفظه على جهاز الكمبيوتر الخاص بك',
Scan_your_barcode_and_select_the_correct_symbology_below:'امسح الرمز الشريطي ضوئيًا وحدد الترميز الصحيح أدناه',
Scan_Search_Product_by_Code_Name:'مسح / بحث عن المنتج حسب الاسم الرمزي',
Paper_size:'حجم الورق',
Clear_Cache:'مسح ذاكرة التخزين المؤقت',
Cache_cleared_successfully:'تم مسح ذاكرة التخزين المؤقت بنجاح',
Failed_to_clear_cache:'فشل مسح ذاكرة التخزين المؤقت',
Scan_Barcode:'ماسح الباركود',
Please_use_short_name_of_unit:'الرجاء استخدام الاسم المختصر للوحدة',
DefaultCustomer:'العميل الافتراضي',
DefaultWarehouse:'المستودع الافتراضي',
Payment_Gateway:'بوابة الدفع',
SMS_Configuration:'إعدادات الرسائل القصيرة',
Gateway:'بوابة الدفع',
Choose_Gateway:'اختر بوابة الدفع',
Send_SMS:'تم ارسال الرسالة بنجاح',
sms_config_invalid:'إعدادات الرسائل القصيرة غير صالحة',
Remove_Stripe_Key_Secret:'حذف مفاتيح Stripe API',
credit_card_account_not_available:'حساب بطاقة الائتمان غير متوفر',
Credit_Card_Info:'معلومات بطاقة الائتمان',
developed_by:'طورت بواسطة',
Unit_already_linked_with_sub_unit:'الوحدة مرتبطة بالفعل بوحدة فرعية',
Total_Items_Quantity:'مجموع العناصر والكمية',
Value_by_Cost_and_Price:'القيمة حسب التكلفة والسعر',
Search_this_table:'ابحث في هذا الجدول',
import_products:'استيراد المنتجات',
Field_optional:'حقل اختياري',
Download_exemple:'تحميل المثال',
field_must_be_in_csv_format:'يجب أن يكون الحقل بتنسيق csv',
Successfully_Imported:'تم الاستيراد بنجاح',
file_size_must_be_less_than_1_mega:'يجب أن يكون حجم الملف أقل من 1 ميغا',
Please_follow_the_import_instructions:'يرجى اتباع تعليمات الاستيراد',
must_be_exist:'يجب أن تكون الوحدة قد تم إنشاؤها بالفعل',
Import_Customers:'استيراد العملاء',
Import_Suppliers:'استيراد الموردين',
Recent_Sales:'المبيعات الأخيرة',
Create_Transfer:'إنشاء تحويل',
order_products:'طلب المنتجات',
Search_Product_by_Code_Name:'ابحث عن المنتج بالكود أو الاسم',
Reports_payments_Purchase_Return:'تقارير مدفوعات مرتجعات الشراء',
Reports_payments_Sale_Return:'تقارير مدفوعات مرتجعات البيع',
payments_Sales_Return:'مدفوعات إرجاع المبيعات',
payments_Purchases_Return:'مدفوعات مشتريات العودة',
CreateSaleReturn:'إنشاء عائد بيع',
EditSaleReturn:'تحرير إرجاع البيع',
SalesReturn:'عائد المبيعات',
CreatePurchaseReturn:'إنشاء إرجاع الشراء',
EditPurchaseReturn:'تحرير إرجاع الشراء',
PurchasesReturn:'عائد المشتريات',
Due:'دين',
Profit:'ربح',
Revenue:'دخل',
Sales_today:'مبيعات اليوم',
People:'اشخاص',
Successfully_Created:'تم إنشاؤه بنجاح',
Successfully_Updated:'تم التحديث بنجاح',
Success:'نجاح',
Failed:'باءت بالفشل',
Warning:'إنذار',
Please_fill_the_form_correctly:'يرجى ملء النموذج بشكل صحيح',
Field_is_required:'هذا الحقل مطلوب',
Choose_Status:'اختر الحالة',
Choose_Method:'اختر الطريقة',
Choose_Symbology:'اختر الترميز',
Choose_Category:'اختر الفئة',
Choose_Customer:'اختر الزبون',
Choose_Supplier:'اختر المورد',
Choose_Unit_Purchase:'اختر وحدة الشراء',
Choose_Sub_Category:'اختر الفئة الفرعية',
Choose_Brand:'اختر الماركة',
Choose_Warehouse:'اختر المستودع',
Choose_Unit_Sale:'اختر وحدة البيع',
Enter_Product_Cost:'أدخل تكلفة المنتج',
Enter_Stock_alert:'أدخل تنبيه المخزون',
Choose_Unit_Product:'اختر وحدة المنتج',
Enter_Product_Price:'أدخل سعر المنتج',
Enter_Name_Product:'أدخل اسم المنتج',
Enter_Role_Name:'أدخل اسم الدور',
Enter_Role_Description:'أدخل وصف الدور',
Enter_name_category:'أدخل اسم الفئة',
Enter_Code_category:'أدخل رمز الفئة',
Enter_Name_Brand:'أدخل اسم الماركة',
Enter_Description_Brand:'أدخل وصف الماركة ',
Enter_Code_Currency:'أدخل رمز العملة',
Enter_name_Currency:'أدخل اسم العملة',
Enter_Symbol_Currency:'أدخل رمز العملة',
Enter_Name_Unit:'أدخل اسم وحدة',
Enter_ShortName_Unit:'أدخل اسمًا قصيرًا للوحدة',
Choose_Base_Unit:'اختر وحدة القاعدة',
Choose_Operator:'اختر عامل التشغيل',
Enter_Operation_Value:'أدخل قيمة العملية',
Enter_Name_Warehouse:'أدخل اسم المستودع',
Enter_Phone_Warehouse:'أدخل هاتف المستودع',
Enter_Country_Warehouse:'أدخل بلد المستودع',
Enter_City_Warehouse:'أدخل مدينة المستودع',
Enter_Email_Warehouse:'أدخل البريد الإلكتروني للمستودع',
Enter_ZipCode_Warehouse:'أدخل الرمز البريدي للمستودع',
Choose_Currency:'اختر العملة',
Thank_you_for_your_business:'شكرا لك على عملك !',
Cancel:'إلغاء',
New_Customer:'عميل جديد',
Incorrect_Login:'تسجيل الدخول غير صحيح',
Successfully_Logged_In:'تم تسجيل الدخول بنجاح',
This_user_not_active:'هذا المستخدم غير نشط',
SignIn:'تسجيل الدخول',
Create_an_account:'انشئ حساب',
Forgot_Password:'هل نسيت كلمة السر',
Email_Address:'بريد الكتروني',
SignUp:'اشتراك',
Already_have_an_account:'هل لديك حساب ؟',
Reset_Password:'إعادة تعيين كلمة المرور',
Failed_to_authenticate_on_SMTP_server:'فشل المصادقة على خادم SMTP',
We_cant_find_a_user_with_that_email_addres:'لا يمكننا العثور على مستخدم بعنوان البريد الإلكتروني هذا',
We_have_emailed_your_password_reset_link:'لقد أرسلنا رابط إعادة تعيين كلمة المرور بالبريد الإلكتروني',
Please_fill_the_Email_Adress:'يرجى ملء عنوان البريد الإلكتروني',
Confirm_password:'تأكيد كلمة المرور',
Your_Password_has_been_changed:'تم تغيير كلمة السر الخاصة بك',
The_password_confirmation_does_not_match:'تأكيد كلمة المرور غير متطابق',
This_password_reset_token_is_invalid:'رمز إعادة تعيين كلمة المرور هذا غير صالح',
Warehouse_report:'تقرير المستودع',
All_Warehouses:'جميع المستودعات',
Expense_List:'قائمة المصاريف',
Expenses:'المصاريف',
This_Week_Sales_Purchases:'مبيعات ومشتريات هذا الأسبوع',
Top_Selling_Products:'المنتجات الأكثر مبيعًا',
View_all:'مشاهدة الكل',
Payment_Sent_Received:'الدفع - المرسل والمستلم',
Error:'خطأ !',
you_are_not_authorized:'آسف! أنك غير مخول.',
Go_back_to_home:'العودة الى الصفحة الرئيسية',
page_not_exist:'آسف! الصفحة التي تبحث عنها غير موجودة.',
Filter:'فلتر',
Invoice_POS:'فاتورة نقاط البيع',
Invoice:'فاتورة',
Customer_Info:'معلومات العميل',
Company_Info:'معلومات الشركة',
Invoice_Info:'معلومات الفاتورة',
Order_Summary:'ملخص الطلب',
Quote_Info:'معلومات الاقتباس',
Del:'حذف',
SuppliersPaiementsReport:'تقرير مدفوعات الموردين',
Purchase_Info:'معلومات الشراء',
Supplier_Info:'معلومات المورد',
Return_Info:'معلومات العودة',
Expense_Category:'فئة المصاريف',
Create_Expense:'أضف المصاريف',
Details:'تفاصيل',
Discount_Method:'طريقة الخصم',
Net_Unit_Cost:'صافي تكلفة الوحدة',
Net_Unit_Price:'صافي سعر الوحدة',
Edit_Expense:'تحرير المصاريف',
All_Brand:'جميع العلامات التجارية',
All_Category:'كل الفئات',
ListExpenses:'قائمة المصروفات',
Create_Permission:'إنشاء إذن',
Edit_Permission:'تحرير إذن',
Reports_payments_Sales:'تقارير مدفوعات المبيعات',
Reports_payments_Purchases:'تقارير مشتريات المدفوعات',
Reports_payments_Return_Customers:'تقارير المدفوعات المرتجعة للعملاء',
Reports_payments_Return_Suppliers:'تقارير المدفوعات عودة الموردين',
Expense_Deleted:'تم حذف هذه المصاريف',
Expense_Updated:'تم تحديث هذه المصاريف',
Expense_Created:'تم إنشاء هذه المصاريف',
DemoVersion:'لا يمكنك القيام بذلك في النسخة التجريبية',
Filesize:'حجم الملف',
GenerateBackup:'إنشاء نسخة احتياطية',
BackupDatabase:'النسخ الاحتياطية',
Backup:'النسخ الاحتياطية',
OrderStatistics:'إحصائيات المبيعات',
AlreadyAdd:'هذا المنتج مضاف بالفعل',
AddProductToList:'الرجاء إضافة المنتج إلى القائمة',
AddQuantity:'الرجاء إضافة الكمية للمنتج',
InvalidData:'بيانات غير صالحة',
LowStock:'الكمية تتجاوز الكمية المتوفرة في المخزون',
WarehouseIdentical:'لا يمكن أن يكون المستودعين متطابقين',
VariantDuplicate:'هذا المتغير مكرر',
Paid:'مدفوعة',
Unpaid:'غير مدفوعة',
IncomeExpenses:'الدخل مقابل المصروفات',
dailySalesPurchases:'المبيعات والمشتريات اليومية',
ProductsExpired:'المنتجات منتهية الصلاحية',
Income:'الدخل'},
_defineProperty(_Received_Amount$Payi,"Expenses",'المصروفات'),_defineProperty(_Received_Amount$Payi,"Sale",'المبيعة'),_defineProperty(_Received_Amount$Payi,"Actif",'فعال'),_defineProperty(_Received_Amount$Payi,"Inactif",'غير فعال'),_defineProperty(_Received_Amount$Payi,"Phone",'الهاتف'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'البحت بالهاتف'),_defineProperty(_Received_Amount$Payi,"CustomerName",'اسم العميل'),_defineProperty(_Received_Amount$Payi,"StockManagement",'إدارة المخزون'),_defineProperty(_Received_Amount$Payi,"dashboard",'لوحة الإستعلام'),_defineProperty(_Received_Amount$Payi,"Products",'منتجات'),_defineProperty(_Received_Amount$Payi,"productsList",'قائمة المنتجات'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'تحويل المخزون'),_defineProperty(_Received_Amount$Payi,"Customers",'الزبائن'),_defineProperty(_Received_Amount$Payi,"Suppliers",'الموردون'),_defineProperty(_Received_Amount$Payi,"Quotations",'عرض الأسعار'),_defineProperty(_Received_Amount$Payi,"Sales",'المبيعات'),_defineProperty(_Received_Amount$Payi,"Purchases",'المشتريات'),_defineProperty(_Received_Amount$Payi,"Returns",'العوائد'),_defineProperty(_Received_Amount$Payi,"Settings",'الإعدادات'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'إعدادات النظام'),_defineProperty(_Received_Amount$Payi,"Users",'المستخدمين'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'صلاحية المجموعة'),_defineProperty(_Received_Amount$Payi,"Currencies",'العملات'),_defineProperty(_Received_Amount$Payi,"ProductTax",'ضريبة المنتج'),_defineProperty(_Received_Amount$Payi,"Categories",'التصنيفات'),_defineProperty(_Received_Amount$Payi,"Warehouses",'المستودعات'),_defineProperty(_Received_Amount$Payi,"Units",'الوحدات'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'وحدات الشراء'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'وحدات البيع'),_defineProperty(_Received_Amount$Payi,"Reports",'التقارير'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'تقرير المدفوعات'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'مدفوعات المشتريات'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'مدفوعات المبيعات'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'مدفوعات المرتجعات'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'الربح والخسارة'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'تنبيهات كمية المنتج'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'الرسم البياني لسهم المستودع'),_defineProperty(_Received_Amount$Payi,"SalesReport",'تقرير المبيعات'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'تقرير المشتريات'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'تقرير العملاء'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'تقرير الموردين'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'تقرير المورد'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'بيانات المبيعات اليومية'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'بيانات المشتريات اليومية'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'السجلات الخمسة الأخيرة'),_defineProperty(_Received_Amount$Payi,"Filters",'البحت'),_defineProperty(_Received_Amount$Payi,"date",'التاريخ'),_defineProperty(_Received_Amount$Payi,"Reference",'المرجع'),_defineProperty(_Received_Amount$Payi,"Supplier",'المورد'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'حالة الدفع'),_defineProperty(_Received_Amount$Payi,"Customer",'الزبون'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'رمز الزبون'),_defineProperty(_Received_Amount$Payi,"Status",'الحالة'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'رمز المورد'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'إدارة المنتجات'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'رمز المنتج'),_defineProperty(_Received_Amount$Payi,"Categorie",'التصنيف'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'التصنيف الفرعي'),_defineProperty(_Received_Amount$Payi,"Name_product",'إسم المنتج'),_defineProperty(_Received_Amount$Payi,"StockAlert",'تنبيه المخزون'),_defineProperty(_Received_Amount$Payi,"warehouse",'المستودع'),_defineProperty(_Received_Amount$Payi,"Tax",'الضريبة'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'سعر الشراء'),_defineProperty(_Received_Amount$Payi,"SellPrice",'سعر البيع'),_defineProperty(_Received_Amount$Payi,"Quantity",'كمية'),_defineProperty(_Received_Amount$Payi,"Action",'الإجراءات'),_defineProperty(_Received_Amount$Payi,"UnitSale",'وحدة البيع'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'وحدة الشراء'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'تفاصيل المنتج'),_defineProperty(_Received_Amount$Payi,"All",'الكل'),_defineProperty(_Received_Amount$Payi,"EditProduct",'تعديل المنتج'),_defineProperty(_Received_Amount$Payi,"AddProduct",'إضافة منتج'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'البحت بالرمز'),_defineProperty(_Received_Amount$Payi,"SearchByName",'البحت بالاسم'),_defineProperty(_Received_Amount$Payi,"Edit",'تعديل'),_defineProperty(_Received_Amount$Payi,"Close",'أغلق'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'يرجى التحديد'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'إدارة الزبائن'),_defineProperty(_Received_Amount$Payi,"Email",'البريد '),_defineProperty(_Received_Amount$Payi,"EditCustomer",'تحرير العميل'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'إضافة عميل'),_defineProperty(_Received_Amount$Payi,"Country",'البلد'),_defineProperty(_Received_Amount$Payi,"City",'المدينة'),_defineProperty(_Received_Amount$Payi,"Adress",'العنوان'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'تفاصيل العميل'),_defineProperty(_Received_Amount$Payi,"CustomersList",'قائمة الزبائن'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'رمز المورد'),_defineProperty(_Received_Amount$Payi,"SupplierName",'اسم المورد'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'إدارة الموردين'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'تفاصيل المورد'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'إدارة التسعيرات'),_defineProperty(_Received_Amount$Payi,"SubTotal",'المجموع الكلي'),_defineProperty(_Received_Amount$Payi,"complete",'مكتملة'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'قيد الانتظار'),_defineProperty(_Received_Amount$Payi,"Recu",'تم الاستلام'),_defineProperty(_Received_Amount$Payi,"partial",'جزئي'),_defineProperty(_Received_Amount$Payi,"Retournee",'مسترجعة'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'تفاصيل عرض السعر '),_defineProperty(_Received_Amount$Payi,"EditQuote",'تعديل عرض السعر'),_defineProperty(_Received_Amount$Payi,"CreateSale",'إنشاء مبيعة'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'تحميل PDF'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'ارسال عرض السعر بالبريد الالكتروني'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'حذف عرض السعر'),_defineProperty(_Received_Amount$Payi,"AddQuote",'إضافة عرض سعر'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'حدد المنتج'),_defineProperty(_Received_Amount$Payi,"Price",'السعر'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'المخزون '),_defineProperty(_Received_Amount$Payi,"Total",'مجموع'),_defineProperty(_Received_Amount$Payi,"Num",'رقم'),_defineProperty(_Received_Amount$Payi,"Unitcost",'تكلفة الوحدة'),_defineProperty(_Received_Amount$Payi,"to",'إلى'),_defineProperty(_Received_Amount$Payi,"Subject",'الموضوع'),_defineProperty(_Received_Amount$Payi,"Message",'الرسالة'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'البريد الإلكتروني للعميل'),_defineProperty(_Received_Amount$Payi,"Sent",'إرسال'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'المنتج'),_defineProperty(_Received_Amount$Payi,"Quote",'عرض الأسعار'),_defineProperty(_Received_Amount$Payi,"Hello",'أهلا'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'يرجى العثور على المرفق لعرض الأسعار الخاص بك'),_defineProperty(_Received_Amount$Payi,"AddProducts",'إضافة منتجات إلى قائمة الطلبات'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'الرجاء اختيار المستودع'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'اختر الزبون'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'إدارة المبيعات'),_defineProperty(_Received_Amount$Payi,"Balance",'الرصيد'),_defineProperty(_Received_Amount$Payi,"QtyBack",'كمية العوائد'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'مجموع العوائد'),_defineProperty(_Received_Amount$Payi,"MontantReste",'المبلغ المتبقي'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'تفاصيل المبيعة'),_defineProperty(_Received_Amount$Payi,"EditSale",'تعديل المبيعة'),_defineProperty(_Received_Amount$Payi,"AddSale",'إضافة مبيعة'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'إظهار المدفوعات'),_defineProperty(_Received_Amount$Payi,"AddPayment",'إضافة الدفع'),_defineProperty(_Received_Amount$Payi,"EditPayment",'تعديل الدفع'),_defineProperty(_Received_Amount$Payi,"EmailSale",'إرسال المبيعة في البريد الإلكتروني'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'حذف المبيعة'),_defineProperty(_Received_Amount$Payi,"Amount",'المبلغ'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'طريقة الدفع'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'طريقة الدفع'),_defineProperty(_Received_Amount$Payi,"Note",'ملحوظة'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'اكتمل الدفع'),_defineProperty(_Received_Amount$Payi,"UserManagement",'إدارة المستخدمين'),_defineProperty(_Received_Amount$Payi,"Firstname",'الاسم الأول'),_defineProperty(_Received_Amount$Payi,"lastname",'اسم العائلة'),_defineProperty(_Received_Amount$Payi,"username",'اسم المستخدم'),_defineProperty(_Received_Amount$Payi,"type",'النوع'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'تراخيص المستخدمين'),_defineProperty(_Received_Amount$Payi,"RoleName",'اسم الدور'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'وصف الدور'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'اضافة التراخيص'),_defineProperty(_Received_Amount$Payi,"View",'عرض'),_defineProperty(_Received_Amount$Payi,"Add",'إضافة'),_defineProperty(_Received_Amount$Payi,"add",'إضافة'),_defineProperty(_Received_Amount$Payi,"Del",'حذف'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'تعديل جديد'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'تحرير التعديل'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'لا يمكنك طرح منتجات لها مخزون 0'),_defineProperty(_Received_Amount$Payi,"Addition",'إضافة'),_defineProperty(_Received_Amount$Payi,"Subtraction",'طرح'),_defineProperty(_Received_Amount$Payi,"profil",'الملف الشخصي'),_defineProperty(_Received_Amount$Payi,"logout",'تسجيل الخروج'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'لا يمكنك التعديل لأن هذا الشراء  مكتمل الدفع  بالفع'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'لا يمكنك التعديل لأن هذه المبيعة  مكتملة الدفع  بالفع'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'لا يمكنك التعديل لأن هذه المرتجعة  مكتملة الدفع  بالفع'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",' هذه التسعيرة أدت بالفعل إلى بيع'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'هده التسعيرة مكتملة'),_defineProperty(_Received_Amount$Payi,"password",'كلمة المرور'),_defineProperty(_Received_Amount$Payi,"Newpassword",'كلمة المرور جديدة'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'تغيير الصورة'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'يرجى ترك هذا الحقل فارغًا إذا لم تقم بتغييره'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'اعدادات عامة'),_defineProperty(_Received_Amount$Payi,"Language",'اللغة'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'العملة الرئيسية'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'كلمة التحقق'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'البريد الرئيسي'),_defineProperty(_Received_Amount$Payi,"SiteName",'اسم الموقع'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'تغيير الشعار'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'اعدادات الارسال'),_defineProperty(_Received_Amount$Payi,"HOST",'مضيف'),_defineProperty(_Received_Amount$Payi,"PORT",'المنفذ'),_defineProperty(_Received_Amount$Payi,"encryption",'التشفير'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'اعدادات الارسال غير صحيحة'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'فواتير المرتجعات'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'بيانات فواتير المرتجعات'),_defineProperty(_Received_Amount$Payi,"ShowAll",'إظهار كافة سجلات كافة المستخدمين'),_defineProperty(_Received_Amount$Payi,"Discount",'الخصم'),_defineProperty(_Received_Amount$Payi,"OrderTax",'ضريبة الطلب'),_defineProperty(_Received_Amount$Payi,"Shipping",'الشحن'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'ادارة العملات'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'شفرة العملة'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'اسم العملة'),_defineProperty(_Received_Amount$Payi,"Symbol",'رمز العملة'),_defineProperty(_Received_Amount$Payi,"CompanyName",'اسم الشركة'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'هاتف الشركة'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'عنوان الشركة'),_defineProperty(_Received_Amount$Payi,"Code",'رمز'),_defineProperty(_Received_Amount$Payi,"image",'صورة'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'طباعة الباركود'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'مرتجعات العملاء'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'مرتجعات الموردين'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'فواتير مرتجعات العملاء'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'فواتير مرتجعات الموردين'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'لا تتوافر بيانات'),_defineProperty(_Received_Amount$Payi,"ProductImage",'صورة المنتج'),_defineProperty(_Received_Amount$Payi,"Barcode",'الباركود'),_defineProperty(_Received_Amount$Payi,"pointofsales",'نقطة مبيعات'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'تحميل مخصص'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'إدارة نقاط البيع'),_defineProperty(_Received_Amount$Payi,"Adjustment",'تعديل'),_defineProperty(_Received_Amount$Payi,"Updat",'تحديث'),_defineProperty(_Received_Amount$Payi,"Reset",'إعادة تعيين'),_defineProperty(_Received_Amount$Payi,"print",'طباعة'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'البحث بالبريد الإلكتروني'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'اختر المنتج'),_defineProperty(_Received_Amount$Payi,"Qty",'الكمية'),_defineProperty(_Received_Amount$Payi,"Items",'العناصر'),_defineProperty(_Received_Amount$Payi,"AmountHT",'المبلغ دون ضريبة'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'المبلغ الإجمالي'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'الرجاء تحديد المورد'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'يرجى تحديد الحالة'),_defineProperty(_Received_Amount$Payi,"PayeBy",'الدفع عن طريق'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'اختر المستودع'),_defineProperty(_Received_Amount$Payi,"payNow",'ادفع الآن'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'قائمة الفئات'),_defineProperty(_Received_Amount$Payi,"Description",'وصف'),_defineProperty(_Received_Amount$Payi,"submit",'تأكيد'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'حدثت مشكلة في إنشاء هذه الفاتورة. حاول مرة اخرى'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'كانت هناك مشكلة في الدفع. حاول مرة اخرى'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'إنشاء تعديل'),_defineProperty(_Received_Amount$Payi,"Afewwords",'... بضع كلمات عن'),_defineProperty(_Received_Amount$Payi,"UserImage",'صورة المستخدم'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'تحديث المنتج'),_defineProperty(_Received_Amount$Payi,"Brand",'الماركة'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'ترميز الباركود'),_defineProperty(_Received_Amount$Payi,"ProductCost",'تكلفة المنتج'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'سعر المنتج'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'منتج الوحدة'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'الطريقة الضريبية'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'صور متعددة'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'المنتج له متغيرات متعددة'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'المنتج له عرض ترويجي'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'بدء الترويج'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'نهاية الترويج'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'سعر الترويج'),_defineProperty(_Received_Amount$Payi,"Price",'السعر'),_defineProperty(_Received_Amount$Payi,"Cost",'كلفة'),_defineProperty(_Received_Amount$Payi,"Unit",'وحدة'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'متغير المنتج'),_defineProperty(_Received_Amount$Payi,"Variant",'متغير'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'سعر الوحدة'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'إنشاء إرجاع العميل'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'تحرير إرجاع العميل'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'إنشاء إرجاع المورد'),_defineProperty(_Received_Amount$Payi,"Documentation",'توثيق'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'تحرير إرجاع المورد'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'من المستودع'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'إلى المستودع'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'تحرير النقل'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'تفاصيل النقل'),_defineProperty(_Received_Amount$Payi,"Pending",'قيد الانتظار'),_defineProperty(_Received_Amount$Payi,"Received",'تم الاستلام'),_defineProperty(_Received_Amount$Payi,"Ordered",'طلب'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'مدير الأذونات'),_defineProperty(_Received_Amount$Payi,"BrandManager",'العلامة التجارية'),_defineProperty(_Received_Amount$Payi,"BrandImage",'صورة الماركة'),_defineProperty(_Received_Amount$Payi,"BrandName",'اسم الماركة'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'ةصف الماركة'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'الوحده الأساسيه'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'إدارة الوحدات'),_defineProperty(_Received_Amount$Payi,"OperationValue",'قيمة العملية'),_defineProperty(_Received_Amount$Payi,"Operator",'عامل'),_defineProperty(_Received_Amount$Payi,"Top5Products",'أفضل 5 منتجات'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'آخر 5 مبيعات'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'قائمة التعديلات'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'قائمة التحويلات'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'إنشاء تحويل'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'مدير الطلبات'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'قائمة التسعيرات'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'قائمة المشتريات'),_defineProperty(_Received_Amount$Payi,"ListSales",'قائمة المبيعات'),_defineProperty(_Received_Amount$Payi,"ListReturns",'قائمة المرتجعات'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'إدارة الأفراد'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'قائمة العلامة التجارية'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'هل أنت واثق؟',
Text:' !لن تتمكن من التراجع عن هذا',
confirmButtonText:'نعم ، احذفه!',
cancelButtonText:'إلغاء',
Deleted:'تم الحذف!',
Failed:'فشل',
Therewassomethingwronge:'كان هناك شيء خاطئ',
CustomerDeleted:'تم حذف هذا العميل',
UserDeleted:'تم حذف هذا المستخدم',
SupplierDeleted:'تم حذف هذا العميل المورد',
QuoteDeleted:'تم حذف هذه التسعيرة',
SaleDeleted:'تم حذف هذا البيع',
PaymentDeleted:'تم حذف هذا الدفع',
PurchaseDeleted:'تم حذف هذا الشراء',
ReturnDeleted:'تم حذف هذه المرتجعة',
ProductDeleted:'تم حذف هدا المنتوج',
ClientError:'هذا العميل مرتبط بالفعل بعملية أخرى',
ProviderError:'هذا المورد مرتبط بالفعل بعملية أخرى',
UnitDeleted:'تم حذف هذه الوحدة',
RoleDeleted:'تم حذف هدا الدور',
TaxeDeleted:'تم حذف هذه الضريبة بنجاح',
SubCatDeleted:'تم حذف هذا  التصنيف فرعي بنجاح',
CatDeleted:'تم حذف هذا التصنيف  بنجاح',
WarehouseDeleted:'تم حذف هذا المخزن  بنجاح',
AlreadyLinked:'هذا المنتج مرتبط بالفعل بعملية أخرى',
AdjustDeleted:'تم حذف هذا التعديل  بنجاح',
TitleCurrency:'تم حذف هذه العملة  بنجاح',
TitleTransfer:'تم حذف النقل  بنجاح',
BackupDeleted:'تمت إزالة النسخة الاحتياطية بنجاح',
TitleBrand:'تم حذف هذه العلامة التجارية'}),
_defineProperty(_Received_Amount$Payi,"Update",(_Update={
TitleBrand:'تم تحديث هذه العلامة التجارية',
TitleSetting:'تم تحديث الاعدادات بنجاح',
TitleProfile:'تم تحديث ملفك الشخصي بنجاح',
TitleAdjust:'تم تحديث التعديل بنجاح',
TitleRole:'تم تحديث الدور بنجاح',
TitleUnit:'تم تحديث الوحدة بنجاح',
TitleCustomer:'تم تحديث المستخدم بنجاح'},
_defineProperty(_Update,"TitleCustomer",'تم تحديث المستخدم بنجاح'),_defineProperty(_Update,"TitleCustomer",'تم تحديث العميل بنجاح'),_defineProperty(_Update,"TitleQuote",'تم تحديث التسعيرة بنجاح'),_defineProperty(_Update,"TitleSale",'تم تحديث البيع بنجاح'),_defineProperty(_Update,"TitlePayment",'تم تحديث الدفع بنجاح'),_defineProperty(_Update,"TitlePurchase",'تم تحديث الشراء بنجاح'),_defineProperty(_Update,"TitleReturn",'تم تحديث المرتجعة بنجاح'),_defineProperty(_Update,"TitleProduct",'تم تحديث المنتوج بنجاح'),_defineProperty(_Update,"TitleSupplier",'تم تحديث المورد بنجاح'),_defineProperty(_Update,"TitleTaxe",'تم تحديث الضريبة بنجاح'),_defineProperty(_Update,"TitleCat",'تم تحديث التصنيف بنجاح'),_defineProperty(_Update,"TitleWarhouse",'تم تحديث المخزن بنجاح'),_defineProperty(_Update,"TitleCurrency",'تم تحديث هذه العملة  بنجاح'),_defineProperty(_Update,"TitleTransfer",'تم تحديث النقل  بنجاح'),_Update)),_defineProperty(_Received_Amount$Payi,"Create",(_Create={
TitleBrand:'تم إنشاء هذه العلامة التجارية',
TitleTransfer:'تم إنشاء النقل بنجاح',
TitleAdjust:'تم إنشاء التعديل بنجاح',
TitleRole:'تم إنشاء الدور بنجاح',
TitleUnit:'تم إنشاء الوحدة بنجاح',
TitleCustomer:'تم إنشاء المستخدم بنجاح'},
_defineProperty(_Create,"TitleCustomer",'تم إنشاء العميل بنجاح'),_defineProperty(_Create,"TitleQuote",'تم إنشاء التسعيرة بنجاح'),_defineProperty(_Create,"TitleSale",'تم إنشاء البيع بنجاح'),_defineProperty(_Create,"TitlePayment",'تم إنشاء الدفع بنجاح'),_defineProperty(_Create,"TitlePurchase",'تم إنشاء الشراء بنجاح'),_defineProperty(_Create,"TitleReturn",'تم إنشاء المرتجعة بنجاح'),_defineProperty(_Create,"TitleProduct",'تم إنشاء المنتوج بنجاح'),_defineProperty(_Create,"TitleSupplier",'تم إنشاء المورد بنجاح'),_defineProperty(_Create,"TitleTaxe",'تم إنشاء الضريبة بنجاح'),_defineProperty(_Create,"TitleCat",'تم إنشاء التصنيف بنجاح'),_defineProperty(_Create,"TitleWarhouse",'تم إنشاء المخزن بنجاح'),_defineProperty(_Create,"TitleCurrency",'تم إنشاء هذه العملة  بنجاح'),_Create)),_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'تم الارسال بنجاح'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'هذا البيع مرتبط بالفعل بإرجاع'}),
_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'إدارة المشتريات'),_defineProperty(_Received_Amount$Payi,"Ordered",'أمر'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'حذف الشراء'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'إرسال الشراء في البريد الإلكتروني'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'تحرير الشراء'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'تفاصيل الشراء'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'أضف شراء'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'البريد الإلكتروني للمورد'),_defineProperty(_Received_Amount$Payi,"ReturnManagement",'إدارة المرتجعات'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'تفاصيل  المرتجعة'),_defineProperty(_Received_Amount$Payi,"EditReturn",'تحرير المرتجعة'),_defineProperty(_Received_Amount$Payi,"AddReturn",'إضافة مرتجعة'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'إرسال المرتجعة في البريد الإلكتروني'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'حذف  المرتجعة'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'تكلفة إضافية'),_defineProperty(_Received_Amount$Payi,"Laivrison",'التسليم'),_defineProperty(_Received_Amount$Payi,"SelectSale",'حدد المبيعة'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'يمكنك حذف العنصر أو تعيين الكمية التي تم إرجاعها إلى الصفر إذا لم يتم إرجاعها'),_defineProperty(_Received_Amount$Payi,"Return",'مرتجعة'),_defineProperty(_Received_Amount$Payi,"Purchase",'شراء'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'مدفوعات المشتريات'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'بيانات مدفوعات المشتريات'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'مدفوعات المبيعات'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'بيانات مدفوعات المبيعات'),_defineProperty(_Received_Amount$Payi,"TotalSales",'إجمالي المبيعات'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'إجمالي المشتريات'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'إجمالي العائدات'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'صافي المدفوعات'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'الدفعات المرسلة'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'الدفعات المستلمة'),_defineProperty(_Received_Amount$Payi,"Recieved",'المستلمة'),_defineProperty(_Received_Amount$Payi,"Sent",'المرسلة'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'تنبيهات كمية المنتج'),_defineProperty(_Received_Amount$Payi,"ProductCode",'كود المنتج'),_defineProperty(_Received_Amount$Payi,"ProductName",'المنتج'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'كمية التنبيه'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'مخطط المخزون  المستودعات'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'إجمالي المنتجات'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'إجمالي الكمية'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'أفضل 5 عملاء'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'المبلغ الإجمالي'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'المبلغ المدفوع'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'تقرير المبيعات '),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",' تقرير المدفوعات '),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'تقرير عروض أسعار '),_defineProperty(_Received_Amount$Payi,"Payments",'المدفوعات'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'أفضل 5 الموردين'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'تقرير المشتريات '),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'تقرير المدفوعات '),_defineProperty(_Received_Amount$Payi,"Name",'اسم'),_defineProperty(_Received_Amount$Payi,"Code",'الكود'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'إدارة المستودعات'),_defineProperty(_Received_Amount$Payi,"ZipCode",'الرمز البريدي'),_defineProperty(_Received_Amount$Payi,"managementCategories",'إدارة التصنيفات'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'رمز الفئة'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'اسم الفئة'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'اصل الفئة'),_defineProperty(_Received_Amount$Payi,"managementTax",'إدارة الضرائب'),_defineProperty(_Received_Amount$Payi,"TaxName",'اسم الضريبة'),_defineProperty(_Received_Amount$Payi,"TaxRate",'معدل الضريبة'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'إدارة وحدة المشتريات'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'إدارة وحدة المبيعات'),_defineProperty(_Received_Amount$Payi,"ShortName",'اسم قصير'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'يرجى تحديد هذه قبل إضافة أي منتج'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'تعديل المخزون'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'يرجى تحديد المستودع قبل اختيار أي منتج'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'تحويل المخزون'),_defineProperty(_Received_Amount$Payi,"Today",'اليوم'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'حدد الفترة'),_defineProperty(_Received_Amount$Payi,"ThisToday",'هذا اليوم'),_defineProperty(_Received_Amount$Payi,"ThisYear",'هذا العام'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'هذا الشهر'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'هذا الاسبوع'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'تفاصيل التعديل'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'تم تنشيط هذا المستخدم'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'تم إلغاء تنشيط هذا المستخدم'),_defineProperty(_Received_Amount$Payi,"NotFound",'الصفحة غير موجودة.'),_defineProperty(_Received_Amount$Payi,"oops",'خطأ! الصفحة غير موجودة.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'لم نتمكن من العثور على الصفحة التي تبحث عنها ، وفي الوقت نفسه ، يمكنك ذلك'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'العودة إلى لوحة القيادة'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/de.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/de.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesDeJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Allemand
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Erhaltener Betrag',
Paying_Amount:'Zahlungsbetrag',
Change:'Veränderung',
Paying_amount_is_greater_than_Received_amount:'Der Zahlungsbetrag ist höher als der erhaltene Betrag',
Paying_amount_is_greater_than_Grand_Total:'Der Zahlungsbetrag ist höher als die Gesamtsumme',
code_must_be_not_exist_already:'Code darf noch nicht vorhanden sein',
You_will_find_your_backup_on:'Sie finden Ihr Backup auf',
and_save_it_to_your_pc:'und speichere es auf deinem PC',
Scan_your_barcode_and_select_the_correct_symbology_below:'Scannen Sie Ihren Barcode und wählen Sie unten die richtige Symbologie aus',
Scan_Search_Product_by_Code_Name:'Produkt nach Codename scannen/durchsuchen',
Paper_size:'Papier größe',
Clear_Cache:'Cache leeren',
Cache_cleared_successfully:'Cache erfolgreich geleert',
Failed_to_clear_cache:'Cache konnte nicht gelöscht werden',
Scan_Barcode:'Barcodelesegerät',
Please_use_short_name_of_unit:'Bitte verwenden Sie die Kurzbezeichnung der Einheit',
DefaultCustomer:'Standardkunde',
DefaultWarehouse:'Standardlager',
Payment_Gateway:'Zahlungs-Gateways',
SMS_Configuration:'SMS-Konfiguration',
Gateway:'Zahlungs-Gateways',
Choose_Gateway:'Wählen Sie Zahlungs-Gateways',
Send_SMS:'Nachricht erfolgreich gesendet',
sms_config_invalid:'falsche SMS-Konfiguration ungültig',
Remove_Stripe_Key_Secret:'Löschen Sie die Stripe-API-Schlüssel',
credit_card_account_not_available:'Kreditkartenkonto nicht verfügbar',
Credit_Card_Info:'Kreditkarteninformationen',
developed_by:'Entwickelt von',
Unit_already_linked_with_sub_unit:'Einheit bereits mit Untereinheit verbunden',
Total_Items_Quantity:'Gesamtartikel und Menge',
Value_by_Cost_and_Price:'Wert nach Kosten und Preis',
Search_this_table:'Durchsuchen Sie diese Tabelle',
import_products:'Produkte importieren',
Field_optional:'Feld optional',
Download_exemple:'Beispiel herunterladen',
field_must_be_in_csv_format:'Das Feld muss im CSV-Format vorliegen',
Successfully_Imported:'Erfolgreich importiert',
file_size_must_be_less_than_1_mega:'Die Dateigröße muss weniger als 1 Mega betragen',
Please_follow_the_import_instructions:'Bitte folgen Sie den Importanweisungen',
must_be_exist:'Einheit muss bereits angelegt sein',
Import_Customers:'Kunden importieren',
Import_Suppliers:'Lieferanten importieren',
Recent_Sales:'Letzte Verkäufe',
Create_Transfer:'Übertragung erstellen',
order_products:'Auftragspositionen',
Search_Product_by_Code_Name:'Suchen Sie das Produkt nach Code oder Name',
Reports_payments_Purchase_Return:'Meldet Kaufrückzahlungen',
Reports_payments_Sale_Return:'Berichte Verkauf Rückzahlungen',
payments_Sales_Return:'Zahlungen Verkäufe Rückgabe',
payments_Purchases_Return:'Zahlungen Einkäufe Rückgabe',
CreateSaleReturn:'Verkaufsrendite erstellen',
EditSaleReturn:'Verkaufsrückgabe bearbeiten',
SalesReturn:'Umsatzrendite',
CreatePurchaseReturn:'Kaufretoure erstellen',
EditPurchaseReturn:'Kaufretoure bearbeiten',
PurchasesReturn:'Käufe zurück',
Due:'fällig',
Profit:'Profitieren',
Revenue:'Einnahmen',
Sales_today:'Verkauf heute',
People:'Menschen',
Successfully_Created:'Erfolgreich erstellt',
Successfully_Updated:'Erfolgreich aktualisiert',
Success:'Erfolg',
Failed:'Gescheitert',
Warning:'Warnung',
Please_fill_the_form_correctly:'Bitte füllen Sie das Formular korrekt aus',
Field_is_required:'Feld ist erforderlich',
Error:'Error!',
you_are_not_authorized:'Es tut uns leid! Sie sind nicht berechtigt.',
Go_back_to_home:'Gehen Sie zurück zur Homepage',
page_not_exist:'Es tut uns leid! Die gesuchte Seite existiert nicht.',
Choose_Status:'Wählen Sie Status',
Choose_Method:'Wählen Sie Methode',
Choose_Symbology:'Wählen Sie Symbologie',
Choose_Category:'Kategorie auswählen',
Choose_Customer:'Wählen Sie Kunde',
Choose_Supplier:'Wählen Sie Lieferant',
Choose_Unit_Purchase:'Wählen Sie Kaufeinheit',
Choose_Sub_Category:'Wählen Sie Unterkategorie',
Choose_Brand:'Wählen Sie Marke',
Choose_Warehouse:'Wählen Sie Lager',
Choose_Unit_Sale:'Wählen Sie Verkaufseinheit',
Enter_Product_Cost:'Produktkosten eingeben',
Enter_Stock_alert:'Bestandswarnung eingeben',
Choose_Unit_Product:'Wählen Sie Produkteinheit',
Enter_Product_Price:'Produktpreis eingeben',
Enter_Name_Product:'Geben Sie den Namen Produkt ein',
Enter_Role_Name:'Geben Sie den Rollennamen ein',
Enter_Role_Description:'Geben Sie die Rollenbeschreibung ein',
Enter_name_category:'Geben Sie den Kategorienamen ein',
Enter_Code_category:'Geben Sie den Kategoriecode ein',
Enter_Name_Brand:'Geben Sie die Namensmarke ein',
Enter_Description_Brand:'Geben Sie Beschreibung Marke ein',
Enter_Code_Currency:'Geben Sie die Codewährung ein',
Enter_name_Currency:'Geben Sie den Namen Währung ein',
Enter_Symbol_Currency:'Geben Sie die Symbolwährung ein',
Enter_Name_Unit:'Geben Sie den Einheitennamen ein',
Enter_ShortName_Unit:'Geben Sie den Kurznamen Unit ein',
Choose_Base_Unit:'Wählen Sie Basiseinheit',
Choose_Operator:'Wählen Sie den Operator',
Enter_Operation_Value:'Geben Sie den Betriebswert ein',
Enter_Name_Warehouse:'Geben Sie den Lagernamen ein',
Enter_Phone_Warehouse:'Geben Sie das Lagertelefon ein',
Enter_Country_Warehouse:'Geben Sie das Lagerland ein',
Enter_City_Warehouse:'Geben Sie die Lagerstadt ein',
Enter_Email_Warehouse:'Geben Sie die Lager E-Mail ein',
Enter_ZipCode_Warehouse:'Geben Sie die Postleitzahl des Lagers ein',
Choose_Currency:'Währung wählen',
Thank_you_for_your_business:'Vielen Dank für Ihr Geschäft!',
Cancel:'Stornieren',
New_Customer:'Neukunde',
Incorrect_Login:'Falsche Anmeldedaten',
Successfully_Logged_In:'Erfolgreich angemeldet',
This_user_not_active:'Dieser Benutzer ist nicht aktiv',
SignIn:'Einloggen',
Create_an_account:'Ein Konto erstellen',
Forgot_Password:'Passwort vergessen ?',
Email_Address:'E-Mail-Addresse',
SignUp:'Anmeldung',
Already_have_an_account:'Sie haben bereits ein Konto ?',
Reset_Password:'Passwort zurücksetzen',
Failed_to_authenticate_on_SMTP_server:'Fehler beim Authentifizieren auf dem SMTP-Server',
We_cant_find_a_user_with_that_email_addres:'Wir können keinen Benutzer mit dieser E-Mail-Adresse finden',
We_have_emailed_your_password_reset_link:'Wir haben Ihren Link zum Zurücksetzen Ihres Passworts per E-Mail gesendet',
Please_fill_the_Email_Adress:'Bitte geben Sie die E-Mail-Adresse ein',
Confirm_password:'Kennwort bestätigen',
Your_Password_has_been_changed:'Ihr Passwort wurde geändert',
The_password_confirmation_does_not_match:'Die Passwortbestätigung stimmt nicht überein',
This_password_reset_token_is_invalid:'Dieses Token zum Zurücksetzen des Passworts ist ungültig',
Warehouse_report:'Lagerbericht',
All_Warehouses:'Alle Lagerhäuser',
Expense_List:'Spesenliste',
Expenses:'Kosten',
This_Week_Sales_Purchases:'Diese Woche Verkäufe & Käufe',
Top_Selling_Products:'Meistverkaufte Produkte',
View_all:'Alle ansehen',
Payment_Sent_Received:'Zahlung gesendet und erhalten',
Filter:'Filter',
Invoice_POS:'Rechnung POS',
Invoice:'Rechnung',
Customer_Info:'Kundeninformation',
Company_Info:'Firmeninfo',
Invoice_Info:'Rechnungsinfo',
Order_Summary:'Bestellübersicht',
Quote_Info:'Angebotsinfo',
Del:'Löschen',
SuppliersPaiementsReport:'Lieferantenzahlungsbericht',
Purchase_Info:'Kaufinfo',
Supplier_Info:'Lieferanteninfo',
Return_Info:'Infos zur Rücksendung',
Expense_Category:'Ausgabenkategorie',
Create_Expense:'Kosten erstellen',
Details:'Einzelheiten',
Discount_Method:'Rabattmethode',
Net_Unit_Cost:'Netto-Stückkosten',
Net_Unit_Price:'Netto-Stückpreis',
Edit_Expense:'Kosten bearbeiten',
All_Brand:'Alle Marke',
All_Category:'Alle Kategorie',
ListExpenses:'Ausgaben auflisten',
Create_Permission:'Berechtigung erstellen',
Edit_Permission:'Berechtigung bearbeiten',
Reports_payments_Sales:'Meldet Zahlungen Verkäufe',
Reports_payments_Purchases:'Meldet Zahlungen Einkäufe',
Reports_payments_Return_Customers:'Berichte Zahlungen Kunden zurückgeben',
Reports_payments_Return_Suppliers:'Berichte Zahlungen Rücklieferanten',
Expense_Deleted:'Diese Ausgabe wurde gelöscht',
Expense_Updated:'Diese Ausgabe wurde aktualisiert',
Expense_Created:'Diese Ausgabe wurde erstellt',
DemoVersion:'Dies ist in der Demoversion nicht möglich',
OrderStatistics:'Verkaufsstatistik',
AlreadyAdd:'Dieses Produkt ist bereits hinzugefügt',
AddProductToList:'Bitte fügen Sie das Produkt der Liste hinzu',
AddQuantity:'Bitte addieren Sie die Menge',
InvalidData:'Ungültige Daten',
LowStock:'Menge übersteigt die auf Lager verfügbare Menge',
WarehouseIdentical:'Die beiden Repositorys können nicht identisch sein',
VariantDuplicate:'Diese Variable ist redundant',
Filesize:'Dateigröße',
GenerateBackup:'Backup generieren',
BackupDatabase:'Backup-Datenbank',
Backup:'Backup-Datenbank',
Paid:'Bezahlt',
Unpaid:'Unbezahlt',
IncomeExpenses:'Einnahmen & Ausgaben',
dailySalesPurchases:'tägliche Verkäufe und Einkäufe',
ProductsExpired:'Produkt abgelaufen',
Today:'heute',
Income:'Einkommen'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Kosten'),_defineProperty(_Received_Amount$Payi,"Sale",'Verkauf'),_defineProperty(_Received_Amount$Payi,"Actif",'Aktiv'),_defineProperty(_Received_Amount$Payi,"Inactif",'Inaktiv'),_defineProperty(_Received_Amount$Payi,"Customers",'Kunden'),_defineProperty(_Received_Amount$Payi,"Phone",'Telefon'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Suche per Telefon'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Lieferanten'),_defineProperty(_Received_Amount$Payi,"Quotations",'Zitate'),_defineProperty(_Received_Amount$Payi,"Sales",'Der Umsatz'),_defineProperty(_Received_Amount$Payi,"Purchases",'Einkäufe'),_defineProperty(_Received_Amount$Payi,"Returns",'Kehrt zurück'),_defineProperty(_Received_Amount$Payi,"Settings",'die Einstellungen'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'Systemeinstellungen'),_defineProperty(_Received_Amount$Payi,"Users",'Benutzer'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Gruppenberechtigungen'),_defineProperty(_Received_Amount$Payi,"Currencies",'Währungen'),_defineProperty(_Received_Amount$Payi,"Warehouses",'Lagerhäuser'),_defineProperty(_Received_Amount$Payi,"Units",'Einheiten'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'Kauf von Einheiten'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Einheiten Vertrieb'),_defineProperty(_Received_Amount$Payi,"Reports",'Berichte'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Zahlungsbericht'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Zahlungen Einkäufe'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Zahlungen Verkäufe'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Zahlung Rückgabe'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'Gibt Rechnungen zurück'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'Rechnungsdaten zurücksenden'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Alle Datensätze aller Benutzer anzeigen'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Gewinn-und Verlust'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Lagerbestandstabelle'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Verkaufsbericht'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Kaufbericht'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Kundenbericht'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Lieferantenbericht'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Lieferantenbericht'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Tägliche Verkaufsdaten'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Tägliche Kaufdaten'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Letzte fünf Datensätze'),_defineProperty(_Received_Amount$Payi,"Filters",'Filter'),_defineProperty(_Received_Amount$Payi,"date",'Datum'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Management Währungen'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Währungscode'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Währungsname'),_defineProperty(_Received_Amount$Payi,"Symbol",'Symbol'),_defineProperty(_Received_Amount$Payi,"Reference",'Referenz'),_defineProperty(_Received_Amount$Payi,"Supplier",'Lieferant'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Zahlungsstatus'),_defineProperty(_Received_Amount$Payi,"Customer",'Kunde'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Kundennummer'),_defineProperty(_Received_Amount$Payi,"Status",'Status'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Lieferantencode'),_defineProperty(_Received_Amount$Payi,"Categorie",'Kategorie'),_defineProperty(_Received_Amount$Payi,"Categories",'Kategorien'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Umlagerung'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Lagerverwaltung'),_defineProperty(_Received_Amount$Payi,"dashboard",'Instrumententafel'),_defineProperty(_Received_Amount$Payi,"Products",'Produkte'),_defineProperty(_Received_Amount$Payi,"productsList",'Produktliste'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Produkt Management'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Produktmengen Warnungen'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Code Produkt'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Produktsteuer'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'Unterkategorie'),_defineProperty(_Received_Amount$Payi,"Name_product",'Bezeichnung'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Lagerwarnung'),_defineProperty(_Received_Amount$Payi,"warehouse",'Warenhaus'),_defineProperty(_Received_Amount$Payi,"Tax",'MwSt'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Kaufpreis'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Verkaufspreis'),_defineProperty(_Received_Amount$Payi,"Quantity",'Quantität'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Einheiten verkaufen'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Stückkauf'),_defineProperty(_Received_Amount$Payi,"All",'Alles'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Produkt bearbeiten'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Produkt hinzufügen'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Suche nach Code'),_defineProperty(_Received_Amount$Payi,"SearchByName",'Suche mit Name'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'Produktdetails'),_defineProperty(_Received_Amount$Payi,"CustomerName",'Kundenname'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Kundenmanagement'),_defineProperty(_Received_Amount$Payi,"Add",'Hinzufügen'),_defineProperty(_Received_Amount$Payi,"add",'Hinzufügen'),_defineProperty(_Received_Amount$Payi,"Edit",'Bearbeiten'),_defineProperty(_Received_Amount$Payi,"Close",'Schließen'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Bitte auswählen'),_defineProperty(_Received_Amount$Payi,"Action",'Aktion'),_defineProperty(_Received_Amount$Payi,"Email",'Email'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Kunden bearbeiten'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Kunden hinzufügen'),_defineProperty(_Received_Amount$Payi,"Country",'Land'),_defineProperty(_Received_Amount$Payi,"City",'Stadt'),_defineProperty(_Received_Amount$Payi,"Adress",'Adresse'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'Kundendetails'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Kundenliste'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Lieferantencode'),_defineProperty(_Received_Amount$Payi,"SupplierName",'Name des Anbieters'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Lieferantenmanagement'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Lieferantendetails'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Zitate management'),_defineProperty(_Received_Amount$Payi,"SubTotal",'Zwischensumme'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Restbetrag'),_defineProperty(_Received_Amount$Payi,"complete",'Komplett'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'steht aus'),_defineProperty(_Received_Amount$Payi,"Recu",'Empfangen'),_defineProperty(_Received_Amount$Payi,"partial",'Teilweise'),_defineProperty(_Received_Amount$Payi,"Retournee",'Rückkehr'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Detaillierte Zita'),_defineProperty(_Received_Amount$Payi,"EditQuote",'bearbeiten zitat'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Verkauf erstellen'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'PDF Herunterladen'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'zitat per E-Mail senden'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",' Löschen zitat'),_defineProperty(_Received_Amount$Payi,"AddQuote",'hinzufügen zitat'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Ausgewähltes Produkt'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Produkt (Code - Name)'),_defineProperty(_Received_Amount$Payi,"Price",'Preis'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'Lagerbestand'),_defineProperty(_Received_Amount$Payi,"Total",'Gesamt'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'Kosten pro Einheit'),_defineProperty(_Received_Amount$Payi,"to",'zu'),_defineProperty(_Received_Amount$Payi,"Subject",'Gegenstand'),_defineProperty(_Received_Amount$Payi,"Message",'Botschaft'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'E-Mail an den Kunden'),_defineProperty(_Received_Amount$Payi,"Sent",'Senden'),_defineProperty(_Received_Amount$Payi,"Quote",'Zitat'),_defineProperty(_Received_Amount$Payi,"Hello",'Hallo'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Sie finden den Anhang zu Ihrem Zitat'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Produkte zur Bestellliste hinzufügen'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Bitte Lager auswählen'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'Wählen Sie Kunde'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Verkaufsleitung'),_defineProperty(_Received_Amount$Payi,"Balance",'Balance'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Mengenrückgabe'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Gesamtrendite'),_defineProperty(_Received_Amount$Payi,"Amount",'Menge'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Verkaufsdetail'),_defineProperty(_Received_Amount$Payi,"EditSale",'Verkauf bearbeiten'),_defineProperty(_Received_Amount$Payi,"AddSale",'Verkauf hinzufügen'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Zahlungen anzeigen'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Zahlung hinzufügen'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Zahlung bearbeiten'),_defineProperty(_Received_Amount$Payi,"EmailSale",'Verkauf per E-Mail senden'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Verkauf löschen'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Bezahlverfahren'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Wahl der Zahlung'),_defineProperty(_Received_Amount$Payi,"Note",'Hinweis'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Zahlung abgeschlossen!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Einkaufsmanagement'),_defineProperty(_Received_Amount$Payi,"Ordered",'Bestellt'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Kauf löschen'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Kauf per E-Mail senden'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Kauf bearbeiten'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Kaufdetail'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Kauf hinzufügen'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Lieferanten-E-Mail'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Kauft Zahlungen'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Kauft Zahlungsdaten'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'Verkaufszahlungen'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Verkaufszahlungsdaten'),_defineProperty(_Received_Amount$Payi,"UserManagement",'Benutzerverwaltung'),_defineProperty(_Received_Amount$Payi,"Firstname",'Vorname'),_defineProperty(_Received_Amount$Payi,"lastname",'Nachname'),_defineProperty(_Received_Amount$Payi,"username",'NUTZERNAME'),_defineProperty(_Received_Amount$Payi,"password",'PASSWORT'),_defineProperty(_Received_Amount$Payi,"Newpassword",'Neues Kennwort'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Avatar ändern'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Bitte lassen Sie dieses Feld leer, wenn Sie es nicht geändert haben'),_defineProperty(_Received_Amount$Payi,"type",'Typ'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Benutzerberechtigungen'),_defineProperty(_Received_Amount$Payi,"RoleName",'Rollenname'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Rollenbeschreibung'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'Berechtigungen hinzufügen'),_defineProperty(_Received_Amount$Payi,"View",'ansehen'),_defineProperty(_Received_Amount$Payi,"Del",'Löschen'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'Neue Anpassung'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Anpassung bearbeiten'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'Sie können keine Produkte mit Lagerbestand 0 subtrahieren'),_defineProperty(_Received_Amount$Payi,"Addition",'Zusatz'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Subtraktion'),_defineProperty(_Received_Amount$Payi,"profil",'profil'),_defineProperty(_Received_Amount$Payi,"logout",'Ausloggen'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'Sie können keine Änderungen vornehmen, da dieser Kauf bereits bezahlt wurde'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'Sie können nicht ändern, da dieser Verkauf bereits bezahlt wurde'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'Sie können keine Änderungen vornehmen, da diese Rücksendung bereits bezahlt wurde'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'Dieses Angebot hat bereits einen Verkauf generiert'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'Dieses Angebot ist abgeschlossen'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Standortkonfiguration'),_defineProperty(_Received_Amount$Payi,"Language",'Sprache'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'Standardwährung'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Anmeldung Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Standard-E-Mail'),_defineProperty(_Received_Amount$Payi,"SiteName",'Site-Name'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Logo ändern'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'SMTP-Konfiguration'),_defineProperty(_Received_Amount$Payi,"HOST",'GASTGEBER'),_defineProperty(_Received_Amount$Payi,"PORT",'HAFEN'),_defineProperty(_Received_Amount$Payi,"encryption",'Verschlüsselung'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'SMTP-Konfiguration falsch'),_defineProperty(_Received_Amount$Payi,"Discount",'Rabatt'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Bestellsteuer'),_defineProperty(_Received_Amount$Payi,"Shipping",'Versand'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Name der Firma'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Firmentelefon'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'Firmenanschrift'),_defineProperty(_Received_Amount$Payi,"Code",'Code'),_defineProperty(_Received_Amount$Payi,"image",'Bild'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'Strichcode drucken'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'Gibt Kunden zurück'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'Gibt Lieferanten zurück'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'Rechnungen Gibt Verkäufe zurück'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'Rechnungen Gibt Einkäufe zurück'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'Keine Daten verfügbar'),_defineProperty(_Received_Amount$Payi,"ProductImage",'Produkt bild'),_defineProperty(_Received_Amount$Payi,"Barcode",'Strichcode'),_defineProperty(_Received_Amount$Payi,"pointofsales",'Verkaufsstelle'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Benutzerdefinierter Upload'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'Kasse Management'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Änderung'),_defineProperty(_Received_Amount$Payi,"Updat",'Aktualisieren'),_defineProperty(_Received_Amount$Payi,"Reset",'Zurücksetzen'),_defineProperty(_Received_Amount$Payi,"print",'drucken'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'Suche per E-Mail'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Wählen Sie Produkt'),_defineProperty(_Received_Amount$Payi,"Qty",'Menge'),_defineProperty(_Received_Amount$Payi,"Items",'Artikel'),_defineProperty(_Received_Amount$Payi,"AmountHT",'Betrag HT'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'Betrag TTC'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Bitte wählen Sie Lieferant'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Bitte wählen Sie Statut'),_defineProperty(_Received_Amount$Payi,"PayeBy",'bezahlt mit'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Wählen Sie Lager'),_defineProperty(_Received_Amount$Payi,"payNow",'Zahlen Sie jetzt'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'Liste der Kategorien'),_defineProperty(_Received_Amount$Payi,"Description",'Beschreibung'),_defineProperty(_Received_Amount$Payi,"submit",'einreichen'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'Beim Erstellen dieser Rechnung ist ein Problem aufgetreten. Bitte versuche es erneut'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'Es gab ein Problem bei der Zahlung. Bitte versuche es erneut.'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Anpassung erstellen'),_defineProperty(_Received_Amount$Payi,"Afewwords",'ein paar Worte über ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'Benutzerbild'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Produkt aktualisieren'),_defineProperty(_Received_Amount$Payi,"Brand",'Marke'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Barcode-Symbologie'),_defineProperty(_Received_Amount$Payi,"ProductCost",'Produktkosten'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Produktpreis'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Einheit Produkt'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Steuermethode'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Mehrfachbild'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Produkt hat mehrere Varianten'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'Produkt hat Werbung'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Promotion Start'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Promotion-Ende'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Aktionspreis'),_defineProperty(_Received_Amount$Payi,"Price",'Preis'),_defineProperty(_Received_Amount$Payi,"Cost",'Kosten'),_defineProperty(_Received_Amount$Payi,"Unit",'Einheit'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Produktvariante'),_defineProperty(_Received_Amount$Payi,"Variant",'Variante'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Stückpreis'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'Rückgabekunden erstellen'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'Kundenretouren aktualisieren'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'Rücklieferanten anlegen'),_defineProperty(_Received_Amount$Payi,"Documentation",'Dokumentation'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'Lieferantenrückgabe aktualisieren'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'Aus dem Lager'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'Zum Lager'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Übertragung bearbeiten'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Detail übertragen'),_defineProperty(_Received_Amount$Payi,"Pending",'steht aus'),_defineProperty(_Received_Amount$Payi,"Received",'Empfangen'),_defineProperty(_Received_Amount$Payi,"Ordered",'Bestellt'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'Berechtigungsmanagement'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Markenführung'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Markenzeichen'),_defineProperty(_Received_Amount$Payi,"BrandName",'Markenname'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Markenbeschreibung'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Grundeinheit'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Verwaltungseinheiten'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Betriebswert'),_defineProperty(_Received_Amount$Payi,"Operator",'Operator'),_defineProperty(_Received_Amount$Payi,"Top5Products",'Top 5 Produkte'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'Letzte 5 Verkäufe'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'Anpassungslisten'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Übertragungen auflisten'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Übertragung erstellen'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Auftragsverwaltung'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Zitate auflisten'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Einkäufe auflisten'),_defineProperty(_Received_Amount$Payi,"ListSales",'Liste Verkäufe'),_defineProperty(_Received_Amount$Payi,"ListReturns",'Liste zurück'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'Management Leute'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Markenliste'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Bist du sicher?',
Text:'Sie können dies nicht rückgängig machen!',
confirmButtonText:'Ja, lösche es!',
cancelButtonText:'Stornieren',
Deleted:'Gelöscht!',
Failed:'Gescheitert!',
Therewassomethingwronge:'Etwas war falsch',
CustomerDeleted:'Dieser Client wurde gelöscht',
SupplierDeleted:'Dieser Lieferant wurde gelöscht',
QuoteDeleted:'Dieses Angebot wurde gelöscht',
SaleDeleted:'Dieser Verkauf wurde gelöscht',
PaymentDeleted:'Diese Zahlung wurde gelöscht',
PurchaseDeleted:'Dieser Kauf wurde gelöscht',
ReturnDeleted:'Diese Rückgabe wurde gelöscht',
ProductDeleted:'Dieses Produkt wurde gelöscht',
ClientError:'Dieser Client ist bereits mit einer anderen Operation verknüpft',
ProviderError:'Dieser Lieferant ist bereits mit anderen Vorgängen verbunden',
UserDeleted:'Dieser Benutzer wurde gelöscht',
UnitDeleted:'Diese Einheit wurde gelöscht',
RoleDeleted:'Diese Rolle wurde gelöscht',
TaxeDeleted:'Diese Steuer wurde gelöscht',
SubCatDeleted:'Diese Unterkategorie wurde gelöscht.',
CatDeleted:'Diese Kategorie wurde gelöscht',
WarehouseDeleted:'Dieses Warehouse wurde gelöscht',
AlreadyLinked:'Dieses Produkt ist bereits mit anderen Prozessen verknüpft',
AdjustDeleted:'Diese Anpassung wurde gelöscht',
TitleCurrency:'Diese Währung wurde erfolgreich gelöscht',
TitleTransfer:'Transfer wurde erfolgreich entfernt',
BackupDeleted:'Backup wurde erfolgreich entfernt',
TitleBrand:'Diese Marke wurde gelöscht'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleBrand:'Diese Marke wurde aktualisiert',
TitleProfile:'Dein Profil wurde erfolgreich aktualisiert',
TitleAdjust:'Anpassung Erfolgreich aktualisiert',
TitleRole:'Rolle erfolgreich aktualisiert',
TitleUnit:'Einheit erfolgreich aktualisiert',
TitleUser:'Benutzer erfolgreich aktualisiert',
TitleCustomer:'Kunde erfolgreich aktualisiert',
TitleQuote:'Angebot erfolgreich aktualisiert',
TitleSale:'Verkauf erfolgreich aktualisiert',
TitlePayment:'Zahlung erfolgreich aktualisiert',
TitlePurchase:'Kauf Erfolgreich aktualisiert',
TitleReturn:'Zurück Erfolgreich aktualisiert',
TitleProduct:'Produktaktualisierung erfolgreich',
TitleSupplier:'Lieferant erfolgreich aktualisiert',
TitleTaxe:'Steuer erfolgreich aktualisiert',
TitleCat:'Kategorie Erfolgreich aktualisiert',
TitleWarhouse:'Warehouse erfolgreich aktualisiert',
TitleSetting:'Einstellungen erfolgreich aktualisiert',
TitleCurrency:'Diese Währung wurde erfolgreich aktualisiert',
TitleTransfer:'Transfer wurde erfolgreich aktualisiert'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'Diese Marke wurde erstellt',
TitleTransfer:'Transfer wurde erfolgreich erstellt',
TitleRole:'Rolle erfolgreich erstellt in',
TitleUnit:'Einheit erfolgreich erstellt in',
TitleUser:'Benutzer erfolgreich erstellt in',
TitleCustomer:'Kunde erfolgreich erstellt in',
TitleQuote:'Angebot erfolgreich erstellt in',
TitleSale:'Verkauf Erfolgreich erstellt in',
TitlePayment:'Zahlung erfolgreich erstellt in',
TitlePurchase:'Kauf erfolgreich erstellt in',
TitleReturn:'Rückgabe Erfolgreich erstellt in',
TitleProduct:'Produkt erfolgreich erstellt in',
TitleSupplier:'Lieferant Erfolgreich erstellt in',
TitleTaxe:'Steuer erfolgreich erstellt',
TitleCat:'Kategorie Erfolgreich erstellt in',
TitleWarhouse:'Warehouse erfolgreich erstellt in',
TitleAdjust:'Anpassung Erfolgreich erstellt in',
TitleCurrency:'Diese Münze wurde erfolgreich erstellt'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'E-Mail Erfolgreich einsenden'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'Dieser Verkauf ist bereits mit einer Rückgabe verbunden!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'Rückgabeverwaltung'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'Detail zurückgeben'),_defineProperty(_Received_Amount$Payi,"EditReturn",'Rückgabe bearbeiten'),_defineProperty(_Received_Amount$Payi,"AddReturn",'Return hinzufügen'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'Senden Sie die Rücksendung per E-Mail'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'Rückgabe löschen'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'Rücknahmegebühr'),_defineProperty(_Received_Amount$Payi,"Laivrison",'Lieferung'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Wählen Sie Verkauf'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'Sie können den Artikel löschen oder den zurückgegebenen Betrag auf Null setzen, wenn er nicht zurückgegeben wird'),_defineProperty(_Received_Amount$Payi,"Return",'Rückkehr'),_defineProperty(_Received_Amount$Payi,"Purchase",'Kauf'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Gesamtumsatz'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Gesamtkäufe'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Gesamtrendite'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Zahlung netto'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Zahlung senden'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Zahlung erhalten'),_defineProperty(_Received_Amount$Payi,"Recieved",'Empfangen'),_defineProperty(_Received_Amount$Payi,"Sent",'senden'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Warnung vor Produktmengen'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Produktcode'),_defineProperty(_Received_Amount$Payi,"ProductName",'Produktname'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Warnung Menge'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Inventardiagramm'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Produkte insgesamt'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Gesamtmenge'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'Top 5 Kunden'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Gesamtmenge'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Ganz bezahlt'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Kunden Verkaufsbericht'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Kundenzahlungsbericht'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'KundenangeboteBericht'),_defineProperty(_Received_Amount$Payi,"Payments",'Zahlungen'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'Top 5 Lieferanten'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Lieferanten Einkaufsbericht'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Lieferanten Zahlungsbericht'),_defineProperty(_Received_Amount$Payi,"Name",'Name'),_defineProperty(_Received_Amount$Payi,"Code",'Code'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Lagerverwaltung'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Postleitzahl'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Kategorienverwaltung'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Codekategorie'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'Namenskategorie'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Eltern-Kategorie'),_defineProperty(_Received_Amount$Payi,"managementTax",'Steuermanagement'),_defineProperty(_Received_Amount$Payi,"TaxName",'Steuername'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Steuersatz'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Käufe Einheitenverwaltung'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Verkaufseinheit Management'),_defineProperty(_Received_Amount$Payi,"ShortName",'Kurzer Name'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Bitte wählen Sie diese aus, bevor Sie ein Produkt hinzufügen'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Bestandskorrektur'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Bitte wählen Sie das Lager aus, bevor Sie ein Produkt auswählen'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Umlagerung'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Wählen Sie Periode'),_defineProperty(_Received_Amount$Payi,"ThisYear",'Dieses Jahr'),_defineProperty(_Received_Amount$Payi,"ThisToday",'Das heute'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'Diesen Monat'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'Diese Woche'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Anpassungsdetail'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'Dieser Benutzer wurde aktiviert'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'Dieser Benutzer wurde deaktiviert'),_defineProperty(_Received_Amount$Payi,"NotFound",'Seite nicht gefunden.'),_defineProperty(_Received_Amount$Payi,"oops",'Error! Seite nicht gefunden.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'Wir konnten die gesuchte Seite nicht finden. In der Zwischenzeit können Sie'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'Zurück zum Dashboard'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/en.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/en.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesEnJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Anglais
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Received Amount',
Paying_Amount:'Paying Amount',
Change:'Change',
Paying_amount_is_greater_than_Received_amount:'Paying amount is greater than received amount',
Paying_amount_is_greater_than_Grand_Total:'Paying amount is greater than Grand Total',
code_must_be_not_exist_already:'code must be not exist already',
You_will_find_your_backup_on:'You will find your backup on',
and_save_it_to_your_pc:'and save it to your pc',
Scan_your_barcode_and_select_the_correct_symbology_below:'Scan your barcode and select the correct symbology below',
Scan_Search_Product_by_Code_Name:'Scan/Search Product by Code Name',
Paper_size:'Paper size',
Clear_Cache:'Clear Cache',
Cache_cleared_successfully:'Cache cleared successfully',
Failed_to_clear_cache:'Failed to clear cache',
Scan_Barcode:'Barcode Scanner',
Please_use_short_name_of_unit:'Please use short name of unit',
DefaultCustomer:'Default Customer',
DefaultWarehouse:'Default Warehouse',
Payment_Gateway:'Payment Gateway',
SMS_Configuration:'SMS Configuration',
Gateway:'Payment Gateway',
Choose_Gateway:'Choose Payment Gateway',
Send_SMS:'Message sent successfully',
sms_config_invalid:'wrong sms config invalid',
Remove_Stripe_Key_Secret:'Delete Stripe API keys',
credit_card_account_not_available:'Credit card account not available',
Credit_Card_Info:'Credit Card Info',
developed_by:'Developed by',
Unit_already_linked_with_sub_unit:'Unit already linked with sub unit',
Total_Items_Quantity:'Total Items & Quantity',
Value_by_Cost_and_Price:'Value by Cost and Price',
Search_this_table:'Search this table',
import_products:'Import products',
Field_optional:'Field optional',
Download_exemple:'Download example',
field_must_be_in_csv_format:'Field must be in csv format',
Successfully_Imported:'Successfully Imported',
file_size_must_be_less_than_1_mega:'File size must be less than 1 mega',
Please_follow_the_import_instructions:'Please follow the import instructions',
must_be_exist:'unit must already be created',
Import_Customers:'Import Customers',
Import_Suppliers:'Import Suppliers',
Recent_Sales:'Recent Sales',
Create_Transfer:'Create Transfer',
order_products:'Order items',
Search_Product_by_Code_Name:'Search Product by code or name',
Reports_payments_Purchase_Return:'Reports Purchase Return Payments',
Reports_payments_Sale_Return:'Reports Sale Return Payments',
payments_Sales_Return:'Payments Sales Return',
payments_Purchases_Return:'Payments Purchases Return',
CreateSaleReturn:'Create Sale Return',
EditSaleReturn:'Edit Sale Return',
SalesReturn:'Sales Return',
CreatePurchaseReturn:'Create Purchase Return',
EditPurchaseReturn:'Edit Purchase Return',
PurchasesReturn:'Purchases Return',
Due:'Due',
Profit:'Profit',
Revenue:'Revenue',
Sales_today:'Today Sales',
People:'People',
Successfully_Created:'Successfully Created',
Successfully_Updated:'Successfully Updated',
Success:'Success',
Failed:'Failed',
Warning:'Warning',
Please_fill_the_form_correctly:'Please fill the form correctly',
Field_is_required:'This Field is required',
Error:'Error!',
you_are_not_authorized:'Sorry! you are not authorized.',
Go_back_to_home:'Go back to homepage',
page_not_exist:'Sorry! The page you were looking for doesn\'t exist.',
Choose_Status:'Choose Status',
Choose_Method:'Choose Method',
Choose_Symbology:'Choose symbology',
Choose_Category:'Choose Category',
Choose_Customer:'Choose Customer',
Choose_Supplier:'Choose Supplier',
Choose_Unit_Purchase:'Choose Purchase Unit',
Choose_Sub_Category:'Choose SubCategory',
Choose_Brand:'Choose Brand',
Choose_Warehouse:'Choose Warehouse',
Choose_Unit_Sale:'Choose Sale Unit',
Enter_Product_Cost:'Enter Product Cost',
Enter_Stock_alert:'Enter Stock alert',
Choose_Unit_Product:'Choose Product Unit',
Enter_Product_Price:'Enter Product Price',
Enter_Name_Product:'Enter Name Product',
Enter_Role_Name:'Enter Role Name',
Enter_Role_Description:'Enter Role Description',
Enter_name_category:'Enter category Name',
Enter_Code_category:'Enter category Code',
Enter_Name_Brand:'Enter Name Brand',
Enter_Description_Brand:'Enter Description Brand',
Enter_Code_Currency:'Enter Code Currency',
Enter_name_Currency:'Enter name Currency',
Enter_Symbol_Currency:'Enter Symbol Currency',
Enter_Name_Unit:'Enter Unit Name',
Enter_ShortName_Unit:'Enter shortname Unit',
Choose_Base_Unit:'Choose Base Unit',
Choose_Operator:'Choose Operator',
Enter_Operation_Value:'Enter Operation Value',
Enter_Name_Warehouse:'Enter Warehouse Name',
Enter_Phone_Warehouse:'Enter Warehouse Phone',
Enter_Country_Warehouse:'Enter Warehouse Country',
Enter_City_Warehouse:'Enter Warehouse City',
Enter_Email_Warehouse:'Enter Warehouse Email',
Enter_ZipCode_Warehouse:'Enter Warehouse Zip Code',
Choose_Currency:'Choose Currency',
Thank_you_for_your_business:'Thank you for shopping with us . Please come again',
Cancel:'Cancel',
New_Customer:'New Customer',
Incorrect_Login:'Incorrect Login',
Successfully_Logged_In:'Successfully Logged In',
This_user_not_active:'This user not active',
SignIn:'Sign In',
Create_an_account:'Create an account',
Forgot_Password:'Forgot Password ?',
Email_Address:'Email Address',
SignUp:'Sign Up',
Already_have_an_account:'Already have an account ?',
Reset_Password:'Reset Password',
Failed_to_authenticate_on_SMTP_server:'Failed to authenticate on SMTP server',
We_cant_find_a_user_with_that_email_addres:'We can\'t find a user with that email addres',
We_have_emailed_your_password_reset_link:'We have e-mailed your password reset link',
Please_fill_the_Email_Adress:'Please fill the Email Address',
Confirm_password:'Confirm password',
Your_Password_has_been_changed:'Your Password has been changed',
The_password_confirmation_does_not_match:'The password confirmation does not match',
This_password_reset_token_is_invalid:'This password reset token is invalid',
Warehouse_report:'Warehouse report',
All_Warehouses:'All Warehouses',
Expense_List:'Expense List',
Expenses:'Expenses',
This_Week_Sales_Purchases:'This Week Sales & Purchases',
Top_Selling_Products:'Top Selling Products',
View_all:'View all',
Payment_Sent_Received:'Payment Sent & Received',
Filter:'Filter',
Invoice_POS:'Invoice POS',
Invoice:'Invoice',
Customer_Info:'Customer Info',
Company_Info:'Company Info',
Invoice_Info:'Invoice Info',
Order_Summary:'Order Summary',
Quote_Info:'Quotation Info',
Del:'Delete',
SuppliersPaiementsReport:'Suppliers Payments Report',
Purchase_Info:'Purchase Info',
Supplier_Info:'Supplier Info',
Return_Info:'Info of Return',
Expense_Category:'Expense Category',
Create_Expense:'Create Expense',
Details:'Details',
Discount_Method:'Discount Type',
Net_Unit_Cost:'Net Unit Cost',
Net_Unit_Price:'Net Unit Price',
Edit_Expense:'Edit Expense',
All_Brand:'All Brand',
All_Category:'All Category',
ListExpenses:'List Expenses',
Create_Permission:'Create Permission',
Edit_Permission:'Edit Permission',
Reports_payments_Sales:'Reports payments Sales',
Reports_payments_Purchases:'Reports payments Purchases',
Reports_payments_Return_Customers:'Payments Return Customers',
Reports_payments_Return_Suppliers:'Payments Return Suppliers',
Expense_Deleted:'This Expense has been deleted',
Expense_Updated:'This Expense has been Updated',
Expense_Created:'This Expense has been Created',
DemoVersion:'You cannot do this in the demo version',
OrderStatistics:'Sales Statistics',
AlreadyAdd:'This Product Already Added !!',
AddProductToList:'Please Add Product To List !!',
AddQuantity:'Please Add quantity of product !!',
InvalidData:'Invalid Data !!',
LowStock:'Quantity exceeds quantity available in stock',
WarehouseIdentical:'The two warehouses cannot be identical !!',
VariantDuplicate:'This Variant Is Duplicate !!',
Filesize:'File size',
GenerateBackup:'Generate Backup',
BackupDatabase:'Backup Database',
Backup:'Backup',
Paid:'Paid',
Unpaid:'Unpaid',
Today:'Today',
Income:'Income'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Expenses'),_defineProperty(_Received_Amount$Payi,"Sale",'Sale'),_defineProperty(_Received_Amount$Payi,"Actif",'Active'),_defineProperty(_Received_Amount$Payi,"Inactif",'Inactive'),_defineProperty(_Received_Amount$Payi,"Customers",'Customer List'),_defineProperty(_Received_Amount$Payi,"Phone",'Phone'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Search by Phone'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Supplier List'),_defineProperty(_Received_Amount$Payi,"Quotations",'Quotations'),_defineProperty(_Received_Amount$Payi,"Sales",'Sales'),_defineProperty(_Received_Amount$Payi,"Purchases",'Purchases'),_defineProperty(_Received_Amount$Payi,"Returns",'Return'),_defineProperty(_Received_Amount$Payi,"Settings",'Settings'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'System Settings'),_defineProperty(_Received_Amount$Payi,"Users",'User List'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Group Permissions'),_defineProperty(_Received_Amount$Payi,"Currencies",'Currency'),_defineProperty(_Received_Amount$Payi,"Warehouses",'Warehouse'),_defineProperty(_Received_Amount$Payi,"Units",'Unit'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'Purchases Units'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Sales Units'),_defineProperty(_Received_Amount$Payi,"Reports",'Reports'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Payments Report'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Payments Purchases'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Payments Sales'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Profit and Loss'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Warehouse Stock Chart'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Sale Report'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Purchase Report'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Customer Report'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Supplier Report'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Supplier Report'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Daily Sales Data'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Daily Purchases Data'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Last five records'),_defineProperty(_Received_Amount$Payi,"Filters",'Filters'),_defineProperty(_Received_Amount$Payi,"date",'Date'),_defineProperty(_Received_Amount$Payi,"Reference",'Reference'),_defineProperty(_Received_Amount$Payi,"Supplier",'Supplier'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Payment Status'),_defineProperty(_Received_Amount$Payi,"Customer",'Customer'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Customer Code'),_defineProperty(_Received_Amount$Payi,"Status",'Status'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Supplier Code'),_defineProperty(_Received_Amount$Payi,"Categorie",'Category'),_defineProperty(_Received_Amount$Payi,"Categories",'Category'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Transfer'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Stock Management'),_defineProperty(_Received_Amount$Payi,"dashboard",'Dashboard'),_defineProperty(_Received_Amount$Payi,"Products",'Products'),_defineProperty(_Received_Amount$Payi,"productsList",'Product List'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Product Management'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Product Quantity Alerts'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Code Product'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Product Tax'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'Sub Category'),_defineProperty(_Received_Amount$Payi,"Name_product",'Name'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Stock Alert'),_defineProperty(_Received_Amount$Payi,"warehouse",'Warehouse'),_defineProperty(_Received_Amount$Payi,"Tax",'Tax'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Buying price'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Sell price'),_defineProperty(_Received_Amount$Payi,"Quantity",'Quantity'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Sale Unit'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Purchase Unit'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Currency Management'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Currency Code'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Currency Name'),_defineProperty(_Received_Amount$Payi,"Symbol",'Symbol'),_defineProperty(_Received_Amount$Payi,"All",'All'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Edit Product'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Search by Code'),_defineProperty(_Received_Amount$Payi,"SearchByName",'Search by Name'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'Product Details'),_defineProperty(_Received_Amount$Payi,"CustomerName",'Customer Name'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Customer Management'),_defineProperty(_Received_Amount$Payi,"Add",'Create'),_defineProperty(_Received_Amount$Payi,"add",'Create'),_defineProperty(_Received_Amount$Payi,"Edit",'Edit'),_defineProperty(_Received_Amount$Payi,"Close",'Close'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Please Select'),_defineProperty(_Received_Amount$Payi,"Action",'Action'),_defineProperty(_Received_Amount$Payi,"Email",'Email'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Edit Customer'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Create Customer'),_defineProperty(_Received_Amount$Payi,"Country",'Country'),_defineProperty(_Received_Amount$Payi,"City",'City'),_defineProperty(_Received_Amount$Payi,"Adress",'Address'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'Customer Details'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Customer List'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Supplier Code'),_defineProperty(_Received_Amount$Payi,"SupplierName",'Supplier Name'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Suppliers Management'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Supplier Details'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Quotations Management'),_defineProperty(_Received_Amount$Payi,"SubTotal",'Subtotal'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Amount left'),_defineProperty(_Received_Amount$Payi,"complete",'Completed'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'Pending'),_defineProperty(_Received_Amount$Payi,"Recu",'Received'),_defineProperty(_Received_Amount$Payi,"partial",'Partial'),_defineProperty(_Received_Amount$Payi,"Retournee",'Return'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Detail Quotation'),_defineProperty(_Received_Amount$Payi,"EditQuote",'Edit Quotation'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Create Sale'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'Download Pdf'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'Send Quotation on Email'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'Delete Quotation'),_defineProperty(_Received_Amount$Payi,"AddQuote",'Create Quotation'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Select Product'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Product (Code - Name)'),_defineProperty(_Received_Amount$Payi,"Price",'Price'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'Stock'),_defineProperty(_Received_Amount$Payi,"Total",'Grand Total'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'Unit cost'),_defineProperty(_Received_Amount$Payi,"to",'To'),_defineProperty(_Received_Amount$Payi,"Subject",'Subject'),_defineProperty(_Received_Amount$Payi,"Message",'Message'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'Email Customer'),_defineProperty(_Received_Amount$Payi,"Sent",'Send'),_defineProperty(_Received_Amount$Payi,"Quote",'Quotation'),_defineProperty(_Received_Amount$Payi,"Hello",'Hello'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Please find the attachment for your Quotation'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Add Products to the Order List'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Please Select warehouse'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'please Select Customer'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Sales Management'),_defineProperty(_Received_Amount$Payi,"Balance",'Balance'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Qty Back'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Total Return'),_defineProperty(_Received_Amount$Payi,"Amount",'Amount'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Sale Detail'),_defineProperty(_Received_Amount$Payi,"EditSale",'Edit Sale'),_defineProperty(_Received_Amount$Payi,"AddSale",'Create Sale'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Show Payments'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Create Payment'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Edit Payment'),_defineProperty(_Received_Amount$Payi,"EmailSale",'Send Sale on Email'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Delete Sale'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Paid by'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Payment choice'),_defineProperty(_Received_Amount$Payi,"Note",'Note'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Payment complete!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Purchases Management'),_defineProperty(_Received_Amount$Payi,"Ordered",'Ordered'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Delete Purchase'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Send Purchase on Email'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Edit Purchase'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Purchase Detail'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Create Purchase'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Supplier Email'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Purchases payments'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Purchases payments data'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'Sales payments'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Sales payments data'),_defineProperty(_Received_Amount$Payi,"UserManagement",'Users management'),_defineProperty(_Received_Amount$Payi,"Firstname",'First name'),_defineProperty(_Received_Amount$Payi,"lastname",'Last name'),_defineProperty(_Received_Amount$Payi,"username",'Username'),_defineProperty(_Received_Amount$Payi,"password",'Password'),_defineProperty(_Received_Amount$Payi,"Newpassword",'New password'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Change Avatar'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Please leave this field blank if you haven\'t changed it'),_defineProperty(_Received_Amount$Payi,"type",'Type'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Users Permissions'),_defineProperty(_Received_Amount$Payi,"RoleName",'Role'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Role Description'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'Create Permissions'),_defineProperty(_Received_Amount$Payi,"View",'View'),_defineProperty(_Received_Amount$Payi,"Del",'Delete'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'New Adjustement'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Edit Adjustement'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'You cannot subtraction products which have stock 0'),_defineProperty(_Received_Amount$Payi,"Addition",'Addition'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Subtraction'),_defineProperty(_Received_Amount$Payi,"profil",'Profile'),_defineProperty(_Received_Amount$Payi,"logout",'Logout'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'You cannot modify because this Purchase already paid'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'You cannot modify because this Sale already paid'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'You cannot modify because this Return already paid'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'This quote already has generate sale'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Create product'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'This Quotation Complete'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Site Configuration'),_defineProperty(_Received_Amount$Payi,"Language",'Language'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'Default Currency'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Login Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Default Email'),_defineProperty(_Received_Amount$Payi,"SiteName",'Site Name'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Change Logo'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'SMTP Configuration'),_defineProperty(_Received_Amount$Payi,"HOST",'HOST'),_defineProperty(_Received_Amount$Payi,"PORT",'PORT'),_defineProperty(_Received_Amount$Payi,"encryption",'Encryption'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'SMTP Configuration Incorrect'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Payments Returns'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'Returns Invoices'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'Returns Invoices Data'),_defineProperty(_Received_Amount$Payi,"ShowAll",'View all records of all Users'),_defineProperty(_Received_Amount$Payi,"Discount",'Discount'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Order Tax'),_defineProperty(_Received_Amount$Payi,"Shipping",'Shipping'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Company Name'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Company Phone'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'Company Address'),_defineProperty(_Received_Amount$Payi,"Code",'Code'),_defineProperty(_Received_Amount$Payi,"image",'Image'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'Print barcode'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'Returns Customer'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'Returns Supplier'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'Return Customer Invoice'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'Return Supplier Invoice'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'No data Available'),_defineProperty(_Received_Amount$Payi,"ProductImage",'Product Image'),_defineProperty(_Received_Amount$Payi,"Barcode",'Barcode'),_defineProperty(_Received_Amount$Payi,"pointofsales",'Point of Sales'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Custom Upload'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'Point of Sale Management'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Adjustment'),_defineProperty(_Received_Amount$Payi,"Updat",'Update'),_defineProperty(_Received_Amount$Payi,"Reset",'Reset'),_defineProperty(_Received_Amount$Payi,"print",'Print'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'Search By Email'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Choose Product'),_defineProperty(_Received_Amount$Payi,"Qty",'Qty'),_defineProperty(_Received_Amount$Payi,"Items",'Items'),_defineProperty(_Received_Amount$Payi,"AmountHT",'Amount HT'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'Amount TTC'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Please Select Supplier'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Please Select Status'),_defineProperty(_Received_Amount$Payi,"PayeBy",'Paid By'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Choose Warehouse'),_defineProperty(_Received_Amount$Payi,"payNow",'Pay Now'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'List of Category'),_defineProperty(_Received_Amount$Payi,"Description",'Description'),_defineProperty(_Received_Amount$Payi,"submit",'Submit'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'There was a problem creating this Invoice. Please try again'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'There was a problem Payment. Please try again.'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'Income & Expenses'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'Daily Sales & Purchases'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'Products Expired'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Brand List'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Create Adjustment'),_defineProperty(_Received_Amount$Payi,"Afewwords",'A few words ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'User Image'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Update Product'),_defineProperty(_Received_Amount$Payi,"Brand",'Brand'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Barcode Symbology'),_defineProperty(_Received_Amount$Payi,"ProductCost",'Product Cost'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Product Price'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Product Unit'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Tax Type'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Multiple Image'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Product Has Multi Variants'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'Product Has Promotion'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Promotion Start'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Promotion End'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Promotion Price'),_defineProperty(_Received_Amount$Payi,"Price",'Price'),_defineProperty(_Received_Amount$Payi,"Cost",'Cost'),_defineProperty(_Received_Amount$Payi,"Unit",'Unit'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Product Variant'),_defineProperty(_Received_Amount$Payi,"Variant",'Variant'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Unit Price'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'Create Return Customer'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'Edit Return Customer'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'Create Return Supplier'),_defineProperty(_Received_Amount$Payi,"Documentation",'Doc'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'Edit Return Supplier'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'From Warehouse'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'To Warehouse'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Edit Transfer'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Transfer Detail'),_defineProperty(_Received_Amount$Payi,"Pending",'Pending'),_defineProperty(_Received_Amount$Payi,"Received",'Received'),_defineProperty(_Received_Amount$Payi,"Ordered",'Ordered'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'Permissions Management'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Brand'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Brand Image'),_defineProperty(_Received_Amount$Payi,"BrandName",'Brand Name'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Brand Description'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Base Unit'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Units Management'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Operation Value'),_defineProperty(_Received_Amount$Payi,"Operator",'Operator'),_defineProperty(_Received_Amount$Payi,"Top5Products",'Top 5 Products'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'Last 5 Sales'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'Adjustment List'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Transfer List'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Create Transfer'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Orders Management'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Quotation List'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Purchase List'),_defineProperty(_Received_Amount$Payi,"ListSales",'Sale List'),_defineProperty(_Received_Amount$Payi,"ListReturns",'Return List'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'People Management'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Are you sure?',
Text:'You won\'t be able to revert this!',
confirmButtonText:'Yes, delete it!',
cancelButtonText:'Cancel',
Deleted:'Deleted!',
Failed:'Failed!',
Therewassomethingwronge:'There was something wronge',
CustomerDeleted:'This Client has been deleted.',
SupplierDeleted:'This Supplier has been deleted.',
QuoteDeleted:'This Quotation has been deleted.',
SaleDeleted:'This Sale has been deleted.',
PaymentDeleted:'This Payment has been deleted.',
PurchaseDeleted:'This Purchase has been deleted.',
ReturnDeleted:'This Return has been deleted.',
ProductDeleted:'This Product has been deleted.',
ClientError:'This Client already linked with other Operation',
ProviderError:'This Supplier already linked with other Operation',
UserDeleted:'This User has been deleted.',
UnitDeleted:'This Unit has been deleted.',
RoleDeleted:'This Role has been deleted.',
TaxeDeleted:'This Tax has been deleted.',
SubCatDeleted:'This Sub Category has been deleted.',
CatDeleted:'This Category has been deleted.',
WarehouseDeleted:'This Warehouse has been deleted.',
AlreadyLinked:'This product already linked with other Operation',
AdjustDeleted:'This Adjustement has been deleted.',
TitleCurrency:'This Currency has been deleted.',
TitleTransfer:'The Transfer has been removed successfully',
BackupDeleted:'Backup has been removed successfully',
TitleBrand:'This Brand has been deleted'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleBrand:'This Brand has been Updated',
TitleProfile:'Your Profile Updated in successfully',
TitleAdjust:'Adjustement Updated in successfully',
TitleRole:'Role Updated in successfully',
TitleUnit:'Unit Updated in successfully',
TitleUser:'User Updated in successfully',
TitleCustomer:'Customer Updated in successfully',
TitleQuote:'Quotation Updated in successfully',
TitleSale:'Sale Updated in successfully',
TitlePayment:'Payment Updated in successfully',
TitlePurchase:'Purchase Updated in successfully',
TitleReturn:'Return Updated in successfully',
TitleProduct:'Product Updated in successfully',
TitleSupplier:'Supplier Updated in successfully',
TitleTaxe:'Tax Updated in successfully',
TitleCat:'Category Updated in successfully',
TitleWarhouse:'Warhouse Updated in successfully',
TitleSetting:'Settings Updated in successfully',
TitleCurrency:'Currency Updated in successfully',
TitleTransfer:'Transfer Updated in successfully'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'This Brand has been Created',
TitleRole:'Role Created in successfully',
TitleUnit:'Unit Created in successfully',
TitleUser:'User Created in successfully',
TitleCustomer:'Customer Created in successfully',
TitleQuote:'Quotation Created in successfully',
TitleSale:'Sale Created in successfully',
TitlePayment:'Payment Created in successfully',
TitlePurchase:'Purchase Created in successfully',
TitleReturn:'Return Created in successfully',
TitleProduct:'Product Created in successfully',
TitleSupplier:'Supplier Created in successfully',
TitleTaxe:'Tax Created in successfully',
TitleCat:'Category Created in successfully',
TitleWarhouse:'Warehouse Created in successfully',
TitleAdjust:'Adjustement Created in successfully',
TitleCurrency:'Currency Created in successfully',
TitleTransfer:'Transfer Created in successfully'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'Email Send in successfully'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'This sale already linked with a Return!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'Return Management'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'Return Detail'),_defineProperty(_Received_Amount$Payi,"EditReturn",'Edit Return'),_defineProperty(_Received_Amount$Payi,"AddReturn",'Create Return'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'Send Return on Email'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'Delete Return'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'Return Surcharge'),_defineProperty(_Received_Amount$Payi,"Laivrison",'Delivery'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Select Sale'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'You can delete the item or set the quantity returned to zero if it is not returned'),_defineProperty(_Received_Amount$Payi,"Return",'Return'),_defineProperty(_Received_Amount$Payi,"Purchase",'Purchase'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Total Sales'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Total Purchases'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Total Returns'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Paiements Net'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Paiements Sent'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Paiements Received'),_defineProperty(_Received_Amount$Payi,"Recieved",'Recieved'),_defineProperty(_Received_Amount$Payi,"Sent",'Sent'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Product Quantity Alerts'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Code'),_defineProperty(_Received_Amount$Payi,"ProductName",'Product'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Alert Quantity'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Warehouse Stock Chart'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Total Products'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Total Quantity'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'Top 5 Customers'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Total Amount'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Total Paid'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Customer Sales Report'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Customer Paiements Report'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'Customer Quotations Report'),_defineProperty(_Received_Amount$Payi,"Payments",'Payments'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'Top 5 Suppliers'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Supplier Purchases Report'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Supplier Paiements Report'),_defineProperty(_Received_Amount$Payi,"Name",'Name'),_defineProperty(_Received_Amount$Payi,"Code",'Code'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Warehouse Management'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Zip Code'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Categories management'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Category Code'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'Category Name'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Parent category'),_defineProperty(_Received_Amount$Payi,"managementTax",'Tax management'),_defineProperty(_Received_Amount$Payi,"TaxName",'Tax Name'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Tax Rate'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Purchases Unit'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Sales Unit'),_defineProperty(_Received_Amount$Payi,"ShortName",'Short Name'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Please Select These before adding any product'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Adjustment'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Please Select warehouse before choose any product'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Stock Transfer'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Select Period'),_defineProperty(_Received_Amount$Payi,"ThisYear",'This Year'),_defineProperty(_Received_Amount$Payi,"ThisToday",'This Today'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'This Month'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'This Week'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Adjustment Detail'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'This User Has been Activated'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'This User Has been Deactivated'),_defineProperty(_Received_Amount$Payi,"NotFound",'Page not found.'),_defineProperty(_Received_Amount$Payi,"oops",'Oops! Page not found.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'We could not find the page you were looking for.Meanwhile, you may'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'Return to dashboard'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/es.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/es.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesEsJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Espagnol
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Cantidad recibida',
Paying_Amount:'Monto de pago',
Change:'cambiar',
Paying_amount_is_greater_than_Received_amount:'El monto a pagar es mayor que el monto recibido',
Paying_amount_is_greater_than_Grand_Total:'El monto a pagar es mayor que el total general',
code_must_be_not_exist_already:'el código no debe existir ya',
You_will_find_your_backup_on:'Encontrarás tu copia de seguridad en',
and_save_it_to_your_pc:'y guárdalo en tu pc',
Scan_your_barcode_and_select_the_correct_symbology_below:'Escanee su código de barras y seleccione la simbología correcta a continuación',
Scan_Search_Product_by_Code_Name:'Escanear / Buscar producto por nombre de código',
Paper_size:'Tamaño de papel',
Clear_Cache:'limpiar cache',
Cache_cleared_successfully:'Caché borrada con éxito',
Failed_to_clear_cache:'No se pudo borrar la caché',
Scan_Barcode:'Escáner de código de barras',
Please_use_short_name_of_unit:'Utilice el nombre corto de la unidad',
DefaultCustomer:'Cliente predeterminado',
DefaultWarehouse:'Almacén predeterminado',
Payment_Gateway:'Pasarela de pago',
SMS_Configuration:'Configuración de SMS',
Gateway:'Pasarela de pago',
Choose_Gateway:'Elija la pasarela de pago',
Send_SMS:'Mensaje enviado con éxito',
sms_config_invalid:'configuración de sms incorrecta no válida',
Remove_Stripe_Key_Secret:'Eliminar claves de API de Stripe',
credit_card_account_not_available:'Cuenta de tarjeta de crédito no disponible',
Credit_Card_Info:'Información de la tarjeta de crédito',
developed_by:'Desarrollado por',
Unit_already_linked_with_sub_unit:'Unidad ya vinculada con la subunidad',
Total_Items_Quantity:'Total de artículos y cantidad',
Value_by_Cost_and_Price:'Valor por costo y precio',
Search_this_table:'Buscar esta tabla',
import_products:'Importar productos',
Field_optional:'Campo opcional',
Download_exemple:'Descargar ejemplo',
field_must_be_in_csv_format:'El campo debe estar en formato csv',
Successfully_Imported:'Importada exitosamente',
file_size_must_be_less_than_1_mega:'El tamaño del archivo debe ser inferior a 1 mega',
Please_follow_the_import_instructions:'Siga las instrucciones de importación.',
must_be_exist:'la unidad ya debe estar creada',
Import_Customers:'Importar clientes',
Import_Suppliers:'Proveedores de importación',
Recent_Sales:'Ventas recientes',
Create_Transfer:'Crear transferencia',
order_products:'encargar artículos',
Search_Product_by_Code_Name:'Buscar producto por código o nombre',
Reports_payments_Purchase_Return:'Informes Pagos de devolución de compra',
Reports_payments_Sale_Return:'Informes Pagos de devolución de venta',
payments_Sales_Return:'pagos ventas Devolución',
payments_Purchases_Return:'pagos compras Devolución',
CreateSaleReturn:'Crear devolución de venta',
EditSaleReturn:'Editar devolución de venta Sale Return',
SalesReturn:'Devolución de ventas',
CreatePurchaseReturn:'Crear devolución de compra',
EditPurchaseReturn:'Editar devolución de compra',
PurchasesReturn:'Devolución de compras',
Due:'debido',
Profit:'Lucro',
Revenue:'Ingresos',
Sales_today:'Ventas hoy',
People:'Gente',
Successfully_Created:'Creado con éxito',
Successfully_Updated:'Actualizado exitosamente',
Success:'Éxito',
Failed:'fallido',
Warning:'Advertencia',
Please_fill_the_form_correctly:'Por favor complete el formulario correctamente',
Field_is_required:'Se requiere campo',
Error:'Error!',
you_are_not_authorized:'¡Perdón! usted no está autorizado.',
Go_back_to_home:'Volver a la página principal',
page_not_exist:'¡Perdón! La página que buscaba no existe.',
Choose_Status:'Elija estado',
Choose_Method:'Elija el método',
Choose_Symbology:'Elija simbología',
Choose_Category:'Elegir la categoría',
Choose_Customer:'Elija cliente',
Choose_Supplier:'Elija proveedor',
Choose_Unit_Purchase:'Elija unidad de compra',
Choose_Sub_Category:'Elija subcategoría',
Choose_Brand:'Elija marca',
Choose_Warehouse:'Elija Almacén',
Choose_Unit_Sale:'Elija la unidad de venta',
Enter_Product_Cost:'Ingrese el costo del producto',
Enter_Stock_alert:'Entrar alerta de stock',
Choose_Unit_Product:'Elija la unidad de producto',
Enter_Product_Price:'Ingrese el precio del producto',
Enter_Name_Product:'Ingrese el nombre del producto',
Enter_Role_Name:'Ingrese el nombre del rol',
Enter_Role_Description:'Ingrese la descripción del rol',
Enter_name_category:'Ingrese el nombre de la categoría',
Enter_Code_category:'Ingrese el código de la categoría',
Enter_Name_Brand:'Ingrese el nombre de la marca',
Enter_Description_Brand:'Ingrese la descripción de la marca',
Enter_Code_Currency:'Ingrese la moneda del código',
Enter_name_Currency:'Ingrese el nombre Moneda',
Enter_Symbol_Currency:'Ingrese la moneda del símbolo',
Enter_Name_Unit:'Ingrese el nombre de la unidad',
Enter_ShortName_Unit:'Introduzca la unidad de nombre corto',
Choose_Base_Unit:'Elija la unidad base',
Choose_Operator:'Elegir Operadora',
Enter_Operation_Value:'Ingrese el valor de la operación',
Enter_Name_Warehouse:'Ingrese el nombre del almacén',
Enter_Phone_Warehouse:'Ingrese el teléfono del almacén',
Enter_Country_Warehouse:'Ingrese el país del almacén',
Enter_City_Warehouse:'Ingrese la ciudad del almacén',
Enter_Email_Warehouse:'Ingrese el correo electrónico del almacén',
Enter_ZipCode_Warehouse:'Ingrese el código postal del almacén',
Choose_Currency:'Elegir Moneda',
Thank_you_for_your_business:'¡Gracias por su negocios!',
Cancel:'Cancelar',
New_Customer:'Nueva cliente',
Incorrect_Login:'Inicio de sesión incorrecto',
Successfully_Logged_In:'Inicio de sesión exitoso',
This_user_not_active:'Esta usuaria no activa',
SignIn:'Registrarse',
Create_an_account:'Crea una cuenta',
Forgot_Password:'Has olvidado tu contraseña ?',
Email_Address:'Dirección de correo electrónico',
SignUp:'Inscribirse',
Already_have_an_account:'Ya tienes una cuenta ?',
Reset_Password:'Restablecer la contraseña',
Failed_to_authenticate_on_SMTP_server:'No se pudo autenticar en el servidor SMTP',
We_cant_find_a_user_with_that_email_addres:'No podemos encontrar un usuario con esa dirección de correo electrónico',
We_have_emailed_your_password_reset_link:'Hemos enviado su enlace de restablecimiento de contraseña por correo electrónico',
Please_fill_the_Email_Adress:'Por favor complete la dirección de correo electrónico',
Confirm_password:'Confirmar Contraseña',
Your_Password_has_been_changed:'Tu contraseña ha sido cambiada',
The_password_confirmation_does_not_match:'La confirmación de la contraseña no coincide',
This_password_reset_token_is_invalid:'Este token de restablecimiento de contraseña no es válido',
Warehouse_report:'Informe de almacén',
All_Warehouses:'Todos los almacenes',
Expense_List:'Lista de gastos',
Expenses:'Gastos',
This_Week_Sales_Purchases:'Ventas y compras de esta semana',
Top_Selling_Products:'Productos más vendidos',
View_all:'Ver todo',
Payment_Sent_Received:'Pago enviado y recibido',
Filter:"Filtrar",
Invoice_POS:"Factura POS",
Invoice:"Factura",
Customer_Info:"Información del cliente",
Company_Info:"Información de la compañía",
Invoice_Info:"Información de la factura",
Order_Summary:"Resumen del pedido",
Quote_Info:"Información de cotización",
Del:"Eliminar",
SuppliersPaiementsReport:"Informe de pagos a proveedores",
Purchase_Info:"Información de compra",
Supplier_Info:"Información del proveedor",
Return_Info:"info de devolución",
Expense_Category:"Categoría de gastos",
Create_Expense:"Crear gasto",
Details:"Detalles",
Discount_Method:"Método de descuento",
Net_Unit_Cost:"Costo unitario neto",
Net_Unit_Price:"Precio unitario neto",
Edit_Expense:"Editar gasto",
All_Brand:"Toda la marca",
All_Category:"Todas las categorías",
ListExpenses:"Lista de gastos",
Create_Permission:"Crear permiso",
Edit_Permission:"Editar permiso",
Reports_payments_Sales:"Reportes pagos Ventas",
Reports_payments_Purchases:"Reporta pagos Compras",
Reports_payments_Return_Customers:"Informes pagos Clientes devueltos",
Reports_payments_Return_Suppliers:"Proveedores de vuelta de los pagos de los informes",
stockyVersion:"No puede hacer esto en la versión de stockystración",
Expense_Deleted:"Este gasto ha sido eliminado",
Expense_Updated:"Este gasto se ha actualizado",
Expense_Created:"Este gasto ha sido creado",
Filesize:"Tamaño del archivo",
GenerateBackup:"Generar respaldo",
BackupDatabase:"Base de datos de respaldo",
Backup:"Base de datos de respaldo",
OrderStatistics:"Estadísticas de ventas",
AlreadyAdd:"Este producto ya ha sido agregado",
AddProductToList:"Agregue un producto a la lista",
AddQuantity:"Agregue la cantidad",
InvalidData:"Fecha inválida",
LowStock:"la cantidad excede la cantidad disponible en stock",
WarehouseIdentical:"Los almacenes no pueden ser iguales",
VariantDuplicate:"Esta variante está duplicada",
Paid:"Pagado",
Unpaid:"No pagado",
IncomeExpenses:"Ingresos y gastos",
dailySalesPurchases:"Ventas y Compras diarias",
ProductsExpired:"Productos caducados",
Today:"hoy",
Income:"Ingresos"},
_defineProperty(_Received_Amount$Payi,"Expenses","Gastos"),_defineProperty(_Received_Amount$Payi,"Sale","rebaja"),_defineProperty(_Received_Amount$Payi,"Actif","Activo"),_defineProperty(_Received_Amount$Payi,"Inactif","Inactivo"),_defineProperty(_Received_Amount$Payi,"Customers","Clientes"),_defineProperty(_Received_Amount$Payi,"Phone","Teléfono"),_defineProperty(_Received_Amount$Payi,"SearchByPhone","Buscar por teléfono"),_defineProperty(_Received_Amount$Payi,"Suppliers","Proveedores"),_defineProperty(_Received_Amount$Payi,"Quotations","Citas"),_defineProperty(_Received_Amount$Payi,"Sales","Ventas"),_defineProperty(_Received_Amount$Payi,"Purchases","Compras"),_defineProperty(_Received_Amount$Payi,"Returns","Devoluciones"),_defineProperty(_Received_Amount$Payi,"Settings","Configuraciones"),_defineProperty(_Received_Amount$Payi,"SystemSettings","Ajustes del sistema"),_defineProperty(_Received_Amount$Payi,"Users","Los usuarios"),_defineProperty(_Received_Amount$Payi,"GroupPermissions","Permisos de grupo"),_defineProperty(_Received_Amount$Payi,"Currencies","Monedas"),_defineProperty(_Received_Amount$Payi,"Warehouses","Almacenes"),_defineProperty(_Received_Amount$Payi,"Units","Unidades"),_defineProperty(_Received_Amount$Payi,"UnitsPrchases"," Compra de unidades"),_defineProperty(_Received_Amount$Payi,"UnitsSales","Ventas de unidades"),_defineProperty(_Received_Amount$Payi,"Reports","Informes"),_defineProperty(_Received_Amount$Payi,"PaymentsReport","Informe de pagos"),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases","Compras de pagos"),_defineProperty(_Received_Amount$Payi,"PaymentsSales","Venta de pagos"),_defineProperty(_Received_Amount$Payi,"PaymentsReturns","Devolución de pagos"),_defineProperty(_Received_Amount$Payi,"ProfitandLoss","Ganancia y perdida"),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart","Gráfico de acciones de almacén"),_defineProperty(_Received_Amount$Payi,"SalesReport","Reporte de ventas"),_defineProperty(_Received_Amount$Payi,"PurchasesReport","Informe de compras"),_defineProperty(_Received_Amount$Payi,"CustomersReport","Informe de clientes"),_defineProperty(_Received_Amount$Payi,"SuppliersReport","Informe de proveedores"),_defineProperty(_Received_Amount$Payi,"SupplierReport","Informe del proveedor"),_defineProperty(_Received_Amount$Payi,"DailySalesData","Datos de ventas diarias"),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData","Datos de compras diarias"),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords","Últimos cinco registros"),_defineProperty(_Received_Amount$Payi,"Filters","Filtros"),_defineProperty(_Received_Amount$Payi,"date","fecha"),_defineProperty(_Received_Amount$Payi,"Reference","Referencia"),_defineProperty(_Received_Amount$Payi,"Supplier","Proveedor"),_defineProperty(_Received_Amount$Payi,"PaymentStatus","Estado de pago"),_defineProperty(_Received_Amount$Payi,"Customer","Cliente"),_defineProperty(_Received_Amount$Payi,"CustomerCode","Código de cliente"),_defineProperty(_Received_Amount$Payi,"Status","Estado"),_defineProperty(_Received_Amount$Payi,"SupplierCode","Código de proveedor"),_defineProperty(_Received_Amount$Payi,"Categorie","Categoría"),_defineProperty(_Received_Amount$Payi,"Categories","Categorias"),_defineProperty(_Received_Amount$Payi,"StockTransfers","Transferencias de stock"),_defineProperty(_Received_Amount$Payi,"StockManagement","Gestion de Stocks"),_defineProperty(_Received_Amount$Payi,"dashboard","Tablero"),_defineProperty(_Received_Amount$Payi,"Products","Productos"),_defineProperty(_Received_Amount$Payi,"productsList","lista de productos"),_defineProperty(_Received_Amount$Payi,"ProductManagement","Gestion de producto"),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts","Alertas de cantidad de producto"),_defineProperty(_Received_Amount$Payi,"CodeProduct","Código de producto"),_defineProperty(_Received_Amount$Payi,"ProductTax","Impuesto de producto"),_defineProperty(_Received_Amount$Payi,"SubCategorie","Subcategoría"),_defineProperty(_Received_Amount$Payi,"Name_product","Designacion"),_defineProperty(_Received_Amount$Payi,"StockAlert","Alerta de stock"),_defineProperty(_Received_Amount$Payi,"warehouse","almacén"),_defineProperty(_Received_Amount$Payi,"Tax","Impuesto"),_defineProperty(_Received_Amount$Payi,"BuyingPrice","Precio de compra"),_defineProperty(_Received_Amount$Payi,"SellPrice","Precio de venta"),_defineProperty(_Received_Amount$Payi,"Quantity","Cantidad"),_defineProperty(_Received_Amount$Payi,"UnitSale","Venta de unidades"),_defineProperty(_Received_Amount$Payi,"UnitPurchase","Compra de unidad"),_defineProperty(_Received_Amount$Payi,"All","todos"),_defineProperty(_Received_Amount$Payi,"EditProduct","Editar producto"),_defineProperty(_Received_Amount$Payi,"AddProduct","Añadir Producto"),_defineProperty(_Received_Amount$Payi,"SearchByCode","Buscar por código"),_defineProperty(_Received_Amount$Payi,"SearchByName","Buscar por nombre"),_defineProperty(_Received_Amount$Payi,"ProductDetails","Detalles de producto"),_defineProperty(_Received_Amount$Payi,"CustomerName","Nombre del cliente"),_defineProperty(_Received_Amount$Payi,"CustomerManagement","Gestión de clientes"),_defineProperty(_Received_Amount$Payi,"Add","Añadir"),_defineProperty(_Received_Amount$Payi,"add","Añadir"),_defineProperty(_Received_Amount$Payi,"Edit","Editar"),_defineProperty(_Received_Amount$Payi,"Close","Cerrar"),_defineProperty(_Received_Amount$Payi,"PleaseSelect","Por favor seleccione"),_defineProperty(_Received_Amount$Payi,"Action","Acción"),_defineProperty(_Received_Amount$Payi,"Email","Email"),_defineProperty(_Received_Amount$Payi,"EditCustomer","Editar cliente"),_defineProperty(_Received_Amount$Payi,"AddCustomer","Agregar cliente"),_defineProperty(_Received_Amount$Payi,"Country","País"),_defineProperty(_Received_Amount$Payi,"City","Ciudad"),_defineProperty(_Received_Amount$Payi,"Adress","Dirección"),_defineProperty(_Received_Amount$Payi,"CustomerDetails","Detalles del cliente"),_defineProperty(_Received_Amount$Payi,"CustomersList","Lista de clientes"),_defineProperty(_Received_Amount$Payi,"SupplierCode","Código de proveedor"),_defineProperty(_Received_Amount$Payi,"SupplierName","Nombre del proveedor"),_defineProperty(_Received_Amount$Payi,"SuppliersManagement","Gerencia de Proveedores"),_defineProperty(_Received_Amount$Payi,"SupplierDetails","Detalles del proveedor"),_defineProperty(_Received_Amount$Payi,"QuotationsManagement","Gestión de cotizaciones"),_defineProperty(_Received_Amount$Payi,"SubTotal","Total parcial"),_defineProperty(_Received_Amount$Payi,"MontantReste","Cantidad restante"),_defineProperty(_Received_Amount$Payi,"complete","completar"),_defineProperty(_Received_Amount$Payi,"EnAttendant","pendiente"),_defineProperty(_Received_Amount$Payi,"Recu","Recibido"),_defineProperty(_Received_Amount$Payi,"partial","Parcial"),_defineProperty(_Received_Amount$Payi,"Retournee","Regreso"),_defineProperty(_Received_Amount$Payi,"DetailQuote","Cotización detallada"),_defineProperty(_Received_Amount$Payi,"EditQuote","Editar cotización"),_defineProperty(_Received_Amount$Payi,"CreateSale","Crear venta"),_defineProperty(_Received_Amount$Payi,"DownloadPdf","Descargar PDF"),_defineProperty(_Received_Amount$Payi,"QuoteEmail","Presupuesto enviado por correo electrónico"),_defineProperty(_Received_Amount$Payi,"DeleteQuote","Eliminar cotización"),_defineProperty(_Received_Amount$Payi,"AddQuote","Agregar cotización"),_defineProperty(_Received_Amount$Payi,"SelectProduct","Seleccionar producto"),_defineProperty(_Received_Amount$Payi,"ProductCodeName","Producto (Código - Nombre)"),_defineProperty(_Received_Amount$Payi,"Price","Precio"),_defineProperty(_Received_Amount$Payi,"CurrentStock","Stock"),_defineProperty(_Received_Amount$Payi,"Total","Total"),_defineProperty(_Received_Amount$Payi,"Num","N°"),_defineProperty(_Received_Amount$Payi,"Unitcost","Costo unitario"),_defineProperty(_Received_Amount$Payi,"to","a"),_defineProperty(_Received_Amount$Payi,"Subject","Sujeto"),_defineProperty(_Received_Amount$Payi,"Message","Mensaje"),_defineProperty(_Received_Amount$Payi,"EmailCustomer","Cliente de correo electrónico"),_defineProperty(_Received_Amount$Payi,"Sent","Enviar"),_defineProperty(_Received_Amount$Payi,"Quote","cotización"),_defineProperty(_Received_Amount$Payi,"Hello","Hola"),_defineProperty(_Received_Amount$Payi,"AttachmentQuote","Encuentra el archivo adjunto para tu cotización"),_defineProperty(_Received_Amount$Payi,"AddProducts","Agregar productos a la lista de pedidos"),_defineProperty(_Received_Amount$Payi,"SelectWarehouse","Por favor seleccione almacén"),_defineProperty(_Received_Amount$Payi,"SelectCustomer","Seleccionar cliente"),_defineProperty(_Received_Amount$Payi,"SalesManagement","Gestión de ventas"),_defineProperty(_Received_Amount$Payi,"Balance","saldo"),_defineProperty(_Received_Amount$Payi,"QtyBack","regreso cantidad"),_defineProperty(_Received_Amount$Payi,"TotalReturn","Regreso total"),_defineProperty(_Received_Amount$Payi,"Amount","monto"),_defineProperty(_Received_Amount$Payi,"SaleDetail","Detalle de venta"),_defineProperty(_Received_Amount$Payi,"EditSale","Editar venta"),_defineProperty(_Received_Amount$Payi,"AddSale","Añadir venta"),_defineProperty(_Received_Amount$Payi,"ShowPayment","Mostrar pagos"),_defineProperty(_Received_Amount$Payi,"AddPayment","Agregar pago"),_defineProperty(_Received_Amount$Payi,"EditPayment","Editar pago"),_defineProperty(_Received_Amount$Payi,"EmailSale","Enviar venta en correo electrónico"),_defineProperty(_Received_Amount$Payi,"DeleteSale","Eliminar venta"),_defineProperty(_Received_Amount$Payi,"ModePaiement","Modo de pago"),_defineProperty(_Received_Amount$Payi,"Paymentchoice","Opción de pago"),_defineProperty(_Received_Amount$Payi,"Note","Nota"),_defineProperty(_Received_Amount$Payi,"PaymentComplete","¡Pago completo!"),_defineProperty(_Received_Amount$Payi,"PurchasesManagement","Gestión de compras"),_defineProperty(_Received_Amount$Payi,"Ordered","Ordenado"),_defineProperty(_Received_Amount$Payi,"DeletePurchase","Eliminar compra"),_defineProperty(_Received_Amount$Payi,"EmailPurchase","Enviar compra por correo electrónico"),_defineProperty(_Received_Amount$Payi,"EditPurchase","Editar compra"),_defineProperty(_Received_Amount$Payi,"PurchaseDetail","Detalle de compra"),_defineProperty(_Received_Amount$Payi,"AddPurchase","Añadir compra"),_defineProperty(_Received_Amount$Payi,"EmailSupplier","Correo electrónico del proveedor"),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice","Compras pagos"),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData","Datos de pagos de compras"),_defineProperty(_Received_Amount$Payi,"SalesInvoice","Pagos de ventas"),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData","Datos de pagos de ventas"),_defineProperty(_Received_Amount$Payi,"UserManagement","gestión de usuarios"),_defineProperty(_Received_Amount$Payi,"Firstname","Primer nombre"),_defineProperty(_Received_Amount$Payi,"lastname","nombre de familia"),_defineProperty(_Received_Amount$Payi,"username","NOMBRE DE USUARIO"),_defineProperty(_Received_Amount$Payi,"password","CONTRASEÑA"),_defineProperty(_Received_Amount$Payi,"Newpassword","Nueva contraseña"),_defineProperty(_Received_Amount$Payi,"ChangeAvatar","Cambiar avatar"),_defineProperty(_Received_Amount$Payi,"LeaveBlank","Deje este campo en blanco si no lo ha cambiado."),_defineProperty(_Received_Amount$Payi,"type","tipo"),_defineProperty(_Received_Amount$Payi,"UserPermissions","Permisos de usuarios"),_defineProperty(_Received_Amount$Payi,"RoleName","Nombre de rol"),_defineProperty(_Received_Amount$Payi,"RoleDescription","Descripción del rol"),_defineProperty(_Received_Amount$Payi,"AddPermissions","Agregar permisos"),_defineProperty(_Received_Amount$Payi,"View","Ver"),_defineProperty(_Received_Amount$Payi,"Del","Eliminar"),_defineProperty(_Received_Amount$Payi,"NewAdjustement","Nuevo ajuste"),_defineProperty(_Received_Amount$Payi,"EditAdjustement","Editar ajuste"),_defineProperty(_Received_Amount$Payi,"CannotSubstraction","No puede restar productos que tienen stock 0"),_defineProperty(_Received_Amount$Payi,"Addition","Adición"),_defineProperty(_Received_Amount$Payi,"Subtraction","Sustracción"),_defineProperty(_Received_Amount$Payi,"profil","perfil"),_defineProperty(_Received_Amount$Payi,"logout","cerrar sesión"),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid","no puede modificar porque esta compra ya ha pagado"),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid","no puede modificar porque esta venta ya pagó"),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid","no se puede modificar porque esta devolución ya ha pagado"),_defineProperty(_Received_Amount$Payi,"QuoteAlready","Este cotización ya ha generado ventas"),_defineProperty(_Received_Amount$Payi,"QuotationComplete","Esta cita completa"),_defineProperty(_Received_Amount$Payi,"SiteConfiguration","Configuración del sitio"),_defineProperty(_Received_Amount$Payi,"Language","Idioma"),_defineProperty(_Received_Amount$Payi,"DefaultCurrency","Moneda predeterminada"),_defineProperty(_Received_Amount$Payi,"LoginCaptcha","Captcha de inicio de sesión"),_defineProperty(_Received_Amount$Payi,"DefaultEmail","Email predeterminado"),_defineProperty(_Received_Amount$Payi,"SiteName","Nombre del sitio"),_defineProperty(_Received_Amount$Payi,"ChangeLogo","Cambiar logo"),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration","Configuración SMTP"),_defineProperty(_Received_Amount$Payi,"HOST","hueste"),_defineProperty(_Received_Amount$Payi,"PORT","PUERTO"),_defineProperty(_Received_Amount$Payi,"encryption","Cifrado"),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect","Configuración SMTP incorrecta"),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices","Devolver facturas"),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData","Devolver datos de factura"),_defineProperty(_Received_Amount$Payi,"ShowAll","Mostrar todos los registros de todos los usuarios"),_defineProperty(_Received_Amount$Payi,"Discount","Descuento"),_defineProperty(_Received_Amount$Payi,"OrderTax","Impuesto de orden"),_defineProperty(_Received_Amount$Payi,"Shipping","Envío"),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies","Monedas de gestión"),_defineProperty(_Received_Amount$Payi,"CurrencyCode","Código de moneda"),_defineProperty(_Received_Amount$Payi,"CurrencyName","Nombre de moneda"),_defineProperty(_Received_Amount$Payi,"Symbol","Símbolo"),_defineProperty(_Received_Amount$Payi,"CompanyName","Nombre de empresa"),_defineProperty(_Received_Amount$Payi,"CompanyPhone","Teléfono de la empresa"),_defineProperty(_Received_Amount$Payi,"CompanyAdress","Dirección de la empresa"),_defineProperty(_Received_Amount$Payi,"Code","Código"),_defineProperty(_Received_Amount$Payi,"image","imagen"),_defineProperty(_Received_Amount$Payi,"Printbarcode","Imprimir código de barras"),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers","Devuelve ventas"),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers","Devoluciones de compras"),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers","facturas Ventas devolución"),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers","facturas devoluciones compras"),_defineProperty(_Received_Amount$Payi,"NodataAvailable","Datos no disponibles"),_defineProperty(_Received_Amount$Payi,"ProductImage","Imagen del producto"),_defineProperty(_Received_Amount$Payi,"Barcode","Código de barras"),_defineProperty(_Received_Amount$Payi,"pointofsales","puntos de venta"),_defineProperty(_Received_Amount$Payi,"CustomUpload","Subida personalizada"),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement","gestión punto de venta"),_defineProperty(_Received_Amount$Payi,"Adjustment","Ajustamiento"),_defineProperty(_Received_Amount$Payi,"Updat","Actualizar"),_defineProperty(_Received_Amount$Payi,"Reset","Reiniciar"),_defineProperty(_Received_Amount$Payi,"print","impresión"),_defineProperty(_Received_Amount$Payi,"SearchByEmail","Buscar por correo "),_defineProperty(_Received_Amount$Payi,"ChooseProduct","Elegir producto"),_defineProperty(_Received_Amount$Payi,"Qty","Cantidad"),_defineProperty(_Received_Amount$Payi,"Items","Artículos"),_defineProperty(_Received_Amount$Payi,"AmountHT","monto HT"),_defineProperty(_Received_Amount$Payi,"AmountTTC","monto TTC"),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier","Seleccione Proveedor"),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut","seleccione estado"),_defineProperty(_Received_Amount$Payi,"PayeBy","Pagado con"),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse","Elija Almacén"),_defineProperty(_Received_Amount$Payi,"payNow","Pagar ahora"),_defineProperty(_Received_Amount$Payi,"ListofCategory","Lista de categoría"),_defineProperty(_Received_Amount$Payi,"Description","Descripción"),_defineProperty(_Received_Amount$Payi,"submit","guardar"),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice","Hubo un problema al crear esta factura. Inténtalo de nuevo"),_defineProperty(_Received_Amount$Payi,"ProblemPayment","Hubo un problema con el pago. Inténtalo de nuevo"),_defineProperty(_Received_Amount$Payi,"CreateAdjustment","Crear ajuste"),_defineProperty(_Received_Amount$Payi,"Afewwords","unas palabras sobre ..."),_defineProperty(_Received_Amount$Payi,"UserImage","Imagen de usuario"),_defineProperty(_Received_Amount$Payi,"UpdateProduct","Actualizar producto"),_defineProperty(_Received_Amount$Payi,"Brand","Marca"),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology","Simbología de códigos de barras"),_defineProperty(_Received_Amount$Payi,"ProductCost","Costo del producto"),_defineProperty(_Received_Amount$Payi,"ProductPrice","Precio del producto"),_defineProperty(_Received_Amount$Payi,"UnitProduct","Producto unitario"),_defineProperty(_Received_Amount$Payi,"TaxMethod","Método de impuestos"),_defineProperty(_Received_Amount$Payi,"MultipleImage","Imagen múltiple"),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants","El producto tiene múltiples variantes"),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion","El producto tiene promoción"),_defineProperty(_Received_Amount$Payi,"PromotionStart","Inicio de promoción"),_defineProperty(_Received_Amount$Payi,"PromotionEnd","Fin de la promoción"),_defineProperty(_Received_Amount$Payi,"PromotionPrice","Precio de promoción"),_defineProperty(_Received_Amount$Payi,"Price","Precio"),_defineProperty(_Received_Amount$Payi,"Cost","Costo"),_defineProperty(_Received_Amount$Payi,"Unit","Unidad"),_defineProperty(_Received_Amount$Payi,"ProductVariant","Variante de producto"),_defineProperty(_Received_Amount$Payi,"Variant","Variante"),_defineProperty(_Received_Amount$Payi,"UnitPrice","Precio unitario"),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer","Crear devolución de cliente"),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer","Editar devolución de cliente"),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier","Crear devolución de proveedor"),_defineProperty(_Received_Amount$Payi,"Documentation","Documentación"),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier","Editar devolución de proveedor"),_defineProperty(_Received_Amount$Payi,"FromWarehouse","De almacén"),_defineProperty(_Received_Amount$Payi,"ToWarehouse","Al almacén"),_defineProperty(_Received_Amount$Payi,"EditTransfer","Editar transferencia"),_defineProperty(_Received_Amount$Payi,"TransferDetail","Detalle de transferencia"),_defineProperty(_Received_Amount$Payi,"Pending","Pendiente"),_defineProperty(_Received_Amount$Payi,"Received","Recibido"),_defineProperty(_Received_Amount$Payi,"Ordered","Ordenado"),_defineProperty(_Received_Amount$Payi,"PermissionsManager","Administrador de permisos"),_defineProperty(_Received_Amount$Payi,"BrandManager","Gerente de marca"),_defineProperty(_Received_Amount$Payi,"BrandImage","Imagen de marca"),_defineProperty(_Received_Amount$Payi,"BrandName","Nombre de la marca"),_defineProperty(_Received_Amount$Payi,"BrandDescription","Descripción de marca"),_defineProperty(_Received_Amount$Payi,"BaseUnit","Unidad base"),_defineProperty(_Received_Amount$Payi,"ManagerUnits","Unidades gestoras"),_defineProperty(_Received_Amount$Payi,"OperationValue","Valor de operación"),_defineProperty(_Received_Amount$Payi,"Operator","Operador"),_defineProperty(_Received_Amount$Payi,"Top5Products","Los 5 mejores productos"),_defineProperty(_Received_Amount$Payi,"Last5Sales","Últimas 5 ventas"),_defineProperty(_Received_Amount$Payi,"ListAdjustments","Lista de ajustes"),_defineProperty(_Received_Amount$Payi,"ListTransfers","Lista de transferencias"),_defineProperty(_Received_Amount$Payi,"CreateTransfer","Crear transferencia"),_defineProperty(_Received_Amount$Payi,"OrdersManager","Gerente de pedidos"),_defineProperty(_Received_Amount$Payi,"ListQuotations","List Quotations"),_defineProperty(_Received_Amount$Payi,"ListPurchases","Lista de compras"),_defineProperty(_Received_Amount$Payi,"ListSales","Lista de ventas"),_defineProperty(_Received_Amount$Payi,"ListReturns","Lista de devoluciones"),_defineProperty(_Received_Amount$Payi,"PeopleManager","Gerente de personas"),_defineProperty(_Received_Amount$Payi,"ListofBrand","Lista de marcas"),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:"Estas seguro ?",
Text:"¡No podrás revertir esto!",
confirmButtonText:"Sí, bórralo!",
cancelButtonText:"Cancelar",
Deleted:"Eliminado!",
Failed:"¡Ha fallado!",
Therewassomethingwronge:"Algo andaba mal",
CustomerDeleted:"Este cliente ha sido eliminado.",
SupplierDeleted:"este proveedor ha sido eliminado.",
QuoteDeleted:"esta cita ha sido eliminada.",
SaleDeleted:"esta venta ha sido eliminada.",
PaymentDeleted:"este pago ha sido eliminado.",
PurchaseDeleted:"esta compra ha sido eliminada.",
ReturnDeleted:"esta devolución ha sido eliminada.",
ProductDeleted:"este producto ha sido eliminado.",
ClientError:"Este cliente ya está vinculado con otra operación",
ProviderError:"Este proveedor ya está vinculado con otra operación",
UserDeleted:"Este usuario ha sido eliminado.",
UnitDeleted:"Esta unidad ha sido eliminada.",
RoleDeleted:"Este rol ha sido eliminado.",
TaxeDeleted:"Este impuesto ha sido eliminado.",
SubCatDeleted:"Esta subcategoría ha sido eliminada.",
CatDeleted:"Esta categoría ha sido eliminada.",
WarehouseDeleted:"Este almacén ha sido eliminado.",
AlreadyLinked:"este producto ya está vinculado con otra Operación",
AdjustDeleted:"Este ajuste ha sido eliminado.",
TitleCurrency:"Esta moneda ha sido eliminada",
TitleTransfer:"Transferir se ha eliminado correctamente",
BackupDeleted:"La copia de seguridad se ha eliminado correctamente",
TitleBrand:"Esta marca ha sido eliminada"}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleProfile:"Su perfil actualizado con éxito",
TitleAdjust:"Ajuste actualizado con éxito",
TitleRole:"Rol actualizado correctamente",
TitleUnit:"Unidad actualizada con éxito",
TitleUser:"Usuario actualizado con éxito",
TitleCustomer:"Cliente actualizado con éxito",
TitleQuote:"Presupuesto actualizado correctamente",
TitleSale:"Venta actualizada con éxito",
TitlePayment:"Pago actualizado correctamente",
TitlePurchase:"Compra actualizada con éxito",
TitleReturn:"Devolución actualizada con éxito",
TitleProduct:"Producto actualizado con éxito",
TitleSupplier:"Proveedor actualizado con éxito",
TitleTaxe:"Impuesto actualizado con éxito",
TitleCat:"Categoría actualizada con éxito",
TitleWarhouse:"Almacén actualizado con éxito",
TitleSetting:"Configuración  actualizado con éxito",
TitleCurrency:"Esta moneda ha sido actualizada",
TitleTransfer:"Transferir se actualizó correctamente",
TitleBrand:"Esta marca ha sido actualizada"}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:"Esta marca ha sido creada",
TitleTransfer:"Transferir se creó correctamente",
TitleRole:"Rol creado con éxito",
TitleUnit:"Unidad creada con éxito",
TitleUser:"Usuario creado con éxito",
TitleCustomer:"Cliente creado con éxito",
TitleQuote:"Cita creada con éxito",
TitleSale:"Venta creada con éxito",
TitlePayment:"Pago creado con éxito",
TitlePurchase:"Compra creada con éxito",
TitleReturn:"retorno Creada con éxito",
TitleProduct:"Producto creado con éxito",
TitleSupplier:"Proveedor creado con éxito",
TitleTaxe:"Impuesto creado con éxito",
TitleCat:"Categoría creada con éxito",
TitleWarhouse:"Almacén creado con éxito",
TitleAdjust:"Ajuste creado con éxito",
TitleCurrency:"Esta moneda ha sido creada"}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:"Enviar por correo electrónico con éxito"}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:"¡Esta venta ya está vinculada con una devolución!"}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement","Gestión de retorno"),_defineProperty(_Received_Amount$Payi,"ReturnDetail","Detalle de retorno"),_defineProperty(_Received_Amount$Payi,"EditReturn","Editar retorno"),_defineProperty(_Received_Amount$Payi,"AddReturn","Agregar retorno"),_defineProperty(_Received_Amount$Payi,"EmailReturn","Enviar retorno en correo electrónico"),_defineProperty(_Received_Amount$Payi,"DeleteReturn","Eliminar retorno"),_defineProperty(_Received_Amount$Payi,"Retoursurcharge","Recargo de retorno"),_defineProperty(_Received_Amount$Payi,"Laivrison","entrega"),_defineProperty(_Received_Amount$Payi,"SelectSale","Seleccionar venta"),_defineProperty(_Received_Amount$Payi,"ZeroPardefault","Puede eliminar el artículo o establecer la cantidad devuelta a cero si no se devuelve"),_defineProperty(_Received_Amount$Payi,"Return","retorno"),_defineProperty(_Received_Amount$Payi,"Purchase","Compra"),_defineProperty(_Received_Amount$Payi,"TotalSales","Ventas totales"),_defineProperty(_Received_Amount$Payi,"TotalPurchases","Compras totales"),_defineProperty(_Received_Amount$Payi,"TotalReturns","Devoluciones totales"),_defineProperty(_Received_Amount$Payi,"PaiementsNet","Pagos Netos"),_defineProperty(_Received_Amount$Payi,"PaiementsSent","Pagos enviados"),_defineProperty(_Received_Amount$Payi,"PaiementsReceived","Pagos recibidos"),_defineProperty(_Received_Amount$Payi,"Recieved","Recibido"),_defineProperty(_Received_Amount$Payi,"Sent","Expedido"),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts","Alertas de cantidad de producto"),_defineProperty(_Received_Amount$Payi,"ProductCode","Código de producto"),_defineProperty(_Received_Amount$Payi,"ProductName","nombre del producto"),_defineProperty(_Received_Amount$Payi,"AlertQuantity","Cantidad de alerta"),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart","Gráfico de acciones de almacén"),_defineProperty(_Received_Amount$Payi,"TotalProducts","Productos totales"),_defineProperty(_Received_Amount$Payi,"TotalQuantity","Cantidad total"),_defineProperty(_Received_Amount$Payi,"TopCustomers","Los 5 mejores clientes"),_defineProperty(_Received_Amount$Payi,"TotalAmount","monto total "),_defineProperty(_Received_Amount$Payi,"TotalPaid","Total pagado"),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport","Informe de ventas del cliente"),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport","Informe de pagos del cliente"),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport","Informe de cotizaciones de clientes"),_defineProperty(_Received_Amount$Payi,"Payments","Pagos"),_defineProperty(_Received_Amount$Payi,"TopSuppliers","Los 5 mejores proveedores"),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport","Informe de compras del proveedor"),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport","Informe de pagos a proveedores"),_defineProperty(_Received_Amount$Payi,"Name","Nombre"),_defineProperty(_Received_Amount$Payi,"Code","Código"),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse","Gestion de almacenes"),_defineProperty(_Received_Amount$Payi,"ZipCode","Código postal"),_defineProperty(_Received_Amount$Payi,"managementCategories","Gestión de categorías"),_defineProperty(_Received_Amount$Payi,"Codecategorie","Categoría de código"),_defineProperty(_Received_Amount$Payi,"Namecategorie","Categoría de nombre"),_defineProperty(_Received_Amount$Payi,"Parentcategorie","Categoría principal"),_defineProperty(_Received_Amount$Payi,"managementTax","Gestión fiscal"),_defineProperty(_Received_Amount$Payi,"TaxName","Nombre fiscal"),_defineProperty(_Received_Amount$Payi,"TaxRate","Tasa de impuesto"),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases","Gestión de la Unidad de Compras"),_defineProperty(_Received_Amount$Payi,"managementUnitSales","Gerencia de Unidad de Ventas"),_defineProperty(_Received_Amount$Payi,"ShortName","Nombre corto"),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct","Seleccione estos antes de agregar cualquier producto"),_defineProperty(_Received_Amount$Payi,"StockAdjustement","Ajuste de Stock"),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse","Seleccione almacén antes de elegir cualquier producto"),_defineProperty(_Received_Amount$Payi,"StockTransfer","Transferencia de acciones"),_defineProperty(_Received_Amount$Payi,"SelectPeriod","Seleccionar periodo"),_defineProperty(_Received_Amount$Payi,"ThisYear","Este año"),_defineProperty(_Received_Amount$Payi,"ThisToday","hoy"),_defineProperty(_Received_Amount$Payi,"ThisMonth","Este mes"),_defineProperty(_Received_Amount$Payi,"ThisWeek","Esta semana"),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail","Detalle de ajuste"),_defineProperty(_Received_Amount$Payi,"ActivateUser","Esta usuaria ha sido activada"),_defineProperty(_Received_Amount$Payi,"DisActivateUser","Esta usuaria ha sido desactivada"),_defineProperty(_Received_Amount$Payi,"NotFound","Página no encontrada."),_defineProperty(_Received_Amount$Payi,"oops","¡error! Página no encontrada."),_defineProperty(_Received_Amount$Payi,"couldNotFind","No pudimos encontrar la página que estaba buscando."),_defineProperty(_Received_Amount$Payi,"ReturnDashboard","volver al tablero"),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/fr.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/fr.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesFrJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Delete,_Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Français
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Montant reçu',
Paying_Amount:'Montant à payer',
Change:'changement',
Paying_amount_is_greater_than_Received_amount:'Le montant à payer est supérieur au montant reçu',
Paying_amount_is_greater_than_Grand_Total:'Le montant à payer est supérieur au montant total',
code_must_be_not_exist_already:'le code ne doit pas déjà exister',
You_will_find_your_backup_on:'Vous trouverez votre sauvegarde sur',
and_save_it_to_your_pc:'et enregistrez-le sur votre pc',
Scan_your_barcode_and_select_the_correct_symbology_below:'Scannez votre code-barres et sélectionnez la symbologie correcte ci-dessous',
Scan_Search_Product_by_Code_Name:'Scannez/recherchez un produit par nom de code',
Paper_size:'Taille de papier',
Clear_Cache:'Vider le cache',
Cache_cleared_successfully:'Cache vidé avec succès',
Failed_to_clear_cache:'Échec de vider du cache',
Scan_Barcode:'Scanner de code-barres',
Please_use_short_name_of_unit:'Veuillez utiliser le nom abrégé de l\'unité',
DefaultCustomer:'Client par défaut',
DefaultWarehouse:'Entrepôt par défaut',
Payment_Gateway:'Passerelle de paiement',
SMS_Configuration:'Configuration SMS',
Gateway:'Passerelle de paiement',
Choose_Gateway:'Choisissez la passerelle de paiement',
Send_SMS:'message envoyé avec succès',
sms_config_invalid:'configuration sms invalide',
Remove_Stripe_Key_Secret:'Supprimer les clés d\'API Stripe',
credit_card_account_not_available:'Compte de carte de crédit non disponible',
Credit_Card_Info:'Informations sur la carte de crédit',
developed_by:'Développé par',
Unit_already_linked_with_sub_unit:'Unité déjà liée à la sous-unité',
Total_Items_Quantity:'Total des articles et quantité',
Value_by_Cost_and_Price:'Valeur par coût et prix',
Search_this_table:'Rechercher dans ce tableau',
import_products:'Importer des produits',
Field_optional:'Champ facultatif',
Download_exemple:'Télécharger l\'exemple',
field_must_be_in_csv_format:'Le champ doit être au format csv',
Successfully_Imported:'Importé avec succès',
file_size_must_be_less_than_1_mega:'La taille du fichier doit être inférieure à 1 méga',
Please_follow_the_import_instructions:'Veuillez suivre les instructions d\'importation',
must_be_exist:'l\'unité doit déjà être créée',
Import_Customers:'Importer des clients',
Import_Suppliers:'Importer des fournisseurs',
Recent_Sales:'Ventes récentes',
Create_Transfer:'Créer un transfert',
order_products:'Products commandés',
Search_Product_by_Code_Name:'Rechercher un produit par code ou par nom',
Reports_payments_Purchase_Return:'Rapports sur les paiements de retour d\'achat',
Reports_payments_Sale_Return:'Rapports sur les paiements de retour de vente',
payments_Sales_Return:'Paiements retour de vente',
payments_Purchases_Return:'Paiements retour d\'achats',
CreateSaleReturn:'Créer un retour de vente',
EditSaleReturn:'Modifier le retour de vente',
SalesReturn:'Retour des ventes',
CreatePurchaseReturn:'Créer un retour d\'achat',
EditPurchaseReturn:'Modifier le retour d\'achat',
PurchasesReturn:'Retour des achats',
Due:'Dû',
Profit:'Profit',
Revenue:'Revenu',
Sales_today:'Ventes aujourd\'hui',
People:'Gens',
Successfully_Created:'Créé avec succès',
Successfully_Updated:'Mise à jour réussie',
Success:'Succès',
Failed:'Échec',
Warning:'Alert',
Error:'Erreur!',
you_are_not_authorized:'Pardon! vous n\'êtes pas autorisé.',
Go_back_to_home:'Retournez à la page d\'accueil',
page_not_exist:'Pardon! La page que vous recherchez n\'existe pas.',
Please_fill_the_form_correctly:'Veuillez remplir le formulaire correctement',
Field_is_required:'Champ requis',
Choose_Status:'Choisissez le statut',
Choose_Method:'Choisissez la méthode',
Choose_Symbology:'Choisissez la symbologie',
Choose_Category:'Choisissez la catégorie',
Choose_Customer:'Choisissez le client',
Choose_Supplier:'Choisissez un fournisseur',
Choose_Unit_Purchase:'Choisissez l\'unité d\'achat',
Choose_Sub_Category:'Choisissez la sous-catégorie',
Choose_Brand:'Choisissez la marque',
Choose_Warehouse:'Choisissez l\'entrepôt',
Choose_Unit_Sale:'Choisissez l\'unité de vente',
Enter_Product_Cost:'Entrez le coût du produit',
Enter_Stock_alert:'Entrer l\'alerte de stock',
Choose_Unit_Product:'Choisissez l\'unité de produit',
Enter_Product_Price:'Entrez le prix du produit',
Enter_Name_Product:'Entrez le nom du produit',
Enter_Role_Name:'Entrez le nom du rôle',
Enter_Role_Description:'Entrez la description du rôle',
Enter_name_category:'Entrez le nom de la catégorie',
Enter_Code_category:'Entrez le code de la catégorie',
Enter_Name_Brand:'Entrez le nom de la marque',
Enter_Description_Brand:'Entrez la description de la marque',
Enter_Code_Currency:'Entrez le code de devise',
Enter_name_Currency:'Entrez le nom Devise',
Enter_Symbol_Currency:'Entrez le symbole de la devise',
Enter_Name_Unit:'Entrez le nom de l`\'unité',
Enter_ShortName_Unit:'Entrez le nom abrégé de l\'unité',
Choose_Base_Unit:'Choisissez l\'unité de base',
Choose_Operator:'Choisissez un opérateur',
Enter_Operation_Value:'Entrez la valeur de l\'opération',
Enter_Name_Warehouse:'Entrez le nom de l\'entrepôt',
Enter_Phone_Warehouse:'Entrez le téléphone de l\'entrepôt',
Enter_Country_Warehouse:'Entrez le pays de l\'entrepôt',
Enter_City_Warehouse:'Entrez la ville de l\'entrepôt',
Enter_Email_Warehouse:'Entrez  e-mail de l\'entrepôt',
Enter_ZipCode_Warehouse:'Entrez le code postal de l\'entrepôt',
Choose_Currency:'Choisir la devise',
Thank_you_for_your_business:'Merci de votre confiance!',
Cancel:'Annuler',
New_Customer:'Nouveau client',
Incorrect_Login:'Login incorrect',
Successfully_Logged_In:'Connexion réussie',
This_user_not_active:'Cet utilisateur n\'est pas actif',
SignIn:'S\'identifier',
Create_an_account:'Créer un compte',
Forgot_Password:'Mot de passe oublié ?',
Email_Address:'Adresse e-mail',
SignUp:'S\'inscrire',
Already_have_an_account:'Vous avez déjà un compte ?',
Reset_Password:'réinitialiser le mot de passe',
Failed_to_authenticate_on_SMTP_server:'Échec de l\'authentification sur le serveur SMTP',
We_cant_find_a_user_with_that_email_addres:'Nous ne pouvons pas trouver un utilisateur avec cette adresse e-mail',
We_have_emailed_your_password_reset_link:'Nous avons envoyé votre lien de réinitialisation de mot de passe par e-mail',
Please_fill_the_Email_Adress:'Veuillez remplir l\'adresse e-mail',
Confirm_password:'Confirmez le mot de passe',
Your_Password_has_been_changed:'Votre mot de passe a été changé',
The_password_confirmation_does_not_match:'La confirmation du mot de passe ne correspond pas',
This_password_reset_token_is_invalid:'Ce jeton de réinitialisation de mot de passe n\'est pas valide',
Warehouse_report:'Rapport d\'entrepôt',
All_Warehouses:'Tous les entrepôts',
Expense_List:'Liste de dépenses',
Expenses:'dépenses',
This_Week_Sales_Purchases:'Ventes et achats de cette semaine',
Top_Selling_Products:'Produits les plus vendus',
View_all:'Voir tout',
Payment_Sent_Received:'Paiement envoyé et reçu',
Filter:'Filtre',
Invoice_POS:'Facture POS',
Invoice:'Facture',
Customer_Info:'Infos client',
Company_Info:'Infos société',
Invoice_Info:'Infos facture',
Order_Summary:'Résumé de la commande',
Quote_Info:'Devis Infos',
Del:'Effacer',
SuppliersPaiementsReport:'Fournisseurs Rapport Paiements',
Purchase_Info:'Infos d\'achat',
Supplier_Info:'Info fournisseur',
Return_Info:'Info de retour',
Expense_Category:'Catégorie de dépenses',
Create_Expense:'Créer une dépense',
Details:'Détails',
Discount_Method:'Méthode de remise',
Net_Unit_Cost:'Coût unitaire net',
Net_Unit_Price:'Prix unitaire net',
Edit_Expense:'Modifier les dépenses',
All_Brand:'Toute marque',
All_Category:'All Category',
ListExpenses:'Liste des dépenses',
Create_Permission:'Créer une autorisation',
Edit_Permission:'Modifier l\'autorisation',
Reports_payments_Sales:'Rapports des paiements des ventes',
Reports_payments_Purchases:'Rapports des achats de paiements',
Reports_payments_Return_Customers:'Rapports de paiements Clients de retour',
Reports_payments_Return_Suppliers:'Rapports des paiements Retour Fournisseurs',
Expense_Deleted:'Cette dépense a été supprimée',
Expense_Updated:'Cette dépense a été mise à jour',
Expense_Created:'Cette dépense a été créée',
DemoVersion:'Vous ne pouvez pas faire cela dans la version de démonstration',
OrderStatistics:'Statistiques de ventes',
AlreadyAdd:'Ce produit est déjà ajouté !!',
AddProductToList:'Veuillez ajouter le produit à la liste !!',
AddQuantity:'Veuillez ajouter la quantité de produit !!',
InvalidData:'Données invalides !!',
LowStock:'la quantité dépasse la quantité disponible en stock',
WarehouseIdentical:'Les deux magasins ne peuvent pas être identiques !!',
VariantDuplicate:'Cette variable est redondante !!',
Filesize:'Taille du fichier',
GenerateBackup:'Générer une sauvegarde',
BackupDatabase:'Sauvegarde de la base de données',
Backup:'Sauvegarde DB',
Paid:'Payé',
Unpaid:'Non payé',
IncomeExpenses:'Revenus et dépenses',
dailySalesPurchases:'Ventes et achats quotidiens',
ProductsExpired:'Produits expirés',
Today:'Aujourd\'hui',
Income:'Revenu'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Dépenses'),_defineProperty(_Received_Amount$Payi,"Sale",'Vente'),_defineProperty(_Received_Amount$Payi,"Phone",'Télé'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Filter par Télé'),_defineProperty(_Received_Amount$Payi,"Actif",'Active'),_defineProperty(_Received_Amount$Payi,"Inactif",'Inactive'),_defineProperty(_Received_Amount$Payi,"CustomerName",'Nom Client'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Gestion Du Stock'),_defineProperty(_Received_Amount$Payi,"dashboard",'Tableau de bord'),_defineProperty(_Received_Amount$Payi,"Products",'Produits'),_defineProperty(_Received_Amount$Payi,"productsList",'Liste de produits'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Stock Transfers'),_defineProperty(_Received_Amount$Payi,"Customers",'Clients'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Fournisseurs'),_defineProperty(_Received_Amount$Payi,"Quotations",'Devis'),_defineProperty(_Received_Amount$Payi,"Sales",'Ventes'),_defineProperty(_Received_Amount$Payi,"Purchases",'Achats'),_defineProperty(_Received_Amount$Payi,"Returns",'Returns'),_defineProperty(_Received_Amount$Payi,"Settings",'Paramètres'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'Paramètres du système'),_defineProperty(_Received_Amount$Payi,"Users",'Utilisateurs'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Autorisations de groupe'),_defineProperty(_Received_Amount$Payi,"Currencies",'Devises'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Produits Taxe'),_defineProperty(_Received_Amount$Payi,"Categories",'Categories'),_defineProperty(_Received_Amount$Payi,"Warehouses",'Entrepôt'),_defineProperty(_Received_Amount$Payi,"Units",'Unités'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'Unités Achats'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Unités Ventes'),_defineProperty(_Received_Amount$Payi,"Reports",'Rapports'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Paiements Rapports'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Paiements Achats'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Paiements Ventes'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Paiements Retours'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'Factures des retours'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'données des Factures de retours'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Afficher tous les enregistrements de tous les utilisateurs'),_defineProperty(_Received_Amount$Payi,"Discount",'Remise'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Taxe de commande'),_defineProperty(_Received_Amount$Payi,"Shipping",'livraison'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Profit et perte'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Alertes de quantité'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Warehouse Stock Chart'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Ventes Rapports'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Achats Rapports'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Clients Rapports'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Fournisseurs Rapports'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Fournisseur Rapports'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Ventes quotidiens'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Achats quotidiens'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Dernières cinq records'),_defineProperty(_Received_Amount$Payi,"Filters",'Filtres'),_defineProperty(_Received_Amount$Payi,"date",'Date'),_defineProperty(_Received_Amount$Payi,"Reference",'Référence'),_defineProperty(_Received_Amount$Payi,"Supplier",'Fournisseur'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Statut de Paiement'),_defineProperty(_Received_Amount$Payi,"Customer",'Client'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Client Code'),_defineProperty(_Received_Amount$Payi,"Status",'Statut'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Fournisseur Code'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Gestion des Produits'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Code Produit'),_defineProperty(_Received_Amount$Payi,"Categorie",'Catégorie'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'Sous-catégorie'),_defineProperty(_Received_Amount$Payi,"Name_product",'Désignation'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Stock Alert'),_defineProperty(_Received_Amount$Payi,"warehouse",'Magasin'),_defineProperty(_Received_Amount$Payi,"Tax",'Taxe'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Prix d\'achat'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Prix de vente'),_defineProperty(_Received_Amount$Payi,"Quantity",'Quantité'),_defineProperty(_Received_Amount$Payi,"Action",'Action'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Unités de Vente'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Unités d\'achat'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'Détails Produit'),_defineProperty(_Received_Amount$Payi,"All",'Tous'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Modifier Produit'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Ajouter Produit'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Filter par Code'),_defineProperty(_Received_Amount$Payi,"SearchByName",'Filter par Nom'),_defineProperty(_Received_Amount$Payi,"Add",'Ajouter'),_defineProperty(_Received_Amount$Payi,"add",'Ajouter'),_defineProperty(_Received_Amount$Payi,"Edit",'Modifier'),_defineProperty(_Received_Amount$Payi,"Close",'Fermer'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Veuillez sélectionner'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Gestion Du Clients'),_defineProperty(_Received_Amount$Payi,"Email",'Email'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Modifier Client'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Ajouter Client'),_defineProperty(_Received_Amount$Payi,"Country",'Pays'),_defineProperty(_Received_Amount$Payi,"City",'Ville'),_defineProperty(_Received_Amount$Payi,"Adress",'Adresse'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'Détails Client'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Liste Des Clients'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Code Fournisseur'),_defineProperty(_Received_Amount$Payi,"SupplierName",'Nom Fournisseur'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Gestion des Fournisseurs'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Détails Fournisseur'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Gestion des Devis'),_defineProperty(_Received_Amount$Payi,"SubTotal",'Grand Total'),_defineProperty(_Received_Amount$Payi,"complete",'completé'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'En attente'),_defineProperty(_Received_Amount$Payi,"Recu",'Recu'),_defineProperty(_Received_Amount$Payi,"partial",'partial'),_defineProperty(_Received_Amount$Payi,"Retournee",'Retournée'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Détail Devis'),_defineProperty(_Received_Amount$Payi,"EditQuote",'Modifier Devis'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Créer une vente'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'Télécharger le PDF'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'Envoyé Devis sur Email'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'Supprimé Devis'),_defineProperty(_Received_Amount$Payi,"AddQuote",'Ajouter Devis'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Sélectionnez un produit'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Produit (Code - Nom)'),_defineProperty(_Received_Amount$Payi,"Price",'Prix'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'Stock'),_defineProperty(_Received_Amount$Payi,"Total",'Total'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'Cout unitaire'),_defineProperty(_Received_Amount$Payi,"to",'à'),_defineProperty(_Received_Amount$Payi,"Subject",'Sujet'),_defineProperty(_Received_Amount$Payi,"Message",'Message'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'Email Client'),_defineProperty(_Received_Amount$Payi,"Sent",'Envoyer'),_defineProperty(_Received_Amount$Payi,"Quote",'Devis'),_defineProperty(_Received_Amount$Payi,"Hello",'Bonjour'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Veuillez trouver la pièce jointe pour votre devis'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Ajouter les Produits sur la liste des commandes'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Sélectionner un entrepôt'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'Sélectionner un client'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Gestion  Des Ventes'),_defineProperty(_Received_Amount$Payi,"Balance",'Balance'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Qté Retour'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Total Retour'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Montant reste'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Détail de la vente'),_defineProperty(_Received_Amount$Payi,"EditSale",'Modifier la vente'),_defineProperty(_Received_Amount$Payi,"AddSale",'Ajouter Vente'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Afficher les paiements'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Ajouter un paiement'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Modifier le paiement'),_defineProperty(_Received_Amount$Payi,"EmailSale",'Envoyer la vente par e-mail'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Supprimer la vente'),_defineProperty(_Received_Amount$Payi,"Amount",'Montant'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Mode de paiement'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Mode de règlement'),_defineProperty(_Received_Amount$Payi,"Note",'Remarque'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Paiement compléte!'),_defineProperty(_Received_Amount$Payi,"UserManagement",'Gestion des utilisateurs'),_defineProperty(_Received_Amount$Payi,"Firstname",'Prénom'),_defineProperty(_Received_Amount$Payi,"lastname",'Nom'),_defineProperty(_Received_Amount$Payi,"username",'utilisateur'),_defineProperty(_Received_Amount$Payi,"type",'Type'),_defineProperty(_Received_Amount$Payi,"password",'Mot de Pass'),_defineProperty(_Received_Amount$Payi,"Newpassword",'Nouveau Mot Pass'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Changer d\'avatar'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Veuillez laisser ce champ vide si vous ne l\'avez pas changé'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Permissions des utilisateurs'),_defineProperty(_Received_Amount$Payi,"RoleName",'Nom Role'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Discription Role'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'Ajouter des autorisations'),_defineProperty(_Received_Amount$Payi,"View",'Afficher'),_defineProperty(_Received_Amount$Payi,"Del",'Supprimer'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'Nouvel Ajustement'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Modifier Ajustement'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'Vous ne pouvez pas soustraire des produits en stock 0'),_defineProperty(_Received_Amount$Payi,"Addition",'Addition'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Soustraction'),_defineProperty(_Received_Amount$Payi,"profil",'Profil'),_defineProperty(_Received_Amount$Payi,"logout",'Se déconnecter'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'Vous ne pouvez pas modifier car cette Achat a déjà payé'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'Vous ne pouvez pas modifier car cette Vente a déjà payé'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'Vous ne pouvez pas modifier car cette Retour a déjà payé'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'Ce devis a déjà généré une vente'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'Cette Devis terminée'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Configuration du site'),_defineProperty(_Received_Amount$Payi,"Language",'Langue'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'Devise par défaut'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Email par défaut'),_defineProperty(_Received_Amount$Payi,"SiteName",'Nom du site'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Changer le logo'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'Configuration SMTP'),_defineProperty(_Received_Amount$Payi,"HOST",'HÔTE'),_defineProperty(_Received_Amount$Payi,"PORT",'PORT'),_defineProperty(_Received_Amount$Payi,"encryption",'Chiffrement'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'Configuration SMTP incorrecte'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Gestion de devises'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Code de devise'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Nom de devise'),_defineProperty(_Received_Amount$Payi,"Symbol",'Symbole'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Nom de la société'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Tele de la société'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'Adresse de la société'),_defineProperty(_Received_Amount$Payi,"Code",'Code'),_defineProperty(_Received_Amount$Payi,"image",'Image'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'Imprimer le code-barres'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'Retours de ventes'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'Retours d\'achats'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'Facture Return Clients'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'Facture Return Suppliers'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'Pas de données disponibles'),_defineProperty(_Received_Amount$Payi,"ProductImage",'Image du produit'),_defineProperty(_Received_Amount$Payi,"Barcode",'Code-barre'),_defineProperty(_Received_Amount$Payi,"pointofsales",'Point de vente'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Téléchargement personnalisé'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'Gestion des points de vente'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Ajustement'),_defineProperty(_Received_Amount$Payi,"Updat",'Mettre à jour'),_defineProperty(_Received_Amount$Payi,"Reset",'Réinitialiser'),_defineProperty(_Received_Amount$Payi,"print",'Impression'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'Recherche par e-mail'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Choisissez un produit'),_defineProperty(_Received_Amount$Payi,"Qty",'Qté'),_defineProperty(_Received_Amount$Payi,"Items",'Articles'),_defineProperty(_Received_Amount$Payi,"AmountHT",'Montant HT'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'Montant TTC'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Veuillez sélectionner un fournisseur'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Veuillez sélectionner le statut'),_defineProperty(_Received_Amount$Payi,"PayeBy",'Payé avec'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Choisissez l\'entrepôt'),_defineProperty(_Received_Amount$Payi,"payNow",'Payez maintenant'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'Liste de la catégorie'),_defineProperty(_Received_Amount$Payi,"Description",'Description'),_defineProperty(_Received_Amount$Payi,"submit",'Soumettre'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'Un problème est survenu lors de la création de cette facture. Veuillez réessayer'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'Il y a eu un problème de paiement. Veuillez réessayer.'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Créer un ajustement'),_defineProperty(_Received_Amount$Payi,"Afewwords",'Quelques mots sur ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'Image utilisateur'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Mettre à jour le produit'),_defineProperty(_Received_Amount$Payi,"Brand",'Marque'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Symbologie des codes à barres'),_defineProperty(_Received_Amount$Payi,"ProductCost",'Coût du produit'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Prix du produit'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Unité du Produit'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Méthode fiscale'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Image multiple'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Le produit a plusieurs variantes'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'Le produit a une promotion'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Début de la promotion'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Fin de la promotion'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Prix de la promotion'),_defineProperty(_Received_Amount$Payi,"Price",'Prix'),_defineProperty(_Received_Amount$Payi,"Cost",'Coût'),_defineProperty(_Received_Amount$Payi,"Unit",'Unité'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Variante de produit'),_defineProperty(_Received_Amount$Payi,"Variant",'Variante'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Prix unitaire'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'Créer un retour client'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'Modifier le retour client'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'Créer le retour fournisseur'),_defineProperty(_Received_Amount$Payi,"Documentation",'Doc'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'Modifier le retour fournisseur'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'De l\'entrepôt'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'vers l\'entrepôt'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Modifier le transfert'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Détail du transfert'),_defineProperty(_Received_Amount$Payi,"Pending",'En attente'),_defineProperty(_Received_Amount$Payi,"Received",'Reçu'),_defineProperty(_Received_Amount$Payi,"Ordered",'Commandé'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'Gestion des autorisations'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Gestion de la marque'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Image de marque'),_defineProperty(_Received_Amount$Payi,"BrandName",'Nom de marque'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Description de la marque'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Unité de base'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Gestion des Unités'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Valeur d\'opération'),_defineProperty(_Received_Amount$Payi,"Operator",'Opération'),_defineProperty(_Received_Amount$Payi,"Top5Products",'Top 5 des produits'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'5 dernières ventes'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'liste des Ajustements'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Liste des transferts'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Créer un transfert'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Gestion des commandes'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Liste des quotes'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Liste des achats'),_defineProperty(_Received_Amount$Payi,"ListSales",'Liste des ventes'),_defineProperty(_Received_Amount$Payi,"ListReturns",'Liste des retours'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'Gestion des personnes'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Liste des marques'),_defineProperty(_Received_Amount$Payi,"Delete",(_Delete={
Title:'Êtes-vous sûr?',
Text:'Vous ne pourrez pas revenir en arrière!',
confirmButtonText:'Oui, supprimez-le!',
cancelButtonText:'Annuler',
Deleted:'Supprimé!',
Failed:'Échec!',
Therewassomethingwronge:'Il y avait quelque chose de mal',
CustomerDeleted:'Ce client a été supprimé.'},
_defineProperty(_Delete,"CustomerDeleted",'Cet utilisateur a été supprimé.'),_defineProperty(_Delete,"SupplierDeleted",'Fournisseur a été supprimé'),_defineProperty(_Delete,"QuoteDeleted",'Cette Devis a été supprimée.'),_defineProperty(_Delete,"SaleDeleted",'Cette Vente a été supprimée.'),_defineProperty(_Delete,"PaymentDeleted",'Cette Paiement a été supprimée.'),_defineProperty(_Delete,"PurchaseDeleted",'Cette Achat a été supprimée.'),_defineProperty(_Delete,"ReturnDeleted",'Cette Retour a été supprimée.'),_defineProperty(_Delete,"ProductDeleted",'Ce produit a été supprimé'),_defineProperty(_Delete,"ClientError",'Ce Client déja lié avec autre Opération'),_defineProperty(_Delete,"ProviderError",'Ce fournisseur déja lié avec autre Opération'),_defineProperty(_Delete,"UnitDeleted",'Cette unités a été supprimé'),_defineProperty(_Delete,"RoleDeleted",'Ce Role a été supprimé'),_defineProperty(_Delete,"TaxeDeleted",'Cette Taxe a été supprimé'),_defineProperty(_Delete,"SubCatDeleted",'Cette sous Categorie a été supprimé'),_defineProperty(_Delete,"CatDeleted",'Cette Categorie a été supprimé'),_defineProperty(_Delete,"WarehouseDeleted",'Ce magasin a été supprimé'),_defineProperty(_Delete,"AlreadyLinked",'Ce produit déja lié avec autre Opération'),_defineProperty(_Delete,"AdjustDeleted",'Cet Ajustement a été supprimé'),_defineProperty(_Delete,"TitleCurrency",'Cet Devise a été supprimé'),_defineProperty(_Delete,"TitleTransfer",'Transfer a été supprimée avec succès'),_defineProperty(_Delete,"BackupDeleted",'Sauvegarde a été supprimée avec succès'),_defineProperty(_Delete,"TitleBrand",'Cette marque a été supprimée'),_Delete)),_defineProperty(_Received_Amount$Payi,"Update",{
TitleSetting:'Paramétres mis à jour avec succès',
TitleProfile:'Profil mis à jour avec succès',
TitleAdjust:'Adjustement mis à jour avec succès',
TitleRole:'Role mis à jour avec succès',
TitleUnit:'Unités mis à jour avec succès',
TitleUser:'Utilisateur mis à jour avec succès',
TitleProduct:'Produit mis à jour avec succès',
TitleCustomer:'Client mis à jour avec succès',
TitleQuote:'Devis mis à jour  avec succès',
TitleSale:'Vente mis à jour  avec succès',
TitlePayment:'Paiement mis à jour  avec succès',
TitlePurchase:'Achat  mis à jour  avec succès',
TitleReturn:'Retour  mis à jour  avec succès',
TitleSupplier:'Fournisseur  mis à jour  avec succès',
TitleTaxe:'Taxe  mis à jour  avec succès',
TitleCat:'Categorie mis à jour avec succès',
TitleWarhouse:'Magasin mis à jour avec succès',
TitleCurrency:'Devise mis à jour avec succès',
TitleTransfer:'Transfer mis à jour avec succès',
TitleBrand:'Cette marque a été mise à jour'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'Cette marque a été créée',
TitleTransfer:'Transfer créé avec succès',
TitleAdjust:'Adjustement créé avec succès',
TitleTaxe:'Taxe créé avec succès',
TitleRole:'Role créé avec succès',
TitleUnit:'Unités créé avec succès',
TitleUser:'Utilisateur créé avec succès',
TitleCustomer:'Client créé avec succès',
TitleQuote:'Devis créé  avec succès',
TitleSale:'Vente créé  avec succès',
TitlePayment:'Paiement créé  avec succès',
TitlePurchase:'Achat créé  avec succès',
TitleReturn:'Retour créé  avec succès',
TitleProduct:'Produit créé avec succès',
TitleSupplier:'Fournisseur  créé  avec succès',
TitleCat:'Categorie  créé  avec succès',
TitleWarhouse:'Magasin créé avec succès',
TitleCurrency:'Devise créé avec succès'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'Email Envoyé avec succès'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'Cette vente déja liée avec un Retour!'}),
_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Gestion des achats'),_defineProperty(_Received_Amount$Payi,"Ordered",'Commandé'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Supprimer l\'achat'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Envoyer l\'achat par e-mail'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Modifier l\'achat'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Détail d\'achat'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Ajouter d\'achat'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Email Fournisseur'),_defineProperty(_Received_Amount$Payi,"ReturnManagement",'Gestion des retours'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'Détails du retour'),_defineProperty(_Received_Amount$Payi,"EditReturn",'Modifier le retour'),_defineProperty(_Received_Amount$Payi,"AddReturn",'Ajouter le retour'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'Envoyer le retour par e-mail'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'Supprimer le retour'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'Return Surcharge'),_defineProperty(_Received_Amount$Payi,"Laivrison",'Laivrison'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Sélectionnez la vente'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'Vous pouvez supprimer l\'élément ou définir la quantité retournée à zéro si elle n\'est pas retournée'),_defineProperty(_Received_Amount$Payi,"Return",'Retour'),_defineProperty(_Received_Amount$Payi,"Purchase",'Achat'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Paiement des achats'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Données Paiement d\'achat'),_defineProperty(_Received_Amount$Payi,"SalesInvoices",'Paiement des ventes'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Données Paiement de vente'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Ventes totales'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Total des achats'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Retours totaux'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Paiement net'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Paiements envoyés'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Paiements reçus'),_defineProperty(_Received_Amount$Payi,"Recieved",'Reçus'),_defineProperty(_Received_Amount$Payi,"Sent",'Envoyés'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Alertes de quantité de produits'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Code produit'),_defineProperty(_Received_Amount$Payi,"ProductName",'Produit'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Quantité d\'alerte'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Graphique du stock d\'entrepôt'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Total Produits'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Total Quantity'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'Top 5 des clients'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Montant total'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Total payé'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Rapport des ventes'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Rapport des paiements'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'Rapport des Devis'),_defineProperty(_Received_Amount$Payi,"Payments",'Paiements'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'Top 5 Providers'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Rapport des achats'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Rapport des paiements'),_defineProperty(_Received_Amount$Payi,"Name",'Nom'),_defineProperty(_Received_Amount$Payi,"Code",'Code'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Gestion d\'entrepôt'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Code postal'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Gestion des catégories'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Code Catégorie'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'Name Catégorie'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Parente Catégorie'),_defineProperty(_Received_Amount$Payi,"managementTax",'Gestion fiscale'),_defineProperty(_Received_Amount$Payi,"TaxName",'Nom de la taxe'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Taux de taxe'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Gestion des unités d\'achats'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Gestion des unités de vente'),_defineProperty(_Received_Amount$Payi,"ShortName",'Nom court'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Veuillez les sélectionner avant d\'ajouter un produit'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Ajustement des stocks'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Veuillez les sélectionner magasin avant de choisir un produit'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Transfert de stock'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Sélectionnez la période'),_defineProperty(_Received_Amount$Payi,"ThisYear",'Cette année'),_defineProperty(_Received_Amount$Payi,"ThisToday",'Ce aujourd\'hui'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'Ce mois-ci'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'Cette semaine'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Détail d\'ajustement'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'Cet utilisateur a été activé'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'Cet utilisateur a été désactivé'),_defineProperty(_Received_Amount$Payi,"NotFound",'Page non trouvée.'),_defineProperty(_Received_Amount$Payi,"oops",'Erreur! Page non trouvée.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'Nous n\'avons pas pu trouver la page que vous recherchiez.'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'Retour au tableau de bord'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/hn.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/hn.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesHnJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Hindi
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'प्राप्त राशि',
Paying_Amount:'भुगतान राशि',
Change:'परिवर्तन',
Paying_amount_is_greater_than_Received_amount:'भुगतान राशि प्राप्त राशि से अधिक है',
Paying_amount_is_greater_than_Grand_Total:'भुगतान राशि कुल योग से अधिक है',
code_must_be_not_exist_already:'कोड पहले से मौजूद नहीं होना चाहिए',
You_will_find_your_backup_on:'आपको अपना बैकअप इस पर मिलेगा',
and_save_it_to_your_pc:'और इसे अपने पीसी में सहेजें',
Scan_your_barcode_and_select_the_correct_symbology_below:'अपना बारकोड स्कैन करें और नीचे सही सिम्बोलॉजी चुनें select',
Scan_Search_Product_by_Code_Name:'कोड नाम से उत्पाद स्कैन/खोजें',
Paper_size:'काग़ज़ का आकार',
Clear_Cache:'कैश को साफ़ करें',
Cache_cleared_successfully:'कैश सफलतापूर्वक साफ़ किया गया',
Failed_to_clear_cache:'कैशे साफ़ करने में विफल',
Scan_Barcode:'बारकोड स्कैनर',
Please_use_short_name_of_unit:'कृपया इकाई के संक्षिप्त नाम का प्रयोग करें',
DefaultCustomer:'डिफ़ॉल्ट ग्राहक',
DefaultWarehouse:'डिफ़ॉल्ट गोदाम',
Payment_Gateway:'अदायगी रास्ता',
SMS_Configuration:'एसएमएस कॉन्फ़िगरेशन',
Gateway:'अदायगी रास्ता',
Choose_Gateway:'पेमेंट गेटवे चुनें',
Send_SMS:'संदेश सफलतापूर्वक भेजा जा चुका है',
sms_config_invalid:'गलत sms कॉन्फिगर्ड अमान्य है',
Remove_Stripe_Key_Secret:'स्ट्राइप एपीआई कीज को डिलीट करें',
credit_card_account_not_available:'क्रेडिट कार्ड खाता उपलब्ध नहीं है',
Credit_Card_Info:'क्रेडिट कार्ड की जानकारी',
developed_by:'द्वारा विकसित',
Unit_already_linked_with_sub_unit:'यूनिट पहले से ही सब यूनिट के साथ जुड़ी हुई है',
Total_Items_Quantity:'कुल आइटम और मात्रा',
Value_by_Cost_and_Price:'मूल्य और मूल्य द्वारा मूल्य',
Search_this_table:'इस तालिका को खोजें',
import_products:'उत्पादों का आयात करें',
Field_optional:'क्षेत्र वैकल्पिक',
Download_exemple:'उदाहरण डाउनलोड करें',
field_must_be_in_csv_format:'फ़ील्ड सीएसवी प्रारूप में होनी चाहिए',
Successfully_Imported:'सफलतापूर्वक आयात किया गया',
file_size_must_be_less_than_1_mega:'फ़ाइल का आकार 1 मेगा से कम होना चाहिए',
Please_follow_the_import_instructions:'कृपया आयात निर्देशों का पालन करें',
must_be_exist:'इकाई पहले से ही बनाई जानी चाहिए',
Import_Customers:'ग्राहक आयात करें',
Import_Suppliers:'आयात आपूर्तिकर्ता',
Recent_Sales:'हाल की बिक्री',
Create_Transfer:'स्थानांतरण बनाएँ',
order_products:'चिजें मँगाओ',
Search_Product_by_Code_Name:'कोड या नाम से उत्पाद खोजें',
Reports_payments_Purchase_Return:'रिपोर्ट खरीद भुगतान',
Reports_payments_Sale_Return:'बिक्री विवरणी भुगतान रिपोर्ट',
payments_Sales_Return:'भुगतान बिक्री वापसी',
payments_Purchases_Return:'भुगतान खरीद वापसी',
CreateSaleReturn:'बिक्री वापसी बनाएँ',
EditSaleReturn:'बिक्री वापसी संपादित करें',
SalesReturn:'बिक्री वापसी',
CreatePurchaseReturn:'खरीद वापसी बनाएँ',
EditPurchaseReturn:'खरीद वापसी संपादित करें',
PurchasesReturn:'खरीद वापसी',
Due:'देय',
Profit:'फायदा',
Revenue:'राजस्व',
Sales_today:'आज बिक्री',
People:'लोग',
Successfully_Created:'सफलतापूर्वक बनाया गया',
Successfully_Updated:'सफलतापूर्वक उत्परिवर्तित',
Success:'सफलता',
Failed:'अनुत्तीर्ण होना',
Warning:'चेतावनी',
Please_fill_the_form_correctly:'कृपया फॉर्म सही से भरें',
Field_is_required:'ये स्थान भरा जाना है',
Error:'त्रुटि!',
you_are_not_authorized:'माफ़ करना! तुम अधिकृत नहीं हो।',
Go_back_to_home:'मुखपृष्ठ पर वापस जाएं',
page_not_exist:'माफ़ करना! जिस पृष्ठ को आप खोज रहे थे वह मौजूद नहीं है।',
Choose_Status:'स्थिति चुनें',
Choose_Method:'विधि चुनें',
Choose_Symbology:'सहजीवन चुनें',
Choose_Category:'वर्ग चुने',
Choose_Customer:'ग्राहक चुनें',
Choose_Supplier:'आपूर्तिकर्ता चुनें',
Choose_Unit_Purchase:'खरीद इकाई चुनें',
Choose_Sub_Category:'उपश्रेणी चुनें',
Choose_Brand:'ब्रांड चुनें',
Choose_Warehouse:'वेयरहाउस चुनें',
Choose_Unit_Sale:'बिक्री इकाई चुनें',
Enter_Product_Cost:'उत्पाद लागत दर्ज करें',
Enter_Stock_alert:'स्टॉक अलर्ट दर्ज करें',
Choose_Unit_Product:'उत्पाद इकाई चुनें',
Enter_Product_Price:'उत्पाद मूल्य दर्ज करें',
Enter_Name_Product:'नाम उत्पाद दर्ज करें',
Enter_Role_Name:'भूमिका का नाम दर्ज करें',
Enter_Role_Description:'भूमिका विवरण दर्ज करें',
Enter_name_category:'श्रेणी का नाम दर्ज करें',
Enter_Code_category:'श्रेणी कोड दर्ज करें',
Enter_Name_Brand:'नाम ब्रांड दर्ज करें',
Enter_Description_Brand:'विवरण ब्रांड दर्ज करें',
Enter_Code_Currency:'कोड करेंसी दर्ज करें',
Enter_name_Currency:'नाम दर्ज करें मुद्रा',
Enter_Symbol_Currency:'प्रतीक मुद्रा दर्ज करें',
Enter_Name_Unit:'इकाई का नाम दर्ज करें',
Enter_ShortName_Unit:'शॉर्टनेम यूनिट दर्ज करें',
Choose_Base_Unit:'बेस यूनिट चुनें',
Choose_Operator:'ऑपरेटर चुनें',
Enter_Operation_Value:'ऑपरेशन मान दर्ज करें',
Enter_Name_Warehouse:'वेयरहाउस का नाम दर्ज करें',
Enter_Phone_Warehouse:'वेयरहाउस फ़ोन दर्ज करें',
Enter_Country_Warehouse:'गोदाम देश दर्ज करें',
Enter_City_Warehouse:'वेयरहाउस सिटी दर्ज करें',
Enter_Email_Warehouse:'गोदाम ईमेल दर्ज करें',
Enter_ZipCode_Warehouse:'वेयरहाउस ज़िप कोड दर्ज करें',
Choose_Currency:'मुद्रा चुनिये',
Thank_you_for_your_business:'आपके व्यापार के लिए धन्यवाद!',
Cancel:'रद्द करना',
New_Customer:'नए ग्राहक',
Incorrect_Login:'गलत लॉगिन',
Successfully_Logged_In:'सफलतापूर्वक लॉग इन किया',
This_user_not_active:'यह उपयोगकर्ता सक्रिय नहीं है',
SignIn:'साइन इन करें',
Create_an_account:'खाता बनाएं',
Forgot_Password:'पासवर्ड भूल गए ?',
Email_Address:'ईमेल पता',
SignUp:'साइन अप करें',
Already_have_an_account:'क्या आपके पास पहले से एक खाता मौजूद है ?',
Reset_Password:'पासवर्ड रीसेट',
Failed_to_authenticate_on_SMTP_server:'SMTP सर्वर पर प्रमाणित करने में विफल',
We_cant_find_a_user_with_that_email_addres:'हमें उस ईमेल पते वाला उपयोगकर्ता नहीं मिल रहा है',
We_have_emailed_your_password_reset_link:'हमने आपका पासवर्ड रीसेट लिंक ई-मेल कर दिया है',
Please_fill_the_Email_Adress:'कृपया ईमेल पता भरें',
Confirm_password:'पासवर्ड की पुष्टि कीजिये',
Your_Password_has_been_changed:'आपका पासवर्ड बदल दिया गया है',
The_password_confirmation_does_not_match:'पासवर्ड की पुष्टि मेल नहीं खाती',
This_password_reset_token_is_invalid:'यह पासवर्ड रीसेट टोकन अमान्य है',
Warehouse_report:'वेयरहाउस की रिपोर्ट',
All_Warehouses:'सभी गोदाम',
Expense_List:'व्यय सूची',
Expenses:'व्यय',
This_Week_Sales_Purchases:'यह सप्ताह बिक्री और खरीद',
Top_Selling_Products:'शीर्ष बेचना उत्पाद',
View_all:'सभी देखें',
Payment_Sent_Received:'भुगतान भेजा और प्राप्त किया',
Filter:'फ़िल्टर',
Invoice_POS:'बीजक POS',
Invoice:'बीजक',
Customer_Info:'ग्राहक की जानकारी',
Company_Info:'कंपनी की जानकारी',
Invoice_Info:'चालान जानकारी',
Order_Summary:'आदेश सारांश',
Quote_Info:'उद्धरण जानकारी',
Del:'हटाएं',
SuppliersPaiementsReport:'आपूर्तिकर्ता भुगतान रिपोर्ट',
Purchase_Info:'खरीद जानकारी',
Supplier_Info:'आपूर्तिकर्ता जानकारी',
Return_Info:'वापसी की जानकारी',
Expense_Category:'व्यय की श्रेणी',
Create_Expense:'व्यय बनाएँ',
Details:'विवरण',
Discount_Method:'डिस्काउंट विधि',
Net_Unit_Cost:'नेट यूनिट लागत',
Net_Unit_Price:'शुद्ध इकाई मूल्य',
Edit_Expense:'व्यय संपादित करें',
All_Brand:'सभी ब्रांड',
All_Category:'सभी श्रेणी',
ListExpenses:'सूची व्यय',
Create_Permission:'अनुमति बनाएँ',
Edit_Permission:'अनुमति संपादित करें',
Reports_payments_Sales:'रिपोर्ट भुगतान बिक्री',
Reports_payments_Purchases:'रिपोर्ट भुगतान खरीद',
Reports_payments_Return_Customers:'रिपोर्ट भुगतान वापसी ग्राहकों',
Reports_payments_Return_Suppliers:'रिपोर्ट भुगतान वापसी आपूर्तिकर्ता',
Expense_Deleted:'यह व्यय हटा दिया गया है',
Expense_Updated:'यह व्यय अद्यतन किया गया है',
Expense_Created:'यह व्यय सृजित किया गया है',
DemoVersion:'आप डेमो संस्करण में ऐसा नहीं कर सकते',
OrderStatistics:'बिक्री के आँकड़े',
AlreadyAdd:'यह उत्पाद पहले से ही जोड़ा गया है',
AddProductToList:'कृपया सूची में उत्पाद जोड़ें',
AddQuantity:'कृपया विस्तार की मात्रा जोड़ें',
InvalidData:'अमान्य तथ्य',
LowStock:'मात्रा स्टॉक में उपलब्ध मात्रा से अधिक है',
WarehouseIdentical:'दो गोदाम समान नहीं हो सकते हैं',
VariantDuplicate:'ये वैरिएंट डुप्लीकेट है',
Filesize:'फाइल का आकार',
GenerateBackup:'बैकअप उत्पन्न करें',
BackupDatabase:'बैकअप डेटाबेस',
Backup:'बैकअप',
Paid:'भुगतान किया है',
Unpaid:'अवैतनिक',
Today:'आज',
Income:'आय'},
_defineProperty(_Received_Amount$Payi,"Expenses",'व्ययव्यय'),_defineProperty(_Received_Amount$Payi,"Sale",'बिक्री'),_defineProperty(_Received_Amount$Payi,"Actif",'सक्रिय'),_defineProperty(_Received_Amount$Payi,"Inactif",'निष्क्रिय'),_defineProperty(_Received_Amount$Payi,"Customers",'ग्राहकों'),_defineProperty(_Received_Amount$Payi,"Phone",'फ़ोन'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'फ़ोन द्वारा खोजें'),_defineProperty(_Received_Amount$Payi,"Suppliers",'आपूर्तिकर्ता'),_defineProperty(_Received_Amount$Payi,"Quotations",'कोटेशन'),_defineProperty(_Received_Amount$Payi,"Sales",'बिक्री'),_defineProperty(_Received_Amount$Payi,"Purchases",'खरीद'),_defineProperty(_Received_Amount$Payi,"Returns",'रिटर्न'),_defineProperty(_Received_Amount$Payi,"Settings",'समायोजन'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'प्रणाली व्यवस्था'),_defineProperty(_Received_Amount$Payi,"Users",'उपयोगकर्ता'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'समूह अनुमतियाँ'),_defineProperty(_Received_Amount$Payi,"Currencies",'मुद्राओं'),_defineProperty(_Received_Amount$Payi,"Warehouses",'गोदामों'),_defineProperty(_Received_Amount$Payi,"Units",'इकाइयों'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'इकाइयाँ खरीदता है'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'इकाइयों की बिक्री'),_defineProperty(_Received_Amount$Payi,"Reports",'रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'भुगतान रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'भुगतान खरीद'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'भुगतान बिक्री'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'लाभ और हानि'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'गोदाम स्टॉक चार्ट'),_defineProperty(_Received_Amount$Payi,"SalesReport",'बिक्री रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'खरीद रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'ग्राहक रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'आपूर्तिकर्ता रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'आपूर्तिकर्ता रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'दैनिक बिक्री डेटा'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'दैनिक खरीद डेटा'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'पिछले पांच रिकॉर्ड'),_defineProperty(_Received_Amount$Payi,"Filters",'फिल्टर'),_defineProperty(_Received_Amount$Payi,"date",'दिनांक'),_defineProperty(_Received_Amount$Payi,"Reference",'संदर्भ'),_defineProperty(_Received_Amount$Payi,"Supplier",'प्रदायक'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'भुगतान की स्थिति'),_defineProperty(_Received_Amount$Payi,"Customer",'ग्राहक'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'ग्राहक क्रमांक'),_defineProperty(_Received_Amount$Payi,"Status",'स्थिति'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'प्रदायक का कोड'),_defineProperty(_Received_Amount$Payi,"Categorie",'वर्ग'),_defineProperty(_Received_Amount$Payi,"Categories",'श्रेणियाँ'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'स्टॉक ट्रांसफर'),_defineProperty(_Received_Amount$Payi,"StockManagement",'स्टाक प्रबंधन'),_defineProperty(_Received_Amount$Payi,"dashboard",'डैशबोर्ड'),_defineProperty(_Received_Amount$Payi,"Products",'उत्पाद'),_defineProperty(_Received_Amount$Payi,"productsList",'उत्पादों की सूची'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'उत्पाद प्रबंधन'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'उत्पाद मात्रा अलर्ट'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'कोड उत्पाद'),_defineProperty(_Received_Amount$Payi,"ProductTax",'उत्पाद कर'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'उपश्रेणी'),_defineProperty(_Received_Amount$Payi,"Name_product",'पद'),_defineProperty(_Received_Amount$Payi,"StockAlert",'स्टॉक अलर्ट'),_defineProperty(_Received_Amount$Payi,"warehouse",'गोदाम'),_defineProperty(_Received_Amount$Payi,"Tax",'कर'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'खरीद मूल्य'),_defineProperty(_Received_Amount$Payi,"SellPrice",'विक्रय मूल्य'),_defineProperty(_Received_Amount$Payi,"Quantity",'मात्रा'),_defineProperty(_Received_Amount$Payi,"UnitSale",'इकाई बिक्री'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'यूनिट खरीद'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'मुद्रा प्रबंधन'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'मुद्रा कोड'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'मुद्रा का नाम'),_defineProperty(_Received_Amount$Payi,"Symbol",'प्रतीक'),_defineProperty(_Received_Amount$Payi,"All",'सब'),_defineProperty(_Received_Amount$Payi,"EditProduct",'उत्पाद संपादित करें'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'कोड द्वारा खोजें'),_defineProperty(_Received_Amount$Payi,"SearchByName",'नाम से खोजें'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'उत्पाद विवरण'),_defineProperty(_Received_Amount$Payi,"CustomerName",'ग्राहक का नाम'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'ग्राहक प्रबंधन'),_defineProperty(_Received_Amount$Payi,"Add",'सृजन करना'),_defineProperty(_Received_Amount$Payi,"add",'सृजन करना'),_defineProperty(_Received_Amount$Payi,"Edit",'संपादित करें'),_defineProperty(_Received_Amount$Payi,"Close",'बंद करे'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'कृपया चुने'),_defineProperty(_Received_Amount$Payi,"Action",'कार्य'),_defineProperty(_Received_Amount$Payi,"Email",'ईमेल'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'ग्राहक संपादित करें'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'ग्राहक बनाएं'),_defineProperty(_Received_Amount$Payi,"Country",'देश'),_defineProperty(_Received_Amount$Payi,"City",'शहर'),_defineProperty(_Received_Amount$Payi,"Adress",'पता'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'उपभोक्ता विवरण'),_defineProperty(_Received_Amount$Payi,"CustomersList",'ग्राहक सूची'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'प्रदायक का कोड'),_defineProperty(_Received_Amount$Payi,"SupplierName",'आपूर्तिकर्ता का नाम'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'आपूर्तिकर्ता प्रबंधन'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'आपूर्तिकर्ता विवरण'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'उद्धरण प्रबंधन'),_defineProperty(_Received_Amount$Payi,"SubTotal",'उप-योग'),_defineProperty(_Received_Amount$Payi,"MontantReste",'बची हुई राशि'),_defineProperty(_Received_Amount$Payi,"complete",'पूरा कर लिया है'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'अपूर्ण'),_defineProperty(_Received_Amount$Payi,"Recu",'प्राप्त किया'),_defineProperty(_Received_Amount$Payi,"partial",'आंशिक'),_defineProperty(_Received_Amount$Payi,"Retournee",'वापसी'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'विस्तार उद्धरण'),_defineProperty(_Received_Amount$Payi,"EditQuote",'उद्धरण संपादित करें'),_defineProperty(_Received_Amount$Payi,"CreateSale",'बिक्री बनाएँ'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'डाउनलोड पीडीऍफ़'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'ईमेल पर भेजा गया उद्धरण'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'उद्धरण हटाएं'),_defineProperty(_Received_Amount$Payi,"AddQuote",'उद्धरण बनाएँ'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'उत्पाद का चयन करें'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'उत्पाद (कोड - नाम)'),_defineProperty(_Received_Amount$Payi,"Price",'कीमत'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'भण्डार'),_defineProperty(_Received_Amount$Payi,"Total",'संपूर्ण'),_defineProperty(_Received_Amount$Payi,"Num",'एन °'),_defineProperty(_Received_Amount$Payi,"Unitcost",'इकाई लागत'),_defineProperty(_Received_Amount$Payi,"to",'सेवा'),_defineProperty(_Received_Amount$Payi,"Subject",'विषय'),_defineProperty(_Received_Amount$Payi,"Message",'संदेश'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'ईमेल ग्राहक'),_defineProperty(_Received_Amount$Payi,"Sent",'संदेश'),_defineProperty(_Received_Amount$Payi,"Quote",'उद्धरण'),_defineProperty(_Received_Amount$Payi,"Hello",'नमस्कार'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'कृपया अपने उद्धरण के लिए अनुलग्नक ढूंढें'),_defineProperty(_Received_Amount$Payi,"AddProducts",'उत्पादों को ऑर्डर सूची में जोड़ें'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'कृपया गोदाम चुनें'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'कृपया ग्राहक चुनें'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'बिक्री प्रबंधन'),_defineProperty(_Received_Amount$Payi,"Balance",'संतुलन'),_defineProperty(_Received_Amount$Payi,"QtyBack",'वापस मात्रा'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'कुल प्राप्ति'),_defineProperty(_Received_Amount$Payi,"Amount",'रकम'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'बिक्री विवरण'),_defineProperty(_Received_Amount$Payi,"EditSale",'बिक्री संपादित करें'),_defineProperty(_Received_Amount$Payi,"AddSale",'बिक्री बनाएँ'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'भुगतान दिखाएं'),_defineProperty(_Received_Amount$Payi,"AddPayment",'भुगतान बनाएं'),_defineProperty(_Received_Amount$Payi,"EditPayment",'भुगतान संपादित करें'),_defineProperty(_Received_Amount$Payi,"EmailSale",'ईमेल में बिक्री भेजें'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'बिक्री हटाएं'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'द्वारा भुगतान'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'भुगतान का विकल्प'),_defineProperty(_Received_Amount$Payi,"Note",'ध्यान दें'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'भुगतान पूरा!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'खरीद प्रबंधन'),_defineProperty(_Received_Amount$Payi,"Ordered",'आदेश दिया'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'खरीद हटाएं'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'ईमेल में खरीद भेजें'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'खरीद संपादित करें'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'खरीद विवरण'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'खरीदारी बनाएँ'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'आपूर्तिकर्ता ईमेल'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'भुगतान खरीदता है'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'भुगतान डेटा खरीदता है'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'बिक्री भुगतान'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'बिक्री भुगतान डेटा'),_defineProperty(_Received_Amount$Payi,"UserManagement",'उपयोगकर्ता प्रबंधन'),_defineProperty(_Received_Amount$Payi,"Firstname",'पहला नाम'),_defineProperty(_Received_Amount$Payi,"lastname",'उपनाम'),_defineProperty(_Received_Amount$Payi,"username",'उपयोगकर्ता नाम'),_defineProperty(_Received_Amount$Payi,"password",'कुंजिका'),_defineProperty(_Received_Amount$Payi,"Newpassword",'नया पासवर्ड'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'अवतार परिवर्तन'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'यदि आपने इसे नहीं बदला है तो कृपया इस फ़ील्ड को खाली छोड़ दें'),_defineProperty(_Received_Amount$Payi,"type",'प्रकार'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'उपयोगकर्ता अनुमतियाँ'),_defineProperty(_Received_Amount$Payi,"RoleName",'भूमिका'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'भूमिका विवरण'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'अनुमतियाँ बनाएँ'),_defineProperty(_Received_Amount$Payi,"View",'राय'),_defineProperty(_Received_Amount$Payi,"Del",'हटाएं'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'नया समायोजन'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'समायोजन संपादित करें'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'आप उन उत्पादों को घटा नहीं सकते जिनके पास स्टॉक 0 है'),_defineProperty(_Received_Amount$Payi,"Addition",'इसके अलावा'),_defineProperty(_Received_Amount$Payi,"Subtraction",'घटाव'),_defineProperty(_Received_Amount$Payi,"profil",'प्रोफ़ाइल'),_defineProperty(_Received_Amount$Payi,"logout",'लॉग आउट'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'आप संशोधित नहीं कर सकते क्योंकि यह खरीद पहले ही भुगतान कर चुकी है'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'आप संशोधित नहीं कर सकते क्योंकि यह बिक्री पहले ही भुगतान कर चुकी है'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'आप संशोधित नहीं कर सकते क्योंकि यह रिटर्न पहले ही भुगतान कर चुका है'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'यह उद्धरण पहले ही बिक्री उत्पन्न कर चुका है'),_defineProperty(_Received_Amount$Payi,"AddProduct",'उत्पाद बनाएँ'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'यह उद्धरण पूरा हुआ'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'साइट कॉन्फ़िगरेशन'),_defineProperty(_Received_Amount$Payi,"Language",'भाषा: हिन्दी'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'डिफ़ॉल्ट मुद्रा'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'कैप्चा लॉगिन करें'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'डिफ़ॉल्ट ईमेल'),_defineProperty(_Received_Amount$Payi,"SiteName",'साइट का नाम'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'लोगो बदलें'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'SMTP कॉन्फ़िगरेशन'),_defineProperty(_Received_Amount$Payi,"HOST",'मेज़बान'),_defineProperty(_Received_Amount$Payi,"PORT",'बंदरगाह'),_defineProperty(_Received_Amount$Payi,"encryption",'एन्क्रिप्शन'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'SMTP कॉन्फ़िगरेशन गलत है'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'भुगतान रिटर्न'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'चालान लौटाता है'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'चालान डेटा लौटाता है'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Show all records of all Users'),_defineProperty(_Received_Amount$Payi,"Discount",'छूट'),_defineProperty(_Received_Amount$Payi,"OrderTax",'आदेश कर'),_defineProperty(_Received_Amount$Payi,"Shipping",'शिपिंग'),_defineProperty(_Received_Amount$Payi,"CompanyName",'कंपनी का नाम'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Company Phone'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'कंपनी का पता'),_defineProperty(_Received_Amount$Payi,"Code",'कोड'),_defineProperty(_Received_Amount$Payi,"image",'छवि'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'प्रिंट बारकोड'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'ग्राहक लौटाता है'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'आपूर्तिकर्ता लौटाता है'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'ग्राहकों का चालान वापस करें'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'आपूर्तिकर्ता लौटें चालान'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'कोई डेटा उपलब्ध नहीं है'),_defineProperty(_Received_Amount$Payi,"ProductImage",'उत्पाद का चित्र'),_defineProperty(_Received_Amount$Payi,"Barcode",'बारकोड'),_defineProperty(_Received_Amount$Payi,"pointofsales",'विक्रय पॉइंट'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'कस्टम अपलोड'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'बिक्री प्रबंधन का बिंदु'),_defineProperty(_Received_Amount$Payi,"Adjustment",'समायोजन'),_defineProperty(_Received_Amount$Payi,"Updat",'अपडेट करें'),_defineProperty(_Received_Amount$Payi,"Reset",'रीसेट'),_defineProperty(_Received_Amount$Payi,"print",'छाप'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'ईमेल द्वारा खोजें'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'उत्पाद चुनें'),_defineProperty(_Received_Amount$Payi,"Qty",'मात्रा'),_defineProperty(_Received_Amount$Payi,"Items",'आइटम'),_defineProperty(_Received_Amount$Payi,"AmountHT",'संपूर्ण'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'कुल रकम'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'कृपया आपूर्तिकर्ता का चयन करें'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'कृपया स्थिति चुनें'),_defineProperty(_Received_Amount$Payi,"PayeBy",'द्वारा भुगतान'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'वेयरहाउस चुनें'),_defineProperty(_Received_Amount$Payi,"payNow",'अब भुगतान करें'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'श्रेणी की सूची'),_defineProperty(_Received_Amount$Payi,"Description",'विवरण'),_defineProperty(_Received_Amount$Payi,"submit",'प्रस्तुत'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'इस चालान को बनाने में एक समस्या थी। कृपया पुन: प्रयास करें'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'भुगतान की समस्या थी। कृपया पुन: प्रयास करें।'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'आय और व्यय'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'दैनिक बिक्री और खरीद'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'उत्पाद समाप्त हो गए'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'सूची ब्रांड'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'समायोजन बनाएँ'),_defineProperty(_Received_Amount$Payi,"Afewwords",'कुछ शब्द ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'उपयोगकर्ता छवि'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'अद्यतन उत्पाद'),_defineProperty(_Received_Amount$Payi,"Brand",'ब्रांड'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'बारकोड सिम्बोलॉजी'),_defineProperty(_Received_Amount$Payi,"ProductCost",'सामान का मूल्य'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'उत्पाद की कीमत'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'यूनिट उत्पाद'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'कर विधि'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'एकाधिक छवि'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'उत्पाद में मल्टी वेरिएंट हैं'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'उत्पाद का प्रचार है'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'प्रमोशन शुरू'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'प्रमोशन का अंत'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'प्रोन्नति मूल्य'),_defineProperty(_Received_Amount$Payi,"Price",'कीमत'),_defineProperty(_Received_Amount$Payi,"Cost",'लागत'),_defineProperty(_Received_Amount$Payi,"Unit",'इकाई'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'उत्पाद वेरिएंट'),_defineProperty(_Received_Amount$Payi,"Variant",'प्रकार'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'यूनिट मूल्य'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'ग्राहक बनाएँ'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'रिटर्न ग्राहक संपादित करें'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'रिटर्न सप्लायर बनाएं'),_defineProperty(_Received_Amount$Payi,"Documentation",'प्रलेखन'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'रिटर्न प्रदायक संपादित करें'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'वेयरहाउस से'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'वेयरहाउस के लिए'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'स्थानांतरण संपादित करें'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'ट्रांसफर डिटेल'),_defineProperty(_Received_Amount$Payi,"Pending",'विचाराधीन'),_defineProperty(_Received_Amount$Payi,"Received",'प्राप्त किया'),_defineProperty(_Received_Amount$Payi,"Ordered",'आदेश दिया'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'अनुमतियाँ प्रबंधन'),_defineProperty(_Received_Amount$Payi,"BrandManager",'ब्रांड'),_defineProperty(_Received_Amount$Payi,"BrandImage",'ब्रांड छवि'),_defineProperty(_Received_Amount$Payi,"BrandName",'ब्रांड का नाम'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'ब्रांड विवरण'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'मूल इकाई'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'इकाइयाँ प्रबंधन'),_defineProperty(_Received_Amount$Payi,"OperationValue",'ऑपरेशन मान'),_defineProperty(_Received_Amount$Payi,"Operator",'ऑपरेटर'),_defineProperty(_Received_Amount$Payi,"Top5Products",'शीर्ष पांच उत्पाद'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'पिछले पांच बिक्री'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'सूची समायोजन'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'सूची स्थानांतरण'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'स्थानांतरण बनाएँ'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'आदेश प्रबंधन'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'सूची उद्धरण'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'सूची खरीद'),_defineProperty(_Received_Amount$Payi,"ListSales",'सूची बिक्री'),_defineProperty(_Received_Amount$Payi,"ListReturns",'सूची रिटर्न'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'जन प्रबंधन'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'क्या आपको यकीन है?',
Text:'आप इसे वापस नहीं कर पाएंगे!',
confirmButtonText:'हाँ, इसे हटा दें!',
cancelButtonText:'रद्द करना',
Deleted:'हटाए गए!',
Failed:'अनुत्तीर्ण होना!',
Therewassomethingwronge:'कुछ गड़बड़ थी',
CustomerDeleted:'इस ग्राहक को हटा दिया गया है।',
SupplierDeleted:'इस आपूर्तिकर्ता को हटा दिया गया है।',
QuoteDeleted:'यह उद्धरण हटा दिया गया है।',
SaleDeleted:'यह बिक्री हटा दी गई है।',
PaymentDeleted:'यह भुगतान हटा दिया गया है।',
PurchaseDeleted:'यह खरीद हटा दी गई है।',
ReturnDeleted:'यह रिटर्न हटा दिया गया है।',
ProductDeleted:'this Product has been deleted.',
ClientError:'यह क्लाइंट पहले से ही अन्य ऑपरेशन से जुड़ा हुआ है',
ProviderError:'यह आपूर्तिकर्ता पहले से ही अन्य ऑपरेशन से जुड़ा हुआ है',
UserDeleted:'यह उपयोगकर्ता हटा दिया गया है।',
UnitDeleted:'यह इकाई हटा दी गई है।',
RoleDeleted:'यह भूमिका हटा दी गई है।',
TaxeDeleted:'यह कर हटा दिया गया है।',
SubCatDeleted:'यह उप श्रेणी हटा दी गई है।',
CatDeleted:'यह श्रेणी हटा दी गई है।',
WarehouseDeleted:'यह वेयरहाउस हटा दिया गया है।',
AlreadyLinked:'यह उत्पाद पहले से ही अन्य ऑपरेशन से जुड़ा हुआ है',
AdjustDeleted:'यह समायोजन हटा दिया गया है।',
TitleCurrency:'यह मुद्रा हटा दी गई है।',
TitleTransfer:'स्थानांतरण सफलतापूर्वक हटा दिया गया है',
BackupDeleted:'बैकअप सफलतापूर्वक निकाल दिया गया है',
TitleBrand:'यह ब्रांड हटा दिया गया है'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleProfile:'आपका प्रोफ़ाइल सफलतापूर्वक में अपडेट किया गया',
TitleAdjust:'समायोजन सफलतापूर्वक में अद्यतन किया गया',
TitleRole:'सफलतापूर्वक में भूमिका निभाई',
TitleUnit:'यूनिट को सफलतापूर्वक अपडेट किया गया',
TitleUser:'उपयोगकर्ता को सफलतापूर्वक अपडेट किया गया',
TitleCustomer:'सफलतापूर्वक ग्राहक अपडेट',
TitleQuote:'उद्धरण सफलतापूर्वक अपडेट किया गया',
TitleSale:'सफलतापूर्वक बिक्री की गई',
TitlePayment:'भुगतान सफलतापूर्वक में अपडेट किया गया',
TitlePurchase:'सफलतापूर्वक में अद्यतन किया गया',
TitleReturn:'सफलतापूर्वक में नवीनीकृत करें',
TitleProduct:'उत्पाद अद्यतन सफलतापूर्वक',
TitleSupplier:'आपूर्तिकर्ता सफलतापूर्वक में अद्यतन किया गया',
TitleTaxe:'कर अद्यतन सफलतापूर्वक',
TitleCat:'कर अद्यतन सफलतापूर्वक',
TitleWarhouse:'वेयरहाउस अद्यतन सफलतापूर्वक',
TitleSetting:'सेटिंग्स को सफलतापूर्वक में अपडेट किया गया',
TitleCurrency:'मुद्रा अद्यतन सफलतापूर्वक',
TitleTransfer:'सफलतापूर्वक में स्थानांतरण',
TitleBrand:'यह ब्रांड अद्यतन किया गया है'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'इस ब्रांड को बनाया गया है',
TitleRole:'भूमिका सफलतापूर्वक बनाई गई',
TitleUnit:'यूनिट सफलतापूर्वक बनाई गई',
TitleUser:'उपयोगकर्ता सफलतापूर्वक बनाया गया',
TitleCustomer:'सफलतापूर्वक बनाया गया ग्राहक',
TitleQuote:'उद्धरण सफलतापूर्वक बनाया गया',
TitleSale:'बिक्री सफलतापूर्वक बनाई गई',
TitlePayment:'भुगतान सफलतापूर्वक किया गया',
TitlePurchase:'सफलतापूर्वक खरीदी गई',
TitleReturn:'वापसी सफलतापूर्वक बनाई गई',
TitleProduct:'उत्पाद सफलतापूर्वक बनाया गया',
TitleSupplier:'आपूर्तिकर्ता सफलतापूर्वक बनाया गया',
TitleTaxe:'टैक्स सफलतापूर्वक बनाया गया',
TitleCat:'श्रेणी सफलतापूर्वक बनाई गई',
TitleWarhouse:'वेयरहाउस सफलतापूर्वक बनाया गया',
TitleAdjust:'समायोजन सफलतापूर्वक में बनाया गया',
TitleCurrency:'मुद्रा सफलतापूर्वक बनाई गई',
TitleTransfer:'सफलतापूर्वक में बनाया गया स्थानांतरण'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'ईमेल सफलतापूर्वक भेजें'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'यह बिक्री पहले ही एक रिटर्न के साथ जुड़ी हुई है!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'वापसी प्रबंधन'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'विस्तार से लौटें'),_defineProperty(_Received_Amount$Payi,"EditReturn",'वापसी संपादित करें'),_defineProperty(_Received_Amount$Payi,"AddReturn",'रिटर्न बनाएँ'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'ईमेल में रिटर्न भेजें'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'रिटर्न डिलीट करें'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'सरचार्ज वापस करें'),_defineProperty(_Received_Amount$Payi,"Laivrison",'वितरण'),_defineProperty(_Received_Amount$Payi,"SelectSale",'बिक्री का चयन करें'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'आप आइटम को हटा सकते हैं या यदि वह वापस नहीं किया गया है तो शून्य पर वापस सेट की गई मात्रा सेट कर सकते हैं'),_defineProperty(_Received_Amount$Payi,"Return",'वापसी'),_defineProperty(_Received_Amount$Payi,"Purchase",'खरीद फरोख्त'),_defineProperty(_Received_Amount$Payi,"TotalSales",'संपूर्ण बिक्री'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'कुल खरीद'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'कुल रिटर्न'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'नेट भुगतान'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'भुगतान भेजा गया'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'भुगतान प्राप्त किया'),_defineProperty(_Received_Amount$Payi,"Recieved",'प्राप्त किया'),_defineProperty(_Received_Amount$Payi,"Sent",'भेज दिया'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'उत्पाद मात्रा अलर्ट'),_defineProperty(_Received_Amount$Payi,"ProductCode",'कोड'),_defineProperty(_Received_Amount$Payi,"ProductName",'उत्पाद'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'चेतावनी मात्रा'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'गोदाम स्टॉक चार्ट'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'कुल उत्पाद'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'कुल मात्रा'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'शीर्ष पांच ग्राहक'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'कुल रकम'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'कुल भुगतान हो गया'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'ग्राहक बिक्री रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'ग्राहक बिक्री रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'ग्राहक उद्धरण रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"Payments",'भुगतान'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'शीर्ष पांच आपूर्तिकर्ता'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'आपूर्तिकर्ता खरीद रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'आपूर्तिकर्ता भुगतान रिपोर्ट'),_defineProperty(_Received_Amount$Payi,"Name",'नाम'),_defineProperty(_Received_Amount$Payi,"Code",'कोड'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'गोदाम प्रबंधन'),_defineProperty(_Received_Amount$Payi,"ZipCode",'पिन कोड'),_defineProperty(_Received_Amount$Payi,"managementCategories",'श्रेणियाँ प्रबंधन'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'कोड श्रेणी'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'नाम श्रेणी'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'अभिभावक श्रेणी'),_defineProperty(_Received_Amount$Payi,"managementTax",'कर प्रबंधन'),_defineProperty(_Received_Amount$Payi,"TaxName",'कर का नाम'),_defineProperty(_Received_Amount$Payi,"TaxRate",'कर दर'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'क्रय इकाई'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'विक्रय इकाई'),_defineProperty(_Received_Amount$Payi,"ShortName",'संक्षिप्त नाम'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'कृपया किसी भी उत्पाद को जोड़ने से पहले इनका चयन करें'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'स्टॉक समायोजन'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'कृपया किसी भी उत्पाद को चुनने से पहले गोदाम का चयन करें'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'स्टाक ट्रान्स्फ़र'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'अवधि का चयन करें'),_defineProperty(_Received_Amount$Payi,"ThisYear",'इस साल'),_defineProperty(_Received_Amount$Payi,"ThisToday",'यह आज'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'इस महीने'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'इस सप्ताह'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'समायोजन विवरण'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'इस उपयोगकर्ता को सक्रिय किया गया है'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'इस उपयोगकर्ता को निष्क्रिय कर दिया गया है'),_defineProperty(_Received_Amount$Payi,"NotFound",'पृष्ठ नहीं मिला।'),_defineProperty(_Received_Amount$Payi,"oops",'त्रुटि! पृष्ठ नहीं मिला।'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'आपको वह पृष्ठ नहीं मिला, जिसकी आप तलाश कर रहे थे। इसके अलावा, आप कर सकते हैं'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'डैशबोर्ड पर लौटें'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/it.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/it.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesItJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Italien
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Importo ricevuto',
Paying_Amount:'Importo da pagare',
Change:'Modificare',
Paying_amount_is_greater_than_Received_amount:'L\'importo del pagamento è maggiore dell\'importo ricevuto',
Paying_amount_is_greater_than_Grand_Total:'L\'importo del pagamento è maggiore del totale complessivo',
code_must_be_not_exist_already:'il codice non deve esistere già',
You_will_find_your_backup_on:'Troverai il tuo backup su',
and_save_it_to_your_pc:'e salvalo sul tuo pc',
Scan_your_barcode_and_select_the_correct_symbology_below:'Scansiona il tuo codice a barre e seleziona la simbologia corretta di seguito',
Scan_Search_Product_by_Code_Name:'Scansione/ricerca prodotto per nome in codice',
Paper_size:'Dimensioni del foglio',
Clear_Cache:'Cancella cache',
Cache_cleared_successfully:'Cache cancellata con successo',
Failed_to_clear_cache:'Impossibile svuotare la cache',
Scan_Barcode:'Scanner di codici a barre',
Please_use_short_name_of_unit:'Si prega di utilizzare il nome breve dell\'unità',
DefaultCustomer:'Cliente predefinito',
DefaultWarehouse:'Magazzino predefinito',
Payment_Gateway:'Casello stradale',
SMS_Configuration:'Configurazione SMS',
Gateway:'Casello stradale',
Choose_Gateway:'Scegli Payment Gateway',
Send_SMS:'messaggio inviato con successo',
sms_config_invalid:'configurazione sms errata non valida',
Remove_Stripe_Key_Secret:'Elimina le chiavi API Stripe',
credit_card_account_not_available:'Conto della carta di credito non disponibile',
Credit_Card_Info:'Informazioni sulla carta di credito',
developed_by:'Sviluppato da',
Unit_already_linked_with_sub_unit:'Unità già abbinata a sottounità',
Total_Items_Quantity:'Articoli totali e quantità',
Value_by_Cost_and_Price:'Valore per costo e prezzo',
Search_this_table:'Cerca in questa tabella',
import_products:'Importa prodotti',
Field_optional:'Campo facoltativo',
Download_exemple:'Scarica esempio',
field_must_be_in_csv_format:'Il campo deve essere in formato csv',
Successfully_Imported:'Importato con successo',
file_size_must_be_less_than_1_mega:'La dimensione del file deve essere inferiore a 1 mega',
Please_follow_the_import_instructions:'Segui le istruzioni per l\'importazione',
must_be_exist:'l\'unità deve essere già creata',
Import_Customers:'Importa clienti',
Import_Suppliers:'Fornitori di importazione',
Recent_Sales:'Vendite recenti',
Create_Transfer:'Crea trasferimento',
order_products:'articoli dell\'ordine',
Search_Product_by_Code_Name:'Cerca prodotto per codice o nome',
Reports_payments_Purchase_Return:'Rapporti sui pagamenti dei resi di acquisto',
Reports_payments_Sale_Return:'Rapporti sui pagamenti dei resi di vendita',
payments_Sales_Return:'ritorno delle vendite dei pagamenti',
payments_Purchases_Return:'ritorno acquisti pagamenti',
CreateSaleReturn:'Crea reso vendita',
EditSaleReturn:'Modifica reso vendita',
SalesReturn:'Reso di vendita',
CreatePurchaseReturn:'Crea reso acquisto',
EditPurchaseReturn:'Modifica reso acquisto',
PurchasesReturn:'Restituzione acquisti',
Due:'dovuto',
Profit:'Profitto',
Revenue:'Reddito',
Sales_today:'Vendite oggi',
People:'Persone',
Successfully_Created:'Creato con successo',
Successfully_Updated:'Aggiornato con successo',
Success:'Successo',
Failed:'Fallito',
Warning:'avvertimento',
Please_fill_the_form_correctly:'Si prega di compilare correttamente il modulo',
Field_is_required:'Il campo è obbligatiorio',
Error:'Errore!',
you_are_not_authorized:'Scusate! non sei autorizzato.',
Go_back_to_home:'Torna alla home page',
page_not_exist:'Scusate! La pagina che stavi cercando non esiste.',
Choose_Status:'Scegli Stato',
Choose_Method:'Scegli il metodo',
Choose_Symbology:'Scegli la simbologia',
Choose_Category:'Scegli la categoria',
Choose_Customer:'Scegli cliente',
Choose_Supplier:'Scegli fornitore',
Choose_Unit_Purchase:'Scegli unità di acquisto',
Choose_Sub_Category:'Scegli Sottocategoria',
Choose_Brand:'Scegli il marchio',
Choose_Warehouse:'Scegli Magazzino',
Choose_Unit_Sale:'Scegli unità di vendita',
Enter_Product_Cost:'Immettere il costo del prodotto',
Enter_Stock_alert:'Inserisci avviso di stock',
Choose_Unit_Product:'Scegli unità di prodotto',
Enter_Product_Price:'Immettere il prezzo del prodotto',
Enter_Name_Product:'Immettere il nome del prodotto',
Enter_Role_Name:'Immettere il nome del ruolo',
Enter_Role_Description:'Immettere la descrizione del ruolo',
Enter_name_category:'Immettere il nome della categoria',
Enter_Code_category:'Immettere il codice della categoria',
Enter_Name_Brand:'Immettere il nome del marchio',
Enter_Description_Brand:'Immettere il marchio della descrizione',
Enter_Code_Currency:'Immettere la valuta del codice',
Enter_name_Currency:'Immettere il nome Valuta',
Enter_Symbol_Currency:'Immettere la valuta del simbolo',
Enter_Name_Unit:'Immettere il nome dell\'unità',
Enter_ShortName_Unit:'Immettere il nome abbreviato Unità',
Choose_Base_Unit:'Scegli unità base',
Choose_Operator:'Scegli operatore',
Enter_Operation_Value:'Immettere il valore dell\'operazione',
Enter_Name_Warehouse:'Immettere il nome del magazzino',
Enter_Phone_Warehouse:'Inserisci il numero di telefono del magazzino',
Enter_Country_Warehouse:'Immettere il Paese magazzino',
Enter_City_Warehouse:'Inserisci la città del magazzino',
Enter_Email_Warehouse:'Inserisci l\'email del magazzino',
Enter_ZipCode_Warehouse:'Inserisci il codice postale del magazzino',
Choose_Currency:'Scegli Valuta',
Thank_you_for_your_business:'Grazie per il tuo business!',
Cancel:'Annulla',
New_Customer:'Nuovo cliente',
Incorrect_Login:'Accesso errato',
Successfully_Logged_In:'Accesso eseguito con successo',
This_user_not_active:'Questo utente non è attivo',
SignIn:'Registrati',
Create_an_account:'Crea un account',
Forgot_Password:'Ha dimenticato la password ?',
Email_Address:'Indirizzo e-mail',
SignUp:'Iscriviti',
Already_have_an_account:'Hai già un account ?',
Reset_Password:'Resetta la password',
Failed_to_authenticate_on_SMTP_server:'Autenticazione sul server SMTP non riuscita',
We_cant_find_a_user_with_that_email_addres:'Non riusciamo a trovare un utente con quell\'indirizzo email',
We_have_emailed_your_password_reset_link:'Abbiamo inviato per e-mail il tuo link per la reimpostazione della password',
Please_fill_the_Email_Adress:'Si prega di compilare l\'indirizzo e-mail',
Confirm_password:'Conferma password',
Your_Password_has_been_changed:'La tua password è stata modificata',
The_password_confirmation_does_not_match:'La conferma della password non corrisponde',
This_password_reset_token_is_invalid:'Questo token di reimpostazione della password non è valido',
Warehouse_report:'Rapporto di magazzino',
All_Warehouses:'Tutti i magazzini',
Expense_List:'Lista delle spese',
Expenses:'Spese',
This_Week_Sales_Purchases:'Vendite e acquisti di questa settimana',
Top_Selling_Products:'Prodotti più venduti',
View_all:'Mostra tutto',
Payment_Sent_Received:'Pagamento inviato e ricevuto',
Filter:'Filtro',
Invoice_POS:'Fattura POS',
Invoice:'Fattura',
Customer_Info:'Info clienti',
Company_Info:'azienda Info',
Invoice_Info:'Info fattura',
Order_Summary:'Riepilogo ordine',
Quote_Info:'Info quotazione',
Del:'Elimina',
SuppliersPaiementsReport:'Report pagamenti fornitori',
Purchase_Info:'Informazioni sull\'acquisto',
Supplier_Info:'Informazioni sul fornitore',
Return_Info:'informazioni di ritorno',
Expense_Category:'Categoria di spesa',
Create_Expense:'Crea spesa',
Details:'Dettagli',
Discount_Method:'Metodo di sconto',
Net_Unit_Cost:'Costo unitario netto',
Net_Unit_Price:'Prezzo unitario netto',
Edit_Expense:'Modifica spesa',
All_Brand:'Tutto il marchio',
All_Category:'Tutte le categorie',
ListExpenses:'Elenco delle spese',
Create_Permission:'Crea autorizzazione',
Edit_Permission:'Modifica autorizzazione',
Reports_payments_Sales:'Segnala i pagamenti delle vendite',
Reports_payments_Purchases:'Segnala pagamenti acquisti',
Reports_payments_Return_Customers:'Segnala pagamenti Resi clienti',
Reports_payments_Return_Suppliers:'Segnala pagamenti Resi Fornitori',
Expense_Deleted:'Questa spesa è stata cancellata',
Expense_Updated:'Questa spesa è stata aggiornata',
Expense_Created:'Questa spesa è stata creata',
DemoVersion:'Non puoi farlo nella versione demo',
Filesize:'Dimensione del file',
GenerateBackup:'Genera backup',
BackupDatabase:'Backup del database',
Backup:'Backup del database',
OrderStatistics:'Statistiche di vendita',
AlreadyAdd:'Este producto ya está agregado',
AddProductToList:'Agregue el producto a la lista',
AddQuantity:'Por favor agregue la cantidad',
InvalidData:'Datos inválidos',
LowStock:'la quantità supera la quantità disponibile in magazzino',
WarehouseIdentical:'Los dos repositorios no pueden ser idénticos',
VariantDuplicate:'Esta variable es redundante',
Paid:'Pagato',
Unpaid:'Non pagato',
IncomeExpenses:'Entrate e uscite',
dailySalesPurchases:'Vendite e acquisti giornalieri',
ProductsExpired:'Prodotti scaduti',
Today:'oggi',
Income:'Reddito'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Spese'),_defineProperty(_Received_Amount$Payi,"Sale",'Vendita'),_defineProperty(_Received_Amount$Payi,"Actif",'Attivo'),_defineProperty(_Received_Amount$Payi,"Inactif",'Inattivo'),_defineProperty(_Received_Amount$Payi,"Customers",'I clienti'),_defineProperty(_Received_Amount$Payi,"Phone",'Telefono'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Cerca per telefono'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Fornitori'),_defineProperty(_Received_Amount$Payi,"Quotations",'Quotazione'),_defineProperty(_Received_Amount$Payi,"Sales",'I saldi'),_defineProperty(_Received_Amount$Payi,"Purchases",'acquisti'),_defineProperty(_Received_Amount$Payi,"Returns",'ritorna'),_defineProperty(_Received_Amount$Payi,"Settings",'impostazioni'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'Impostazioni di sistema'),_defineProperty(_Received_Amount$Payi,"Users",'utenti'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Autorizzazioni di gruppo'),_defineProperty(_Received_Amount$Payi,"Currencies",'valute'),_defineProperty(_Received_Amount$Payi,"Warehouses",'magazzini'),_defineProperty(_Received_Amount$Payi,"Units",'unità'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'Acquisti di unità'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Vendite di unità'),_defineProperty(_Received_Amount$Payi,"Reports",'Rapporti'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Rapporto sui pagamenti'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Pagamenti Acquisti'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Vendite di pagamenti'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Profitti e perdite'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Grafico azioni magazzino'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Rapporto delle vendite'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Rapporto d\'acquisto'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Rapporto dei clienti'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Rapporto fornitori'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Rapporto del fornitore'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Dati di vendita giornalieri'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Dati di acquisto giornalieri'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Ultimi cinque record'),_defineProperty(_Received_Amount$Payi,"Filters",'filtri'),_defineProperty(_Received_Amount$Payi,"date",'Data'),_defineProperty(_Received_Amount$Payi,"Reference",'Riferimento'),_defineProperty(_Received_Amount$Payi,"Supplier",'Fornitore'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Stato del pagamento'),_defineProperty(_Received_Amount$Payi,"Customer",'Cliente'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Codice Cliente'),_defineProperty(_Received_Amount$Payi,"Status",'Stato'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Codice fornitore'),_defineProperty(_Received_Amount$Payi,"Categorie",'Categoria'),_defineProperty(_Received_Amount$Payi,"Categories",'categorie'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Trasferimenti di azioni'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Gestione delle scorte'),_defineProperty(_Received_Amount$Payi,"dashboard",'Pannello di controllo'),_defineProperty(_Received_Amount$Payi,"Products",'Prodotti'),_defineProperty(_Received_Amount$Payi,"productsList",'Elenco prodotti'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Gestione del prodotto'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Avviso quantità prodotto'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Codice prodotto'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Imposta sul prodotto'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'sottocategoria'),_defineProperty(_Received_Amount$Payi,"Name_product",'Designazione'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Avviso stock'),_defineProperty(_Received_Amount$Payi,"warehouse",'magazzino'),_defineProperty(_Received_Amount$Payi,"Tax",'Imposta'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Prezzo d\'acquisto'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Prezzo di vendita'),_defineProperty(_Received_Amount$Payi,"Quantity",'Quantità'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Vendita unitaria'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Acquisto unitario'),_defineProperty(_Received_Amount$Payi,"All",'Tutti'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Modifica prodotto'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Aggiungi prodotto'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Cerca per codice'),_defineProperty(_Received_Amount$Payi,"SearchByName",'Ricerca per nome'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'Dettagli del prodotto'),_defineProperty(_Received_Amount$Payi,"CustomerName",'Nome del cliente'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Gestione clienti'),_defineProperty(_Received_Amount$Payi,"Add",'Inserisci'),_defineProperty(_Received_Amount$Payi,"add",'Inserisci'),_defineProperty(_Received_Amount$Payi,"Edit",'modificare'),_defineProperty(_Received_Amount$Payi,"Close",'Vicino'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Si prega di selezionare'),_defineProperty(_Received_Amount$Payi,"Action",'Azione'),_defineProperty(_Received_Amount$Payi,"Email",'E-mail'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Modifica cliente'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Aggiungi cliente'),_defineProperty(_Received_Amount$Payi,"Country",'Nazione'),_defineProperty(_Received_Amount$Payi,"City",'Città'),_defineProperty(_Received_Amount$Payi,"Adress",'Indirizzo'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'Dettagli cliente'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Elenco clienti'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Codice fornitore'),_defineProperty(_Received_Amount$Payi,"SupplierName",'Nome del fornitore'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Gestione dei fornitori'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Dettagli del fornitore'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Gestione delle quotazioni'),_defineProperty(_Received_Amount$Payi,"SubTotal",'totale parziale'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Importo rimasto'),_defineProperty(_Received_Amount$Payi,"complete",'completare'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'in attesa di'),_defineProperty(_Received_Amount$Payi,"Recu",'Ricevuto'),_defineProperty(_Received_Amount$Payi,"partial",'Parziale'),_defineProperty(_Received_Amount$Payi,"Retournee",'Ritorno'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Quotazione di dettaglio'),_defineProperty(_Received_Amount$Payi,"EditQuote",'Modifica Quotazione'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Crea vendita'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'Scarica il pdf'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'Preventivo inviato via e-mail'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'Elimina Quotazione'),_defineProperty(_Received_Amount$Payi,"AddQuote",'Aggiungi Quotazione'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Seleziona prodotto'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Prodotto (Codice - Nome)'),_defineProperty(_Received_Amount$Payi,"Price",'Prezzo'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'Scorta'),_defineProperty(_Received_Amount$Payi,"Total",'Totale'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'Costo unitario'),_defineProperty(_Received_Amount$Payi,"to",'per'),_defineProperty(_Received_Amount$Payi,"Subject",'Soggetto'),_defineProperty(_Received_Amount$Payi,"Message",'Messaggio'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'Email del cliente'),_defineProperty(_Received_Amount$Payi,"Sent",'Spedire'),_defineProperty(_Received_Amount$Payi,"Quote",'Quotazione'),_defineProperty(_Received_Amount$Payi,"Hello",'Ciao'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Si prega di trovare l\'allegato per il preventivo'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Aggiungi prodotti all\'elenco ordini'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Seleziona il magazzino'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'Seleziona cliente'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Direzione vendite'),_defineProperty(_Received_Amount$Payi,"Balance",'Equilibrio'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Quantità ritorno'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Rendimento totale'),_defineProperty(_Received_Amount$Payi,"Amount",'somma'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Dettaglio di vendita'),_defineProperty(_Received_Amount$Payi,"EditSale",'Modifica vendita'),_defineProperty(_Received_Amount$Payi,"AddSale",'Aggiungi vendita'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Mostra pagamenti'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Aggiungi pagamento'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Modifica pagamento'),_defineProperty(_Received_Amount$Payi,"EmailSale",'Invia vendita via email'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Elimina vendita'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Modalità di pagamento'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Scelta di pagamento'),_defineProperty(_Received_Amount$Payi,"Note",'Nota'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Pagamento completato!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Gestione degli acquisti'),_defineProperty(_Received_Amount$Payi,"Ordered",'Ordinato'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Elimina acquisto'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Invia acquisto via e-mail'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Modifica acquisto'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Dettaglio d\'acquisto'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Aggiungi acquisto'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Email del fornitore'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Pagamenti acquisti'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Acquista i dati sui pagamenti'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'Pagamenti alle vendite'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Dati di pagamento delle vendite'),_defineProperty(_Received_Amount$Payi,"UserManagement",'gestione degli utenti'),_defineProperty(_Received_Amount$Payi,"Firstname",'Nome di battesimo'),_defineProperty(_Received_Amount$Payi,"lastname",'cognome'),_defineProperty(_Received_Amount$Payi,"username",'NOME UTENTE'),_defineProperty(_Received_Amount$Payi,"password",'PASSWORD'),_defineProperty(_Received_Amount$Payi,"Newpassword",'Nuova password'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Cambia avatar'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Si prega di lasciare vuoto questo campo se non è stato modificato'),_defineProperty(_Received_Amount$Payi,"type",'genere'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Autorizzazioni degli utenti'),_defineProperty(_Received_Amount$Payi,"RoleName",'Nome del ruolo'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Descrizione del ruolo'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'Aggiungi autorizzazioni'),_defineProperty(_Received_Amount$Payi,"View",'Visualizza'),_defineProperty(_Received_Amount$Payi,"Del",'Elimina'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'Nuovo regolazione'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Modifica regolazione'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'Non è possibile sottrarre prodotti con stock 0'),_defineProperty(_Received_Amount$Payi,"Addition",'aggiunta'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Sottrazione'),_defineProperty(_Received_Amount$Payi,"profil",'profilo'),_defineProperty(_Received_Amount$Payi,"logout",'disconnettersi'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'non è possibile cambiare perché questo acquisto è già stato pagato'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'non puoi modificare perché questa vendita è già stata pagata'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'non puoi modificare perché questa Ritorno è già stata pagata'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'Questa citazione ha già generato vendita'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'Questa citazione è completa'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Configurazione del sito'),_defineProperty(_Received_Amount$Payi,"Language",'linguaggio'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'Valuta predefinita'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Accedi Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Email predefinita'),_defineProperty(_Received_Amount$Payi,"SiteName",'Nome del sito'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Cambia logo'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'Configurazione SMTP'),_defineProperty(_Received_Amount$Payi,"HOST",'OSPITE'),_defineProperty(_Received_Amount$Payi,"PORT",'PORTA'),_defineProperty(_Received_Amount$Payi,"encryption",'crittografia'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'Configurazione SMTP errata'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Pagamenti di ritorno'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'fatture di ritorno'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'Dati di fatture di ritorno'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Mostra tutti i record di tutti gli utenti'),_defineProperty(_Received_Amount$Payi,"Discount",'Sconto'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Imposta sugli ordini'),_defineProperty(_Received_Amount$Payi,"Shipping",'spedizione'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Valute di gestione'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Codice valuta'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Nome valuta'),_defineProperty(_Received_Amount$Payi,"Symbol",'Simbolo'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Nome della ditta'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Telefono aziendale'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'Indirizzo aziendale'),_defineProperty(_Received_Amount$Payi,"Code",'Codice'),_defineProperty(_Received_Amount$Payi,"image",'Immagine'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'Stampa codice a barre'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'Vendite di ritorno'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'Restituire gli acquisti'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'fatture Vendite di reso'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'fatture Resi acquisti'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'Nessun dato disponibile'),_defineProperty(_Received_Amount$Payi,"ProductImage",'Immagine del prodotto'),_defineProperty(_Received_Amount$Payi,"Barcode",'codice a barre'),_defineProperty(_Received_Amount$Payi,"pointofsales",'punto vendita'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Caricamento personalizzato'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'Gestione punto vendita'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Regolazione'),_defineProperty(_Received_Amount$Payi,"Updat",'Aggiornare'),_defineProperty(_Received_Amount$Payi,"Reset",'Ripristina'),_defineProperty(_Received_Amount$Payi,"print",'Stampa'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'Cerca per e-mail'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Scegli il prodotto'),_defineProperty(_Received_Amount$Payi,"Qty",'Qtà'),_defineProperty(_Received_Amount$Payi,"Items",'Elementi'),_defineProperty(_Received_Amount$Payi,"AmountHT",'somma HT'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'somma TTC'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Seleziona il fornitore'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Seleziona lo stato'),_defineProperty(_Received_Amount$Payi,"PayeBy",'Pagato con'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Scegli Magazzino'),_defineProperty(_Received_Amount$Payi,"payNow",'paga ora'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'Elenco delle categorie'),_defineProperty(_Received_Amount$Payi,"Description",'Descrizione'),_defineProperty(_Received_Amount$Payi,"submit",'Invia'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'Si è verificato un problema durante la creazione di questa fattura. Per favore riprova'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'Si è verificato un problema con il pagamento. Per favore riprova.'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Crea aggiustamento'),_defineProperty(_Received_Amount$Payi,"Afewwords",'qualche parola in merito...'),_defineProperty(_Received_Amount$Payi,"UserImage",'Immagine dell\'utente'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Aggiorna prodotto'),_defineProperty(_Received_Amount$Payi,"Brand",'Marca'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Simbologia del codice a barre'),_defineProperty(_Received_Amount$Payi,"ProductCost",'costi del prodotto'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Prezzo del prodotto'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Prodotto unitario'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Metodo fiscale'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Immagine multipla'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Il prodotto ha più varianti'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'Il prodotto ha una promozione'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Inizia la promozione'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Fine promozione'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Prezzo promozionale'),_defineProperty(_Received_Amount$Payi,"Price",'Prezzo'),_defineProperty(_Received_Amount$Payi,"Cost",'Costo'),_defineProperty(_Received_Amount$Payi,"Unit",'Unità'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Variante di prodotto'),_defineProperty(_Received_Amount$Payi,"Variant",'Variante'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Prezzo unitario'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'Crea cliente di reso'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'Modifica cliente di reso'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'Crea fornitore di reso'),_defineProperty(_Received_Amount$Payi,"Documentation",'Documentazione'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'Modifica fornitore di reso'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'Dal magazzino'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'Al magazzino'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Modifica trasferimento'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Dettaglio trasferimento'),_defineProperty(_Received_Amount$Payi,"Pending",'in attesa di'),_defineProperty(_Received_Amount$Payi,"Received",'Ricevuto'),_defineProperty(_Received_Amount$Payi,"Ordered",'Ordinato'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'Gestore delle autorizzazioni'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Gestore di marchio'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Immagine di marca'),_defineProperty(_Received_Amount$Payi,"BrandName",'Nome di marca'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Descrizione di marca'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Unità base'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Gestione delle unità'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Valore dell\'operazione'),_defineProperty(_Received_Amount$Payi,"Operator",'Operatore'),_defineProperty(_Received_Amount$Payi,"Top5Products",'I 5 migliori prodotti'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'Ultime 5 vendite'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'Elenca le regolazioni'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Elenco trasferimenti'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Crea trasferimento'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Gestione degli ordini'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Elenco citazioni'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Elenco acquisti'),_defineProperty(_Received_Amount$Payi,"ListSales",'Elenco vendite'),_defineProperty(_Received_Amount$Payi,"ListReturns",'Elenco dei resi'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'manager del personale'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Elenco dei marchi'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Sei sicuro?',
Text:'Non sarai in grado di ripristinare questo!',
confirmButtonText:'Sì, cancellalo!',
cancelButtonText:'Annulla',
Deleted:'eliminare!',
Failed:'Mancato!',
Therewassomethingwronge:'C\'era qualcosa che non andava',
CustomerDeleted:'questo cliente è stato eliminato',
SupplierDeleted:'questo fornitore è stato eliminato',
QuoteDeleted:'questa citazione è stata eliminato',
SaleDeleted:'questa vendita è stata eliminata',
PaymentDeleted:'questo pagamento è stato eliminato',
PurchaseDeleted:'questo acquisto è stato eliminato',
ReturnDeleted:'questo ritorno è stato eliminato',
ProductDeleted:'questo prodotto è stato eliminato',
ClientError:'Questo cliente è già collegato ad altre operazioni',
ProviderError:'Questo fornitore è già collegato ad altre operazioni',
UserDeleted:'Questo utente è stato eliminato',
UnitDeleted:'Questa unità è stata eliminata',
RoleDeleted:'Questo ruolo è stato eliminato',
TaxeDeleted:'Questa imposta è stata eliminata',
SubCatDeleted:'Questa sottocategoria è stata eliminata',
CatDeleted:'Questa categoria è stata eliminata',
WarehouseDeleted:'Questo magazzino è stato eliminata',
AlreadyLinked:'questo prodotto è già collegato ad altre operazioni',
AdjustDeleted:'Questo adeguamento è stato eliminato',
TitleCurrency:'Questa valuta è stata eliminata',
TitleTransfer:'La trasferimento è stata rimossa con successo',
BackupDeleted:'Il backup è stato rimosso con successo',
TitleBrand:'Questo marchio è stato eliminato'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleBrand:'Questo marchio è stato aggiornato',
TitleProfile:'Il tuo profilo è stato aggiornato con successo',
TitleAdjust:'Aggiustamento aggiornato con successo',
TitleRole:'Ruolo aggiornato con successo',
TitleUnit:'L\'unità è stata aggiornata con successo',
TitleUser:'Aggiornamento utente eseguito correttamente',
TitleCustomer:'Il cliente è stato aggiornato con successo',
TitleQuote:'Preventivo aggiornato con successo',
TitleSale:'Vendita aggiornata con successo',
TitlePayment:'Pagamento aggiornato con successo',
TitlePurchase:'Acquisto aggiornato con successo',
TitleReturn:'Ritorno Aggiornato con successo',
TitleProduct:'Prodotto aggiornato con successo',
TitleSupplier:'Il fornitore è stato aggiornato con successo',
TitleTaxe:'Imposte aggiornate con successo',
TitleCat:'Categoria aggiornata con successo',
TitleWarhouse:'Magazzino aggiornato con successo',
TitleSetting:'Impostazioni aggiornate con successo',
TitleCurrency:'Questa valuta è stata aggiornata',
TitleTransfer:'La trasferimento è stata aggiornata con successo'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'Questo marchio è stato creato',
TitleTransfer:'La trasferimento è stata aggiornata con successo',
TitleRole:'Ruolo creato con successo',
TitleUnit:'Unità creata con successo',
TitleUser:'Utente creato correttamente',
TitleCustomer:'Cliente creato con successo',
TitleQuote:'Citazione creata con successo',
TitleSale:'Vendita creata con successo',
TitlePayment:'Pagamento creato con successo',
TitlePurchase:'Acquisto creato con successo',
TitleReturn:'Ritorno Creato con successo',
TitleProduct:'Prodotto creato con successo',
TitleSupplier:'Fornitore creato con successo',
TitleTaxe:'Imposta creata con successo',
TitleCat:'Categoria creata con successo',
TitleWarhouse:'Magazzino creato con successo',
TitleAdjust:'Aggiustamento creato con successo',
TitleCurrency:'Questa valuta è stata creata'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'Email Invia correttamente'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'questa vendita già collegata con un ritorno!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'Gestione dei ritorna'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'Dettagli di ritorno'),_defineProperty(_Received_Amount$Payi,"EditReturn",'Modifica ritorno'),_defineProperty(_Received_Amount$Payi,"AddReturn",'Aggiungi ritorno'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'Invia Ritorno in e-mail'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'Elimina ritorno'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'Supplemento per restituzione'),_defineProperty(_Received_Amount$Payi,"Laivrison",'consegna'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Seleziona vendita'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'È possibile eliminare l\'articolo o impostare la quantità restituita su zero se non viene restituita'),_defineProperty(_Received_Amount$Payi,"Return",'Ritorno'),_defineProperty(_Received_Amount$Payi,"Purchase",'Acquista'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Vendite totali'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Acquisti totali'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Retorna totali'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Pagamenti netti'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Pagamenti inviati'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Pagamenti ricevuti'),_defineProperty(_Received_Amount$Payi,"Recieved",'ricevuti'),_defineProperty(_Received_Amount$Payi,"Sent",'inviati'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Avvisi quantità prodotto'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Codice prodotto'),_defineProperty(_Received_Amount$Payi,"ProductName",'nome del prodotto'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Quantità di avviso'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Grafico azioni magazzino'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Totale prodotti'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Quantità totale'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'I 5 migliori clienti'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Importo totale'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Totale pagato'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Rapporto sulle vendite dei clienti'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Rapporto sui pagamenti dei clienti'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'Rapporto sulle citazioni dei clienti'),_defineProperty(_Received_Amount$Payi,"Payments",'pagamenti'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'Primi 5 fornitori'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Rapporto sugli acquisti dei fornitori'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Rapporto sui pagamenti dei fornitori'),_defineProperty(_Received_Amount$Payi,"Name",'Nome'),_defineProperty(_Received_Amount$Payi,"Code",'Codice'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Gestione del magazzino'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Cap'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Gestione delle categorie'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Categoria di codice'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'Nome categoria'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Categoria principale'),_defineProperty(_Received_Amount$Payi,"managementTax",'Gestione fiscale'),_defineProperty(_Received_Amount$Payi,"TaxName",'Nome fiscale'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Aliquota fiscale'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Gestione dell\'unità acquisti'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Gestione dell\'unità di vendita'),_defineProperty(_Received_Amount$Payi,"ShortName",'Nome corto'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Seleziona questi prima di aggiungere qualsiasi prodotto'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Adeguamento delle scorte'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Seleziona il magazzino prima di scegliere qualsiasi prodotto'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Trasferimento stock'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Seleziona Periodo'),_defineProperty(_Received_Amount$Payi,"ThisYear",'Quest\'anno'),_defineProperty(_Received_Amount$Payi,"ThisToday",'Questo oggi'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'Questo mese'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'Questa settimana'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Dettaglio regolazione'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'Questo utente è stato attivato'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'Questo utente è stato disattivato'),_defineProperty(_Received_Amount$Payi,"NotFound",'Pagina non trovata.'),_defineProperty(_Received_Amount$Payi,"oops",'errore! Pagina non trovata.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'Non siamo riusciti a trovare la pagina che stavi cercando. Nel frattempo, potresti'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'torna alla dashboard'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/ru.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/ru.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesRuJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Russian
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Полученная сумма',
Paying_Amount:'Сумма платежа',
Change:'Изменять',
Paying_amount_is_greater_than_Received_amount:'Сумма платежа больше полученной суммы',
Paying_amount_is_greater_than_Grand_Total:'Сумма платежа превышает общую сумму',
code_must_be_not_exist_already:'код уже не должен существовать',
You_will_find_your_backup_on:'Вы найдете резервную копию на',
and_save_it_to_your_pc:'и сохраните на свой компьютер',
Scan_your_barcode_and_select_the_correct_symbology_below:'Отсканируйте свой штрих-код и выберите правильную символику ниже',
Scan_Search_Product_by_Code_Name:'Сканирование / поиск продукта по кодовому названию',
Paper_size:'Размер бумаги',
Clear_Cache:'Очистить кэш',
Cache_cleared_successfully:'Кеш успешно очищен',
Failed_to_clear_cache:'Не удалось очистить кеш',
Scan_Barcode:'Сканер штрих-кода',
Please_use_short_name_of_unit:'Пожалуйста, используйте короткое название единицы',
DefaultCustomer:'Клиент по умолчанию',
DefaultWarehouse:'Склад по умолчанию',
Payment_Gateway:'Платежный шлюз',
SMS_Configuration:'Конфигурация SMS',
Gateway:'Платежный шлюз',
Choose_Gateway:'Выберите платежный шлюз',
Send_SMS:'Сообщение успешно отправлено',
sms_config_invalid:'неверная конфигурация смс недействительна',
Remove_Stripe_Key_Secret:'Удалить ключи API Stripe',
credit_card_account_not_available:'Счет кредитной карты недоступен',
Credit_Card_Info:'Информация о кредитной карте',
developed_by:'Разработан',
Unit_already_linked_with_sub_unit:'Объект уже связан с дополнительным блоком',
Total_Items_Quantity:'Итого и количество',
Value_by_Cost_and_Price:'Соотношение затрат и цен',
Search_this_table:'Искать в этой таблице',
import_products:'Импортные товары',
Field_optional:'Поле необязательно',
Download_exemple:'Скачать пример',
field_must_be_in_csv_format:'Поле должно быть в формате csv.',
Successfully_Imported:'Успешно импортировано',
file_size_must_be_less_than_1_mega:'Размер файла не должен превышать 1 мегабайт.',
Please_follow_the_import_instructions:'Следуйте инструкциям по импорту',
must_be_exist:'юнит уже должен быть создан',
Import_Customers:'Импортные клиенты',
Import_Suppliers:'Поставщики импорта',
Recent_Sales:'Последние продажи',
Create_Transfer:'Создать перевод',
order_products:'элементы заказа',
Search_Product_by_Code_Name:'Поиск продукта по коду или названию',
Reports_payments_Purchase_Return:'Отчеты о возвратных платежах за покупку',
Reports_payments_Sale_Return:'Отчеты о продажах и возвратах платежей',
payments_Sales_Return:'возврат платежей',
payments_Purchases_Return:'платежи покупки возврат',
CreateSaleReturn:'Создать возврат продажи',
EditSaleReturn:'Изменить возврат продажи',
SalesReturn:'Возвращение продаж',
CreatePurchaseReturn:'Создать возврат покупки',
EditPurchaseReturn:'Изменить возврат покупки',
PurchasesReturn:'Покупки Возврат',
Due:'должный',
Profit:'Выгода',
Revenue:'Доход',
Sales_today:'Продажи сегодня',
People:'Люди',
Successfully_Created:'Успешно создано',
Successfully_Updated:'Успешно обновлено',
Success:'Успех',
Failed:'Не удалось',
Warning:'Warning',
Please_fill_the_form_correctly:'Пожалуйста, заполните форму правильно',
Field_is_required:'Поле, обязательное для заполнения',
Error:'Ошибка!',
you_are_not_authorized:'Извини! вы не авторизованы.',
Go_back_to_home:'Вернуться на главную',
page_not_exist:'Извини! Страница, которую вы искали, не существует.',
Choose_Status:'Выберите статус',
Choose_Method:'Выберите метод',
Choose_Symbology:'Выберите символы',
Choose_Category:'Выберите категорию',
Choose_Customer:'Выберите клиента',
Choose_Supplier:'Выберите поставщика',
Choose_Unit_Purchase:'Выберите покупную единицу',
Choose_Sub_Category:'Выберите подкатегорию',
Choose_Brand:'Выберите марку',
Choose_Warehouse:'Выберите склад',
Choose_Unit_Sale:'Выберите единицу продажи',
Enter_Product_Cost:'Введите стоимость продукта',
Enter_Stock_alert:'Введите оповещение о наличии акций',
Choose_Unit_Product:'Выберите единицу продукции',
Enter_Product_Price:'Введите цену продукта',
Enter_Name_Product:'Введите название продукта',
Enter_Role_Name:'Введите имя роли',
Enter_Role_Description:'Введите описание роли',
Enter_name_category:'Введите название категории',
Enter_Code_category:'Введите код категории',
Enter_Name_Brand:'Введите название бренда',
Enter_Description_Brand:'Введите описание бренда',
Enter_Code_Currency:'Введите валюту кода',
Enter_name_Currency:'Введите имя Валюта',
Enter_Symbol_Currency:'Введите валюту символа',
Enter_Name_Unit:'Введите название объекта',
Enter_ShortName_Unit:'Введите короткое имя',
Choose_Base_Unit:'Выберите базовый блок',
Choose_Operator:'Выберите оператора',
Enter_Operation_Value:'Введите значение операции',
Enter_Name_Warehouse:'Введите название склада',
Enter_Phone_Warehouse:'Введите телефон склада',
Enter_Country_Warehouse:'Укажите страну склада',
Enter_City_Warehouse:'Введите город склада',
Enter_Email_Warehouse:'Введите адрес электронной почты склада',
Enter_ZipCode_Warehouse:'Введите почтовый индекс склада',
Choose_Currency:'Выберите Валюту',
Thank_you_for_your_business:'Спасибо за ваш бизнес!',
Cancel:'Отмена',
New_Customer:'Новый покупатель',
Incorrect_Login:'Неправильный логин',
Successfully_Logged_In:'Успешный вход в систему',
This_user_not_active:'Этот пользователь не активен',
SignIn:'Войти',
Create_an_account:'Завести аккаунт',
Forgot_Password:'Забыл пароль ?',
Email_Address:'Адрес электронной почты',
SignUp:'Зарегистрироваться',
Already_have_an_account:'Уже есть аккаунт?',
Reset_Password:'Сброс пароля',
Failed_to_authenticate_on_SMTP_server:'Не удалось пройти аутентификацию на SMTP-сервере',
We_cant_find_a_user_with_that_email_addres:'Мы не можем найти пользователя с таким адресом электронной почты',
We_have_emailed_your_password_reset_link:'Мы отправили вам ссылку для сброса пароля по электронной почте',
Please_fill_the_Email_Adress:'Пожалуйста, заполните адрес электронной почты',
Confirm_password:'Подтвердить Пароль',
Your_Password_has_been_changed:'Ваш пароль был изменен',
The_password_confirmation_does_not_match:'Подтверждение пароля не совпадает',
This_password_reset_token_is_invalid:'Этот токен сброса пароля недействителен',
Warehouse_report:'Отчет о складе',
All_Warehouses:'Все склады',
Expense_List:'Список расходов',
Expenses:'Затраты',
This_Week_Sales_Purchases:'Продажи и покупки на этой неделе',
Top_Selling_Products:'Самые продаваемые товары',
View_all:'Посмотреть все',
Payment_Sent_Received:'Платеж отправлен и получен',
Filter:'Фильтр',
Invoice_POS:'Счет-фактура POS',
Invoice:'Выставленный счет',
Customer_Info:'Информация о клиенте',
Company_Info:'информация о компании',
Invoice_Info:'Информация о счете',
Order_Summary:'итог заказа',
Quote_Info:'Ценовая информация',
Del:'удалять',
SuppliersPaiementsReport:'Отчет о платежах поставщикам',
Purchase_Info:'Информация о покупке',
Supplier_Info:'Информация о поставщиках',
Return_Info:'информация о возврате',
Expense_Category:'Категория расходов',
Create_Expense:'Создать расход',
Details:'Детали',
Discount_Method:'Метод скидки',
Net_Unit_Cost:'Чистая стоимость единицы',
Net_Unit_Price:'Чистая цена за единицу',
Edit_Expense:'Изменить расходы',
All_Brand:'Все марки',
All_Category:'Все категории',
ListExpenses:'Перечислить расходы',
Create_Permission:'Создать разрешение',
Edit_Permission:'Изменить разрешение',
Reports_payments_Sales:'Отчеты о платежах Продажи',
Reports_payments_Purchases:'Отчеты о платежах Покупки',
Reports_payments_Return_Customers:'Отчеты о платежах Возврат клиентов',
Reports_payments_Return_Suppliers:'Отчеты о платежах Возврат Поставщикам',
Expense_Deleted:'Этот расход был удален',
Expense_Updated:'Этот расход был обновлен',
Expense_Created:'Этот расход был создан',
DemoVersion:'Вы не можете этого сделать в демо-версии',
OrderStatistics:'Статистика продаж',
AlreadyAdd:'Этот продукт уже добавлен!',
AddProductToList:'Пожалуйста, добавьте товар в список!',
AddQuantity:'Пожалуйста, добавьте количество деталей !!',
InvalidData:'Неверные данные !!',
LowStock:'количество превышает количество на складе',
WarehouseIdentical:'Два склада не могут быть идентичными !!',
VariantDuplicate:'Этот вариант дублируется !!',
Filesize:'Размер файла',
GenerateBackup:'Создать резервную копию',
BackupDatabase:'Резервная база данных',
Backup:'резервное копирование',
Paid:'Платный',
Unpaid:'Неоплаченный',
Today:'Cегодня',
Income:'Доход'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Затраты'),_defineProperty(_Received_Amount$Payi,"Sale",'распродажа'),_defineProperty(_Received_Amount$Payi,"Actif",'Активный'),_defineProperty(_Received_Amount$Payi,"Inactif",'Неактивный'),_defineProperty(_Received_Amount$Payi,"Customers",'Клиенты'),_defineProperty(_Received_Amount$Payi,"Phone",'Телефон'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Поиск по телефону'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Поставщики'),_defineProperty(_Received_Amount$Payi,"Quotations",'Котировки'),_defineProperty(_Received_Amount$Payi,"Sales",'Продажи'),_defineProperty(_Received_Amount$Payi,"Purchases",'Покупки'),_defineProperty(_Received_Amount$Payi,"Returns",'Возврат'),_defineProperty(_Received_Amount$Payi,"Settings",'Настройки'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'Системные настройки'),_defineProperty(_Received_Amount$Payi,"Users",'Пользователи'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Групповые разрешения'),_defineProperty(_Received_Amount$Payi,"Currencies",'Валюты'),_defineProperty(_Received_Amount$Payi,"Warehouses",'Склады'),_defineProperty(_Received_Amount$Payi,"Units",'Единицы'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'Покупка единиц'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Единицы продаж'),_defineProperty(_Received_Amount$Payi,"Reports",'Отчеты'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Отчет о платежах'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Платежи Покупки'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Платежи Продажи'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Прибыль и убыток'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'График складских запасов'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Отчет о продажах'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Отчет о закупках'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Отчет клиентов'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Отчет о поставщиках'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Отчет поставщика'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Ежедневные данные о продажах'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Данные о ежедневных покупках'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Последние пять рекордов'),_defineProperty(_Received_Amount$Payi,"Filters",'Фильтры'),_defineProperty(_Received_Amount$Payi,"date",'Дата'),_defineProperty(_Received_Amount$Payi,"Reference",'Справка'),_defineProperty(_Received_Amount$Payi,"Supplier",'Поставщик'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Статус платежа'),_defineProperty(_Received_Amount$Payi,"Customer",'Покупатель'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Код клиента'),_defineProperty(_Received_Amount$Payi,"Status",'Положение дел'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Код поставщиком'),_defineProperty(_Received_Amount$Payi,"Categorie",'Категория'),_defineProperty(_Received_Amount$Payi,"Categories",'Категории'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Передача запасов'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Управление запасами'),_defineProperty(_Received_Amount$Payi,"dashboard",'Щиток приборов'),_defineProperty(_Received_Amount$Payi,"Products",'Товары'),_defineProperty(_Received_Amount$Payi,"productsList",'Список продуктов'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Управление продуктом'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Оповещения о количестве товаров'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Код продукта'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Налог на продукцию'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'Подкатегория'),_defineProperty(_Received_Amount$Payi,"Name_product",'Обозначение'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Уведомление о наличии запасов'),_defineProperty(_Received_Amount$Payi,"warehouse",'склад'),_defineProperty(_Received_Amount$Payi,"Tax",'Налог'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Цена покупки'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Цена продажи'),_defineProperty(_Received_Amount$Payi,"Quantity",'Количество'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Продажа единиц'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Покупка единицы'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Валютный менеджмент'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Код валюты'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Название валюты'),_defineProperty(_Received_Amount$Payi,"Symbol",'Символ'),_defineProperty(_Received_Amount$Payi,"All",'Все'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Редактировать продукт'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Поиск по коду'),_defineProperty(_Received_Amount$Payi,"SearchByName",'Поиск по имени'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'информация о продукте'),_defineProperty(_Received_Amount$Payi,"CustomerName",'Имя Клиента'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Управление клиентами'),_defineProperty(_Received_Amount$Payi,"Add",'Создайте'),_defineProperty(_Received_Amount$Payi,"add",'Создайте'),_defineProperty(_Received_Amount$Payi,"Edit",'редактировать'),_defineProperty(_Received_Amount$Payi,"Close",'близко'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Пожалуйста выберите'),_defineProperty(_Received_Amount$Payi,"Action",'Действие'),_defineProperty(_Received_Amount$Payi,"Email",'Электронное письмо'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Изменить клиента'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Создать клиента'),_defineProperty(_Received_Amount$Payi,"Country",'Страна'),_defineProperty(_Received_Amount$Payi,"City",'город'),_defineProperty(_Received_Amount$Payi,"Adress",'Адрес'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'Детали клиента'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Список клиентов'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Код поставщиком'),_defineProperty(_Received_Amount$Payi,"SupplierName",'наименование поставщика'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Управление поставщиками'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Детали поставщика'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Управление котировками'),_defineProperty(_Received_Amount$Payi,"SubTotal",'Промежуточный итог'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Осталась сумма'),_defineProperty(_Received_Amount$Payi,"complete",'завершено'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'в ожидании'),_defineProperty(_Received_Amount$Payi,"Recu",'Получила'),_defineProperty(_Received_Amount$Payi,"partial",'Частичное'),_defineProperty(_Received_Amount$Payi,"Retournee",'Возвращение'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Подробная цитата'),_defineProperty(_Received_Amount$Payi,"EditQuote",'Изменить цитату'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Создать распродажу'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'Скачать Pdf'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'Предложение отправлено по электронной почте'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'Удалить предложение'),_defineProperty(_Received_Amount$Payi,"AddQuote",'Создать предложение'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Выбрать продукт'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Продукт (Код - Название)'),_defineProperty(_Received_Amount$Payi,"Price",'Цена'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'Склад'),_defineProperty(_Received_Amount$Payi,"Total",'Общее'),_defineProperty(_Received_Amount$Payi,"Num",'№'),_defineProperty(_Received_Amount$Payi,"Unitcost",'стоимость единицы'),_defineProperty(_Received_Amount$Payi,"to",'к'),_defineProperty(_Received_Amount$Payi,"Subject",'Предмет'),_defineProperty(_Received_Amount$Payi,"Message",'Сообщение'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'Электронная почта клиента'),_defineProperty(_Received_Amount$Payi,"Sent",'послать'),_defineProperty(_Received_Amount$Payi,"Quote",'Цитата'),_defineProperty(_Received_Amount$Payi,"Hello",'Здравствуйте'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Пожалуйста, найдите приложение к вашему предложению'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Добавить товары в список заказов'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Пожалуйста, выберите склад'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'пожалуйста, выберите клиента'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Управление продажами'),_defineProperty(_Received_Amount$Payi,"Balance",'Остаток средств'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Назад Количество'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Общий доход'),_defineProperty(_Received_Amount$Payi,"Amount",'Количество'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Детали продажи'),_defineProperty(_Received_Amount$Payi,"EditSale",'Изменить распродажу'),_defineProperty(_Received_Amount$Payi,"AddSale",'Создать распродажу'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Показать платежи'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Создать платеж'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Изменить платеж'),_defineProperty(_Received_Amount$Payi,"EmailSale",'Отправить распродажу по электронной почте'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Удалить распродажу'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Оплачивается'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Выбор платежа'),_defineProperty(_Received_Amount$Payi,"Note",'Заметка'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Оплата завершена!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Управление закупками'),_defineProperty(_Received_Amount$Payi,"Ordered",'Упорядоченный'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Удалить покупку'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Отправить покупку по электронной почте'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Изменить покупку'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Детали покупки'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Создать покупку'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Электронная почта поставщика'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Оплата покупок'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Данные о платежах покупок'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'Платежи за продажу'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Данные о продажах'),_defineProperty(_Received_Amount$Payi,"UserManagement",'управление пользователями'),_defineProperty(_Received_Amount$Payi,"Firstname",'Имя'),_defineProperty(_Received_Amount$Payi,"lastname",'фамилия'),_defineProperty(_Received_Amount$Payi,"username",'Имя пользователя'),_defineProperty(_Received_Amount$Payi,"password",'пароль'),_defineProperty(_Received_Amount$Payi,"Newpassword",'Новый пароль'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Сменить аватар'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Оставьте это поле пустым, если вы его не меняли'),_defineProperty(_Received_Amount$Payi,"type",'тип'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Разрешения пользователей'),_defineProperty(_Received_Amount$Payi,"RoleName",'Роль'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Описание роли'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'Создать разрешения'),_defineProperty(_Received_Amount$Payi,"View",'Посмотреть'),_defineProperty(_Received_Amount$Payi,"Del",'удалять'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'Новая корректировка'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Изменить настройку'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'Вы не можете вычесть продукты, у которых есть запас 0'),_defineProperty(_Received_Amount$Payi,"Addition",'Дополнение'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Вычитание'),_defineProperty(_Received_Amount$Payi,"profil",'профиль'),_defineProperty(_Received_Amount$Payi,"logout",'выйти'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'вы не можете изменить, потому что эта покупка уже оплачена'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'вы не можете изменить, потому что эта Распродажа уже оплачена'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'вы не можете изменить, потому что этот возврат уже оплачен'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'Эта цитата уже привела к продаже'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Создать продукт'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'Цитата завершена'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Конфигурация сайта'),_defineProperty(_Received_Amount$Payi,"Language",'Язык'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'Валюта по умолчанию'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Войти Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Почта по умолчанию'),_defineProperty(_Received_Amount$Payi,"SiteName",'Название сайта'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Изменить логотип'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'Конфигурация SMTP'),_defineProperty(_Received_Amount$Payi,"HOST",'ВЕДУЩИЙ'),_defineProperty(_Received_Amount$Payi,"PORT",'ПОРТ'),_defineProperty(_Received_Amount$Payi,"encryption",'Шифрование'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'Неправильная конфигурация SMTP'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Платежи Возврат'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'Возврат счетов'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'Возвращает данные счетов-фактур'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Показать все записи всех пользователей'),_defineProperty(_Received_Amount$Payi,"Discount",'Скидка'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Налог на заказ'),_defineProperty(_Received_Amount$Payi,"Shipping",'Перевозка'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Название компании'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Телефон компании'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'Адрес компании'),_defineProperty(_Received_Amount$Payi,"Code",'Код'),_defineProperty(_Received_Amount$Payi,"image",'образ'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'Распечатать штрих-код'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'Возвращает клиентов'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'Возврат Поставщикам'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'Возврат счета-фактуры клиента'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'Счет-фактура возврата поставщика'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'Данные недоступны'),_defineProperty(_Received_Amount$Payi,"ProductImage",'Изображение продукта'),_defineProperty(_Received_Amount$Payi,"Barcode",'Штрих-код'),_defineProperty(_Received_Amount$Payi,"pointofsales",'Точка продаж'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Пользовательская загрузка'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'точка управления продажами'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Регулировка'),_defineProperty(_Received_Amount$Payi,"Updat",'Обновить'),_defineProperty(_Received_Amount$Payi,"Reset",'Сброс настроек'),_defineProperty(_Received_Amount$Payi,"print",'Распечатать'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'Поиск по почте'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Выберите продукт'),_defineProperty(_Received_Amount$Payi,"Qty",'Кол-во'),_defineProperty(_Received_Amount$Payi,"Items",'Предметы'),_defineProperty(_Received_Amount$Payi,"AmountHT",'Количество'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'общая сумма'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Пожалуйста, выберите поставщика'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Пожалуйста, выберите статус'),_defineProperty(_Received_Amount$Payi,"PayeBy",'Оплачивается'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Выберите склад'),_defineProperty(_Received_Amount$Payi,"payNow",'Заплатить сейчас'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'Список категорий'),_defineProperty(_Received_Amount$Payi,"Description",'Описание'),_defineProperty(_Received_Amount$Payi,"submit",'представить'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'При создании этого счета возникла проблема. Пожалуйста, попробуйте еще раз'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'Возникла проблема с оплатой. Пожалуйста, попробуйте еще раз.'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'Доходы и расходы'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'Ежедневные продажи и покупки'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'Срок действия продуктов истек'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Список брендов'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Создать корректировку'),_defineProperty(_Received_Amount$Payi,"Afewwords",'Несколько слов ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'Изображение пользователя'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Обновить продукт'),_defineProperty(_Received_Amount$Payi,"Brand",'Марка'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Символика штрих-кода'),_defineProperty(_Received_Amount$Payi,"ProductCost",'Стоимость продукта'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Цена продукта'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Единица продукта'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Налоговый метод'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Несколько изображений'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Продукт имеет несколько вариантов'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'У продукта есть продвижение'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Начало продвижения'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Конец акции'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Цена акции'),_defineProperty(_Received_Amount$Payi,"Price",'Цена'),_defineProperty(_Received_Amount$Payi,"Cost",'Стоимость'),_defineProperty(_Received_Amount$Payi,"Unit",'Ед. изм'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Вариант продукта'),_defineProperty(_Received_Amount$Payi,"Variant",'Вариант'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Цена за единицу'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'Создать возвратного клиента'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'Изменить возвратного клиента'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'Создать поставщика возврата'),_defineProperty(_Received_Amount$Payi,"Documentation",'Документация'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'Изменить поставщика возврата'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'Со склада'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'На склад'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Редактировать перевод'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Детали перевода'),_defineProperty(_Received_Amount$Payi,"Pending",'В ожидании'),_defineProperty(_Received_Amount$Payi,"Received",'Получила'),_defineProperty(_Received_Amount$Payi,"Ordered",'Упорядоченный'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'Управление разрешениями'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Марка'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Фирменное изображение'),_defineProperty(_Received_Amount$Payi,"BrandName",'Имя бренда'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Описание бренда'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Базовый блок'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Управление подразделениями'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Значение операции'),_defineProperty(_Received_Amount$Payi,"Operator",'Оператор'),_defineProperty(_Received_Amount$Payi,"Top5Products",'Пять лучших продуктов'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'Последние пять продаж'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'Список корректировок'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Список переводов'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Создать перевод'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Управление заказами'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Список котировок'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Список покупок'),_defineProperty(_Received_Amount$Payi,"ListSales",'Список продаж'),_defineProperty(_Received_Amount$Payi,"ListReturns",'Список возвратов'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'Управление персоналом'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Ты уверен?',
Text:'Вы не сможете отменить это!',
confirmButtonText:'Да удалите!',
cancelButtonText:'Отмена',
Deleted:'Удалено!',
Failed:'Не удалось!',
Therewassomethingwronge:'Что-то было не так',
CustomerDeleted:'этот Клиент был удален.',
SupplierDeleted:'этот поставщик был удален.',
QuoteDeleted:'Цитата удалена.',
SaleDeleted:'эта распродажа была удалена.',
PaymentDeleted:'этот Платеж был удален.',
PurchaseDeleted:'эта покупка была удалена.',
ReturnDeleted:'этот возврат был удален.',
ProductDeleted:'этот продукт был удален.',
ClientError:'Этот клиент уже связан с другой операцией',
ProviderError:'Этот поставщик уже связан с другой операцией',
UserDeleted:'Этот пользователь был удален.',
UnitDeleted:'Этот блок был удален.',
RoleDeleted:'Эта роль удалена.',
TaxeDeleted:'Этот налог был удален.',
SubCatDeleted:'Эта подкатегория была удалена.',
CatDeleted:'Эта категория была удалена.',
WarehouseDeleted:'Этот склад был удален.',
AlreadyLinked:'этот продукт уже связан с другой операцией',
AdjustDeleted:'Эта корректировка была удалена.',
TitleCurrency:'Эта валюта была удалена.',
TitleTransfer:'Перевод успешно удален',
BackupDeleted:'Резервная копия была успешно удалена',
TitleBrand:'Этот бренд был удален'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleBrand:'Этот бренд был обновлен',
TitleProfile:'Ваш профиль успешно обновлен',
TitleAdjust:'Настройка успешно обновлена',
TitleRole:'Роль обновлена успешно',
TitleUnit:'Объект успешно обновлен',
TitleUser:'Пользователь успешно обновлен',
TitleCustomer:'Обновление клиента успешно',
TitleQuote:'Предложение обновлено успешно',
TitleSale:'Распродажа успешно обновлена',
TitlePayment:'Платеж успешно обновлен',
TitlePurchase:'Покупка успешно обновлена',
TitleReturn:'Возврат Обновлено успешно',
TitleProduct:'Обновление продукта успешно выполнено',
TitleSupplier:'Поставщик успешно обновлен',
TitleTaxe:'Налог обновлен успешно',
TitleCat:'Категория обновлена успешно',
TitleWarhouse:'Склад успешно обновлен',
TitleSetting:'Настройки обновлены успешно',
TitleCurrency:'Обновление валюты успешно',
TitleTransfer:'Перенос успешно обновлен'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'Этот бренд был создан',
TitleRole:'Роль успешно создана',
TitleUnit:'Объект успешно создан',
TitleUser:'Пользователь успешно создан в',
TitleCustomer:'Клиент успешно создан',
TitleQuote:'Предложение создано в успешно',
TitleSale:'Распродажа успешно создана',
TitlePayment:'Платеж успешно создан',
TitlePurchase:'Покупка успешно создана',
TitleReturn:'Возврат успешно создан',
TitleProduct:'Продукт успешно создан',
TitleSupplier:'Поставщик успешно создан',
TitleTaxe:'Налог создан в успешно',
TitleCat:'Категория создана в успешно',
TitleWarhouse:'Склад успешно создан',
TitleAdjust:'Корректировка успешно создана',
TitleCurrency:'Валюта успешно создана',
TitleTransfer:'Перевод успешно создан'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'Электронная почта отправлена успешно'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'эта распродажа уже связана с возвратом!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'Управление возвратом'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'Деталь возврата'),_defineProperty(_Received_Amount$Payi,"EditReturn",'Изменить возврат'),_defineProperty(_Received_Amount$Payi,"AddReturn",'Создать возврат'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'Отправить возврат по почте'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'Удалить возврат'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'Return Surcharge'),_defineProperty(_Received_Amount$Payi,"Laivrison",'Доставка'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Выбрать распродажу'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'Вы можете удалить товар или установить возвращаемое количество равным нулю, если оно не возвращается.'),_defineProperty(_Received_Amount$Payi,"Return",'Возвращение'),_defineProperty(_Received_Amount$Payi,"Purchase",'Покупка'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Тотальная распродажа'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Всего покупок'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Общая прибыль'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Чистые платежи'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Отправленные платежи'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Платежи получены'),_defineProperty(_Received_Amount$Payi,"Recieved",'Получила'),_defineProperty(_Received_Amount$Payi,"Sent",'Отправлено'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Оповещения о количестве товаров'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Код'),_defineProperty(_Received_Amount$Payi,"ProductName",'Товар'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Количество предупреждений'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'График складских запасов'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Всего продуктов'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Общая численность'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'Пятерка крупнейших клиентов'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Итого'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Общая сумма'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Отчет о продажах клиентов'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Отчет о платежах клиентов'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'Отчет о предложениях клиентов'),_defineProperty(_Received_Amount$Payi,"Payments",'Платежи'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'Пятерка лучших поставщиков'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Отчет о закупках поставщика'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Отчет о платежах поставщикам'),_defineProperty(_Received_Amount$Payi,"Name",'название'),_defineProperty(_Received_Amount$Payi,"Code",'Код'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Управление складом'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Почтовый Индекс'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Управление категориями'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Категория кода'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'Категория имени'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Родительская категория'),_defineProperty(_Received_Amount$Payi,"managementTax",'Налоговый менеджмент'),_defineProperty(_Received_Amount$Payi,"TaxName",'Название налога'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Ставка налога'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Единица закупок'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Отдел продаж'),_defineProperty(_Received_Amount$Payi,"ShortName",'Короткое имя'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Пожалуйста, выберите их перед добавлением любого продукта'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Регулировка запаса'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Пожалуйста, выберите склад, прежде чем выбрать любой продукт'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Передача запасов'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Выберите период'),_defineProperty(_Received_Amount$Payi,"ThisYear",'В этом году'),_defineProperty(_Received_Amount$Payi,"ThisToday",'Это сегодня'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'Этот месяц'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'Эта неделя'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Детали настройки'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'Этот пользователь был активирован'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'Этот пользователь был деактивирован'),_defineProperty(_Received_Amount$Payi,"NotFound",'Страница не найдена.'),_defineProperty(_Received_Amount$Payi,"oops",'ошибка! Страница не найдена.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'Мы не смогли найти страницу, которую вы искали. Тем временем вы можете'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'вернуться на панель управления'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/sm_ch.js":
/*!*****************************************************!*\
  !*** ./resources/src/translations/locales/sm_ch.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesSm_chJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Simplified Chinese
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'收到金额',
Paying_Amount:'支付金额',
Change:'改变',
Paying_amount_is_greater_than_Received_amount:'支付金额大于收到金额',
Paying_amount_is_greater_than_Grand_Total:'支付金额大于总计',
code_must_be_not_exist_already:'代码必须不存在',
You_will_find_your_backup_on:'你会发现你的备份',
and_save_it_to_your_pc:'并将其保存到您的电脑',
Scan_your_barcode_and_select_the_correct_symbology_below:'扫描您的条形码并在下方选择正确的符号',
Scan_Search_Product_by_Code_Name:'按代码名称扫描/搜索产品',
Paper_size:'纸张尺寸',
Clear_Cache:'清除缓存',
Cache_cleared_successfully:'缓存清除成功',
Failed_to_clear_cache:'清除缓存失败',
Scan_Barcode:'条形码扫描器',
Please_use_short_name_of_unit:'请使用单位简称',
DefaultCustomer:'默认客户',
DefaultWarehouse:'默认仓库',
Payment_Gateway:'支付网关',
SMS_Configuration:'短信配置',
Gateway:'支付网关',
Choose_Gateway:'选择支付网关',
Send_SMS:'消息已成功发送',
sms_config_invalid:'错误的短信配置无效',
Remove_Stripe_Key_Secret:'删除Stripe API密钥',
credit_card_account_not_available:'信用卡帐户不可用',
Credit_Card_Info:'信用卡资料',
developed_by:'由开发',
Unit_already_linked_with_sub_unit:'单元已与子单元链接',
Total_Items_Quantity:'项目总数和数量',
Value_by_Cost_and_Price:'按成本和价格的价值',
Search_this_table:'搜索此表',
import_products:'进口产品',
Field_optional:'字段可选',
Download_exemple:'下载范例',
field_must_be_in_csv_format:'字段必须为csv格式',
Successfully_Imported:'成功导入',
file_size_must_be_less_than_1_mega:'档案大小必须小于1兆',
Please_follow_the_import_instructions:'请遵循导入说明',
must_be_exist:'单位必须已经创建',
Import_Customers:'导入客户',
Import_Suppliers:'进口供应商',
Recent_Sales:'最近的销售',
Create_Transfer:'创建转移',
order_products:'订购物品',
Search_Product_by_Code_Name:'按代码或名称搜索产品',
Reports_payments_Purchase_Return:'报告购买退货付款',
Reports_payments_Sale_Return:'报告销售退货付款',
payments_Sales_Return:'付款销售退货',
payments_Purchases_Return:'付款购买退货',
CreateSaleReturn:'创建销售退货',
EditSaleReturn:'编辑销售退货',
SalesReturn:'销售退货',
CreatePurchaseReturn:'创建采购退货',
EditPurchaseReturn:'编辑购买退货',
PurchasesReturn:'采购退货',
Due:'到期的',
Profit:'利润',
Revenue:'收入',
Sales_today:'今日销量',
People:'人们',
Successfully_Created:'成功创建',
Successfully_Updated:'成功更新',
Success:'成功',
Failed:'失败的',
Warning:'警告',
Please_fill_the_form_correctly:'请正确填写表格',
Field_is_required:'必填项',
Error:'错误!',
you_are_not_authorized:'对不起！ 您没有权限。',
Go_back_to_home:'返回首页',
page_not_exist:'对不起！ 您要查找的页面不存在。',
Choose_Status:'选择状态',
Choose_Method:'选择方法',
Choose_Symbology:'选择符号',
Choose_Category:'选择类别',
Choose_Customer:'选择客户',
Choose_Supplier:'选择供应商',
Choose_Unit_Purchase:'选择采购单位',
Choose_Sub_Category:'选择子类别',
Choose_Brand:'选择品牌',
Choose_Warehouse:'选择仓库',
Choose_Unit_Sale:'选择销售单位',
Enter_Product_Cost:'输入产品成本',
Enter_Stock_alert:'输入库存警报',
Choose_Unit_Product:'选择产品单位',
Enter_Product_Price:'输入产品价格',
Enter_Name_Product:'输入名称产品',
Enter_Role_Name:'输入角色名称',
Enter_Role_Description:'输入角色描述',
Enter_name_category:'输入类别名称',
Enter_Code_category:'输入类别代码',
Enter_Name_Brand:'输入名称品牌',
Enter_Description_Brand:'输入描述品牌',
Enter_Code_Currency:'输入代码货币',
Enter_name_Currency:'输入名称货币',
Enter_Symbol_Currency:'输入符号货币',
Enter_Name_Unit:'输入单位名称',
Enter_ShortName_Unit:'输入简称单位',
Choose_Base_Unit:'选择基本单位',
Choose_Operator:'选择运营商',
Enter_Operation_Value:'输入操作值',
Enter_Name_Warehouse:'输入仓库名称',
Enter_Phone_Warehouse:'输入仓库电话',
Enter_Country_Warehouse:'输入仓库国家',
Enter_City_Warehouse:'进入仓库城市',
Enter_Email_Warehouse:'输入仓库电子邮件',
Enter_ZipCode_Warehouse:'输入仓库邮政编码',
Choose_Currency:'选择货币',
Thank_you_for_your_business:'感谢您的业务！',
Cancel:'取消',
New_Customer:'新客户',
Incorrect_Login:'登陆错误',
Successfully_Logged_In:'成功登录',
This_user_not_active:'该用户不活跃',
SignIn:'登入',
Create_an_account:'创建一个帐户',
Forgot_Password:'忘记密码 ？',
Email_Address:'电子邮件地址',
SignUp:'报名',
Already_have_an_account:'已经有帐号了？',
Reset_Password:'重设密码',
Failed_to_authenticate_on_SMTP_server:'无法在SMTP服务器上进行身份验证',
We_cant_find_a_user_with_that_email_addres:'我们找不到使用该电子邮件地址的用户',
We_have_emailed_your_password_reset_link:'我们已经通过电子邮件发送了您的密码重置链接',
Please_fill_the_Email_Adress:'请填写电子邮件地址',
Confirm_password:'确认密码',
Your_Password_has_been_changed:'您的密码已被更改',
The_password_confirmation_does_not_match:'密码确认不匹配',
This_password_reset_token_is_invalid:'此密码重置令牌无效',
Warehouse_report:'仓库报告',
All_Warehouses:'所有仓库',
Expense_List:'费用清单',
Expenses:'花费',
This_Week_Sales_Purchases:'本周买卖',
Top_Selling_Products:'畅销产品',
View_all:'查看全部',
Payment_Sent_Received:'已发送并已收到付款',
Filter:'过滤',
Invoice_POS:'发票POS',
Invoice:'发票',
Customer_Info:'客户信息',
Company_Info:'公司介绍',
Invoice_Info:'发票信息',
Order_Summary:'订单摘要',
Quote_Info:'报价信息',
Del:'删除',
SuppliersPaiementsReport:'供应商付款报告',
Purchase_Info:'购买信息',
Supplier_Info:'供应商信息',
Return_Info:'退货信息',
Expense_Category:'费用类别',
Create_Expense:'创建费用',
Details:'细节',
Discount_Method:'优惠方式',
Net_Unit_Cost:'净单位成本',
Net_Unit_Price:'净单价',
Edit_Expense:'编辑费用',
All_Brand:'所有品牌',
All_Category:'所有类别',
ListExpenses:'清单费用',
Create_Permission:'建立权限',
Edit_Permission:'编辑权限',
Reports_payments_Sales:'报告付款销售',
Reports_payments_Purchases:'报告付款购买',
Reports_payments_Return_Customers:'报告付款返回客户',
Reports_payments_Return_Suppliers:'报表付款退货供应商',
Expense_Deleted:'该费用已被删除',
Expense_Updated:'此费用已更新',
Expense_Created:'费用已创建',
DemoVersion:'您无法在演示版中执行此操作',
OrderStatistics:'销售统计',
AlreadyAdd:'该产品已添加！',
AddProductToList:'请添加产品到列表！',
AddQuantity:'请添加详细数量！',
InvalidData:'无效数据 ！！',
LowStock:'数量超过库存可用数量',
WarehouseIdentical:'两个仓库不能完全相同！',
VariantDuplicate:'这个变种是重复的！',
Filesize:'文件大小',
GenerateBackup:'产生备份',
BackupDatabase:'备份资料库',
Backup:'后备',
Paid:'已付费',
Unpaid:'未付',
Today:'今天',
Income:'收入'},
_defineProperty(_Received_Amount$Payi,"Expenses",'花费'),_defineProperty(_Received_Amount$Payi,"Sale",'特卖'),_defineProperty(_Received_Amount$Payi,"Actif",'活性'),_defineProperty(_Received_Amount$Payi,"Inactif",'不活跃'),_defineProperty(_Received_Amount$Payi,"Customers",'顾客'),_defineProperty(_Received_Amount$Payi,"Phone",'电话'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'通过电话搜索'),_defineProperty(_Received_Amount$Payi,"Suppliers",'供应商'),_defineProperty(_Received_Amount$Payi,"Quotations",'报价单'),_defineProperty(_Received_Amount$Payi,"Sales",'营业额'),_defineProperty(_Received_Amount$Payi,"Purchases",'采购'),_defineProperty(_Received_Amount$Payi,"Returns",'退货'),_defineProperty(_Received_Amount$Payi,"Settings",'设定值'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'系统设置'),_defineProperty(_Received_Amount$Payi,"Users",'用户数'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'组权限'),_defineProperty(_Received_Amount$Payi,"Currencies",'货币'),_defineProperty(_Received_Amount$Payi,"Warehouses",'货仓'),_defineProperty(_Received_Amount$Payi,"Units",'单位'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'单位购买'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'单位销售'),_defineProperty(_Received_Amount$Payi,"Reports",'报告书'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'付款报告'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'付款购买'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'付款销售'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'收益与损失'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'仓库库存图'),_defineProperty(_Received_Amount$Payi,"SalesReport",'销售报告'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'采购报告'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'客户报告'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'供应商报告'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'供应商报告'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'每日销售数据'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'每日购买数据'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'最近五条记录'),_defineProperty(_Received_Amount$Payi,"Filters",'筛选器'),_defineProperty(_Received_Amount$Payi,"date",'日期'),_defineProperty(_Received_Amount$Payi,"Reference",'参考'),_defineProperty(_Received_Amount$Payi,"Supplier",'供应商'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'支付状态'),_defineProperty(_Received_Amount$Payi,"Customer",'顾客'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'客户代码'),_defineProperty(_Received_Amount$Payi,"Status",'状态'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'供应商代码'),_defineProperty(_Received_Amount$Payi,"Categorie",'类别'),_defineProperty(_Received_Amount$Payi,"Categories",'分类目录'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'库存转移'),_defineProperty(_Received_Amount$Payi,"StockManagement",'库存管理'),_defineProperty(_Received_Amount$Payi,"dashboard",'仪表板'),_defineProperty(_Received_Amount$Payi,"Products",'产品展示'),_defineProperty(_Received_Amount$Payi,"productsList",'产品清单'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'产品管理'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'产品数量警报'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'代码产品'),_defineProperty(_Received_Amount$Payi,"ProductTax",'产品税'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'子类别'),_defineProperty(_Received_Amount$Payi,"Name_product",'指定'),_defineProperty(_Received_Amount$Payi,"StockAlert",'库存警报'),_defineProperty(_Received_Amount$Payi,"warehouse",'仓库'),_defineProperty(_Received_Amount$Payi,"Tax",'税'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'买价'),_defineProperty(_Received_Amount$Payi,"SellPrice",'卖价'),_defineProperty(_Received_Amount$Payi,"Quantity",'数量'),_defineProperty(_Received_Amount$Payi,"UnitSale",'单位销售'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'单位购买'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'货币管理'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'货币代码'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'货币名称'),_defineProperty(_Received_Amount$Payi,"Symbol",'符号'),_defineProperty(_Received_Amount$Payi,"All",'所有'),_defineProperty(_Received_Amount$Payi,"EditProduct",'编辑产品'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'按代码搜索'),_defineProperty(_Received_Amount$Payi,"SearchByName",'按名称搜索'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'产品详情'),_defineProperty(_Received_Amount$Payi,"CustomerName",'顾客姓名'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'用户管理'),_defineProperty(_Received_Amount$Payi,"Add",'创建'),_defineProperty(_Received_Amount$Payi,"add",'创建'),_defineProperty(_Received_Amount$Payi,"Edit",'编辑'),_defineProperty(_Received_Amount$Payi,"Close",'关'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'请选择'),_defineProperty(_Received_Amount$Payi,"Action",'行动'),_defineProperty(_Received_Amount$Payi,"Email",'电子邮件'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'编辑客户'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'建立客户'),_defineProperty(_Received_Amount$Payi,"Country",'国家'),_defineProperty(_Received_Amount$Payi,"City",'市'),_defineProperty(_Received_Amount$Payi,"Adress",'地址'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'顾客信息'),_defineProperty(_Received_Amount$Payi,"CustomersList",'客户名单'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'供应商代码'),_defineProperty(_Received_Amount$Payi,"SupplierName",'供应商名称'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'供应商管理'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'供应商详细信息'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'报价管理'),_defineProperty(_Received_Amount$Payi,"SubTotal",'小计'),_defineProperty(_Received_Amount$Payi,"MontantReste",'剩余金额'),_defineProperty(_Received_Amount$Payi,"complete",'已完成'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'待定'),_defineProperty(_Received_Amount$Payi,"Recu",'已收到'),_defineProperty(_Received_Amount$Payi,"partial",'部分的'),_defineProperty(_Received_Amount$Payi,"Retournee",'返回'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'详细报价'),_defineProperty(_Received_Amount$Payi,"EditQuote",'编辑报价'),_defineProperty(_Received_Amount$Payi,"CreateSale",'建立销售'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'下载PDF'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'电子邮件发送报价'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'删除报价'),_defineProperty(_Received_Amount$Payi,"AddQuote",'创建报价'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'选择产品'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'产品（代码-名称）'),_defineProperty(_Received_Amount$Payi,"Price",'价钱'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'股票'),_defineProperty(_Received_Amount$Payi,"Total",'总'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'单位成本'),_defineProperty(_Received_Amount$Payi,"to",'至'),_defineProperty(_Received_Amount$Payi,"Subject",'学科'),_defineProperty(_Received_Amount$Payi,"Message",'信息'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'电邮客户'),_defineProperty(_Received_Amount$Payi,"Sent",'发送'),_defineProperty(_Received_Amount$Payi,"Quote",'报价单'),_defineProperty(_Received_Amount$Payi,"Hello",'你好'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'请找到您的报价附件'),_defineProperty(_Received_Amount$Payi,"AddProducts",'将产品添加到订单清单'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'请选择仓库'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'请选择客户'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'销售管理'),_defineProperty(_Received_Amount$Payi,"Balance",'平衡'),_defineProperty(_Received_Amount$Payi,"QtyBack",'退货数量'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'总回报'),_defineProperty(_Received_Amount$Payi,"Amount",'量'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'销售明细'),_defineProperty(_Received_Amount$Payi,"EditSale",'编辑销售'),_defineProperty(_Received_Amount$Payi,"AddSale",'建立销售'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'显示付款'),_defineProperty(_Received_Amount$Payi,"AddPayment",'创建付款'),_defineProperty(_Received_Amount$Payi,"EditPayment",'编辑付款'),_defineProperty(_Received_Amount$Payi,"EmailSale",'通过电子邮件发送销售'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'删除销售'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'由...支付'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'付款方式'),_defineProperty(_Received_Amount$Payi,"Note",'注意'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'付款完成！'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'采购管理'),_defineProperty(_Received_Amount$Payi,"Ordered",'已订购'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'删除购买'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'通过邮件发送购买'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'编辑购买'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'采购明细'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'创建购买'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'供应商邮件'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'购买付款'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'购买付款数据'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'销售付款'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'销售付款数据'),_defineProperty(_Received_Amount$Payi,"UserManagement",'用户管理'),_defineProperty(_Received_Amount$Payi,"Firstname",'名字'),_defineProperty(_Received_Amount$Payi,"lastname",'姓'),_defineProperty(_Received_Amount$Payi,"username",'用户名'),_defineProperty(_Received_Amount$Payi,"password",'密码'),_defineProperty(_Received_Amount$Payi,"Newpassword",'新密码'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'更改头像'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'如果尚未更改，请将该字段留空'),_defineProperty(_Received_Amount$Payi,"type",'类型'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'用户权限'),_defineProperty(_Received_Amount$Payi,"RoleName",'角色'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'角色描述'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'创建权限'),_defineProperty(_Received_Amount$Payi,"View",'视图'),_defineProperty(_Received_Amount$Payi,"Del",'删除'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'新调整'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'编辑调整'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'您不能减去有库存0的产品'),_defineProperty(_Received_Amount$Payi,"Addition",'加成'),_defineProperty(_Received_Amount$Payi,"Subtraction",'减法'),_defineProperty(_Received_Amount$Payi,"profil",'概况'),_defineProperty(_Received_Amount$Payi,"logout",'登出'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'您无法修改，因为此购买已付款'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'您无法修改，因为此销售已经付款'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'您无法修改，因为此退货已经支付'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'此报价已产生销售'),_defineProperty(_Received_Amount$Payi,"AddProduct",'创建产品'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'报价完成'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'网站配置'),_defineProperty(_Received_Amount$Payi,"Language",'语言'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'预设货币'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'登录验证码'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'默认电子邮件'),_defineProperty(_Received_Amount$Payi,"SiteName",'网站名称'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'变更标志'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'SMTP配置'),_defineProperty(_Received_Amount$Payi,"HOST",'主办'),_defineProperty(_Received_Amount$Payi,"PORT",'港口'),_defineProperty(_Received_Amount$Payi,"encryption",'加密'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'SMTP配置不正确'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'付款退货'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'退回发票'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'退回发票数据'),_defineProperty(_Received_Amount$Payi,"ShowAll",'显示所有用户的所有记录'),_defineProperty(_Received_Amount$Payi,"Discount",'折扣'),_defineProperty(_Received_Amount$Payi,"OrderTax",'订单税'),_defineProperty(_Received_Amount$Payi,"Shipping",'运输'),_defineProperty(_Received_Amount$Payi,"CompanyName",'公司名'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'公司电话'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'公司地址'),_defineProperty(_Received_Amount$Payi,"Code",'码'),_defineProperty(_Received_Amount$Payi,"image",'图片'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'打印条形码'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'回头客'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'退货供应商'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'退货客户发票'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'退货供应商发票'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'没有可用数据'),_defineProperty(_Received_Amount$Payi,"ProductImage",'产品图片'),_defineProperty(_Received_Amount$Payi,"Barcode",'条码'),_defineProperty(_Received_Amount$Payi,"pointofsales",'销售点'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'自定义上传'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'销售点管理'),_defineProperty(_Received_Amount$Payi,"Adjustment",'调整'),_defineProperty(_Received_Amount$Payi,"Updat",'更新资料'),_defineProperty(_Received_Amount$Payi,"Reset",'重启'),_defineProperty(_Received_Amount$Payi,"print",'打印'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'通过电子邮件搜索'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'选择产品'),_defineProperty(_Received_Amount$Payi,"Qty",'数量'),_defineProperty(_Received_Amount$Payi,"Items",'物品'),_defineProperty(_Received_Amount$Payi,"AmountHT",'量'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'合计金额'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'请选择供应商'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'请选择状态'),_defineProperty(_Received_Amount$Payi,"PayeBy",'由...支付'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'选择仓库'),_defineProperty(_Received_Amount$Payi,"payNow",'现在付款'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'类别清单'),_defineProperty(_Received_Amount$Payi,"Description",'描述'),_defineProperty(_Received_Amount$Payi,"submit",'提交'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'创建此发票时出现问题. Please try again'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'付款有问题。 请再试一次.'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'收入与支出'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'每日销售与购买'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'产品过期'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'列出品牌'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'创建调整'),_defineProperty(_Received_Amount$Payi,"Afewwords",'几句话 ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'用户图片'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'更新产品'),_defineProperty(_Received_Amount$Payi,"Brand",'牌'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'条码符号'),_defineProperty(_Received_Amount$Payi,"ProductCost",'产品成本'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'产品价格'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'单位产品'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'税法'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'多张图片'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'产品具有多种变体'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'产品促销'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'促销开始'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'促销结束'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'促销价'),_defineProperty(_Received_Amount$Payi,"Price",'价钱'),_defineProperty(_Received_Amount$Payi,"Cost",'成本'),_defineProperty(_Received_Amount$Payi,"Unit",'单元'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'产品变体'),_defineProperty(_Received_Amount$Payi,"Variant",'变体'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'单价'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'创建退货客户'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'编辑退货客户'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'创建退货供应商'),_defineProperty(_Received_Amount$Payi,"Documentation",'文献资料'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'编辑退货供应商'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'从仓库'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'到仓库'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'编辑转移'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'转账明细'),_defineProperty(_Received_Amount$Payi,"Pending",'待定'),_defineProperty(_Received_Amount$Payi,"Received",'已收到'),_defineProperty(_Received_Amount$Payi,"Ordered",'已订购'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'权限管理'),_defineProperty(_Received_Amount$Payi,"BrandManager",'牌'),_defineProperty(_Received_Amount$Payi,"BrandImage",'品牌形象'),_defineProperty(_Received_Amount$Payi,"BrandName",'品牌'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'品牌描述'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'基本单位'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'单位管理'),_defineProperty(_Received_Amount$Payi,"OperationValue",'运营价值'),_defineProperty(_Received_Amount$Payi,"Operator",'操作员'),_defineProperty(_Received_Amount$Payi,"Top5Products",'前五名产品'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'最近五次销售'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'清单调整'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'清单转移'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'创建转移'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'订单管理'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'清单报价'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'列出购买'),_defineProperty(_Received_Amount$Payi,"ListSales",'清单销售'),_defineProperty(_Received_Amount$Payi,"ListReturns",'清单退货'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'人事管理'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Are you sure?',
Text:'您将无法还原它！',
confirmButtonText:'是的，删除它！',
cancelButtonText:'取消',
Deleted:'已删除！',
Failed:'失败了！',
Therewassomethingwronge:'出事了',
CustomerDeleted:'该客户端已被删除。',
SupplierDeleted:'该供应商已被删除.',
QuoteDeleted:'此报价已被删除。',
SaleDeleted:'此销售已被删除。',
PaymentDeleted:'此付款已被删除。',
PurchaseDeleted:'此购买已被删除。',
ReturnDeleted:'此退货已被删除。',
ProductDeleted:'该产品已被删除。',
ClientError:'该客户端已经与其他操作链接',
ProviderError:'该供应商已与其他运营部门链接',
UserDeleted:'该用户已被删除。',
UnitDeleted:'该单位已被删除。',
RoleDeleted:'该角色已被删除。',
TaxeDeleted:'该税项已被删除.',
SubCatDeleted:'该子类别已被删除。',
CatDeleted:'此类别已被删除。',
WarehouseDeleted:'该仓库已被删除。',
AlreadyLinked:'该产品已经与其他操作链接',
AdjustDeleted:'此调整已被删除。',
TitleCurrency:'该货币已被删除。',
TitleTransfer:'转移已成功删除',
BackupDeleted:'备份已成功删除',
TitleBrand:'该品牌已被删除'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleBrand:'该品牌已更新',
TitleProfile:'您的个人资料已成功更新',
TitleAdjust:'调整已成功更新',
TitleRole:'角色更新成功',
TitleUnit:'单位更新成功',
TitleUser:'用户已成功更新',
TitleCustomer:'客户更新成功',
TitleQuote:'报价已成功更新',
TitleSale:'销售已成功更新',
TitlePayment:'付款已成功更新',
TitlePurchase:'购买已成功更新',
TitleReturn:'返回成功更新',
TitleProduct:'产品更新成功',
TitleSupplier:'供应商更新成功',
TitleTaxe:'税务更新成功',
TitleCat:'分类成功更新',
TitleWarhouse:'仓库已成功更新',
TitleSetting:'设置已成功更新',
TitleCurrency:'货币更新成功',
TitleTransfer:'转移成功更新'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'该品牌已创建',
TitleRole:'角色创建成功',
TitleUnit:'单位创建成功',
TitleUser:'用户创建成功',
TitleCustomer:'客户创建成功',
TitleQuote:'报价创建成功',
TitleSale:'销售成功创建',
TitlePayment:'付款成功创建',
TitlePurchase:'购买成功创建',
TitleReturn:'返回创建成功',
TitleProduct:'产品创建成功',
TitleSupplier:'供应商创建成功',
TitleTaxe:'税收创建成功',
TitleCat:'分类成功创建',
TitleWarhouse:'成功创建仓库',
TitleAdjust:'调整已成功创建',
TitleCurrency:'货币创建成功',
TitleTransfer:'转移成功创建'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'电子邮件发送成功'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'此销售已经与退货相关！'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'退货管理'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'退货明细'),_defineProperty(_Received_Amount$Payi,"EditReturn",'编辑退货'),_defineProperty(_Received_Amount$Payi,"AddReturn",'创建退货'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'发送邮件退回'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'删除退货'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'回程附加费'),_defineProperty(_Received_Amount$Payi,"Laivrison",'交货'),_defineProperty(_Received_Amount$Payi,"SelectSale",'选择销售'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'您可以删除该项目或将未退回的数量设置为零'),_defineProperty(_Received_Amount$Payi,"Return",'返回'),_defineProperty(_Received_Amount$Payi,"Purchase",'采购'),_defineProperty(_Received_Amount$Payi,"TotalSales",'总销售额'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'总购买'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'总回报'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'净付款'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'已付款'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'付款已收到'),_defineProperty(_Received_Amount$Payi,"Recieved",'已收到'),_defineProperty(_Received_Amount$Payi,"Sent",'已发送'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'产品数量警报'),_defineProperty(_Received_Amount$Payi,"ProductCode",'码'),_defineProperty(_Received_Amount$Payi,"ProductName",'产品'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'警报数量'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'仓库库存图'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'产品总数'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'总数（量'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'前五名客户'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'总金额'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'总支付'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'客户销售报告'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'客户付款报告'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'客户报价报告'),_defineProperty(_Received_Amount$Payi,"Payments",'付款方式'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'前五名供应商'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'供应商采购报告'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'供应商付款报告'),_defineProperty(_Received_Amount$Payi,"Name",'名称'),_defineProperty(_Received_Amount$Payi,"Code",'码'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'仓库管理'),_defineProperty(_Received_Amount$Payi,"ZipCode",'邮政编码'),_defineProperty(_Received_Amount$Payi,"managementCategories",'分类管理'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'代码类别'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'名称类别'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'父类别'),_defineProperty(_Received_Amount$Payi,"managementTax",'税务管理'),_defineProperty(_Received_Amount$Payi,"TaxName",'税名'),_defineProperty(_Received_Amount$Payi,"TaxRate",'税率'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'采购单位'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'销售单位'),_defineProperty(_Received_Amount$Payi,"ShortName",'简称'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'请在添加任何产品之前选择这些'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'库存调整'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'选择任何产品之前，请先选择仓库'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'库存转移'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'选择时期'),_defineProperty(_Received_Amount$Payi,"ThisYear",'今年'),_defineProperty(_Received_Amount$Payi,"ThisToday",'今天'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'这个月'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'本星期'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'调整细节'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'该用户已被激活'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'此用户已被停用'),_defineProperty(_Received_Amount$Payi,"NotFound",'找不到网页。'),_defineProperty(_Received_Amount$Payi,"oops",'错误！ 找不到网页。'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'我们找不到您想要的页面。与此同时，您可能'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'返回仪表板'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/thai.js":
/*!****************************************************!*\
  !*** ./resources/src/translations/locales/thai.js ***!
  \****************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesThaiJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Taiwan
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'จำนวนเงินที่ได้รับ',
Paying_Amount:'จำนวนเงินที่จ่าย',
Change:'เปลี่ยน',
Paying_amount_is_greater_than_Received_amount:'จำนวนเงินที่จ่ายมากกว่าจำนวนเงินที่ได้รับ',
Paying_amount_is_greater_than_Grand_Total:'จำนวนเงินที่จ่ายมากกว่ายอดรวม',
code_must_be_not_exist_already:'รหัสจะต้องไม่มีอยู่แล้ว',
You_will_find_your_backup_on:'คุณจะพบข้อมูลสำรองของคุณบน',
and_save_it_to_your_pc:'และบันทึกลงในพีซีของคุณ',
Scan_your_barcode_and_select_the_correct_symbology_below:'สแกนบาร์โค้ดของคุณและเลือกสัญลักษณ์ที่ถูกต้องด้านล่าง',
Scan_Search_Product_by_Code_Name:'สแกน/ค้นหาสินค้าด้วยชื่อรหัส',
Paper_size:'ขนาดกระดาษ',
Clear_Cache:'ล้างแคช',
Cache_cleared_successfully:'ล้างแคชเรียบร้อยแล้ว',
Failed_to_clear_cache:'ไม่สามารถล้างแคช',
Scan_Barcode:'เครื่องสแกนบาร์โค้ด',
Please_use_short_name_of_unit:'โปรดใช้ชื่อย่อของหน่วย',
DefaultCustomer:'ลูกค้าเริ่มต้น',
DefaultWarehouse:'คลังสินค้าเริ่มต้น',
Payment_Gateway:'ช่องทางการชำระเงิน',
SMS_Configuration:'การกำหนดค่า SMS',
Gateway:'ช่องทางการชำระเงิน',
Choose_Gateway:'เลือกช่องทางการชำระเงิน',
Send_SMS:'ข้อความที่ส่งประสบความสำเร็จ',
sms_config_invalid:'การกำหนดค่า sms ผิดไม่ถูกต้อง',
Remove_Stripe_Key_Secret:'ลบคีย์ Stripe API',
credit_card_account_not_available:'ไม่มีบัญชีบัตรเครดิต',
Credit_Card_Info:'ข้อมูลบัตรเครดิต',
developed_by:'พัฒนาโดย',
Unit_already_linked_with_sub_unit:'เชื่อมโยงหน่วยกับหน่วยย่อยแล้ว',
Total_Items_Quantity:'รายการและปริมาณทั้งหมด',
Value_by_Cost_and_Price:'คุ้มค่าตามต้นทุนและราคา',
Search_this_table:'ค้นหาตารางนี้',
import_products:'นำเข้าสินค้า',
Field_optional:'ฟิลด์ไม่บังคับ',
Download_exemple:'ดาวน์โหลดตัวอย่าง',
field_must_be_in_csv_format:'ฟิลด์ต้องอยู่ในรูปแบบ csv',
Successfully_Imported:'นำเข้าสำเร็จ',
file_size_must_be_less_than_1_mega:'ขนาดไฟล์ต้องน้อยกว่า 1 เมกะไบต์',
Please_follow_the_import_instructions:'โปรดปฏิบัติตามคำแนะนำการนำเข้า',
must_be_exist:'ต้องสร้างหน่วยแล้ว',
Import_Customers:'นำเข้าลูกค้า',
Import_Suppliers:'นำเข้าซัพพลายเออร์',
Recent_Sales:'ยอดขายล่าสุด',
Create_Transfer:'สร้างการโอน',
order_products:'รายการสั่งซื้อ',
Search_Product_by_Code_Name:'ค้นหาสินค้าตามรหัสหรือชื่อ',
Reports_payments_Purchase_Return:'รายงานการชำระเงินคืนการซื้อ',
Reports_payments_Sale_Return:'รายงานการชำระเงินคืนการขาย',
payments_Sales_Return:'การชำระเงินการขายคืน',
payments_Purchases_Return:'การชำระเงินการซื้อสินค้าคืน',
CreateSaleReturn:'สร้างผลตอบแทนจากการขาย',
EditSaleReturn:'แก้ไขการขายคืน',
SalesReturn:'ผลตอบแทนจากการขาย',
CreatePurchaseReturn:'สร้างผลตอบแทนการซื้อ',
EditPurchaseReturn:'แก้ไขการคืนสินค้า',
PurchasesReturn:'การซื้อคืน',
Due:'ครบกำหนด',
Profit:'กำไร',
Revenue:'รายได้',
Sales_today:'ขายวันนี้',
People:'คน',
Successfully_Created:'สร้างสำเร็จแล้ว',
Successfully_Updated:'อัปเดตเรียบร้อยแล้ว',
Success:'ประสบความสำเร็จ',
Failed:'ล้มเหลว',
Warning:'คำเตือน',
Please_fill_the_form_correctly:'กรุณากรอกแบบฟอร์มให้ถูกต้อง',
Field_is_required:'ต้องระบุฟิลด์',
Error:'ข้อผิดพลาด!',
you_are_not_authorized:'ขออภัย! คุณไม่ได้รับอนุญาต',
Go_back_to_home:'กลับไปที่หน้าแรก',
page_not_exist:'ขออภัย! ไม่มีหน้าที่คุณค้นหา',
Choose_Status:'เลือกสถานะ',
Choose_Method:'เลือกวิธีการ',
Choose_Symbology:'เลือกสัญลักษณ์',
Choose_Category:'เลือกหมวดหมู่',
Choose_Customer:'เลือกลูกค้า',
Choose_Supplier:'เลือกซัพพลายเออร์',
Choose_Unit_Purchase:'เลือกหน่วยซื้อ',
Choose_Sub_Category:'เลือกหมวดหมู่ย่อย',
Choose_Brand:'เลือกยี่ห้อ',
Choose_Warehouse:'เลือกคลังสินค้า',
Choose_Unit_Sale:'เลือกหน่วยขาย',
Enter_Product_Cost:'ป้อนต้นทุนผลิตภัณฑ์',
Enter_Stock_alert:'เข้าสู่การแจ้งเตือนสต็อก',
Choose_Unit_Product:'เลือกหน่วยผลิตภัณฑ์',
Enter_Product_Price:'ป้อนราคาสินค้า',
Enter_Name_Product:'ป้อนชื่อผลิตภัณฑ์',
Enter_Role_Name:'ป้อนชื่อบทบาท',
Enter_Role_Description:'ป้อนคำอธิบายบทบาท',
Enter_name_category:'ป้อนชื่อหมวดหมู่',
Enter_Code_category:'ป้อนรหัสหมวดหมู่',
Enter_Name_Brand:'ใส่ชื่อยี่ห้อ',
Enter_Description_Brand:'ป้อนคำอธิบายยี่ห้อ',
Enter_Code_Currency:'ป้อนรหัสสกุลเงิน',
Enter_name_Currency:'ป้อนชื่อสกุล',
Enter_Symbol_Currency:'ป้อนสัญลักษณ์สกุลเงิน',
Enter_Name_Unit:'ป้อนชื่อหน่วย',
Enter_ShortName_Unit:'ใส่ชื่อย่อหน่วย',
Choose_Base_Unit:'เลือกหน่วยฐาน',
Choose_Operator:'เลือกตัวดำเนินการ',
Enter_Operation_Value:'ป้อนค่าการดำเนินการ',
Enter_Name_Warehouse:'ป้อนชื่อคลังสินค้า',
Enter_Phone_Warehouse:'ป้อนโทรศัพท์คลังสินค้า',
Enter_Country_Warehouse:'เข้าสู่ประเทศคลังสินค้า',
Enter_City_Warehouse:'เข้าสู่เมืองคลังสินค้า',
Enter_Email_Warehouse:'ป้อนอีเมลคลังสินค้า',
Enter_ZipCode_Warehouse:'ป้อนรหัสไปรษณีย์ของคลังสินค้า',
Choose_Currency:'เลือกสกุลเงิน',
Thank_you_for_your_business:'ขอบคุณสำหรับธุรกิจของคุณ!',
Cancel:'ยกเลิก',
New_Customer:'ลูกค้าใหม่',
Incorrect_Login:'การเข้าสู่ระบบไม่ถูกต้อง',
Successfully_Logged_In:'เข้าสู่ระบบเรียบร้อยแล้ว',
This_user_not_active:'ผู้ใช้รายนี้ไม่ได้ใช้งาน',
SignIn:'เข้าสู่ระบบ',
Create_an_account:'สร้างบัญชี',
Forgot_Password:'ลืมรหัสผ่าน ?',
Email_Address:'ที่อยู่อีเมล',
SignUp:'ลงชื่อ',
Already_have_an_account:'มีบัญชีอยู่แล้ว?',
Reset_Password:'รีเซ็ตรหัสผ่าน',
Failed_to_authenticate_on_SMTP_server:'ไม่สามารถตรวจสอบสิทธิ์บนเซิร์ฟเวอร์ SMTP',
We_cant_find_a_user_with_that_email_addres:'เราไม่พบผู้ใช้ที่มีที่อยู่อีเมลดังกล่าว',
We_have_emailed_your_password_reset_link:'เราได้ส่งลิงค์รีเซ็ตรหัสผ่านของคุณไปทางอีเมลแล้ว',
Please_fill_the_Email_Adress:'กรุณากรอกที่อยู่อีเมล',
Confirm_password:'ยืนยันรหัสผ่าน',
Your_Password_has_been_changed:'รหัสผ่านของคุณถูกเปลี่ยน',
The_password_confirmation_does_not_match:'การยืนยันรหัสผ่านไม่ตรงกัน',
This_password_reset_token_is_invalid:'โทเค็นการรีเซ็ตรหัสผ่านนี้ไม่ถูกต้อง',
Warehouse_report:'รายงานคลังสินค้า',
All_Warehouses:'คลังสินค้าทั้งหมด',
Expense_List:'รายการค่าใช้จ่าย',
Expenses:'ค่าใช้จ่าย',
This_Week_Sales_Purchases:'ยอดขายและการซื้อประจำสัปดาห์นี้',
Top_Selling_Products:'สินค้าขายดี',
View_all:'ดูทั้งหมด',
Payment_Sent_Received:'การชำระเงินที่ส่งและรับ',
Filter:'กรอง',
Invoice_POS:'POS ใบแจ้งหนี้',
Invoice:'ใบแจ้งหนี้',
Customer_Info:'ข้อมูลลูกค้า',
Company_Info:'ข้อมูล บริษัท',
Invoice_Info:'ข้อมูลใบแจ้งหนี้',
Order_Summary:'สรุปคำสั่งซื้อ',
Quote_Info:'ข้อมูลใบเสนอราคา',
Del:'ลบ',
SuppliersPaiementsReport:'รายงานการชำระเงินของซัพพลายเออร์',
Purchase_Info:'ข้อมูลการซื้อ',
Supplier_Info:'ข้อมูลซัพพลายเออร์',
Return_Info:'ข้อมูลการกลับมา',
Expense_Category:'หมวดค่าใช้จ่าย',
Create_Expense:'สร้างค่าใช้จ่าย',
Details:'รายละเอียด',
Discount_Method:'วิธีส่วนลด',
Net_Unit_Cost:'ต้นทุนต่อหน่วยสุทธิ',
Net_Unit_Price:'ราคาต่อหน่วยสุทธิ',
Edit_Expense:'แก้ไขค่าใช้จ่าย',
All_Brand:'ทุกยี่ห้อ',
All_Category:'หมวดหมู่ทั้งหมด',
ListExpenses:'รายการค่าใช้จ่าย',
Create_Permission:'สร้างสิทธิ์',
Edit_Permission:'แก้ไขการอนุญาต',
Reports_payments_Sales:'รายงานการชำระเงินการขาย',
Reports_payments_Purchases:'รายงานการชำระเงินการซื้อ',
Reports_payments_Return_Customers:'รายงานการชำระเงินคืนลูกค้า',
Reports_payments_Return_Suppliers:'รายงานการชำระเงินที่ส่งคืนซัพพลายเออร์',
Expense_Deleted:'ลบค่าใช้จ่ายนี้แล้ว',
Expense_Updated:'ค่าใช้จ่ายนี้ได้รับการอัปเดต',
Expense_Created:'สร้างค่าใช้จ่ายนี้แล้ว',
DemoVersion:'คุณไม่สามารถทำได้ในเวอร์ชันสาธิต',
OrderStatistics:'สถิติการขาย',
AlreadyAdd:'สินค้านี้เข้าแล้ว !!',
AddProductToList:'กรุณาเพิ่มสินค้าในรายการ !!',
AddQuantity:'กรุณาเพิ่มจำนวนรายละเอียด !!',
InvalidData:'ข้อมูลไม่ถูกต้อง !!',
LowStock:'ปริมาณเกินกว่าปริมาณที่มีอยู่ในสต็อก',
WarehouseIdentical:'โกดังทั้งสองแห่งไม่สามารถเหมือนกันได้ !!',
VariantDuplicate:'ตัวแปรนี้ซ้ำกัน !!',
Filesize:'ขนาดไฟล์',
GenerateBackup:'สร้างการสำรองข้อมูล',
BackupDatabase:'ฐานข้อมูลสำรอง',
Backup:'การสำรองข้อมูล',
Paid:'จ่าย',
Unpaid:'ยังไม่ได้ชำระ',
Today:'วันนี้',
Income:'รายได้'},
_defineProperty(_Received_Amount$Payi,"Expenses",'ค่าใช้จ่าย'),_defineProperty(_Received_Amount$Payi,"Sale",'ขาย'),_defineProperty(_Received_Amount$Payi,"Actif",'คล่องแคล่ว'),_defineProperty(_Received_Amount$Payi,"Inactif",'ไม่ใช้งาน'),_defineProperty(_Received_Amount$Payi,"Customers",'ลูกค้า'),_defineProperty(_Received_Amount$Payi,"Phone",'โทรศัพท์'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'ค้นหาทางโทรศัพท์'),_defineProperty(_Received_Amount$Payi,"Suppliers",'ซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"Quotations",'ใบเสนอราคา'),_defineProperty(_Received_Amount$Payi,"Sales",'ฝ่ายขาย'),_defineProperty(_Received_Amount$Payi,"Purchases",'การซื้อ'),_defineProperty(_Received_Amount$Payi,"Returns",'ผลตอบแทน'),_defineProperty(_Received_Amount$Payi,"Settings",'การตั้งค่า'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'การตั้งค่าระบบ'),_defineProperty(_Received_Amount$Payi,"Users",'ผู้ใช้'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'สิทธิ์กลุ่ม'),_defineProperty(_Received_Amount$Payi,"Currencies",'สกุลเงิน'),_defineProperty(_Received_Amount$Payi,"Warehouses",'โกดัง'),_defineProperty(_Received_Amount$Payi,"Units",'หน่วย'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'หน่วยการซื้อ'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'หน่วยการขาย'),_defineProperty(_Received_Amount$Payi,"Reports",'รายงาน'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'รายงานการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'การซื้อการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'การชำระเงินการขาย'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'กำไรและขาดทุน'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'แผนภูมิสต็อคคลังสินค้า'),_defineProperty(_Received_Amount$Payi,"SalesReport",'รายงานการขาย'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'รายงานการซื้อ'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'รายงานลูกค้า'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'รายงานซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'รายงานซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'ข้อมูลการขายรายวัน'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'ข้อมูลการซื้อรายวัน'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'ห้าบันทึกล่าสุด'),_defineProperty(_Received_Amount$Payi,"Filters",'ฟิลเตอร์'),_defineProperty(_Received_Amount$Payi,"date",'วันที่'),_defineProperty(_Received_Amount$Payi,"Reference",'ข้อมูลอ้างอิง'),_defineProperty(_Received_Amount$Payi,"Supplier",'ผู้ผลิต'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'สถานะการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"Customer",'ลูกค้า'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'รหัสลูกค้า'),_defineProperty(_Received_Amount$Payi,"Status",'สถานะ'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'รหัสผู้จัดจำหน่าย'),_defineProperty(_Received_Amount$Payi,"Categorie",'ประเภท'),_defineProperty(_Received_Amount$Payi,"Categories",'หมวดหมู่'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'การโอนหุ้น'),_defineProperty(_Received_Amount$Payi,"StockManagement",'การจัดการสต็อก'),_defineProperty(_Received_Amount$Payi,"dashboard",'แผงควบคุม'),_defineProperty(_Received_Amount$Payi,"Products",'ผลิตภัณฑ์'),_defineProperty(_Received_Amount$Payi,"productsList",'รายการสินค้า'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'การจัดการผลิตภัณฑ์'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'การแจ้งเตือนปริมาณสินค้า'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'รหัสสินค้า'),_defineProperty(_Received_Amount$Payi,"ProductTax",'ภาษีสินค้า'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'หมวดหมู่ย่อย'),_defineProperty(_Received_Amount$Payi,"Name_product",'การกำหนด'),_defineProperty(_Received_Amount$Payi,"StockAlert",'แจ้งเตือนสต๊อก'),_defineProperty(_Received_Amount$Payi,"warehouse",'คลังสินค้า'),_defineProperty(_Received_Amount$Payi,"Tax",'Taxภาษี'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'ราคาซื้อ'),_defineProperty(_Received_Amount$Payi,"SellPrice",'ราคาขาย'),_defineProperty(_Received_Amount$Payi,"Quantity",'ปริมาณ'),_defineProperty(_Received_Amount$Payi,"UnitSale",'ขายหน่วย'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'ซื้อหน่วย'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'การจัดการสกุลเงิน'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'รหัสสกุลเงิน'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'ชื่อสกุล'),_defineProperty(_Received_Amount$Payi,"Symbol",'สัญลักษณ์'),_defineProperty(_Received_Amount$Payi,"All",'ทั้งหมด'),_defineProperty(_Received_Amount$Payi,"EditProduct",'แก้ไขผลิตภัณฑ์'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'ค้นหาตามรหัส'),_defineProperty(_Received_Amount$Payi,"SearchByName",'ค้นหาตามชื่อ'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'รายละเอียดสินค้า'),_defineProperty(_Received_Amount$Payi,"CustomerName",'ชื่อลูกค้า'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'การจัดการลูกค้า'),_defineProperty(_Received_Amount$Payi,"Add",'สร้าง'),_defineProperty(_Received_Amount$Payi,"add",'สร้าง'),_defineProperty(_Received_Amount$Payi,"Edit",'แก้ไข'),_defineProperty(_Received_Amount$Payi,"Close",'ปิด'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'โปรดเลือก'),_defineProperty(_Received_Amount$Payi,"Action",'หนังบู๊'),_defineProperty(_Received_Amount$Payi,"Email",'อีเมล์'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'แก้ไขลูกค้า'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'สร้างลูกค้า'),_defineProperty(_Received_Amount$Payi,"Country",'ประเทศ'),_defineProperty(_Received_Amount$Payi,"City",'เมือง'),_defineProperty(_Received_Amount$Payi,"Adress",'ที่อยู่'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'รายละเอียดลูกค้า'),_defineProperty(_Received_Amount$Payi,"CustomersList",'รายชื่อลูกค้า'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'รหัสผู้จัดจำหน่าย'),_defineProperty(_Received_Amount$Payi,"SupplierName",'ชื่อผู้ผลิต'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'การจัดการซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'รายละเอียดซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'การจัดการใบเสนอราคา'),_defineProperty(_Received_Amount$Payi,"SubTotal",'ผลรวมย่อย'),_defineProperty(_Received_Amount$Payi,"MontantReste",'เหลือจำนวน'),_defineProperty(_Received_Amount$Payi,"complete",'เสร็จสมบูรณ์'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'รอดำเนินการ'),_defineProperty(_Received_Amount$Payi,"Recu",'ได้รับ'),_defineProperty(_Received_Amount$Payi,"partial",'บางส่วน'),_defineProperty(_Received_Amount$Payi,"Retournee",'กลับ'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'ใบเสนอราคารายละเอียด'),_defineProperty(_Received_Amount$Payi,"EditQuote",'แก้ไขใบเสนอราคา'),_defineProperty(_Received_Amount$Payi,"CreateSale",'สร้างการขาย'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'ดาวน์โหลด Pdf'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'ส่งใบเสนอราคาทางอีเมล'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'ลบใบเสนอราคา'),_defineProperty(_Received_Amount$Payi,"AddQuote",'สร้างใบเสนอราคา'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'เลือกผลิตภัณฑ์'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'สินค้า (รหัส - ชื่อ)'),_defineProperty(_Received_Amount$Payi,"Price",'ราคา'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'คลังสินค้า'),_defineProperty(_Received_Amount$Payi,"Total",'รวม'),_defineProperty(_Received_Amount$Payi,"Num",'ไม่มี'),_defineProperty(_Received_Amount$Payi,"Unitcost",'ต้นทุนต่อหน่วย'),_defineProperty(_Received_Amount$Payi,"to",'ถึง'),_defineProperty(_Received_Amount$Payi,"Subject",'เรื่อง'),_defineProperty(_Received_Amount$Payi,"Message",'ข้อความ'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'ส่งอีเมลถึงลูกค้า'),_defineProperty(_Received_Amount$Payi,"Sent",'ส่ง'),_defineProperty(_Received_Amount$Payi,"Quote",'คำอ้างอิง'),_defineProperty(_Received_Amount$Payi,"Hello",'สวัสดี'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'โปรดดูไฟล์แนบสำหรับใบเสนอราคาของคุณ'),_defineProperty(_Received_Amount$Payi,"AddProducts",'เพิ่มสินค้าในรายการสั่งซื้อ'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'กรุณาเลือกคลังสินค้า'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'กรุณาเลือกลูกค้า'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'การบริหารการขาย'),_defineProperty(_Received_Amount$Payi,"Balance",'สมดุล'),_defineProperty(_Received_Amount$Payi,"QtyBack",'ปริมาณกลับ'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'ผลตอบแทนรวม'),_defineProperty(_Received_Amount$Payi,"Amount",'จำนวน'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'รายละเอียดการขาย'),_defineProperty(_Received_Amount$Payi,"EditSale",'แก้ไขการขาย'),_defineProperty(_Received_Amount$Payi,"AddSale",'สร้างการขาย'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'แสดงการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"AddPayment",'สร้างการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"EditPayment",'แก้ไขการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"EmailSale",'ส่งการขายทางอีเมล'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'ลบการขาย'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'จ่ายโดย'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'ทางเลือกในการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"Note",'บันทึก'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'ชำระเงินเรียบร้อย!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'การจัดการการซื้อ'),_defineProperty(_Received_Amount$Payi,"Ordered",'สั่งซื้อ'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'ลบการซื้อ'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'ส่งคำสั่งซื้อทางอีเมล'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'แก้ไขการซื้อ'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'รายละเอียดการซื้อ'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'สร้างการซื้อ'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'อีเมลซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'ซื้อการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'ซื้อข้อมูลการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'การชำระเงินการขาย'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'ข้อมูลการชำระเงินการขาย'),_defineProperty(_Received_Amount$Payi,"UserManagement",'การจัดการผู้ใช้'),_defineProperty(_Received_Amount$Payi,"Firstname",'ชื่อจริง'),_defineProperty(_Received_Amount$Payi,"lastname",'นามสกุล'),_defineProperty(_Received_Amount$Payi,"username",'ชื่อผู้ใช้'),_defineProperty(_Received_Amount$Payi,"password",'รหัสผ่าน'),_defineProperty(_Received_Amount$Payi,"Newpassword",'รหัสผ่านใหม่'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'เปลี่ยนภาพ'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'โปรดเว้นฟิลด์นี้ว่างไว้หากคุณยังไม่ได้เปลี่ยนแปลง'),_defineProperty(_Received_Amount$Payi,"type",'ชนิด'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'สิทธิ์ของผู้ใช้'),_defineProperty(_Received_Amount$Payi,"RoleName",'บทบาท'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'คำอธิบายบทบาท'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'สร้างสิทธิ์'),_defineProperty(_Received_Amount$Payi,"View",'ดู'),_defineProperty(_Received_Amount$Payi,"Del",'ลบ'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'การปรับใหม่'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'แก้ไขการปรับปรุง'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'คุณไม่สามารถลบสินค้าที่มีสต็อก 0 ได้'),_defineProperty(_Received_Amount$Payi,"Addition",'ส่วนที่เพิ่มเข้าไป'),_defineProperty(_Received_Amount$Payi,"Subtraction",'การลบ'),_defineProperty(_Received_Amount$Payi,"profil",'ประวัติ'),_defineProperty(_Received_Amount$Payi,"logout",'ออกจากระบบ'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'คุณไม่สามารถแก้ไขได้เนื่องจากการซื้อนี้ชำระเงินแล้ว'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'คุณไม่สามารถแก้ไขได้เนื่องจากการขายนี้ชำระเงินแล้ว'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'คุณไม่สามารถแก้ไขได้เนื่องจากการส่งคืนนี้ชำระเงินแล้ว'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'คำพูดนี้สร้างยอดขายแล้ว'),_defineProperty(_Received_Amount$Payi,"AddProduct",'สร้างผลิตภัณฑ์'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'ใบเสนอราคานี้สมบูรณ์'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'การกำหนดค่าไซต์'),_defineProperty(_Received_Amount$Payi,"Language",'ภาษา'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'สกุลเงินเริ่มต้น'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'เข้าสู่ระบบ Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'อีเมลเริ่มต้น'),_defineProperty(_Received_Amount$Payi,"SiteName",'ชื่อไซต์'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'เปลี่ยนโลโก้'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'การกำหนดค่า SMTP'),_defineProperty(_Received_Amount$Payi,"HOST",'โฮสต์'),_defineProperty(_Received_Amount$Payi,"PORT",'ท่าเรือ'),_defineProperty(_Received_Amount$Payi,"encryption",'การเข้ารหัส'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'การกำหนดค่า SMTP ไม่ถูกต้อง'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'การคืนเงิน'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'ส่งคืนใบแจ้งหนี้'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'ส่งคืนข้อมูลใบแจ้งหนี้'),_defineProperty(_Received_Amount$Payi,"ShowAll",'แสดงบันทึกทั้งหมดของผู้ใช้ทั้งหมด'),_defineProperty(_Received_Amount$Payi,"Discount",'ส่วนลด'),_defineProperty(_Received_Amount$Payi,"OrderTax",'ภาษีการสั่งซื้อ'),_defineProperty(_Received_Amount$Payi,"Shipping",'การส่งสินค้า'),_defineProperty(_Received_Amount$Payi,"CompanyName",'ชื่อ บริษัท'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'โทรศัพท์ บริษัท'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'ที่อยู่ บริษัท'),_defineProperty(_Received_Amount$Payi,"Code",'รหัส'),_defineProperty(_Received_Amount$Payi,"image",'ภาพ'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'พิมพ์บาร์โค้ด'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'ส่งคืนลูกค้า'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'ส่งคืนซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'ส่งคืนใบแจ้งหนี้ของลูกค้า'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'ส่งคืนใบแจ้งหนี้ของซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'ไม่มีข้อมูลที่สามารถใช้ได้'),_defineProperty(_Received_Amount$Payi,"ProductImage",'รูปภาพสินค้า'),_defineProperty(_Received_Amount$Payi,"Barcode",'บาร์โค้ด'),_defineProperty(_Received_Amount$Payi,"pointofsales",'จุดขาย'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'อัปโหลดแบบกำหนดเอง'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'การจัดการจุดขาย'),_defineProperty(_Received_Amount$Payi,"Adjustment",'การปรับ'),_defineProperty(_Received_Amount$Payi,"Updat",'อัปเดต'),_defineProperty(_Received_Amount$Payi,"Reset",'รีเซ็ต'),_defineProperty(_Received_Amount$Payi,"print",'พิมพ์'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'ค้นหาทางอีเมล'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'เลือกผลิตภัณฑ์'),_defineProperty(_Received_Amount$Payi,"Qty",'จำนวน'),_defineProperty(_Received_Amount$Payi,"Items",'รายการ'),_defineProperty(_Received_Amount$Payi,"AmountHT",'จำนวน'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'จำนวนเงินทั้งหมด'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'กรุณาเลือกซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'กรุณาเลือกสถานะ'),_defineProperty(_Received_Amount$Payi,"PayeBy",'จ่ายโดย'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'เลือกคลังสินค้า'),_defineProperty(_Received_Amount$Payi,"payNow",'จ่ายตอนนี้'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'รายการหมวดหมู่'),_defineProperty(_Received_Amount$Payi,"Description",'คำอธิบาย'),_defineProperty(_Received_Amount$Payi,"submit",'ส่ง'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'เกิดปัญหาในการสร้างใบแจ้งหนี้นี้ กรุณาลองอีกครั้ง'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'เกิดปัญหาในการชำระเงิน กรุณาลองอีกครั้ง.'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'รายได้และค่าใช้จ่าย'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'การขายและการซื้อรายวัน'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'สินค้าหมดอายุ'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'รายชื่อแบรนด์'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'สร้างการปรับปรุง'),_defineProperty(_Received_Amount$Payi,"Afewwords",'ไม่กี่คำ ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'รูปภาพผู้ใช้'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'อัปเดตผลิตภัณฑ์'),_defineProperty(_Received_Amount$Payi,"Brand",'ยี่ห้อ'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'สัญลักษณ์บาร์โค้ด'),_defineProperty(_Received_Amount$Payi,"ProductCost",'ต้นทุนสินค้า'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'ราคาสินค้า'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'ผลิตภัณฑ์หน่วย'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'วิธีการเสียภาษี'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'หลายภาพ'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'สินค้ามีหลายตัวแปร'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'สินค้ามีโปรโมชั่น'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'เริ่มโปรโมชั่น'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'สิ้นสุดโปรโมชั่น'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'ราคาโปรโมชั่น'),_defineProperty(_Received_Amount$Payi,"Price",'ราคา'),_defineProperty(_Received_Amount$Payi,"Cost",'ค่าใช้จ่าย'),_defineProperty(_Received_Amount$Payi,"Unit",'หน่วย'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'ตัวเลือกสินค้า'),_defineProperty(_Received_Amount$Payi,"Variant",'ตัวแปร'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'ราคาต่อหน่วย'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'สร้างลูกค้าที่กลับมา'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'แก้ไขลูกค้าที่กลับมา'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'สร้างผู้ส่งคืนสินค้า'),_defineProperty(_Received_Amount$Payi,"Documentation",'เอกสารประกอบ'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'แก้ไขผู้ส่งคืนสินค้า'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'จากคลังสินค้า'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'ไปยังคลังสินค้า'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'แก้ไขการโอน'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'รายละเอียดการโอน'),_defineProperty(_Received_Amount$Payi,"Pending",'รอดำเนินการ'),_defineProperty(_Received_Amount$Payi,"Received",'ได้รับ'),_defineProperty(_Received_Amount$Payi,"Ordered",'สั่งซื้อ'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'การจัดการสิทธิ์'),_defineProperty(_Received_Amount$Payi,"BrandManager",'ยี่ห้อ'),_defineProperty(_Received_Amount$Payi,"BrandImage",'ภาพลักษณ์ของแบรนด์'),_defineProperty(_Received_Amount$Payi,"BrandName",'ชื่อแบรนด์'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'คำอธิบายแบรนด์'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'หน่วยฐาน'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'การจัดการหน่วย'),_defineProperty(_Received_Amount$Payi,"OperationValue",'มูลค่าการดำเนินการ'),_defineProperty(_Received_Amount$Payi,"Operator",'ตัวดำเนินการ'),_defineProperty(_Received_Amount$Payi,"Top5Products",'ผลิตภัณฑ์ห้าอันดับแรก'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'การขายห้าครั้งสุดท้าย'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'การปรับเปลี่ยนรายการ'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'รายการโอน'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'สร้างการโอน'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'การจัดการคำสั่งซื้อ'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'รายการใบเสนอราคา'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'แสดงรายการซื้อ'),_defineProperty(_Received_Amount$Payi,"ListSales",'แสดงรายการขาย'),_defineProperty(_Received_Amount$Payi,"ListReturns",'รายการส่งคืน'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'การบริหารคน'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'คุณแน่ใจไหม?',
Text:'คุณจะไม่สามารถเปลี่ยนกลับได้!',
confirmButtonText:'ใช่ลบมัน!',
cancelButtonText:'ยกเลิก',
Deleted:'ลบแล้ว!',
Failed:'ล้มเหลว!',
Therewassomethingwronge:'มีบางอย่างผิดปกติ',
CustomerDeleted:'ลูกค้ารายนี้ถูกลบ',
SupplierDeleted:'ซัพพลายเออร์รายนี้ถูกลบ',
QuoteDeleted:'ใบเสนอราคานี้ถูกลบ',
SaleDeleted:'การลดราคานี้ถูกลบ',
PaymentDeleted:'การชำระเงินนี้ถูกลบ',
PurchaseDeleted:'การซื้อนี้ถูกลบ',
ReturnDeleted:'ผลตอบแทนนี้ถูกลบ',
ProductDeleted:'สินค้านี้ถูกลบ',
ClientError:'ลูกค้ารายนี้เชื่อมโยงกับการดำเนินการอื่นแล้ว',
ProviderError:'ซัพพลายเออร์รายนี้เชื่อมโยงกับการดำเนินการอื่นแล้ว',
UserDeleted:'ผู้ใช้รายนี้ถูกลบ.',
UnitDeleted:'หน่วยนี้ถูกลบแล้ว',
RoleDeleted:'บทบาทนี้ถูกลบ',
TaxeDeleted:'ภาษีนี้ถูกลบแล้ว.',
SubCatDeleted:'หมวดหมู่ย่อยนี้ถูกลบ.',
CatDeleted:'หมวดหมู่นี้ถูกลบ',
WarehouseDeleted:'คลังสินค้านี้ถูกลบ',
AlreadyLinked:'ผลิตภัณฑ์นี้เชื่อมโยงกับการทำงานอื่นแล้ว',
AdjustDeleted:'การปรับปรุงนี้ถูกลบ',
TitleCurrency:'สกุลเงินนี้ถูกลบ',
TitleTransfer:'ลบการโอนเรียบร้อยแล้ว',
BackupDeleted:'ลบข้อมูลสำรองเรียบร้อยแล้ว',
TitleBrand:'แบรนด์นี้ถูกลบ'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleBrand:'แบรนด์นี้ได้รับการอัปเดต',
TitleProfile:'อัปเดตโปรไฟล์ของคุณเรียบร้อยแล้ว',
TitleAdjust:'อัปเดตการปรับปรุงเรียบร้อยแล้ว',
TitleRole:'อัปเดตบทบาทในเรียบร้อยแล้ว',
TitleUnit:'อัปเดตหน่วยในเรียบร้อยแล้ว',
TitleUser:'อัปเดตผู้ใช้เรียบร้อยแล้ว',
TitleCustomer:'การอัปเดตลูกค้าในเรียบร้อยแล้ว',
TitleQuote:'อัปเดตใบเสนอราคาเรียบร้อยแล้ว',
TitleSale:'อัปเดตการขายเรียบร้อยแล้ว',
TitlePayment:'อัปเดตการชำระเงินเรียบร้อยแล้ว',
TitlePurchase:'อัปเดตการซื้อในเรียบร้อยแล้ว',
TitleReturn:'กลับอัปเดตในเรียบร้อยแล้ว',
TitleProduct:'อัปเดตผลิตภัณฑ์เรียบร้อยแล้ว',
TitleSupplier:'อัปเดตซัพพลายเออร์เรียบร้อยแล้ว',
TitleTaxe:'อัปเดตภาษีเรียบร้อยแล้ว',
TitleCat:'อัปเดตหมวดหมู่เรียบร้อยแล้ว',
TitleWarhouse:'อัปเดตคลังสินค้าเรียบร้อยแล้ว',
TitleSetting:'อัปเดตการตั้งค่าเรียบร้อยแล้ว',
TitleCurrency:'อัปเดตสกุลเงินสำเร็จแล้ว',
TitleTransfer:'อัปเดตการโอนเข้าเรียบร้อยแล้ว'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'แบรนด์นี้ถูกสร้างขึ้น',
TitleRole:'สร้างบทบาทในสำเร็จแล้ว',
TitleUnit:'สร้างหน่วยในสำเร็จแล้ว',
TitleUser:'สร้างผู้ใช้ในสำเร็จแล้ว',
TitleCustomer:'สร้างลูกค้าสำเร็จแล้ว',
TitleQuote:'สร้างใบเสนอราคาสำเร็จแล้ว',
TitleSale:'สร้างการขายสำเร็จแล้ว',
TitlePayment:'สร้างการชำระเงินในเรียบร้อยแล้ว',
TitlePurchase:'สร้างในการซื้อเรียบร้อยแล้ว',
TitleReturn:'ส่งคืนสร้างในเรียบร้อยแล้ว',
TitleProduct:'สร้างผลิตภัณฑ์สำเร็จแล้ว',
TitleSupplier:'สร้างซัพพลายเออร์ในเรียบร้อยแล้ว',
TitleTaxe:'สร้างภาษีเรียบร้อยแล้ว',
TitleCat:'สร้างหมวดหมู่สำเร็จแล้ว',
TitleWarhouse:'สร้างคลังสินค้าในเรียบร้อยแล้ว',
TitleAdjust:'สร้างการปรับปรุงในสำเร็จแล้ว',
TitleCurrency:'สร้างสกุลเงินสำเร็จแล้ว',
TitleTransfer:'โอนสร้างในเรียบร้อยแล้ว'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'ส่งอีเมลเรียบร้อยแล้ว'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'การขายนี้เชื่อมโยงกับการคืนสินค้าแล้ว!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'การจัดการผลตอบแทน'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'รายละเอียดการคืนสินค้า'),_defineProperty(_Received_Amount$Payi,"EditReturn",'แก้ไขผลตอบแทน'),_defineProperty(_Received_Amount$Payi,"AddReturn",'สร้างผลตอบแทน'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'ส่งผลตอบแทนทางอีเมล'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'ลบผลตอบแทน'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'คืนเงินเพิ่ม'),_defineProperty(_Received_Amount$Payi,"Laivrison",'จัดส่ง'),_defineProperty(_Received_Amount$Payi,"SelectSale",'เลือกลดราคา'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'คุณสามารถลบรายการหรือตั้งค่าปริมาณที่ส่งคืนเป็นศูนย์หากไม่มีการส่งคืน'),_defineProperty(_Received_Amount$Payi,"Return",'กลับ'),_defineProperty(_Received_Amount$Payi,"Purchase",'ซื้อ'),_defineProperty(_Received_Amount$Payi,"TotalSales",'ยอดขายทั้งหมด'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'การซื้อทั้งหมด'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'ผลตอบแทนรวม'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'การชำระเงินสุทธิ'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'ส่งการชำระเงิน'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'การชำระเงินที่ได้รับ'),_defineProperty(_Received_Amount$Payi,"Recieved",'ได้รับ'),_defineProperty(_Received_Amount$Payi,"Sent",'ส่งแล้ว'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'การแจ้งเตือนปริมาณสินค้า'),_defineProperty(_Received_Amount$Payi,"ProductCode",'รหัส'),_defineProperty(_Received_Amount$Payi,"ProductName",'สินค้า'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'ปริมาณการแจ้งเตือน'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'แผนภูมิสต็อคคลังสินค้า'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'ผลิตภัณฑ์ทั้งหมด'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'ปริมาณรวม'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'ลูกค้าห้าอันดับแรก'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'จำนวนเงินทั้งหมด'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'ทั้งหมดที่จ่าย'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'รายงานการขายของลูกค้า'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'รายงานการชำระเงินของลูกค้า'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'รายงานใบเสนอราคาของลูกค้า'),_defineProperty(_Received_Amount$Payi,"Payments",'การชำระเงิน'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'ซัพพลายเออร์ห้าอันดับแรก'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'รายงานการซื้อของซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'รายงานการชำระเงินของซัพพลายเออร์'),_defineProperty(_Received_Amount$Payi,"Name",'ชื่อ'),_defineProperty(_Received_Amount$Payi,"Code",'รหัส'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'การจัดการคลังสินค้า'),_defineProperty(_Received_Amount$Payi,"ZipCode",'รหัสไปรษณีย์'),_defineProperty(_Received_Amount$Payi,"managementCategories",'การจัดการหมวดหมู่'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'หมวดรหัส'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'หมวดหมู่ชื่อ'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'หมวดหมู่ผู้ปกครอง'),_defineProperty(_Received_Amount$Payi,"managementTax",'การจัดการภาษี'),_defineProperty(_Received_Amount$Payi,"TaxName",'ชื่อผู้เสียภาษี'),_defineProperty(_Received_Amount$Payi,"TaxRate",'อัตราภาษี'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'หน่วยการซื้อ'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'หน่วยขาย'),_defineProperty(_Received_Amount$Payi,"ShortName",'ชื่อสั้น'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'โปรดเลือกสิ่งเหล่านี้ก่อนเพิ่มผลิตภัณฑ์ใด ๆ'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'การปรับหุ้น'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'กรุณาเลือกคลังสินค้าก่อนเลือกสินค้า'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'การโอนหุ้น'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'เลือกช่วงเวลา'),_defineProperty(_Received_Amount$Payi,"ThisYear",'ปีนี้'),_defineProperty(_Received_Amount$Payi,"ThisToday",'วันนี้'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'เดือนนี้'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'ในสัปดาห์นี้'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'รายละเอียดการปรับ'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'ผู้ใช้นี้ได้รับการเปิดใช้งานแล้ว'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'ผู้ใช้รายนี้ถูกปิดใช้งาน'),_defineProperty(_Received_Amount$Payi,"NotFound",'ไม่พบหน้านี้.'),_defineProperty(_Received_Amount$Payi,"oops",'ผิดพลาด! ไม่พบหน้านี้.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'เราไม่พบหน้าที่คุณกำลังค้นหาในขณะเดียวกันคุณอาจ'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'กลับไปที่แดชบอร์ด'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/tr_ch.js":
/*!*****************************************************!*\
  !*** ./resources/src/translations/locales/tr_ch.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesTr_chJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Traditional Chinese
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'收到金額',
Paying_Amount:'支付金額',
Change:'改變',
Paying_amount_is_greater_than_Received_amount:'支付金額大於收到金額',
Paying_amount_is_greater_than_Grand_Total:'支付金額大於總計',
code_must_be_not_exist_already:'代碼必須不存在',
You_will_find_your_backup_on:'你會發現你的備份',
and_save_it_to_your_pc:'並將其保存到您的電腦',
Scan_your_barcode_and_select_the_correct_symbology_below:'掃描您的條形碼並在下方選擇正確的符號',
Scan_Search_Product_by_Code_Name:'按代碼名稱掃描/搜索產品',
Paper_size:'紙張尺寸',
Clear_Cache:'清除緩存',
Cache_cleared_successfully:'緩存清除成功',
Failed_to_clear_cache:'清除緩存失敗',
Scan_Barcode:'條形碼掃描器',
Please_use_short_name_of_unit:'請使用單位簡稱',
DefaultCustomer:'默認客戶',
DefaultWarehouse:'默認倉庫',
Payment_Gateway:'支付網關',
SMS_Configuration:'短信配置',
Gateway:'支付網關',
Choose_Gateway:'選擇支付網關',
Send_SMS:'消息已成功發送',
sms_config_invalid:'錯誤的短信配置無效',
Remove_Stripe_Key_Secret:'刪除Stripe API密鑰',
credit_card_account_not_available:'信用卡帳戶不可用',
Credit_Card_Info:'信用卡資料',
developed_by:'由開發',
Unit_already_linked_with_sub_unit:'單元已與子單元鏈接',
Total_Items_Quantity:'項目總數和數量',
Value_by_Cost_and_Price:'按成本和價格的價值',
Search_this_table:'搜索此表',
import_products:'進口產品',
Field_optional:'字段可選',
Download_exemple:'下載範例',
field_must_be_in_csv_format:'字段必須為csv格式',
Successfully_Imported:'成功導入',
file_size_must_be_less_than_1_mega:'檔案大小必須小於1兆',
Please_follow_the_import_instructions:'請遵循導入說明',
must_be_exist:'單位必須已經創建',
Import_Customers:'導入客戶',
Import_Suppliers:'進口供應商',
Recent_Sales:'最近的銷售',
Create_Transfer:'創建轉移',
order_products:'訂購物品',
Search_Product_by_Code_Name:'按代碼或名稱搜索產品',
Reports_payments_Purchase_Return:'報告購買退貨付款',
Reports_payments_Sale_Return:'報告銷售退貨付款',
payments_Sales_Return:'付款銷售退貨',
payments_Purchases_Return:'付款購買退貨',
CreateSaleReturn:'創建銷售退貨',
EditSaleReturn:'編輯銷售退貨',
SalesReturn:'銷售退貨',
CreatePurchaseReturn:'創建採購退貨',
EditPurchaseReturn:'編輯購買退貨',
PurchasesReturn:'採購退貨',
Due:'到期的',
Profit:'利潤',
Revenue:'收入',
Sales_today:'今日銷量',
People:'人們',
Successfully_Created:'成功創建',
Successfully_Updated:'成功更新',
Success:'成功',
Failed:'失敗的',
Warning:'警告',
Please_fill_the_form_correctly:'請正確填寫表格',
Field_is_required:'必填項',
Error:'錯誤!',
you_are_not_authorized:'對不起！ 您沒有權限。',
Go_back_to_home:'返回首頁',
page_not_exist:'對不起！ 您要查找的頁面不存在。',
Choose_Status:'選擇狀態',
Choose_Method:'選擇方法',
Choose_Symbology:'選擇符號',
Choose_Category:'選擇類別',
Choose_Customer:'選擇客戶',
Choose_Supplier:'選擇供應商',
Choose_Unit_Purchase:'選擇採購單位',
Choose_Sub_Category:'選擇子類別',
Choose_Brand:'選擇品牌',
Choose_Warehouse:'選擇倉庫',
Choose_Unit_Sale:'選擇銷售單位',
Enter_Product_Cost:'輸入產品成本',
Enter_Stock_alert:'輸入庫存警報',
Choose_Unit_Product:'選擇產品單位',
Enter_Product_Price:'輸入產品價格',
Enter_Name_Product:'輸入名稱產品',
Enter_Role_Name:'輸入角色名稱',
Enter_Role_Description:'輸入角色描述',
Enter_name_category:'輸入類別名稱',
Enter_Code_category:'輸入類別代碼',
Enter_Name_Brand:'輸入名稱品牌',
Enter_Description_Brand:'輸入描述品牌',
Enter_Code_Currency:'輸入代碼貨幣',
Enter_name_Currency:'輸入名稱貨幣',
Enter_Symbol_Currency:'輸入符號貨幣',
Enter_Name_Unit:'輸入單位名稱',
Enter_ShortName_Unit:'輸入簡稱單位',
Choose_Base_Unit:'選擇基本單位',
Choose_Operator:'選擇運營商',
Enter_Operation_Value:'輸入操作值',
Enter_Name_Warehouse:'輸入倉庫名稱',
Enter_Phone_Warehouse:'輸入倉庫電話',
Enter_Country_Warehouse:'輸入倉庫國家',
Enter_City_Warehouse:'進入倉庫城市',
Enter_Email_Warehouse:'輸入倉庫電子郵件',
Enter_ZipCode_Warehouse:'輸入倉庫郵政編碼',
Choose_Currency:'選擇貨幣',
Thank_you_for_your_business:'感謝您的業務！',
Cancel:'取消',
New_Customer:'新客戶',
Incorrect_Login:'登陸錯誤',
Successfully_Logged_In:'成功登錄',
This_user_not_active:'該用戶不活躍',
SignIn:'登入',
Create_an_account:'創建一個帳戶',
Forgot_Password:'忘記密碼 ？',
Email_Address:'電子郵件地址',
SignUp:'報名',
Already_have_an_account:'已經有帳號了？',
Reset_Password:'重設密碼',
Failed_to_authenticate_on_SMTP_server:'無法在SMTP服務器上進行身份驗證',
We_cant_find_a_user_with_that_email_addres:'我們找不到使用該電子郵件地址的用戶',
We_have_emailed_your_password_reset_link:'我們已經通過電子郵件發送了您的密碼重置鏈接',
Please_fill_the_Email_Adress:'請填寫電子郵件地址',
Confirm_password:'確認密碼',
Your_Password_has_been_changed:'您的密碼已被更改',
The_password_confirmation_does_not_match:'密碼確認不匹配',
This_password_reset_token_is_invalid:'此密碼重置令牌無效',
Warehouse_report:'倉庫報告',
All_Warehouses:'所有倉庫',
Expense_List:'費用清單',
Expenses:'花費',
This_Week_Sales_Purchases:'本週銷售與購買',
Top_Selling_Products:'暢銷產品',
View_all:'查看全部',
Payment_Sent_Received:'已發送並已收到付款',
Filter:'過濾',
Invoice_POS:'發票POS',
Invoice:'發票',
Customer_Info:'客戶信息',
Company_Info:'公司介紹',
Invoice_Info:'發票信息',
Order_Summary:'訂單摘要',
Quote_Info:'報價信息',
Del:'刪除',
SuppliersPaiementsReport:'供應商付款報告',
Purchase_Info:'購買信息',
Supplier_Info:'供應商信息',
Return_Info:'退貨信息',
Expense_Category:'費用類別',
Create_Expense:'創建費用',
Details:'細節',
Discount_Method:'優惠方式',
Net_Unit_Cost:'淨單位成本',
Net_Unit_Price:'淨單價',
Edit_Expense:'編輯費用',
All_Brand:'所有品牌',
All_Category:'所有類別',
ListExpenses:'清單費用',
Create_Permission:'建立權限',
Edit_Permission:'編輯權限',
Reports_payments_Sales:'報告付款銷售',
Reports_payments_Purchases:'報告付款購買',
Reports_payments_Return_Customers:'報告付款返回客戶',
Reports_payments_Return_Suppliers:'報表付款退貨供應商',
Expense_Deleted:'該費用已被刪除',
Expense_Updated:'此費用已更新',
Expense_Created:'費用已創建',
DemoVersion:'您無法在演示版中執行此操作',
OrderStatistics:'銷售統計',
AlreadyAdd:'該產品已添加！',
AddProductToList:'請添加產品到列表！',
AddQuantity:'請添加詳細數量！',
InvalidData:'無效數據 ！！',
LowStock:'數量超過庫存可用數量',
WarehouseIdentical:'兩個倉庫不能完全相同！',
VariantDuplicate:'這個變種是重複的！',
Filesize:'文件大小',
GenerateBackup:'產生備份',
BackupDatabase:'備份資料庫',
Backup:'後備',
Paid:'已付費',
Unpaid:'未付',
Today:'今天',
Income:'收入'},
_defineProperty(_Received_Amount$Payi,"Expenses",'花費'),_defineProperty(_Received_Amount$Payi,"Sale",'特賣'),_defineProperty(_Received_Amount$Payi,"Actif",'活性'),_defineProperty(_Received_Amount$Payi,"Inactif",'不活躍'),_defineProperty(_Received_Amount$Payi,"Customers",'顧客'),_defineProperty(_Received_Amount$Payi,"Phone",'電話'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'通過電話搜索'),_defineProperty(_Received_Amount$Payi,"Suppliers",'供應商'),_defineProperty(_Received_Amount$Payi,"Quotations",'報價單'),_defineProperty(_Received_Amount$Payi,"Sales",'營業額'),_defineProperty(_Received_Amount$Payi,"Purchases",'採購'),_defineProperty(_Received_Amount$Payi,"Returns",'退貨'),_defineProperty(_Received_Amount$Payi,"Settings",'設定值'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'系統設置'),_defineProperty(_Received_Amount$Payi,"Users",'用戶數'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'組權限'),_defineProperty(_Received_Amount$Payi,"Currencies",'貨幣'),_defineProperty(_Received_Amount$Payi,"Warehouses",'貨倉'),_defineProperty(_Received_Amount$Payi,"Units",'單位'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'單位購買'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'單位銷售'),_defineProperty(_Received_Amount$Payi,"Reports",'報告書'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'付款報告'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'付款購買'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'付款銷售'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'收益與損失'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'倉庫庫存圖'),_defineProperty(_Received_Amount$Payi,"SalesReport",'銷售報告'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'採購報告'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'客戶報告'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'供應商報告'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'供應商報告'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'每日銷售數據'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'每日購買數據'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'最近五條記錄'),_defineProperty(_Received_Amount$Payi,"Filters",'篩選器'),_defineProperty(_Received_Amount$Payi,"date",'日期'),_defineProperty(_Received_Amount$Payi,"Reference",'參考'),_defineProperty(_Received_Amount$Payi,"Supplier",'供應商'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'支付狀態'),_defineProperty(_Received_Amount$Payi,"Customer",'顧客'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'客戶代碼'),_defineProperty(_Received_Amount$Payi,"Status",'狀態'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'供應商代碼'),_defineProperty(_Received_Amount$Payi,"Categorie",'類別'),_defineProperty(_Received_Amount$Payi,"Categories",'分類目錄'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'庫存轉移'),_defineProperty(_Received_Amount$Payi,"StockManagement",'庫存管理'),_defineProperty(_Received_Amount$Payi,"dashboard",'儀表板'),_defineProperty(_Received_Amount$Payi,"Products",'產品展示'),_defineProperty(_Received_Amount$Payi,"productsList",'產品清單'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'產品管理'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'產品數量警報'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'代碼產品'),_defineProperty(_Received_Amount$Payi,"ProductTax",'產品稅'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'子類別'),_defineProperty(_Received_Amount$Payi,"Name_product",'指定'),_defineProperty(_Received_Amount$Payi,"StockAlert",'庫存警報'),_defineProperty(_Received_Amount$Payi,"warehouse",'倉庫'),_defineProperty(_Received_Amount$Payi,"Tax",'稅'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'買價'),_defineProperty(_Received_Amount$Payi,"SellPrice",'賣價'),_defineProperty(_Received_Amount$Payi,"Quantity",'數量'),_defineProperty(_Received_Amount$Payi,"UnitSale",'單位銷售'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'單位購買'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'貨幣管理'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'貨幣代碼'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'貨幣名稱'),_defineProperty(_Received_Amount$Payi,"Symbol",'符號'),_defineProperty(_Received_Amount$Payi,"All",'所有'),_defineProperty(_Received_Amount$Payi,"EditProduct",'編輯產品'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'按代碼搜索'),_defineProperty(_Received_Amount$Payi,"SearchByName",'按名稱搜索'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'產品詳情'),_defineProperty(_Received_Amount$Payi,"CustomerName",'顧客姓名'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'用戶管理'),_defineProperty(_Received_Amount$Payi,"Add",'創建'),_defineProperty(_Received_Amount$Payi,"add",'創建'),_defineProperty(_Received_Amount$Payi,"Edit",'編輯'),_defineProperty(_Received_Amount$Payi,"Close",'關'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'請選擇'),_defineProperty(_Received_Amount$Payi,"Action",'行動'),_defineProperty(_Received_Amount$Payi,"Email",'電子郵件'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'編輯客戶'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'建立客戶'),_defineProperty(_Received_Amount$Payi,"Country",'國家'),_defineProperty(_Received_Amount$Payi,"City",'市'),_defineProperty(_Received_Amount$Payi,"Adress",'地址'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'顧客信息'),_defineProperty(_Received_Amount$Payi,"CustomersList",'客戶名單'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'供應商代碼'),_defineProperty(_Received_Amount$Payi,"SupplierName",'供應商名稱'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'供應商管理'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'供應商詳細信息'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'報價管理'),_defineProperty(_Received_Amount$Payi,"SubTotal",'小計'),_defineProperty(_Received_Amount$Payi,"MontantReste",'剩餘金額'),_defineProperty(_Received_Amount$Payi,"complete",'已完成'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'待定'),_defineProperty(_Received_Amount$Payi,"Recu",'已收到'),_defineProperty(_Received_Amount$Payi,"partial",'部分的'),_defineProperty(_Received_Amount$Payi,"Retournee",'返回'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'詳細報價'),_defineProperty(_Received_Amount$Payi,"EditQuote",'編輯報價'),_defineProperty(_Received_Amount$Payi,"CreateSale",'建立銷售'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'下載pdf'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'電子郵件發送報價'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'刪除報價'),_defineProperty(_Received_Amount$Payi,"AddQuote",'創建報價'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'選擇產品'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'產品（代碼-名稱）'),_defineProperty(_Received_Amount$Payi,"Price",'價錢'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'股票'),_defineProperty(_Received_Amount$Payi,"Total",'總'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'單位成本'),_defineProperty(_Received_Amount$Payi,"to",'至'),_defineProperty(_Received_Amount$Payi,"Subject",'學科'),_defineProperty(_Received_Amount$Payi,"Message",'信息'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'電郵客戶'),_defineProperty(_Received_Amount$Payi,"Sent",'發送'),_defineProperty(_Received_Amount$Payi,"Quote",'報價單'),_defineProperty(_Received_Amount$Payi,"Hello",'你好'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'請找到您的報價附件'),_defineProperty(_Received_Amount$Payi,"AddProducts",'將產品添加到訂單清單'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'請選擇倉庫'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'請選擇客戶'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'銷售管理'),_defineProperty(_Received_Amount$Payi,"Balance",'平衡'),_defineProperty(_Received_Amount$Payi,"QtyBack",'數量返還'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'總回報'),_defineProperty(_Received_Amount$Payi,"Amount",'量'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'銷售明細'),_defineProperty(_Received_Amount$Payi,"EditSale",'編輯銷售'),_defineProperty(_Received_Amount$Payi,"AddSale",'建立銷售'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'顯示付款'),_defineProperty(_Received_Amount$Payi,"AddPayment",'創建付款'),_defineProperty(_Received_Amount$Payi,"EditPayment",'編輯付款'),_defineProperty(_Received_Amount$Payi,"EmailSale",'通過電子郵件發送銷售'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'刪除銷售'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'由...支付'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'付款方式'),_defineProperty(_Received_Amount$Payi,"Note",'注意'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'付款完成！'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'採購管理'),_defineProperty(_Received_Amount$Payi,"Ordered",'已訂購'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'刪除購買'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'通過電子郵件發送購買'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'編輯購買'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'採購明細'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'創建購買'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'供應商電子郵件'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'購買付款'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'購買付款數據'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'銷售付款'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'銷售付款數據'),_defineProperty(_Received_Amount$Payi,"UserManagement",'用戶管理'),_defineProperty(_Received_Amount$Payi,"Firstname",'名字'),_defineProperty(_Received_Amount$Payi,"lastname",'姓'),_defineProperty(_Received_Amount$Payi,"username",'用戶名'),_defineProperty(_Received_Amount$Payi,"password",'密碼'),_defineProperty(_Received_Amount$Payi,"Newpassword",'新密碼'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'更改頭像'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'如果尚未更改，請將該字段留空'),_defineProperty(_Received_Amount$Payi,"type",'類型'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'用戶權限'),_defineProperty(_Received_Amount$Payi,"RoleName",'角色'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'角色描述'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'創建權限'),_defineProperty(_Received_Amount$Payi,"View",'視圖'),_defineProperty(_Received_Amount$Payi,"Del",'刪除'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'新調整'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'編輯調整'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'您不能減去有庫存0的產品'),_defineProperty(_Received_Amount$Payi,"Addition",'加成'),_defineProperty(_Received_Amount$Payi,"Subtraction",'減法'),_defineProperty(_Received_Amount$Payi,"profil",'概況'),_defineProperty(_Received_Amount$Payi,"logout",'登出'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'您無法修改，因為此購買已付款'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'您無法修改，因為此銷售已經付款'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'您無法修改，因為此退貨已經支付'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'此報價已產生銷售'),_defineProperty(_Received_Amount$Payi,"AddProduct",'創建產品'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'報價完成'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'網站配置'),_defineProperty(_Received_Amount$Payi,"Language",'語言'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'預設貨幣'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'登錄驗證碼'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'默認電子郵件'),_defineProperty(_Received_Amount$Payi,"SiteName",'網站名稱'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'變更標誌'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'SMTP配置'),_defineProperty(_Received_Amount$Payi,"HOST",'主辦'),_defineProperty(_Received_Amount$Payi,"PORT",'港口'),_defineProperty(_Received_Amount$Payi,"encryption",'加密'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'SMTP配置不正確'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'付款退貨'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'退回發票'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'退回發票數據'),_defineProperty(_Received_Amount$Payi,"ShowAll",'顯示所有用戶的所有記錄'),_defineProperty(_Received_Amount$Payi,"Discount",'折扣'),_defineProperty(_Received_Amount$Payi,"OrderTax",'訂單稅'),_defineProperty(_Received_Amount$Payi,"Shipping",'運輸'),_defineProperty(_Received_Amount$Payi,"CompanyName",'公司名'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'公司電話'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'公司地址'),_defineProperty(_Received_Amount$Payi,"Code",'碼'),_defineProperty(_Received_Amount$Payi,"image",'圖片'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'打印條形碼'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'回頭客'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'退貨供應商'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'退貨客戶發票'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'退貨供應商發票'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'沒有可用數據'),_defineProperty(_Received_Amount$Payi,"ProductImage",'產品圖片'),_defineProperty(_Received_Amount$Payi,"Barcode",'條碼'),_defineProperty(_Received_Amount$Payi,"pointofsales",'銷售點'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'自定義上傳'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'銷售點管理'),_defineProperty(_Received_Amount$Payi,"Adjustment",'調整'),_defineProperty(_Received_Amount$Payi,"Updat",'更新資料'),_defineProperty(_Received_Amount$Payi,"Reset",'重啟'),_defineProperty(_Received_Amount$Payi,"print",'打印'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'通過電子郵件搜索'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'選擇產品'),_defineProperty(_Received_Amount$Payi,"Qty",'數量'),_defineProperty(_Received_Amount$Payi,"Items",'物品'),_defineProperty(_Received_Amount$Payi,"AmountHT",'量'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'合計金額'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'請選擇供應商'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'請選擇狀態'),_defineProperty(_Received_Amount$Payi,"PayeBy",'由...支付'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'選擇倉庫'),_defineProperty(_Received_Amount$Payi,"payNow",'現在付款'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'類別清單'),_defineProperty(_Received_Amount$Payi,"Description",'描述'),_defineProperty(_Received_Amount$Payi,"submit",'提交'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'創建此發票時出現問題。 請再試一次'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'付款有問題。 請再試一次。'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'收入與支出'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'每日銷售與購買'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'產品過期'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'列出品牌'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'創建調整'),_defineProperty(_Received_Amount$Payi,"Afewwords",'幾句話 ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'用戶圖片'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'更新產品'),_defineProperty(_Received_Amount$Payi,"Brand",'牌'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'條碼符號'),_defineProperty(_Received_Amount$Payi,"ProductCost",'產品成本'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'產品價格'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'單位產品'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'稅法'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'多張圖片'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'產品具有多種變體'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'產品促銷'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'促銷開始'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'促銷結束'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'促銷價'),_defineProperty(_Received_Amount$Payi,"Price",'價錢'),_defineProperty(_Received_Amount$Payi,"Cost",'成本'),_defineProperty(_Received_Amount$Payi,"Unit",'單元'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'產品變體'),_defineProperty(_Received_Amount$Payi,"Variant",'變體'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'單價'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'創建退貨客戶'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'編輯退貨客戶'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'創建退貨供應商'),_defineProperty(_Received_Amount$Payi,"Documentation",'文獻資料'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'編輯退貨供應商'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'從倉庫'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'到倉庫'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'編輯轉移'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'轉賬明細'),_defineProperty(_Received_Amount$Payi,"Pending",'待定'),_defineProperty(_Received_Amount$Payi,"Received",'已收到'),_defineProperty(_Received_Amount$Payi,"Ordered",'已訂購'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'權限管理'),_defineProperty(_Received_Amount$Payi,"BrandManager",'牌'),_defineProperty(_Received_Amount$Payi,"BrandImage",'品牌形象'),_defineProperty(_Received_Amount$Payi,"BrandName",'品牌'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'品牌描述'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'基本單位'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'單位管理'),_defineProperty(_Received_Amount$Payi,"OperationValue",'運營價值'),_defineProperty(_Received_Amount$Payi,"Operator",'操作員'),_defineProperty(_Received_Amount$Payi,"Top5Products",'前五名產品'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'最近五次銷售'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'清單調整'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'清單轉移'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'創建轉移'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'訂單管理'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'清單報價'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'列出購買'),_defineProperty(_Received_Amount$Payi,"ListSales",'清單銷售'),_defineProperty(_Received_Amount$Payi,"ListReturns",'清單退貨'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'人事管理'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'你確定嗎？',
Text:'您將無法還原它！',
confirmButtonText:'是的，刪除它！',
cancelButtonText:'取消',
Deleted:'已刪除！',
Failed:'失敗了！',
Therewassomethingwronge:'出事了',
CustomerDeleted:'該客戶端已被刪除。',
SupplierDeleted:'該供應商已被刪除。',
QuoteDeleted:'此報價已被刪除。',
SaleDeleted:'此銷售已被刪除。',
PaymentDeleted:'此付款已被刪除。',
PurchaseDeleted:'此購買已被刪除。',
ReturnDeleted:'此退貨已被刪除。',
ProductDeleted:'該產品已被刪除',
ClientError:'該客戶端已經與其他操作鏈接',
ProviderError:'該供應商已與其他運營部門鏈接',
UserDeleted:'該用戶已被刪除。',
UnitDeleted:'該單位已被刪除。',
RoleDeleted:'該角色已被刪除。',
TaxeDeleted:'該稅項已被刪除。',
SubCatDeleted:'該子類別已被刪除。',
CatDeleted:'此類別已被刪除。',
WarehouseDeleted:'該倉庫已被刪除。',
AlreadyLinked:'該產品已經與其他操作鏈接',
AdjustDeleted:'此調整已被刪除。',
TitleCurrency:'該貨幣已被刪除。',
TitleTransfer:'轉移已成功刪除',
BackupDeleted:'備份已成功刪除',
TitleBrand:'該品牌已被刪除'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleProfile:'您的個人資料已成功更新',
TitleAdjust:'調整已成功更新',
TitleRole:'角色更新成功',
TitleUnit:'單位更新成功',
TitleUser:'用戶已成功更新',
TitleCustomer:'客戶更新成功',
TitleQuote:'報價已成功更新',
TitleSale:'銷售已成功更新',
TitlePayment:'付款已成功更新',
TitlePurchase:'購買已成功更新',
TitleReturn:'返回成功更新',
TitleProduct:'產品更新成功',
TitleSupplier:'供應商更新成功',
TitleTaxe:'稅務更新成功',
TitleCat:'分類成功更新',
TitleWarhouse:'倉庫已成功更新',
TitleSetting:'設置已成功更新',
TitleCurrency:'貨幣更新成功',
TitleTransfer:'轉移成功更新',
TitleBrand:'該品牌已更新'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'該品牌已創建',
TitleRole:'角色創建成功',
TitleUnit:'單位創建成功',
TitleUser:'用戶創建成功',
TitleCustomer:'客戶創建成功',
TitleQuote:'報價創建成功',
TitleSale:'銷售成功創建',
TitlePayment:'付款成功創建',
TitlePurchase:'購買成功創建',
TitleReturn:'返回創建成功',
TitleProduct:'產品創建成功',
TitleSupplier:'供應商創建成功',
TitleTaxe:'稅收創建成功',
TitleCat:'分類成功創建',
TitleWarhouse:'成功創建倉庫',
TitleAdjust:'調整已成功創建',
TitleCurrency:'貨幣創建成功',
TitleTransfer:'轉移成功創建'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'電子郵件發送成功'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'此銷售已經與退貨相關！'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'退貨管理'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'退貨明細'),_defineProperty(_Received_Amount$Payi,"EditReturn",'編輯退貨'),_defineProperty(_Received_Amount$Payi,"AddReturn",'創建退貨'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'通過電子郵件發送退貨'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'刪除退貨'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'回程附加費'),_defineProperty(_Received_Amount$Payi,"Laivrison",'交貨'),_defineProperty(_Received_Amount$Payi,"SelectSale",'選擇銷售'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'您可以刪除該項目或將未退回的數量設置為零'),_defineProperty(_Received_Amount$Payi,"Return",'返回'),_defineProperty(_Received_Amount$Payi,"Purchase",'採購'),_defineProperty(_Received_Amount$Payi,"TotalSales",'總銷售額'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'總購買'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'總回報'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'淨付款'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'已付款'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'付款已收到'),_defineProperty(_Received_Amount$Payi,"Recieved",'已收到'),_defineProperty(_Received_Amount$Payi,"Sent",'已發送'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'產品數量警報'),_defineProperty(_Received_Amount$Payi,"ProductCode",'碼'),_defineProperty(_Received_Amount$Payi,"ProductName",'產品'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'警報數量'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'倉庫庫存圖'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'產品總數'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'總數（量'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'前五名客戶'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'總金額'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'總支付'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'客戶銷售報告'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'客戶付款報告'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'客戶報價報告'),_defineProperty(_Received_Amount$Payi,"Payments",'付款方式'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'前五名供應商'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'供應商採購報告'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'供應商付款報告'),_defineProperty(_Received_Amount$Payi,"Name",'名稱'),_defineProperty(_Received_Amount$Payi,"Code",'碼'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'倉庫管理'),_defineProperty(_Received_Amount$Payi,"ZipCode",'郵政編碼'),_defineProperty(_Received_Amount$Payi,"managementCategories",'分類管理'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'代碼類別'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'名稱類別'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'父類別'),_defineProperty(_Received_Amount$Payi,"managementTax",'稅務管理'),_defineProperty(_Received_Amount$Payi,"TaxName",'稅名'),_defineProperty(_Received_Amount$Payi,"TaxRate",'稅率'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'採購單位'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'銷售單位'),_defineProperty(_Received_Amount$Payi,"ShortName",'簡稱'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'請在添加任何產品之前選擇這些'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'庫存調整'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'選擇任何產品之前，請先選擇倉庫'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'庫存轉移'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'選擇時期'),_defineProperty(_Received_Amount$Payi,"ThisYear",'今年'),_defineProperty(_Received_Amount$Payi,"ThisToday",'今天'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'這個月'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'本星期'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'調整細節'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'該用戶已被激活'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'此用戶已被停用'),_defineProperty(_Received_Amount$Payi,"NotFound",'找不到網頁。'),_defineProperty(_Received_Amount$Payi,"oops",'錯誤！ 找不到網頁。'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'我們找不到您想要的頁面。與此同時，您可能'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'返回儀表板'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/tur.js":
/*!***************************************************!*\
  !*** ./resources/src/translations/locales/tur.js ***!
  \***************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesTurJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Turc
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Alınan miktar',
Paying_Amount:'Ödeme Tutarı',
Change:'Değişiklik',
Paying_amount_is_greater_than_Received_amount:'Ödeme tutarı alınan tutardan fazla',
Paying_amount_is_greater_than_Grand_Total:'Ödeme tutarı Genel Toplam\'dan büyük',
code_must_be_not_exist_already:'kod zaten mevcut olmamalı',
You_will_find_your_backup_on:'Yedeklemenizi şurada bulacaksınız:',
and_save_it_to_your_pc:'ve bilgisayarınıza kaydedin',
Scan_your_barcode_and_select_the_correct_symbology_below:'Barkodunuzu tarayın ve aşağıdan doğru sembolojiyi seçin',
Scan_Search_Product_by_Code_Name:'Ürünü Kod Adına Göre Tara/Ara',
Paper_size:'Kağıt boyutu',
Clear_Cache:'Önbelleği Temizle',
Cache_cleared_successfully:'Önbellek başarıyla temizlendi',
Failed_to_clear_cache:'Önbellek temizlenemedi',
Scan_Barcode:'Barkod okuyucu',
Please_use_short_name_of_unit:'Lütfen birimin kısa adını kullanın',
DefaultCustomer:'Varsayılan Müşteri',
DefaultWarehouse:'Varsayılan Depo',
Payment_Gateway:'Ödeme Sağlayıcı',
SMS_Configuration:'SMS Yapılandırması',
Gateway:'Ödeme Sağlayıcı',
Choose_Gateway:'Ödeme Ağ Geçidini Seçin',
Send_SMS:'Mesaj başarıyla gönderildi',
sms_config_invalid:'yanlış sms yapılandırması geçersiz',
Remove_Stripe_Key_Secret:'Stripe API anahtarlarını silin',
credit_card_account_not_available:'Kredi kartı hesabı mevcut değil',
Credit_Card_Info:'Kredi Kartı Bilgileri',
developed_by:'Tarafından geliştirilmiş',
Unit_already_linked_with_sub_unit:'Birim zaten alt birime bağlı',
Total_Items_Quantity:'Toplam Öğeler ve Miktar',
Value_by_Cost_and_Price:'Maliyet ve Fiyata Göre Değer',
Search_this_table:'Bu tabloda ara',
import_products:'Ürünleri içe aktar',
Field_optional:'İsteğe bağlı alan',
Download_exemple:'Örneği indirin',
field_must_be_in_csv_format:'Alan, csv biçiminde olmalıdır',
Successfully_Imported:'Başarıyla İçe Aktarıldı',
file_size_must_be_less_than_1_mega:'Dosya boyutu 1 mega\'dan küçük olmalıdır',
Please_follow_the_import_instructions:'Lütfen içe aktarma talimatlarını izleyin',
must_be_exist:'birim zaten oluşturulmuş olmalıdır',
Import_Customers:'Müşterileri İçe Aktar',
Import_Suppliers:'İthalat Tedarikçileri',
Recent_Sales:'Son Satışlar',
Create_Transfer:'Transfer Oluştur',
order_products:'sipariş öğeleri',
Search_Product_by_Code_Name:'Koda veya Ada Göre Ürün Ara',
Reports_payments_Purchase_Return:'Raporlar Satın Alma İade Ödemeleri',
Reports_payments_Sale_Return:'Raporlar Satış İadesi Ödemeleri',
payments_Sales_Return:'ödemeler satış iadesi',
payments_Purchases_Return:'ödemeler satın alma iadesi',
CreateSaleReturn:'Satış İadesi Oluştur',
EditSaleReturn:'Satış İadesini Düzenle',
SalesReturn:'Satış İadesi',
CreatePurchaseReturn:'Satın Alma İadesi Oluştur',
EditPurchaseReturn:'Satın Alma İadesini Düzenle',
PurchasesReturn:'Satın Alma İadesi',
Due:'vadesi dolmuş',
Profit:'Kar',
Revenue:'gelir',
Sales_today:'Bugün satış',
People:'İnsanlar',
Successfully_Created:'Başarıyla Oluşturuldu',
Successfully_Updated:'Başarıyla güncellendi',
Success:'Başarı',
Failed:'Başarısız oldu',
Warning:'Uyarı',
Please_fill_the_form_correctly:'Lütfen formu doğru doldurunuz',
Field_is_required:'Alan gereklidir',
Error:'Hata!',
you_are_not_authorized:'Afedersiniz! yetkili değilsin.',
Go_back_to_home:'Ana sayfaya geri dön',
page_not_exist:'Afedersiniz! Aradığınız sayfa mevcut değil.',
Choose_Status:'Durum Seçin',
Choose_Method:'Yöntem Seçin',
Choose_Symbology:'Semboloji seçin',
Choose_Category:'Kategori Seçin',
Choose_Customer:'Müşteri Seçin',
Choose_Supplier:'Tedarikçi Seçin',
Choose_Unit_Purchase:'Satın Alma Birimini Seçin',
Choose_Sub_Category:'Alt Kategori Seçin',
Choose_Brand:'Marka Seçin',
Choose_Warehouse:'Depo Seçin',
Choose_Unit_Sale:'Satış Birimini Seçin',
Enter_Product_Cost:'Ürün Maliyetini Girin',
Enter_Stock_alert:'Stok uyarısını girin',
Choose_Unit_Product:'Ürün Birimini Seçin',
Enter_Product_Price:'Ürün Fiyatını Girin',
Enter_Name_Product:'Ürün Adını Girin',
Enter_Role_Name:'Rol Adını Girin',
Enter_Role_Description:'Rol Açıklamasını Girin',
Enter_name_category:'Kategori adını girin',
Enter_Code_category:'Kategori kodunu girin',
Enter_Name_Brand:'İsim Markasını Girin',
Enter_Description_Brand:'Açıklama Markasını Girin',
Enter_Code_Currency:'Kod Para Birimi Girin',
Enter_name_Currency:'Adı girin Para birimi',
Enter_Symbol_Currency:'Sembol Para Birimi Girin',
Enter_Name_Unit:'Birim Adını Girin',
Enter_ShortName_Unit:'Kısa ad Birimi girin',
Choose_Base_Unit:'Baz Ünitesini Seçin',
Choose_Operator:'Operatör Seçin',
Enter_Operation_Value:'İşlem Değerini Girin',
Enter_Name_Warehouse:'Depo Adını Girin',
Enter_Phone_Warehouse:'Depo Telefonunu Girin',
Enter_Country_Warehouse:'Depo Ülkesini Girin',
Enter_City_Warehouse:'Depo Şehrini Girin',
Enter_Email_Warehouse:'Depo E-postasını Girin',
Enter_ZipCode_Warehouse:'Depo Posta Kodunu Girin',
Choose_Currency:'Para Birimini Seç',
Thank_you_for_your_business:'İşiniz için teşekkür ederim!',
Cancel:'İptal etmek',
New_Customer:'Yeni müşteri',
Incorrect_Login:'Yanlış giriş',
Successfully_Logged_In:'Başarıyla Giriş Yapıldı',
This_user_not_active:'Bu kullanıcı aktif değil',
SignIn:'Oturum aç',
Create_an_account:'Bir hesap oluşturun',
Forgot_Password:'Parolanızı mı unuttunuz ?',
Email_Address:'e-posta adresi',
SignUp:'Kaydol',
Already_have_an_account:'Zaten hesabınız var mı ?',
Reset_Password:'Şifreyi yenile',
Failed_to_authenticate_on_SMTP_server:'SMTP sunucusunda kimlik doğrulanamadı',
We_cant_find_a_user_with_that_email_addres:'Bu e-posta adresine sahip bir kullanıcı bulamıyoruz',
We_have_emailed_your_password_reset_link:'şifre sıfırlama bağlantınızı e-postayla gönderdim',
Please_fill_the_Email_Adress:'Lütfen E-posta Adresini doldurun',
Confirm_password:'Şifreyi Onayla',
Your_Password_has_been_changed:'Şifreniz değiştirildi',
The_password_confirmation_does_not_match:'Parola onayı eşleşmiyor',
This_password_reset_token_is_invalid:'Bu şifre sıfırlama jetonu geçersiz',
Warehouse_report:'Depo raporu',
All_Warehouses:'Tüm Depolar',
Expense_List:'Gider Listesi',
Expenses:'Masraflar',
This_Week_Sales_Purchases:'Bu Hafta Satışlar ve Satın Alımlar',
Top_Selling_Products:'En Çok Satan Ürünler',
View_all:'Hepsini gör',
Payment_Sent_Received:'Gönderilen ve Alınan Ödeme',
Filter:'Filtrele',
Invoice_POS:'Fatura POS',
Invoice:'Fatura',
Customer_Info:'Müşteri Bilgisi',
Company_Info:'Şirket bilgileri',
Invoice_Info:'Fatura Bilgileri',
Order_Summary:'sipariş özeti',
Quote_Info:'Teklif Bilgisi',
Del:'Sil',
SuppliersPaiementsReport:'Tedarikçi Ödemeleri Raporu',
Purchase_Info:'Satın Alma Bilgileri',
Supplier_Info:'Tedarikçi Bilgileri',
Return_Info:'Dönüş bilgisi',
Expense_Category:'Gider Kategorisi',
Create_Expense:'Gider Yaratın',
Details:'DetDetaylarails',
Discount_Method:'İndirim Yöntemi',
Net_Unit_Cost:'Net Birim Maliyeti',
Net_Unit_Price:'Net Birim Fiyatı',
Edit_Expense:'Gider Düzenle',
All_Brand:'Tüm Marka',
All_Category:'Tüm Kategori',
ListExpenses:'Giderleri Listele',
Create_Permission:'İzin Oluştur',
Edit_Permission:'İzni Düzenle',
Reports_payments_Sales:'Rapor ödemeleri Satış',
Reports_payments_Purchases:'Rapor ödemeleri Satın alma işlemleri',
Reports_payments_Return_Customers:'Rapor ödemeleri İade Müşterileri',
Reports_payments_Return_Suppliers:'Rapor ödemeleri İade Tedarikçileri',
Expense_Deleted:'Bu Gider silindi',
Expense_Updated:'Bu Gider Güncellendi',
Expense_Created:'Bu Gider Oluşturuldu',
DemoVersion:'Bunu demo sürümünde yapamazsınız',
OrderStatistics:'Satış İstatistikleri',
AlreadyAdd:'Bu Ürün Zaten Eklendi !!',
AddProductToList:'Lütfen Ürünü Listeye Ekleyin !!',
AddQuantity:'Lütfen Detay Miktarı Ekleyin !!',
InvalidData:'Geçersiz veri !!',
LowStock:'miktar stokta bulunan miktarı aşıyor',
WarehouseIdentical:'İki depo aynı olamaz !!',
VariantDuplicate:'Bu Varyant Yineleniyor !!',
Filesize:'Dosya boyutu',
GenerateBackup:'Yedek Oluştur',
BackupDatabase:'Yedek veritabanı',
Backup:'Destek olmak',
Paid:'Ücretli',
Unpaid:'Ödenmemiş',
Today:'Bugün',
Income:'Gelir'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Masraflar'),_defineProperty(_Received_Amount$Payi,"Sale",'Satış'),_defineProperty(_Received_Amount$Payi,"Actif",'Aktif'),_defineProperty(_Received_Amount$Payi,"Inactif",'Etkin değil'),_defineProperty(_Received_Amount$Payi,"Customers",'Müşteriler'),_defineProperty(_Received_Amount$Payi,"Phone",'Telefon'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Telefonla Ara'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Tedarikçiler'),_defineProperty(_Received_Amount$Payi,"Quotations",'Alıntılar'),_defineProperty(_Received_Amount$Payi,"Sales",'Satış'),_defineProperty(_Received_Amount$Payi,"Purchases",'Satın alma'),_defineProperty(_Received_Amount$Payi,"Returns",'İadeler'),_defineProperty(_Received_Amount$Payi,"Settings",'Ayarlar'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'Sistem ayarları'),_defineProperty(_Received_Amount$Payi,"Users",'Kullanıcılar'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Grup İzinleri'),_defineProperty(_Received_Amount$Payi,"Currencies",'Para birimleri'),_defineProperty(_Received_Amount$Payi,"Warehouses",'Depolar'),_defineProperty(_Received_Amount$Payi,"Units",'Birimler'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'Birimler Alımları'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Satış Birimleri'),_defineProperty(_Received_Amount$Payi,"Reports",'Raporlar'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Ödemeler Raporu'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Payments Satın Alımları'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Ödemeler Satış'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Kar ve zarar'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Wdepo Stok Tablosu'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Satış raporu'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Satın Alma Raporu'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Müşteriler Raporu'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Tedarikçiler Raporu'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Tedarikçi Raporu'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Günlük Satış Verileri'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Günlük Satın Alma Verileri'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Son beş kayıt'),_defineProperty(_Received_Amount$Payi,"Filters",'Filtreler'),_defineProperty(_Received_Amount$Payi,"date",'tarih'),_defineProperty(_Received_Amount$Payi,"Reference",'Referans'),_defineProperty(_Received_Amount$Payi,"Supplier",'Tedarikçi'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Ödeme Durumu'),_defineProperty(_Received_Amount$Payi,"Customer",'Müşteri'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Müşteri kodu'),_defineProperty(_Received_Amount$Payi,"Status",'Durum'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Tedarikçi Kodu'),_defineProperty(_Received_Amount$Payi,"Categorie",'Kategori'),_defineProperty(_Received_Amount$Payi,"Categories",'Kategoriler'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Stok Transferleri'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Stok yönetimi'),_defineProperty(_Received_Amount$Payi,"dashboard",'Gösterge Paneli'),_defineProperty(_Received_Amount$Payi,"Products",'Ürün:% s'),_defineProperty(_Received_Amount$Payi,"productsList",'ürün listesi'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Ürün Yönetimi'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Ürün Miktarı Uyarıları'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Kod Ürün'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Ürün Vergisi'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'Alt kategori'),_defineProperty(_Received_Amount$Payi,"Name_product",'Tanımlama'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Stok Uyarısı'),_defineProperty(_Received_Amount$Payi,"warehouse",'depo'),_defineProperty(_Received_Amount$Payi,"Tax",'Vergi'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Alım fiyati'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Satış fiyatı'),_defineProperty(_Received_Amount$Payi,"Quantity",'Miktar'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Birim Satışı'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Birim Satın Alma'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Para Birimi Yönetimi'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Para Birimi Kodu'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Para Birimi Adı'),_defineProperty(_Received_Amount$Payi,"Symbol",'Sembol'),_defineProperty(_Received_Amount$Payi,"All",'Herşey'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Ürünü Düzenle'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Koda göre ara'),_defineProperty(_Received_Amount$Payi,"SearchByName",'İsme Göre Ara'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'Ürün Detayları'),_defineProperty(_Received_Amount$Payi,"CustomerName",'müşteri adı'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Müşteri yönetimi'),_defineProperty(_Received_Amount$Payi,"Add",'Oluşturmak'),_defineProperty(_Received_Amount$Payi,"add",'Oluşturmak'),_defineProperty(_Received_Amount$Payi,"Edit",'Düzenle'),_defineProperty(_Received_Amount$Payi,"Close",'Kapat'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Lütfen seçin'),_defineProperty(_Received_Amount$Payi,"Action",'Aksiyon'),_defineProperty(_Received_Amount$Payi,"Email",'E-posta adresi'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Müşteriyi Düzenle'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Müşteri Yaratın'),_defineProperty(_Received_Amount$Payi,"Country",'Ülke'),_defineProperty(_Received_Amount$Payi,"City",'Kent'),_defineProperty(_Received_Amount$Payi,"Adress",'Adres'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'Müşteri detayları'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Müşteri Listesi'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Tedarikçi Kodu'),_defineProperty(_Received_Amount$Payi,"SupplierName",'sağlayıcı adı'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Tedarikçi Yönetimi'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Tedarikçi Detayları'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Teklif Yönetimi'),_defineProperty(_Received_Amount$Payi,"SubTotal",'ara toplam'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Kalan miktar'),_defineProperty(_Received_Amount$Payi,"complete",'Tamamlandı'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'Bekliyor'),_defineProperty(_Received_Amount$Payi,"Recu",'Alınan'),_defineProperty(_Received_Amount$Payi,"partial",'Kısmi'),_defineProperty(_Received_Amount$Payi,"Retournee",'Dönüş'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Detay Teklifi'),_defineProperty(_Received_Amount$Payi,"EditQuote",'Teklifi Düzenle'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Satış Oluşturun'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'PDF İndir'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'Postayla Gönderilen Teklif'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'Teklifi Sil'),_defineProperty(_Received_Amount$Payi,"AddQuote",'Teklif Oluştur'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Ürünü seç'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Ürün (Kod - İsim)'),_defineProperty(_Received_Amount$Payi,"Price",'Fiyat'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'Stok'),_defineProperty(_Received_Amount$Payi,"Total",'Toplam'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'Birim maliyet'),_defineProperty(_Received_Amount$Payi,"to",'-e'),_defineProperty(_Received_Amount$Payi,"Subject",'Konu'),_defineProperty(_Received_Amount$Payi,"Message",'İleti'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'Müşteriye E-posta Gönder'),_defineProperty(_Received_Amount$Payi,"Sent",'Gönder'),_defineProperty(_Received_Amount$Payi,"Quote",'Teklif'),_defineProperty(_Received_Amount$Payi,"Hello",'Merhaba'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Lütfen Teklifiniz için eki bulun'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Sipariş Listesine Ürün Ekleme'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Lütfen depo seçin'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'lütfen Müşteri Seçiniz'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Satış Yönetimi'),_defineProperty(_Received_Amount$Payi,"Balance",'Denge'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Miktar Geri'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Toplam getiri'),_defineProperty(_Received_Amount$Payi,"Amount",'Miktar'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Satış Detayı'),_defineProperty(_Received_Amount$Payi,"EditSale",'İndirimi Düzenle'),_defineProperty(_Received_Amount$Payi,"AddSale",'Satış Oluşturun'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Ödemeleri Göster'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Ödeme Oluştur'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Ödemeyi Düzenle'),_defineProperty(_Received_Amount$Payi,"EmailSale",'E-postayla Satış Gönder'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Satışı Sil'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Ödeyen'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Ödeme seçimi'),_defineProperty(_Received_Amount$Payi,"Note",'Not'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Ödeme tamamlandı!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Satın Alma Yönetimi'),_defineProperty(_Received_Amount$Payi,"Ordered",'Sipariş verildi'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Satın Almayı Sil'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Satın Almayı postayla gönder'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Satın Almayı Düzenle'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Satın Alma Detayı'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Satın Alma Oluştur'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Tedarikçi E-postası'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Satın alma ödemeleri'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Ödeme verilerini satın alır'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'Satış ödemeleri'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Satış ödemeleri verileri'),_defineProperty(_Received_Amount$Payi,"UserManagement",'kullanıcı yönetimi'),_defineProperty(_Received_Amount$Payi,"Firstname",'İsim'),_defineProperty(_Received_Amount$Payi,"lastname",'Soyadı'),_defineProperty(_Received_Amount$Payi,"username",'Kullanıcı adı'),_defineProperty(_Received_Amount$Payi,"password",'Parola'),_defineProperty(_Received_Amount$Payi,"Newpassword",'Yeni Şifre'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Avatarı değiştir'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Değiştirmediyseniz lütfen bu alanı boş bırakın'),_defineProperty(_Received_Amount$Payi,"type",'tip'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Kullanıcı İzinleri'),_defineProperty(_Received_Amount$Payi,"RoleName",'Rol'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Rol Tanımı'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'İzin Oluşturun'),_defineProperty(_Received_Amount$Payi,"View",'Görünüm'),_defineProperty(_Received_Amount$Payi,"Del",'Sil'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'Yeni Düzenleme'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Ayarı Düzenle'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'Stokta 0 olan ürünleri çıkaramazsınız'),_defineProperty(_Received_Amount$Payi,"Addition",'İlave'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Çıkarma'),_defineProperty(_Received_Amount$Payi,"profil",'profil'),_defineProperty(_Received_Amount$Payi,"logout",'çıkış Yap'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'bu Satın Alma zaten ödendiği için değişiklik yapamazsınız'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'bu Satış zaten ödendiği için değişiklik yapamazsınız'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'bu İade zaten ödendiği için değiştiremezsiniz'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'Bu teklif zaten satış sağladı'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Ürün oluştur'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'Bu Teklif Tamamlandı'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Site yapılandırması'),_defineProperty(_Received_Amount$Payi,"Language",'Dil'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'Varsayılan Para Birimi'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Giriş Captcha'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Varsayılan E-posta'),_defineProperty(_Received_Amount$Payi,"SiteName",'Site adı'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Logoyu Değiştir'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'SMTP Yapılandırması'),_defineProperty(_Received_Amount$Payi,"HOST",'ev sahibi'),_defineProperty(_Received_Amount$Payi,"PORT",'LİMAN'),_defineProperty(_Received_Amount$Payi,"encryption",'Şifreleme'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'SMTP Yapılandırması Yanlış'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Ödeme İadeleri'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'Faturaları döndürür'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'Fatura Verilerini döndürür'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Tüm Kullanıcıların tüm kayıtlarını göster'),_defineProperty(_Received_Amount$Payi,"Discount",'İndirim'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Sipariş Vergisi'),_defineProperty(_Received_Amount$Payi,"Shipping",'Nakliye'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Şirket Adı'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Şirket Telefonu'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'şirket adresi'),_defineProperty(_Received_Amount$Payi,"Code",'Kod'),_defineProperty(_Received_Amount$Payi,"image",'görüntü'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'Barkod yazdır'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'İade Müşterileri'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'İade Tedarikçileri'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'Müşteri Faturasını İade Et'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'İade Tedarikçileri Faturası'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'Veri yok'),_defineProperty(_Received_Amount$Payi,"ProductImage",'Ürün resmi'),_defineProperty(_Received_Amount$Payi,"Barcode",'Barkod'),_defineProperty(_Received_Amount$Payi,"pointofsales",'satış noktaları'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Özel Yükleme'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'Satış Noktası Yönetimi'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Ayarlama'),_defineProperty(_Received_Amount$Payi,"Updat",'Güncelleme'),_defineProperty(_Received_Amount$Payi,"Reset",'Sıfırla'),_defineProperty(_Received_Amount$Payi,"print",'Yazdır'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'E-postayla Ara'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Ürün Seçin'),_defineProperty(_Received_Amount$Payi,"Qty",'Adet'),_defineProperty(_Received_Amount$Payi,"Items",'Öğeler'),_defineProperty(_Received_Amount$Payi,"AmountHT",'Miktar'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'Toplam Tutar'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Lütfen Tedarikçi Seçiniz'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Lütfen Durum Seçiniz'),_defineProperty(_Received_Amount$Payi,"PayeBy",'Ödeyen'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Depo Seçin'),_defineProperty(_Received_Amount$Payi,"payNow",'Şimdi öde'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'Kategori Listesi'),_defineProperty(_Received_Amount$Payi,"Description",'Açıklama'),_defineProperty(_Received_Amount$Payi,"submit",'Sunmak'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'Bu Fatura oluşturulurken bir sorunla karşılaşıldı. Lütfen tekrar deneyin'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'Ödeme ile ilgili bir sorun oluştu. Lütfen tekrar deneyin.'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'Gelir ve Giderler'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'Günlük Satışlar ve Satın Alımlar'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'Ürünlerin Süresi Doldu'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Marka Listesi'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Düzenleme Oluştur'),_defineProperty(_Received_Amount$Payi,"Afewwords",'Bir kaç kelime ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'Kullanıcı Resmi'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Ürünü Güncelle'),_defineProperty(_Received_Amount$Payi,"Brand",'Marka'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Barkod Sembolojisi '),_defineProperty(_Received_Amount$Payi,"ProductCost",'Ürün maliyeti'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Ürün fiyatı'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Birim Ürün'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Vergi Yöntemi'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Çoklu Resim'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Ürünün Çok Varyantı Var'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'Ürün Promosyonludur'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Promosyon Başlangıcı'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Promosyon Sonu'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Promosyon fiyatı'),_defineProperty(_Received_Amount$Payi,"Price",'Fiyat'),_defineProperty(_Received_Amount$Payi,"Cost",'Maliyet'),_defineProperty(_Received_Amount$Payi,"Unit",'Birim'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Ürün Varyantı'),_defineProperty(_Received_Amount$Payi,"Variant",'Varyant'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Birim fiyat'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'İade Müşterisi Oluşturun'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'İade Müşterisini Düzenle'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'İade Tedarikçisi Oluştur'),_defineProperty(_Received_Amount$Payi,"Documentation",'Dokümantasyon'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'İade Tedarikçisini Düzenle'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'Depodan'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'Depoya'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Transferi Düzenle'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Transfer ayrıntıları'),_defineProperty(_Received_Amount$Payi,"Pending",'Bekliyor'),_defineProperty(_Received_Amount$Payi,"Received",'Alınan'),_defineProperty(_Received_Amount$Payi,"Ordered",'Sipariş verildi'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'İzin Yönetimi'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Marka'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Marka imajı'),_defineProperty(_Received_Amount$Payi,"BrandName",'Marka adı'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Marka Tanımı'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Ana ünite'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Birim Yönetimi'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Operasyon Değeri'),_defineProperty(_Received_Amount$Payi,"Operator",'Şebeke'),_defineProperty(_Received_Amount$Payi,"Top5Products",'En İyi Beş Ürün'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'Son beş Satış'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'Ayarlamaları Listele'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Transferleri Listele'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Transfer Oluştur'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Sipariş Yönetimi'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Alıntıları Listele'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Satın Alma İşlemlerini Listele'),_defineProperty(_Received_Amount$Payi,"ListSales",'Satışları Listele'),_defineProperty(_Received_Amount$Payi,"ListReturns",'İade Listesi'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'İnsan yönetimi'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Emin misiniz?',
Text:'Bunu geri alamayacaksın!',
confirmButtonText:'Evet, silin!',
cancelButtonText:'İptal etmek',
Deleted:'Silindi!',
Failed:'Başarısız oldu!',
Therewassomethingwronge:'Yanlış bir şeyler vardı',
CustomerDeleted:'bu Müşteri silindi.',
SupplierDeleted:'bu Tedarikçi silindi.',
QuoteDeleted:'bu Teklif silinmiştir.',
SaleDeleted:'bu Satış silindi.',
PaymentDeleted:'bu Ödeme silindi.',
PurchaseDeleted:'bu Satın Alma silindi.',
ReturnDeleted:'bu İade silindi.',
ProductDeleted:'bu Ürün silinmiştir.',
ClientError:'Bu Müşteri zaten başka bir Operasyona bağlı',
ProviderError:'Bu Tedarikçi zaten diğer Operasyonla bağlantılı',
UserDeleted:'Bu Kullanıcı silinmiştir.',
UnitDeleted:'Bu Birim silindi.',
RoleDeleted:'Bu Rol silindi.',
TaxeDeleted:'Bu Vergi silinmiştir.',
SubCatDeleted:'Bu Alt Kategori silinmiştir.',
CatDeleted:'Bu Kategori silindi.',
WarehouseDeleted:'Bu Depo silindi.',
AlreadyLinked:'bu ürün zaten diğer Operasyon ile bağlantılı',
AdjustDeleted:'Bu Ayar silindi.',
TitleCurrency:'Bu Para Birimi silindi. ',
TitleTransfer:'Transfer başarıyla kaldırıldı',
BackupDeleted:'Yedek başarıyla kaldırıldı',
TitleBrand:'Bu Marka silindi'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleProfile:'Profiliniz başarıyla güncellendi',
TitleAdjust:'Ayar başarıyla güncellendi',
TitleRole:'Rol başarıyla güncellendi',
TitleUnit:'Birim başarıyla güncellendi',
TitleUser:'Kullanıcı başarıyla güncellendi',
TitleCustomer:'Başarıyla Müşteri Güncellemesi',
TitleQuote:'Teklif başarıyla güncellendi',
TitleSale:'Satış başarıyla güncellendi',
TitlePayment:'Ödeme başarıyla güncellendi',
TitlePurchase:'Satın Alma Başarıyla Güncellendi',
TitleReturn:'İade Başarıyla güncellendi',
TitleProduct:'Ürün Güncellemesi başarıyla yapıldı',
TitleSupplier:'Tedarikçi başarıyla güncellendi',
TitleTaxe:'Vergi başarıyla güncellendi',
TitleCat:'Kategori başarıyla güncellendi',
TitleWarhouse:'Depo başarıyla güncellendi',
TitleSetting:'Ayarlar başarıyla güncellendi',
TitleCurrency:'Para Birimi Güncellemesi başarıyla yapıldı',
TitleTransfer:'Transfer başarıyla güncellendi',
TitleBrand:'Bu Marka Oluşturuldu'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'Bu Marka Oluşturuldu',
TitleRole:'Başarıyla Oluşturulan Rol',
TitleUnit:'Birim Başarıyla Oluşturuldu',
TitleUser:'Kullanıcı başarıyla oluşturuldu',
TitleCustomer:'Müşteri başarıyla oluşturuldu',
TitleQuote:'Başarıyla Oluşturulan Teklif',
TitleSale:'Satış başarıyla oluşturuldu',
TitlePayment:'Ödeme başarıyla oluşturuldu',
TitlePurchase:'Başarıyla Oluşturulan Satın Alma',
TitleReturn:'İade Başarıyla Oluşturuldu',
TitleProduct:'Ürün Başarıyla Oluşturuldu',
TitleSupplier:'Tedarikçi Başarıyla Oluşturuldu',
TitleTaxe:'Başarıyla Oluşturulan Vergi',
TitleCat:'Başarıyla Oluşturulan Kategori',
TitleWarhouse:'Depo Başarıyla Oluşturuldu',
TitleAdjust:'Ayar başarıyla oluşturuldu',
TitleCurrency:'Para Birimi Başarıyla Oluşturuldu',
TitleTransfer:'Transfer başarıyla oluşturuldu'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'E-posta başarıyla gönderildi'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'bu satış zaten bir İade ile bağlantılı!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'İade Yönetimi'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'Dönüş Detayı'),_defineProperty(_Received_Amount$Payi,"EditReturn",'İadeyi Düzenle'),_defineProperty(_Received_Amount$Payi,"AddReturn",'İade Oluştur'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'E-postayla İade Gönder'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'İadeyi Sil'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'İade Ek Ücreti'),_defineProperty(_Received_Amount$Payi,"Laivrison",'teslimat'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Satış Seçiniz'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'Kalemi silebilir veya iade edilmezse iade edilen miktarı sıfıra ayarlayabilirsiniz.'),_defineProperty(_Received_Amount$Payi,"Return",'Dönüş'),_defineProperty(_Received_Amount$Payi,"Purchase",'Satın alma'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Toplam satış'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Toplam Satın Alma'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Toplam İade'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Net Ödemeler'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Gönderilen Ödemeler'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Ödemeler alındı'),_defineProperty(_Received_Amount$Payi,"Recieved",'Alınan'),_defineProperty(_Received_Amount$Payi,"Sent",'Gönderildi'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Ürün Miktarı Uyarıları'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Kod'),_defineProperty(_Received_Amount$Payi,"ProductName",'Ürün'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Uyarı Miktarı'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Depo Stok Tablosu'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Toplam Ürünler'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Toplam miktar'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'İlk beş Müşteri'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Toplam tutar'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Toplam Ödenen'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Müşteri Satış Raporu'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Müşteri Ödemeleri Raporu'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'Müşteri Teklifleri Raporu'),_defineProperty(_Received_Amount$Payi,"Payments",'Ödemeler'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'İlk beş Tedarikçi'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Tedarikçi Satın Alma Raporu'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Tedarikçi Ödemeleri Raporu'),_defineProperty(_Received_Amount$Payi,"Name",'İsim'),_defineProperty(_Received_Amount$Payi,"Code",'Kod'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Depo yönetimi'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Posta kodu'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Kategori yönetimi'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Kod kategorisi'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'İsim kategorisi'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Aile kategorisi'),_defineProperty(_Received_Amount$Payi,"managementTax",'Vergi yönetimi'),_defineProperty(_Received_Amount$Payi,"TaxName",'Vergi Adı'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Vergi oranı'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Satın Alma Birimi'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Satış Birimi'),_defineProperty(_Received_Amount$Payi,"ShortName",'Kısa isim'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Lütfen herhangi bir ürün eklemeden önce Bunları seçin'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Stok Ayarı'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Lütfen herhangi bir ürün seçmeden önce depoyu seçin'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Stok Transferi'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Dönem Seçin'),_defineProperty(_Received_Amount$Payi,"ThisYear",'Bu yıl'),_defineProperty(_Received_Amount$Payi,"ThisToday",'Bu Bugün'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'Bu ay'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'Bu hafta'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Ayar Detayı'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'Bu Kullanıcı Etkinleştirildi'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'Bu Kullanıcı Devre Dışı Bırakıldı'),_defineProperty(_Received_Amount$Payi,"NotFound",'Sayfa bulunamadı.'),_defineProperty(_Received_Amount$Payi,"oops",'hata! Sayfa bulunamadı.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'Aradığınız sayfayı bulamadık.'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'kontrol paneline dön'),_Received_Amount$Payi);

/***/},

/***/"./resources/src/translations/locales/vn.js":
/*!**************************************************!*\
  !*** ./resources/src/translations/locales/vn.js ***!
  \**************************************************/
/*! exports provided: default */
/***/function resourcesSrcTranslationsLocalesVnJs(module,__webpack_exports__,__webpack_require__){
__webpack_require__.r(__webpack_exports__);
var _Received_Amount$Payi;

function _defineProperty(obj,key,value){if(key in obj){Object.defineProperty(obj,key,{value:value,enumerable:true,configurable:true,writable:true});}else {obj[key]=value;}return obj;}

//Language Vietnamien
/* harmony default export */__webpack_exports__["default"]=(_Received_Amount$Payi={
Received_Amount:'Số tiền đã nhận',
Paying_Amount:'Số tiền thanh toán',
Change:'Biến đổi',
Paying_amount_is_greater_than_Received_amount:'Số tiền thanh toán lớn hơn số tiền đã nhận',
Paying_amount_is_greater_than_Grand_Total:'Số tiền thanh toán lớn hơn Tổng số tiền',
code_must_be_not_exist_already:'mã phải không tồn tại rồi',
You_will_find_your_backup_on:'Bạn sẽ tìm thấy bản sao lưu của mình trên',
and_save_it_to_your_pc:'và lưu nó vào máy tính của bạn',
Scan_your_barcode_and_select_the_correct_symbology_below:'Quét mã vạch của bạn và chọn mã ký hiệu chính xác bên dưới',
Scan_Search_Product_by_Code_Name:'Quét / Tìm kiếm sản phẩm theo tên mã',
Paper_size:'Khổ giấy',
Clear_Cache:'Xóa bộ nhớ cache',
Cache_cleared_successfully:'Đã xóa bộ nhớ cache thành công',
Failed_to_clear_cache:'Không xóa được bộ nhớ cache',
Scan_Barcode:'Máy quét mã vạch',
Please_use_short_name_of_unit:'Vui lòng sử dụng tên ngắn của đơn vị',
DefaultCustomer:'Khách hàng mặc định',
DefaultWarehouse:'Kho mặc định',
Payment_Gateway:'Cổng thanh toán',
SMS_Configuration:'Cấu hình SMS',
Gateway:'Cổng thanh toán',
Choose_Gateway:'Chọn Cổng thanh toán',
Send_SMS:'Đã gửi tin nhắn thành công',
sms_config_invalid:'sai cấu hình sms không hợp lệ',
Remove_Stripe_Key_Secret:'Xóa các khóa API sọc',
credit_card_account_not_available:'Tài khoản thẻ tín dụng không khả dụng',
Credit_Card_Info:'Thông tin thẻ tín dụng',
developed_by:'Được phát triển bởi',
Unit_already_linked_with_sub_unit:'Đơn vị đã được liên kết với đơn vị phụ',
Total_Items_Quantity:'Tổng số mặt hàng và số lượng',
Value_by_Cost_and_Price:'Giá trị theo Chi phí và Giá cả',
Search_this_table:'Tìm kiếm bảng này',
import_products:'Nhập sản phẩm',
Field_optional:'Trường tùy chọn',
Download_exemple:'Tải xuống ví dụ',
field_must_be_in_csv_format:'Trường phải ở định dạng csv',
Successfully_Imported:'Đã nhập thành công',
file_size_must_be_less_than_1_mega:'Kích thước tệp phải nhỏ hơn 1 mega',
Please_follow_the_import_instructions:'Vui lòng làm theo hướng dẫn nhập',
must_be_exist:'đơn vị phải được tạo',
Import_Customers:'Nhập khách hàng',
Import_Suppliers:'Các nhà cung cấp nhập khẩu',
Recent_Sales:'Bán hàng gần đây',
Create_Transfer:'Tạo chuyển khoản',
order_products:'đặt hàng',
Search_Product_by_Code_Name:'Tìm kiếm sản phẩm theo mã hoặc tên',
Reports_payments_Purchase_Return:'Báo cáo Mua hàng Trả lại Thanh toán',
Reports_payments_Sale_Return:'Báo cáo các khoản thanh toán trả lại hàng bán',
payments_Sales_Return:'thanh toán bán hàng trả lại',
payments_Purchases_Return:'thanh toán mua hàng trả lại',
CreateSaleReturn:'Tạo lợi nhuận bán hàng',
EditSaleReturn:'Chỉnh sửa lợi nhuận bán hàng',
SalesReturn:'Lợi nhuận bán hàng',
CreatePurchaseReturn:'Tạo lợi tức mua hàng',
EditPurchaseReturn:'Chỉnh sửa lợi tức mua hàng',
PurchasesReturn:'Mua hàng trả lại',
Due:'đến hạn',
Profit:'Lợi nhuận',
Revenue:'Doanh thu',
Sales_today:'Bán hàng hôm nay',
People:'Mọi người',
Successfully_Created:'Thành công trong việc tạo ra',
Successfully_Updated:'Cập nhật thành công',
Success:'Sự thành công',
Failed:'Thất bại',
Warning:'Cảnh báo',
Please_fill_the_form_correctly:'Vui lòng điền vào biểu mẫu một cách chính xác',
Field_is_required:'Lĩnh vực được yêu cầu',
Error:'lỗi!',
you_are_not_authorized:'Lấy làm tiếc! Bạn không được ủy quyền.',
Go_back_to_home:'Quay lại trang chủ',
page_not_exist:'Lấy làm tiếc! Trang bạn đang tìm kiếm không tồn tại.',
Choose_Status:'Chọn trạng thái',
Choose_Method:'Chọn phương pháp',
Choose_Symbology:'Chọn ký hiệu',
Choose_Category:'Chọn danh mục',
Choose_Customer:'Chọn khách hàng',
Choose_Supplier:'Chọn nhà cung cấp',
Choose_Unit_Purchase:'Chọn đơn vị mua hàng',
Choose_Sub_Category:'Chọn Danh mục con',
Choose_Brand:'Chọn thương hiệu',
Choose_Warehouse:'Chọn nhà kho',
Choose_Unit_Sale:'Chọn đơn vị bán hàng',
Enter_Product_Cost:'Nhập giá thành sản phẩm',
Enter_Stock_alert:'Nhập cảnh báo còn hàng',
Choose_Unit_Product:'Chọn đơn vị sản phẩm',
Enter_Product_Price:'Nhập giá sản phẩm',
Enter_Name_Product:'Nhập Tên Sản phẩm',
Enter_Role_Name:'Nhập tên vai trò',
Enter_Role_Description:'Nhập mô tả vai trò',
Enter_name_category:'Nhập tên danh mục',
Enter_Code_category:'Nhập mã danh mục',
Enter_Name_Brand:'Nhập tên thương hiệu',
Enter_Description_Brand:'Nhập nhãn hiệu mô tả',
Enter_Code_Currency:'Nhập tiền tệ mã',
Enter_name_Currency:'Nhập tên Đơn vị tiền tệ',
Enter_Symbol_Currency:'Nhập tiền tệ ký hiệu',
Enter_Name_Unit:'Nhập tên đơn vị',
Enter_ShortName_Unit:'Nhập tên viết tắt Đơn vị',
Choose_Base_Unit:'Chọn đơn vị cơ sở',
Choose_Operator:'Chọn nhà điều hành',
Enter_Operation_Value:'Nhập giá trị hoạt động',
Enter_Name_Warehouse:'Nhập tên kho',
Enter_Phone_Warehouse:'Nhập số điện thoại kho hàng',
Enter_Country_Warehouse:'Nhập quốc gia kho hàng',
Enter_City_Warehouse:'Nhập thành phố kho hàng',
Enter_Email_Warehouse:'Nhập Email Kho hàng',
Enter_ZipCode_Warehouse:'Nhập mã Zip kho hàng',
Choose_Currency:'Chọn tiền tệ',
Thank_you_for_your_business:'Cảm ơn bạn cho doanh nghiệp của bạn!',
Cancel:'Huỷ bỏ',
New_Customer:'Khách hàng mới',
Incorrect_Login:'Đăng nhập không chính xác',
Successfully_Logged_In:'Đã đăng nhập thành công',
This_user_not_active:'Người dùng này không hoạt động',
SignIn:'Đăng nhập',
Create_an_account:'Tạo một tài khoản',
Forgot_Password:'Quên mật khẩu ?',
Email_Address:'Địa chỉ email',
SignUp:'Đăng ký',
Already_have_an_account:'Bạn co săn san để tạo một tai khoản ?',
Reset_Password:'Đặt lại mật khẩu',
Failed_to_authenticate_on_SMTP_server:'Không xác thực được trên máy chủ SMTP',
We_cant_find_a_user_with_that_email_addres:'Chúng tôi không thể tìm thấy người dùng có địa chỉ email đó',
We_have_emailed_your_password_reset_link:'Chúng tôi đã gửi qua e-mail liên kết đặt lại mật khẩu của bạn',
Please_fill_the_Email_Adress:'Vui lòng điền vào Địa chỉ Email',
Confirm_password:'Xác nhận mật khẩu',
Your_Password_has_been_changed:'Mật khẩu của bạn đã được thay đổi',
The_password_confirmation_does_not_match:'Xác nhận mật khẩu không khớp',
This_password_reset_token_is_invalid:'Mã thông báo đặt lại mật khẩu này không hợp lệ',
Warehouse_report:'Báo cáo kho hàng',
All_Warehouses:'Tất cả các kho hàng',
Expense_List:'Danh sách chi phí',
Expenses:'Chi phí',
This_Week_Sales_Purchases:'Bán hàng và mua hàng trong tuần này',
Top_Selling_Products:'Sản phẩm bán chạy nhất',
View_all:'Xem tất cả',
Payment_Sent_Received:'Thanh toán đã Gửi và Nhận',
Filter:'Bộ lọc',
Invoice_POS:'POS xuất hóa đơn',
Invoice:'Hóa đơn',
Customer_Info:'thông tin khách hàng',
Company_Info:'Thông tin công ty',
Invoice_Info:'Thông tin hóa đơn',
Order_Summary:'Tóm tắt theo thứ tự',
Quote_Info:'Thông tin báo giá',
Del:'Xóa bỏ',
SuppliersPaiementsReport:'Báo cáo thanh toán cho nhà cung cấp',
Purchase_Info:'Thông tin mua hàng',
Supplier_Info:'Thông tin nhà cung cấp',
Return_Info:'thông tin về sự trở lại',
Expense_Category:'Hạng mục Chi phí',
Create_Expense:'Tạo chi phí',
Details:'Chi tiết',
Discount_Method:'Phương thức chiết khấu',
Net_Unit_Cost:'Đơn giá ròng',
Net_Unit_Price:'Đơn giá ròng',
Edit_Expense:'Chỉnh sửa chi phí',
All_Brand:'Tất cả thương hiệu',
All_Category:'Tất cả các loại',
ListExpenses:'Liệt kê chi phí',
Create_Permission:'Tạo quyền',
Edit_Permission:'Chỉnh sửa quyền',
Reports_payments_Sales:'Báo cáo thanh toán Bán hàng',
Reports_payments_Purchases:'Báo cáo thanh toán Mua hàng',
Reports_payments_Return_Customers:'Báo cáo thanh toán Khách hàng trả lại',
Reports_payments_Return_Suppliers:'Báo cáo thanh toán Trả lại nhà cung cấp',
Expense_Deleted:'Chi phí này đã bị xóa',
Expense_Updated:'Chi phí này đã được cập nhật',
Expense_Created:'Chi phí này đã được tạo',
DemoVersion:'Bạn không thể làm điều này trong phiên bản demo',
OrderStatistics:'Thống kê bán hàng',
AlreadyAdd:'Sản phẩm này đã được thêm vào !!',
AddProductToList:'Vui lòng thêm sản phẩm vào danh sách !!',
AddQuantity:'Vui lòng thêm số lượng Chi tiết !!',
InvalidData:'Dữ liệu không hợp lệ !!',
LowStock:'số lượng vượt quá số lượng có sẵn trong kho',
WarehouseIdentical:'Hai kho không thể giống hệt nhau !!',
VariantDuplicate:'Biến thể này là trùng lặp !!',
Filesize:'Kích thước tập tin',
GenerateBackup:'Tạo bản sao lưu',
BackupDatabase:'Cơ sở dữ liệu sao lưu',
Backup:'Sao lưu',
Paid:'Đã thanh toán',
Unpaid:'Chưa thanh toán',
Today:'Hôm nay',
Income:'Thu nhập'},
_defineProperty(_Received_Amount$Payi,"Expenses",'Chi phí'),_defineProperty(_Received_Amount$Payi,"Sale",'Giảm giá'),_defineProperty(_Received_Amount$Payi,"Actif",'Hoạt động'),_defineProperty(_Received_Amount$Payi,"Inactif",'Không hoạt động'),_defineProperty(_Received_Amount$Payi,"Customers",'Khách hàng'),_defineProperty(_Received_Amount$Payi,"Phone",'Điện thoại'),_defineProperty(_Received_Amount$Payi,"SearchByPhone",'Tìm kiếm bằng điện thoại'),_defineProperty(_Received_Amount$Payi,"Suppliers",'Các nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"Quotations",'Báo giá'),_defineProperty(_Received_Amount$Payi,"Sales",'Bán hàng'),_defineProperty(_Received_Amount$Payi,"Purchases",'Mua hàng'),_defineProperty(_Received_Amount$Payi,"Returns",'Lợi nhuận'),_defineProperty(_Received_Amount$Payi,"Settings",'Cài đặt'),_defineProperty(_Received_Amount$Payi,"SystemSettings",'Cài đặt hệ thống'),_defineProperty(_Received_Amount$Payi,"Users",'Người dùng'),_defineProperty(_Received_Amount$Payi,"GroupPermissions",'Quyền nhóm'),_defineProperty(_Received_Amount$Payi,"Currencies",'Tiền tệ'),_defineProperty(_Received_Amount$Payi,"Warehouses",'Nhà kho'),_defineProperty(_Received_Amount$Payi,"Units",'Các đơn vị'),_defineProperty(_Received_Amount$Payi,"UnitsPrchases",'Đơn vị mua hàng'),_defineProperty(_Received_Amount$Payi,"UnitsSales",'Đơn vị bán hàng'),_defineProperty(_Received_Amount$Payi,"Reports",'Báo cáo'),_defineProperty(_Received_Amount$Payi,"PaymentsReport",'Báo cáo thanh toán'),_defineProperty(_Received_Amount$Payi,"PaymentsPurchases",'Thanh toán Mua hàng'),_defineProperty(_Received_Amount$Payi,"PaymentsSales",'Thanh toán Bán hàng'),_defineProperty(_Received_Amount$Payi,"ProfitandLoss",'Lợi nhuận và thua lỗ'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Biểu đồ kho hàng'),_defineProperty(_Received_Amount$Payi,"SalesReport",'Báo cáo bán hàng'),_defineProperty(_Received_Amount$Payi,"PurchasesReport",'Báo cáo mua hàng'),_defineProperty(_Received_Amount$Payi,"CustomersReport",'Báo cáo khách hàng'),_defineProperty(_Received_Amount$Payi,"SuppliersReport",'Báo cáo nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"SupplierReport",'Báo cáo nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"DailySalesData",'Dữ liệu bán hàng hàng ngày'),_defineProperty(_Received_Amount$Payi,"DailyPurchasesData",'Daily Purchases Data'),_defineProperty(_Received_Amount$Payi,"Derni\xE8rescinqrecords",'Năm bản ghi cuối cùng'),_defineProperty(_Received_Amount$Payi,"Filters",'Bộ lọc'),_defineProperty(_Received_Amount$Payi,"date",'ngày'),_defineProperty(_Received_Amount$Payi,"Reference",'Tài liệu tham khảo'),_defineProperty(_Received_Amount$Payi,"Supplier",'Nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"PaymentStatus",'Tình trạng thanh toán'),_defineProperty(_Received_Amount$Payi,"Customer",'khách hàng'),_defineProperty(_Received_Amount$Payi,"CustomerCode",'Mã khách hàng'),_defineProperty(_Received_Amount$Payi,"Status",'Trạng thái'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Mã nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"Categorie",'thể loại'),_defineProperty(_Received_Amount$Payi,"Categories",'Thể loại'),_defineProperty(_Received_Amount$Payi,"StockTransfers",'Chuyển kho'),_defineProperty(_Received_Amount$Payi,"StockManagement",'Quản lý chứng khoán'),_defineProperty(_Received_Amount$Payi,"dashboard",'bảng điều khiển'),_defineProperty(_Received_Amount$Payi,"Products",'Các sản phẩm'),_defineProperty(_Received_Amount$Payi,"productsList",'danh sách sản phẩm'),_defineProperty(_Received_Amount$Payi,"ProductManagement",'Quản lý sản phẩm'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Cảnh báo số lượng sản phẩm'),_defineProperty(_Received_Amount$Payi,"CodeProduct",'Mã sản phẩm'),_defineProperty(_Received_Amount$Payi,"ProductTax",'Thuế sản phẩm'),_defineProperty(_Received_Amount$Payi,"SubCategorie",'Danh mục con'),_defineProperty(_Received_Amount$Payi,"Name_product",'Chỉ định'),_defineProperty(_Received_Amount$Payi,"StockAlert",'Cảnh báo hàng tồn kho'),_defineProperty(_Received_Amount$Payi,"warehouse",'Kho'),_defineProperty(_Received_Amount$Payi,"Tax",'Thuế'),_defineProperty(_Received_Amount$Payi,"BuyingPrice",'Giá mua'),_defineProperty(_Received_Amount$Payi,"SellPrice",'Giá bán'),_defineProperty(_Received_Amount$Payi,"Quantity",'Định lượng'),_defineProperty(_Received_Amount$Payi,"UnitSale",'Bán đơn vị'),_defineProperty(_Received_Amount$Payi,"UnitPurchase",'Mua đơn vị'),_defineProperty(_Received_Amount$Payi,"ManagementCurrencies",'Quản lý tiền tệ'),_defineProperty(_Received_Amount$Payi,"CurrencyCode",'Mã tiền tệ'),_defineProperty(_Received_Amount$Payi,"CurrencyName",'Tên tiền tệ'),_defineProperty(_Received_Amount$Payi,"Symbol",'Biểu tượng'),_defineProperty(_Received_Amount$Payi,"All",'Tất cả'),_defineProperty(_Received_Amount$Payi,"EditProduct",'Chỉnh sửa sản phẩm'),_defineProperty(_Received_Amount$Payi,"SearchByCode",'Tìm kiếm theo mã'),_defineProperty(_Received_Amount$Payi,"SearchByName",'Tìm kiếm theo tên'),_defineProperty(_Received_Amount$Payi,"ProductDetails",'Thông tin chi tiết sản phẩm'),_defineProperty(_Received_Amount$Payi,"CustomerName",'tên khách hàng'),_defineProperty(_Received_Amount$Payi,"CustomerManagement",'Quản lý khách hàng'),_defineProperty(_Received_Amount$Payi,"Add",'Tạo nên'),_defineProperty(_Received_Amount$Payi,"add",'Tạo nên'),_defineProperty(_Received_Amount$Payi,"Edit",'Biên tập'),_defineProperty(_Received_Amount$Payi,"Close",'Đóng'),_defineProperty(_Received_Amount$Payi,"PleaseSelect",'Vui lòng chọn'),_defineProperty(_Received_Amount$Payi,"Action",'Hoạt động'),_defineProperty(_Received_Amount$Payi,"Email",'thư'),_defineProperty(_Received_Amount$Payi,"EditCustomer",'Chỉnh sửa khách hàng'),_defineProperty(_Received_Amount$Payi,"AddCustomer",'Tạo khách hàng'),_defineProperty(_Received_Amount$Payi,"Country",'Quốc gia'),_defineProperty(_Received_Amount$Payi,"City",'Tp.'),_defineProperty(_Received_Amount$Payi,"Adress",'Địa chỉ'),_defineProperty(_Received_Amount$Payi,"CustomerDetails",'Chi tiết khách hàng'),_defineProperty(_Received_Amount$Payi,"CustomersList",'Danh sách khách hàng'),_defineProperty(_Received_Amount$Payi,"SupplierCode",'Mã nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"SupplierName",'tên đệm'),_defineProperty(_Received_Amount$Payi,"SuppliersManagement",'Quản lý nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"SupplierDetails",'Thông tin chi tiết về nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"QuotationsManagement",'Quản lý Báo giá'),_defineProperty(_Received_Amount$Payi,"SubTotal",'Tổng phụ'),_defineProperty(_Received_Amount$Payi,"MontantReste",'Số tiền còn lại'),_defineProperty(_Received_Amount$Payi,"complete",'hoàn thành'),_defineProperty(_Received_Amount$Payi,"EnAttendant",'đang chờ xử lý'),_defineProperty(_Received_Amount$Payi,"Recu",'Nhận'),_defineProperty(_Received_Amount$Payi,"partial",'Một phần'),_defineProperty(_Received_Amount$Payi,"Retournee",'Trở về'),_defineProperty(_Received_Amount$Payi,"DetailQuote",'Báo giá chi tiết'),_defineProperty(_Received_Amount$Payi,"EditQuote",'Chỉnh sửa Báo giá'),_defineProperty(_Received_Amount$Payi,"CreateSale",'Tạo bán hàng'),_defineProperty(_Received_Amount$Payi,"DownloadPdf",'Tải PDF'),_defineProperty(_Received_Amount$Payi,"QuoteEmail",'Báo giá đã gửi qua thư'),_defineProperty(_Received_Amount$Payi,"DeleteQuote",'Xóa báo giá'),_defineProperty(_Received_Amount$Payi,"AddQuote",'Tạo Báo giá'),_defineProperty(_Received_Amount$Payi,"SelectProduct",'Chọn sản phẩm'),_defineProperty(_Received_Amount$Payi,"ProductCodeName",'Product (Code - Name)'),_defineProperty(_Received_Amount$Payi,"Price",'Giá bán'),_defineProperty(_Received_Amount$Payi,"CurrentStock",'cổ phần'),_defineProperty(_Received_Amount$Payi,"Total",'Toàn bộ'),_defineProperty(_Received_Amount$Payi,"Num",'N°'),_defineProperty(_Received_Amount$Payi,"Unitcost",'Đơn giá'),_defineProperty(_Received_Amount$Payi,"to",'đến'),_defineProperty(_Received_Amount$Payi,"Subject",'Môn học'),_defineProperty(_Received_Amount$Payi,"Message",'Thông điệp'),_defineProperty(_Received_Amount$Payi,"EmailCustomer",'Gửi email cho khách hàng'),_defineProperty(_Received_Amount$Payi,"Sent",'Gửi'),_defineProperty(_Received_Amount$Payi,"Quote",'Bảng báo giá'),_defineProperty(_Received_Amount$Payi,"Hello",'xin chào'),_defineProperty(_Received_Amount$Payi,"AttachmentQuote",'Vui lòng tìm tệp đính kèm cho Báo giá của bạn'),_defineProperty(_Received_Amount$Payi,"AddProducts",'Thêm sản phẩm vào danh sách đặt hàng'),_defineProperty(_Received_Amount$Payi,"SelectWarehouse",'Vui lòng chọn kho'),_defineProperty(_Received_Amount$Payi,"SelectCustomer",'vui lòng chọn khách hàng'),_defineProperty(_Received_Amount$Payi,"SalesManagement",'Quản lý bán hàng'),_defineProperty(_Received_Amount$Payi,"Balance",'Thăng bằng'),_defineProperty(_Received_Amount$Payi,"QtyBack",'Số lượng trở lại'),_defineProperty(_Received_Amount$Payi,"TotalReturn",'Bắt đầu lại từ đầu'),_defineProperty(_Received_Amount$Payi,"Amount",'Số tiền'),_defineProperty(_Received_Amount$Payi,"SaleDetail",'Chi tiết giảm giá'),_defineProperty(_Received_Amount$Payi,"EditSale",'Chỉnh sửa giảm giá'),_defineProperty(_Received_Amount$Payi,"AddSale",'Tạo bán hàng'),_defineProperty(_Received_Amount$Payi,"ShowPayment",'Hiển thị các khoản thanh toán'),_defineProperty(_Received_Amount$Payi,"AddPayment",'Tạo thanh toán'),_defineProperty(_Received_Amount$Payi,"EditPayment",'Chỉnh sửa Thanh toán'),_defineProperty(_Received_Amount$Payi,"EmailSale",'Send Sale in Email'),_defineProperty(_Received_Amount$Payi,"DeleteSale",'Xóa giảm giá'),_defineProperty(_Received_Amount$Payi,"ModePaiement",'Được trả bởi'),_defineProperty(_Received_Amount$Payi,"Paymentchoice",'Lựa chọn thanh toán'),_defineProperty(_Received_Amount$Payi,"Note",'Ghi chú'),_defineProperty(_Received_Amount$Payi,"PaymentComplete",'Hoàn tất thanh toán!'),_defineProperty(_Received_Amount$Payi,"PurchasesManagement",'Quản lý mua hàng'),_defineProperty(_Received_Amount$Payi,"Ordered",'Đã đặt hàng'),_defineProperty(_Received_Amount$Payi,"DeletePurchase",'Xóa giao dịch mua'),_defineProperty(_Received_Amount$Payi,"EmailPurchase",'Gửi đơn mua hàng qua thư'),_defineProperty(_Received_Amount$Payi,"EditPurchase",'Chỉnh sửa giao dịch mua'),_defineProperty(_Received_Amount$Payi,"PurchaseDetail",'Chi tiết Mua hàng'),_defineProperty(_Received_Amount$Payi,"AddPurchase",'Tạo giao dịch mua'),_defineProperty(_Received_Amount$Payi,"EmailSupplier",'Thư nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"PurchaseInvoice",'Thanh toán mua hàng'),_defineProperty(_Received_Amount$Payi,"PurchasesInvoicesData",'Mua dữ liệu thanh toán'),_defineProperty(_Received_Amount$Payi,"SalesInvoice",'Thanh toán bán hàng'),_defineProperty(_Received_Amount$Payi,"SalesInvoicesData",'Dữ liệu thanh toán bán hàng'),_defineProperty(_Received_Amount$Payi,"UserManagement",'quản lý người dùng'),_defineProperty(_Received_Amount$Payi,"Firstname",'Tên đầu tiên'),_defineProperty(_Received_Amount$Payi,"lastname",'họ'),_defineProperty(_Received_Amount$Payi,"username",'tên tài khoản'),_defineProperty(_Received_Amount$Payi,"password",'Mật khẩu'),_defineProperty(_Received_Amount$Payi,"Newpassword",'Mật khẩu mới'),_defineProperty(_Received_Amount$Payi,"ChangeAvatar",'Thay đổi hình đại diện'),_defineProperty(_Received_Amount$Payi,"LeaveBlank",'Vui lòng để trống trường này nếu bạn chưa thay đổi'),_defineProperty(_Received_Amount$Payi,"type",'kiểu'),_defineProperty(_Received_Amount$Payi,"UserPermissions",'Quyền của người dùng'),_defineProperty(_Received_Amount$Payi,"RoleName",'Vai trò'),_defineProperty(_Received_Amount$Payi,"RoleDescription",'Mô tả vai trò'),_defineProperty(_Received_Amount$Payi,"AddPermissions",'Tạo quyền'),_defineProperty(_Received_Amount$Payi,"View",'Lượt xem'),_defineProperty(_Received_Amount$Payi,"Del",'Xóa bỏ'),_defineProperty(_Received_Amount$Payi,"NewAdjustement",'Điều chỉnh mới'),_defineProperty(_Received_Amount$Payi,"EditAdjustement",'Chỉnh sửa điều chỉnh'),_defineProperty(_Received_Amount$Payi,"CannotSubstraction",'Bạn không thể trừ các sản phẩm có hàng 0'),_defineProperty(_Received_Amount$Payi,"Addition",'Thêm vào'),_defineProperty(_Received_Amount$Payi,"Subtraction",'Phép trừ'),_defineProperty(_Received_Amount$Payi,"profil",'hồ sơ'),_defineProperty(_Received_Amount$Payi,"logout",'đăng xuất'),_defineProperty(_Received_Amount$Payi,"PurchaseAlreadyPaid",'bạn không thể sửa đổi vì Giao dịch mua này đã được thanh toán'),_defineProperty(_Received_Amount$Payi,"SaleAlreadyPaid",'bạn không thể sửa đổi vì Giảm giá này đã được thanh toán'),_defineProperty(_Received_Amount$Payi,"ReturnAlreadyPaid",'bạn không thể sửa đổi vì lợi nhuận này đã được thanh toán'),_defineProperty(_Received_Amount$Payi,"QuoteAlready",'Báo giá này đã tạo ra doanh số bán hàng'),_defineProperty(_Received_Amount$Payi,"AddProduct",'Tạo sản phẩm'),_defineProperty(_Received_Amount$Payi,"QuotationComplete",'Báo giá này hoàn thành'),_defineProperty(_Received_Amount$Payi,"SiteConfiguration",'Cấu hình trang web'),_defineProperty(_Received_Amount$Payi,"Language",'Ngôn ngữ'),_defineProperty(_Received_Amount$Payi,"DefaultCurrency",'mặc định ngoại tệ'),_defineProperty(_Received_Amount$Payi,"LoginCaptcha",'Captcha đăng nhập'),_defineProperty(_Received_Amount$Payi,"DefaultEmail",'Thư mặc định'),_defineProperty(_Received_Amount$Payi,"SiteName",'Tên trang web'),_defineProperty(_Received_Amount$Payi,"ChangeLogo",'Thay đổi biểu trưng'),_defineProperty(_Received_Amount$Payi,"SMTPConfiguration",'Cấu hình SMTP'),_defineProperty(_Received_Amount$Payi,"HOST",'TỔ CHỨC'),_defineProperty(_Received_Amount$Payi,"PORT",'HẢI CẢNG'),_defineProperty(_Received_Amount$Payi,"encryption",'Mã hóa'),_defineProperty(_Received_Amount$Payi,"SMTPIncorrect",'Cấu hình SMTP không chính xác'),_defineProperty(_Received_Amount$Payi,"PaymentsReturns",'Thanh toán Lợi nhuận'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoices",'Trả lại hóa đơn'),_defineProperty(_Received_Amount$Payi,"ReturnsInvoicesData",'Trả về dữ liệu hóa đơn'),_defineProperty(_Received_Amount$Payi,"ShowAll",'Hiển thị tất cả hồ sơ của tất cả Người dùng'),_defineProperty(_Received_Amount$Payi,"Discount",'Giảm giá'),_defineProperty(_Received_Amount$Payi,"OrderTax",'Thuế đặt hàng'),_defineProperty(_Received_Amount$Payi,"Shipping",'Đang chuyển hàng'),_defineProperty(_Received_Amount$Payi,"CompanyName",'Tên công ty'),_defineProperty(_Received_Amount$Payi,"CompanyPhone",'Điện thoại công ty'),_defineProperty(_Received_Amount$Payi,"CompanyAdress",'địa chỉ công ty'),_defineProperty(_Received_Amount$Payi,"Code",'Mã'),_defineProperty(_Received_Amount$Payi,"image",'hình ảnh'),_defineProperty(_Received_Amount$Payi,"Printbarcode",'In mã vạch'),_defineProperty(_Received_Amount$Payi,"ReturnsCustomers",'Trả lại khách hàng'),_defineProperty(_Received_Amount$Payi,"ReturnsSuppliers",'Trả lại nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"FactureReturnCustomers",'Khách hàng trả lại hóa đơn'),_defineProperty(_Received_Amount$Payi,"FactureReturnSuppliers",'Trả lại hóa đơn cho nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"NodataAvailable",'Không có dữ liệu'),_defineProperty(_Received_Amount$Payi,"ProductImage",'Hình ảnh sản phẩm'),_defineProperty(_Received_Amount$Payi,"Barcode",'Mã vạch'),_defineProperty(_Received_Amount$Payi,"pointofsales",'điểm ban hang'),_defineProperty(_Received_Amount$Payi,"CustomUpload",'Tải lên tùy chỉnh'),_defineProperty(_Received_Amount$Payi,"pointofsaleManagement",'quản lý điểm bán hàng'),_defineProperty(_Received_Amount$Payi,"Adjustment",'Điều chỉnh'),_defineProperty(_Received_Amount$Payi,"Updat",'Cập nhật'),_defineProperty(_Received_Amount$Payi,"Reset",'Cài lại'),_defineProperty(_Received_Amount$Payi,"print",'In'),_defineProperty(_Received_Amount$Payi,"SearchByEmail",'Tìm kiếm bằng Email'),_defineProperty(_Received_Amount$Payi,"ChooseProduct",'Chọn sản phẩm'),_defineProperty(_Received_Amount$Payi,"Qty",'Định lượng'),_defineProperty(_Received_Amount$Payi,"Items",'Mặt hàng'),_defineProperty(_Received_Amount$Payi,"AmountHT",'Số tiền'),_defineProperty(_Received_Amount$Payi,"AmountTTC",'Tổng số tiền'),_defineProperty(_Received_Amount$Payi,"PleaseSelectSupplier",'Vui lòng chọn nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"PleaseSelectStatut",'Vui lòng chọn trạng thái'),_defineProperty(_Received_Amount$Payi,"PayeBy",'Được trả bởi'),_defineProperty(_Received_Amount$Payi,"ChooseWarehouse",'Chọn nhà kho'),_defineProperty(_Received_Amount$Payi,"payNow",'Trả tiền ngay'),_defineProperty(_Received_Amount$Payi,"ListofCategory",'Danh sách thể loại'),_defineProperty(_Received_Amount$Payi,"Description",'Sự miêu tả'),_defineProperty(_Received_Amount$Payi,"submit",'Gửi đi'),_defineProperty(_Received_Amount$Payi,"ProblemCreatingThisInvoice",'Đã xảy ra sự cố khi tạo Hóa đơn này. Vui lòng thử lại'),_defineProperty(_Received_Amount$Payi,"ProblemPayment",'Đã xảy ra sự cố Thanh toán. Vui lòng thử lại.'),_defineProperty(_Received_Amount$Payi,"IncomeExpenses",'Chi phí thu nhập'),_defineProperty(_Received_Amount$Payi,"dailySalesPurchases",'Bán hàng và mua hàng ngày'),_defineProperty(_Received_Amount$Payi,"ProductsExpired",'Sản phẩm đã hết hạn'),_defineProperty(_Received_Amount$Payi,"ListofBrand",'Liệt kê thương hiệu'),_defineProperty(_Received_Amount$Payi,"CreateAdjustment",'Tạo điều chỉnh'),_defineProperty(_Received_Amount$Payi,"Afewwords",'Một vài từ ...'),_defineProperty(_Received_Amount$Payi,"UserImage",'Hình ảnh Người dùng'),_defineProperty(_Received_Amount$Payi,"UpdateProduct",'Cập nhật sản phẩm'),_defineProperty(_Received_Amount$Payi,"Brand",'Nhãn hiệu'),_defineProperty(_Received_Amount$Payi,"BarcodeSymbology",'Ký hiệu mã vạch'),_defineProperty(_Received_Amount$Payi,"ProductCost",'Giá thành sản phẩm'),_defineProperty(_Received_Amount$Payi,"ProductPrice",'Giá sản phẩm'),_defineProperty(_Received_Amount$Payi,"UnitProduct",'Sản phẩm đơn vị'),_defineProperty(_Received_Amount$Payi,"TaxMethod",'Phương pháp tính thuế'),_defineProperty(_Received_Amount$Payi,"MultipleImage",'Nhiều hình ảnh'),_defineProperty(_Received_Amount$Payi,"ProductHasMultiVariants",'Sản phẩm có nhiều biến thể'),_defineProperty(_Received_Amount$Payi,"ProductHasPromotion",'Sản phẩm có khuyến mãi'),_defineProperty(_Received_Amount$Payi,"PromotionStart",'Bắt đầu Quảng cáo'),_defineProperty(_Received_Amount$Payi,"PromotionEnd",'Kết thúc khuyến mại'),_defineProperty(_Received_Amount$Payi,"PromotionPrice",'Giá khuyến mãi'),_defineProperty(_Received_Amount$Payi,"Price",'Giá bán'),_defineProperty(_Received_Amount$Payi,"Cost",'Giá cả'),_defineProperty(_Received_Amount$Payi,"Unit",'Đơn vị'),_defineProperty(_Received_Amount$Payi,"ProductVariant",'Biến thể sản phẩm'),_defineProperty(_Received_Amount$Payi,"Variant",'Biến thể'),_defineProperty(_Received_Amount$Payi,"UnitPrice",'Đơn giá'),_defineProperty(_Received_Amount$Payi,"CreateReturnCustomer",'Tạo khách hàng trở lại'),_defineProperty(_Received_Amount$Payi,"EditReturnCustomer",'Chỉnh sửa khách hàng trở lại'),_defineProperty(_Received_Amount$Payi,"CreateReturnSupplier",'Tạo nhà cung cấp trở lại'),_defineProperty(_Received_Amount$Payi,"Documentation",'Tài liệu'),_defineProperty(_Received_Amount$Payi,"EditReturnSupplier",'Chỉnh sửa nhà cung cấp trả hàng'),_defineProperty(_Received_Amount$Payi,"FromWarehouse",'Từ kho hàng'),_defineProperty(_Received_Amount$Payi,"ToWarehouse",'Đến nhà kho'),_defineProperty(_Received_Amount$Payi,"EditTransfer",'Chỉnh sửa chuyển khoản'),_defineProperty(_Received_Amount$Payi,"TransferDetail",'Chi tiết chuyển khoản'),_defineProperty(_Received_Amount$Payi,"Pending",'Đang chờ xử lý'),_defineProperty(_Received_Amount$Payi,"Received",'Nhận'),_defineProperty(_Received_Amount$Payi,"Ordered",'Đã đặt hàng'),_defineProperty(_Received_Amount$Payi,"PermissionsManager",'Quản lý quyền'),_defineProperty(_Received_Amount$Payi,"BrandManager",'Nhãn hiệu'),_defineProperty(_Received_Amount$Payi,"BrandImage",'Hình ảnh thương hiệu'),_defineProperty(_Received_Amount$Payi,"BrandName",'Thương hiệu'),_defineProperty(_Received_Amount$Payi,"BrandDescription",'Mô tả thương hiệu'),_defineProperty(_Received_Amount$Payi,"BaseUnit",'Đơn vị cơ sở'),_defineProperty(_Received_Amount$Payi,"ManagerUnits",'Quản lý đơn vị'),_defineProperty(_Received_Amount$Payi,"OperationValue",'Giá trị hoạt động'),_defineProperty(_Received_Amount$Payi,"Operator",'Nhà điều hành'),_defineProperty(_Received_Amount$Payi,"Top5Products",'Năm sản phẩm hàng đầu'),_defineProperty(_Received_Amount$Payi,"Last5Sales",'Năm lần bán hàng gần đây nhất'),_defineProperty(_Received_Amount$Payi,"ListAdjustments",'Liệt kê các điều chỉnh'),_defineProperty(_Received_Amount$Payi,"ListTransfers",'Chuyển danh sách'),_defineProperty(_Received_Amount$Payi,"CreateTransfer",'Tạo chuyển khoản'),_defineProperty(_Received_Amount$Payi,"OrdersManager",'Quản lý đơn hàng'),_defineProperty(_Received_Amount$Payi,"ListQuotations",'Liệt kê Báo giá'),_defineProperty(_Received_Amount$Payi,"ListPurchases",'Liệt kê các giao dịch mua'),_defineProperty(_Received_Amount$Payi,"ListSales",'Liệt kê doanh số'),_defineProperty(_Received_Amount$Payi,"ListReturns",'Danh sách trả lại'),_defineProperty(_Received_Amount$Payi,"PeopleManager",'Quản lý con người'),_defineProperty(_Received_Amount$Payi,"Delete",{
Title:'Bạn có chắc không?',
Text:'Bạn sẽ không thể hoàn nguyên điều này!',
confirmButtonText:'Có, xóa nó!',
cancelButtonText:'Huỷ bỏ',
Deleted:'Đã xóa!',
Failed:'Thất bại!',
Therewassomethingwronge:'Có gì đó không ổn',
CustomerDeleted:'Khách hàng này đã bị xóa.',
SupplierDeleted:'Nhà cung cấp này đã bị xóa.',
QuoteDeleted:'Báo giá này đã bị xóa.',
SaleDeleted:'Giảm giá này đã bị xóa.',
PaymentDeleted:'Thanh toán này đã bị xóa.',
PurchaseDeleted:'Giao dịch mua này đã bị xóa.',
ReturnDeleted:'Trở lại này đã bị xóa.',
ProductDeleted:'Sản phẩm này đã bị xóa.',
ClientError:'Khách hàng này đã được liên kết với Hoạt động khác',
ProviderError:'Nhà cung cấp này đã được liên kết với Hoạt động khác',
UserDeleted:'Người dùng này đã bị xóa.',
UnitDeleted:'Đơn vị này đã bị xóa.',
RoleDeleted:'Vai trò này đã bị xóa.',
TaxeDeleted:'Thuế này đã bị xóa.',
SubCatDeleted:'Danh mục Phụ này đã bị xóa.',
CatDeleted:'Danh mục này đã bị xóa.',
WarehouseDeleted:'Kho này đã bị xóa.',
AlreadyLinked:'sản phẩm này đã được liên kết với Hoạt động khác',
AdjustDeleted:'Điều chỉnh này đã bị xóa.',
TitleCurrency:'Tiền tệ này đã bị xóa.',
TitleTransfer:'Chuyển khoản đã được xóa thành công',
BackupDeleted:'Bản sao lưu đã được xóa thành công',
TitleBrand:'Thương hiệu này đã bị xóa'}),
_defineProperty(_Received_Amount$Payi,"Update",{
TitleProfile:'Hồ sơ của bạn đã được cập nhật thành công',
TitleAdjust:'Đã cập nhật điều chỉnh thành công',
TitleRole:'Đã cập nhật vai trò thành công',
TitleUnit:'Đã cập nhật đơn vị thành công',
TitleUser:'Đã cập nhật người dùng thành công',
TitleCustomer:'Cập nhật khách hàng thành công',
TitleQuote:'Đã cập nhật báo giá thành công',
TitleSale:'Đã cập nhật ưu đãi thành công',
TitlePayment:'Đã cập nhật thanh toán thành công',
TitlePurchase:'Đã cập nhật giao dịch mua thành công',
TitleReturn:'Đã cập nhật trở lại thành công',
TitleProduct:'Cập nhật sản phẩm thành công',
TitleSupplier:'Đã cập nhật nhà cung cấp thành công',
TitleTaxe:'Đã cập nhật thuế thành công',
TitleCat:'Đã cập nhật danh mục thành công',
TitleWarhouse:'Đã cập nhật kho hàng thành công',
TitleSetting:'Đã cập nhật cài đặt thành công',
TitleCurrency:'Cập nhật tiền tệ thành công',
TitleTransfer:'Đã cập nhật chuyển khoản thành công',
TitleBrand:'Thương hiệu này đã được cập nhật'}),
_defineProperty(_Received_Amount$Payi,"Create",{
TitleBrand:'Thương hiệu này đã được tạo',
TitleRole:'Đã tạo vai trò thành công',
TitleUnit:'Đã tạo đơn vị thành công',
TitleUser:'Người dùng được tạo thành công',
TitleCustomer:'Khách hàng được tạo thành công',
TitleQuote:'Báo giá được tạo thành công',
TitleSale:'Giảm giá được tạo thành công',
TitlePayment:'Thanh toán được tạo thành công',
TitlePurchase:'Mua hàng đã được tạo thành công',
TitleReturn:'Đã tạo trả lại thành công',
TitleProduct:'Sản phẩm được tạo thành công',
TitleSupplier:'Đã tạo nhà cung cấp thành công',
TitleTaxe:'Đã tạo thuế thành công',
TitleCat:'Đã tạo danh mục thành công',
TitleWarhouse:'Đã tạo kho thành công',
TitleAdjust:'Đã tạo điều chỉnh thành công',
TitleCurrency:'Tiền tệ được tạo thành công',
TitleTransfer:'Đã tạo chuyển khoản thành công'}),
_defineProperty(_Received_Amount$Payi,"Send",{
TitleEmail:'Gửi email thành công'}),
_defineProperty(_Received_Amount$Payi,"return",{
TitleSale:'giảm giá này đã được liên kết với một Trả lại!'}),
_defineProperty(_Received_Amount$Payi,"ReturnManagement",'Quản lý trả hàng'),_defineProperty(_Received_Amount$Payi,"ReturnDetail",'Trả lại chi tiết'),_defineProperty(_Received_Amount$Payi,"EditReturn",'Chỉnh sửa lợi nhuận'),_defineProperty(_Received_Amount$Payi,"AddReturn",'Tạo lợi nhuận'),_defineProperty(_Received_Amount$Payi,"EmailReturn",'Gửi trở lại trong thư'),_defineProperty(_Received_Amount$Payi,"DeleteReturn",'Xóa trả lại'),_defineProperty(_Received_Amount$Payi,"Retoursurcharge",'Phụ phí trả hàng'),_defineProperty(_Received_Amount$Payi,"Laivrison",'chuyển'),_defineProperty(_Received_Amount$Payi,"SelectSale",'Chọn giảm giá'),_defineProperty(_Received_Amount$Payi,"ZeroPardefault",'Bạn có thể xóa mặt hàng hoặc đặt số lượng trả về 0 nếu hàng không được trả lại'),_defineProperty(_Received_Amount$Payi,"Return",'Trở về'),_defineProperty(_Received_Amount$Payi,"Purchase",'Mua'),_defineProperty(_Received_Amount$Payi,"TotalSales",'Tổng doanh số'),_defineProperty(_Received_Amount$Payi,"TotalPurchases",'Tổng số lần mua'),_defineProperty(_Received_Amount$Payi,"TotalReturns",'Tổng lợi nhuận'),_defineProperty(_Received_Amount$Payi,"PaiementsNet",'Thanh toán ròng'),_defineProperty(_Received_Amount$Payi,"PaiementsSent",'Thanh toán đã gửi'),_defineProperty(_Received_Amount$Payi,"PaiementsReceived",'Đã nhận thanh toán'),_defineProperty(_Received_Amount$Payi,"Recieved",'Nhận'),_defineProperty(_Received_Amount$Payi,"Sent",'Gởi'),_defineProperty(_Received_Amount$Payi,"ProductQuantityAlerts",'Cảnh báo số lượng sản phẩm'),_defineProperty(_Received_Amount$Payi,"ProductCode",'Mã'),_defineProperty(_Received_Amount$Payi,"ProductName",'Sản phẩm'),_defineProperty(_Received_Amount$Payi,"AlertQuantity",'Số lượng cảnh báo'),_defineProperty(_Received_Amount$Payi,"WarehouseStockChart",'Warehouse Stock Chart'),_defineProperty(_Received_Amount$Payi,"TotalProducts",'Tổng số sản phẩm'),_defineProperty(_Received_Amount$Payi,"TotalQuantity",'Tổng số lượng'),_defineProperty(_Received_Amount$Payi,"TopCustomers",'Năm khách hàng hàng đầu'),_defineProperty(_Received_Amount$Payi,"TotalAmount",'Tổng cộng'),_defineProperty(_Received_Amount$Payi,"TotalPaid",'Tổng số chi trả'),_defineProperty(_Received_Amount$Payi,"CustomerSalesReport",'Báo cáo bán hàng của khách hàng'),_defineProperty(_Received_Amount$Payi,"CustomerPaiementsReport",'Báo cáo thanh toán của khách hàng'),_defineProperty(_Received_Amount$Payi,"CustomerQuotationsReport",'Báo cáo báo giá khách hàng'),_defineProperty(_Received_Amount$Payi,"Payments",'Thanh toán'),_defineProperty(_Received_Amount$Payi,"TopSuppliers",'Năm nhà cung cấp hàng đầu'),_defineProperty(_Received_Amount$Payi,"SupplierPurchasesReport",'Báo cáo mua hàng của nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"SupplierPaiementsReport",'Báo cáo thanh toán của nhà cung cấp'),_defineProperty(_Received_Amount$Payi,"Name",'Tên'),_defineProperty(_Received_Amount$Payi,"Code",'Mã'),_defineProperty(_Received_Amount$Payi,"ManagementWarehouse",'Quản lý kho'),_defineProperty(_Received_Amount$Payi,"ZipCode",'Mã Bưu Chính'),_defineProperty(_Received_Amount$Payi,"managementCategories",'Quản lý danh mục'),_defineProperty(_Received_Amount$Payi,"Codecategorie",'Loại mã'),_defineProperty(_Received_Amount$Payi,"Namecategorie",'Tên loại'),_defineProperty(_Received_Amount$Payi,"Parentcategorie",'Gia phả'),_defineProperty(_Received_Amount$Payi,"managementTax",'Quản lý thuế'),_defineProperty(_Received_Amount$Payi,"TaxName",'Tên thuế'),_defineProperty(_Received_Amount$Payi,"TaxRate",'Thuế suất'),_defineProperty(_Received_Amount$Payi,"managementUnitPurchases",'Đơn vị mua hàng'),_defineProperty(_Received_Amount$Payi,"managementUnitSales",'Đơn vị bán hàng'),_defineProperty(_Received_Amount$Payi,"ShortName",'Tên ngắn'),_defineProperty(_Received_Amount$Payi,"PleaseSelectThesebeforeaddinganyproduct",'Vui lòng chọn những thứ này trước khi thêm bất kỳ sản phẩm nào'),_defineProperty(_Received_Amount$Payi,"StockAdjustement",'Điều chỉnh chứng khoán'),_defineProperty(_Received_Amount$Payi,"PleaseSelectWarehouse",'Vui lòng chọn kho trước khi chọn bất kỳ sản phẩm nào'),_defineProperty(_Received_Amount$Payi,"StockTransfer",'Chuyển nhượng chứng khoán'),_defineProperty(_Received_Amount$Payi,"SelectPeriod",'Chọn khoảng thời gian'),_defineProperty(_Received_Amount$Payi,"ThisYear",'Năm nay'),_defineProperty(_Received_Amount$Payi,"ThisToday",'Hôm nay'),_defineProperty(_Received_Amount$Payi,"ThisMonth",'Tháng này'),_defineProperty(_Received_Amount$Payi,"ThisWeek",'Tuần này'),_defineProperty(_Received_Amount$Payi,"AdjustmentDetail",'Chi tiết điều chỉnh'),_defineProperty(_Received_Amount$Payi,"ActivateUser",'Người dùng này đã được kích hoạt'),_defineProperty(_Received_Amount$Payi,"DisActivateUser",'Người dùng này đã bị vô hiệu hóa'),_defineProperty(_Received_Amount$Payi,"NotFound",'Không tìm thấy trang.'),_defineProperty(_Received_Amount$Payi,"oops",'Lỗi! Không tìm thấy trang.'),_defineProperty(_Received_Amount$Payi,"couldNotFind",'Chúng tôi không thể tìm thấy trang bạn đang tìm kiếm. Trong khi đó, bạn có thể'),_defineProperty(_Received_Amount$Payi,"ReturnDashboard",'trở lại trang tổng quan'),_Received_Amount$Payi);

/***/},

/***/0:
/*!*********************************************************************************************!*\
  !*** multi ./resources/src/main.js ./resources/src/assets/styles/sass/globals/globals.scss ***!
  \*********************************************************************************************/
/*! no static exports found */
/***/function _(module,exports,__webpack_require__){

__webpack_require__(/*! C:\projects\stocky\resources\src\main.js */"./resources/src/main.js");
module.exports=__webpack_require__(/*! C:\projects\stocky\resources\src\assets\styles\sass\globals\globals.scss */"./resources/src/assets/styles/sass/globals/globals.scss");


/***/}

/******/});

}());
